//  Persistence of Vision Raytracer V3.5

//  Date : 01/17/2005    (17.01.2005)
//  Marc Jacquier  jan 2005

/* 
Please render at 3/4 ratio (+w690 +h1280 for instance)
Render 1st pass with 
#declare use_rad=1;
in "la_jument_source.pov"
Render 2nd pass with
#declare use_rad=2; 


Created with Moray 3.5, z is up!!

*/
#version 3.5;
#declare use_rad=2;
global_settings{

 #if (use_rad)
 radiosity{ 
  
  #if (use_rad=1) 
    pretrace_start 0.08
    pretrace_end   0.04
    count 35
    nearest_count 20
    error_bound 1
    recursion_limit 3
    low_error_factor .9
    gray_threshold 0
    minimum_reuse 0.015
    brightness 1.0
    adc_bailout 0.01/2
    save_file "rad-save-load.rad"
  #else
    
    pretrace_start 1 pretrace_end 1 
    load_file "rad-save-load.rad" 
    error_bound .5    
    recursion_limit 3  
    always_sample off  
  #end
 }
 #end
}



default {
  texture {
    pigment { rgb <1,0,0> }
  }
}


// Scene Includes

#include "functions.inc"

// End Scene Includes

global_settings {
  adc_bailout 0.05
  ambient_light <1.0,1.0,1.0>
  assumed_gamma 1.9
  hf_gray_16 off
  irid_wavelength <0.247059,0.176471,0.137255>
  max_intersections 64
  max_trace_level 10
  number_of_waves 10
  noise_generator 2
  charset ascii
}

background { color <0.565,0.620,0.745> }

fog {
  fog_type 2    // Ground Fog
  distance     1000.0
  color <0.223529,0.239216,0.270588,0.0,0.0>
  up           <0,0,1>
  fog_offset   0.0
  fog_alt      200.0
}

camera {  //  Camera Camera01
  location  <    -33.547,     -69.377,       1.750>
  sky       <    0.00000,     0.00000,     1.00000> // Use right handed-system 
  up        <        0.0,         0.0,         1.0> // Where Z is up
  right     <    0.74398,         0.0,         0.0> // Right Vector is adjusted to compensate for spherical (Moray) vs. planar (POV-Ray) aspect ratio
  angle         20.00000    // Vertical      26.667
  look_at   <     -4.440,     -14.967,      10.144>
}

//
// *******  L I G H T S *******
//

#declare Soleil = light_source {
  <0.0, 0.0, 0.0>
  color rgb <1.000, 0.800, 0.600>*2.5000
  media_attenuation on
  photons {
  }
  translate  4078.583233*z
}

#declare Soleil_nuage = light_source {
  <0.0, 0.0, 0.0>
  color rgb <1.000, 1.000, 1.000>*1.1000
  photons {
  }
  translate  4078.583233*z
}


//
// ********  MATERIALS  *******
//

#include "la_jument_grain_rc4.inc"


//
// ********  REFERENCED OBJECTS  *******
//                                          

// Macro_IsoRbox
#macro IsoRBoxN (Vec1,Vec2,Arr,F,A)

 #local vMin = <min(Vec1.x,Vec2.x),min(Vec1.y,Vec2.y),min(Vec1.z,Vec2.z)>;
 #local vMax = <max(Vec1.x,Vec2.x),max(Vec1.y,Vec2.y),max(Vec1.z,Vec2.z)>; 
 #local LX = vMax.x - vMin.x;
 #local LY = vMax.y - vMin.y;
 #local LZ = vMax.z - vMin.z;
 #declare f_wrinkles_moi=function{pattern{wrinkles translate Vec1*vlength(Vec1-Vec2)}};
 
isosurface {
 function {f_rounded_box (x,y,z,Arr,LX/2,LY/2,LZ/2) +( f_wrinkles_moi(x*F,y*F,z*F)-.5)*A }
 threshold 0
max_gradient 1.5
 contained_by {box {-<LX,LY,LZ>*1.5,<LX,LY,LZ>*1.5}}
 translate <LX/2,LY/2,LZ/2>
 translate vMin
}
#undef f_wrinkles_moi 
#end



// Macro_fenetres_mur
#macro Fenetre_murs()
#declare Ht_dep_fenetres=Bs;
#declare Dist_fenetres=2.5*.92;
#declare N_fenetres=5;
#declare Cnt_trous=0;
#declare U_trous=union{
#while(Cnt_trous<N_fenetres)
object{Trou_fenetre scale<.8,1,.8>  translate <0,R1,(Ht_dep_fenetres+Dist_fenetres*Cnt_trous)>}
#declare Cnt_trous=Cnt_trous+1;
#end
}
difference{object{Mur_tour} object{U_trous}}




#declare Cnt_trous=0;
union{
#while(Cnt_trous<N_fenetres)
union {Fenetre() 
object{Menuiserie}scale<.8,1,.8> translate z*Dist_fenetres*Cnt_trous}
#declare Cnt_trous=Cnt_trous+1;
#end
Reorient_Trans(z,(<0,R2,Ht>-<0,R1,Bs>)) 
 translate <0,R1,(Ht_dep_fenetres)>
}
#end





// Macro_chainage
#include"transforms.inc" 
#local S_trans=seed(0);

#local S_pig=seed(10);


#macro Chaine(Rayon1,Rayon2,Bas,Haut)
#local  X_coin1=Rayon1*.41421;
#local  X_coin2=Rayon2*.41421;
#local V1=<X_coin1,Rayon1,Bas>;
#local V2=<X_coin2,Rayon2,Haut> ;

#local  Arr=0.01;
#local F=20;
#local A=0.008;



#local H_chaine=vlength(V2-V1);
#local H_pierre=.25;
#local Nombre_chaine= H_chaine/H_pierre;
#local Prof_chaine=0.4;
#local Larg_long=.3;
#local Larg_courte=.2;
#local Cnt=0;

union{
#while (Cnt< Nombre_chaine)
     union{  object{ IsoRBoxN (<-Arr*2,-.02 ,H_pierre*Cnt>,<Larg_long, Prof_chaine,  H_pierre*(Cnt+1)>,Arr,F,A)rotate z*0}
       object{ IsoRBoxN (<Arr*2,-.02,H_pierre*Cnt>,<-Larg_long, Prof_chaine, H_pierre*(Cnt+1)>,Arr,F,A )rotate z*-45}
texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}
}
union{
       object{ IsoRBoxN (<-Arr*2,-.02, H_pierre*(Cnt+1)>,< Larg_courte, Prof_chaine,  H_pierre*(Cnt+2)>,Arr,F,A)rotate z*0}
       object{ IsoRBoxN (<Arr*2,-.02, H_pierre*(Cnt+1)>,<- Larg_courte, Prof_chaine,   H_pierre*(Cnt+2)>,Arr,F,A )rotate z*-45}
texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}
 }
#local Cnt=Cnt+2;
#end
Reorient_Trans(z,(V2-V1))
 translate V1//*<1,1,0>
}
#end
#macro Tour_chainage(R1,R2,Bs,Ht)
#declare Cnt_tour=0;
#while (Cnt_tour<8)
object {Chaine(R1,R2,Bs,Ht) rotate z*45*Cnt_tour}
#declare Cnt_tour=Cnt_tour+1;
#end
#end



// Macro_empierrement1
#include"transforms.inc" 

#macro Tour_empierre(Rayon1,Rayon2,Bas,Haut,Prof, Octet)
#local  X_coin1=Rayon1*.41421;
#local X_coin2=Rayon2*.41421;
#local V1=<X_coin1,Rayon1,Bas>;
#local V2=<X_coin2,Rayon2,Haut> ;


#declare Larg_brick=.28;
#declare Prof_brick=0.3;
#declare Haut_brick=0.10;
#declare Mortier=0.0005;
#declare F_brick=
function{
   pigment   {      brick        
      brick_size < Larg_brick, Haut_brick, Prof_brick>
      mortar Mortier

scale.001     }
}
 #declare f_wrinkles_moi=function{pattern{wrinkles}};
#declare Mur_tour=
isosurface {
function{-y-(f_brick(x*25,z*25,y*25)*Prof)+f_wrinkles_moi(x*10,y*10,z*10)*.02 }
 threshold 0
max_gradient 4
 contained_by {box {<-V2.x,-1,0>,<V2.x,Prof_brick,(V2-V1).z>}}
Reorient_Trans(z,(V2-V1)*<0,1,1>) 
translate<0,V1.y,V1.z>
texture{M_granite}
}
#undef F_brick
#undef f_wrinkles_moi

#declare Cnt_tour=0; 
#while (Cnt_tour<8)
#if (val(substr(Octet,Cnt_tour+1,1) )=1)
object{Mur_tour rotate z*45*Cnt_tour}
#end
#declare Cnt_tour=Cnt_tour+1;
#end

#end



// Macro_corbeau
#macro M_corbeau(R,Ht)
#local X_coin=R*0.4142;

union{
object{Corbeau_plein translate <0,R,Ht>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
union{
object{Corbeau_coin translate<X_coin,R,Ht>}
object{Corbeau_coin translate<X_coin,R,Ht>scale<-1,1,1> rotate z*-45}texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}
}
object{Corbeau_plein translate <(X_coin+.11)/2,R,Ht> scale<-1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
object{Corbeau_plein translate <(X_coin+.11)/2,R,Ht> texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
}
#end

#macro Tour_Corbeau(R,Ht)
#declare Cnt_tour=0;

#while (Cnt_tour<8)
object{ M_corbeau(R,Ht) rotate z*45*Cnt_tour}
#declare Cnt_tour=Cnt_tour+1;
#end

#end



// Macro_soleplate
#macro M_soleplate(R,Ht)
#local X_coin=R*0.4142;
#local  Arr=0.01;
#local F=20;
#local A=0.008;

union{ 
object{ IsoRBoxN (<0,0,0>,<(X_coin+.11)/2, 0.5, 0.1>,Arr,F,A) translate <0,R,Ht>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
union{
object{ IsoRBoxN (<X_coin,0,0>,<(X_coin+.11)/2,.5,.1>,Arr,F,A) translate<0,R,Ht>}
object{ IsoRBoxN (<X_coin,0,0>,<(X_coin+.11)/2,.5,.1>,Arr,F,A) translate<0,R,Ht> scale<-1,1,1> rotate z*-45}texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}
}
object{ IsoRBoxN (<0,0,0>,<(X_coin+.11)/2,.5,.1>,Arr,F,A) translate <0,R,Ht> scale<-1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
}
#end

#macro Tour_soleplate(R,Ht)
#declare Cnt_tour=0;

#while (Cnt_tour<8)
object{ M_soleplate(R,Ht) rotate z*45*Cnt_tour}
#declare Cnt_tour=Cnt_tour+1;
#end

#end



// Macro_solehaute
#macro M_solehaute(R,Ht)
#local X_coin=R*0.4142;
#local  Arr=0.01;
#local F=20;
#local A=0.008;

union{ 
object{ IsoRBoxN (<(X_coin-.11)/4,0,0>,<-(X_coin+.11)/4, 0.5, 0.25>,Arr,F,A) translate <0,R,Ht>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
union{
object{ IsoRBoxN (<X_coin,0,0>,<(X_coin+.28),.5,.25>,Arr,F,A) translate<0,R,Ht>}
object{ IsoRBoxN (<X_coin,0,0>,<(X_coin+.28),.5,.25>,Arr,F,A) translate<0,R,Ht> scale<-1,1,1> rotate z*-45}texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}
}
object{ IsoRBoxN (<(X_coin+.28),0,0>,<(X_coin+.11)/4,.5,.25>,Arr,F,A) translate <0,R,Ht> scale<1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
object{ IsoRBoxN (<(X_coin+.28),0,0>,<(X_coin+.11)/4,.5,.25>,Arr,F,A) translate <0,R,Ht> scale<-1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
}

#end

#macro Tour_solehaute(R,Ht)
#declare Cnt_tour=0;

#while (Cnt_tour<8)
object{ M_solehaute(R,Ht) rotate z*45*Cnt_tour}
#declare Cnt_tour=Cnt_tour+1;
#end

#end



// Macro_chanfrein
#macro M_chanfrein(R,Ht)
#local X_coin=R*0.4142;
#local  Arr=0.01;
#local F=20;
#local A=0.008;
#local Rot=-35;

union{ 
object{ IsoRBoxN (<(X_coin-.11)/4,0,0>,<-(X_coin+.11)/4, 0.5, 0.25>,Arr,F,A) rotate x*Rot translate <0,R,Ht>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
union{
difference{
object{ IsoRBoxN (<X_coin-.2,0,0>,<(X_coin+.28),.5,.25>,Arr,F,A) rotate x*Rot translate<0,R,Ht>}
box {<0,-.7,-.3>,<-.35,.7,.5>rotate z*-22.5  translate<X_coin,R,Ht>  }
}
difference{
object{ IsoRBoxN (<X_coin-.2,0,0>,<(X_coin+.28),.5,.25>,Arr,F,A) rotate x*Rot translate<0,R,Ht>}
box {<0,-.7,-.3>,<-.35,.7,.5>rotate z*-22.5  translate<X_coin,R,Ht>  }
 scale<-1,1,1> rotate z*-45
}

texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}

}


object{ IsoRBoxN (<(X_coin+.28),0,0>,<(X_coin+.11)/4,.5,.25>,Arr,F,A)  rotate x*Rot translate <0,R,Ht> scale<1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
object{ IsoRBoxN (<(X_coin+.28),0,0>,<(X_coin+.11)/4,.5,.25>,Arr,F,A)  rotate x*Rot translate <0,R,Ht> scale<-1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}

}

 


#end

#macro Tour_chanfrein(R,Ht)
#declare Cnt_tour=0;

#while (Cnt_tour<8)
object{ M_chanfrein(R,Ht) rotate z*45*Cnt_tour}
#declare Cnt_tour=Cnt_tour+1;
#end

#end



// Macro_fenetres_mur1
#macro Fenetre_murs2(R2)
#declare Ht_dep_fenetres=18.8;

#declare N_fenetres=1;



#declare Mur_trou=
difference{object{Mur_tour} object{Trou_fenetre   translate <0,R2,Ht_dep_fenetres+1>}}





#declare Mur_fenetre_rotonde=
union{
union {Fenetre() object{Menuiserie}  translate <0,R2,(Ht_dep_fenetres+1)>}
object{ Mur_trou}

}

object{Mur_fenetre_rotonde}
object{Mur_fenetre_rotonde rotate z*90}
object{Mur_fenetre_rotonde rotate z*-90}

#end



#declare Nuage2 = object {
  box { // Nuage2
    <-1, -1, -1>, <1, 1, 1>
    scale <0.9, 0.8, 0.5>
    rotate <-0.0, 0.0, -0.0>
    translate  0.17*z
    material {
      Mat_Nuage_media_1
    }
    no_image
    hollow
    scale <353.023529, 550.656616, 258.17923>
    rotate 13.802025*z
    translate  <-61.497792, 507.098275, 84.312721>
  }
}


#declare Nuage = object {
  box { // Nuage
    <-1, -1, -1>, <1, 1, 1>
    scale <0.9, 0.8, 0.5>
    rotate <-0.0, 0.0, -0.0>
    translate  0.17*z
    material {
      Mat_Nuage_media
    }
    no_reflection
    hollow
    scale <353.023529, 550.656616, 258.17923>
    rotate 13.802025*z
    translate  <-61.497792, 507.098275, 84.312721>
  }
}




#declare Cube036 = object {
  box { // Cube036
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    scale <0.7, 0.08, 1.9>
    translate  <0.0, -1.869294, 4.966013>
  }
}
#declare Cube083 = object {
  box { // Cube083
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    material {
      T_peinture_Bois
    }
    scale <0.02, 0.07, 0.6>
    translate  <-0.2285, -1.869294, 6.119618>
  }
}
#declare Cube085 = object {
  box { // Cube085
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    material {
      T_peinture_Bois
    }
    scale <0.02, 0.07, 0.476938>
    rotate 90.0*y
    translate  <-0.238852, -1.869294, 6.119618>
  }
}
#declare Moulures_porte = union {
  object { Cube083 }
  object { // Cube084 -> Cube083
    Cube083
    scale <-1.0, 1.0, 1.0>
    translate  <0.0, 0.0, 0.0>
  }
  object { Cube085 }
  object { // Cube086 -> Cube085
    Cube085
    rotate <-0.0, -0.0, 0.0>
    translate  0.592171*z
  }
  translate  -0.078842*z
}
#declare Cube080 = object {
  box { // Cube080
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    material {
      T_peinture_Bois
    }
    scale <0.02, 0.07, 1.9>
    translate  <-0.362901, -1.869294, 4.966013>
  }
}
#declare Torus005 = object {
  torus { // Torus005
    1.7, 0.03  rotate -x*90
    rotate -90.0*x
    translate  34.2*z
  }
}
#declare Cylndr003 = object {
  cylinder { // Cylndr003
    <0,0,1>, <0,0,0>, 1 
    scale <0.04, 0.04, 0.55>
    rotate -135.0*y
    translate  37.213386*z
  }
}
#declare Cylndr004 = object {
  cylinder { // Cylndr004
    <0,0,1>, <0,0,0>, 1 
    scale <0.04, 0.04, 0.55>
    rotate <0.0, -122.0, -11.25>
    translate  37.213386*z
  }
}
// Include contains 'TransSweep029'
#include "la_jument_grain_rc4.in1"

#declare TransSweep029 = object {
  TransSweep029_Raw
  rotate <-0.0, -0.0, 0.0>
  translate  <-0.257005, 0.0, -0.005085>
  photons {
    collect off
  }
  scale <0.3, 0.207743, 0.207743>
  rotate <90.0, 0.0, -115.892746>
  translate  <0.008801, 0.022621, 0.908441>
}
#declare Cube140 = object {
  box { // Cube140
    <-1, -1, -1>, <1, 1, 1>
    translate  1.07983*x
    scale <0.801051, 0.03, 0.03>
    translate  33.639646*z
  }
}
#declare REnfort_vitre_circulaire = difference {
  cylinder { // Cylndr048
    <0,0,1>, <0,0,0>, 1 
    scale <1.68, 1.68, 0.04>
    translate  31.001*z
  }
  cylinder { // Cylndr049
    <0,0,1>, <0,0,0>, 1 
    scale <1.66, 1.66, 0.05>
    translate  30.996708*z
  }
}
#declare Cylndr075 = object {
  cylinder { // Cylndr075
    <0,0,1>, <0,0,0>, 1 
    scale <0.02, 0.01, 1.0>
    translate  -1.66*y
    scale <1.0, 1.0, 2.49>
    translate  31.0*z
  }
}
#declare coupe_cerclage = intersection {
  box { // Cube066
    <-1, -1, -1>, <1, 1, 1>
    rotate 0.0*z
    translate  <1.001508, 1.0, 0.0>
    scale <0.349823, 0.217329, 1.0>
    translate  <0.499627, -0.435243, 0.0>
  }
  torus { // Torus004
    2.0, 0.02  rotate -x*90
    scale <1.0, 1.0, 0.5>
    translate  1.5*y
  }
}
#declare Face_cerclage = union {
  torus { // Torus003
    0.5, 0.01  rotate -x*90
    scale <1.0, 1.0, 3.0>
    rotate -90.0*x
    translate  -0.438945*y
  }
  object { coupe_cerclage }
  object { // coupe_cerclage1 -> coupe_cerclage
    coupe_cerclage
    rotate -45.0*y
  }
  object { // coupe_cerclage2 -> coupe_cerclage
    coupe_cerclage
    rotate -90.0*y
  }
  object { // coupe_cerclage3 -> coupe_cerclage
    coupe_cerclage
    rotate <180.0, -45.0, 180.0>
  }
  object { // coupe_cerclage4 -> coupe_cerclage
    coupe_cerclage
    rotate <180.0, 0.0, 180.0>
  }
  object { // coupe_cerclage5 -> coupe_cerclage
    coupe_cerclage
    rotate <180.0, 45.0, 180.0>
  }
  object { // coupe_cerclage6 -> coupe_cerclage
    coupe_cerclage
    rotate 90.0*y
  }
  object { // coupe_cerclage7 -> coupe_cerclage
    coupe_cerclage
    rotate 45.0*y
  }
  cylinder { // Cylndr072
    <0,0,1>, <0,0,0>, 1 
    translate  <0.0, -0.09024, -0.5>
    scale <0.015, 0.03, 1.0>
    translate  -0.453742*y
  }
  material {
    T_bronze
  }
}
#declare Cylndr071 = object {
  cylinder { // Cylndr071
    <0,0,1>, <0,0,0>, 1 
    translate  -0.5*z
    scale <1.19, 1.19, 1.0>
    rotate -90.0*x
  }
}
#declare Sphere006 = object {
  sphere { // Sphere006
    <0,0,0>,1
    bounded_by { // Bound00001
      box {
        <-1.0, -1.0, -1.0>, <1.0, 1.0, 1.0>
        scale 1.04
        translate  <-0.0, 0.0, 0.0>
      }
    }
    scale 2.0
    translate  1.5*y
  }
}
#declare RndCube001 = merge {
  sphere { <0.0000, 0.0200, 0.6400>, 0.0100 }
  sphere { <0.0000, -0.0200, 0.6400>, 0.0100 }
  sphere { <0.0000, 0.0200, -0.6400>, 0.0100 }
  sphere { <0.0000, -0.0200, -0.6400>, 0.0100 }
  cylinder { <0.0000, 0.0200, -0.6400>, <0.0000, 0.0200, 0.6400>, 0.0100 }
  cylinder { <0.0000, -0.0200, -0.6400>, <0.0000, -0.0200, 0.6400>, 0.0100 }
  cylinder { <0.0000, 0.0200, 0.6400>, <0.0000, -0.0200, 0.6400>, 0.0100 }
  cylinder { <0.0000, 0.0200, -0.6400>, <0.0000, -0.0200, -0.6400>, 0.0100 }
  box { <-0.0100, -0.0200, -0.6400> <0.0100, 0.0200, 0.6400> }
  translate  <-0.4, 0.6, 0.7>
}
#declare RndCube003 = merge {
  sphere { <0.4000, 0.0200, 0.0000>, 0.0100 }
  sphere { <0.4000, -0.0200, 0.0000>, 0.0100 }
  sphere { <-0.4000, -0.0200, 0.0000>, 0.0100 }
  sphere { <-0.4000, 0.0200, 0.0000>, 0.0100 }
  cylinder { <0.4000, 0.0200, 0.0000>, <-0.4000, 0.0200, 0.0000>, 0.0100 }
  cylinder { <0.4000, -0.0200, 0.0000>, <-0.4000, -0.0200, 0.0000>, 0.0100 }
  cylinder { <0.4000, 0.0200, 0.0000>, <0.4000, -0.0200, 0.0000>, 0.0100 }
  cylinder { <-0.4000, 0.0200, 0.0000>, <-0.4000, -0.0200, 0.0000>, 0.0100 }
  box { <-0.4000, -0.0200, -0.0100> <0.4000, 0.0200, 0.0100> }
  translate  <0.0, 0.6, 0.7>
  translate  0.639953*z
}
#declare RndCube004 = merge {
  sphere { <0.0000, 0.0200, 0.6400>, 0.0100 }
  sphere { <0.0000, -0.0200, 0.6400>, 0.0100 }
  sphere { <0.0000, 0.0200, -0.6400>, 0.0100 }
  sphere { <0.0000, -0.0200, -0.6400>, 0.0100 }
  cylinder { <0.0000, 0.0200, -0.6400>, <0.0000, 0.0200, 0.6400>, 0.0100 }
  cylinder { <0.0000, -0.0200, -0.6400>, <0.0000, -0.0200, 0.6400>, 0.0100 }
  cylinder { <0.0000, 0.0200, 0.6400>, <0.0000, -0.0200, 0.6400>, 0.0100 }
  cylinder { <0.0000, 0.0200, -0.6400>, <0.0000, -0.0200, -0.6400>, 0.0100 }
  box { <-0.0100, -0.0200, -0.6400> <0.0100, 0.0200, 0.6400> }
  translate  <0.0, 0.6, 0.7>
}
#declare RndCube005 = merge {
  sphere { <0.4000, 0.0200, 0.0000>, 0.0100 }
  sphere { <0.4000, -0.0200, 0.0000>, 0.0100 }
  sphere { <-0.4000, -0.0200, 0.0000>, 0.0100 }
  sphere { <-0.4000, 0.0200, 0.0000>, 0.0100 }
  cylinder { <0.4000, 0.0200, 0.0000>, <-0.4000, 0.0200, 0.0000>, 0.0100 }
  cylinder { <0.4000, -0.0200, 0.0000>, <-0.4000, -0.0200, 0.0000>, 0.0100 }
  cylinder { <0.4000, 0.0200, 0.0000>, <0.4000, -0.0200, 0.0000>, 0.0100 }
  cylinder { <-0.4000, 0.0200, 0.0000>, <-0.4000, -0.0200, 0.0000>, 0.0100 }
  box { <-0.4000, -0.0200, -0.0100> <0.4000, 0.0200, 0.0100> }
  translate  0.6*y
  translate  0.451808*z
}
#declare Cadre_opt_carre = union {
  object { RndCube001 }
  object { // RndCube002 -> RndCube001
    RndCube001
    scale <-1.0, 1.0, 1.0>
  }
  object { RndCube003 }
  object { RndCube004 }
  object { RndCube005 }
  box { // Cube067
    <-1, -1, -1>, <1, 1, 1>
    translate  1.0*z
    scale <0.39549, 0.021581, 0.440953>
    translate  <0.0, 0.598581, 0.453781>
    material {
      Mat_verre_lentille_plane
      // Transform to parent space
    }
  }
  material {
    T_bronze
  }
  translate  -1.559085*z
}
#declare Coupe_pied_optique = difference {
  box { // Cube068
    <-1, -1, -1>, <1, 1, 1>
    translate  1.0*z
    scale <0.158094, 0.120042, 0.299512>
    translate  -0.620622*x
  }
  object { // Cylndr073 -> Cylndr071
    Cylndr071
    translate  1.5*z
  }
  material {
    T_bronze
  }
  translate  -1.5*z
}
#declare REnfort_vitre_circulaire4 = difference {
  cylinder { // Cylndr077
    <0,0,1>, <0,0,0>, 1 
    scale <1.65, 1.65, 0.05>
    translate  31.001*z
  }
  cylinder { // Cylndr078
    <0,0,1>, <0,0,0>, 1 
    scale <1.56, 1.56, 0.06>
    translate  30.996708*z
  }
  material {
    T_peinture_Bois
  }
}
#declare Cube114 = object {
  box { // Cube114
    <-1, -1, -1>, <1, 1, 1>
    scale <1.0, 0.7, 0.5>
    translate  <0.0, -40.5, 0.5>
    scale <0.03, 0.04, 2.49>
    translate  <0.0, 0.000008, 31.0>
  }
}
#declare CSG002 = difference {
  box { // Cube059
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.0, 0.5>
    scale <1.55195, 1.897915, 1.86>
    translate  <1.216349, 0.0, 29.0>
  }
  box { // Cube060
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.0, 0.5>
    scale <1.388993, 2.294014, 1.9>
    translate  <1.205166, -0.0671, 29.0>
  }
  box { // Cube063
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.0, 0.5>
    scale <0.370299, 0.845552, 0.445577>
    translate  <2.503205, 0.0, 30.103245>
  }
}
#declare Cabine = union {
  object { CSG002 }
  box { // Cube064
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.0, 0.5>
    material {
      Mat_verre_
    }
    scale <0.031442, 0.905685, 0.543518>
    translate  <2.588713, 0.0, 30.055808>
  }
  box { // Cube061
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.499762, 0.5>
    scale <1.638011, 2.005028, 0.08>
    translate  <1.205166, -0.981338, 30.849617>
  }
  box { // Cube062
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.499762, 0.5>
    scale <-0.527738, 0.183718, 0.08>
    rotate -22.5*z
    translate  <2.771488, -1.149986, 30.849617>
  }
  box { // Cube065
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.499762, 0.5>
    scale <-0.2529, 0.185, -1.848935>
    rotate -22.5*z
    translate  <2.697739, -1.118588, 30.849617>
  }
  box { // Cube069
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.499762, 0.5>
    scale <-0.2529, 0.185, -1.848935>
    rotate 22.5*z
    translate  <2.766751, 0.949088, 30.849617>
  }
  box { // Cube070
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.499762, 0.5>
    scale <-1.492729, 0.183646, -1.848935>
    translate  <2.699038, 0.935546, 30.849617>
  }
  box { // Cube071
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.499762, 0.5>
    scale <-0.2529, 0.185, 0.08>
    rotate 22.5*z
    translate  <2.846697, 1.025303, 30.849617>
  }
  box { // Cube072
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.499762, 0.5>
    scale <-1.570963, 0.185, 0.08>
    translate  <2.775721, 1.011146, 30.849617>
  }
  material {
    T_peinture_rouge_norm
  }
}
#declare Cylndr035 = object {
  cylinder { // Cylndr035
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 0.7>
    translate  <2.15, 0.6, 0.0>
  }
}
#declare Coupe_tore_rembarde_cabine = intersection {
  torus { // Torus027
    0.1, 0.015  rotate -x*90
    translate  <-0.002914, 0.0, 0.7>
  }
  box { // Cube026
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, 1.0, 0.0>
    scale <0.12, 0.12, 0.02>
    translate  0.7*z
  }
  translate  <2.053409, 0.822544, 23.3>
}
#declare Cube027 = object {
  box { // Cube027
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, 1.0, 0.0>
    scale <0.12, 0.12, 0.02>
    rotate -89.841866*z
    translate  0.7*z
  }
}
#declare Diedre = intersection {
  object { Cube027 }
  object { // Cube028 -> Cube027
    Cube027
    rotate 49.277088*z
  }
}
#declare Coupe_tore_rembarde_cabine1 = intersection {
  torus { // Torus028
    0.1, 0.015  rotate -x*90
    translate  <-0.002914, 0.0, 0.7>
  }
  object { Diedre }
  translate  <2.05472, -0.854123, 23.3>
}
#declare Diedre1 = intersection {
  box { // Cube029
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, 1.0, 0.0>
    scale <0.12, 0.12, 0.02>
    rotate -55.237579*z
    translate  0.7*z
  }
  object { // Cube030 -> Cube027
    Cube027
    rotate 68.273842*z
  }
  rotate -125.678284*z
}
#declare Coupe_tore_rembarde_cabine2 = intersection {
  torus { // Torus029
    0.1, 0.015  rotate -x*90
    translate  <-0.002914, 0.0, 0.7>
  }
  object { Diedre1 }
  translate  <1.568015, 1.021458, 23.3>
}
#declare Coupe_tore_rembarde_cabine3 = intersection {
  torus { // Torus030
    0.1, 0.015  rotate -x*90
    translate  <-0.002914, 0.0, 0.7>
  }
  box { // Cube031
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, 1.0, 0.0>
    scale <0.12, 0.12, 0.02>
    translate  0.7*z
  }
  scale -1.0
  rotate <180.0, 0.0, 134.842712>
  translate  <0.91936, -1.981567, 23.3>
}
#declare Coupe_tore_rembarde_cabine4 = intersection {
  torus { // Torus031
    0.1, 0.015  rotate -x*90
    translate  <-0.002914, 0.0, 0.7>
  }
  box { // Cube032
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, 1.0, 0.0>
    scale <0.12, 0.12, 0.02>
    rotate -180.0*z
    translate  0.7*z
  }
  rotate <-0.0, -0.0, 0.0>
  translate  <0.0, -0.0, -0.699895>
  scale -1.0
  rotate <0.0, -47.850193, 23.035391>
  translate  <0.786575, -2.076534, 23.923633>
}
#declare Bastingage_cabine = union {
  object { Coupe_tore_rembarde_cabine }
  cylinder { // Cylndr040
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 1.688285>
    rotate 90.0*x
    translate  <2.15, 0.815387, 24.0>
  }
  object { Coupe_tore_rembarde_cabine1 }
  cylinder { // Cylndr041
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 0.475297>
    rotate <90.0, 0.0, -90.0>
    translate  <2.054205, 0.921826, 24.0>
  }
  object { Coupe_tore_rembarde_cabine2 }
  object { Coupe_tore_rembarde_cabine3 }
  cylinder { // Cylndr067
    <0,0,1>, <0,0,0>, 1 
    scale <-0.015, -0.015, -1.61>
    rotate <-90.0, 0.0, 134.842712>
    translate  <0.986869, -2.050402, 24.0>
  }
  object { Coupe_tore_rembarde_cabine4 }
  cylinder { // Cylndr090
    <0,0,1>, <0,0,0>, 1 
    scale <-0.015, -0.015, -1.61>
    rotate <-5.143202, 35.942669, 0.082299>
    translate  <0.760337, -1.981662, 23.940717>
  }
  translate  -23.3*z
}
#declare Cube087 = object {
  box { // Cube087
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*y
    scale <0.12, 0.25, 0.03>
    translate  <-0.011749, -0.245314, -1.067891>
  }
}
#declare Cylndr126 = object {
  cylinder { // Cylndr126
    <0,0,1>, <0,0,0>, 1 
    scale <-0.015, -0.015, -1.61>
    rotate <-0.134215, 36.566647, -0.034012>
    translate  <0.790484, -0.254033, -0.066134>
  }
}
#declare Cylndr128 = object {
  object { // Cylndr128 -> Cylndr126
    Cylndr126
    rotate <-0.0, 0.0, 0.0>
    translate  <0.037637, 0.261552, 0.0>
  }
}
#declare Cylndr039 = object {
  cylinder { // Cylndr039
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 0.7>
    translate  <1.239541, 1.267752, 0.0>
  }
}
#declare Cube024 = object {
  box { // Cube024
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.5, -1.0, 0.0>
    scale <1.0, 1.0, 0.02>
    rotate 55.660587*z
    translate  0.7*z
  }
}
#declare Coupe_tore_rembarde_tourelle = difference {
  torus { // Torus025
    1.78, 0.015  rotate -x*90
    translate  <-0.002914, 0.0, 0.7>
  }
  object { Cube024 }
  object { // Cube025 -> Cube024
    Cube024
    scale <1.0, -1.0, 1.0>
    rotate 2.169344*z
  }
  rotate -22.5*z
}
#declare Coupe_tore_rembarde_tourelle1 = object {
  object { // Coupe_tore_rembarde_tourelle1 -> Coupe_tore_rembarde_tourelle
    Coupe_tore_rembarde_tourelle
    rotate -0.0*z
    translate  -0.35*z
  }
}
#declare Cube033 = object {
  box { // Cube033
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.0, 0.5, 0.5>
    scale <0.05, 1.5, 0.08>
    translate  <-0.6, 1.916689, 0.0>
  }
}
#declare Cube041 = object {
  box { // Cube041
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.0, 0.5, 0.5>
    scale <1.25, 0.05, 0.08>
    translate  3.404638*y
  }
}
#declare Cube043 = object {
  box { // Cube043
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.0, 0.5, 0.5>
    scale <0.05, 1.4, 0.08>
    rotate 51.559868*x
    translate  <-0.6, 2.271486, -1.076372>
  }
}
#declare Cylndr066 = object {
  cylinder { // Cylndr066
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 0.608351>
    translate  <-0.63418, 3.46605, 0.076374>
  }
}
#declare Cylndr093 = object {
  cylinder { // Cylndr093
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 1.286438>
    rotate 90.0*y
    translate  <-0.63418, 3.46605, 0.686205>
  }
}
#declare Pilier_rambarde = union {
  cylinder { // Cylndr001
    <0,0,1>, <0,0,0>, 1 
    translate  -0.5*z
    scale <0.11, 0.11, 0.3>
    rotate -90.0*x
    translate  1.0*z
  }
  box { // Cube018
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    scale <0.3, 0.3, 1.0>
  }
  scale <1.0, 1.0, 0.8>
  rotate -112.309372*z
  translate  <2.300819, -0.944849, 21.006897>
}
#declare Main_courrante = intersection {
  box { // Cube019
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    scale <0.2, 2.0, 0.2>
  }
  cylinder { // Cylndr002
    <0,0,1>, <0,0,0>, 1 
    translate  <0.0, -0.5, -0.5>
    scale <0.15, 0.15, 2.0>
    rotate -90.0*x
    translate  -0.077977*z
  }
  scale <1.0, 1.0, 0.8>
  translate  <2.283272, -0.025931, 21.656356>
}
#declare TMesh014 = mesh2 {
    vertex_vectors {
      1173,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.1402372, 1.0000000>,
      <-0.3404041, 0.1402372, 1.0000000>,
      <-0.3404041, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0701186, 1.0000000>,
      <-0.1702614, 0.1402372, 1.0000000>,
      <-0.3404041, 0.0701186, 1.0000000>,
      <-0.1702614, 0.0000000, 1.0000000>,
      <-0.1702614, 0.0701186, 1.0000000>,
      <-0.3404041, -0.1402372, 1.0000000>,
      <-0.0000000, -0.1402372, 1.0000000>,
      <-0.3404041, -0.0701186, 1.0000000>,
      <-0.1702614, -0.1402372, 1.0000000>,
      <-0.0000000, -0.0701186, 1.0000000>,
      <-0.1702614, -0.0701186, 1.0000000>,
      <0.3404041, -0.1402372, 1.0000000>,
      <0.3404041, 0.0000000, 1.0000000>,
      <0.1702614, -0.1402372, 1.0000000>,
      <0.3404041, -0.0701186, 1.0000000>,
      <0.1702614, 0.0000000, 1.0000000>,
      <0.1702614, -0.0701186, 1.0000000>,
      <0.3404041, 0.1402372, 1.0000000>,
      <0.3404041, 0.0701186, 1.0000000>,
      <0.1702614, 0.1402372, 1.0000000>,
      <0.1702614, 0.0701186, 1.0000000>,
      <-0.0000074, 0.0000000, -1.0000000>,
      <-0.0000000, -0.1402372, -1.0000000>,
      <-0.3404041, -0.1402372, -1.0000000>,
      <-0.3404486, 0.0000000, -1.0000000>,
      <-0.0000000, -0.0701186, -1.0000000>,
      <-0.1702614, -0.1402372, -1.0000000>,
      <-0.3404041, -0.0701186, -1.0000000>,
      <-0.1702911, 0.0000000, -1.0000000>,
      <-0.1702614, -0.0701186, -1.0000000>,
      <-0.3409979, 0.1402372, -1.0000000>,
      <-0.0000594, 0.1402372, -1.0000000>,
      <-0.3405822, 0.0701186, -1.0000000>,
      <-0.1704990, 0.1402372, -1.0000000>,
      <-0.0000297, 0.0701186, -1.0000000>,
      <-0.1703802, 0.0701186, -1.0000000>,
      <0.3404041, 0.1402372, -1.0000000>,
      <0.3404041, 0.0000000, -1.0000000>,
      <0.1702614, 0.1402372, -1.0000000>,
      <0.3404041, 0.0701186, -1.0000000>,
      <0.1702614, 0.0000000, -1.0000000>,
      <0.1702614, 0.0701186, -1.0000000>,
      <0.3404041, -0.1402372, -1.0000000>,
      <0.3404041, -0.0701186, -1.0000000>,
      <0.1702614, -0.1402372, -1.0000000>,
      <0.1702614, -0.0701186, -1.0000000>,
      <-1.0191930, 0.0000000, 0.0000000>,
      <-1.0191930, 0.0000000, -1.0000000>,
      <-1.0191930, -0.1402372, -1.0000000>,
      <-1.0191930, -0.1402372, 0.0000000>,
      <-1.0191930, 0.0000000, -0.5000000>,
      <-1.0191930, -0.0701186, -1.0000000>,
      <-1.0191930, -0.1402372, -0.5000000>,
      <-1.0191930, -0.0701186, 0.0000000>,
      <-1.0191930, -0.0701186, -0.5000000>,
      <-1.0191930, -0.1402372, 1.0000000>,
      <-1.0191930, 0.0000000, 1.0000000>,
      <-1.0191930, -0.1402372, 0.5000000>,
      <-1.0191930, -0.0701186, 1.0000000>,
      <-1.0191930, 0.0000000, 0.5000000>,
      <-1.0191930, -0.0701186, 0.5000000>,
      <-1.0191930, 0.1402372, 1.0000000>,
      <-1.0191930, 0.1402372, 0.0000000>,
      <-1.0191930, 0.0701186, 1.0000000>,
      <-1.0191930, 0.1402372, 0.5000000>,
      <-1.0191930, 0.0701186, 0.0000000>,
      <-1.0191930, 0.0701186, 0.5000000>,
      <-1.0191930, 0.1402372, -1.0000000>,
      <-1.0191930, 0.1402372, -0.5000000>,
      <-1.0191930, 0.0701186, -1.0000000>,
      <-1.0191930, 0.0701186, -0.5000000>,
      <1.0191930, 0.0000000, 0.0000000>,
      <1.0191930, 0.0000000, -1.0000000>,
      <1.0191930, 0.1402372, -1.0000000>,
      <1.0191930, 0.1402372, 0.0000000>,
      <1.0191930, 0.0000000, -0.5000000>,
      <1.0191930, 0.0701186, -1.0000000>,
      <1.0191930, 0.1402372, -0.5000000>,
      <1.0191930, 0.0701186, 0.0000000>,
      <1.0191930, 0.0701186, -0.5000000>,
      <1.0191930, 0.1402372, 1.0000000>,
      <1.0191930, 0.0000000, 1.0000000>,
      <1.0191930, 0.1402372, 0.5000000>,
      <1.0191930, 0.0701186, 1.0000000>,
      <1.0191930, 0.0000000, 0.5000000>,
      <1.0191930, 0.0701186, 0.5000000>,
      <1.0191930, -0.1402372, 1.0000000>,
      <1.0191930, -0.1402372, 0.0000000>,
      <1.0191930, -0.0701186, 1.0000000>,
      <1.0191930, -0.1402372, 0.5000000>,
      <1.0191930, -0.0701186, 0.0000000>,
      <1.0191930, -0.0701186, 0.5000000>,
      <1.0191930, -0.1402372, -1.0000000>,
      <1.0191930, -0.1402372, -0.5000000>,
      <1.0191930, -0.0701186, -1.0000000>,
      <1.0191930, -0.0701186, -0.5000000>,
      <-0.6800361, 0.0000000, 1.0000000>,
      <-0.6800361, -0.1402372, 1.0000000>,
      <-0.6800361, -0.0701186, 1.0000000>,
      <-0.5103091, -0.1402372, 1.0000000>,
      <-0.5103091, 0.0000000, 1.0000000>,
      <-0.5103091, -0.0701186, 1.0000000>,
      <-0.6800361, 0.1402372, 1.0000000>,
      <-0.5103091, 0.1402372, 1.0000000>,
      <-0.6800361, 0.0701186, 1.0000000>,
      <-0.5103091, 0.0701186, 1.0000000>,
      <-0.8496443, 0.1402372, 1.0000000>,
      <-0.8496443, 0.0000000, 1.0000000>,
      <-0.8496443, 0.0701186, 1.0000000>,
      <-0.8496443, -0.1402372, 1.0000000>,
      <-0.8496443, -0.0701186, 1.0000000>,
      <-0.6800435, 0.0000000, -1.0000000>,
      <-0.6800955, 0.1402372, -1.0000000>,
      <-0.6800658, 0.0701186, -1.0000000>,
      <-0.5105467, 0.1402372, -1.0000000>,
      <-0.5103388, 0.0000000, -1.0000000>,
      <-0.5104279, 0.0701186, -1.0000000>,
      <-0.6800361, -0.1402372, -1.0000000>,
      <-0.5103091, -0.1402372, -1.0000000>,
      <-0.6800361, -0.0701186, -1.0000000>,
      <-0.5103091, -0.0701186, -1.0000000>,
      <-0.8496443, -0.1402372, -1.0000000>,
      <-0.8496443, 0.0000000, -1.0000000>,
      <-0.8496443, -0.0701186, -1.0000000>,
      <-0.8496443, 0.1402372, -1.0000000>,
      <-0.8496443, 0.0701186, -1.0000000>,
      <0.6800361, 0.0000000, 1.0000000>,
      <0.6800361, 0.1402372, 1.0000000>,
      <0.6800361, 0.0701186, 1.0000000>,
      <0.5103091, 0.1402372, 1.0000000>,
      <0.5103091, 0.0000000, 1.0000000>,
      <0.5103091, 0.0701186, 1.0000000>,
      <0.6800361, -0.1402372, 1.0000000>,
      <0.5103091, -0.1402372, 1.0000000>,
      <0.6800361, -0.0701186, 1.0000000>,
      <0.5103091, -0.0701186, 1.0000000>,
      <0.8496443, -0.1402372, 1.0000000>,
      <0.8496443, 0.0000000, 1.0000000>,
      <0.8496443, -0.0701186, 1.0000000>,
      <0.8496443, 0.1402372, 1.0000000>,
      <0.8496443, 0.0701186, 1.0000000>,
      <0.6800361, 0.0000000, -1.0000000>,
      <0.6800361, -0.1402372, -1.0000000>,
      <0.6800361, -0.0701186, -1.0000000>,
      <0.5103091, -0.1402372, -1.0000000>,
      <0.5103091, 0.0000000, -1.0000000>,
      <0.5103091, -0.0701186, -1.0000000>,
      <0.6800361, 0.1402372, -1.0000000>,
      <0.5103091, 0.1402372, -1.0000000>,
      <0.6800361, 0.0701186, -1.0000000>,
      <0.5103091, 0.0701186, -1.0000000>,
      <0.8496443, 0.1402372, -1.0000000>,
      <0.8496443, 0.0000000, -1.0000000>,
      <0.8496443, 0.0701186, -1.0000000>,
      <0.8496443, -0.1402372, -1.0000000>,
      <0.8496443, -0.0701186, -1.0000000>,
      <-0.2486628, -0.1391416, 0.0000000>,
      <-0.2426962, -0.1364026, 0.4986355>,
      <-0.3409088, -0.1402372, 0.0000000>,
      <-0.2480718, -0.1380460, 0.2758588>,
      <-0.3032058, -0.1402372, 0.7692380>,
      <-0.3407169, -0.1402372, 0.6578213>,
      <-0.2946824, -0.1402372, 0.0000000>,
      <-0.2942389, -0.1402372, 0.3826298>,
      <-0.2426962, -0.1364026, -0.4986355>,
      <-0.3407169, -0.1402372, -0.6578213>,
      <-0.3032058, -0.1402372, -0.7692380>,
      <-0.2480718, -0.1380460, -0.2758588>,
      <-0.2942389, -0.1402372, -0.3826298>,
      <-0.1575097, -0.0964131, -0.2114056>,
      <-0.1575097, -0.1314724, 0.0000000>,
      <-0.1906677, -0.1205163, -0.3245640>,
      <-0.1575097, -0.1227075, -0.1153121>,
      <-0.2029977, -0.1358548, -0.0000000>,
      <-0.2026136, -0.1314724, -0.1902859>,
      <-0.1575097, -0.0964131, 0.2114056>,
      <-0.1575097, -0.1227075, 0.1153121>,
      <-0.1906677, -0.1205163, 0.3245640>,
      <-0.2026136, -0.1314724, 0.1902859>,
      <0.2486628, -0.1391416, 0.0000000>,
      <0.2426962, -0.1364026, -0.4986355>,
      <0.3409088, -0.1402372, 0.0000000>,
      <0.2480718, -0.1380460, -0.2758588>,
      <0.3032058, -0.1402372, -0.7692380>,
      <0.3407169, -0.1402372, -0.6578213>,
      <0.2946824, -0.1402372, 0.0000000>,
      <0.2942389, -0.1402372, -0.3826298>,
      <0.2426962, -0.1364026, 0.4986355>,
      <0.3407169, -0.1402372, 0.6578213>,
      <0.3032058, -0.1402372, 0.7692380>,
      <0.2480718, -0.1380460, 0.2758588>,
      <0.2942389, -0.1402372, 0.3826298>,
      <0.1575097, -0.0964131, 0.2114056>,
      <0.1575097, -0.1314724, 0.0000000>,
      <0.1906677, -0.1205163, 0.3245640>,
      <0.1575097, -0.1227075, 0.1153121>,
      <0.2029977, -0.1358548, 0.0000000>,
      <0.2026136, -0.1314724, 0.1902859>,
      <0.1575097, -0.0964131, -0.2114056>,
      <0.1575097, -0.1227075, -0.1153121>,
      <0.1906677, -0.1205163, -0.3245640>,
      <0.2026136, -0.1314724, -0.1902859>,
      <-0.2483285, 0.1391416, 0.0050143>,
      <-0.2406335, 0.1364026, -0.4901904>,
      <-0.3408484, 0.1402372, 0.0206374>,
      <-0.2467347, 0.1380460, -0.2682170>,
      <-0.2987694, 0.1402372, -0.7450305>,
      <-0.3405780, 0.1402372, -0.6170584>,
      <-0.2944843, 0.1402372, 0.0157584>,
      <-0.2934464, 0.1402372, -0.3692583>,
      <-0.2426962, 0.1364026, 0.4992563>,
      <-0.3407169, 0.1402372, 0.6641182>,
      <-0.3032058, 0.1402372, 0.7717211>,
      <-0.2480718, 0.1380460, 0.2783419>,
      <-0.2942389, 0.1402372, 0.3925623>,
      <-0.1575097, 0.0964131, 0.2114056>,
      <-0.1575097, 0.1314724, 0.0000000>,
      <-0.1906677, 0.1205163, 0.3245640>,
      <-0.1575097, 0.1227075, 0.1153121>,
      <-0.2027699, 0.1358548, 0.0008598>,
      <-0.2026136, 0.1314724, 0.1902859>,
      <-0.1575097, 0.0964131, -0.2114056>,
      <-0.1575097, 0.1227075, -0.1153121>,
      <-0.1897565, 0.1205163, -0.3211249>,
      <-0.2017023, 0.1314724, -0.1868468>,
      <0.2486628, 0.1391416, 0.0000000>,
      <0.2426962, 0.1364026, 0.4986355>,
      <0.3409088, 0.1402372, 0.0000000>,
      <0.2480718, 0.1380460, 0.2758588>,
      <0.3032058, 0.1402372, 0.7692380>,
      <0.3407169, 0.1402372, 0.6578213>,
      <0.2946824, 0.1402372, 0.0000000>,
      <0.2942389, 0.1402372, 0.3826298>,
      <0.2426962, 0.1364026, -0.4986355>,
      <0.3407169, 0.1402372, -0.6578213>,
      <0.3032058, 0.1402372, -0.7692380>,
      <0.2480718, 0.1380460, -0.2758588>,
      <0.2942389, 0.1402372, -0.3826298>,
      <0.1575097, 0.0964131, -0.2114056>,
      <0.1575097, 0.1314724, 0.0000000>,
      <0.1906677, 0.1205163, -0.3245640>,
      <0.1575097, 0.1227075, -0.1153121>,
      <0.2029977, 0.1358548, -0.0000000>,
      <0.2026136, 0.1314724, -0.1902859>,
      <0.1575097, 0.0964131, 0.2114056>,
      <0.1575097, 0.1227075, 0.1153121>,
      <0.1906677, 0.1205163, 0.3245640>,
      <0.2026136, 0.1314724, 0.1902859>,
      <-0.4333033, -0.1391416, 0.0000000>,
      <-0.4392031, -0.1364026, -0.4986355>,
      <-0.4338646, -0.1380460, -0.2758588>,
      <-0.3781983, -0.1402372, -0.7692380>,
      <-0.3871947, -0.1402372, 0.0000000>,
      <-0.3875194, -0.1402372, -0.3826298>,
      <-0.4392031, -0.1364026, 0.4986355>,
      <-0.3781983, -0.1402372, 0.7692380>,
      <-0.4338646, -0.1380460, 0.2758588>,
      <-0.3875194, -0.1402372, 0.3826298>,
      <-0.5244861, -0.0964131, 0.2114056>,
      <-0.5244861, -0.1314724, 0.0000000>,
      <-0.4913281, -0.1205163, 0.3245640>,
      <-0.5244861, -0.1227075, 0.1153121>,
      <-0.4789981, -0.1358548, 0.0000000>,
      <-0.4793822, -0.1314724, 0.1902859>,
      <-0.5244861, -0.0964131, -0.2114056>,
      <-0.5244861, -0.1227075, -0.1153121>,
      <-0.4913281, -0.1205163, -0.3245640>,
      <-0.4793822, -0.1314724, -0.1902859>,
      <-0.9252987, -0.1391416, 0.0000000>,
      <-0.9160898, -0.1364026, 0.4806144>,
      <-0.9231485, -0.1380460, 0.2639772>,
      <-0.9704118, -0.1402372, 0.7175614>,
      <-0.9718875, -0.1402372, 0.0000000>,
      <-0.9704540, -0.1402372, 0.3747088>,
      <-0.9160898, -0.1364026, -0.4806144>,
      <-0.9704118, -0.1402372, -0.7175614>,
      <-0.9231485, -0.1380460, -0.2639772>,
      <-0.9704540, -0.1402372, -0.3747088>,
      <-0.8357049, -0.0964131, -0.2114056>,
      <-0.8357049, -0.1314724, 0.0000000>,
      <-0.8667641, -0.1205163, -0.3166430>,
      <-0.8357049, -0.1227075, -0.1153121>,
      <-0.8801434, -0.1358548, -0.0000000>,
      <-0.8787099, -0.1314724, -0.1823649>,
      <-0.8357049, -0.0964131, 0.2114056>,
      <-0.8357049, -0.1227075, 0.1153121>,
      <-0.8667641, -0.1205163, 0.3166430>,
      <-0.8787099, -0.1314724, 0.1823649>,
      <-0.4330226, 0.1396894, -0.0090293>,
      <-0.4392031, 0.1364026, 0.4992563>,
      <-0.4338646, 0.1380460, 0.2783419>,
      <-0.3781983, 0.1402372, 0.7717211>,
      <-0.3870323, 0.1402372, 0.0071967>,
      <-0.3875194, 0.1402372, 0.3925623>,
      <-0.4327420, 0.1402372, -0.6537495>,
      <-0.3868700, 0.1402372, -0.8268748>,
      <-0.4327420, 0.1402372, -0.3243917>,
      <-0.3868700, 0.1402372, -0.4035050>,
      <-0.5244861, 0.1402372, -0.3074990>,
      <-0.5244861, 0.1358548, -0.0096093>,
      <-0.4786140, 0.1402372, -0.4806243>,
      <-0.5244861, 0.1402372, -0.1537495>,
      <-0.4788061, 0.1380460, -0.0125066>,
      <-0.4786140, 0.1402372, -0.2403121>,
      <-0.5244861, 0.0964131, 0.2114056>,
      <-0.5244861, 0.1227075, 0.1153121>,
      <-0.4913281, 0.1205163, 0.3245640>,
      <-0.4793822, 0.1314724, 0.1902859>,
      <-0.9252987, 0.1391416, 0.0000000>,
      <-0.9160898, 0.1364026, -0.4806144>,
      <-0.9231485, 0.1380460, -0.2639772>,
      <-0.9704118, 0.1402372, -0.7175614>,
      <-0.9718875, 0.1402372, 0.0000000>,
      <-0.9704540, 0.1402372, -0.3747088>,
      <-0.9160898, 0.1364026, 0.4806144>,
      <-0.9704118, 0.1402372, 0.7175614>,
      <-0.9231485, 0.1380460, 0.2639772>,
      <-0.9704540, 0.1402372, 0.3747088>,
      <-0.8357049, 0.0964131, 0.2114056>,
      <-0.8357049, 0.1314724, 0.0000000>,
      <-0.8667641, 0.1205163, 0.3166430>,
      <-0.8357049, 0.1227075, 0.1153121>,
      <-0.8801434, 0.1358548, 0.0000000>,
      <-0.8787099, 0.1314724, 0.1823649>,
      <-0.8357049, 0.0964131, -0.2114056>,
      <-0.8357049, 0.1227075, -0.1153121>,
      <-0.8667641, 0.1205163, -0.3166430>,
      <-0.8787099, 0.1314724, -0.1823649>,
      <0.4333033, 0.1391416, 0.0000000>,
      <0.4392031, 0.1364026, -0.4986355>,
      <0.4338646, 0.1380460, -0.2758588>,
      <0.3781983, 0.1402372, -0.7692380>,
      <0.3871947, 0.1402372, 0.0000000>,
      <0.3875194, 0.1402372, -0.3826298>,
      <0.4392031, 0.1364026, 0.4986355>,
      <0.3781983, 0.1402372, 0.7692380>,
      <0.4338646, 0.1380460, 0.2758588>,
      <0.3875194, 0.1402372, 0.3826298>,
      <0.5244861, 0.0964131, 0.2114056>,
      <0.5244861, 0.1314724, 0.0000000>,
      <0.4913281, 0.1205163, 0.3245640>,
      <0.5244861, 0.1227075, 0.1153121>,
      <0.4789981, 0.1358548, 0.0000000>,
      <0.4793822, 0.1314724, 0.1902859>,
      <0.5244861, 0.0964131, -0.2114056>,
      <0.5244861, 0.1227075, -0.1153121>,
      <0.4913281, 0.1205163, -0.3245640>,
      <0.4793822, 0.1314724, -0.1902859>,
      <0.9252987, 0.1391416, 0.0000000>,
      <0.9160898, 0.1364026, 0.4806144>,
      <0.9231485, 0.1380460, 0.2639772>,
      <0.9704118, 0.1402372, 0.7175614>,
      <0.9718875, 0.1402372, 0.0000000>,
      <0.9704540, 0.1402372, 0.3747088>,
      <0.9160898, 0.1364026, -0.4806144>,
      <0.9704118, 0.1402372, -0.7175614>,
      <0.9231485, 0.1380460, -0.2639772>,
      <0.9704540, 0.1402372, -0.3747088>,
      <0.8357049, 0.0964131, -0.2114056>,
      <0.8357049, 0.1314724, 0.0000000>,
      <0.8667641, 0.1205163, -0.3166430>,
      <0.8357049, 0.1227075, -0.1153121>,
      <0.8801434, 0.1358548, -0.0000000>,
      <0.8787099, 0.1314724, -0.1823649>,
      <0.8357049, 0.0964131, 0.2114056>,
      <0.8357049, 0.1227075, 0.1153121>,
      <0.8667641, 0.1205163, 0.3166430>,
      <0.8787099, 0.1314724, 0.1823649>,
      <0.4333033, -0.1391416, 0.0000000>,
      <0.4392031, -0.1364026, 0.4986355>,
      <0.4338646, -0.1380460, 0.2758588>,
      <0.3781983, -0.1402372, 0.7692380>,
      <0.3871947, -0.1402372, 0.0000000>,
      <0.3875194, -0.1402372, 0.3826298>,
      <0.4392031, -0.1364026, -0.4986355>,
      <0.3781983, -0.1402372, -0.7692380>,
      <0.4338646, -0.1380460, -0.2758588>,
      <0.3875194, -0.1402372, -0.3826298>,
      <0.5244861, -0.0964131, -0.2114056>,
      <0.5244861, -0.1314724, 0.0000000>,
      <0.4913281, -0.1205163, -0.3245640>,
      <0.5244861, -0.1227075, -0.1153121>,
      <0.4789981, -0.1358548, -0.0000000>,
      <0.4793822, -0.1314724, -0.1902859>,
      <0.5244861, -0.0964131, 0.2114056>,
      <0.5244861, -0.1227075, 0.1153121>,
      <0.4913281, -0.1205163, 0.3245640>,
      <0.4793822, -0.1314724, 0.1902859>,
      <0.9252987, -0.1391416, 0.0000000>,
      <0.9160898, -0.1364026, -0.4806144>,
      <0.9231485, -0.1380460, -0.2639772>,
      <0.9704118, -0.1402372, -0.7175614>,
      <0.9718875, -0.1402372, 0.0000000>,
      <0.9704540, -0.1402372, -0.3747088>,
      <0.9160898, -0.1364026, 0.4806144>,
      <0.9704118, -0.1402372, 0.7175614>,
      <0.9231485, -0.1380460, 0.2639772>,
      <0.9704540, -0.1402372, 0.3747088>,
      <0.8357049, -0.0964131, 0.2114056>,
      <0.8357049, -0.1314724, 0.0000000>,
      <0.8667641, -0.1205163, 0.3166430>,
      <0.8357049, -0.1227075, 0.1153121>,
      <0.8801434, -0.1358548, 0.0000000>,
      <0.8787099, -0.1314724, 0.1823649>,
      <0.8357049, -0.0964131, -0.2114056>,
      <0.8357049, -0.1227075, -0.1153121>,
      <0.8667641, -0.1205163, -0.3166430>,
      <0.8787099, -0.1314724, -0.1823649>,
      <-0.8357049, 0.0000000, 0.0000000>,
      <-0.8357049, 0.0000000, 0.2882803>,
      <-0.8357049, 0.0000000, 0.1441402>,
      <-0.8357049, -0.0525889, 0.2690617>,
      <-0.8357049, -0.0657362, 0.0000000>,
      <-0.8357049, -0.0613538, 0.1345308>,
      <-0.8357049, 0.0000000, -0.2882803>,
      <-0.8357049, -0.0525889, -0.2690617>,
      <-0.8357049, 0.0000000, -0.1441402>,
      <-0.8357049, -0.0613538, -0.1345308>,
      <-0.8357049, 0.0525889, -0.2690617>,
      <-0.8357049, 0.0657362, -0.0000000>,
      <-0.8357049, 0.0613538, -0.1345308>,
      <-0.8357049, 0.0525889, 0.2690617>,
      <-0.8357049, 0.0613538, 0.1345308>,
      <-0.5244861, 0.0005478, -0.0012012>,
      <-0.5244861, 0.0043824, -0.2978897>,
      <-0.5244861, 0.0021912, -0.1489448>,
      <-0.5244861, -0.0525889, -0.2690617>,
      <-0.5244861, -0.0657362, -0.0000000>,
      <-0.5244861, -0.0613538, -0.1345308>,
      <-0.5244861, 0.0000000, 0.2882803>,
      <-0.5244861, -0.0525889, 0.2690617>,
      <-0.5244861, 0.0000000, 0.1441402>,
      <-0.5244861, -0.0613538, 0.1345308>,
      <-0.5244861, 0.0525889, 0.2690617>,
      <-0.5244861, 0.0679274, -0.0048047>,
      <-0.5244861, 0.0613538, 0.1345308>,
      <-0.5244861, 0.0701186, -0.3074990>,
      <-0.5244861, 0.0701186, -0.1537495>,
      <-0.6800955, 0.0000000, 0.7112225>,
      <-0.5694407, 0.0000000, 0.6649822>,
      <-0.5530942, -0.0996999, 0.7025586>,
      <-0.6797371, -0.1314724, 0.7179394>,
      <-0.6197709, 0.0000000, 0.7005104>,
      <-0.5652298, -0.0547802, 0.6748141>,
      <-0.6131409, -0.1227075, 0.7166493>,
      <-0.6799163, -0.0657362, 0.7134615>,
      <-0.6174414, -0.0613538, 0.7063408>,
      <-0.8046971, -0.0996999, 0.6952794>,
      <-0.7907503, 0.0000000, 0.6649822>,
      <-0.7456165, -0.1227075, 0.7112391>,
      <-0.7938861, -0.0547802, 0.6707565>,
      <-0.7404201, 0.0000000, 0.7005104>,
      <-0.7420328, -0.0613538, 0.7036358>,
      <-0.8063097, 0.0996999, 0.7013658>,
      <-0.6804539, 0.1314724, 0.7179394>,
      <-0.7949612, 0.0547802, 0.6748141>,
      <-0.7470500, 0.1227075, 0.7166493>,
      <-0.6802747, 0.0657362, 0.7134615>,
      <-0.7427495, 0.0613538, 0.7063408>,
      <-0.5547068, 0.0996999, 0.6964721>,
      <-0.6145744, 0.1227075, 0.7112391>,
      <-0.5663049, 0.0547802, 0.6707565>,
      <-0.6181582, 0.0613538, 0.7036358>,
      <-0.6797564, 0.0005478, -0.7113877>,
      <-0.6804539, -0.1314724, -0.7179394>,
      <-0.5547068, -0.0996999, -0.6964721>,
      <-0.5677646, 0.0038346, -0.6654301>,
      <-0.6802747, -0.0657362, -0.7134615>,
      <-0.6145744, -0.1227075, -0.7112391>,
      <-0.5663049, -0.0547802, -0.6707565>,
      <-0.6184146, 0.0021912, -0.7011710>,
      <-0.6181582, -0.0613538, -0.7036358>,
      <-0.5244861, 0.1402372, -0.7219346>,
      <-0.6770246, 0.1358548, -0.7192608>,
      <-0.5585256, 0.0701186, -0.6766057>,
      <-0.6022908, 0.1402372, -0.7219346>,
      <-0.6785600, 0.0679274, -0.7141221>,
      <-0.6120164, 0.0701186, -0.7089835>,
      <-0.8046971, 0.0996999, -0.6952794>,
      <-0.7907503, 0.0000000, -0.6649822>,
      <-0.7456165, 0.1227075, -0.7112391>,
      <-0.7938861, 0.0547802, -0.6707565>,
      <-0.7404201, 0.0000000, -0.7005104>,
      <-0.7420328, 0.0613538, -0.7036358>,
      <-0.8063097, -0.0996999, -0.7013658>,
      <-0.7949612, -0.0547802, -0.6748141>,
      <-0.7470500, -0.1227075, -0.7166493>,
      <-0.7427495, -0.0613538, -0.7063408>,
      <-0.0000000, 0.0000000, 0.7112225>,
      <0.0003584, -0.1314724, 0.7179394>,
      <-0.1266951, -0.0996999, 0.6964721>,
      <-0.1119613, 0.0000000, 0.6649822>,
      <0.0001792, -0.0657362, 0.7134615>,
      <-0.0662337, -0.1227075, 0.7112391>,
      <-0.1150971, -0.0547802, 0.6707565>,
      <-0.0610372, 0.0000000, 0.7005104>,
      <-0.0626499, -0.0613538, 0.7036358>,
      <-0.1283078, 0.0996999, 0.7025586>,
      <-0.0003584, 0.1314724, 0.7179394>,
      <-0.1161722, 0.0547802, 0.6748141>,
      <-0.0676672, 0.1227075, 0.7166493>,
      <-0.0001792, 0.0657362, 0.7134615>,
      <-0.0633667, 0.0613538, 0.7063408>,
      <0.1266951, 0.0996999, 0.6964721>,
      <0.1119613, 0.0000000, 0.6649822>,
      <0.0662337, 0.1227075, 0.7112391>,
      <0.1150971, 0.0547802, 0.6707565>,
      <0.0610372, 0.0000000, 0.7005104>,
      <0.0626499, 0.0613538, 0.7036358>,
      <0.1283078, -0.0996999, 0.7025586>,
      <0.1161722, -0.0547802, 0.6748141>,
      <0.0676672, -0.1227075, 0.7166493>,
      <0.0633667, -0.0613538, 0.7063408>,
      <0.1575097, 0.0000000, 0.0000000>,
      <0.1575097, 0.0000000, -0.2882803>,
      <0.1575097, 0.0000000, -0.1441402>,
      <0.1575097, -0.0525889, -0.2690617>,
      <0.1575097, -0.0657362, -0.0000000>,
      <0.1575097, -0.0613538, -0.1345308>,
      <0.1575097, 0.0000000, 0.2882803>,
      <0.1575097, -0.0525889, 0.2690617>,
      <0.1575097, 0.0000000, 0.1441402>,
      <0.1575097, -0.0613538, 0.1345308>,
      <0.1575097, 0.0525889, 0.2690617>,
      <0.1575097, 0.0657362, 0.0000000>,
      <0.1575097, 0.0613538, 0.1345308>,
      <0.1575097, 0.0525889, -0.2690617>,
      <0.1575097, 0.0613538, -0.1345308>,
      <-0.0000000, 0.0000000, -0.7112225>,
      <-0.1119613, 0.0000000, -0.6649822>,
      <-0.1283078, -0.0996999, -0.7025586>,
      <-0.0003584, -0.1314724, -0.7179394>,
      <-0.0610372, 0.0000000, -0.7005104>,
      <-0.1161722, -0.0547802, -0.6748141>,
      <-0.0676672, -0.1227075, -0.7166493>,
      <-0.0001792, -0.0657362, -0.7134615>,
      <-0.0633667, -0.0613538, -0.7063408>,
      <0.1266951, -0.0996999, -0.6964721>,
      <0.1119613, 0.0000000, -0.6649822>,
      <0.0662337, -0.1227075, -0.7112391>,
      <0.1150971, -0.0547802, -0.6707565>,
      <0.0610372, 0.0000000, -0.7005104>,
      <0.0626499, -0.0613538, -0.7036358>,
      <0.1283078, 0.0996999, -0.7025586>,
      <0.0003584, 0.1314724, -0.7179394>,
      <0.1161722, 0.0547802, -0.6748141>,
      <0.0676672, 0.1227075, -0.7166493>,
      <0.0001792, 0.0657362, -0.7134615>,
      <0.0633667, 0.0613538, -0.7063408>,
      <-0.1263534, 0.0996999, -0.6959543>,
      <-0.0662337, 0.1227075, -0.7112391>,
      <-0.1150971, 0.0547802, -0.6707565>,
      <-0.0626499, 0.0613538, -0.7036358>,
      <-0.1575097, 0.0000000, 0.0000000>,
      <-0.1575097, 0.0000000, 0.2882803>,
      <-0.1575097, 0.0000000, 0.1441402>,
      <-0.1575097, -0.0525889, 0.2690617>,
      <-0.1575097, -0.0657362, 0.0000000>,
      <-0.1575097, -0.0613538, 0.1345308>,
      <-0.1575097, 0.0000000, -0.2882803>,
      <-0.1575097, -0.0525889, -0.2690617>,
      <-0.1575097, 0.0000000, -0.1441402>,
      <-0.1575097, -0.0613538, -0.1345308>,
      <-0.1575097, 0.0525889, -0.2690617>,
      <-0.1575097, 0.0657362, -0.0000000>,
      <-0.1575097, 0.0613538, -0.1345308>,
      <-0.1575097, 0.0525889, 0.2690617>,
      <-0.1575097, 0.0613538, 0.1345308>,
      <0.5244861, 0.0000000, 0.0000000>,
      <0.5244861, 0.0000000, -0.2882803>,
      <0.5244861, 0.0000000, -0.1441402>,
      <0.5244861, 0.0525889, -0.2690617>,
      <0.5244861, 0.0657362, -0.0000000>,
      <0.5244861, 0.0613538, -0.1345308>,
      <0.5244861, 0.0000000, 0.2882803>,
      <0.5244861, 0.0525889, 0.2690617>,
      <0.5244861, 0.0000000, 0.1441402>,
      <0.5244861, 0.0613538, 0.1345308>,
      <0.5244861, -0.0525889, 0.2690617>,
      <0.5244861, -0.0657362, 0.0000000>,
      <0.5244861, -0.0613538, 0.1345308>,
      <0.5244861, -0.0525889, -0.2690617>,
      <0.5244861, -0.0613538, -0.1345308>,
      <0.6800955, 0.0000000, 0.7112225>,
      <0.5694407, 0.0000000, 0.6649822>,
      <0.5530942, 0.0996999, 0.7025586>,
      <0.6797371, 0.1314724, 0.7179394>,
      <0.6197709, 0.0000000, 0.7005104>,
      <0.5652298, 0.0547802, 0.6748141>,
      <0.6131409, 0.1227075, 0.7166493>,
      <0.6799163, 0.0657362, 0.7134615>,
      <0.6174414, 0.0613538, 0.7063408>,
      <0.8046971, 0.0996999, 0.6952794>,
      <0.7907503, 0.0000000, 0.6649822>,
      <0.7456165, 0.1227075, 0.7112391>,
      <0.7938861, 0.0547802, 0.6707565>,
      <0.7404201, 0.0000000, 0.7005104>,
      <0.7420328, 0.0613538, 0.7036358>,
      <0.8063097, -0.0996999, 0.7013658>,
      <0.6804539, -0.1314724, 0.7179394>,
      <0.7949612, -0.0547802, 0.6748141>,
      <0.7470500, -0.1227075, 0.7166493>,
      <0.6802747, -0.0657362, 0.7134615>,
      <0.7427495, -0.0613538, 0.7063408>,
      <0.5547068, -0.0996999, 0.6964721>,
      <0.6145744, -0.1227075, 0.7112391>,
      <0.5663049, -0.0547802, 0.6707565>,
      <0.6181582, -0.0613538, 0.7036358>,
      <0.8357049, 0.0000000, 0.0000000>,
      <0.8357049, 0.0000000, 0.2882803>,
      <0.8357049, 0.0000000, 0.1441402>,
      <0.8357049, 0.0525889, 0.2690617>,
      <0.8357049, 0.0657362, 0.0000000>,
      <0.8357049, 0.0613538, 0.1345308>,
      <0.8357049, 0.0000000, -0.2882803>,
      <0.8357049, 0.0525889, -0.2690617>,
      <0.8357049, 0.0000000, -0.1441402>,
      <0.8357049, 0.0613538, -0.1345308>,
      <0.8357049, -0.0525889, -0.2690617>,
      <0.8357049, -0.0657362, -0.0000000>,
      <0.8357049, -0.0613538, -0.1345308>,
      <0.8357049, -0.0525889, 0.2690617>,
      <0.8357049, -0.0613538, 0.1345308>,
      <0.6800955, 0.0000000, -0.7112225>,
      <0.6804539, 0.1314724, -0.7179394>,
      <0.5547068, 0.0996999, -0.6964721>,
      <0.5694407, 0.0000000, -0.6649822>,
      <0.6802747, 0.0657362, -0.7134615>,
      <0.6145744, 0.1227075, -0.7112391>,
      <0.5663049, 0.0547802, -0.6707565>,
      <0.6197709, 0.0000000, -0.7005104>,
      <0.6181582, 0.0613538, -0.7036358>,
      <0.5530942, -0.0996999, -0.7025586>,
      <0.6797371, -0.1314724, -0.7179394>,
      <0.5652298, -0.0547802, -0.6748141>,
      <0.6131409, -0.1227075, -0.7166493>,
      <0.6799163, -0.0657362, -0.7134615>,
      <0.6174414, -0.0613538, -0.7063408>,
      <0.8046971, -0.0996999, -0.6952794>,
      <0.7907503, 0.0000000, -0.6649822>,
      <0.7456165, -0.1227075, -0.7112391>,
      <0.7938861, -0.0547802, -0.6707565>,
      <0.7404201, 0.0000000, -0.7005104>,
      <0.7420328, -0.0613538, -0.7036358>,
      <0.8063097, 0.0996999, -0.7013658>,
      <0.7949612, 0.0547802, -0.6748141>,
      <0.7470500, 0.1227075, -0.7166493>,
      <0.7427495, 0.0613538, -0.7063408>,
      <-0.8356354, 0.0000000, 0.5134756>,
      <-0.8531509, -0.0964131, 0.5437641>,
      <-0.8403390, -0.0525889, 0.5183718>,
      <-0.8502788, -0.0964131, 0.3775265>,
      <-0.8385719, 0.0000000, 0.4058434>,
      <-0.8414389, -0.0525889, 0.4005788>,
      <-0.8534197, 0.0964131, 0.5447785>,
      <-0.8502788, 0.0964131, 0.3775265>,
      <-0.8405182, 0.0525889, 0.5190480>,
      <-0.8414389, 0.0525889, 0.4005788>,
      <-0.8394286, 0.0964131, 0.6397201>,
      <-0.8210918, 0.0000000, 0.6012462>,
      <-0.8262882, 0.0525889, 0.6114215>,
      <-0.8383535, -0.0964131, 0.6356625>,
      <-0.8255715, -0.0525889, 0.6087164>,
      <-0.5245556, 0.0000000, 0.5134756>,
      <-0.5067777, 0.0964131, 0.5444580>,
      <-0.5198519, 0.0525889, 0.5183718>,
      <-0.5093874, 0.0964131, 0.3795067>,
      <-0.5216191, 0.0000000, 0.4058434>,
      <-0.5187521, 0.0525889, 0.4005788>,
      <-0.5065089, -0.0964131, 0.5454724>,
      <-0.5093874, -0.0964131, 0.3795067>,
      <-0.5196727, -0.0525889, 0.5190480>,
      <-0.5187521, -0.0525889, 0.4005788>,
      <-0.5202376, -0.0964131, 0.6405152>,
      <-0.5390992, 0.0000000, 0.6012462>,
      <-0.5339027, -0.0525889, 0.6114215>,
      <-0.5213127, 0.0964131, 0.6364576>,
      <-0.5346195, 0.0525889, 0.6087164>,
      <-0.5263668, 0.0043824, -0.5115833>,
      <-0.5067777, -0.0964131, -0.5444580>,
      <-0.5198519, -0.0525889, -0.5183718>,
      <-0.5093874, -0.0964131, -0.3795067>,
      <-0.5230526, 0.0043824, -0.4084756>,
      <-0.5187521, -0.0525889, -0.4005788>,
      <-0.5244861, 0.1402372, -0.5147168>,
      <-0.5244861, 0.1402372, -0.4111079>,
      <-0.5269175, 0.0701186, -0.5114791>,
      <-0.5244861, 0.0701186, -0.4111079>,
      <-0.5244861, 0.1402372, -0.6183257>,
      <-0.5391764, 0.0043824, -0.5997345>,
      <-0.5342117, 0.0701186, -0.6053746>,
      <-0.5213127, -0.0964131, -0.6364576>,
      <-0.5346195, -0.0525889, -0.6087164>,
      <-0.8356354, 0.0000000, -0.5134756>,
      <-0.8531509, 0.0964131, -0.5437641>,
      <-0.8403390, 0.0525889, -0.5183718>,
      <-0.8502788, 0.0964131, -0.3775265>,
      <-0.8385719, 0.0000000, -0.4058434>,
      <-0.8414389, 0.0525889, -0.4005788>,
      <-0.8534197, -0.0964131, -0.5447785>,
      <-0.8502788, -0.0964131, -0.3775265>,
      <-0.8405182, -0.0525889, -0.5190480>,
      <-0.8414389, -0.0525889, -0.4005788>,
      <-0.8394286, -0.0964131, -0.6397201>,
      <-0.8210918, 0.0000000, -0.6012462>,
      <-0.8262882, -0.0525889, -0.6114215>,
      <-0.8383535, 0.0964131, -0.6356625>,
      <-0.8255715, 0.0525889, -0.6087164>,
      <-0.1573808, 0.0000000, 0.5134756>,
      <-0.1751588, -0.0964131, 0.5444580>,
      <-0.1620845, -0.0525889, 0.5183718>,
      <-0.1726084, -0.0964131, 0.3795067>,
      <-0.1603768, 0.0000000, 0.4058434>,
      <-0.1632438, -0.0525889, 0.4005788>,
      <-0.1754276, 0.0964131, 0.5454724>,
      <-0.1726084, 0.0964131, 0.3795067>,
      <-0.1622637, 0.0525889, 0.5190480>,
      <-0.1632438, 0.0525889, 0.4005788>,
      <-0.1615207, 0.0964131, 0.6405152>,
      <-0.1426591, 0.0000000, 0.6012462>,
      <-0.1478555, 0.0525889, 0.6114215>,
      <-0.1604455, -0.0964131, 0.6364576>,
      <-0.1471388, -0.0525889, 0.6087164>,
      <0.1573808, 0.0000000, 0.5134756>,
      <0.1751588, 0.0964131, 0.5444580>,
      <0.1620845, 0.0525889, 0.5183718>,
      <0.1726084, 0.0964131, 0.3795067>,
      <0.1603768, 0.0000000, 0.4058434>,
      <0.1632438, 0.0525889, 0.4005788>,
      <0.1754276, -0.0964131, 0.5454724>,
      <0.1726084, -0.0964131, 0.3795067>,
      <0.1622637, -0.0525889, 0.5190480>,
      <0.1632438, -0.0525889, 0.4005788>,
      <0.1615207, -0.0964131, 0.6405152>,
      <0.1426591, 0.0000000, 0.6012462>,
      <0.1478555, -0.0525889, 0.6114215>,
      <0.1604455, 0.0964131, 0.6364576>,
      <0.1471388, 0.0525889, 0.6087164>,
      <0.1573808, 0.0000000, -0.5134756>,
      <0.1751588, -0.0964131, -0.5444580>,
      <0.1620845, -0.0525889, -0.5183718>,
      <0.1726084, -0.0964131, -0.3795067>,
      <0.1603768, 0.0000000, -0.4058434>,
      <0.1632438, -0.0525889, -0.4005788>,
      <0.1754276, 0.0964131, -0.5454724>,
      <0.1726084, 0.0964131, -0.3795067>,
      <0.1622637, 0.0525889, -0.5190480>,
      <0.1632438, 0.0525889, -0.4005788>,
      <0.1615207, 0.0964131, -0.6405152>,
      <0.1426591, 0.0000000, -0.6012462>,
      <0.1478555, 0.0525889, -0.6114215>,
      <0.1604455, -0.0964131, -0.6364576>,
      <0.1471388, -0.0525889, -0.6087164>,
      <-0.1573808, 0.0000000, -0.5134756>,
      <-0.1750449, 0.0964131, -0.5441567>,
      <-0.1620845, 0.0525889, -0.5183718>,
      <-0.1723806, 0.0964131, -0.3786469>,
      <-0.1603768, 0.0000000, -0.4058434>,
      <-0.1632438, 0.0525889, -0.4005788>,
      <-0.1754276, -0.0964131, -0.5454724>,
      <-0.1726084, -0.0964131, -0.3795067>,
      <-0.1622637, -0.0525889, -0.5190480>,
      <-0.1632438, -0.0525889, -0.4005788>,
      <-0.1615207, -0.0964131, -0.6405152>,
      <-0.1426591, 0.0000000, -0.6012462>,
      <-0.1478555, -0.0525889, -0.6114215>,
      <-0.1602177, 0.0964131, -0.6361124>,
      <-0.1471388, 0.0525889, -0.6087164>,
      <0.8356354, 0.0000000, 0.5134756>,
      <0.8531509, 0.0964131, 0.5437641>,
      <0.8403390, 0.0525889, 0.5183718>,
      <0.8502788, 0.0964131, 0.3775265>,
      <0.8385719, 0.0000000, 0.4058434>,
      <0.8414389, 0.0525889, 0.4005788>,
      <0.8534197, -0.0964131, 0.5447785>,
      <0.8502788, -0.0964131, 0.3775265>,
      <0.8405182, -0.0525889, 0.5190480>,
      <0.8414389, -0.0525889, 0.4005788>,
      <0.8394286, -0.0964131, 0.6397201>,
      <0.8210918, 0.0000000, 0.6012462>,
      <0.8262882, -0.0525889, 0.6114215>,
      <0.8383535, 0.0964131, 0.6356625>,
      <0.8255715, 0.0525889, 0.6087164>,
      <0.5245556, 0.0000000, 0.5134756>,
      <0.5067777, -0.0964131, 0.5444580>,
      <0.5198519, -0.0525889, 0.5183718>,
      <0.5093874, -0.0964131, 0.3795067>,
      <0.5216191, 0.0000000, 0.4058434>,
      <0.5187521, -0.0525889, 0.4005788>,
      <0.5065089, 0.0964131, 0.5454724>,
      <0.5093874, 0.0964131, 0.3795067>,
      <0.5196727, 0.0525889, 0.5190480>,
      <0.5187521, 0.0525889, 0.4005788>,
      <0.5202376, 0.0964131, 0.6405152>,
      <0.5390992, 0.0000000, 0.6012462>,
      <0.5339027, 0.0525889, 0.6114215>,
      <0.5213127, -0.0964131, 0.6364576>,
      <0.5346195, -0.0525889, 0.6087164>,
      <0.5245556, 0.0000000, -0.5134756>,
      <0.5067777, 0.0964131, -0.5444580>,
      <0.5198519, 0.0525889, -0.5183718>,
      <0.5093874, 0.0964131, -0.3795067>,
      <0.5216191, 0.0000000, -0.4058434>,
      <0.5187521, 0.0525889, -0.4005788>,
      <0.5065089, -0.0964131, -0.5454724>,
      <0.5093874, -0.0964131, -0.3795067>,
      <0.5196727, -0.0525889, -0.5190480>,
      <0.5187521, -0.0525889, -0.4005788>,
      <0.5202376, -0.0964131, -0.6405152>,
      <0.5390992, 0.0000000, -0.6012462>,
      <0.5339027, -0.0525889, -0.6114215>,
      <0.5213127, 0.0964131, -0.6364576>,
      <0.5346195, 0.0525889, -0.6087164>,
      <0.8356354, 0.0000000, -0.5134756>,
      <0.8531509, -0.0964131, -0.5437641>,
      <0.8403390, -0.0525889, -0.5183718>,
      <0.8502788, -0.0964131, -0.3775265>,
      <0.8385719, 0.0000000, -0.4058434>,
      <0.8414389, -0.0525889, -0.4005788>,
      <0.8534197, 0.0964131, -0.5447785>,
      <0.8502788, 0.0964131, -0.3775265>,
      <0.8405182, 0.0525889, -0.5190480>,
      <0.8414389, 0.0525889, -0.4005788>,
      <0.8394286, 0.0964131, -0.6397201>,
      <0.8210918, 0.0000000, -0.6012462>,
      <0.8262882, 0.0525889, -0.6114215>,
      <0.8383535, -0.0964131, -0.6356625>,
      <0.8255715, -0.0525889, -0.6087164>,
      <-0.8878697, -0.1324462, -0.6453888>,
      <-0.8555900, -0.1364026, -0.8030150>,
      <-0.9035150, -0.1358548, -0.6025713>,
      <-0.9243141, -0.1402372, -0.8920582>,
      <-0.8864180, -0.1358548, -0.7295949>,
      <-0.9244130, -0.1402372, -0.7461190>,
      <-0.8245869, -0.1248987, -0.7457510>,
      <-0.8727720, -0.1227075, -0.6003565>,
      <-0.8587809, -0.1227075, -0.6866199>,
      <-0.8767986, -0.1227075, -0.4888531>,
      <-0.8877901, 0.1324462, -0.6450882>,
      <-0.8553212, 0.1364026, -0.8020006>,
      <-0.8862388, 0.1358548, -0.7289187>,
      <-0.9243141, 0.1402372, -0.8920582>,
      <-0.9035150, 0.1358548, -0.6025713>,
      <-0.9244130, 0.1402372, -0.7461190>,
      <-0.8725928, 0.1227075, -0.5996802>,
      <-0.8767986, 0.1227075, -0.4888531>,
      <-0.8235118, 0.1248987, -0.7416933>,
      <-0.8580642, 0.1227075, -0.6839148>,
      <-0.6793458, -0.1391416, -0.8519473>,
      <-0.4999718, -0.1364026, -0.8096520>,
      <-0.6795411, -0.1402372, -0.9248033>,
      <-0.4196868, -0.1402372, -0.9135177>,
      <-0.5779657, -0.1380460, -0.8449746>,
      <-0.5467247, -0.1402372, -0.9207131>,
      <-0.5335310, -0.1248987, -0.7464642>,
      <-0.6797500, -0.1358548, -0.7837730>,
      <-0.5988574, -0.1314724, -0.7763327>,
      <-0.7792266, -0.1380460, -0.8408800>,
      <-0.7599515, -0.1314724, -0.7758572>,
      <-0.8112486, -0.1402372, -0.9175325>,
      <-0.6739143, 0.1396894, -0.8557764>,
      <-0.4327420, 0.1402372, -0.8609673>,
      <-0.5564187, 0.1402372, -0.8609673>,
      <-0.3868700, 0.1402372, -0.9304837>,
      <-0.6762306, 0.1402372, -0.9272459>,
      <-0.5334827, 0.1402372, -0.9304837>,
      <-0.7790474, 0.1380460, -0.8402037>,
      <-0.8112486, 0.1402372, -0.9175325>,
      <-0.6746951, 0.1380460, -0.7868763>,
      <-0.7592348, 0.1314724, -0.7731521>,
      <-0.4786140, 0.1402372, -0.7914510>,
      <-0.5793548, 0.1402372, -0.7914510>,
      <-0.4695893, -0.1324462, -0.6524893>,
      <-0.4702495, -0.1358548, -0.7356698>,
      <-0.4529733, -0.1358548, -0.6152480>,
      <-0.4314616, -0.1402372, -0.7572206>,
      <-0.4865487, -0.1227075, -0.6024556>,
      <-0.4812936, -0.1227075, -0.4967741>,
      <-0.5000280, -0.1227075, -0.6870954>,
      <-0.2123674, -0.1324462, -0.6527898>,
      <-0.1816544, -0.1364026, -0.8106664>,
      <-0.2289334, -0.1358548, -0.6152480>,
      <-0.2614342, -0.1402372, -0.9135177>,
      <-0.2116582, -0.1358548, -0.7363461>,
      <-0.2501780, -0.1402372, -0.7572206>,
      <-0.1489461, -0.1248987, -0.7505219>,
      <-0.1955669, -0.1227075, -0.6031319>,
      <-0.1824470, -0.1227075, -0.6898005>,
      <-0.2007022, -0.1227075, -0.4967741>,
      <-0.2110860, 0.1324462, -0.6492759>,
      <-0.1793229, 0.1364026, -0.8063300>,
      <-0.2099141, 0.1358548, -0.7327386>,
      <-0.2549778, 0.1402372, -0.9044866>,
      <-0.2273684, 0.1358548, -0.6097441>,
      <-0.2484742, 0.1402372, -0.7524006>,
      <-0.1949321, 0.1227075, -0.6012506>,
      <-0.1997910, 0.1227075, -0.4933350>,
      <-0.1465041, 0.1248987, -0.7443928>,
      <-0.1808190, 0.1227075, -0.6857145>,
      <-0.0000448, -0.1391416, -0.8531400>,
      <-0.1029919, -0.1380460, -0.8456509>,
      <-0.0000000, -0.1402372, -0.9255984>,
      <-0.1339646, -0.1402372, -0.9207131>,
      <0.1813857, -0.1364026, -0.8096520>,
      <0.2614342, -0.1402372, -0.9135177>,
      <0.1028127, -0.1380460, -0.8449746>,
      <0.1339646, -0.1402372, -0.9207131>,
      <0.1478710, -0.1248987, -0.7464642>,
      <-0.0001792, -0.1358548, -0.7845681>,
      <0.0819507, -0.1314724, -0.7763327>,
      <-0.0826675, -0.1314724, -0.7790378>,
      <0.0003791, 0.1391416, -0.8526222>,
      <0.0001981, 0.1402372, -0.9252532>,
      <-0.1014755, 0.1380460, -0.8429032>,
      <-0.1331721, 0.1402372, -0.9193322>,
      <0.0004070, 0.1358548, -0.7842229>,
      <-0.0810395, 0.1314724, -0.7749518>,
      <0.1816544, 0.1364026, -0.8106664>,
      <0.1489461, 0.1248987, -0.7505219>,
      <0.1029919, 0.1380460, -0.8456509>,
      <0.0826675, 0.1314724, -0.7790378>,
      <0.2614342, 0.1402372, -0.9135177>,
      <0.1339646, 0.1402372, -0.9207131>,
      <0.2122878, -0.1324462, -0.6524893>,
      <0.2114791, -0.1358548, -0.7356698>,
      <0.2289334, -0.1358548, -0.6152480>,
      <0.2501780, -0.1402372, -0.7572206>,
      <0.1953877, -0.1227075, -0.6024556>,
      <0.2007022, -0.1227075, -0.4967741>,
      <0.1817303, -0.1227075, -0.6870954>,
      <0.2123674, 0.1324462, -0.6527898>,
      <0.2289334, 0.1358548, -0.6152480>,
      <0.2116582, 0.1358548, -0.7363461>,
      <0.2501780, 0.1402372, -0.7572206>,
      <0.1955669, 0.1227075, -0.6031319>,
      <0.1824470, 0.1227075, -0.6898005>,
      <0.2007022, 0.1227075, -0.4967741>,
      <0.4695096, -0.1324462, -0.6527898>,
      <0.4997030, -0.1364026, -0.8106664>,
      <0.4529733, -0.1358548, -0.6152480>,
      <0.4196868, -0.1402372, -0.9135177>,
      <0.4700703, -0.1358548, -0.7363461>,
      <0.4314616, -0.1402372, -0.7572206>,
      <0.5324559, -0.1248987, -0.7505219>,
      <0.4863696, -0.1227075, -0.6031319>,
      <0.4993113, -0.1227075, -0.6898005>,
      <0.4812936, -0.1227075, -0.4967741>,
      <0.4695893, 0.1324462, -0.6524893>,
      <0.4999718, 0.1364026, -0.8096520>,
      <0.4702495, 0.1358548, -0.7356698>,
      <0.4196868, 0.1402372, -0.9135177>,
      <0.4529733, 0.1358548, -0.6152480>,
      <0.4314616, 0.1402372, -0.7572206>,
      <0.4865487, 0.1227075, -0.6024556>,
      <0.4812936, 0.1227075, -0.4967741>,
      <0.5335310, 0.1248987, -0.7464642>,
      <0.5000280, 0.1227075, -0.6870954>,
      <0.6792562, -0.1391416, -0.8519473>,
      <0.5777865, -0.1380460, -0.8456509>,
      <0.6795411, -0.1402372, -0.9248033>,
      <0.5467247, -0.1402372, -0.9207131>,
      <0.8553212, -0.1364026, -0.8020006>,
      <0.9243141, -0.1402372, -0.8920582>,
      <0.7790474, -0.1380460, -0.8402037>,
      <0.8112486, -0.1402372, -0.9175325>,
      <0.8235118, -0.1248987, -0.7416933>,
      <0.6793916, -0.1358548, -0.7837730>,
      <0.7592348, -0.1314724, -0.7731521>,
      <0.5981406, -0.1314724, -0.7790378>,
      <0.6793458, 0.1391416, -0.8519473>,
      <0.6795411, 0.1402372, -0.9248033>,
      <0.5779657, 0.1380460, -0.8449746>,
      <0.5467247, 0.1402372, -0.9207131>,
      <0.6797500, 0.1358548, -0.7837730>,
      <0.5988574, 0.1314724, -0.7763327>,
      <0.8555900, 0.1364026, -0.8030150>,
      <0.8245869, 0.1248987, -0.7457510>,
      <0.7792266, 0.1380460, -0.8408800>,
      <0.7599515, 0.1314724, -0.7758572>,
      <0.9243141, 0.1402372, -0.8920582>,
      <0.8112486, 0.1402372, -0.9175325>,
      <0.8877901, -0.1324462, -0.6450882>,
      <0.8862388, -0.1358548, -0.7289187>,
      <0.9035150, -0.1358548, -0.6025713>,
      <0.9244130, -0.1402372, -0.7461190>,
      <0.8725928, -0.1227075, -0.5996802>,
      <0.8767986, -0.1227075, -0.4888531>,
      <0.8580642, -0.1227075, -0.6839148>,
      <0.8878697, 0.1324462, -0.6453888>,
      <0.9035150, 0.1358548, -0.6025713>,
      <0.8864180, 0.1358548, -0.7295949>,
      <0.9244130, 0.1402372, -0.7461190>,
      <0.8727720, 0.1227075, -0.6003565>,
      <0.8587809, 0.1227075, -0.6866199>,
      <0.8767986, 0.1227075, -0.4888531>,
      <-0.8877901, -0.1324462, 0.6450882>,
      <-0.8553212, -0.1364026, 0.8020006>,
      <-0.8862388, -0.1358548, 0.7289187>,
      <-0.9243141, -0.1402372, 0.8920582>,
      <-0.9035150, -0.1358548, 0.6025713>,
      <-0.9244130, -0.1402372, 0.7461190>,
      <-0.8725928, -0.1227075, 0.5996802>,
      <-0.8767986, -0.1227075, 0.4888531>,
      <-0.8235118, -0.1248987, 0.7416933>,
      <-0.8580642, -0.1227075, 0.6839148>,
      <-0.8878697, 0.1324462, 0.6453888>,
      <-0.8555900, 0.1364026, 0.8030150>,
      <-0.9035150, 0.1358548, 0.6025713>,
      <-0.9243141, 0.1402372, 0.8920582>,
      <-0.8864180, 0.1358548, 0.7295949>,
      <-0.9244130, 0.1402372, 0.7461190>,
      <-0.8245869, 0.1248987, 0.7457510>,
      <-0.8727720, 0.1227075, 0.6003565>,
      <-0.8587809, 0.1227075, 0.6866199>,
      <-0.8767986, 0.1227075, 0.4888531>,
      <-0.6792562, -0.1391416, 0.8519473>,
      <-0.4997030, -0.1364026, 0.8106664>,
      <-0.5777865, -0.1380460, 0.8456509>,
      <-0.4196868, -0.1402372, 0.9135177>,
      <-0.6795411, -0.1402372, 0.9248033>,
      <-0.5467247, -0.1402372, 0.9207131>,
      <-0.7790474, -0.1380460, 0.8402037>,
      <-0.8112486, -0.1402372, 0.9175325>,
      <-0.6793916, -0.1358548, 0.7837730>,
      <-0.7592348, -0.1314724, 0.7731521>,
      <-0.5324559, -0.1248987, 0.7505219>,
      <-0.5981406, -0.1314724, 0.7790378>,
      <-0.6793458, 0.1391416, 0.8519473>,
      <-0.4999718, 0.1364026, 0.8096520>,
      <-0.6795411, 0.1402372, 0.9248033>,
      <-0.4196868, 0.1402372, 0.9135177>,
      <-0.5779657, 0.1380460, 0.8449746>,
      <-0.5467247, 0.1402372, 0.9207131>,
      <-0.5335310, 0.1248987, 0.7464642>,
      <-0.6797500, 0.1358548, 0.7837730>,
      <-0.5988574, 0.1314724, 0.7763327>,
      <-0.7792266, 0.1380460, 0.8408800>,
      <-0.7599515, 0.1314724, 0.7758572>,
      <-0.8112486, 0.1402372, 0.9175325>,
      <-0.4695096, -0.1324462, 0.6527898>,
      <-0.4529733, -0.1358548, 0.6152480>,
      <-0.4700703, -0.1358548, 0.7363461>,
      <-0.4314616, -0.1402372, 0.7572206>,
      <-0.4863696, -0.1227075, 0.6031319>,
      <-0.4993113, -0.1227075, 0.6898005>,
      <-0.4812936, -0.1227075, 0.4967741>,
      <-0.4695893, 0.1324462, 0.6524893>,
      <-0.4702495, 0.1358548, 0.7356698>,
      <-0.4529733, 0.1358548, 0.6152480>,
      <-0.4314616, 0.1402372, 0.7572206>,
      <-0.4865487, 0.1227075, 0.6024556>,
      <-0.4812936, 0.1227075, 0.4967741>,
      <-0.5000280, 0.1227075, 0.6870954>,
      <-0.2122878, -0.1324462, 0.6524893>,
      <-0.1813857, -0.1364026, 0.8096520>,
      <-0.2114791, -0.1358548, 0.7356698>,
      <-0.2614342, -0.1402372, 0.9135177>,
      <-0.2289334, -0.1358548, 0.6152480>,
      <-0.2501780, -0.1402372, 0.7572206>,
      <-0.1953877, -0.1227075, 0.6024556>,
      <-0.2007022, -0.1227075, 0.4967741>,
      <-0.1478710, -0.1248987, 0.7464642>,
      <-0.1817303, -0.1227075, 0.6870954>,
      <-0.2123674, 0.1324462, 0.6527898>,
      <-0.1816544, 0.1364026, 0.8106664>,
      <-0.2289334, 0.1358548, 0.6152480>,
      <-0.2614342, 0.1402372, 0.9135177>,
      <-0.2116582, 0.1358548, 0.7363461>,
      <-0.2501780, 0.1402372, 0.7572206>,
      <-0.1489461, 0.1248987, 0.7505219>,
      <-0.1955669, 0.1227075, 0.6031319>,
      <-0.1824470, 0.1227075, 0.6898005>,
      <-0.2007022, 0.1227075, 0.4967741>,
      <0.0000448, -0.1391416, 0.8531400>,
      <-0.0000000, -0.1402372, 0.9255984>,
      <-0.1028127, -0.1380460, 0.8449746>,
      <-0.1339646, -0.1402372, 0.9207131>,
      <0.0001792, -0.1358548, 0.7845681>,
      <-0.0819507, -0.1314724, 0.7763327>,
      <0.1816544, -0.1364026, 0.8106664>,
      <0.1489461, -0.1248987, 0.7505219>,
      <0.1029919, -0.1380460, 0.8456509>,
      <0.0826675, -0.1314724, 0.7790378>,
      <0.2614342, -0.1402372, 0.9135177>,
      <0.1339646, -0.1402372, 0.9207131>,
      <-0.0000448, 0.1391416, 0.8531400>,
      <-0.1029919, 0.1380460, 0.8456509>,
      <-0.0000000, 0.1402372, 0.9255984>,
      <-0.1339646, 0.1402372, 0.9207131>,
      <0.1813857, 0.1364026, 0.8096520>,
      <0.2614342, 0.1402372, 0.9135177>,
      <0.1028127, 0.1380460, 0.8449746>,
      <0.1339646, 0.1402372, 0.9207131>,
      <0.1478710, 0.1248987, 0.7464642>,
      <-0.0001792, 0.1358548, 0.7845681>,
      <0.0819507, 0.1314724, 0.7763327>,
      <-0.0826675, 0.1314724, 0.7790378>,
      <0.2123674, -0.1324462, 0.6527898>,
      <0.2289334, -0.1358548, 0.6152480>,
      <0.2116582, -0.1358548, 0.7363461>,
      <0.2501780, -0.1402372, 0.7572206>,
      <0.1955669, -0.1227075, 0.6031319>,
      <0.1824470, -0.1227075, 0.6898005>,
      <0.2007022, -0.1227075, 0.4967741>,
      <0.2122878, 0.1324462, 0.6524893>,
      <0.2114791, 0.1358548, 0.7356698>,
      <0.2289334, 0.1358548, 0.6152480>,
      <0.2501780, 0.1402372, 0.7572206>,
      <0.1953877, 0.1227075, 0.6024556>,
      <0.2007022, 0.1227075, 0.4967741>,
      <0.1817303, 0.1227075, 0.6870954>,
      <0.4695893, -0.1324462, 0.6524893>,
      <0.4999718, -0.1364026, 0.8096520>,
      <0.4702495, -0.1358548, 0.7356698>,
      <0.4196868, -0.1402372, 0.9135177>,
      <0.4529733, -0.1358548, 0.6152480>,
      <0.4314616, -0.1402372, 0.7572206>,
      <0.4865487, -0.1227075, 0.6024556>,
      <0.4812936, -0.1227075, 0.4967741>,
      <0.5335310, -0.1248987, 0.7464642>,
      <0.5000280, -0.1227075, 0.6870954>,
      <0.4695096, 0.1324462, 0.6527898>,
      <0.4997030, 0.1364026, 0.8106664>,
      <0.4529733, 0.1358548, 0.6152480>,
      <0.4196868, 0.1402372, 0.9135177>,
      <0.4700703, 0.1358548, 0.7363461>,
      <0.4314616, 0.1402372, 0.7572206>,
      <0.5324559, 0.1248987, 0.7505219>,
      <0.4863696, 0.1227075, 0.6031319>,
      <0.4993113, 0.1227075, 0.6898005>,
      <0.4812936, 0.1227075, 0.4967741>,
      <0.6793458, -0.1391416, 0.8519473>,
      <0.6795411, -0.1402372, 0.9248033>,
      <0.5779657, -0.1380460, 0.8449746>,
      <0.5467247, -0.1402372, 0.9207131>,
      <0.6797500, -0.1358548, 0.7837730>,
      <0.5988574, -0.1314724, 0.7763327>,
      <0.8555900, -0.1364026, 0.8030150>,
      <0.8245869, -0.1248987, 0.7457510>,
      <0.7792266, -0.1380460, 0.8408800>,
      <0.7599515, -0.1314724, 0.7758572>,
      <0.9243141, -0.1402372, 0.8920582>,
      <0.8112486, -0.1402372, 0.9175325>,
      <0.6792562, 0.1391416, 0.8519473>,
      <0.5777865, 0.1380460, 0.8456509>,
      <0.6795411, 0.1402372, 0.9248033>,
      <0.5467247, 0.1402372, 0.9207131>,
      <0.8553212, 0.1364026, 0.8020006>,
      <0.9243141, 0.1402372, 0.8920582>,
      <0.7790474, 0.1380460, 0.8402037>,
      <0.8112486, 0.1402372, 0.9175325>,
      <0.8235118, 0.1248987, 0.7416933>,
      <0.6793916, 0.1358548, 0.7837730>,
      <0.7592348, 0.1314724, 0.7731521>,
      <0.5981406, 0.1314724, 0.7790378>,
      <0.8878697, -0.1324462, 0.6453888>,
      <0.9035150, -0.1358548, 0.6025713>,
      <0.8864180, -0.1358548, 0.7295949>,
      <0.9244130, -0.1402372, 0.7461190>,
      <0.8727720, -0.1227075, 0.6003565>,
      <0.8587809, -0.1227075, 0.6866199>,
      <0.8767986, -0.1227075, 0.4888531>,
      <0.8877901, 0.1324462, 0.6450882>,
      <0.8862388, 0.1358548, 0.7289187>,
      <0.9035150, 0.1358548, 0.6025713>,
      <0.9244130, 0.1402372, 0.7461190>,
      <0.8725928, 0.1227075, 0.5996802>,
      <0.8767986, 0.1227075, 0.4888531>,
      <0.8580642, 0.1227075, 0.6839148>
    }
    normal_vectors {
      1846,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0271834, -0.9996302, 0.0007625>,
      <0.0158112, -0.9998750, -0.0000000>,
      <0.0636163, -0.9979744, 0.0000000>,
      <0.1186485, -0.9929088, 0.0073906>,
      <0.1689856, -0.9856171, -0.0016813>,
      <0.0284599, -0.9995913, -0.0026877>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0271834, -0.9996302, -0.0007625>,
      <0.1186485, -0.9929088, -0.0073906>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0284599, -0.9995913, 0.0026877>,
      <0.1689856, -0.9856171, 0.0016813>,
      <0.2645461, -0.9635311, -0.0402880>,
      <0.1117200, -0.9937397, 0.0000000>,
      <0.4746355, -0.8797520, -0.0275248>,
      <0.9521264, -0.2781447, -0.1268499>,
      <0.4492419, -0.8813724, -0.1461659>,
      <0.4492419, -0.8813724, -0.1461659>,
      <0.1277633, -0.9918047, 0.0000000>,
      <0.2645461, -0.9635311, 0.0402880>,
      <0.1277633, -0.9918047, 0.0000000>,
      <0.4492419, -0.8813724, 0.1461659>,
      <0.4492419, -0.8813724, 0.1461659>,
      <0.9521264, -0.2781447, 0.1268499>,
      <0.4746355, -0.8797520, 0.0275248>,
      <-0.0271834, -0.9996302, -0.0007625>,
      <-0.0158112, -0.9998750, 0.0000000>,
      <-0.0636163, -0.9979744, -0.0000000>,
      <-0.1186485, -0.9929088, -0.0073906>,
      <-0.1689856, -0.9856171, 0.0016813>,
      <-0.0284599, -0.9995913, 0.0026877>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <-0.0271834, -0.9996302, 0.0007625>,
      <-0.1186485, -0.9929088, 0.0073906>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <-0.0284599, -0.9995913, -0.0026877>,
      <-0.1689856, -0.9856171, -0.0016813>,
      <-0.2645461, -0.9635311, 0.0402880>,
      <-0.1117200, -0.9937397, -0.0000000>,
      <-0.4746355, -0.8797520, 0.0275248>,
      <-0.9521264, -0.2781447, 0.1268499>,
      <-0.4492419, -0.8813724, 0.1461659>,
      <-0.4492419, -0.8813724, 0.1461659>,
      <-0.1277633, -0.9918047, 0.0000000>,
      <-0.2645461, -0.9635311, -0.0402880>,
      <-0.1277633, -0.9918047, 0.0000000>,
      <-0.4492419, -0.8813724, -0.1461659>,
      <-0.4492419, -0.8813724, -0.1461659>,
      <-0.9521264, -0.2781447, -0.1268499>,
      <-0.4746355, -0.8797520, -0.0275248>,
      <0.0262726, 0.9996546, -0.0006559>,
      <0.0157487, 0.9998760, 0.0000150>,
      <0.0636083, 0.9979749, 0.0001349>,
      <0.1175435, 0.9930430, -0.0070073>,
      <0.1722382, 0.9850533, 0.0020187>,
      <0.0280923, 0.9996017, 0.0026888>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0272887, 0.9996273, 0.0007836>,
      <0.1196706, 0.9927851, 0.0075260>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0282606, 0.9995969, -0.0027247>,
      <0.1688913, 0.9856332, -0.0016920>,
      <0.2662251, 0.9630579, 0.0405417>,
      <0.1122767, 0.9936770, 0.0002447>,
      <0.4749381, 0.8795877, 0.0275546>,
      <0.9521264, 0.2781447, 0.1268499>,
      <0.4499446, 0.8810234, 0.1461081>,
      <0.4499446, 0.8810234, 0.1461081>,
      <0.1286104, 0.9916952, 0.0000000>,
      <0.2645447, 0.9635446, -0.0399746>,
      <0.1286104, 0.9916952, 0.0000000>,
      <0.4477021, 0.8821346, -0.1462923>,
      <0.4477021, 0.8821346, -0.1462923>,
      <0.9531099, 0.2753420, -0.1255717>,
      <0.4805146, 0.8765637, -0.0272378>,
      <-0.0271834, 0.9996302, 0.0007625>,
      <-0.0158112, 0.9998750, -0.0000000>,
      <-0.0636163, 0.9979744, 0.0000000>,
      <-0.1186485, 0.9929088, 0.0073906>,
      <-0.1689856, 0.9856171, -0.0016813>,
      <-0.0284599, 0.9995913, -0.0026877>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <-0.0271834, 0.9996302, -0.0007625>,
      <-0.1186485, 0.9929088, -0.0073906>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <-0.0284599, 0.9995913, 0.0026877>,
      <-0.1689856, 0.9856171, 0.0016813>,
      <-0.2645461, 0.9635311, -0.0402880>,
      <-0.1117200, 0.9937397, 0.0000000>,
      <-0.4746355, 0.8797520, -0.0275248>,
      <-0.9521264, 0.2781447, -0.1268499>,
      <-0.4492419, 0.8813724, -0.1461659>,
      <-0.4492419, 0.8813724, -0.1461659>,
      <-0.1277633, 0.9918047, 0.0000000>,
      <-0.2645461, 0.9635311, 0.0402880>,
      <-0.1277633, 0.9918047, 0.0000000>,
      <-0.4492419, 0.8813724, 0.1461659>,
      <-0.4492419, 0.8813724, 0.1461659>,
      <-0.9521264, 0.2781447, 0.1268499>,
      <-0.4746355, 0.8797520, 0.0275248>,
      <-0.0270880, -0.9996328, -0.0007795>,
      <-0.0157657, -0.9998757, 0.0000000>,
      <-0.0635070, -0.9979814, -0.0000000>,
      <-0.1183737, -0.9929414, -0.0074217>,
      <-0.1683766, -0.9857214, 0.0016242>,
      <-0.0283100, -0.9995957, 0.0026570>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.0270880, -0.9996328, 0.0007795>,
      <-0.1183737, -0.9929414, 0.0074217>,
      <0.0000000, -1.0000000, -0.0000000>,
      <-0.0283100, -0.9995957, -0.0026570>,
      <-0.1683766, -0.9857214, -0.0016242>,
      <-0.2644009, -0.9635704, 0.0403027>,
      <-0.1116720, -0.9937451, -0.0000000>,
      <-0.4742591, -0.8799544, 0.0275419>,
      <-0.9521264, -0.2781447, 0.1268499>,
      <-0.4492419, -0.8813724, 0.1461659>,
      <-0.4492419, -0.8813724, 0.1461659>,
      <-0.1277633, -0.9918047, 0.0000000>,
      <-0.2644009, -0.9635704, -0.0403027>,
      <-0.1277633, -0.9918047, 0.0000000>,
      <-0.4492419, -0.8813724, -0.1461659>,
      <-0.4492419, -0.8813724, -0.1461659>,
      <-0.9521264, -0.2781447, -0.1268499>,
      <-0.4742591, -0.8799544, -0.0275419>,
      <0.0249238, -0.9996892, 0.0005428>,
      <0.0154383, -0.9998808, -0.0000000>,
      <0.0635616, -0.9979779, 0.0000000>,
      <0.1185227, -0.9929283, 0.0067583>,
      <0.1773972, -0.9841360, -0.0025522>,
      <0.0278120, -0.9996094, -0.0027598>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <0.0249238, -0.9996892, -0.0005428>,
      <0.1185227, -0.9929283, -0.0067583>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <-0.0000000, -1.0000000, -0.0000000>,
      <0.0278120, -0.9996094, 0.0027598>,
      <0.1773972, -0.9841360, 0.0025522>,
      <0.2685449, -0.9624312, -0.0401218>,
      <0.1142996, -0.9934463, 0.0000000>,
      <0.4894148, -0.8716356, -0.0269166>,
      <0.9544129, -0.2715801, -0.1238561>,
      <0.4472936, -0.8823362, -0.1463258>,
      <0.4472936, -0.8823362, -0.1463258>,
      <0.1317602, -0.9912816, 0.0000000>,
      <0.2685449, -0.9624312, 0.0401218>,
      <0.1317602, -0.9912816, 0.0000000>,
      <0.4472936, -0.8823362, 0.1463258>,
      <0.4472936, -0.8823362, 0.1463258>,
      <0.9544129, -0.2715801, 0.1238561>,
      <0.4894148, -0.8716356, 0.0269166>,
      <-0.0266175, 0.9996453, 0.0008961>,
      <-0.0080730, 0.9999673, 0.0004262>,
      <-0.0328336, 0.9994495, 0.0047630>,
      <-0.1181145, 0.9929623, 0.0086468>,
      <-0.1682858, 0.9857369, -0.0016345>,
      <-0.0281140, 0.9996011, -0.0026938>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.0006969, 0.9999998, 0.0001094>,
      <-0.0019730, 0.9999974, 0.0011284>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <0.0021237, 0.9999859, 0.0048656>,
      <-0.0556556, 0.9982294, 0.0209891>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0199627, 0.9996926, 0.0147070>,
      <0.0199627, 0.9996926, 0.0147070>,
      <-0.0583075, 0.9961867, 0.0649026>,
      <-0.2664261, 0.9628006, 0.0450802>,
      <-0.0583075, 0.9961867, 0.0649026>,
      <-0.4549729, 0.8766553, 0.1564455>,
      <-0.4549729, 0.8766553, 0.1564455>,
      <-0.9521264, 0.2781447, 0.1268499>,
      <-0.4745617, 0.8797903, 0.0275717>,
      <0.0249238, 0.9996892, -0.0005428>,
      <0.0154383, 0.9998808, 0.0000000>,
      <0.0635616, 0.9979779, -0.0000000>,
      <0.1185227, 0.9929283, -0.0067583>,
      <0.1773972, 0.9841360, 0.0025522>,
      <0.0278120, 0.9996094, 0.0027598>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <-0.0000000, 1.0000000, 0.0000000>,
      <-0.0000000, 1.0000000, 0.0000000>,
      <-0.0000000, 1.0000000, 0.0000000>,
      <0.0249238, 0.9996892, 0.0005428>,
      <0.1185227, 0.9929283, 0.0067583>,
      <-0.0000000, 1.0000000, 0.0000000>,
      <-0.0000000, 1.0000000, 0.0000000>,
      <-0.0000000, 1.0000000, 0.0000000>,
      <-0.0000000, 1.0000000, 0.0000000>,
      <0.0278120, 0.9996094, -0.0027598>,
      <0.1773972, 0.9841360, -0.0025522>,
      <0.2685449, 0.9624312, 0.0401218>,
      <0.1142996, 0.9934463, -0.0000000>,
      <0.4894148, 0.8716356, 0.0269166>,
      <0.9544129, 0.2715801, 0.1238561>,
      <0.4472936, 0.8823362, 0.1463258>,
      <0.4472936, 0.8823362, 0.1463258>,
      <0.1317602, 0.9912816, 0.0000000>,
      <0.2685449, 0.9624312, -0.0401218>,
      <0.1317602, 0.9912816, 0.0000000>,
      <0.4472936, 0.8823362, -0.1463258>,
      <0.4472936, 0.8823362, -0.1463258>,
      <0.9544129, 0.2715801, -0.1238561>,
      <0.4894148, 0.8716356, -0.0269166>,
      <0.0270880, 0.9996328, -0.0007795>,
      <0.0157657, 0.9998757, 0.0000000>,
      <0.0635070, 0.9979814, -0.0000000>,
      <0.1183737, 0.9929414, -0.0074217>,
      <0.1683766, 0.9857214, 0.0016242>,
      <0.0283100, 0.9995957, 0.0026570>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0270880, 0.9996328, 0.0007795>,
      <0.1183737, 0.9929414, 0.0074217>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0283100, 0.9995957, -0.0026570>,
      <0.1683766, 0.9857214, -0.0016242>,
      <0.2644009, 0.9635704, 0.0403027>,
      <0.1116720, 0.9937451, -0.0000000>,
      <0.4742591, 0.8799544, 0.0275419>,
      <0.9521264, 0.2781447, 0.1268499>,
      <0.4492419, 0.8813724, 0.1461659>,
      <0.4492419, 0.8813724, 0.1461659>,
      <0.1277633, 0.9918047, 0.0000000>,
      <0.2644009, 0.9635704, -0.0403027>,
      <0.1277633, 0.9918047, 0.0000000>,
      <0.4492419, 0.8813724, -0.1461659>,
      <0.4492419, 0.8813724, -0.1461659>,
      <0.9521264, 0.2781447, -0.1268499>,
      <0.4742591, 0.8799544, -0.0275419>,
      <-0.0249238, 0.9996892, 0.0005428>,
      <-0.0154383, 0.9998808, -0.0000000>,
      <-0.0635616, 0.9979779, 0.0000000>,
      <-0.1185227, 0.9929283, 0.0067583>,
      <-0.1773972, 0.9841360, -0.0025522>,
      <-0.0278120, 0.9996094, -0.0027598>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <-0.0249238, 0.9996892, -0.0005428>,
      <-0.1185227, 0.9929283, -0.0067583>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.0278120, 0.9996094, 0.0027598>,
      <-0.1773972, 0.9841360, 0.0025522>,
      <-0.2685449, 0.9624312, -0.0401218>,
      <-0.1142996, 0.9934463, 0.0000000>,
      <-0.4894148, 0.8716356, -0.0269166>,
      <-0.9544129, 0.2715801, -0.1238561>,
      <-0.4472936, 0.8823362, -0.1463258>,
      <-0.4472936, 0.8823362, -0.1463258>,
      <-0.1317602, 0.9912816, 0.0000000>,
      <-0.2685449, 0.9624312, 0.0401218>,
      <-0.1317602, 0.9912816, 0.0000000>,
      <-0.4472936, 0.8823362, 0.1463258>,
      <-0.4472936, 0.8823362, 0.1463258>,
      <-0.9544129, 0.2715801, 0.1238561>,
      <-0.4894148, 0.8716356, 0.0269166>,
      <0.0270880, -0.9996328, 0.0007795>,
      <0.0157657, -0.9998757, -0.0000000>,
      <0.0635070, -0.9979814, 0.0000000>,
      <0.1183737, -0.9929414, 0.0074217>,
      <0.1683766, -0.9857214, -0.0016242>,
      <0.0283100, -0.9995957, -0.0026570>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0270880, -0.9996328, -0.0007795>,
      <0.1183737, -0.9929414, -0.0074217>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0283100, -0.9995957, 0.0026570>,
      <0.1683766, -0.9857214, 0.0016242>,
      <0.2644009, -0.9635704, -0.0403027>,
      <0.1116720, -0.9937451, 0.0000000>,
      <0.4742591, -0.8799544, -0.0275419>,
      <0.9521264, -0.2781447, -0.1268499>,
      <0.4492419, -0.8813724, -0.1461659>,
      <0.4492419, -0.8813724, -0.1461659>,
      <0.1277633, -0.9918047, 0.0000000>,
      <0.2644009, -0.9635704, 0.0403027>,
      <0.1277633, -0.9918047, 0.0000000>,
      <0.4492419, -0.8813724, 0.1461659>,
      <0.4492419, -0.8813724, 0.1461659>,
      <0.9521264, -0.2781447, 0.1268499>,
      <0.4742591, -0.8799544, 0.0275419>,
      <-0.0249238, -0.9996892, -0.0005428>,
      <-0.0154383, -0.9998808, 0.0000000>,
      <-0.0635616, -0.9979779, -0.0000000>,
      <-0.1185227, -0.9929283, -0.0067583>,
      <-0.1773972, -0.9841360, 0.0025522>,
      <-0.0278120, -0.9996094, 0.0027598>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.0249238, -0.9996892, 0.0005428>,
      <-0.1185227, -0.9929283, 0.0067583>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.0278120, -0.9996094, -0.0027598>,
      <-0.1773972, -0.9841360, -0.0025522>,
      <-0.2685449, -0.9624312, 0.0401218>,
      <-0.1142996, -0.9934463, -0.0000000>,
      <-0.4894148, -0.8716356, 0.0269166>,
      <-0.9544129, -0.2715801, 0.1238561>,
      <-0.4472936, -0.8823362, 0.1463258>,
      <-0.4472936, -0.8823362, 0.1463258>,
      <-0.1317602, -0.9912816, 0.0000000>,
      <-0.2685449, -0.9624312, -0.0401218>,
      <-0.1317602, -0.9912816, 0.0000000>,
      <-0.4472936, -0.8823362, -0.1463258>,
      <-0.4472936, -0.8823362, -0.1463258>,
      <-0.9544129, -0.2715801, -0.1238561>,
      <-0.4894148, -0.8716356, -0.0269166>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-0.2770176, -0.1594361, -0.9475449>,
      <0.0215406, -0.0694039, -0.9973561>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.3686853, -0.0210584, -0.9293157>,
      <-0.7674919, -0.0274138, -0.6404722>,
      <-0.6813637, -0.3194497, -0.6585556>,
      <-0.3312750, -0.7554929, -0.5652321>,
      <-0.0666422, -0.2068886, -0.9760922>,
      <-0.0666422, -0.2068886, -0.9760922>,
      <0.0406309, -0.0922665, -0.9949050>,
      <0.3135500, -0.1192183, -0.9420581>,
      <0.3686853, 0.0210584, -0.9293157>,
      <0.0406309, -0.0922665, -0.9949050>,
      <0.1332052, -0.1721985, -0.9760144>,
      <0.1332052, -0.1721985, -0.9760144>,
      <0.3497831, -0.7334363, -0.5828576>,
      <0.6958359, -0.2675263, -0.6665149>,
      <0.7674919, 0.0274138, -0.6404722>,
      <0.2790581, 0.1576442, -0.9472459>,
      <-0.0215406, 0.0694039, -0.9973561>,
      <0.6849686, 0.3101976, -0.6592385>,
      <0.3544738, 0.7329912, -0.5805792>,
      <0.0769455, 0.2042615, -0.9758876>,
      <0.0769455, 0.2042615, -0.9758876>,
      <-0.0406309, 0.0922665, -0.9949050>,
      <-0.3115195, 0.1210667, -0.9424959>,
      <-0.0406309, 0.0922665, -0.9949050>,
      <-0.1225206, 0.1751386, -0.9768906>,
      <-0.1225206, 0.1751386, -0.9768906>,
      <-0.3267300, 0.7558415, -0.5674074>,
      <-0.6924710, 0.2771060, -0.6661053>,
      <-0.3114336, -0.1116970, 0.9436805>,
      <-0.3622749, 0.0488360, 0.9307910>,
      <0.0069615, 0.0065789, 0.9999541>,
      <-0.0204344, -0.0672569, 0.9975264>,
      <-0.0406309, -0.0922665, 0.9949050>,
      <-0.1225206, -0.1751386, 0.9768906>,
      <-0.1225206, -0.1751386, 0.9768906>,
      <-0.3267300, -0.7558415, 0.5674074>,
      <-0.6989674, -0.2588926, 0.6666478>,
      <-0.7835349, 0.0599960, 0.6184444>,
      <-0.2502750, 0.2029691, 0.9466604>,
      <0.0361541, 0.0772649, 0.9963549>,
      <-0.7429168, 0.3662946, 0.5602704>,
      <-0.6882423, 0.5091230, 0.5168329>,
      <0.0102646, 0.2356442, 0.9717852>,
      <0.0102646, 0.2356442, 0.9717852>,
      <0.0619566, 0.0993721, 0.9931196>,
      <0.3130610, 0.1190626, 0.9422404>,
      <0.3690961, -0.0208404, 0.9291576>,
      <0.0619566, 0.0993721, 0.9931196>,
      <0.1344429, 0.1724855, 0.9757940>,
      <0.1344429, 0.1724855, 0.9757940>,
      <0.3497831, 0.7334363, 0.5828576>,
      <0.6958359, 0.2675263, 0.6665149>,
      <0.7674919, -0.0274138, 0.6404722>,
      <0.2792820, -0.1574474, 0.9472127>,
      <0.6849686, -0.3101976, 0.6592385>,
      <0.3544738, -0.7329912, 0.5805792>,
      <0.0769455, -0.2042615, 0.9758876>,
      <0.0769455, -0.2042615, 0.9758876>,
      <-0.0406309, -0.0922665, 0.9949050>,
      <0.3083877, -0.1210303, -0.9435299>,
      <0.3649996, 0.0210663, -0.9307693>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <0.0212984, -0.0694051, -0.9973612>,
      <0.0401991, -0.0922697, -0.9949223>,
      <0.1213033, -0.1750782, -0.9770533>,
      <0.1213033, -0.1750782, -0.9770533>,
      <0.3243478, -0.7560162, -0.5685402>,
      <0.6886960, -0.2776307, -0.6697903>,
      <0.7638272, 0.0275239, -0.6448337>,
      <0.2741919, 0.1593919, -0.9483739>,
      <-0.0212984, 0.0694051, -0.9973612>,
      <0.6775887, 0.3200852, -0.6621322>,
      <0.3288676, 0.7556800, -0.5663866>,
      <0.0659791, 0.2068448, -0.9761465>,
      <0.0659791, 0.2068448, -0.9761465>,
      <-0.0401991, 0.0922697, -0.9949223>,
      <-0.3083877, 0.1210303, -0.9435299>,
      <-0.3649996, -0.0210663, -0.9307693>,
      <-0.0401991, 0.0922697, -0.9949223>,
      <-0.1213033, 0.1750782, -0.9770533>,
      <-0.1213033, 0.1750782, -0.9770533>,
      <-0.3243478, 0.7560162, -0.5685402>,
      <-0.6886960, 0.2776307, -0.6697903>,
      <-0.7638272, -0.0275239, -0.6448337>,
      <-0.2741919, -0.1593919, -0.9483739>,
      <-0.6775887, -0.3200852, -0.6621322>,
      <-0.3288676, -0.7556800, -0.5663866>,
      <-0.0659791, -0.2068448, -0.9761465>,
      <-0.0659791, -0.2068448, -0.9761465>,
      <0.0401991, -0.0922697, -0.9949223>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <0.2741919, -0.1593919, 0.9483739>,
      <-0.0212984, -0.0694051, 0.9973612>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.3649996, -0.0210663, 0.9307693>,
      <0.7638272, -0.0275239, 0.6448337>,
      <0.6775887, -0.3200852, 0.6621322>,
      <0.3288676, -0.7556800, 0.5663866>,
      <0.0659791, -0.2068448, 0.9761465>,
      <0.0659791, -0.2068448, 0.9761465>,
      <-0.0401991, -0.0922697, 0.9949223>,
      <-0.3083877, -0.1210303, 0.9435299>,
      <-0.3649996, 0.0210663, 0.9307693>,
      <-0.0401991, -0.0922697, 0.9949223>,
      <-0.1213033, -0.1750782, 0.9770533>,
      <-0.1213033, -0.1750782, 0.9770533>,
      <-0.3243478, -0.7560162, 0.5685402>,
      <-0.6886960, -0.2776307, 0.6697903>,
      <-0.7638272, 0.0275239, 0.6448337>,
      <-0.2741919, 0.1593919, 0.9483739>,
      <0.0212984, 0.0694051, 0.9973612>,
      <-0.6775887, 0.3200852, 0.6621322>,
      <-0.3288676, 0.7556800, 0.5663866>,
      <-0.0659791, 0.2068448, 0.9761465>,
      <-0.0659791, 0.2068448, 0.9761465>,
      <0.0401991, 0.0922697, 0.9949223>,
      <0.3092605, 0.1202293, 0.9433466>,
      <0.0401991, 0.0922697, 0.9949223>,
      <0.1258809, 0.1738081, 0.9767010>,
      <0.1258809, 0.1738081, 0.9767010>,
      <0.3341208, 0.7466395, 0.5752328>,
      <0.6901622, 0.2734790, 0.6699891>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <1.0000000, -0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, 0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, -0.0000000, -0.0000000>,
      <1.0000000, 0.0000000, -0.0000000>,
      <0.2770176, 0.1594361, -0.9475449>,
      <-0.0215406, 0.0694039, -0.9973561>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.3686853, 0.0210584, -0.9293157>,
      <0.7674919, 0.0274138, -0.6404722>,
      <0.6813637, 0.3194497, -0.6585556>,
      <0.3312750, 0.7554929, -0.5652321>,
      <0.0666422, 0.2068886, -0.9760922>,
      <0.0666422, 0.2068886, -0.9760922>,
      <-0.0406309, 0.0922665, -0.9949050>,
      <-0.3135500, 0.1192183, -0.9420581>,
      <-0.3686853, -0.0210584, -0.9293157>,
      <-0.0406309, 0.0922665, -0.9949050>,
      <-0.1332052, 0.1721985, -0.9760144>,
      <-0.1332052, 0.1721985, -0.9760144>,
      <-0.3497831, 0.7334363, -0.5828576>,
      <-0.6958359, 0.2675263, -0.6665149>,
      <-0.7674919, -0.0274138, -0.6404722>,
      <-0.2790581, -0.1576442, -0.9472459>,
      <0.0215406, -0.0694039, -0.9973561>,
      <-0.6849686, -0.3101976, -0.6592385>,
      <-0.3544738, -0.7329912, -0.5805792>,
      <-0.0769455, -0.2042615, -0.9758876>,
      <-0.0769455, -0.2042615, -0.9758876>,
      <0.0406309, -0.0922665, -0.9949050>,
      <0.3115195, -0.1210667, -0.9424959>,
      <0.0406309, -0.0922665, -0.9949050>,
      <0.1225206, -0.1751386, -0.9768906>,
      <0.1225206, -0.1751386, -0.9768906>,
      <0.3267300, -0.7558415, -0.5674074>,
      <0.6924710, -0.2771060, -0.6661053>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, -0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, -0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, -0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <0.3115195, 0.1210667, 0.9424959>,
      <0.3686853, -0.0210584, 0.9293157>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0215406, 0.0694039, 0.9973561>,
      <0.0406309, 0.0922665, 0.9949050>,
      <0.1225206, 0.1751386, 0.9768906>,
      <0.1225206, 0.1751386, 0.9768906>,
      <0.3267300, 0.7558415, 0.5674074>,
      <0.6924710, 0.2771060, 0.6661053>,
      <0.7674919, -0.0274138, 0.6404722>,
      <0.2770176, -0.1594361, 0.9475449>,
      <-0.0215406, -0.0694039, 0.9973561>,
      <0.6813637, -0.3194497, 0.6585556>,
      <0.3312750, -0.7554929, 0.5652321>,
      <0.0666422, -0.2068886, 0.9760922>,
      <0.0666422, -0.2068886, 0.9760922>,
      <-0.0406309, -0.0922665, 0.9949050>,
      <-0.3135500, -0.1192183, 0.9420581>,
      <-0.3686853, 0.0210584, 0.9293157>,
      <-0.0406309, -0.0922665, 0.9949050>,
      <-0.1332052, -0.1721985, 0.9760144>,
      <-0.1332052, -0.1721985, 0.9760144>,
      <-0.3497831, -0.7334363, 0.5828576>,
      <-0.6958359, -0.2675263, 0.6665149>,
      <-0.7674919, 0.0274138, 0.6404722>,
      <-0.2790581, 0.1576442, 0.9472459>,
      <-0.6849686, 0.3101976, 0.6592385>,
      <-0.3544738, 0.7329912, 0.5805792>,
      <-0.0769455, 0.2042615, 0.9758876>,
      <-0.0769455, 0.2042615, 0.9758876>,
      <0.0406309, 0.0922665, 0.9949050>,
      <0.9928935, -0.1167756, 0.0229342>,
      <0.9999785, 0.0002769, 0.0065491>,
      <0.9964800, 0.0029818, -0.0837780>,
      <0.9804802, -0.1834264, -0.0708055>,
      <0.8807901, -0.4708073, -0.0504907>,
      <0.9145580, -0.4025754, 0.0389458>,
      <0.9544129, -0.2715801, 0.1238561>,
      <0.9979726, -0.0396778, 0.0497622>,
      <0.9979726, -0.0396778, 0.0497622>,
      <0.9995112, 0.0000000, 0.0312631>,
      <0.9928130, 0.1173446, 0.0235054>,
      <0.9800540, 0.1870982, -0.0669956>,
      <0.9995112, 0.0000000, 0.0312631>,
      <0.9979726, 0.0396778, 0.0497622>,
      <0.9979726, 0.0396778, 0.0497622>,
      <0.9544129, 0.2715801, 0.1238561>,
      <0.9147869, 0.4019964, 0.0395458>,
      <0.8829979, 0.4670788, -0.0463915>,
      <0.9216567, 0.2737543, -0.2749681>,
      <0.9585195, 0.0131859, -0.2847218>,
      <0.7576979, 0.6060879, -0.2419740>,
      <0.9232132, -0.2568940, -0.2858020>,
      <0.7485080, -0.6131884, -0.2524595>,
      <-0.9924482, 0.1204737, 0.0230811>,
      <-0.9999785, -0.0002769, 0.0065491>,
      <-0.9964800, -0.0029818, -0.0837780>,
      <-0.9797030, 0.1875294, -0.0708146>,
      <-0.8721536, 0.4866366, -0.0503280>,
      <-0.9066310, 0.4201520, 0.0386326>,
      <-0.9521264, 0.2781447, 0.1268499>,
      <-0.9979299, 0.0400937, 0.0502838>,
      <-0.9979299, 0.0400937, 0.0502838>,
      <-0.9995112, 0.0000000, 0.0312631>,
      <-0.9923667, -0.1210331, 0.0236514>,
      <-0.9792696, -0.1911585, -0.0670030>,
      <-0.9995112, 0.0000000, 0.0312631>,
      <-0.9979299, -0.0400937, 0.0502838>,
      <-0.9979299, -0.0400937, 0.0502838>,
      <-0.9521264, -0.2781447, 0.1268499>,
      <-0.9068898, -0.4195378, 0.0392295>,
      <-0.8744965, -0.4828222, -0.0462457>,
      <-0.9199767, -0.2804012, -0.2738942>,
      <-0.9585195, -0.0131859, -0.2847218>,
      <-0.7446493, -0.6250981, -0.2339866>,
      <-0.9216223, 0.2637176, -0.2847199>,
      <-0.7354719, 0.6320467, -0.2441272>,
      <-0.9915391, -0.1279186, -0.0220686>,
      <-0.9991790, -0.0403094, 0.0040638>,
      <-0.9959075, -0.0475622, 0.0768517>,
      <-0.9785272, -0.1938953, 0.0699223>,
      <-0.8721536, -0.4866366, 0.0503280>,
      <-0.9066310, -0.4201520, -0.0386326>,
      <-0.9521264, -0.2781447, -0.1268499>,
      <-0.9979185, -0.0419926, -0.0489416>,
      <-0.9979185, -0.0419926, -0.0489416>,
      <-0.9998427, -0.0053017, -0.0169250>,
      <-0.9999460, -0.0044591, 0.0093834>,
      <-0.9985315, 0.0273908, 0.0467404>,
      <-0.9998427, -0.0053017, -0.0169250>,
      <-0.9999974, -0.0001613, -0.0022804>,
      <-0.9999974, -0.0001613, -0.0022804>,
      <-1.0000000, 0.0000000, 0.0000000>,
      <-0.9999833, 0.0057792, 0.0000000>,
      <-0.9999833, 0.0057792, 0.0000000>,
      <-0.9989329, 0.0461847, 0.0000000>,
      <-0.9755303, 0.1506027, 0.1601858>,
      <-0.9675405, -0.0018590, 0.2527090>,
      <-0.9989329, 0.0461847, 0.0000000>,
      <-0.9843277, 0.1763489, 0.0000000>,
      <-0.9843277, 0.1763489, 0.0000000>,
      <-0.6882423, 0.5091230, 0.5168329>,
      <-0.9247519, -0.2561360, 0.2814752>,
      <-0.7354719, -0.6320467, 0.2441272>,
      <0.9928935, 0.1167756, -0.0229342>,
      <0.9999785, -0.0002769, -0.0065491>,
      <0.9964800, -0.0029818, 0.0837780>,
      <0.9804802, 0.1834264, 0.0708055>,
      <0.8807901, 0.4708073, 0.0504907>,
      <0.9145580, 0.4025754, -0.0389458>,
      <0.9544129, 0.2715801, -0.1238561>,
      <0.9979726, 0.0396778, -0.0497622>,
      <0.9979726, 0.0396778, -0.0497622>,
      <0.9995112, 0.0000000, -0.0312631>,
      <0.9928130, -0.1173446, -0.0235054>,
      <0.9800540, -0.1870982, 0.0669956>,
      <0.9995112, 0.0000000, -0.0312631>,
      <0.9979726, -0.0396778, -0.0497622>,
      <0.9979726, -0.0396778, -0.0497622>,
      <0.9544129, -0.2715801, -0.1238561>,
      <0.9147869, -0.4019964, -0.0395458>,
      <0.8829979, -0.4670788, 0.0463915>,
      <0.9216567, -0.2737543, 0.2749681>,
      <0.9585195, -0.0131859, 0.2847218>,
      <0.7576979, -0.6060879, 0.2419740>,
      <0.9232132, 0.2568940, 0.2858020>,
      <0.7485080, 0.6131884, 0.2524595>,
      <0.9924604, -0.1204158, 0.0228540>,
      <0.9999802, 0.0002772, 0.0062946>,
      <0.9963805, 0.0029916, -0.0849525>,
      <0.9795812, -0.1877555, -0.0718924>,
      <0.8716658, -0.4874221, -0.0511709>,
      <0.9065541, -0.4203343, 0.0384554>,
      <0.9521264, -0.2781447, 0.1268499>,
      <0.9979299, -0.0400937, 0.0502838>,
      <0.9979299, -0.0400937, 0.0502838>,
      <0.9995112, 0.0000000, 0.0312631>,
      <0.9923790, 0.1209757, 0.0234249>,
      <0.9791496, 0.1913967, -0.0680685>,
      <0.9995112, 0.0000000, 0.0312631>,
      <0.9979299, 0.0400937, 0.0502838>,
      <0.9979299, 0.0400937, 0.0502838>,
      <0.9521264, 0.2781447, 0.1268499>,
      <0.9068132, 0.4197198, 0.0390527>,
      <0.8740199, 0.4836038, -0.0470809>,
      <0.9188516, 0.2812967, -0.2767380>,
      <0.9575967, 0.0132554, -0.2878069>,
      <0.7428225, 0.6265037, -0.2360251>,
      <0.9204894, -0.2645285, -0.2876178>,
      <0.7336004, -0.6334298, -0.2461650>,
      <-0.9924604, 0.1204158, 0.0228540>,
      <-0.9999802, -0.0002772, 0.0062946>,
      <-0.9963805, -0.0029916, -0.0849525>,
      <-0.9795812, 0.1877555, -0.0718924>,
      <-0.8716658, 0.4874221, -0.0511709>,
      <-0.9065541, 0.4203343, 0.0384554>,
      <-0.9521264, 0.2781447, 0.1268499>,
      <-0.9979299, 0.0400937, 0.0502838>,
      <-0.9979299, 0.0400937, 0.0502838>,
      <-0.9995112, 0.0000000, 0.0312631>,
      <-0.9923790, -0.1209757, 0.0234249>,
      <-0.9791496, -0.1913967, -0.0680685>,
      <-0.9995112, 0.0000000, 0.0312631>,
      <-0.9979299, -0.0400937, 0.0502838>,
      <-0.9979299, -0.0400937, 0.0502838>,
      <-0.9521264, -0.2781447, 0.1268499>,
      <-0.9068132, -0.4197198, 0.0390527>,
      <-0.8740199, -0.4836038, -0.0470809>,
      <-0.9188516, -0.2812967, -0.2767380>,
      <-0.9575967, -0.0132554, -0.2878069>,
      <-0.7428225, -0.6265037, -0.2360251>,
      <-0.9204894, 0.2645285, -0.2876178>,
      <-0.7336004, 0.6334298, -0.2461650>,
      <-0.9924604, -0.1204158, -0.0228540>,
      <-0.9999802, 0.0002772, -0.0062946>,
      <-0.9963805, 0.0029916, 0.0849525>,
      <-0.9795812, -0.1877555, 0.0718924>,
      <-0.8716658, -0.4874221, 0.0511709>,
      <-0.9065541, -0.4203343, -0.0384554>,
      <-0.9521264, -0.2781447, -0.1268499>,
      <-0.9979299, -0.0400937, -0.0502838>,
      <-0.9979299, -0.0400937, -0.0502838>,
      <-0.9995112, 0.0000000, -0.0312631>,
      <-0.9923790, 0.1209757, -0.0234249>,
      <-0.9791496, 0.1913967, 0.0680685>,
      <-0.9995112, 0.0000000, -0.0312631>,
      <-0.9979299, 0.0400937, -0.0502838>,
      <-0.9979299, 0.0400937, -0.0502838>,
      <-0.9521264, 0.2781447, -0.1268499>,
      <-0.9068132, 0.4197198, -0.0390527>,
      <-0.8740199, 0.4836038, 0.0470809>,
      <-0.9188516, 0.2812967, 0.2767380>,
      <-0.9575967, 0.0132554, 0.2878069>,
      <-0.7428225, 0.6265037, 0.2360251>,
      <-0.9204894, -0.2645285, 0.2876178>,
      <-0.7336004, -0.6334298, 0.2461650>,
      <0.9926554, 0.1188098, -0.0227902>,
      <0.9999802, -0.0002772, -0.0062946>,
      <0.9963805, -0.0029916, 0.0849525>,
      <0.9799218, 0.1859711, 0.0718886>,
      <0.8754435, 0.4805961, 0.0512447>,
      <0.9100239, 0.4127555, -0.0385920>,
      <0.9531099, 0.2753420, -0.1255717>,
      <0.9979485, 0.0399134, -0.0500577>,
      <0.9979485, 0.0399134, -0.0500577>,
      <0.9995112, 0.0000000, -0.0312631>,
      <0.9923790, -0.1209757, -0.0234249>,
      <0.9791496, -0.1913967, 0.0680685>,
      <0.9995112, 0.0000000, -0.0312631>,
      <0.9979299, -0.0400937, -0.0502838>,
      <0.9979299, -0.0400937, -0.0502838>,
      <0.9521264, -0.2781447, -0.1268499>,
      <0.9068132, -0.4197198, -0.0390527>,
      <0.8740199, -0.4836038, 0.0470809>,
      <0.9188516, -0.2812967, 0.2767380>,
      <0.9575967, -0.0132554, 0.2878069>,
      <0.7428225, -0.6265037, 0.2360251>,
      <0.9211876, 0.2615650, 0.2880924>,
      <0.7392438, 0.6254040, 0.2497768>,
      <-0.9928935, 0.1167756, 0.0229342>,
      <-0.9999785, -0.0002769, 0.0065491>,
      <-0.9964800, -0.0029818, -0.0837780>,
      <-0.9804802, 0.1834264, -0.0708055>,
      <-0.8807901, 0.4708073, -0.0504907>,
      <-0.9145580, 0.4025754, 0.0389458>,
      <-0.9544129, 0.2715801, 0.1238561>,
      <-0.9979726, 0.0396778, 0.0497622>,
      <-0.9979726, 0.0396778, 0.0497622>,
      <-0.9995112, 0.0000000, 0.0312631>,
      <-0.9928130, -0.1173446, 0.0235054>,
      <-0.9800540, -0.1870982, -0.0669956>,
      <-0.9995112, 0.0000000, 0.0312631>,
      <-0.9979726, -0.0396778, 0.0497622>,
      <-0.9979726, -0.0396778, 0.0497622>,
      <-0.9544129, -0.2715801, 0.1238561>,
      <-0.9147869, -0.4019964, 0.0395458>,
      <-0.8829979, -0.4670788, -0.0463915>,
      <-0.9216567, -0.2737543, -0.2749681>,
      <-0.9585195, -0.0131859, -0.2847218>,
      <-0.7576979, -0.6060879, -0.2419740>,
      <-0.9232132, 0.2568940, -0.2858020>,
      <-0.7485080, 0.6131884, -0.2524595>,
      <0.9924482, -0.1204737, 0.0230811>,
      <0.9999785, 0.0002769, 0.0065491>,
      <0.9964800, 0.0029818, -0.0837780>,
      <0.9797030, -0.1875294, -0.0708146>,
      <0.8721536, -0.4866366, -0.0503280>,
      <0.9066310, -0.4201520, 0.0386326>,
      <0.9521264, -0.2781447, 0.1268499>,
      <0.9979299, -0.0400937, 0.0502838>,
      <0.9979299, -0.0400937, 0.0502838>,
      <0.9995112, 0.0000000, 0.0312631>,
      <0.9923667, 0.1210331, 0.0236514>,
      <0.9792696, 0.1911585, -0.0670030>,
      <0.9995112, 0.0000000, 0.0312631>,
      <0.9979299, 0.0400937, 0.0502838>,
      <0.9979299, 0.0400937, 0.0502838>,
      <0.9521264, 0.2781447, 0.1268499>,
      <0.9068898, 0.4195378, 0.0392295>,
      <0.8744965, 0.4828222, -0.0462457>,
      <0.9199767, 0.2804012, -0.2738942>,
      <0.9585195, 0.0131859, -0.2847218>,
      <0.7446493, 0.6250981, -0.2339866>,
      <0.9216223, -0.2637176, -0.2847199>,
      <0.7354719, -0.6320467, -0.2441272>,
      <0.9924482, 0.1204737, -0.0230811>,
      <0.9999785, -0.0002769, -0.0065491>,
      <0.9964800, -0.0029818, 0.0837780>,
      <0.9797030, 0.1875294, 0.0708146>,
      <0.8721536, 0.4866366, 0.0503280>,
      <0.9066310, 0.4201520, -0.0386326>,
      <0.9521264, 0.2781447, -0.1268499>,
      <0.9979299, 0.0400937, -0.0502838>,
      <0.9979299, 0.0400937, -0.0502838>,
      <0.9995112, 0.0000000, -0.0312631>,
      <0.9923667, -0.1210331, -0.0236514>,
      <0.9792696, -0.1911585, 0.0670030>,
      <0.9995112, 0.0000000, -0.0312631>,
      <0.9979299, -0.0400937, -0.0502838>,
      <0.9979299, -0.0400937, -0.0502838>,
      <0.9521264, -0.2781447, -0.1268499>,
      <0.9068898, -0.4195378, -0.0392295>,
      <0.8744965, -0.4828222, 0.0462457>,
      <0.9199767, -0.2804012, 0.2738942>,
      <0.9585195, -0.0131859, 0.2847218>,
      <0.7446493, -0.6250981, 0.2339866>,
      <0.9216223, 0.2637176, 0.2847199>,
      <0.7354719, 0.6320467, 0.2441272>,
      <-0.9928935, -0.1167756, -0.0229342>,
      <-0.9999785, 0.0002769, -0.0065491>,
      <-0.9964800, 0.0029818, 0.0837780>,
      <-0.9804802, -0.1834264, 0.0708055>,
      <-0.8807901, -0.4708073, 0.0504907>,
      <-0.9145580, -0.4025754, -0.0389458>,
      <-0.9544129, -0.2715801, -0.1238561>,
      <-0.9979726, -0.0396778, -0.0497622>,
      <-0.9979726, -0.0396778, -0.0497622>,
      <-0.9995112, 0.0000000, -0.0312631>,
      <-0.9928130, 0.1173446, -0.0235054>,
      <-0.9800540, 0.1870982, 0.0669956>,
      <-0.9995112, 0.0000000, -0.0312631>,
      <-0.9979726, 0.0396778, -0.0497622>,
      <-0.9979726, 0.0396778, -0.0497622>,
      <-0.9544129, 0.2715801, -0.1238561>,
      <-0.9147869, 0.4019964, -0.0395458>,
      <-0.8829979, 0.4670788, 0.0463915>,
      <-0.9216567, 0.2737543, 0.2749681>,
      <-0.9585195, 0.0131859, 0.2847218>,
      <-0.7576979, 0.6060879, 0.2419740>,
      <-0.9232132, -0.2568940, 0.2858020>,
      <-0.7485080, -0.6131884, 0.2524595>,
      <0.0482097, -0.9987898, 0.0097358>,
      <0.1969688, -0.9791583, 0.0495208>,
      <0.3188757, -0.9470474, 0.0376770>,
      <0.2089778, -0.9776422, 0.0233263>,
      <-0.0000000, -1.0000000, -0.0000000>,
      <0.0143095, -0.9998365, 0.0110528>,
      <0.0551493, -0.9956726, 0.0747973>,
      <0.4410350, -0.8849010, 0.1497942>,
      <0.5973515, -0.8003804, 0.0506199>,
      <0.1299145, -0.9585727, 0.2534966>,
      <0.5870263, -0.8095641, -0.0024786>,
      <0.9544129, -0.2715801, -0.1238561>,
      <0.0480395, 0.9987978, 0.0097589>,
      <0.2084705, 0.9777479, 0.0234334>,
      <0.3152758, 0.9482275, 0.0382850>,
      <0.1931316, 0.9799203, 0.0495628>,
      <0.0536178, 0.9958594, 0.0734115>,
      <0.0142523, 0.9998377, 0.0110167>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <0.5858114, 0.8104447, -0.0020890>,
      <0.5902082, 0.8055244, 0.0527708>,
      <0.9544129, 0.2715801, -0.1238561>,
      <0.4258763, 0.8920912, 0.1510057>,
      <0.1216223, 0.9617354, 0.2455058>,
      <0.0009324, -0.9998915, 0.0147042>,
      <0.0070028, -0.9979075, 0.0642775>,
      <0.0006708, -0.9991505, 0.0412039>,
      <0.0001017, -0.9999532, 0.0096693>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.0134997, -0.9998402, 0.0117224>,
      <-0.0463852, -0.9965598, 0.0686802>,
      <0.0517822, -0.9877922, 0.1469186>,
      <0.0000462, -0.9970278, 0.0770428>,
      <-0.1100614, -0.9658078, 0.2347377>,
      <0.2055456, -0.9557358, 0.2105233>,
      <0.2055456, -0.9557358, 0.2105233>,
      <-0.0036764, -0.9959329, 0.0900227>,
      <-0.0495848, -0.9867662, 0.1543818>,
      <-0.0040415, -0.9978479, 0.0654463>,
      <-0.0036764, -0.9959329, 0.0900227>,
      <-0.2115209, -0.9523944, 0.2195537>,
      <-0.2115209, -0.9523944, 0.2195537>,
      <-0.0001451, -0.9999017, 0.0140175>,
      <-0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <-0.0003095, 0.9999998, 0.0005534>,
      <-0.0010901, 0.9999866, 0.0050658>,
      <-0.0112265, 0.9997184, 0.0209052>,
      <-0.0029897, 0.9999942, 0.0016432>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.0004248, 0.9999075, 0.0135909>,
      <-0.0068243, 0.9979973, 0.0628868>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <-0.0586049, 0.9874677, 0.1465370>,
      <-0.0468893, 0.9982445, 0.0361845>,
      <-0.2298621, 0.9504710, 0.2092088>,
      <-0.2298621, 0.9504710, 0.2092088>,
      <-0.1185366, 0.9922306, 0.0377825>,
      <-0.0116084, 0.9999324, 0.0007253>,
      <-0.1185366, 0.9922306, 0.0377825>,
      <-0.0287953, 0.9995755, -0.0044304>,
      <-0.0287953, 0.9995755, -0.0044304>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <-0.0425592, -0.9990531, 0.0090291>,
      <-0.1862363, -0.9821957, 0.0246510>,
      <-0.2920535, -0.9556906, 0.0368813>,
      <-0.1821572, -0.9823047, 0.0435463>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.5568339, -0.8306238, 0.0002554>,
      <-0.5634159, -0.8245649, 0.0515288>,
      <-0.9521264, -0.2781447, -0.1268499>,
      <-0.4100657, -0.9013040, 0.1396325>,
      <0.0428235, -0.9990412, 0.0091022>,
      <0.1853207, -0.9816935, 0.0439790>,
      <0.2954967, -0.9546384, 0.0367041>,
      <0.1873545, -0.9819826, 0.0246678>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0135324, -0.9998386, 0.0118215>,
      <0.0474538, -0.9964129, 0.0700674>,
      <0.4227513, -0.8954629, 0.1393823>,
      <0.5697889, -0.8202656, 0.0500491>,
      <0.1167373, -0.9631452, 0.2423297>,
      <0.5583231, -0.8296236, -0.0000141>,
      <0.9521264, -0.2781447, -0.1268499>,
      <0.0448383, 0.9989505, 0.0093542>,
      <0.1958972, 0.9803257, 0.0242028>,
      <0.3014456, 0.9527326, 0.0378308>,
      <0.1860469, 0.9814434, 0.0464255>,
      <0.0490044, 0.9962937, 0.0706925>,
      <0.0137997, 0.9998393, 0.0114458>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <0.5692041, 0.8221960, -0.0006158>,
      <0.5739981, 0.8171615, 0.0526616>,
      <0.9531099, 0.2753420, -0.1255717>,
      <0.4150961, 0.8980793, 0.1454264>,
      <0.1141343, 0.9641388, 0.2396034>,
      <-0.0008921, -0.9998907, 0.0147602>,
      <-0.0000041, -0.9999522, 0.0097728>,
      <-0.0001775, -0.9991508, 0.0412023>,
      <-0.0068319, -0.9978443, 0.0652686>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0008861, -0.9998915, 0.0147012>,
      <0.0066010, -0.9979200, 0.0641261>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.0134757, -0.9998398, 0.0117812>,
      <-0.0461894, -0.9965552, 0.0688787>,
      <0.0506046, -0.9879379, 0.1463486>,
      <-0.0012894, -0.9970972, 0.0761287>,
      <-0.1093416, -0.9658024, 0.2350958>,
      <0.2037573, -0.9563439, 0.2094980>,
      <0.2037573, -0.9563439, 0.2094980>,
      <-0.0035806, -0.9960591, 0.0886200>,
      <-0.0530826, -0.9871032, 0.1510280>,
      <-0.0035806, -0.9960591, 0.0886200>,
      <-0.2108064, -0.9534055, 0.2158207>,
      <-0.2108064, -0.9534055, 0.2158207>,
      <-0.0005697, 0.9998964, 0.0143829>,
      <-0.0054363, 0.9979236, 0.0641793>,
      <0.0005430, 0.9991507, 0.0412016>,
      <0.0000499, 0.9999527, 0.0097277>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.0000000, 1.0000000, -0.0000000>,
      <-0.0489678, 0.9878285, 0.1476381>,
      <0.0018879, 0.9970659, 0.0765253>,
      <-0.2031728, 0.9561712, 0.2108495>,
      <-0.2031728, 0.9561712, 0.2108495>,
      <0.0036064, 0.9960021, 0.0892572>,
      <0.0534248, 0.9870530, 0.1512353>,
      <0.0069905, 0.9978395, 0.0653259>,
      <0.0036064, 0.9960021, 0.0892572>,
      <0.2107538, 0.9533459, 0.2161352>,
      <0.2107538, 0.9533459, 0.2161352>,
      <-0.1167373, 0.9631452, 0.2423297>,
      <-0.0474538, 0.9964129, 0.0700674>,
      <0.0009106, 0.9998906, 0.0147601>,
      <-0.0135324, 0.9998386, 0.0118215>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.0426686, -0.9990476, 0.0091266>,
      <-0.1868743, -0.9820715, 0.0247703>,
      <-0.2921314, -0.9556506, 0.0372976>,
      <-0.1819054, -0.9823270, 0.0440922>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.5571086, -0.8304396, 0.0003650>,
      <-0.5627351, -0.8249912, 0.0521416>,
      <-0.9521264, -0.2781447, -0.1268499>,
      <-0.4085956, -0.9018097, 0.1406728>,
      <-0.0428235, 0.9990412, 0.0091022>,
      <-0.1853207, 0.9816935, 0.0439790>,
      <-0.2954967, 0.9546384, 0.0367041>,
      <-0.1873545, 0.9819826, 0.0246678>,
      <0.0000000, 1.0000000, 0.0000000>,
      <-0.4227513, 0.8954629, 0.1393823>,
      <-0.5697889, 0.8202656, 0.0500491>,
      <-0.5583231, 0.8296236, -0.0000141>,
      <-0.9521264, 0.2781447, -0.1268499>,
      <0.0427128, -0.9990468, 0.0090044>,
      <0.1855590, -0.9816732, 0.0434234>,
      <0.2954049, -0.9546828, 0.0362854>,
      <0.1867130, -0.9821077, 0.0245486>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0135562, -0.9998389, 0.0117623>,
      <0.0476525, -0.9964179, 0.0698612>,
      <0.4242230, -0.8949337, 0.1383059>,
      <0.5704583, -0.8198376, 0.0494329>,
      <0.1175005, -0.9631500, 0.2419417>,
      <0.5580465, -0.8298096, -0.0001235>,
      <0.9521264, -0.2781447, -0.1268499>,
      <0.0425592, 0.9990531, 0.0090291>,
      <0.1862363, 0.9821957, 0.0246510>,
      <0.2920535, 0.9556906, 0.0368813>,
      <0.1821572, 0.9823047, 0.0435463>,
      <0.0463852, 0.9965598, 0.0686802>,
      <0.0134997, 0.9998402, 0.0117224>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.5568339, 0.8306238, 0.0002554>,
      <0.5634159, 0.8245649, 0.0515288>,
      <0.9521264, 0.2781447, -0.1268499>,
      <0.4100657, 0.9013040, 0.1396325>,
      <0.1100614, 0.9658078, 0.2347377>,
      <-0.0009386, -0.9998906, 0.0147632>,
      <-0.0001099, -0.9999532, 0.0096692>,
      <-0.0010330, -0.9991503, 0.0412012>,
      <-0.0072424, -0.9978313, 0.0654240>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0001421, -0.9999025, 0.0139634>,
      <0.0038544, -0.9979242, 0.0642840>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <-0.0142523, -0.9998377, 0.0110167>,
      <-0.0536178, -0.9958594, 0.0734115>,
      <0.0471304, -0.9876428, 0.1494671>,
      <-0.0027100, -0.9970232, 0.0770551>,
      <-0.1216223, -0.9617354, 0.2455058>,
      <0.2043065, -0.9554497, 0.2130134>,
      <0.2043065, -0.9554497, 0.2130134>,
      <-0.0036797, -0.9959258, 0.0901017>,
      <-0.0543149, -0.9869442, 0.1516279>,
      <-0.0036797, -0.9959258, 0.0901017>,
      <-0.2126843, -0.9527437, 0.2168982>,
      <-0.2126843, -0.9527437, 0.2168982>,
      <-0.0009324, 0.9998915, 0.0147042>,
      <-0.0070028, 0.9979075, 0.0642775>,
      <-0.0006708, 0.9991505, 0.0412039>,
      <-0.0001017, 0.9999532, 0.0096693>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <-0.0517822, 0.9877922, 0.1469186>,
      <-0.0000462, 0.9970278, 0.0770428>,
      <-0.2055456, 0.9557358, 0.2105233>,
      <-0.2055456, 0.9557358, 0.2105233>,
      <0.0036764, 0.9959329, 0.0900227>,
      <0.0495848, 0.9867662, 0.1543818>,
      <0.0040415, 0.9978479, 0.0654463>,
      <0.0036764, 0.9959329, 0.0900227>,
      <0.2115209, 0.9523944, 0.2195537>,
      <0.2115209, 0.9523944, 0.2195537>,
      <-0.1299145, 0.9585727, 0.2534966>,
      <-0.0551493, 0.9956726, 0.0747973>,
      <0.0001451, 0.9999017, 0.0140175>,
      <-0.0143095, 0.9998365, 0.0110528>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.0480395, -0.9987978, 0.0097589>,
      <-0.2084705, -0.9777479, 0.0234334>,
      <-0.3152758, -0.9482275, 0.0382850>,
      <-0.1931316, -0.9799203, 0.0495628>,
      <0.0000000, -1.0000000, -0.0000000>,
      <-0.5858114, -0.8104447, -0.0020890>,
      <-0.5902082, -0.8055244, 0.0527708>,
      <-0.9544129, -0.2715801, -0.1238561>,
      <-0.4258763, -0.8920912, 0.1510057>,
      <-0.0482097, 0.9987898, 0.0097358>,
      <-0.1969688, 0.9791583, 0.0495208>,
      <-0.3188757, 0.9470474, 0.0376770>,
      <-0.2089778, 0.9776422, 0.0233263>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.4410350, 0.8849010, 0.1497942>,
      <-0.5973515, 0.8003804, 0.0506199>,
      <-0.5870263, 0.8095641, -0.0024786>,
      <-0.9544129, 0.2715801, -0.1238561>,
      <0.0480395, -0.9987978, -0.0097589>,
      <0.2084705, -0.9777479, -0.0234334>,
      <0.3152758, -0.9482275, -0.0382850>,
      <0.1931316, -0.9799203, -0.0495628>,
      <0.0536178, -0.9958594, -0.0734115>,
      <0.0142523, -0.9998377, -0.0110167>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <0.5858114, -0.8104447, 0.0020890>,
      <0.5902082, -0.8055244, -0.0527708>,
      <0.9544129, -0.2715801, 0.1238561>,
      <0.4258763, -0.8920912, -0.1510057>,
      <0.1216223, -0.9617354, -0.2455058>,
      <0.0482097, 0.9987898, -0.0097358>,
      <0.1969688, 0.9791583, -0.0495208>,
      <0.3188757, 0.9470474, -0.0376770>,
      <0.2089778, 0.9776422, -0.0233263>,
      <-0.0000000, 1.0000000, 0.0000000>,
      <0.0143095, 0.9998365, -0.0110528>,
      <0.0551493, 0.9956726, -0.0747973>,
      <0.4410350, 0.8849010, -0.1497942>,
      <0.5973515, 0.8003804, -0.0506199>,
      <0.1299145, 0.9585727, -0.2534966>,
      <0.5870263, 0.8095641, 0.0024786>,
      <0.9544129, 0.2715801, 0.1238561>,
      <0.0009386, -0.9998906, -0.0147632>,
      <0.0001099, -0.9999532, -0.0096692>,
      <0.0010330, -0.9991503, -0.0412012>,
      <0.0072424, -0.9978313, -0.0654240>,
      <-0.0476525, -0.9964179, -0.0698612>,
      <-0.0135562, -0.9998389, -0.0117623>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.0001421, -0.9999025, -0.0139634>,
      <-0.0038544, -0.9979242, -0.0642840>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.0000000, -1.0000000, 0.0000000>,
      <-0.0471304, -0.9876428, -0.1494671>,
      <0.0027100, -0.9970232, -0.0770551>,
      <-0.2043065, -0.9554497, -0.2130134>,
      <-0.2043065, -0.9554497, -0.2130134>,
      <0.0036797, -0.9959258, -0.0901017>,
      <0.0543149, -0.9869442, -0.1516279>,
      <0.0036797, -0.9959258, -0.0901017>,
      <0.2126843, -0.9527437, -0.2168982>,
      <0.2126843, -0.9527437, -0.2168982>,
      <-0.1175005, -0.9631500, -0.2419417>,
      <0.0009324, 0.9998915, -0.0147042>,
      <0.0070028, 0.9979075, -0.0642775>,
      <0.0006708, 0.9991505, -0.0412039>,
      <0.0001017, 0.9999532, -0.0096693>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.0134609, 0.9998407, -0.0117243>,
      <-0.0463852, 0.9965598, -0.0686802>,
      <0.0517822, 0.9877922, -0.1469186>,
      <0.0000462, 0.9970278, -0.0770428>,
      <-0.1100614, 0.9658078, -0.2347377>,
      <0.2055456, 0.9557358, -0.2105233>,
      <0.2055456, 0.9557358, -0.2105233>,
      <-0.0036764, 0.9959329, -0.0900227>,
      <-0.0495848, 0.9867662, -0.1543818>,
      <-0.0040415, 0.9978479, -0.0654463>,
      <-0.0036764, 0.9959329, -0.0900227>,
      <-0.2115209, 0.9523944, -0.2195537>,
      <-0.2115209, 0.9523944, -0.2195537>,
      <-0.0001451, 0.9999017, -0.0140175>,
      <-0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <-0.0427128, -0.9990468, -0.0090044>,
      <-0.1855590, -0.9816732, -0.0434234>,
      <-0.2954049, -0.9546828, -0.0362854>,
      <-0.1867130, -0.9821077, -0.0245486>,
      <0.0000000, -1.0000000, -0.0000000>,
      <-0.4242230, -0.8949337, -0.1383059>,
      <-0.5704583, -0.8198376, -0.0494329>,
      <-0.5580465, -0.8298096, 0.0001235>,
      <-0.9521264, -0.2781447, 0.1268499>,
      <-0.0423815, 0.9990605, -0.0090515>,
      <-0.1858453, 0.9822686, -0.0246971>,
      <-0.2920535, 0.9556906, -0.0368813>,
      <-0.1821572, 0.9823047, -0.0435463>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.5568333, 0.8306242, -0.0002555>,
      <-0.5634159, 0.8245649, -0.0515288>,
      <-0.9521264, 0.2781447, 0.1268499>,
      <-0.4100657, 0.9013040, -0.1396325>,
      <0.0426686, -0.9990476, -0.0091266>,
      <0.1868743, -0.9820715, -0.0247703>,
      <0.2921314, -0.9556506, -0.0372976>,
      <0.1819054, -0.9823270, -0.0440922>,
      <0.0461894, -0.9965552, -0.0688787>,
      <0.0134757, -0.9998398, -0.0117812>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.5571086, -0.8304396, -0.0003650>,
      <0.5627351, -0.8249912, -0.0521416>,
      <0.9521264, -0.2781447, 0.1268499>,
      <0.4085956, -0.9018097, -0.1406728>,
      <0.1093416, -0.9658024, -0.2350958>,
      <0.0426438, 0.9990487, -0.0091245>,
      <0.1853207, 0.9816935, -0.0439790>,
      <0.2954967, 0.9546384, -0.0367041>,
      <0.1869615, 0.9820563, -0.0247139>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0134933, 0.9998391, -0.0118233>,
      <0.0474538, 0.9964129, -0.0700674>,
      <0.4227513, 0.8954629, -0.1393823>,
      <0.5697889, 0.8202656, -0.0500491>,
      <0.1167373, 0.9631452, -0.2423297>,
      <0.5583231, 0.8296236, 0.0000141>,
      <0.9521264, 0.2781447, 0.1268499>,
      <-0.0008861, -0.9998915, -0.0147012>,
      <-0.0066010, -0.9979200, -0.0641261>,
      <0.0001775, -0.9991508, -0.0412023>,
      <0.0000041, -0.9999522, -0.0097728>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <-0.0506046, -0.9879379, -0.1463486>,
      <0.0012894, -0.9970972, -0.0761287>,
      <-0.2037573, -0.9563439, -0.2094980>,
      <-0.2037573, -0.9563439, -0.2094980>,
      <0.0035806, -0.9960591, -0.0886200>,
      <0.0530826, -0.9871032, -0.1510280>,
      <0.0068319, -0.9978443, -0.0652686>,
      <0.0035806, -0.9960591, -0.0886200>,
      <0.2108064, -0.9534055, -0.2158207>,
      <0.2108064, -0.9534055, -0.2158207>,
      <-0.1167373, -0.9631452, -0.2423297>,
      <-0.0474538, -0.9964129, -0.0700674>,
      <0.0008921, -0.9998907, -0.0147602>,
      <-0.0135324, -0.9998386, -0.0118215>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.0008921, 0.9998907, -0.0147602>,
      <-0.0000041, 0.9999522, -0.0097728>,
      <-0.0001775, 0.9991508, -0.0412023>,
      <-0.0068319, 0.9978443, -0.0652686>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0008861, 0.9998915, -0.0147012>,
      <0.0066010, 0.9979200, -0.0641261>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.0134757, 0.9998398, -0.0117812>,
      <-0.0461894, 0.9965552, -0.0688787>,
      <0.0506046, 0.9879379, -0.1463486>,
      <-0.0012894, 0.9970972, -0.0761287>,
      <-0.1093416, 0.9658024, -0.2350958>,
      <0.2037573, 0.9563439, -0.2094980>,
      <0.2037573, 0.9563439, -0.2094980>,
      <-0.0035806, 0.9960591, -0.0886200>,
      <-0.0530826, 0.9871032, -0.1510280>,
      <-0.0035806, 0.9960591, -0.0886200>,
      <-0.2108064, 0.9534055, -0.2158207>,
      <-0.2108064, 0.9534055, -0.2158207>,
      <-0.0428235, -0.9990412, -0.0091022>,
      <-0.1853207, -0.9816935, -0.0439790>,
      <-0.2954967, -0.9546384, -0.0367041>,
      <-0.1873545, -0.9819826, -0.0246678>,
      <0.0000000, -1.0000000, -0.0000000>,
      <-0.4227513, -0.8954629, -0.1393823>,
      <-0.5697889, -0.8202656, -0.0500491>,
      <-0.5583231, -0.8296236, 0.0000141>,
      <-0.9521264, -0.2781447, 0.1268499>,
      <-0.0426686, 0.9990476, -0.0091266>,
      <-0.1868743, 0.9820715, -0.0247703>,
      <-0.2921314, 0.9556506, -0.0372976>,
      <-0.1819054, 0.9823270, -0.0440922>,
      <0.0000000, 1.0000000, -0.0000000>,
      <-0.5571086, 0.8304396, -0.0003650>,
      <-0.5627351, 0.8249912, -0.0521416>,
      <-0.9521264, 0.2781447, 0.1268499>,
      <-0.4085956, 0.9018097, -0.1406728>,
      <0.0425592, -0.9990531, -0.0090291>,
      <0.1862363, -0.9821957, -0.0246510>,
      <0.2920535, -0.9556906, -0.0368813>,
      <0.1821572, -0.9823047, -0.0435463>,
      <0.0463852, -0.9965598, -0.0686802>,
      <0.0134997, -0.9998402, -0.0117224>,
      <0.0000000, -1.0000000, -0.0000000>,
      <0.5568339, -0.8306238, -0.0002554>,
      <0.5634159, -0.8245649, -0.0515288>,
      <0.9521264, -0.2781447, 0.1268499>,
      <0.4100657, -0.9013040, -0.1396325>,
      <0.1100614, -0.9658078, -0.2347377>,
      <0.0427128, 0.9990468, -0.0090044>,
      <0.1855590, 0.9816732, -0.0434234>,
      <0.2954049, 0.9546828, -0.0362854>,
      <0.1867130, 0.9821077, -0.0245486>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0135562, 0.9998389, -0.0117623>,
      <0.0476525, 0.9964179, -0.0698612>,
      <0.4242230, 0.8949337, -0.1383059>,
      <0.5704583, 0.8198376, -0.0494329>,
      <0.1175005, 0.9631500, -0.2419417>,
      <0.5580465, 0.8298096, 0.0001235>,
      <0.9521264, 0.2781447, 0.1268499>,
      <-0.0009324, -0.9998915, -0.0147042>,
      <-0.0070028, -0.9979075, -0.0642775>,
      <-0.0006708, -0.9991505, -0.0412039>,
      <-0.0001017, -0.9999532, -0.0096693>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, -0.0000000>,
      <-0.0517822, -0.9877922, -0.1469186>,
      <-0.0000462, -0.9970278, -0.0770428>,
      <-0.2055456, -0.9557358, -0.2105233>,
      <-0.2055456, -0.9557358, -0.2105233>,
      <0.0036764, -0.9959329, -0.0900227>,
      <0.0495848, -0.9867662, -0.1543818>,
      <0.0040415, -0.9978479, -0.0654463>,
      <0.0036764, -0.9959329, -0.0900227>,
      <0.2115209, -0.9523944, -0.2195537>,
      <0.2115209, -0.9523944, -0.2195537>,
      <-0.1299145, -0.9585727, -0.2534966>,
      <-0.0551493, -0.9956726, -0.0747973>,
      <0.0001451, -0.9999017, -0.0140175>,
      <-0.0143095, -0.9998365, -0.0110528>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.0009386, 0.9998906, -0.0147632>,
      <-0.0001099, 0.9999532, -0.0096692>,
      <-0.0010330, 0.9991503, -0.0412012>,
      <-0.0072424, 0.9978313, -0.0654240>,
      <0.0000000, 1.0000000, -0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0001421, 0.9999025, -0.0139634>,
      <0.0038544, 0.9979242, -0.0642840>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <0.0000000, 1.0000000, 0.0000000>,
      <-0.0142523, 0.9998377, -0.0110167>,
      <-0.0536178, 0.9958594, -0.0734115>,
      <0.0471304, 0.9876428, -0.1494671>,
      <-0.0027100, 0.9970232, -0.0770551>,
      <-0.1216223, 0.9617354, -0.2455058>,
      <0.2043065, 0.9554497, -0.2130134>,
      <0.2043065, 0.9554497, -0.2130134>,
      <-0.0036797, 0.9959258, -0.0901017>,
      <-0.0543149, 0.9869442, -0.1516279>,
      <-0.0036797, 0.9959258, -0.0901017>,
      <-0.2126843, 0.9527437, -0.2168982>,
      <-0.2126843, 0.9527437, -0.2168982>,
      <-0.0482097, -0.9987898, -0.0097358>,
      <-0.1969688, -0.9791583, -0.0495208>,
      <-0.3188757, -0.9470474, -0.0376770>,
      <-0.2089778, -0.9776422, -0.0233263>,
      <0.0000000, -1.0000000, 0.0000000>,
      <-0.4410350, -0.8849010, -0.1497942>,
      <-0.5973515, -0.8003804, -0.0506199>,
      <-0.5870263, -0.8095641, 0.0024786>,
      <-0.9544129, -0.2715801, 0.1238561>,
      <-0.0480395, 0.9987978, -0.0097589>,
      <-0.2084705, 0.9777479, -0.0234334>,
      <-0.3152758, 0.9482275, -0.0382850>,
      <-0.1931316, 0.9799203, -0.0495628>,
      <0.0000000, 1.0000000, 0.0000000>,
      <-0.5858114, 0.8104447, 0.0020890>,
      <-0.5902082, 0.8055244, -0.0527708>,
      <-0.9544129, 0.2715801, 0.1238561>,
      <-0.4258763, 0.8920912, -0.1510057>
    }
    uv_vectors {
      914,
      <0.2500000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 1.0000000>,
      <0.5000000, 1.0000000>,
      <0.2500000, 0.0000000>,
      <0.5000000, 0.0000000>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.3333333>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.3333333>,
      <1.0000000, 0.6666667>,
      <1.0000000, 0.3333333>,
      <0.3750000, 0.5000000>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.6666667>,
      <0.2500000, 0.5000000>,
      <0.3750000, 0.3333333>,
      <0.5000000, 0.5000000>,
      <0.3750000, 0.6666667>,
      <0.8750000, 0.5000000>,
      <1.0000000, 0.3333333>,
      <1.0000000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.3333333>,
      <1.0000000, 0.5000005>,
      <0.8750871, 0.6666667>,
      <0.7500000, 0.5000000>,
      <0.8750000, 0.3333333>,
      <0.1250000, 0.5000000>,
      <0.0000000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.1250000, 0.3333333>,
      <0.2500000, 0.5000000>,
      <0.1250000, 0.6666667>,
      <0.0000000, 0.5000000>,
      <0.6250000, 0.5000000>,
      <0.7500000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6250000, 0.6666667>,
      <0.5000000, 0.5000000>,
      <0.6250000, 0.3333333>,
      <0.7500000, 0.5000000>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.3333333>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.5000005>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.6666667>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.6666667>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.3333333>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.0000000>,
      <0.2500000, 0.0000000>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.0000000>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.3333333>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.0000000>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.0000000>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.0000000>,
      <0.2500000, 0.8333333>,
      <0.2500000, 1.0000000>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 1.0000000>,
      <0.2500000, 0.8399549>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.8333333>,
      <0.2500000, 1.0000000>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.6666667>,
      <0.5000000, 1.0000000>,
      <0.5000000, 1.0000000>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.8333333>,
      <0.5000000, 1.0000000>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.6666667>,
      <0.1250000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1250000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1200338, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.1078428, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.6250000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.3125000, 0.5833333>,
      <0.3750000, 0.5000000>,
      <0.3750000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.5000000>,
      <0.3750000, 0.5833333>,
      <0.3125218, 0.6666667>,
      <0.2500000, 0.5833333>,
      <0.3125218, 0.5000000>,
      <0.3125000, 0.4166667>,
      <0.3750000, 0.5000000>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.3333333>,
      <0.3750000, 0.3333333>,
      <0.3125218, 0.5000000>,
      <0.2500000, 0.4166667>,
      <0.3125218, 0.3333333>,
      <0.3750000, 0.4166667>,
      <0.4375000, 0.4166667>,
      <0.3750000, 0.5000000>,
      <0.3750000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.5000000>,
      <0.3750000, 0.4166667>,
      <0.4374782, 0.3333333>,
      <0.5000000, 0.4166667>,
      <0.4374782, 0.5000000>,
      <0.4375000, 0.5833333>,
      <0.3750000, 0.5000000>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.6666667>,
      <0.3750000, 0.6666667>,
      <0.4374782, 0.5000000>,
      <0.5000000, 0.5833333>,
      <0.4374782, 0.6666667>,
      <0.3750000, 0.5833333>,
      <0.9375000, 0.4166668>,
      <0.8750000, 0.5000000>,
      <0.8750000, 0.3333333>,
      <1.0000000, 0.3333333>,
      <1.0000000, 0.5000005>,
      <0.8750000, 0.4166667>,
      <0.9374782, 0.3333333>,
      <1.0000000, 0.4166669>,
      <0.9374768, 0.5000002>,
      <0.9375218, 0.5833335>,
      <0.8750000, 0.5000000>,
      <1.0000000, 0.5000005>,
      <1.0000000, 0.6666667>,
      <0.8750871, 0.6666667>,
      <0.9374768, 0.5000002>,
      <1.0000000, 0.5833342>,
      <0.9375544, 0.6666667>,
      <0.8750436, 0.5833333>,
      <0.8125218, 0.5833333>,
      <0.8750000, 0.5000000>,
      <0.8750871, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.5000000>,
      <0.8750436, 0.5833333>,
      <0.8125763, 0.6666667>,
      <0.7500000, 0.5833333>,
      <0.8125232, 0.5000000>,
      <0.8125000, 0.4166667>,
      <0.8750000, 0.5000000>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.3333333>,
      <0.8750000, 0.3333333>,
      <0.8125232, 0.5000000>,
      <0.7500000, 0.4166667>,
      <0.8125218, 0.3333333>,
      <0.8750000, 0.4166667>,
      <0.0625000, 0.4166667>,
      <0.1250000, 0.5000000>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0625000, 0.5000000>,
      <0.0000000, 0.4166667>,
      <0.0625000, 0.3333333>,
      <0.1250000, 0.4166667>,
      <0.1875000, 0.4166667>,
      <0.1250000, 0.5000000>,
      <0.1250000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.5000000>,
      <0.1250000, 0.4166667>,
      <0.1875000, 0.3333333>,
      <0.2500000, 0.4166667>,
      <0.1875000, 0.5000000>,
      <0.1875000, 0.5833333>,
      <0.1250000, 0.5000000>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.1875000, 0.5000000>,
      <0.2500000, 0.5833333>,
      <0.1875000, 0.6666667>,
      <0.1250000, 0.5833333>,
      <0.0625000, 0.5833333>,
      <0.1250000, 0.5000000>,
      <0.1250000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.5000000>,
      <0.1250000, 0.5833333>,
      <0.0625000, 0.6666667>,
      <0.0000000, 0.5833333>,
      <0.0625000, 0.5000000>,
      <0.6875000, 0.5833333>,
      <0.6250000, 0.5000000>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6875000, 0.5000000>,
      <0.7500000, 0.5833333>,
      <0.6875000, 0.6666667>,
      <0.6250000, 0.5833333>,
      <0.5625000, 0.5833333>,
      <0.6250000, 0.5000000>,
      <0.6250000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.5000000>,
      <0.6250000, 0.5833333>,
      <0.5625000, 0.6666667>,
      <0.5000000, 0.5833333>,
      <0.5625000, 0.5000000>,
      <0.5625000, 0.4166667>,
      <0.6250000, 0.5000000>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5625000, 0.5000000>,
      <0.5000000, 0.4166667>,
      <0.5625000, 0.3333333>,
      <0.6250000, 0.4166667>,
      <0.6875000, 0.4166667>,
      <0.6250000, 0.5000000>,
      <0.6250000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.5000000>,
      <0.6250000, 0.4166667>,
      <0.6875000, 0.3333333>,
      <0.7500000, 0.4166667>,
      <0.6875000, 0.5000000>,
      <0.2500000, 0.4166667>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.4166667>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.4166667>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.5833333>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.5833333>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.5833333>,
      <0.2500000, 0.5833333>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.5833333>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.5833333>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.4166667>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.5000000>,
      <0.2500000, 0.4166667>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.4166667>,
      <0.0000000, 0.5833335>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.5000005>,
      <0.0000000, 0.5833333>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.5833342>,
      <0.0000000, 0.5000002>,
      <0.0000000, 0.4166668>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.5000005>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.5000002>,
      <0.0000000, 0.4166669>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.4166667>,
      <0.0000000, 0.4166667>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.4166667>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.4166667>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.5833333>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.5000000>,
      <0.0000000, 0.5833333>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.5833333>,
      <0.5000000, 0.5833333>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.5833333>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.5833333>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.4166667>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.4166667>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.4166667>,
      <0.5000000, 0.4166667>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.4166667>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.4166667>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.5833333>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.5000000>,
      <0.5000000, 0.5833333>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.5833333>,
      <0.7500000, 0.4166667>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.4166667>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.4166667>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.5833333>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.5833333>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.5833333>,
      <0.7500000, 0.5833333>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.5833333>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.5833333>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.4166667>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.5000000>,
      <0.7500000, 0.4166667>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.4166667>,
      <0.2500000, 0.2500000>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.2411415>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.2236965>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.0833333>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.0000000>,
      <0.2500000, 0.0000000>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.1096369>,
      <0.2500000, 0.0000000>,
      <0.2500000, 0.0921919>,
      <0.2500000, 0.0833333>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.0000000>,
      <0.2500000, 0.0000000>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.0921919>,
      <0.2500000, 0.0000000>,
      <0.2500000, 0.0895343>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.2500000>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.1666667>,
      <0.2500000, 0.2437990>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.2411415>,
      <0.5000000, 0.0833333>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.0000000>,
      <0.5000000, 0.0000000>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.0921919>,
      <0.5000000, 0.0000000>,
      <0.5000000, 0.1096369>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.2500000>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.2236965>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.2411415>,
      <0.5000000, 0.2500000>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.2411415>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.2437990>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.0833333>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.0000000>,
      <0.5000000, 0.0000000>,
      <0.5000000, 0.1666667>,
      <0.5000000, 0.0895343>,
      <0.5000000, 0.0000000>,
      <0.5000000, 0.0921919>,
      <0.2500000, 0.9183221>,
      <0.2500000, 0.8333333>,
      <0.2500000, 1.0000000>,
      <0.2500000, 1.0000000>,
      <0.2500000, 0.8399549>,
      <0.2500000, 0.9080566>,
      <0.2500000, 1.0000000>,
      <0.2500000, 0.9000036>,
      <0.2500000, 0.8366166>,
      <0.2500000, 0.7516554>,
      <0.2500000, 0.8333333>,
      <0.2500000, 0.8399549>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.8366166>,
      <0.2500000, 0.7805240>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.7588243>,
      <0.2500000, 0.7500000>,
      <0.2500000, 0.8333333>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.8333333>,
      <0.2500000, 0.7588243>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.7562010>,
      <0.2500000, 0.8333333>,
      <0.2500000, 0.9166667>,
      <0.2500000, 0.8333333>,
      <0.2500000, 0.8333333>,
      <0.2500000, 1.0000000>,
      <0.2500000, 1.0000000>,
      <0.2500000, 0.8333333>,
      <0.2500000, 0.9104657>,
      <0.2500000, 1.0000000>,
      <0.2500000, 0.9080566>,
      <0.5000000, 0.7500000>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.7588585>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.7763035>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.9166667>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.8333333>,
      <0.5000000, 1.0000000>,
      <0.5000000, 1.0000000>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.8903631>,
      <0.5000000, 1.0000000>,
      <0.5000000, 0.9078081>,
      <0.5000000, 0.9166667>,
      <0.5000000, 0.8333333>,
      <0.5000000, 1.0000000>,
      <0.5000000, 1.0000000>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.9078081>,
      <0.5000000, 1.0000000>,
      <0.5000000, 0.9104657>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.7500000>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.8333333>,
      <0.5000000, 0.7562010>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.7588585>,
      <0.0625000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0691440, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0822276, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.1875000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.1677724, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1808560, 0.3333333>,
      <0.1875000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.1808560, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1828493, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0625000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0671507, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0691440, 0.3333333>,
      <0.1875000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.1813598, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1875000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0625000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0625000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0686402, 0.3333333>,
      <0.0625000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.0686402, 0.3333333>,
      <0.0000000, 0.3333333>,
      <0.0671507, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.1875000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1250000, 0.3333333>,
      <0.1828493, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.1813598, 0.3333333>,
      <0.1862585, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1200338, 0.6666667>,
      <0.1793375, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1646070, 0.6666667>,
      <0.1225341, 0.6666667>,
      <0.0612585, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.1200338, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.1225341, 0.6666667>,
      <0.0749973, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0611433, 0.6666667>,
      <0.0582107, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.1078428, 0.6666667>,
      <0.0611433, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0521944, 0.6666667>,
      <0.1164327, 0.6666667>,
      <0.1832107, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.1078428, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1164327, 0.6666667>,
      <0.1707212, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1793375, 0.6666667>,
      <0.0625000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.0686402, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0625000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.1875000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.1875000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1813598, 0.6666667>,
      <0.1875000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.1813598, 0.6666667>,
      <0.2500000, 0.6666667>,
      <0.1828493, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.0625000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.1250000, 0.6666667>,
      <0.0671507, 0.6666667>,
      <0.0000000, 0.6666667>,
      <0.0686402, 0.6666667>,
      <0.6875000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6808560, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6677724, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5625000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5822276, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5691440, 0.6666667>,
      <0.5625000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5691440, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5671507, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6875000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6828493, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6808560, 0.6666667>,
      <0.5625000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5686402, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5625000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6875000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6875000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6813598, 0.6666667>,
      <0.6875000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6813598, 0.6666667>,
      <0.7500000, 0.6666667>,
      <0.6828493, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5625000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.6250000, 0.6666667>,
      <0.5671507, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5686402, 0.6666667>,
      <0.5625000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5691440, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5822276, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.6875000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.6677724, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6808560, 0.3333333>,
      <0.6875000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.6808560, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6828493, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5625000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5671507, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5691440, 0.3333333>,
      <0.6875000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.6813598, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6875000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5625000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5625000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5686402, 0.3333333>,
      <0.5625000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.5686402, 0.3333333>,
      <0.5000000, 0.3333333>,
      <0.5671507, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.6875000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6250000, 0.3333333>,
      <0.6828493, 0.3333333>,
      <0.7500000, 0.3333333>,
      <0.6813598, 0.3333333>
    }
    texture_list {
      1,
      texture { T_Pierre }
    }
    face_indices {
      2344,   // 0 triangles and 1172 quads
      <8, 7, 0>, 0,
      <8, 0, 4>, 0,
      <8, 4, 1>, 0,
      <8, 1, 5>, 0,
      <8, 5, 2>, 0,
      <8, 2, 6>, 0,
      <8, 6, 3>, 0,
      <8, 3, 7>, 0,
      <14, 13, 0>, 0,
      <14, 0, 7>, 0,
      <14, 7, 3>, 0,
      <14, 3, 11>, 0,
      <14, 11, 9>, 0,
      <14, 9, 12>, 0,
      <14, 12, 10>, 0,
      <14, 10, 13>, 0,
      <20, 19, 0>, 0,
      <20, 0, 13>, 0,
      <20, 13, 10>, 0,
      <20, 10, 17>, 0,
      <20, 17, 15>, 0,
      <20, 15, 18>, 0,
      <20, 18, 16>, 0,
      <20, 16, 19>, 0,
      <24, 4, 0>, 0,
      <24, 0, 19>, 0,
      <24, 19, 16>, 0,
      <24, 16, 22>, 0,
      <24, 22, 21>, 0,
      <24, 21, 23>, 0,
      <24, 23, 1>, 0,
      <24, 1, 4>, 0,
      <33, 32, 25>, 0,
      <33, 25, 29>, 0,
      <33, 29, 26>, 0,
      <33, 26, 30>, 0,
      <33, 30, 27>, 0,
      <33, 27, 31>, 0,
      <33, 31, 28>, 0,
      <33, 28, 32>, 0,
      <39, 38, 25>, 0,
      <39, 25, 32>, 0,
      <39, 32, 28>, 0,
      <39, 28, 36>, 0,
      <39, 36, 34>, 0,
      <39, 34, 37>, 0,
      <39, 37, 35>, 0,
      <39, 35, 38>, 0,
      <45, 44, 25>, 0,
      <45, 25, 38>, 0,
      <45, 38, 35>, 0,
      <45, 35, 42>, 0,
      <45, 42, 40>, 0,
      <45, 40, 43>, 0,
      <45, 43, 41>, 0,
      <45, 41, 44>, 0,
      <49, 29, 25>, 0,
      <49, 25, 44>, 0,
      <49, 44, 41>, 0,
      <49, 41, 47>, 0,
      <49, 47, 46>, 0,
      <49, 46, 48>, 0,
      <49, 48, 26>, 0,
      <49, 26, 29>, 0,
      <58, 57, 50>, 0,
      <58, 50, 54>, 0,
      <58, 54, 51>, 0,
      <58, 51, 55>, 0,
      <58, 55, 52>, 0,
      <58, 52, 56>, 0,
      <58, 56, 53>, 0,
      <58, 53, 57>, 0,
      <64, 63, 50>, 0,
      <64, 50, 57>, 0,
      <64, 57, 53>, 0,
      <64, 53, 61>, 0,
      <64, 61, 59>, 0,
      <64, 59, 62>, 0,
      <64, 62, 60>, 0,
      <64, 60, 63>, 0,
      <70, 69, 50>, 0,
      <70, 50, 63>, 0,
      <70, 63, 60>, 0,
      <70, 60, 67>, 0,
      <70, 67, 65>, 0,
      <70, 65, 68>, 0,
      <70, 68, 66>, 0,
      <70, 66, 69>, 0,
      <74, 54, 50>, 0,
      <74, 50, 69>, 0,
      <74, 69, 66>, 0,
      <74, 66, 72>, 0,
      <74, 72, 71>, 0,
      <74, 71, 73>, 0,
      <74, 73, 51>, 0,
      <74, 51, 54>, 0,
      <83, 82, 75>, 0,
      <83, 75, 79>, 0,
      <83, 79, 76>, 0,
      <83, 76, 80>, 0,
      <83, 80, 77>, 0,
      <83, 77, 81>, 0,
      <83, 81, 78>, 0,
      <83, 78, 82>, 0,
      <89, 88, 75>, 0,
      <89, 75, 82>, 0,
      <89, 82, 78>, 0,
      <89, 78, 86>, 0,
      <89, 86, 84>, 0,
      <89, 84, 87>, 0,
      <89, 87, 85>, 0,
      <89, 85, 88>, 0,
      <95, 94, 75>, 0,
      <95, 75, 88>, 0,
      <95, 88, 85>, 0,
      <95, 85, 92>, 0,
      <95, 92, 90>, 0,
      <95, 90, 93>, 0,
      <95, 93, 91>, 0,
      <95, 91, 94>, 0,
      <99, 79, 75>, 0,
      <99, 75, 94>, 0,
      <99, 94, 91>, 0,
      <99, 91, 97>, 0,
      <99, 97, 96>, 0,
      <99, 96, 98>, 0,
      <99, 98, 76>, 0,
      <99, 76, 79>, 0,
      <105, 104, 100>, 0,
      <105, 100, 102>, 0,
      <105, 102, 101>, 0,
      <105, 101, 103>, 0,
      <105, 103, 9>, 0,
      <105, 9, 11>, 0,
      <105, 11, 3>, 0,
      <105, 3, 104>, 0,
      <109, 108, 100>, 0,
      <109, 100, 104>, 0,
      <109, 104, 3>, 0,
      <109, 3, 6>, 0,
      <109, 6, 2>, 0,
      <109, 2, 107>, 0,
      <109, 107, 106>, 0,
      <109, 106, 108>, 0,
      <112, 111, 100>, 0,
      <112, 100, 108>, 0,
      <112, 108, 106>, 0,
      <112, 106, 110>, 0,
      <112, 110, 65>, 0,
      <112, 65, 67>, 0,
      <112, 67, 60>, 0,
      <112, 60, 111>, 0,
      <114, 102, 100>, 0,
      <114, 100, 111>, 0,
      <114, 111, 60>, 0,
      <114, 60, 62>, 0,
      <114, 62, 59>, 0,
      <114, 59, 113>, 0,
      <114, 113, 101>, 0,
      <114, 101, 102>, 0,
      <120, 119, 115>, 0,
      <120, 115, 117>, 0,
      <120, 117, 116>, 0,
      <120, 116, 118>, 0,
      <120, 118, 34>, 0,
      <120, 34, 36>, 0,
      <120, 36, 28>, 0,
      <120, 28, 119>, 0,
      <124, 123, 115>, 0,
      <124, 115, 119>, 0,
      <124, 119, 28>, 0,
      <124, 28, 31>, 0,
      <124, 31, 27>, 0,
      <124, 27, 122>, 0,
      <124, 122, 121>, 0,
      <124, 121, 123>, 0,
      <127, 126, 115>, 0,
      <127, 115, 123>, 0,
      <127, 123, 121>, 0,
      <127, 121, 125>, 0,
      <127, 125, 52>, 0,
      <127, 52, 55>, 0,
      <127, 55, 51>, 0,
      <127, 51, 126>, 0,
      <129, 117, 115>, 0,
      <129, 115, 126>, 0,
      <129, 126, 51>, 0,
      <129, 51, 73>, 0,
      <129, 73, 71>, 0,
      <129, 71, 128>, 0,
      <129, 128, 116>, 0,
      <129, 116, 117>, 0,
      <135, 134, 130>, 0,
      <135, 130, 132>, 0,
      <135, 132, 131>, 0,
      <135, 131, 133>, 0,
      <135, 133, 21>, 0,
      <135, 21, 22>, 0,
      <135, 22, 16>, 0,
      <135, 16, 134>, 0,
      <139, 138, 130>, 0,
      <139, 130, 134>, 0,
      <139, 134, 16>, 0,
      <139, 16, 18>, 0,
      <139, 18, 15>, 0,
      <139, 15, 137>, 0,
      <139, 137, 136>, 0,
      <139, 136, 138>, 0,
      <142, 141, 130>, 0,
      <142, 130, 138>, 0,
      <142, 138, 136>, 0,
      <142, 136, 140>, 0,
      <142, 140, 90>, 0,
      <142, 90, 92>, 0,
      <142, 92, 85>, 0,
      <142, 85, 141>, 0,
      <144, 132, 130>, 0,
      <144, 130, 141>, 0,
      <144, 141, 85>, 0,
      <144, 85, 87>, 0,
      <144, 87, 84>, 0,
      <144, 84, 143>, 0,
      <144, 143, 131>, 0,
      <144, 131, 132>, 0,
      <150, 149, 145>, 0,
      <150, 145, 147>, 0,
      <150, 147, 146>, 0,
      <150, 146, 148>, 0,
      <150, 148, 46>, 0,
      <150, 46, 47>, 0,
      <150, 47, 41>, 0,
      <150, 41, 149>, 0,
      <154, 153, 145>, 0,
      <154, 145, 149>, 0,
      <154, 149, 41>, 0,
      <154, 41, 43>, 0,
      <154, 43, 40>, 0,
      <154, 40, 152>, 0,
      <154, 152, 151>, 0,
      <154, 151, 153>, 0,
      <157, 156, 145>, 0,
      <157, 145, 153>, 0,
      <157, 153, 151>, 0,
      <157, 151, 155>, 0,
      <157, 155, 77>, 0,
      <157, 77, 80>, 0,
      <157, 80, 76>, 0,
      <157, 76, 156>, 0,
      <159, 147, 145>, 0,
      <159, 145, 156>, 0,
      <159, 156, 76>, 0,
      <159, 76, 98>, 0,
      <159, 98, 96>, 0,
      <159, 96, 158>, 0,
      <159, 158, 146>, 0,
      <159, 146, 147>, 0,
      <167, 166, 160>, 0,
      <167, 160, 163>, 0,
      <167, 163, 161>, 0,
      <167, 161, 164>, 0,
      <167, 164, 9>, 0,
      <167, 9, 165>, 0,
      <167, 165, 162>, 0,
      <167, 162, 166>, 0,
      <172, 171, 160>, 0,
      <172, 160, 166>, 0,
      <172, 166, 162>, 0,
      <172, 162, 169>, 0,
      <172, 169, 27>, 0,
      <172, 27, 170>, 0,
      <172, 170, 168>, 0,
      <172, 168, 171>, 0,
      <178, 177, 160>, 0,
      <178, 160, 171>, 0,
      <178, 171, 168>, 0,
      <178, 168, 175>, 0,
      <178, 175, 173>, 0,
      <178, 173, 176>, 0,
      <178, 176, 174>, 0,
      <178, 174, 177>, 0,
      <182, 163, 160>, 0,
      <182, 160, 177>, 0,
      <182, 177, 174>, 0,
      <182, 174, 180>, 0,
      <182, 180, 179>, 0,
      <182, 179, 181>, 0,
      <182, 181, 161>, 0,
      <182, 161, 163>, 0,
      <190, 189, 183>, 0,
      <190, 183, 186>, 0,
      <190, 186, 184>, 0,
      <190, 184, 187>, 0,
      <190, 187, 46>, 0,
      <190, 46, 188>, 0,
      <190, 188, 185>, 0,
      <190, 185, 189>, 0,
      <195, 194, 183>, 0,
      <195, 183, 189>, 0,
      <195, 189, 185>, 0,
      <195, 185, 192>, 0,
      <195, 192, 15>, 0,
      <195, 15, 193>, 0,
      <195, 193, 191>, 0,
      <195, 191, 194>, 0,
      <201, 200, 183>, 0,
      <201, 183, 194>, 0,
      <201, 194, 191>, 0,
      <201, 191, 198>, 0,
      <201, 198, 196>, 0,
      <201, 196, 199>, 0,
      <201, 199, 197>, 0,
      <201, 197, 200>, 0,
      <205, 186, 183>, 0,
      <205, 183, 200>, 0,
      <205, 200, 197>, 0,
      <205, 197, 203>, 0,
      <205, 203, 202>, 0,
      <205, 202, 204>, 0,
      <205, 204, 184>, 0,
      <205, 184, 186>, 0,
      <213, 212, 206>, 0,
      <213, 206, 209>, 0,
      <213, 209, 207>, 0,
      <213, 207, 210>, 0,
      <213, 210, 34>, 0,
      <213, 34, 211>, 0,
      <213, 211, 208>, 0,
      <213, 208, 212>, 0,
      <218, 217, 206>, 0,
      <218, 206, 212>, 0,
      <218, 212, 208>, 0,
      <218, 208, 215>, 0,
      <218, 215, 2>, 0,
      <218, 2, 216>, 0,
      <218, 216, 214>, 0,
      <218, 214, 217>, 0,
      <224, 223, 206>, 0,
      <224, 206, 217>, 0,
      <224, 217, 214>, 0,
      <224, 214, 221>, 0,
      <224, 221, 219>, 0,
      <224, 219, 222>, 0,
      <224, 222, 220>, 0,
      <224, 220, 223>, 0,
      <228, 209, 206>, 0,
      <228, 206, 223>, 0,
      <228, 223, 220>, 0,
      <228, 220, 226>, 0,
      <228, 226, 225>, 0,
      <228, 225, 227>, 0,
      <228, 227, 207>, 0,
      <228, 207, 209>, 0,
      <236, 235, 229>, 0,
      <236, 229, 232>, 0,
      <236, 232, 230>, 0,
      <236, 230, 233>, 0,
      <236, 233, 21>, 0,
      <236, 21, 234>, 0,
      <236, 234, 231>, 0,
      <236, 231, 235>, 0,
      <241, 240, 229>, 0,
      <241, 229, 235>, 0,
      <241, 235, 231>, 0,
      <241, 231, 238>, 0,
      <241, 238, 40>, 0,
      <241, 40, 239>, 0,
      <241, 239, 237>, 0,
      <241, 237, 240>, 0,
      <247, 246, 229>, 0,
      <247, 229, 240>, 0,
      <247, 240, 237>, 0,
      <247, 237, 244>, 0,
      <247, 244, 242>, 0,
      <247, 242, 245>, 0,
      <247, 245, 243>, 0,
      <247, 243, 246>, 0,
      <251, 232, 229>, 0,
      <251, 229, 246>, 0,
      <251, 246, 243>, 0,
      <251, 243, 249>, 0,
      <251, 249, 248>, 0,
      <251, 248, 250>, 0,
      <251, 250, 230>, 0,
      <251, 230, 232>, 0,
      <257, 256, 252>, 0,
      <257, 252, 254>, 0,
      <257, 254, 253>, 0,
      <257, 253, 255>, 0,
      <257, 255, 27>, 0,
      <257, 27, 169>, 0,
      <257, 169, 162>, 0,
      <257, 162, 256>, 0,
      <261, 260, 252>, 0,
      <261, 252, 256>, 0,
      <261, 256, 162>, 0,
      <261, 162, 165>, 0,
      <261, 165, 9>, 0,
      <261, 9, 259>, 0,
      <261, 259, 258>, 0,
      <261, 258, 260>, 0,
      <267, 266, 252>, 0,
      <267, 252, 260>, 0,
      <267, 260, 258>, 0,
      <267, 258, 264>, 0,
      <267, 264, 262>, 0,
      <267, 262, 265>, 0,
      <267, 265, 263>, 0,
      <267, 263, 266>, 0,
      <271, 254, 252>, 0,
      <271, 252, 266>, 0,
      <271, 266, 263>, 0,
      <271, 263, 269>, 0,
      <271, 269, 268>, 0,
      <271, 268, 270>, 0,
      <271, 270, 253>, 0,
      <271, 253, 254>, 0,
      <277, 276, 272>, 0,
      <277, 272, 274>, 0,
      <277, 274, 273>, 0,
      <277, 273, 275>, 0,
      <277, 275, 59>, 0,
      <277, 59, 61>, 0,
      <277, 61, 53>, 0,
      <277, 53, 276>, 0,
      <281, 280, 272>, 0,
      <281, 272, 276>, 0,
      <281, 276, 53>, 0,
      <281, 53, 56>, 0,
      <281, 56, 52>, 0,
      <281, 52, 279>, 0,
      <281, 279, 278>, 0,
      <281, 278, 280>, 0,
      <287, 286, 272>, 0,
      <287, 272, 280>, 0,
      <287, 280, 278>, 0,
      <287, 278, 284>, 0,
      <287, 284, 282>, 0,
      <287, 282, 285>, 0,
      <287, 285, 283>, 0,
      <287, 283, 286>, 0,
      <291, 274, 272>, 0,
      <291, 272, 286>, 0,
      <291, 286, 283>, 0,
      <291, 283, 289>, 0,
      <291, 289, 288>, 0,
      <291, 288, 290>, 0,
      <291, 290, 273>, 0,
      <291, 273, 274>, 0,
      <297, 296, 292>, 0,
      <297, 292, 294>, 0,
      <297, 294, 293>, 0,
      <297, 293, 295>, 0,
      <297, 295, 2>, 0,
      <297, 2, 215>, 0,
      <297, 215, 208>, 0,
      <297, 208, 296>, 0,
      <301, 300, 292>, 0,
      <301, 292, 296>, 0,
      <301, 296, 208>, 0,
      <301, 208, 211>, 0,
      <301, 211, 34>, 0,
      <301, 34, 299>, 0,
      <301, 299, 298>, 0,
      <301, 298, 300>, 0,
      <307, 306, 292>, 0,
      <307, 292, 300>, 0,
      <307, 300, 298>, 0,
      <307, 298, 304>, 0,
      <307, 304, 302>, 0,
      <307, 302, 305>, 0,
      <307, 305, 303>, 0,
      <307, 303, 306>, 0,
      <311, 294, 292>, 0,
      <311, 292, 306>, 0,
      <311, 306, 303>, 0,
      <311, 303, 309>, 0,
      <311, 309, 308>, 0,
      <311, 308, 310>, 0,
      <311, 310, 293>, 0,
      <311, 293, 294>, 0,
      <317, 316, 312>, 0,
      <317, 312, 314>, 0,
      <317, 314, 313>, 0,
      <317, 313, 315>, 0,
      <317, 315, 71>, 0,
      <317, 71, 72>, 0,
      <317, 72, 66>, 0,
      <317, 66, 316>, 0,
      <321, 320, 312>, 0,
      <321, 312, 316>, 0,
      <321, 316, 66>, 0,
      <321, 66, 68>, 0,
      <321, 68, 65>, 0,
      <321, 65, 319>, 0,
      <321, 319, 318>, 0,
      <321, 318, 320>, 0,
      <327, 326, 312>, 0,
      <327, 312, 320>, 0,
      <327, 320, 318>, 0,
      <327, 318, 324>, 0,
      <327, 324, 322>, 0,
      <327, 322, 325>, 0,
      <327, 325, 323>, 0,
      <327, 323, 326>, 0,
      <331, 314, 312>, 0,
      <331, 312, 326>, 0,
      <331, 326, 323>, 0,
      <331, 323, 329>, 0,
      <331, 329, 328>, 0,
      <331, 328, 330>, 0,
      <331, 330, 313>, 0,
      <331, 313, 314>, 0,
      <337, 336, 332>, 0,
      <337, 332, 334>, 0,
      <337, 334, 333>, 0,
      <337, 333, 335>, 0,
      <337, 335, 40>, 0,
      <337, 40, 238>, 0,
      <337, 238, 231>, 0,
      <337, 231, 336>, 0,
      <341, 340, 332>, 0,
      <341, 332, 336>, 0,
      <341, 336, 231>, 0,
      <341, 231, 234>, 0,
      <341, 234, 21>, 0,
      <341, 21, 339>, 0,
      <341, 339, 338>, 0,
      <341, 338, 340>, 0,
      <347, 346, 332>, 0,
      <347, 332, 340>, 0,
      <347, 340, 338>, 0,
      <347, 338, 344>, 0,
      <347, 344, 342>, 0,
      <347, 342, 345>, 0,
      <347, 345, 343>, 0,
      <347, 343, 346>, 0,
      <351, 334, 332>, 0,
      <351, 332, 346>, 0,
      <351, 346, 343>, 0,
      <351, 343, 349>, 0,
      <351, 349, 348>, 0,
      <351, 348, 350>, 0,
      <351, 350, 333>, 0,
      <351, 333, 334>, 0,
      <357, 356, 352>, 0,
      <357, 352, 354>, 0,
      <357, 354, 353>, 0,
      <357, 353, 355>, 0,
      <357, 355, 84>, 0,
      <357, 84, 86>, 0,
      <357, 86, 78>, 0,
      <357, 78, 356>, 0,
      <361, 360, 352>, 0,
      <361, 352, 356>, 0,
      <361, 356, 78>, 0,
      <361, 78, 81>, 0,
      <361, 81, 77>, 0,
      <361, 77, 359>, 0,
      <361, 359, 358>, 0,
      <361, 358, 360>, 0,
      <367, 366, 352>, 0,
      <367, 352, 360>, 0,
      <367, 360, 358>, 0,
      <367, 358, 364>, 0,
      <367, 364, 362>, 0,
      <367, 362, 365>, 0,
      <367, 365, 363>, 0,
      <367, 363, 366>, 0,
      <371, 354, 352>, 0,
      <371, 352, 366>, 0,
      <371, 366, 363>, 0,
      <371, 363, 369>, 0,
      <371, 369, 368>, 0,
      <371, 368, 370>, 0,
      <371, 370, 353>, 0,
      <371, 353, 354>, 0,
      <377, 376, 372>, 0,
      <377, 372, 374>, 0,
      <377, 374, 373>, 0,
      <377, 373, 375>, 0,
      <377, 375, 15>, 0,
      <377, 15, 192>, 0,
      <377, 192, 185>, 0,
      <377, 185, 376>, 0,
      <381, 380, 372>, 0,
      <381, 372, 376>, 0,
      <381, 376, 185>, 0,
      <381, 185, 188>, 0,
      <381, 188, 46>, 0,
      <381, 46, 379>, 0,
      <381, 379, 378>, 0,
      <381, 378, 380>, 0,
      <387, 386, 372>, 0,
      <387, 372, 380>, 0,
      <387, 380, 378>, 0,
      <387, 378, 384>, 0,
      <387, 384, 382>, 0,
      <387, 382, 385>, 0,
      <387, 385, 383>, 0,
      <387, 383, 386>, 0,
      <391, 374, 372>, 0,
      <391, 372, 386>, 0,
      <391, 386, 383>, 0,
      <391, 383, 389>, 0,
      <391, 389, 388>, 0,
      <391, 388, 390>, 0,
      <391, 390, 373>, 0,
      <391, 373, 374>, 0,
      <397, 396, 392>, 0,
      <397, 392, 394>, 0,
      <397, 394, 393>, 0,
      <397, 393, 395>, 0,
      <397, 395, 96>, 0,
      <397, 96, 97>, 0,
      <397, 97, 91>, 0,
      <397, 91, 396>, 0,
      <401, 400, 392>, 0,
      <401, 392, 396>, 0,
      <401, 396, 91>, 0,
      <401, 91, 93>, 0,
      <401, 93, 90>, 0,
      <401, 90, 399>, 0,
      <401, 399, 398>, 0,
      <401, 398, 400>, 0,
      <407, 406, 392>, 0,
      <407, 392, 400>, 0,
      <407, 400, 398>, 0,
      <407, 398, 404>, 0,
      <407, 404, 402>, 0,
      <407, 402, 405>, 0,
      <407, 405, 403>, 0,
      <407, 403, 406>, 0,
      <411, 394, 392>, 0,
      <411, 392, 406>, 0,
      <411, 406, 403>, 0,
      <411, 403, 409>, 0,
      <411, 409, 408>, 0,
      <411, 408, 410>, 0,
      <411, 410, 393>, 0,
      <411, 393, 394>, 0,
      <417, 416, 412>, 0,
      <417, 412, 414>, 0,
      <417, 414, 413>, 0,
      <417, 413, 415>, 0,
      <417, 415, 288>, 0,
      <417, 288, 289>, 0,
      <417, 289, 283>, 0,
      <417, 283, 416>, 0,
      <421, 420, 412>, 0,
      <421, 412, 416>, 0,
      <421, 416, 283>, 0,
      <421, 283, 285>, 0,
      <421, 285, 282>, 0,
      <421, 282, 419>, 0,
      <421, 419, 418>, 0,
      <421, 418, 420>, 0,
      <424, 423, 412>, 0,
      <424, 412, 420>, 0,
      <424, 420, 418>, 0,
      <424, 418, 422>, 0,
      <424, 422, 328>, 0,
      <424, 328, 329>, 0,
      <424, 329, 323>, 0,
      <424, 323, 423>, 0,
      <426, 414, 412>, 0,
      <426, 412, 423>, 0,
      <426, 423, 323>, 0,
      <426, 323, 325>, 0,
      <426, 325, 322>, 0,
      <426, 322, 425>, 0,
      <426, 425, 413>, 0,
      <426, 413, 414>, 0,
      <432, 431, 427>, 0,
      <432, 427, 429>, 0,
      <432, 429, 428>, 0,
      <432, 428, 430>, 0,
      <432, 430, 268>, 0,
      <432, 268, 269>, 0,
      <432, 269, 263>, 0,
      <432, 263, 431>, 0,
      <436, 435, 427>, 0,
      <436, 427, 431>, 0,
      <436, 431, 263>, 0,
      <436, 263, 265>, 0,
      <436, 265, 262>, 0,
      <436, 262, 434>, 0,
      <436, 434, 433>, 0,
      <436, 433, 435>, 0,
      <439, 438, 427>, 0,
      <439, 427, 435>, 0,
      <439, 435, 433>, 0,
      <439, 433, 437>, 0,
      <439, 437, 308>, 0,
      <439, 308, 309>, 0,
      <439, 309, 303>, 0,
      <439, 303, 438>, 0,
      <441, 429, 427>, 0,
      <441, 427, 438>, 0,
      <441, 438, 303>, 0,
      <441, 303, 305>, 0,
      <441, 305, 302>, 0,
      <441, 302, 440>, 0,
      <441, 440, 428>, 0,
      <441, 428, 429>, 0,
      <450, 449, 442>, 0,
      <450, 442, 446>, 0,
      <450, 446, 443>, 0,
      <450, 443, 447>, 0,
      <450, 447, 444>, 0,
      <450, 444, 448>, 0,
      <450, 448, 445>, 0,
      <450, 445, 449>, 0,
      <456, 455, 442>, 0,
      <456, 442, 449>, 0,
      <456, 449, 445>, 0,
      <456, 445, 453>, 0,
      <456, 453, 451>, 0,
      <456, 451, 454>, 0,
      <456, 454, 452>, 0,
      <456, 452, 455>, 0,
      <462, 461, 442>, 0,
      <462, 442, 455>, 0,
      <462, 455, 452>, 0,
      <462, 452, 459>, 0,
      <462, 459, 457>, 0,
      <462, 457, 460>, 0,
      <462, 460, 458>, 0,
      <462, 458, 461>, 0,
      <466, 446, 442>, 0,
      <466, 442, 461>, 0,
      <466, 461, 458>, 0,
      <466, 458, 464>, 0,
      <466, 464, 463>, 0,
      <466, 463, 465>, 0,
      <466, 465, 443>, 0,
      <466, 443, 446>, 0,
      <475, 474, 467>, 0,
      <475, 467, 471>, 0,
      <475, 471, 468>, 0,
      <475, 468, 472>, 0,
      <475, 472, 469>, 0,
      <475, 469, 473>, 0,
      <475, 473, 470>, 0,
      <475, 470, 474>, 0,
      <481, 480, 467>, 0,
      <481, 467, 474>, 0,
      <481, 474, 470>, 0,
      <481, 470, 478>, 0,
      <481, 478, 476>, 0,
      <481, 476, 479>, 0,
      <481, 479, 477>, 0,
      <481, 477, 480>, 0,
      <487, 486, 467>, 0,
      <487, 467, 480>, 0,
      <487, 480, 477>, 0,
      <487, 477, 484>, 0,
      <487, 484, 482>, 0,
      <487, 482, 485>, 0,
      <487, 485, 483>, 0,
      <487, 483, 486>, 0,
      <491, 471, 467>, 0,
      <491, 467, 486>, 0,
      <491, 486, 483>, 0,
      <491, 483, 489>, 0,
      <491, 489, 488>, 0,
      <491, 488, 490>, 0,
      <491, 490, 468>, 0,
      <491, 468, 471>, 0,
      <500, 499, 492>, 0,
      <500, 492, 496>, 0,
      <500, 496, 493>, 0,
      <500, 493, 497>, 0,
      <500, 497, 494>, 0,
      <500, 494, 498>, 0,
      <500, 498, 495>, 0,
      <500, 495, 499>, 0,
      <506, 505, 492>, 0,
      <506, 492, 499>, 0,
      <506, 499, 495>, 0,
      <506, 495, 503>, 0,
      <506, 503, 501>, 0,
      <506, 501, 504>, 0,
      <506, 504, 502>, 0,
      <506, 502, 505>, 0,
      <512, 511, 492>, 0,
      <512, 492, 505>, 0,
      <512, 505, 502>, 0,
      <512, 502, 509>, 0,
      <512, 509, 507>, 0,
      <512, 507, 510>, 0,
      <512, 510, 508>, 0,
      <512, 508, 511>, 0,
      <516, 496, 492>, 0,
      <516, 492, 511>, 0,
      <516, 511, 508>, 0,
      <516, 508, 514>, 0,
      <516, 514, 513>, 0,
      <516, 513, 515>, 0,
      <516, 515, 493>, 0,
      <516, 493, 496>, 0,
      <522, 521, 517>, 0,
      <522, 517, 519>, 0,
      <522, 519, 518>, 0,
      <522, 518, 520>, 0,
      <522, 520, 202>, 0,
      <522, 202, 203>, 0,
      <522, 203, 197>, 0,
      <522, 197, 521>, 0,
      <526, 525, 517>, 0,
      <526, 517, 521>, 0,
      <526, 521, 197>, 0,
      <526, 197, 199>, 0,
      <526, 199, 196>, 0,
      <526, 196, 524>, 0,
      <526, 524, 523>, 0,
      <526, 523, 525>, 0,
      <529, 528, 517>, 0,
      <529, 517, 525>, 0,
      <529, 525, 523>, 0,
      <529, 523, 527>, 0,
      <529, 527, 248>, 0,
      <529, 248, 249>, 0,
      <529, 249, 243>, 0,
      <529, 243, 528>, 0,
      <531, 519, 517>, 0,
      <531, 517, 528>, 0,
      <531, 528, 243>, 0,
      <531, 243, 245>, 0,
      <531, 245, 242>, 0,
      <531, 242, 530>, 0,
      <531, 530, 518>, 0,
      <531, 518, 519>, 0,
      <540, 539, 532>, 0,
      <540, 532, 536>, 0,
      <540, 536, 533>, 0,
      <540, 533, 537>, 0,
      <540, 537, 534>, 0,
      <540, 534, 538>, 0,
      <540, 538, 535>, 0,
      <540, 535, 539>, 0,
      <546, 545, 532>, 0,
      <546, 532, 539>, 0,
      <546, 539, 535>, 0,
      <546, 535, 543>, 0,
      <546, 543, 541>, 0,
      <546, 541, 544>, 0,
      <546, 544, 542>, 0,
      <546, 542, 545>, 0,
      <552, 551, 532>, 0,
      <552, 532, 545>, 0,
      <552, 545, 542>, 0,
      <552, 542, 549>, 0,
      <552, 549, 547>, 0,
      <552, 547, 550>, 0,
      <552, 550, 548>, 0,
      <552, 548, 551>, 0,
      <556, 536, 532>, 0,
      <556, 532, 551>, 0,
      <556, 551, 548>, 0,
      <556, 548, 554>, 0,
      <556, 554, 553>, 0,
      <556, 553, 555>, 0,
      <556, 555, 533>, 0,
      <556, 533, 536>, 0,
      <562, 561, 557>, 0,
      <562, 557, 559>, 0,
      <562, 559, 558>, 0,
      <562, 558, 560>, 0,
      <562, 560, 179>, 0,
      <562, 179, 180>, 0,
      <562, 180, 174>, 0,
      <562, 174, 561>, 0,
      <566, 565, 557>, 0,
      <566, 557, 561>, 0,
      <566, 561, 174>, 0,
      <566, 174, 176>, 0,
      <566, 176, 173>, 0,
      <566, 173, 564>, 0,
      <566, 564, 563>, 0,
      <566, 563, 565>, 0,
      <569, 568, 557>, 0,
      <569, 557, 565>, 0,
      <569, 565, 563>, 0,
      <569, 563, 567>, 0,
      <569, 567, 225>, 0,
      <569, 225, 226>, 0,
      <569, 226, 220>, 0,
      <569, 220, 568>, 0,
      <571, 559, 557>, 0,
      <571, 557, 568>, 0,
      <571, 568, 220>, 0,
      <571, 220, 222>, 0,
      <571, 222, 219>, 0,
      <571, 219, 570>, 0,
      <571, 570, 558>, 0,
      <571, 558, 559>, 0,
      <577, 576, 572>, 0,
      <577, 572, 574>, 0,
      <577, 574, 573>, 0,
      <577, 573, 575>, 0,
      <577, 575, 348>, 0,
      <577, 348, 349>, 0,
      <577, 349, 343>, 0,
      <577, 343, 576>, 0,
      <581, 580, 572>, 0,
      <581, 572, 576>, 0,
      <581, 576, 343>, 0,
      <581, 343, 345>, 0,
      <581, 345, 342>, 0,
      <581, 342, 579>, 0,
      <581, 579, 578>, 0,
      <581, 578, 580>, 0,
      <584, 583, 572>, 0,
      <584, 572, 580>, 0,
      <584, 580, 578>, 0,
      <584, 578, 582>, 0,
      <584, 582, 388>, 0,
      <584, 388, 389>, 0,
      <584, 389, 383>, 0,
      <584, 383, 583>, 0,
      <586, 574, 572>, 0,
      <586, 572, 583>, 0,
      <586, 583, 383>, 0,
      <586, 383, 385>, 0,
      <586, 385, 382>, 0,
      <586, 382, 585>, 0,
      <586, 585, 573>, 0,
      <586, 573, 574>, 0,
      <595, 594, 587>, 0,
      <595, 587, 591>, 0,
      <595, 591, 588>, 0,
      <595, 588, 592>, 0,
      <595, 592, 589>, 0,
      <595, 589, 593>, 0,
      <595, 593, 590>, 0,
      <595, 590, 594>, 0,
      <601, 600, 587>, 0,
      <601, 587, 594>, 0,
      <601, 594, 590>, 0,
      <601, 590, 598>, 0,
      <601, 598, 596>, 0,
      <601, 596, 599>, 0,
      <601, 599, 597>, 0,
      <601, 597, 600>, 0,
      <607, 606, 587>, 0,
      <607, 587, 600>, 0,
      <607, 600, 597>, 0,
      <607, 597, 604>, 0,
      <607, 604, 602>, 0,
      <607, 602, 605>, 0,
      <607, 605, 603>, 0,
      <607, 603, 606>, 0,
      <611, 591, 587>, 0,
      <611, 587, 606>, 0,
      <611, 606, 603>, 0,
      <611, 603, 609>, 0,
      <611, 609, 608>, 0,
      <611, 608, 610>, 0,
      <611, 610, 588>, 0,
      <611, 588, 591>, 0,
      <617, 616, 612>, 0,
      <617, 612, 614>, 0,
      <617, 614, 613>, 0,
      <617, 613, 615>, 0,
      <617, 615, 368>, 0,
      <617, 368, 369>, 0,
      <617, 369, 363>, 0,
      <617, 363, 616>, 0,
      <621, 620, 612>, 0,
      <621, 612, 616>, 0,
      <621, 616, 363>, 0,
      <621, 363, 365>, 0,
      <621, 365, 362>, 0,
      <621, 362, 619>, 0,
      <621, 619, 618>, 0,
      <621, 618, 620>, 0,
      <624, 623, 612>, 0,
      <624, 612, 620>, 0,
      <624, 620, 618>, 0,
      <624, 618, 622>, 0,
      <624, 622, 408>, 0,
      <624, 408, 409>, 0,
      <624, 409, 403>, 0,
      <624, 403, 623>, 0,
      <626, 614, 612>, 0,
      <626, 612, 623>, 0,
      <626, 623, 403>, 0,
      <626, 403, 405>, 0,
      <626, 405, 402>, 0,
      <626, 402, 625>, 0,
      <626, 625, 613>, 0,
      <626, 613, 614>, 0,
      <635, 634, 627>, 0,
      <635, 627, 631>, 0,
      <635, 631, 628>, 0,
      <635, 628, 632>, 0,
      <635, 632, 629>, 0,
      <635, 629, 633>, 0,
      <635, 633, 630>, 0,
      <635, 630, 634>, 0,
      <641, 640, 627>, 0,
      <641, 627, 634>, 0,
      <641, 634, 630>, 0,
      <641, 630, 638>, 0,
      <641, 638, 636>, 0,
      <641, 636, 639>, 0,
      <641, 639, 637>, 0,
      <641, 637, 640>, 0,
      <647, 646, 627>, 0,
      <647, 627, 640>, 0,
      <647, 640, 637>, 0,
      <647, 637, 644>, 0,
      <647, 644, 642>, 0,
      <647, 642, 645>, 0,
      <647, 645, 643>, 0,
      <647, 643, 646>, 0,
      <651, 631, 627>, 0,
      <651, 627, 646>, 0,
      <651, 646, 643>, 0,
      <651, 643, 649>, 0,
      <651, 649, 648>, 0,
      <651, 648, 650>, 0,
      <651, 650, 628>, 0,
      <651, 628, 631>, 0,
      <657, 656, 652>, 0,
      <657, 652, 654>, 0,
      <657, 654, 653>, 0,
      <657, 653, 655>, 0,
      <657, 655, 288>, 0,
      <657, 288, 415>, 0,
      <657, 415, 413>, 0,
      <657, 413, 656>, 0,
      <661, 660, 652>, 0,
      <661, 652, 656>, 0,
      <661, 656, 413>, 0,
      <661, 413, 425>, 0,
      <661, 425, 322>, 0,
      <661, 322, 659>, 0,
      <661, 659, 658>, 0,
      <661, 658, 660>, 0,
      <664, 663, 652>, 0,
      <664, 652, 660>, 0,
      <664, 660, 658>, 0,
      <664, 658, 662>, 0,
      <664, 662, 457>, 0,
      <664, 457, 459>, 0,
      <664, 459, 452>, 0,
      <664, 452, 663>, 0,
      <666, 654, 652>, 0,
      <666, 652, 663>, 0,
      <666, 663, 452>, 0,
      <666, 452, 454>, 0,
      <666, 454, 451>, 0,
      <666, 451, 665>, 0,
      <666, 665, 653>, 0,
      <666, 653, 654>, 0,
      <672, 671, 667>, 0,
      <672, 667, 669>, 0,
      <672, 669, 668>, 0,
      <672, 668, 670>, 0,
      <672, 670, 308>, 0,
      <672, 308, 437>, 0,
      <672, 437, 433>, 0,
      <672, 433, 671>, 0,
      <676, 675, 667>, 0,
      <676, 667, 671>, 0,
      <676, 671, 433>, 0,
      <676, 433, 434>, 0,
      <676, 434, 262>, 0,
      <676, 262, 674>, 0,
      <676, 674, 673>, 0,
      <676, 673, 675>, 0,
      <679, 678, 667>, 0,
      <679, 667, 675>, 0,
      <679, 675, 673>, 0,
      <679, 673, 677>, 0,
      <679, 677, 444>, 0,
      <679, 444, 447>, 0,
      <679, 447, 443>, 0,
      <679, 443, 678>, 0,
      <681, 669, 667>, 0,
      <681, 667, 678>, 0,
      <681, 678, 443>, 0,
      <681, 443, 465>, 0,
      <681, 465, 463>, 0,
      <681, 463, 680>, 0,
      <681, 680, 668>, 0,
      <681, 668, 669>, 0,
      <687, 686, 682>, 0,
      <687, 682, 684>, 0,
      <687, 684, 683>, 0,
      <687, 683, 685>, 0,
      <687, 685, 268>, 0,
      <687, 268, 430>, 0,
      <687, 430, 428>, 0,
      <687, 428, 686>, 0,
      <691, 690, 682>, 0,
      <691, 682, 686>, 0,
      <691, 686, 428>, 0,
      <691, 428, 440>, 0,
      <691, 440, 302>, 0,
      <691, 302, 689>, 0,
      <691, 689, 688>, 0,
      <691, 688, 690>, 0,
      <694, 693, 682>, 0,
      <694, 682, 690>, 0,
      <694, 690, 688>, 0,
      <694, 688, 692>, 0,
      <694, 692, 476>, 0,
      <694, 476, 478>, 0,
      <694, 478, 470>, 0,
      <694, 470, 693>, 0,
      <696, 684, 682>, 0,
      <696, 682, 693>, 0,
      <696, 693, 470>, 0,
      <696, 470, 473>, 0,
      <696, 473, 469>, 0,
      <696, 469, 695>, 0,
      <696, 695, 683>, 0,
      <696, 683, 684>, 0,
      <702, 701, 697>, 0,
      <702, 697, 699>, 0,
      <702, 699, 698>, 0,
      <702, 698, 700>, 0,
      <702, 700, 328>, 0,
      <702, 328, 422>, 0,
      <702, 422, 418>, 0,
      <702, 418, 701>, 0,
      <706, 705, 697>, 0,
      <706, 697, 701>, 0,
      <706, 701, 418>, 0,
      <706, 418, 419>, 0,
      <706, 419, 282>, 0,
      <706, 282, 704>, 0,
      <706, 704, 703>, 0,
      <706, 703, 705>, 0,
      <709, 708, 697>, 0,
      <709, 697, 705>, 0,
      <709, 705, 703>, 0,
      <709, 703, 707>, 0,
      <709, 707, 488>, 0,
      <709, 488, 489>, 0,
      <709, 489, 483>, 0,
      <709, 483, 708>, 0,
      <711, 699, 697>, 0,
      <711, 697, 708>, 0,
      <711, 708, 483>, 0,
      <711, 483, 485>, 0,
      <711, 485, 482>, 0,
      <711, 482, 710>, 0,
      <711, 710, 698>, 0,
      <711, 698, 699>, 0,
      <717, 716, 712>, 0,
      <717, 712, 714>, 0,
      <717, 714, 713>, 0,
      <717, 713, 715>, 0,
      <717, 715, 179>, 0,
      <717, 179, 560>, 0,
      <717, 560, 558>, 0,
      <717, 558, 716>, 0,
      <721, 720, 712>, 0,
      <721, 712, 716>, 0,
      <721, 716, 558>, 0,
      <721, 558, 570>, 0,
      <721, 570, 219>, 0,
      <721, 219, 719>, 0,
      <721, 719, 718>, 0,
      <721, 718, 720>, 0,
      <724, 723, 712>, 0,
      <724, 712, 720>, 0,
      <724, 720, 718>, 0,
      <724, 718, 722>, 0,
      <724, 722, 501>, 0,
      <724, 501, 503>, 0,
      <724, 503, 495>, 0,
      <724, 495, 723>, 0,
      <726, 714, 712>, 0,
      <726, 712, 723>, 0,
      <726, 723, 495>, 0,
      <726, 495, 498>, 0,
      <726, 498, 494>, 0,
      <726, 494, 725>, 0,
      <726, 725, 713>, 0,
      <726, 713, 714>, 0,
      <732, 731, 727>, 0,
      <732, 727, 729>, 0,
      <732, 729, 728>, 0,
      <732, 728, 730>, 0,
      <732, 730, 248>, 0,
      <732, 248, 527>, 0,
      <732, 527, 523>, 0,
      <732, 523, 731>, 0,
      <736, 735, 727>, 0,
      <736, 727, 731>, 0,
      <736, 731, 523>, 0,
      <736, 523, 524>, 0,
      <736, 524, 196>, 0,
      <736, 196, 734>, 0,
      <736, 734, 733>, 0,
      <736, 733, 735>, 0,
      <739, 738, 727>, 0,
      <739, 727, 735>, 0,
      <739, 735, 733>, 0,
      <739, 733, 737>, 0,
      <739, 737, 513>, 0,
      <739, 513, 514>, 0,
      <739, 514, 508>, 0,
      <739, 508, 738>, 0,
      <741, 729, 727>, 0,
      <741, 727, 738>, 0,
      <741, 738, 508>, 0,
      <741, 508, 510>, 0,
      <741, 510, 507>, 0,
      <741, 507, 740>, 0,
      <741, 740, 728>, 0,
      <741, 728, 729>, 0,
      <747, 746, 742>, 0,
      <747, 742, 744>, 0,
      <747, 744, 743>, 0,
      <747, 743, 745>, 0,
      <747, 745, 202>, 0,
      <747, 202, 520>, 0,
      <747, 520, 518>, 0,
      <747, 518, 746>, 0,
      <751, 750, 742>, 0,
      <751, 742, 746>, 0,
      <751, 746, 518>, 0,
      <751, 518, 530>, 0,
      <751, 530, 242>, 0,
      <751, 242, 749>, 0,
      <751, 749, 748>, 0,
      <751, 748, 750>, 0,
      <754, 753, 742>, 0,
      <754, 742, 750>, 0,
      <754, 750, 748>, 0,
      <754, 748, 752>, 0,
      <754, 752, 547>, 0,
      <754, 547, 549>, 0,
      <754, 549, 542>, 0,
      <754, 542, 753>, 0,
      <756, 744, 742>, 0,
      <756, 742, 753>, 0,
      <756, 753, 542>, 0,
      <756, 542, 544>, 0,
      <756, 544, 541>, 0,
      <756, 541, 755>, 0,
      <756, 755, 743>, 0,
      <756, 743, 744>, 0,
      <762, 761, 757>, 0,
      <762, 757, 759>, 0,
      <762, 759, 758>, 0,
      <762, 758, 760>, 0,
      <762, 760, 225>, 0,
      <762, 225, 567>, 0,
      <762, 567, 563>, 0,
      <762, 563, 761>, 0,
      <766, 765, 757>, 0,
      <766, 757, 761>, 0,
      <766, 761, 563>, 0,
      <766, 563, 564>, 0,
      <766, 564, 173>, 0,
      <766, 173, 764>, 0,
      <766, 764, 763>, 0,
      <766, 763, 765>, 0,
      <769, 768, 757>, 0,
      <769, 757, 765>, 0,
      <769, 765, 763>, 0,
      <769, 763, 767>, 0,
      <769, 767, 534>, 0,
      <769, 534, 537>, 0,
      <769, 537, 533>, 0,
      <769, 533, 768>, 0,
      <771, 759, 757>, 0,
      <771, 757, 768>, 0,
      <771, 768, 533>, 0,
      <771, 533, 555>, 0,
      <771, 555, 553>, 0,
      <771, 553, 770>, 0,
      <771, 770, 758>, 0,
      <771, 758, 759>, 0,
      <777, 776, 772>, 0,
      <777, 772, 774>, 0,
      <777, 774, 773>, 0,
      <777, 773, 775>, 0,
      <777, 775, 368>, 0,
      <777, 368, 615>, 0,
      <777, 615, 613>, 0,
      <777, 613, 776>, 0,
      <781, 780, 772>, 0,
      <781, 772, 776>, 0,
      <781, 776, 613>, 0,
      <781, 613, 625>, 0,
      <781, 625, 402>, 0,
      <781, 402, 779>, 0,
      <781, 779, 778>, 0,
      <781, 778, 780>, 0,
      <784, 783, 772>, 0,
      <784, 772, 780>, 0,
      <784, 780, 778>, 0,
      <784, 778, 782>, 0,
      <784, 782, 602>, 0,
      <784, 602, 604>, 0,
      <784, 604, 597>, 0,
      <784, 597, 783>, 0,
      <786, 774, 772>, 0,
      <786, 772, 783>, 0,
      <786, 783, 597>, 0,
      <786, 597, 599>, 0,
      <786, 599, 596>, 0,
      <786, 596, 785>, 0,
      <786, 785, 773>, 0,
      <786, 773, 774>, 0,
      <792, 791, 787>, 0,
      <792, 787, 789>, 0,
      <792, 789, 788>, 0,
      <792, 788, 790>, 0,
      <792, 790, 388>, 0,
      <792, 388, 582>, 0,
      <792, 582, 578>, 0,
      <792, 578, 791>, 0,
      <796, 795, 787>, 0,
      <796, 787, 791>, 0,
      <796, 791, 578>, 0,
      <796, 578, 579>, 0,
      <796, 579, 342>, 0,
      <796, 342, 794>, 0,
      <796, 794, 793>, 0,
      <796, 793, 795>, 0,
      <799, 798, 787>, 0,
      <799, 787, 795>, 0,
      <799, 795, 793>, 0,
      <799, 793, 797>, 0,
      <799, 797, 589>, 0,
      <799, 589, 592>, 0,
      <799, 592, 588>, 0,
      <799, 588, 798>, 0,
      <801, 789, 787>, 0,
      <801, 787, 798>, 0,
      <801, 798, 588>, 0,
      <801, 588, 610>, 0,
      <801, 610, 608>, 0,
      <801, 608, 800>, 0,
      <801, 800, 788>, 0,
      <801, 788, 789>, 0,
      <807, 806, 802>, 0,
      <807, 802, 804>, 0,
      <807, 804, 803>, 0,
      <807, 803, 805>, 0,
      <807, 805, 348>, 0,
      <807, 348, 575>, 0,
      <807, 575, 573>, 0,
      <807, 573, 806>, 0,
      <811, 810, 802>, 0,
      <811, 802, 806>, 0,
      <811, 806, 573>, 0,
      <811, 573, 585>, 0,
      <811, 585, 382>, 0,
      <811, 382, 809>, 0,
      <811, 809, 808>, 0,
      <811, 808, 810>, 0,
      <814, 813, 802>, 0,
      <814, 802, 810>, 0,
      <814, 810, 808>, 0,
      <814, 808, 812>, 0,
      <814, 812, 636>, 0,
      <814, 636, 638>, 0,
      <814, 638, 630>, 0,
      <814, 630, 813>, 0,
      <816, 804, 802>, 0,
      <816, 802, 813>, 0,
      <816, 813, 630>, 0,
      <816, 630, 633>, 0,
      <816, 633, 629>, 0,
      <816, 629, 815>, 0,
      <816, 815, 803>, 0,
      <816, 803, 804>, 0,
      <822, 821, 817>, 0,
      <822, 817, 819>, 0,
      <822, 819, 818>, 0,
      <822, 818, 820>, 0,
      <822, 820, 408>, 0,
      <822, 408, 622>, 0,
      <822, 622, 618>, 0,
      <822, 618, 821>, 0,
      <826, 825, 817>, 0,
      <826, 817, 821>, 0,
      <826, 821, 618>, 0,
      <826, 618, 619>, 0,
      <826, 619, 362>, 0,
      <826, 362, 824>, 0,
      <826, 824, 823>, 0,
      <826, 823, 825>, 0,
      <829, 828, 817>, 0,
      <829, 817, 825>, 0,
      <829, 825, 823>, 0,
      <829, 823, 827>, 0,
      <829, 827, 648>, 0,
      <829, 648, 649>, 0,
      <829, 649, 643>, 0,
      <829, 643, 828>, 0,
      <831, 819, 817>, 0,
      <831, 817, 828>, 0,
      <831, 828, 643>, 0,
      <831, 643, 645>, 0,
      <831, 645, 642>, 0,
      <831, 642, 830>, 0,
      <831, 830, 818>, 0,
      <831, 818, 819>, 0,
      <837, 836, 832>, 0,
      <837, 832, 834>, 0,
      <837, 834, 278>, 0,
      <837, 278, 279>, 0,
      <837, 279, 52>, 0,
      <837, 52, 835>, 0,
      <837, 835, 833>, 0,
      <837, 833, 836>, 0,
      <840, 839, 832>, 0,
      <840, 832, 836>, 0,
      <840, 836, 833>, 0,
      <840, 833, 838>, 0,
      <840, 838, 488>, 0,
      <840, 488, 707>, 0,
      <840, 707, 703>, 0,
      <840, 703, 839>, 0,
      <841, 834, 832>, 0,
      <841, 832, 839>, 0,
      <841, 839, 703>, 0,
      <841, 703, 704>, 0,
      <841, 704, 282>, 0,
      <841, 282, 284>, 0,
      <841, 284, 278>, 0,
      <841, 278, 834>, 0,
      <847, 846, 842>, 0,
      <847, 842, 844>, 0,
      <847, 844, 843>, 0,
      <847, 843, 845>, 0,
      <847, 845, 71>, 0,
      <847, 71, 315>, 0,
      <847, 315, 313>, 0,
      <847, 313, 846>, 0,
      <849, 848, 842>, 0,
      <849, 842, 846>, 0,
      <849, 846, 313>, 0,
      <849, 313, 330>, 0,
      <849, 330, 328>, 0,
      <849, 328, 700>, 0,
      <849, 700, 698>, 0,
      <849, 698, 848>, 0,
      <851, 844, 842>, 0,
      <851, 842, 848>, 0,
      <851, 848, 698>, 0,
      <851, 698, 710>, 0,
      <851, 710, 482>, 0,
      <851, 482, 850>, 0,
      <851, 850, 843>, 0,
      <851, 843, 844>, 0,
      <857, 856, 852>, 0,
      <857, 852, 854>, 0,
      <857, 854, 121>, 0,
      <857, 121, 122>, 0,
      <857, 122, 27>, 0,
      <857, 27, 855>, 0,
      <857, 855, 853>, 0,
      <857, 853, 856>, 0,
      <860, 859, 852>, 0,
      <860, 852, 856>, 0,
      <860, 856, 853>, 0,
      <860, 853, 858>, 0,
      <860, 858, 469>, 0,
      <860, 469, 472>, 0,
      <860, 472, 468>, 0,
      <860, 468, 859>, 0,
      <862, 861, 852>, 0,
      <862, 852, 859>, 0,
      <862, 859, 468>, 0,
      <862, 468, 490>, 0,
      <862, 490, 488>, 0,
      <862, 488, 838>, 0,
      <862, 838, 833>, 0,
      <862, 833, 861>, 0,
      <863, 854, 852>, 0,
      <863, 852, 861>, 0,
      <863, 861, 833>, 0,
      <863, 833, 835>, 0,
      <863, 835, 52>, 0,
      <863, 52, 125>, 0,
      <863, 125, 121>, 0,
      <863, 121, 854>, 0,
      <869, 868, 864>, 0,
      <869, 864, 866>, 0,
      <869, 866, 865>, 0,
      <869, 865, 867>, 0,
      <869, 867, 34>, 0,
      <869, 34, 118>, 0,
      <869, 118, 116>, 0,
      <869, 116, 868>, 0,
      <871, 870, 864>, 0,
      <871, 864, 868>, 0,
      <871, 868, 116>, 0,
      <871, 116, 128>, 0,
      <871, 128, 71>, 0,
      <871, 71, 845>, 0,
      <871, 845, 843>, 0,
      <871, 843, 870>, 0,
      <873, 872, 864>, 0,
      <873, 864, 870>, 0,
      <873, 870, 843>, 0,
      <873, 843, 850>, 0,
      <873, 850, 482>, 0,
      <873, 482, 484>, 0,
      <873, 484, 477>, 0,
      <873, 477, 872>, 0,
      <875, 866, 864>, 0,
      <875, 864, 872>, 0,
      <875, 872, 477>, 0,
      <875, 477, 479>, 0,
      <875, 479, 476>, 0,
      <875, 476, 874>, 0,
      <875, 874, 865>, 0,
      <875, 865, 866>, 0,
      <879, 878, 876>, 0,
      <879, 876, 877>, 0,
      <879, 877, 853>, 0,
      <879, 853, 855>, 0,
      <879, 855, 27>, 0,
      <879, 27, 255>, 0,
      <879, 255, 253>, 0,
      <879, 253, 878>, 0,
      <881, 880, 876>, 0,
      <881, 876, 878>, 0,
      <881, 878, 253>, 0,
      <881, 253, 270>, 0,
      <881, 270, 268>, 0,
      <881, 268, 685>, 0,
      <881, 685, 683>, 0,
      <881, 683, 880>, 0,
      <882, 877, 876>, 0,
      <882, 876, 880>, 0,
      <882, 880, 683>, 0,
      <882, 683, 695>, 0,
      <882, 695, 469>, 0,
      <882, 469, 858>, 0,
      <882, 858, 853>, 0,
      <882, 853, 877>, 0,
      <888, 887, 883>, 0,
      <888, 883, 885>, 0,
      <888, 885, 168>, 0,
      <888, 168, 170>, 0,
      <888, 170, 27>, 0,
      <888, 27, 886>, 0,
      <888, 886, 884>, 0,
      <888, 884, 887>, 0,
      <891, 890, 883>, 0,
      <891, 883, 887>, 0,
      <891, 887, 884>, 0,
      <891, 884, 889>, 0,
      <891, 889, 534>, 0,
      <891, 534, 767>, 0,
      <891, 767, 763>, 0,
      <891, 763, 890>, 0,
      <892, 885, 883>, 0,
      <892, 883, 890>, 0,
      <892, 890, 763>, 0,
      <892, 763, 764>, 0,
      <892, 764, 173>, 0,
      <892, 173, 175>, 0,
      <892, 175, 168>, 0,
      <892, 168, 885>, 0,
      <898, 897, 893>, 0,
      <898, 893, 895>, 0,
      <898, 895, 894>, 0,
      <898, 894, 896>, 0,
      <898, 896, 34>, 0,
      <898, 34, 210>, 0,
      <898, 210, 207>, 0,
      <898, 207, 897>, 0,
      <900, 899, 893>, 0,
      <900, 893, 897>, 0,
      <900, 897, 207>, 0,
      <900, 207, 227>, 0,
      <900, 227, 225>, 0,
      <900, 225, 760>, 0,
      <900, 760, 758>, 0,
      <900, 758, 899>, 0,
      <902, 895, 893>, 0,
      <902, 893, 899>, 0,
      <902, 899, 758>, 0,
      <902, 758, 770>, 0,
      <902, 770, 553>, 0,
      <902, 553, 901>, 0,
      <902, 901, 894>, 0,
      <902, 894, 895>, 0,
      <906, 905, 903>, 0,
      <906, 903, 904>, 0,
      <906, 904, 884>, 0,
      <906, 884, 886>, 0,
      <906, 886, 27>, 0,
      <906, 27, 30>, 0,
      <906, 30, 26>, 0,
      <906, 26, 905>, 0,
      <910, 909, 903>, 0,
      <910, 903, 905>, 0,
      <910, 905, 26>, 0,
      <910, 26, 48>, 0,
      <910, 48, 46>, 0,
      <910, 46, 908>, 0,
      <910, 908, 907>, 0,
      <910, 907, 909>, 0,
      <913, 912, 903>, 0,
      <913, 903, 909>, 0,
      <913, 909, 907>, 0,
      <913, 907, 911>, 0,
      <913, 911, 541>, 0,
      <913, 541, 543>, 0,
      <913, 543, 535>, 0,
      <913, 535, 912>, 0,
      <914, 904, 903>, 0,
      <914, 903, 912>, 0,
      <914, 912, 535>, 0,
      <914, 535, 538>, 0,
      <914, 538, 534>, 0,
      <914, 534, 889>, 0,
      <914, 889, 884>, 0,
      <914, 884, 904>, 0,
      <918, 917, 915>, 0,
      <918, 915, 916>, 0,
      <918, 916, 35>, 0,
      <918, 35, 37>, 0,
      <918, 37, 34>, 0,
      <918, 34, 896>, 0,
      <918, 896, 894>, 0,
      <918, 894, 917>, 0,
      <920, 919, 915>, 0,
      <920, 915, 917>, 0,
      <920, 917, 894>, 0,
      <920, 894, 901>, 0,
      <920, 901, 553>, 0,
      <920, 553, 554>, 0,
      <920, 554, 548>, 0,
      <920, 548, 919>, 0,
      <924, 923, 915>, 0,
      <924, 915, 919>, 0,
      <924, 919, 548>, 0,
      <924, 548, 550>, 0,
      <924, 550, 547>, 0,
      <924, 547, 922>, 0,
      <924, 922, 921>, 0,
      <924, 921, 923>, 0,
      <926, 916, 915>, 0,
      <926, 915, 923>, 0,
      <926, 923, 921>, 0,
      <926, 921, 925>, 0,
      <926, 925, 40>, 0,
      <926, 40, 42>, 0,
      <926, 42, 35>, 0,
      <926, 35, 916>, 0,
      <930, 929, 927>, 0,
      <930, 927, 928>, 0,
      <930, 928, 907>, 0,
      <930, 907, 908>, 0,
      <930, 908, 46>, 0,
      <930, 46, 187>, 0,
      <930, 187, 184>, 0,
      <930, 184, 929>, 0,
      <932, 931, 927>, 0,
      <932, 927, 929>, 0,
      <932, 929, 184>, 0,
      <932, 184, 204>, 0,
      <932, 204, 202>, 0,
      <932, 202, 745>, 0,
      <932, 745, 743>, 0,
      <932, 743, 931>, 0,
      <933, 928, 927>, 0,
      <933, 927, 931>, 0,
      <933, 931, 743>, 0,
      <933, 743, 755>, 0,
      <933, 755, 541>, 0,
      <933, 541, 911>, 0,
      <933, 911, 907>, 0,
      <933, 907, 928>, 0,
      <937, 936, 934>, 0,
      <937, 934, 935>, 0,
      <937, 935, 237>, 0,
      <937, 237, 239>, 0,
      <937, 239, 40>, 0,
      <937, 40, 925>, 0,
      <937, 925, 921>, 0,
      <937, 921, 936>, 0,
      <939, 938, 934>, 0,
      <939, 934, 936>, 0,
      <939, 936, 921>, 0,
      <939, 921, 922>, 0,
      <939, 922, 547>, 0,
      <939, 547, 752>, 0,
      <939, 752, 748>, 0,
      <939, 748, 938>, 0,
      <940, 935, 934>, 0,
      <940, 934, 938>, 0,
      <940, 938, 748>, 0,
      <940, 748, 749>, 0,
      <940, 749, 242>, 0,
      <940, 242, 244>, 0,
      <940, 244, 237>, 0,
      <940, 237, 935>, 0,
      <946, 945, 941>, 0,
      <946, 941, 943>, 0,
      <946, 943, 378>, 0,
      <946, 378, 379>, 0,
      <946, 379, 46>, 0,
      <946, 46, 944>, 0,
      <946, 944, 942>, 0,
      <946, 942, 945>, 0,
      <949, 948, 941>, 0,
      <949, 941, 945>, 0,
      <949, 945, 942>, 0,
      <949, 942, 947>, 0,
      <949, 947, 636>, 0,
      <949, 636, 812>, 0,
      <949, 812, 808>, 0,
      <949, 808, 948>, 0,
      <950, 943, 941>, 0,
      <950, 941, 948>, 0,
      <950, 948, 808>, 0,
      <950, 808, 809>, 0,
      <950, 809, 382>, 0,
      <950, 382, 384>, 0,
      <950, 384, 378>, 0,
      <950, 378, 943>, 0,
      <956, 955, 951>, 0,
      <956, 951, 953>, 0,
      <956, 953, 952>, 0,
      <956, 952, 954>, 0,
      <956, 954, 40>, 0,
      <956, 40, 335>, 0,
      <956, 335, 333>, 0,
      <956, 333, 955>, 0,
      <958, 957, 951>, 0,
      <958, 951, 955>, 0,
      <958, 955, 333>, 0,
      <958, 333, 350>, 0,
      <958, 350, 348>, 0,
      <958, 348, 805>, 0,
      <958, 805, 803>, 0,
      <958, 803, 957>, 0,
      <960, 953, 951>, 0,
      <960, 951, 957>, 0,
      <960, 957, 803>, 0,
      <960, 803, 815>, 0,
      <960, 815, 629>, 0,
      <960, 629, 959>, 0,
      <960, 959, 952>, 0,
      <960, 952, 953>, 0,
      <964, 963, 961>, 0,
      <964, 961, 962>, 0,
      <964, 962, 942>, 0,
      <964, 942, 944>, 0,
      <964, 944, 46>, 0,
      <964, 46, 148>, 0,
      <964, 148, 146>, 0,
      <964, 146, 963>, 0,
      <968, 967, 961>, 0,
      <968, 961, 963>, 0,
      <968, 963, 146>, 0,
      <968, 146, 158>, 0,
      <968, 158, 96>, 0,
      <968, 96, 966>, 0,
      <968, 966, 965>, 0,
      <968, 965, 967>, 0,
      <971, 970, 961>, 0,
      <971, 961, 967>, 0,
      <971, 967, 965>, 0,
      <971, 965, 969>, 0,
      <971, 969, 642>, 0,
      <971, 642, 644>, 0,
      <971, 644, 637>, 0,
      <971, 637, 970>, 0,
      <972, 962, 961>, 0,
      <972, 961, 970>, 0,
      <972, 970, 637>, 0,
      <972, 637, 639>, 0,
      <972, 639, 636>, 0,
      <972, 636, 947>, 0,
      <972, 947, 942>, 0,
      <972, 942, 962>, 0,
      <976, 975, 973>, 0,
      <976, 973, 974>, 0,
      <976, 974, 151>, 0,
      <976, 151, 152>, 0,
      <976, 152, 40>, 0,
      <976, 40, 954>, 0,
      <976, 954, 952>, 0,
      <976, 952, 975>, 0,
      <978, 977, 973>, 0,
      <978, 973, 975>, 0,
      <978, 975, 952>, 0,
      <978, 952, 959>, 0,
      <978, 959, 629>, 0,
      <978, 629, 632>, 0,
      <978, 632, 628>, 0,
      <978, 628, 977>, 0,
      <982, 981, 973>, 0,
      <982, 973, 977>, 0,
      <982, 977, 628>, 0,
      <982, 628, 650>, 0,
      <982, 650, 648>, 0,
      <982, 648, 980>, 0,
      <982, 980, 979>, 0,
      <982, 979, 981>, 0,
      <984, 974, 973>, 0,
      <984, 973, 981>, 0,
      <984, 981, 979>, 0,
      <984, 979, 983>, 0,
      <984, 983, 77>, 0,
      <984, 77, 155>, 0,
      <984, 155, 151>, 0,
      <984, 151, 974>, 0,
      <988, 987, 985>, 0,
      <988, 985, 986>, 0,
      <988, 986, 965>, 0,
      <988, 965, 966>, 0,
      <988, 966, 96>, 0,
      <988, 96, 395>, 0,
      <988, 395, 393>, 0,
      <988, 393, 987>, 0,
      <990, 989, 985>, 0,
      <990, 985, 987>, 0,
      <990, 987, 393>, 0,
      <990, 393, 410>, 0,
      <990, 410, 408>, 0,
      <990, 408, 820>, 0,
      <990, 820, 818>, 0,
      <990, 818, 989>, 0,
      <991, 986, 985>, 0,
      <991, 985, 989>, 0,
      <991, 989, 818>, 0,
      <991, 818, 830>, 0,
      <991, 830, 642>, 0,
      <991, 642, 969>, 0,
      <991, 969, 965>, 0,
      <991, 965, 986>, 0,
      <995, 994, 992>, 0,
      <995, 992, 993>, 0,
      <995, 993, 358>, 0,
      <995, 358, 359>, 0,
      <995, 359, 77>, 0,
      <995, 77, 983>, 0,
      <995, 983, 979>, 0,
      <995, 979, 994>, 0,
      <997, 996, 992>, 0,
      <997, 992, 994>, 0,
      <997, 994, 979>, 0,
      <997, 979, 980>, 0,
      <997, 980, 648>, 0,
      <997, 648, 827>, 0,
      <997, 827, 823>, 0,
      <997, 823, 996>, 0,
      <998, 993, 992>, 0,
      <998, 992, 996>, 0,
      <998, 996, 823>, 0,
      <998, 823, 824>, 0,
      <998, 824, 362>, 0,
      <998, 362, 364>, 0,
      <998, 364, 358>, 0,
      <998, 358, 993>, 0,
      <1004, 1003, 999>, 0,
      <1004, 999, 1001>, 0,
      <1004, 1001, 1000>, 0,
      <1004, 1000, 1002>, 0,
      <1004, 1002, 59>, 0,
      <1004, 59, 275>, 0,
      <1004, 275, 273>, 0,
      <1004, 273, 1003>, 0,
      <1006, 1005, 999>, 0,
      <1006, 999, 1003>, 0,
      <1006, 1003, 273>, 0,
      <1006, 273, 290>, 0,
      <1006, 290, 288>, 0,
      <1006, 288, 655>, 0,
      <1006, 655, 653>, 0,
      <1006, 653, 1005>, 0,
      <1008, 1001, 999>, 0,
      <1008, 999, 1005>, 0,
      <1008, 1005, 653>, 0,
      <1008, 653, 665>, 0,
      <1008, 665, 451>, 0,
      <1008, 451, 1007>, 0,
      <1008, 1007, 1000>, 0,
      <1008, 1000, 1001>, 0,
      <1014, 1013, 1009>, 0,
      <1014, 1009, 1011>, 0,
      <1014, 1011, 318>, 0,
      <1014, 318, 319>, 0,
      <1014, 319, 65>, 0,
      <1014, 65, 1012>, 0,
      <1014, 1012, 1010>, 0,
      <1014, 1010, 1013>, 0,
      <1017, 1016, 1009>, 0,
      <1017, 1009, 1013>, 0,
      <1017, 1013, 1010>, 0,
      <1017, 1010, 1015>, 0,
      <1017, 1015, 457>, 0,
      <1017, 457, 662>, 0,
      <1017, 662, 658>, 0,
      <1017, 658, 1016>, 0,
      <1018, 1011, 1009>, 0,
      <1018, 1009, 1016>, 0,
      <1018, 1016, 658>, 0,
      <1018, 658, 659>, 0,
      <1018, 659, 322>, 0,
      <1018, 322, 324>, 0,
      <1018, 324, 318>, 0,
      <1018, 318, 1011>, 0,
      <1024, 1023, 1019>, 0,
      <1024, 1019, 1021>, 0,
      <1024, 1021, 1020>, 0,
      <1024, 1020, 1022>, 0,
      <1024, 1022, 9>, 0,
      <1024, 9, 103>, 0,
      <1024, 103, 101>, 0,
      <1024, 101, 1023>, 0,
      <1026, 1025, 1019>, 0,
      <1026, 1019, 1023>, 0,
      <1026, 1023, 101>, 0,
      <1026, 101, 113>, 0,
      <1026, 113, 59>, 0,
      <1026, 59, 1002>, 0,
      <1026, 1002, 1000>, 0,
      <1026, 1000, 1025>, 0,
      <1028, 1027, 1019>, 0,
      <1028, 1019, 1025>, 0,
      <1028, 1025, 1000>, 0,
      <1028, 1000, 1007>, 0,
      <1028, 1007, 451>, 0,
      <1028, 451, 453>, 0,
      <1028, 453, 445>, 0,
      <1028, 445, 1027>, 0,
      <1030, 1021, 1019>, 0,
      <1030, 1019, 1027>, 0,
      <1030, 1027, 445>, 0,
      <1030, 445, 448>, 0,
      <1030, 448, 444>, 0,
      <1030, 444, 1029>, 0,
      <1030, 1029, 1020>, 0,
      <1030, 1020, 1021>, 0,
      <1036, 1035, 1031>, 0,
      <1036, 1031, 1033>, 0,
      <1036, 1033, 106>, 0,
      <1036, 106, 107>, 0,
      <1036, 107, 2>, 0,
      <1036, 2, 1034>, 0,
      <1036, 1034, 1032>, 0,
      <1036, 1032, 1035>, 0,
      <1039, 1038, 1031>, 0,
      <1039, 1031, 1035>, 0,
      <1039, 1035, 1032>, 0,
      <1039, 1032, 1037>, 0,
      <1039, 1037, 463>, 0,
      <1039, 463, 464>, 0,
      <1039, 464, 458>, 0,
      <1039, 458, 1038>, 0,
      <1041, 1040, 1031>, 0,
      <1041, 1031, 1038>, 0,
      <1041, 1038, 458>, 0,
      <1041, 458, 460>, 0,
      <1041, 460, 457>, 0,
      <1041, 457, 1015>, 0,
      <1041, 1015, 1010>, 0,
      <1041, 1010, 1040>, 0,
      <1042, 1033, 1031>, 0,
      <1042, 1031, 1040>, 0,
      <1042, 1040, 1010>, 0,
      <1042, 1010, 1012>, 0,
      <1042, 1012, 65>, 0,
      <1042, 65, 110>, 0,
      <1042, 110, 106>, 0,
      <1042, 106, 1033>, 0,
      <1046, 1045, 1043>, 0,
      <1046, 1043, 1044>, 0,
      <1046, 1044, 258>, 0,
      <1046, 258, 259>, 0,
      <1046, 259, 9>, 0,
      <1046, 9, 1022>, 0,
      <1046, 1022, 1020>, 0,
      <1046, 1020, 1045>, 0,
      <1048, 1047, 1043>, 0,
      <1048, 1043, 1045>, 0,
      <1048, 1045, 1020>, 0,
      <1048, 1020, 1029>, 0,
      <1048, 1029, 444>, 0,
      <1048, 444, 677>, 0,
      <1048, 677, 673>, 0,
      <1048, 673, 1047>, 0,
      <1049, 1044, 1043>, 0,
      <1049, 1043, 1047>, 0,
      <1049, 1047, 673>, 0,
      <1049, 673, 674>, 0,
      <1049, 674, 262>, 0,
      <1049, 262, 264>, 0,
      <1049, 264, 258>, 0,
      <1049, 258, 1044>, 0,
      <1053, 1052, 1050>, 0,
      <1053, 1050, 1051>, 0,
      <1053, 1051, 1032>, 0,
      <1053, 1032, 1034>, 0,
      <1053, 1034, 2>, 0,
      <1053, 2, 295>, 0,
      <1053, 295, 293>, 0,
      <1053, 293, 1052>, 0,
      <1055, 1054, 1050>, 0,
      <1055, 1050, 1052>, 0,
      <1055, 1052, 293>, 0,
      <1055, 293, 310>, 0,
      <1055, 310, 308>, 0,
      <1055, 308, 670>, 0,
      <1055, 670, 668>, 0,
      <1055, 668, 1054>, 0,
      <1056, 1051, 1050>, 0,
      <1056, 1050, 1054>, 0,
      <1056, 1054, 668>, 0,
      <1056, 668, 680>, 0,
      <1056, 680, 463>, 0,
      <1056, 463, 1037>, 0,
      <1056, 1037, 1032>, 0,
      <1056, 1032, 1051>, 0,
      <1062, 1061, 1057>, 0,
      <1062, 1057, 1059>, 0,
      <1062, 1059, 1058>, 0,
      <1062, 1058, 1060>, 0,
      <1062, 1060, 9>, 0,
      <1062, 9, 164>, 0,
      <1062, 164, 161>, 0,
      <1062, 161, 1061>, 0,
      <1064, 1063, 1057>, 0,
      <1064, 1057, 1061>, 0,
      <1064, 1061, 161>, 0,
      <1064, 161, 181>, 0,
      <1064, 181, 179>, 0,
      <1064, 179, 715>, 0,
      <1064, 715, 713>, 0,
      <1064, 713, 1063>, 0,
      <1066, 1059, 1057>, 0,
      <1066, 1057, 1063>, 0,
      <1066, 1063, 713>, 0,
      <1066, 713, 725>, 0,
      <1066, 725, 494>, 0,
      <1066, 494, 1065>, 0,
      <1066, 1065, 1058>, 0,
      <1066, 1058, 1059>, 0,
      <1072, 1071, 1067>, 0,
      <1072, 1067, 1069>, 0,
      <1072, 1069, 214>, 0,
      <1072, 214, 216>, 0,
      <1072, 216, 2>, 0,
      <1072, 2, 1070>, 0,
      <1072, 1070, 1068>, 0,
      <1072, 1068, 1071>, 0,
      <1075, 1074, 1067>, 0,
      <1075, 1067, 1071>, 0,
      <1075, 1071, 1068>, 0,
      <1075, 1068, 1073>, 0,
      <1075, 1073, 501>, 0,
      <1075, 501, 722>, 0,
      <1075, 722, 718>, 0,
      <1075, 718, 1074>, 0,
      <1076, 1069, 1067>, 0,
      <1076, 1067, 1074>, 0,
      <1076, 1074, 718>, 0,
      <1076, 718, 719>, 0,
      <1076, 719, 219>, 0,
      <1076, 219, 221>, 0,
      <1076, 221, 214>, 0,
      <1076, 214, 1069>, 0,
      <1080, 1079, 1077>, 0,
      <1080, 1077, 1078>, 0,
      <1080, 1078, 10>, 0,
      <1080, 10, 12>, 0,
      <1080, 12, 9>, 0,
      <1080, 9, 1060>, 0,
      <1080, 1060, 1058>, 0,
      <1080, 1058, 1079>, 0,
      <1082, 1081, 1077>, 0,
      <1082, 1077, 1079>, 0,
      <1082, 1079, 1058>, 0,
      <1082, 1058, 1065>, 0,
      <1082, 1065, 494>, 0,
      <1082, 494, 497>, 0,
      <1082, 497, 493>, 0,
      <1082, 493, 1081>, 0,
      <1086, 1085, 1077>, 0,
      <1086, 1077, 1081>, 0,
      <1086, 1081, 493>, 0,
      <1086, 493, 515>, 0,
      <1086, 515, 513>, 0,
      <1086, 513, 1084>, 0,
      <1086, 1084, 1083>, 0,
      <1086, 1083, 1085>, 0,
      <1088, 1078, 1077>, 0,
      <1088, 1077, 1085>, 0,
      <1088, 1085, 1083>, 0,
      <1088, 1083, 1087>, 0,
      <1088, 1087, 15>, 0,
      <1088, 15, 17>, 0,
      <1088, 17, 10>, 0,
      <1088, 10, 1078>, 0,
      <1092, 1091, 1089>, 0,
      <1092, 1089, 1090>, 0,
      <1092, 1090, 1068>, 0,
      <1092, 1068, 1070>, 0,
      <1092, 1070, 2>, 0,
      <1092, 2, 5>, 0,
      <1092, 5, 1>, 0,
      <1092, 1, 1091>, 0,
      <1096, 1095, 1089>, 0,
      <1096, 1089, 1091>, 0,
      <1096, 1091, 1>, 0,
      <1096, 1, 23>, 0,
      <1096, 23, 21>, 0,
      <1096, 21, 1094>, 0,
      <1096, 1094, 1093>, 0,
      <1096, 1093, 1095>, 0,
      <1099, 1098, 1089>, 0,
      <1099, 1089, 1095>, 0,
      <1099, 1095, 1093>, 0,
      <1099, 1093, 1097>, 0,
      <1099, 1097, 507>, 0,
      <1099, 507, 509>, 0,
      <1099, 509, 502>, 0,
      <1099, 502, 1098>, 0,
      <1100, 1090, 1089>, 0,
      <1100, 1089, 1098>, 0,
      <1100, 1098, 502>, 0,
      <1100, 502, 504>, 0,
      <1100, 504, 501>, 0,
      <1100, 501, 1073>, 0,
      <1100, 1073, 1068>, 0,
      <1100, 1068, 1090>, 0,
      <1104, 1103, 1101>, 0,
      <1104, 1101, 1102>, 0,
      <1104, 1102, 191>, 0,
      <1104, 191, 193>, 0,
      <1104, 193, 15>, 0,
      <1104, 15, 1087>, 0,
      <1104, 1087, 1083>, 0,
      <1104, 1083, 1103>, 0,
      <1106, 1105, 1101>, 0,
      <1106, 1101, 1103>, 0,
      <1106, 1103, 1083>, 0,
      <1106, 1083, 1084>, 0,
      <1106, 1084, 513>, 0,
      <1106, 513, 737>, 0,
      <1106, 737, 733>, 0,
      <1106, 733, 1105>, 0,
      <1107, 1102, 1101>, 0,
      <1107, 1101, 1105>, 0,
      <1107, 1105, 733>, 0,
      <1107, 733, 734>, 0,
      <1107, 734, 196>, 0,
      <1107, 196, 198>, 0,
      <1107, 198, 191>, 0,
      <1107, 191, 1102>, 0,
      <1111, 1110, 1108>, 0,
      <1111, 1108, 1109>, 0,
      <1111, 1109, 1093>, 0,
      <1111, 1093, 1094>, 0,
      <1111, 1094, 21>, 0,
      <1111, 21, 233>, 0,
      <1111, 233, 230>, 0,
      <1111, 230, 1110>, 0,
      <1113, 1112, 1108>, 0,
      <1113, 1108, 1110>, 0,
      <1113, 1110, 230>, 0,
      <1113, 230, 250>, 0,
      <1113, 250, 248>, 0,
      <1113, 248, 730>, 0,
      <1113, 730, 728>, 0,
      <1113, 728, 1112>, 0,
      <1114, 1109, 1108>, 0,
      <1114, 1108, 1112>, 0,
      <1114, 1112, 728>, 0,
      <1114, 728, 740>, 0,
      <1114, 740, 507>, 0,
      <1114, 507, 1097>, 0,
      <1114, 1097, 1093>, 0,
      <1114, 1093, 1109>, 0,
      <1120, 1119, 1115>, 0,
      <1120, 1115, 1117>, 0,
      <1120, 1117, 1116>, 0,
      <1120, 1116, 1118>, 0,
      <1120, 1118, 15>, 0,
      <1120, 15, 375>, 0,
      <1120, 375, 373>, 0,
      <1120, 373, 1119>, 0,
      <1122, 1121, 1115>, 0,
      <1122, 1115, 1119>, 0,
      <1122, 1119, 373>, 0,
      <1122, 373, 390>, 0,
      <1122, 390, 388>, 0,
      <1122, 388, 790>, 0,
      <1122, 790, 788>, 0,
      <1122, 788, 1121>, 0,
      <1124, 1117, 1115>, 0,
      <1124, 1115, 1121>, 0,
      <1124, 1121, 788>, 0,
      <1124, 788, 800>, 0,
      <1124, 800, 608>, 0,
      <1124, 608, 1123>, 0,
      <1124, 1123, 1116>, 0,
      <1124, 1116, 1117>, 0,
      <1130, 1129, 1125>, 0,
      <1130, 1125, 1127>, 0,
      <1130, 1127, 338>, 0,
      <1130, 338, 339>, 0,
      <1130, 339, 21>, 0,
      <1130, 21, 1128>, 0,
      <1130, 1128, 1126>, 0,
      <1130, 1126, 1129>, 0,
      <1133, 1132, 1125>, 0,
      <1133, 1125, 1129>, 0,
      <1133, 1129, 1126>, 0,
      <1133, 1126, 1131>, 0,
      <1133, 1131, 589>, 0,
      <1133, 589, 797>, 0,
      <1133, 797, 793>, 0,
      <1133, 793, 1132>, 0,
      <1134, 1127, 1125>, 0,
      <1134, 1125, 1132>, 0,
      <1134, 1132, 793>, 0,
      <1134, 793, 794>, 0,
      <1134, 794, 342>, 0,
      <1134, 342, 344>, 0,
      <1134, 344, 338>, 0,
      <1134, 338, 1127>, 0,
      <1138, 1137, 1135>, 0,
      <1138, 1135, 1136>, 0,
      <1138, 1136, 136>, 0,
      <1138, 136, 137>, 0,
      <1138, 137, 15>, 0,
      <1138, 15, 1118>, 0,
      <1138, 1118, 1116>, 0,
      <1138, 1116, 1137>, 0,
      <1140, 1139, 1135>, 0,
      <1140, 1135, 1137>, 0,
      <1140, 1137, 1116>, 0,
      <1140, 1116, 1123>, 0,
      <1140, 1123, 608>, 0,
      <1140, 608, 609>, 0,
      <1140, 609, 603>, 0,
      <1140, 603, 1139>, 0,
      <1144, 1143, 1135>, 0,
      <1144, 1135, 1139>, 0,
      <1144, 1139, 603>, 0,
      <1144, 603, 605>, 0,
      <1144, 605, 602>, 0,
      <1144, 602, 1142>, 0,
      <1144, 1142, 1141>, 0,
      <1144, 1141, 1143>, 0,
      <1146, 1136, 1135>, 0,
      <1146, 1135, 1143>, 0,
      <1146, 1143, 1141>, 0,
      <1146, 1141, 1145>, 0,
      <1146, 1145, 90>, 0,
      <1146, 90, 140>, 0,
      <1146, 140, 136>, 0,
      <1146, 136, 1136>, 0,
      <1150, 1149, 1147>, 0,
      <1150, 1147, 1148>, 0,
      <1150, 1148, 1126>, 0,
      <1150, 1126, 1128>, 0,
      <1150, 1128, 21>, 0,
      <1150, 21, 133>, 0,
      <1150, 133, 131>, 0,
      <1150, 131, 1149>, 0,
      <1154, 1153, 1147>, 0,
      <1154, 1147, 1149>, 0,
      <1154, 1149, 131>, 0,
      <1154, 131, 143>, 0,
      <1154, 143, 84>, 0,
      <1154, 84, 1152>, 0,
      <1154, 1152, 1151>, 0,
      <1154, 1151, 1153>, 0,
      <1157, 1156, 1147>, 0,
      <1157, 1147, 1153>, 0,
      <1157, 1153, 1151>, 0,
      <1157, 1151, 1155>, 0,
      <1157, 1155, 596>, 0,
      <1157, 596, 598>, 0,
      <1157, 598, 590>, 0,
      <1157, 590, 1156>, 0,
      <1158, 1148, 1147>, 0,
      <1158, 1147, 1156>, 0,
      <1158, 1156, 590>, 0,
      <1158, 590, 593>, 0,
      <1158, 593, 589>, 0,
      <1158, 589, 1131>, 0,
      <1158, 1131, 1126>, 0,
      <1158, 1126, 1148>, 0,
      <1162, 1161, 1159>, 0,
      <1162, 1159, 1160>, 0,
      <1162, 1160, 398>, 0,
      <1162, 398, 399>, 0,
      <1162, 399, 90>, 0,
      <1162, 90, 1145>, 0,
      <1162, 1145, 1141>, 0,
      <1162, 1141, 1161>, 0,
      <1164, 1163, 1159>, 0,
      <1164, 1159, 1161>, 0,
      <1164, 1161, 1141>, 0,
      <1164, 1141, 1142>, 0,
      <1164, 1142, 602>, 0,
      <1164, 602, 782>, 0,
      <1164, 782, 778>, 0,
      <1164, 778, 1163>, 0,
      <1165, 1160, 1159>, 0,
      <1165, 1159, 1163>, 0,
      <1165, 1163, 778>, 0,
      <1165, 778, 779>, 0,
      <1165, 779, 402>, 0,
      <1165, 402, 404>, 0,
      <1165, 404, 398>, 0,
      <1165, 398, 1160>, 0,
      <1169, 1168, 1166>, 0,
      <1169, 1166, 1167>, 0,
      <1169, 1167, 1151>, 0,
      <1169, 1151, 1152>, 0,
      <1169, 1152, 84>, 0,
      <1169, 84, 355>, 0,
      <1169, 355, 353>, 0,
      <1169, 353, 1168>, 0,
      <1171, 1170, 1166>, 0,
      <1171, 1166, 1168>, 0,
      <1171, 1168, 353>, 0,
      <1171, 353, 370>, 0,
      <1171, 370, 368>, 0,
      <1171, 368, 775>, 0,
      <1171, 775, 773>, 0,
      <1171, 773, 1170>, 0,
      <1172, 1167, 1166>, 0,
      <1172, 1166, 1170>, 0,
      <1172, 1170, 773>, 0,
      <1172, 773, 785>, 0,
      <1172, 785, 596>, 0,
      <1172, 596, 1155>, 0,
      <1172, 1155, 1151>, 0,
      <1172, 1151, 1167>, 0
    }
    normal_indices {
      2344,   // from 0 triangles and 1172 quads
      <0, 1, 2>,
      <0, 2, 3>,
      <0, 3, 4>,
      <0, 4, 5>,
      <0, 6, 7>,
      <0, 7, 8>,
      <0, 8, 9>,
      <0, 9, 1>,
      <10, 11, 2>,
      <10, 2, 1>,
      <10, 1, 9>,
      <10, 9, 12>,
      <10, 12, 13>,
      <10, 13, 14>,
      <10, 15, 16>,
      <10, 16, 11>,
      <17, 18, 2>,
      <17, 2, 11>,
      <17, 11, 19>,
      <17, 19, 20>,
      <17, 21, 22>,
      <17, 22, 23>,
      <17, 23, 24>,
      <17, 24, 18>,
      <25, 3, 2>,
      <25, 2, 18>,
      <25, 18, 24>,
      <25, 24, 26>,
      <25, 26, 27>,
      <25, 27, 28>,
      <25, 29, 30>,
      <25, 30, 3>,
      <31, 32, 33>,
      <31, 33, 34>,
      <31, 34, 35>,
      <31, 35, 36>,
      <31, 37, 38>,
      <31, 38, 39>,
      <31, 39, 40>,
      <31, 40, 32>,
      <41, 42, 33>,
      <41, 33, 32>,
      <41, 32, 40>,
      <41, 40, 43>,
      <41, 43, 44>,
      <41, 44, 45>,
      <41, 46, 47>,
      <41, 47, 42>,
      <48, 49, 33>,
      <48, 33, 42>,
      <48, 42, 50>,
      <48, 50, 51>,
      <48, 52, 53>,
      <48, 53, 54>,
      <48, 54, 55>,
      <48, 55, 49>,
      <56, 34, 33>,
      <56, 33, 49>,
      <56, 49, 55>,
      <56, 55, 57>,
      <56, 57, 58>,
      <56, 58, 59>,
      <56, 60, 61>,
      <56, 61, 34>,
      <62, 63, 64>,
      <62, 64, 65>,
      <62, 65, 66>,
      <62, 66, 67>,
      <62, 68, 69>,
      <62, 69, 70>,
      <62, 71, 72>,
      <62, 72, 63>,
      <73, 74, 64>,
      <73, 64, 63>,
      <73, 63, 75>,
      <73, 75, 76>,
      <73, 77, 78>,
      <73, 78, 79>,
      <73, 80, 81>,
      <73, 81, 74>,
      <82, 83, 64>,
      <82, 64, 74>,
      <82, 74, 84>,
      <82, 84, 85>,
      <82, 86, 87>,
      <82, 87, 88>,
      <82, 89, 90>,
      <82, 90, 83>,
      <91, 65, 64>,
      <91, 64, 83>,
      <91, 83, 92>,
      <91, 92, 93>,
      <91, 94, 95>,
      <91, 95, 96>,
      <91, 97, 98>,
      <91, 98, 65>,
      <99, 100, 101>,
      <99, 101, 102>,
      <99, 102, 103>,
      <99, 103, 104>,
      <99, 105, 106>,
      <99, 106, 107>,
      <99, 108, 109>,
      <99, 109, 100>,
      <110, 111, 101>,
      <110, 101, 100>,
      <110, 100, 112>,
      <110, 112, 113>,
      <110, 114, 115>,
      <110, 115, 116>,
      <110, 117, 118>,
      <110, 118, 111>,
      <119, 120, 101>,
      <119, 101, 111>,
      <119, 111, 121>,
      <119, 121, 122>,
      <119, 123, 124>,
      <119, 124, 125>,
      <119, 126, 127>,
      <119, 127, 120>,
      <128, 102, 101>,
      <128, 101, 120>,
      <128, 120, 129>,
      <128, 129, 130>,
      <128, 131, 132>,
      <128, 132, 133>,
      <128, 134, 135>,
      <128, 135, 102>,
      <136, 137, 138>,
      <136, 138, 139>,
      <136, 139, 140>,
      <136, 140, 141>,
      <136, 142, 143>,
      <136, 143, 12>,
      <136, 12, 9>,
      <136, 9, 137>,
      <144, 145, 138>,
      <144, 138, 137>,
      <144, 137, 9>,
      <144, 9, 8>,
      <144, 8, 146>,
      <144, 146, 147>,
      <144, 148, 149>,
      <144, 149, 145>,
      <150, 151, 138>,
      <150, 138, 145>,
      <150, 145, 152>,
      <150, 152, 153>,
      <150, 154, 155>,
      <150, 155, 156>,
      <150, 157, 158>,
      <150, 158, 151>,
      <159, 139, 138>,
      <159, 138, 151>,
      <159, 151, 160>,
      <159, 160, 161>,
      <159, 162, 163>,
      <159, 163, 164>,
      <159, 165, 166>,
      <159, 166, 139>,
      <167, 168, 169>,
      <167, 169, 170>,
      <167, 170, 171>,
      <167, 171, 172>,
      <167, 173, 174>,
      <167, 174, 43>,
      <167, 43, 40>,
      <167, 40, 168>,
      <175, 176, 169>,
      <175, 169, 168>,
      <175, 168, 40>,
      <175, 40, 39>,
      <175, 39, 177>,
      <175, 177, 178>,
      <175, 179, 180>,
      <175, 180, 176>,
      <181, 182, 169>,
      <181, 169, 176>,
      <181, 176, 183>,
      <181, 183, 184>,
      <181, 185, 186>,
      <181, 186, 187>,
      <181, 188, 189>,
      <181, 189, 182>,
      <190, 170, 169>,
      <190, 169, 182>,
      <190, 182, 191>,
      <190, 191, 192>,
      <190, 193, 194>,
      <190, 194, 195>,
      <190, 196, 197>,
      <190, 197, 170>,
      <198, 199, 200>,
      <198, 200, 201>,
      <198, 201, 202>,
      <198, 202, 203>,
      <198, 204, 205>,
      <198, 205, 26>,
      <198, 26, 24>,
      <198, 24, 199>,
      <206, 207, 200>,
      <206, 200, 199>,
      <206, 199, 24>,
      <206, 24, 23>,
      <206, 23, 208>,
      <206, 208, 209>,
      <206, 210, 211>,
      <206, 211, 207>,
      <212, 213, 200>,
      <212, 200, 207>,
      <212, 207, 214>,
      <212, 214, 215>,
      <212, 216, 217>,
      <212, 217, 218>,
      <212, 219, 220>,
      <212, 220, 213>,
      <221, 201, 200>,
      <221, 200, 213>,
      <221, 213, 222>,
      <221, 222, 223>,
      <221, 224, 225>,
      <221, 225, 226>,
      <221, 227, 228>,
      <221, 228, 201>,
      <229, 230, 231>,
      <229, 231, 232>,
      <229, 232, 233>,
      <229, 233, 234>,
      <229, 235, 236>,
      <229, 236, 57>,
      <229, 57, 55>,
      <229, 55, 230>,
      <237, 238, 231>,
      <237, 231, 230>,
      <237, 230, 55>,
      <237, 55, 54>,
      <237, 54, 239>,
      <237, 239, 240>,
      <237, 241, 242>,
      <237, 242, 238>,
      <243, 244, 231>,
      <243, 231, 238>,
      <243, 238, 245>,
      <243, 245, 246>,
      <243, 247, 248>,
      <243, 248, 249>,
      <243, 250, 251>,
      <243, 251, 244>,
      <252, 232, 231>,
      <252, 231, 244>,
      <252, 244, 253>,
      <252, 253, 254>,
      <252, 255, 256>,
      <252, 256, 257>,
      <252, 258, 259>,
      <252, 259, 232>,
      <260, 261, 262>,
      <260, 262, 263>,
      <260, 263, 264>,
      <260, 264, 265>,
      <260, 265, 266>,
      <260, 266, 267>,
      <260, 267, 268>,
      <260, 268, 261>,
      <269, 270, 262>,
      <269, 262, 261>,
      <269, 261, 268>,
      <269, 268, 271>,
      <269, 271, 272>,
      <269, 272, 273>,
      <269, 273, 274>,
      <269, 274, 270>,
      <275, 276, 262>,
      <275, 262, 270>,
      <275, 270, 274>,
      <275, 274, 277>,
      <275, 277, 278>,
      <275, 278, 279>,
      <275, 280, 281>,
      <275, 281, 276>,
      <282, 263, 262>,
      <282, 262, 276>,
      <282, 276, 283>,
      <282, 283, 284>,
      <282, 285, 286>,
      <282, 286, 287>,
      <282, 287, 264>,
      <282, 264, 263>,
      <288, 289, 290>,
      <288, 290, 291>,
      <288, 291, 292>,
      <288, 292, 293>,
      <288, 293, 294>,
      <288, 294, 295>,
      <288, 295, 296>,
      <288, 296, 289>,
      <297, 298, 290>,
      <297, 290, 289>,
      <297, 289, 296>,
      <297, 296, 299>,
      <297, 299, 300>,
      <297, 300, 301>,
      <297, 301, 302>,
      <297, 302, 298>,
      <303, 304, 290>,
      <303, 290, 298>,
      <303, 298, 302>,
      <303, 302, 305>,
      <303, 305, 306>,
      <303, 306, 307>,
      <303, 308, 309>,
      <303, 309, 304>,
      <310, 291, 290>,
      <310, 290, 304>,
      <310, 304, 311>,
      <310, 311, 312>,
      <310, 313, 314>,
      <310, 314, 315>,
      <310, 315, 292>,
      <310, 292, 291>,
      <316, 317, 318>,
      <316, 318, 319>,
      <316, 319, 320>,
      <316, 320, 321>,
      <316, 321, 322>,
      <316, 322, 323>,
      <316, 323, 324>,
      <316, 324, 317>,
      <325, 326, 318>,
      <325, 318, 317>,
      <325, 317, 324>,
      <325, 324, 327>,
      <325, 327, 328>,
      <325, 328, 329>,
      <325, 329, 330>,
      <325, 330, 326>,
      <331, 332, 318>,
      <331, 318, 326>,
      <331, 326, 330>,
      <331, 330, 333>,
      <331, 333, 334>,
      <331, 334, 335>,
      <331, 336, 337>,
      <331, 337, 332>,
      <338, 319, 318>,
      <338, 318, 332>,
      <338, 332, 339>,
      <338, 339, 340>,
      <338, 341, 342>,
      <338, 342, 343>,
      <338, 343, 320>,
      <338, 320, 319>,
      <344, 345, 346>,
      <344, 346, 347>,
      <344, 347, 348>,
      <344, 348, 349>,
      <344, 349, 350>,
      <344, 350, 351>,
      <344, 351, 352>,
      <344, 352, 345>,
      <353, 354, 346>,
      <353, 346, 345>,
      <353, 345, 352>,
      <353, 352, 355>,
      <353, 355, 356>,
      <353, 356, 357>,
      <353, 357, 358>,
      <353, 358, 354>,
      <359, 360, 346>,
      <359, 346, 354>,
      <359, 354, 358>,
      <359, 358, 361>,
      <359, 361, 362>,
      <359, 362, 363>,
      <359, 364, 365>,
      <359, 365, 360>,
      <366, 347, 346>,
      <366, 346, 360>,
      <366, 360, 367>,
      <366, 367, 368>,
      <366, 369, 370>,
      <366, 370, 371>,
      <366, 371, 348>,
      <366, 348, 347>,
      <372, 373, 374>,
      <372, 374, 375>,
      <372, 375, 376>,
      <372, 376, 377>,
      <372, 377, 378>,
      <372, 378, 271>,
      <372, 271, 268>,
      <372, 268, 373>,
      <379, 380, 374>,
      <379, 374, 373>,
      <379, 373, 268>,
      <379, 268, 267>,
      <379, 267, 381>,
      <379, 381, 382>,
      <379, 382, 383>,
      <379, 383, 380>,
      <384, 385, 374>,
      <384, 374, 380>,
      <384, 380, 383>,
      <384, 383, 386>,
      <384, 386, 387>,
      <384, 387, 388>,
      <384, 389, 390>,
      <384, 390, 385>,
      <391, 375, 374>,
      <391, 374, 385>,
      <391, 385, 392>,
      <391, 392, 393>,
      <391, 394, 395>,
      <391, 395, 396>,
      <391, 396, 376>,
      <391, 376, 375>,
      <397, 398, 399>,
      <397, 399, 400>,
      <397, 400, 401>,
      <397, 401, 402>,
      <397, 402, 403>,
      <397, 403, 404>,
      <397, 405, 406>,
      <397, 406, 398>,
      <407, 408, 399>,
      <407, 399, 398>,
      <407, 398, 409>,
      <407, 409, 410>,
      <407, 411, 412>,
      <407, 412, 413>,
      <407, 413, 414>,
      <407, 414, 408>,
      <415, 416, 399>,
      <415, 399, 408>,
      <415, 408, 414>,
      <415, 414, 417>,
      <415, 417, 418>,
      <415, 418, 419>,
      <415, 420, 421>,
      <415, 421, 416>,
      <422, 400, 399>,
      <422, 399, 416>,
      <422, 416, 423>,
      <422, 423, 424>,
      <422, 425, 426>,
      <422, 426, 427>,
      <422, 427, 401>,
      <422, 401, 400>,
      <428, 429, 430>,
      <428, 430, 431>,
      <428, 431, 432>,
      <428, 432, 433>,
      <428, 433, 434>,
      <428, 434, 327>,
      <428, 327, 324>,
      <428, 324, 429>,
      <435, 436, 430>,
      <435, 430, 429>,
      <435, 429, 324>,
      <435, 324, 323>,
      <435, 323, 437>,
      <435, 437, 438>,
      <435, 439, 440>,
      <435, 440, 436>,
      <441, 442, 430>,
      <441, 430, 436>,
      <441, 436, 443>,
      <441, 443, 444>,
      <441, 445, 446>,
      <441, 446, 447>,
      <441, 448, 449>,
      <441, 449, 442>,
      <450, 431, 430>,
      <450, 430, 442>,
      <450, 442, 451>,
      <450, 451, 452>,
      <450, 453, 454>,
      <450, 454, 455>,
      <450, 455, 432>,
      <450, 432, 431>,
      <456, 457, 458>,
      <456, 458, 459>,
      <456, 459, 460>,
      <456, 460, 461>,
      <456, 461, 462>,
      <456, 462, 463>,
      <456, 464, 465>,
      <456, 465, 457>,
      <466, 467, 458>,
      <466, 458, 457>,
      <466, 457, 468>,
      <466, 468, 469>,
      <466, 470, 471>,
      <466, 471, 472>,
      <466, 472, 473>,
      <466, 473, 467>,
      <474, 475, 458>,
      <474, 458, 467>,
      <474, 467, 473>,
      <474, 473, 476>,
      <474, 476, 477>,
      <474, 477, 478>,
      <474, 479, 480>,
      <474, 480, 475>,
      <481, 459, 458>,
      <481, 458, 475>,
      <481, 475, 482>,
      <481, 482, 483>,
      <481, 484, 485>,
      <481, 485, 486>,
      <481, 486, 460>,
      <481, 460, 459>,
      <487, 488, 489>,
      <487, 489, 490>,
      <487, 490, 491>,
      <487, 491, 492>,
      <487, 492, 493>,
      <487, 493, 355>,
      <487, 355, 352>,
      <487, 352, 488>,
      <494, 495, 489>,
      <494, 489, 488>,
      <494, 488, 352>,
      <494, 352, 351>,
      <494, 351, 496>,
      <494, 496, 497>,
      <494, 497, 498>,
      <494, 498, 495>,
      <499, 500, 489>,
      <499, 489, 495>,
      <499, 495, 498>,
      <499, 498, 501>,
      <499, 501, 502>,
      <499, 502, 503>,
      <499, 504, 505>,
      <499, 505, 500>,
      <506, 490, 489>,
      <506, 489, 500>,
      <506, 500, 507>,
      <506, 507, 508>,
      <506, 509, 510>,
      <506, 510, 511>,
      <506, 511, 491>,
      <506, 491, 490>,
      <512, 513, 514>,
      <512, 514, 515>,
      <512, 515, 516>,
      <512, 516, 517>,
      <512, 517, 518>,
      <512, 518, 519>,
      <512, 520, 521>,
      <512, 521, 513>,
      <522, 523, 514>,
      <522, 514, 513>,
      <522, 513, 524>,
      <522, 524, 525>,
      <522, 526, 527>,
      <522, 527, 528>,
      <522, 528, 529>,
      <522, 529, 523>,
      <530, 531, 514>,
      <530, 514, 523>,
      <530, 523, 529>,
      <530, 529, 532>,
      <530, 532, 533>,
      <530, 533, 534>,
      <530, 535, 536>,
      <530, 536, 531>,
      <537, 515, 514>,
      <537, 514, 531>,
      <537, 531, 538>,
      <537, 538, 539>,
      <537, 540, 541>,
      <537, 541, 542>,
      <537, 542, 516>,
      <537, 516, 515>,
      <543, 544, 545>,
      <543, 545, 546>,
      <543, 546, 547>,
      <543, 547, 548>,
      <543, 548, 549>,
      <543, 549, 299>,
      <543, 299, 296>,
      <543, 296, 544>,
      <550, 551, 545>,
      <550, 545, 544>,
      <550, 544, 296>,
      <550, 296, 295>,
      <550, 295, 552>,
      <550, 552, 553>,
      <550, 553, 554>,
      <550, 554, 551>,
      <555, 556, 545>,
      <555, 545, 551>,
      <555, 551, 554>,
      <555, 554, 557>,
      <555, 557, 558>,
      <555, 558, 559>,
      <555, 560, 561>,
      <555, 561, 556>,
      <562, 546, 545>,
      <562, 545, 556>,
      <562, 556, 563>,
      <562, 563, 564>,
      <562, 565, 566>,
      <562, 566, 567>,
      <562, 567, 547>,
      <562, 547, 546>,
      <568, 569, 570>,
      <568, 570, 571>,
      <568, 571, 572>,
      <568, 572, 573>,
      <568, 573, 574>,
      <568, 574, 575>,
      <568, 576, 577>,
      <568, 577, 569>,
      <578, 579, 570>,
      <578, 570, 569>,
      <578, 569, 580>,
      <578, 580, 581>,
      <578, 582, 583>,
      <578, 583, 584>,
      <578, 584, 585>,
      <578, 585, 579>,
      <586, 587, 570>,
      <586, 570, 579>,
      <586, 579, 585>,
      <586, 585, 588>,
      <586, 588, 589>,
      <586, 589, 590>,
      <586, 591, 592>,
      <586, 592, 587>,
      <593, 571, 570>,
      <593, 570, 587>,
      <593, 587, 594>,
      <593, 594, 595>,
      <593, 596, 597>,
      <593, 597, 598>,
      <593, 598, 572>,
      <593, 572, 571>,
      <599, 600, 601>,
      <599, 601, 602>,
      <599, 602, 603>,
      <599, 603, 604>,
      <599, 605, 606>,
      <599, 606, 607>,
      <599, 608, 609>,
      <599, 609, 600>,
      <610, 611, 601>,
      <610, 601, 600>,
      <610, 600, 612>,
      <610, 612, 613>,
      <610, 614, 615>,
      <610, 615, 616>,
      <610, 617, 618>,
      <610, 618, 611>,
      <619, 620, 601>,
      <619, 601, 611>,
      <619, 611, 621>,
      <619, 621, 622>,
      <619, 623, 624>,
      <619, 624, 625>,
      <619, 626, 627>,
      <619, 627, 620>,
      <628, 602, 601>,
      <628, 601, 620>,
      <628, 620, 629>,
      <628, 629, 630>,
      <628, 631, 632>,
      <628, 632, 633>,
      <628, 634, 635>,
      <628, 635, 602>,
      <636, 637, 638>,
      <636, 638, 639>,
      <636, 639, 640>,
      <636, 640, 641>,
      <636, 642, 643>,
      <636, 643, 644>,
      <636, 645, 646>,
      <636, 646, 637>,
      <647, 648, 638>,
      <647, 638, 637>,
      <647, 637, 649>,
      <647, 649, 650>,
      <647, 651, 652>,
      <647, 652, 653>,
      <647, 654, 655>,
      <647, 655, 648>,
      <656, 657, 638>,
      <656, 638, 648>,
      <656, 648, 658>,
      <656, 658, 659>,
      <656, 660, 661>,
      <656, 661, 662>,
      <656, 663, 664>,
      <656, 664, 657>,
      <665, 639, 638>,
      <665, 638, 657>,
      <665, 657, 666>,
      <665, 666, 667>,
      <665, 668, 669>,
      <665, 669, 670>,
      <665, 671, 672>,
      <665, 672, 639>,
      <673, 674, 675>,
      <673, 675, 676>,
      <673, 676, 677>,
      <673, 677, 678>,
      <673, 678, 679>,
      <673, 679, 680>,
      <673, 681, 682>,
      <673, 682, 674>,
      <683, 684, 675>,
      <683, 675, 674>,
      <683, 674, 685>,
      <683, 685, 686>,
      <683, 687, 688>,
      <683, 688, 689>,
      <683, 689, 690>,
      <683, 690, 684>,
      <691, 692, 675>,
      <691, 675, 684>,
      <691, 684, 690>,
      <691, 690, 693>,
      <691, 693, 694>,
      <691, 694, 695>,
      <691, 696, 697>,
      <691, 697, 692>,
      <698, 676, 675>,
      <698, 675, 692>,
      <698, 692, 699>,
      <698, 699, 700>,
      <698, 701, 702>,
      <698, 702, 703>,
      <698, 703, 677>,
      <698, 677, 676>,
      <704, 705, 706>,
      <704, 706, 707>,
      <704, 707, 708>,
      <704, 708, 709>,
      <704, 710, 711>,
      <704, 711, 712>,
      <704, 712, 713>,
      <704, 713, 705>,
      <714, 715, 706>,
      <714, 706, 705>,
      <714, 705, 713>,
      <714, 713, 716>,
      <714, 716, 717>,
      <714, 717, 718>,
      <714, 719, 720>,
      <714, 720, 715>,
      <721, 722, 706>,
      <721, 706, 715>,
      <721, 715, 723>,
      <721, 723, 724>,
      <721, 725, 726>,
      <721, 726, 727>,
      <721, 727, 728>,
      <721, 728, 722>,
      <729, 707, 706>,
      <729, 706, 722>,
      <729, 722, 728>,
      <729, 728, 730>,
      <729, 730, 731>,
      <729, 731, 732>,
      <729, 733, 734>,
      <729, 734, 707>,
      <735, 736, 737>,
      <735, 737, 738>,
      <735, 738, 739>,
      <735, 739, 740>,
      <735, 741, 742>,
      <735, 742, 743>,
      <735, 743, 744>,
      <735, 744, 736>,
      <745, 746, 737>,
      <745, 737, 736>,
      <745, 736, 744>,
      <745, 744, 747>,
      <745, 747, 748>,
      <745, 748, 749>,
      <745, 750, 751>,
      <745, 751, 746>,
      <752, 753, 737>,
      <752, 737, 746>,
      <752, 746, 754>,
      <752, 754, 755>,
      <752, 756, 757>,
      <752, 757, 758>,
      <752, 758, 759>,
      <752, 759, 753>,
      <760, 738, 737>,
      <760, 737, 753>,
      <760, 753, 759>,
      <760, 759, 761>,
      <760, 761, 762>,
      <760, 762, 763>,
      <760, 764, 765>,
      <760, 765, 738>,
      <766, 767, 768>,
      <766, 768, 769>,
      <766, 769, 770>,
      <766, 770, 771>,
      <766, 772, 773>,
      <766, 773, 774>,
      <766, 775, 776>,
      <766, 776, 767>,
      <777, 778, 768>,
      <777, 768, 767>,
      <777, 767, 779>,
      <777, 779, 780>,
      <777, 781, 782>,
      <777, 782, 783>,
      <777, 784, 785>,
      <777, 785, 778>,
      <786, 787, 768>,
      <786, 768, 778>,
      <786, 778, 788>,
      <786, 788, 789>,
      <786, 790, 791>,
      <786, 791, 792>,
      <786, 793, 794>,
      <786, 794, 787>,
      <795, 769, 768>,
      <795, 768, 787>,
      <795, 787, 796>,
      <795, 796, 797>,
      <795, 798, 799>,
      <795, 799, 800>,
      <795, 801, 802>,
      <795, 802, 769>,
      <803, 804, 805>,
      <803, 805, 806>,
      <803, 806, 807>,
      <803, 807, 808>,
      <803, 808, 809>,
      <803, 809, 810>,
      <803, 811, 812>,
      <803, 812, 804>,
      <813, 814, 805>,
      <813, 805, 804>,
      <813, 804, 815>,
      <813, 815, 816>,
      <813, 817, 818>,
      <813, 818, 819>,
      <813, 819, 820>,
      <813, 820, 814>,
      <821, 822, 805>,
      <821, 805, 814>,
      <821, 814, 820>,
      <821, 820, 823>,
      <821, 823, 824>,
      <821, 824, 825>,
      <821, 826, 827>,
      <821, 827, 822>,
      <828, 806, 805>,
      <828, 805, 822>,
      <828, 822, 829>,
      <828, 829, 830>,
      <828, 831, 832>,
      <828, 832, 833>,
      <828, 833, 807>,
      <828, 807, 806>,
      <834, 835, 836>,
      <834, 836, 837>,
      <834, 837, 838>,
      <834, 838, 839>,
      <834, 840, 841>,
      <834, 841, 842>,
      <834, 843, 844>,
      <834, 844, 835>,
      <845, 846, 836>,
      <845, 836, 835>,
      <845, 835, 847>,
      <845, 847, 848>,
      <845, 849, 850>,
      <845, 850, 851>,
      <845, 852, 853>,
      <845, 853, 846>,
      <854, 855, 836>,
      <854, 836, 846>,
      <854, 846, 856>,
      <854, 856, 857>,
      <854, 858, 859>,
      <854, 859, 860>,
      <854, 861, 862>,
      <854, 862, 855>,
      <863, 837, 836>,
      <863, 836, 855>,
      <863, 855, 864>,
      <863, 864, 865>,
      <863, 866, 867>,
      <863, 867, 868>,
      <863, 869, 870>,
      <863, 870, 837>,
      <871, 872, 873>,
      <871, 873, 874>,
      <871, 874, 875>,
      <871, 875, 876>,
      <871, 877, 878>,
      <871, 878, 879>,
      <871, 880, 881>,
      <871, 881, 872>,
      <882, 883, 873>,
      <882, 873, 872>,
      <882, 872, 884>,
      <882, 884, 885>,
      <882, 886, 887>,
      <882, 887, 888>,
      <882, 889, 890>,
      <882, 890, 883>,
      <891, 892, 873>,
      <891, 873, 883>,
      <891, 883, 893>,
      <891, 893, 894>,
      <891, 895, 896>,
      <891, 896, 897>,
      <891, 898, 899>,
      <891, 899, 892>,
      <900, 874, 873>,
      <900, 873, 892>,
      <900, 892, 901>,
      <900, 901, 902>,
      <900, 903, 904>,
      <900, 904, 905>,
      <900, 906, 907>,
      <900, 907, 874>,
      <908, 909, 910>,
      <908, 910, 911>,
      <908, 911, 912>,
      <908, 912, 913>,
      <908, 913, 914>,
      <908, 914, 915>,
      <908, 916, 917>,
      <908, 917, 909>,
      <918, 919, 910>,
      <918, 910, 909>,
      <918, 909, 920>,
      <918, 920, 921>,
      <918, 922, 923>,
      <918, 923, 924>,
      <918, 924, 925>,
      <918, 925, 919>,
      <926, 927, 910>,
      <926, 910, 919>,
      <926, 919, 925>,
      <926, 925, 928>,
      <926, 928, 929>,
      <926, 929, 930>,
      <926, 931, 932>,
      <926, 932, 927>,
      <933, 911, 910>,
      <933, 910, 927>,
      <933, 927, 934>,
      <933, 934, 935>,
      <933, 936, 937>,
      <933, 937, 938>,
      <933, 938, 912>,
      <933, 912, 911>,
      <939, 940, 941>,
      <939, 941, 942>,
      <939, 942, 943>,
      <939, 943, 944>,
      <939, 945, 946>,
      <939, 946, 947>,
      <939, 948, 949>,
      <939, 949, 940>,
      <950, 951, 941>,
      <950, 941, 940>,
      <950, 940, 952>,
      <950, 952, 953>,
      <950, 954, 955>,
      <950, 955, 956>,
      <950, 957, 958>,
      <950, 958, 951>,
      <959, 960, 941>,
      <959, 941, 951>,
      <959, 951, 961>,
      <959, 961, 962>,
      <959, 963, 964>,
      <959, 964, 965>,
      <959, 966, 967>,
      <959, 967, 960>,
      <968, 942, 941>,
      <968, 941, 960>,
      <968, 960, 969>,
      <968, 969, 970>,
      <968, 971, 972>,
      <968, 972, 973>,
      <968, 974, 975>,
      <968, 975, 942>,
      <976, 977, 978>,
      <976, 978, 979>,
      <976, 979, 980>,
      <976, 980, 981>,
      <976, 982, 983>,
      <976, 983, 984>,
      <976, 984, 985>,
      <976, 985, 977>,
      <986, 987, 978>,
      <986, 978, 977>,
      <986, 977, 985>,
      <986, 985, 988>,
      <986, 988, 989>,
      <986, 989, 990>,
      <986, 991, 992>,
      <986, 992, 987>,
      <993, 994, 978>,
      <993, 978, 987>,
      <993, 987, 995>,
      <993, 995, 996>,
      <993, 997, 998>,
      <993, 998, 999>,
      <993, 999, 1000>,
      <993, 1000, 994>,
      <1001, 979, 978>,
      <1001, 978, 994>,
      <1001, 994, 1000>,
      <1001, 1000, 1002>,
      <1001, 1002, 1003>,
      <1001, 1003, 1004>,
      <1001, 1005, 1006>,
      <1001, 1006, 979>,
      <1007, 1008, 1009>,
      <1007, 1009, 1010>,
      <1007, 1010, 1011>,
      <1007, 1011, 1012>,
      <1007, 1012, 1013>,
      <1007, 1013, 1014>,
      <1007, 1015, 1016>,
      <1007, 1016, 1008>,
      <1017, 1018, 1009>,
      <1017, 1009, 1008>,
      <1017, 1008, 1019>,
      <1017, 1019, 1020>,
      <1017, 1021, 1022>,
      <1017, 1022, 1023>,
      <1017, 1023, 1024>,
      <1017, 1024, 1018>,
      <1025, 1026, 1009>,
      <1025, 1009, 1018>,
      <1025, 1018, 1024>,
      <1025, 1024, 1027>,
      <1025, 1027, 694>,
      <1025, 694, 693>,
      <1025, 693, 690>,
      <1025, 690, 1026>,
      <1028, 1010, 1009>,
      <1028, 1009, 1026>,
      <1028, 1026, 690>,
      <1028, 690, 689>,
      <1028, 689, 688>,
      <1028, 688, 1029>,
      <1028, 1029, 1011>,
      <1028, 1011, 1010>,
      <1030, 1031, 1032>,
      <1030, 1032, 1033>,
      <1030, 1033, 1034>,
      <1030, 1034, 1035>,
      <1030, 1035, 1036>,
      <1030, 1036, 1037>,
      <1030, 1038, 1039>,
      <1030, 1039, 1031>,
      <1040, 1041, 1032>,
      <1040, 1032, 1031>,
      <1040, 1031, 1042>,
      <1040, 1042, 1043>,
      <1040, 1044, 1045>,
      <1040, 1045, 1046>,
      <1040, 1046, 1047>,
      <1040, 1047, 1041>,
      <1048, 1049, 1032>,
      <1048, 1032, 1041>,
      <1048, 1041, 1047>,
      <1048, 1047, 1050>,
      <1048, 1050, 679>,
      <1048, 679, 678>,
      <1048, 678, 677>,
      <1048, 677, 1049>,
      <1051, 1033, 1032>,
      <1051, 1032, 1049>,
      <1051, 1049, 677>,
      <1051, 677, 703>,
      <1051, 703, 702>,
      <1051, 702, 1052>,
      <1051, 1052, 1034>,
      <1051, 1034, 1033>,
      <1053, 1054, 1055>,
      <1053, 1055, 1056>,
      <1053, 1056, 1057>,
      <1053, 1057, 1058>,
      <1053, 1058, 1059>,
      <1053, 1059, 1060>,
      <1053, 1061, 1062>,
      <1053, 1062, 1054>,
      <1063, 1064, 1055>,
      <1063, 1055, 1054>,
      <1063, 1054, 1065>,
      <1063, 1065, 1066>,
      <1063, 1067, 1068>,
      <1063, 1068, 1069>,
      <1063, 1070, 1071>,
      <1063, 1071, 1064>,
      <1072, 1073, 1055>,
      <1072, 1055, 1064>,
      <1072, 1064, 1074>,
      <1072, 1074, 1075>,
      <1072, 1076, 1077>,
      <1072, 1077, 716>,
      <1072, 716, 713>,
      <1072, 713, 1073>,
      <1078, 1056, 1055>,
      <1078, 1055, 1073>,
      <1078, 1073, 713>,
      <1078, 713, 712>,
      <1078, 712, 711>,
      <1078, 711, 1079>,
      <1078, 1079, 1057>,
      <1078, 1057, 1056>,
      <1080, 1081, 1082>,
      <1080, 1082, 1083>,
      <1080, 1083, 1084>,
      <1080, 1084, 1085>,
      <1080, 1085, 1086>,
      <1080, 1086, 1087>,
      <1080, 1088, 1089>,
      <1080, 1089, 1081>,
      <1090, 1091, 1082>,
      <1090, 1082, 1081>,
      <1090, 1081, 1092>,
      <1090, 1092, 1093>,
      <1090, 1094, 1095>,
      <1090, 1095, 1096>,
      <1090, 1096, 1097>,
      <1090, 1097, 1091>,
      <1098, 1099, 1082>,
      <1098, 1082, 1091>,
      <1098, 1091, 1097>,
      <1098, 1097, 1100>,
      <1098, 1100, 731>,
      <1098, 731, 730>,
      <1098, 730, 728>,
      <1098, 728, 1099>,
      <1101, 1083, 1082>,
      <1101, 1082, 1099>,
      <1101, 1099, 728>,
      <1101, 728, 727>,
      <1101, 727, 726>,
      <1101, 726, 1102>,
      <1101, 1102, 1084>,
      <1101, 1084, 1083>,
      <1103, 1104, 1105>,
      <1103, 1105, 1106>,
      <1103, 1106, 1107>,
      <1103, 1107, 1108>,
      <1103, 1108, 1109>,
      <1103, 1109, 1110>,
      <1103, 1111, 1112>,
      <1103, 1112, 1104>,
      <1113, 1114, 1105>,
      <1113, 1105, 1104>,
      <1113, 1104, 1115>,
      <1113, 1115, 1116>,
      <1113, 1117, 1118>,
      <1113, 1118, 1119>,
      <1113, 1119, 1120>,
      <1113, 1120, 1114>,
      <1121, 1122, 1105>,
      <1121, 1105, 1114>,
      <1121, 1114, 1120>,
      <1121, 1120, 1123>,
      <1121, 1123, 748>,
      <1121, 748, 747>,
      <1121, 747, 744>,
      <1121, 744, 1122>,
      <1124, 1106, 1105>,
      <1124, 1105, 1122>,
      <1124, 1122, 744>,
      <1124, 744, 743>,
      <1124, 743, 742>,
      <1124, 742, 1125>,
      <1124, 1125, 1107>,
      <1124, 1107, 1106>,
      <1126, 1127, 1128>,
      <1126, 1128, 1129>,
      <1126, 1129, 1130>,
      <1126, 1130, 1131>,
      <1126, 1131, 1132>,
      <1126, 1132, 1133>,
      <1126, 1134, 1135>,
      <1126, 1135, 1127>,
      <1136, 1137, 1128>,
      <1136, 1128, 1127>,
      <1136, 1127, 1138>,
      <1136, 1138, 1139>,
      <1136, 1140, 1141>,
      <1136, 1141, 1142>,
      <1136, 1142, 1143>,
      <1136, 1143, 1137>,
      <1144, 1145, 1128>,
      <1144, 1128, 1137>,
      <1144, 1137, 1143>,
      <1144, 1143, 1146>,
      <1144, 1146, 762>,
      <1144, 762, 761>,
      <1144, 761, 759>,
      <1144, 759, 1145>,
      <1147, 1129, 1128>,
      <1147, 1128, 1145>,
      <1147, 1145, 759>,
      <1147, 759, 758>,
      <1147, 758, 757>,
      <1147, 757, 1148>,
      <1147, 1148, 1130>,
      <1147, 1130, 1129>,
      <1149, 1150, 1151>,
      <1149, 1151, 1152>,
      <1149, 1152, 1153>,
      <1149, 1153, 1154>,
      <1149, 1154, 1155>,
      <1149, 1155, 1156>,
      <1149, 1157, 1158>,
      <1149, 1158, 1150>,
      <1159, 1160, 1151>,
      <1159, 1151, 1150>,
      <1159, 1150, 1161>,
      <1159, 1161, 1162>,
      <1159, 1163, 1164>,
      <1159, 1164, 1165>,
      <1159, 1165, 1166>,
      <1159, 1166, 1160>,
      <1167, 1168, 1151>,
      <1167, 1151, 1160>,
      <1167, 1160, 1166>,
      <1167, 1166, 1169>,
      <1167, 1169, 824>,
      <1167, 824, 823>,
      <1167, 823, 820>,
      <1167, 820, 1168>,
      <1170, 1152, 1151>,
      <1170, 1151, 1168>,
      <1170, 1168, 820>,
      <1170, 820, 819>,
      <1170, 819, 818>,
      <1170, 818, 1171>,
      <1170, 1171, 1153>,
      <1170, 1153, 1152>,
      <1172, 1173, 1174>,
      <1172, 1174, 1175>,
      <1172, 1175, 1176>,
      <1172, 1176, 1177>,
      <1172, 1177, 1178>,
      <1172, 1178, 1179>,
      <1172, 1180, 1181>,
      <1172, 1181, 1173>,
      <1182, 1183, 1174>,
      <1182, 1174, 1173>,
      <1182, 1173, 1184>,
      <1182, 1184, 1185>,
      <1182, 1186, 1187>,
      <1182, 1187, 1188>,
      <1182, 1188, 1189>,
      <1182, 1189, 1183>,
      <1190, 1191, 1174>,
      <1190, 1174, 1183>,
      <1190, 1183, 1189>,
      <1190, 1189, 1192>,
      <1190, 1192, 809>,
      <1190, 809, 808>,
      <1190, 808, 807>,
      <1190, 807, 1191>,
      <1193, 1175, 1174>,
      <1193, 1174, 1191>,
      <1193, 1191, 807>,
      <1193, 807, 833>,
      <1193, 833, 832>,
      <1193, 832, 1194>,
      <1193, 1194, 1176>,
      <1193, 1176, 1175>,
      <1195, 1196, 1197>,
      <1195, 1197, 1198>,
      <1195, 1198, 1199>,
      <1195, 1199, 1200>,
      <1195, 1200, 1201>,
      <1195, 1201, 1202>,
      <1195, 1203, 1204>,
      <1195, 1204, 1196>,
      <1205, 1206, 1197>,
      <1205, 1197, 1196>,
      <1205, 1196, 1207>,
      <1205, 1207, 1208>,
      <1205, 1209, 1210>,
      <1205, 1210, 1211>,
      <1205, 1211, 1212>,
      <1205, 1212, 1206>,
      <1213, 1214, 1197>,
      <1213, 1197, 1206>,
      <1213, 1206, 1212>,
      <1213, 1212, 1215>,
      <1213, 1215, 929>,
      <1213, 929, 928>,
      <1213, 928, 925>,
      <1213, 925, 1214>,
      <1216, 1198, 1197>,
      <1216, 1197, 1214>,
      <1216, 1214, 925>,
      <1216, 925, 924>,
      <1216, 924, 923>,
      <1216, 923, 1217>,
      <1216, 1217, 1199>,
      <1216, 1199, 1198>,
      <1218, 1219, 1220>,
      <1218, 1220, 1221>,
      <1218, 1221, 1222>,
      <1218, 1222, 1223>,
      <1218, 1223, 1224>,
      <1218, 1224, 1225>,
      <1218, 1226, 1227>,
      <1218, 1227, 1219>,
      <1228, 1229, 1220>,
      <1228, 1220, 1219>,
      <1228, 1219, 1230>,
      <1228, 1230, 1231>,
      <1228, 1232, 1233>,
      <1228, 1233, 1234>,
      <1228, 1234, 1235>,
      <1228, 1235, 1229>,
      <1236, 1237, 1220>,
      <1236, 1220, 1229>,
      <1236, 1229, 1235>,
      <1236, 1235, 1238>,
      <1236, 1238, 914>,
      <1236, 914, 913>,
      <1236, 913, 912>,
      <1236, 912, 1237>,
      <1239, 1221, 1220>,
      <1239, 1220, 1237>,
      <1239, 1237, 912>,
      <1239, 912, 938>,
      <1239, 938, 937>,
      <1239, 937, 1240>,
      <1239, 1240, 1222>,
      <1239, 1222, 1221>,
      <1241, 1242, 1243>,
      <1241, 1243, 1244>,
      <1241, 1244, 1245>,
      <1241, 1245, 1246>,
      <1241, 1246, 1247>,
      <1241, 1247, 1248>,
      <1241, 1249, 1250>,
      <1241, 1250, 1242>,
      <1251, 1252, 1243>,
      <1251, 1243, 1242>,
      <1251, 1242, 1253>,
      <1251, 1253, 1254>,
      <1251, 1255, 1256>,
      <1251, 1256, 1257>,
      <1251, 1257, 1258>,
      <1251, 1258, 1252>,
      <1259, 1260, 1243>,
      <1259, 1243, 1252>,
      <1259, 1252, 1258>,
      <1259, 1258, 1261>,
      <1259, 1261, 989>,
      <1259, 989, 988>,
      <1259, 988, 985>,
      <1259, 985, 1260>,
      <1262, 1244, 1243>,
      <1262, 1243, 1260>,
      <1262, 1260, 985>,
      <1262, 985, 984>,
      <1262, 984, 983>,
      <1262, 983, 1263>,
      <1262, 1263, 1245>,
      <1262, 1245, 1244>,
      <1264, 1265, 1266>,
      <1264, 1266, 1267>,
      <1264, 1267, 1268>,
      <1264, 1268, 1269>,
      <1264, 1269, 1270>,
      <1264, 1270, 1271>,
      <1264, 1272, 1273>,
      <1264, 1273, 1265>,
      <1274, 1275, 1266>,
      <1274, 1266, 1265>,
      <1274, 1265, 1276>,
      <1274, 1276, 1277>,
      <1274, 1278, 1279>,
      <1274, 1279, 1280>,
      <1274, 1280, 1281>,
      <1274, 1281, 1275>,
      <1282, 1283, 1266>,
      <1282, 1266, 1275>,
      <1282, 1275, 1281>,
      <1282, 1281, 1284>,
      <1282, 1284, 1003>,
      <1282, 1003, 1002>,
      <1282, 1002, 1000>,
      <1282, 1000, 1283>,
      <1285, 1267, 1266>,
      <1285, 1266, 1283>,
      <1285, 1283, 1000>,
      <1285, 1000, 999>,
      <1285, 999, 998>,
      <1285, 998, 1286>,
      <1285, 1286, 1268>,
      <1285, 1268, 1267>,
      <1287, 1288, 1289>,
      <1287, 1289, 1290>,
      <1287, 1290, 414>,
      <1287, 414, 413>,
      <1287, 413, 1291>,
      <1287, 1291, 1292>,
      <1287, 1292, 1293>,
      <1287, 1293, 1288>,
      <1294, 1295, 1289>,
      <1294, 1289, 1288>,
      <1294, 1288, 1293>,
      <1294, 1293, 1296>,
      <1294, 1296, 731>,
      <1294, 731, 1100>,
      <1294, 1100, 1097>,
      <1294, 1097, 1295>,
      <1297, 1290, 1289>,
      <1297, 1289, 1295>,
      <1297, 1295, 1097>,
      <1297, 1097, 1096>,
      <1297, 1096, 1298>,
      <1297, 1298, 417>,
      <1297, 417, 414>,
      <1297, 414, 1290>,
      <1299, 1300, 1301>,
      <1299, 1301, 1302>,
      <1299, 1302, 1303>,
      <1299, 1303, 1304>,
      <1299, 1304, 1305>,
      <1299, 1305, 461>,
      <1299, 461, 460>,
      <1299, 460, 1300>,
      <1306, 1307, 1301>,
      <1306, 1301, 1300>,
      <1306, 1300, 460>,
      <1306, 460, 486>,
      <1306, 486, 1308>,
      <1306, 1308, 1085>,
      <1306, 1085, 1084>,
      <1306, 1084, 1307>,
      <1309, 1302, 1301>,
      <1309, 1301, 1307>,
      <1309, 1307, 1084>,
      <1309, 1084, 1102>,
      <1309, 1102, 726>,
      <1309, 726, 1310>,
      <1309, 1310, 1303>,
      <1309, 1303, 1302>,
      <1311, 1312, 1313>,
      <1311, 1313, 1314>,
      <1311, 1314, 1315>,
      <1311, 1315, 1316>,
      <1311, 1317, 1318>,
      <1311, 1318, 1319>,
      <1311, 1319, 1320>,
      <1311, 1320, 1312>,
      <1321, 1322, 1313>,
      <1321, 1313, 1312>,
      <1321, 1312, 1320>,
      <1321, 1320, 1323>,
      <1321, 1323, 711>,
      <1321, 711, 1324>,
      <1321, 1325, 1326>,
      <1321, 1326, 1322>,
      <1327, 1328, 1313>,
      <1327, 1313, 1322>,
      <1327, 1322, 1329>,
      <1327, 1329, 1330>,
      <1327, 1331, 731>,
      <1327, 731, 1296>,
      <1327, 1296, 1293>,
      <1327, 1293, 1328>,
      <1332, 1314, 1313>,
      <1332, 1313, 1328>,
      <1332, 1328, 1293>,
      <1332, 1293, 1292>,
      <1332, 1292, 1333>,
      <1332, 1333, 1334>,
      <1332, 1335, 1336>,
      <1332, 1336, 1314>,
      <1337, 1338, 1339>,
      <1337, 1339, 1340>,
      <1337, 1340, 1341>,
      <1337, 1341, 1342>,
      <1337, 1343, 1344>,
      <1337, 1344, 1345>,
      <1337, 1346, 1347>,
      <1337, 1347, 1338>,
      <1348, 1349, 1339>,
      <1348, 1339, 1338>,
      <1348, 1338, 1350>,
      <1348, 1350, 1351>,
      <1348, 1352, 1353>,
      <1348, 1353, 1304>,
      <1348, 1304, 1303>,
      <1348, 1303, 1349>,
      <1354, 1355, 1339>,
      <1354, 1339, 1349>,
      <1354, 1349, 1303>,
      <1354, 1303, 1310>,
      <1354, 1310, 726>,
      <1354, 726, 1356>,
      <1354, 1357, 1358>,
      <1354, 1358, 1355>,
      <1359, 1340, 1339>,
      <1359, 1339, 1355>,
      <1359, 1355, 1360>,
      <1359, 1360, 1361>,
      <1359, 1362, 1363>,
      <1359, 1363, 1364>,
      <1359, 1365, 1366>,
      <1359, 1366, 1340>,
      <1367, 1368, 1369>,
      <1367, 1369, 1370>,
      <1367, 1370, 1320>,
      <1367, 1320, 1319>,
      <1367, 1319, 1371>,
      <1367, 1371, 377>,
      <1367, 377, 376>,
      <1367, 376, 1368>,
      <1372, 1373, 1369>,
      <1372, 1369, 1368>,
      <1372, 1368, 376>,
      <1372, 376, 396>,
      <1372, 396, 1374>,
      <1372, 1374, 1058>,
      <1372, 1058, 1057>,
      <1372, 1057, 1373>,
      <1375, 1370, 1369>,
      <1375, 1369, 1373>,
      <1375, 1373, 1057>,
      <1375, 1057, 1079>,
      <1375, 1079, 711>,
      <1375, 711, 1323>,
      <1375, 1323, 1320>,
      <1375, 1320, 1370>,
      <1376, 1377, 1378>,
      <1376, 1378, 1379>,
      <1376, 1379, 274>,
      <1376, 274, 273>,
      <1376, 273, 1380>,
      <1376, 1380, 1381>,
      <1376, 1381, 1382>,
      <1376, 1382, 1377>,
      <1383, 1384, 1378>,
      <1383, 1378, 1377>,
      <1383, 1377, 1382>,
      <1383, 1382, 1385>,
      <1383, 1385, 809>,
      <1383, 809, 1192>,
      <1383, 1192, 1189>,
      <1383, 1189, 1384>,
      <1386, 1379, 1378>,
      <1386, 1378, 1384>,
      <1386, 1384, 1189>,
      <1386, 1189, 1188>,
      <1386, 1188, 1387>,
      <1386, 1387, 277>,
      <1386, 277, 274>,
      <1386, 274, 1379>,
      <1388, 1389, 1390>,
      <1388, 1390, 1391>,
      <1388, 1391, 1392>,
      <1388, 1392, 1393>,
      <1388, 1393, 1394>,
      <1388, 1394, 321>,
      <1388, 321, 320>,
      <1388, 320, 1389>,
      <1395, 1396, 1390>,
      <1395, 1390, 1389>,
      <1395, 1389, 320>,
      <1395, 320, 343>,
      <1395, 343, 1397>,
      <1395, 1397, 1177>,
      <1395, 1177, 1176>,
      <1395, 1176, 1396>,
      <1398, 1391, 1390>,
      <1398, 1390, 1396>,
      <1398, 1396, 1176>,
      <1398, 1176, 1194>,
      <1398, 1194, 832>,
      <1398, 832, 1399>,
      <1398, 1399, 1392>,
      <1398, 1392, 1391>,
      <1400, 1401, 1402>,
      <1400, 1402, 1403>,
      <1400, 1403, 1382>,
      <1400, 1382, 1381>,
      <1400, 1381, 1404>,
      <1400, 1404, 1405>,
      <1400, 1406, 1407>,
      <1400, 1407, 1401>,
      <1408, 1409, 1402>,
      <1408, 1402, 1401>,
      <1408, 1401, 1410>,
      <1408, 1410, 1411>,
      <1408, 1412, 1413>,
      <1408, 1413, 1414>,
      <1408, 1414, 1415>,
      <1408, 1415, 1409>,
      <1416, 1417, 1402>,
      <1416, 1402, 1409>,
      <1416, 1409, 1415>,
      <1416, 1415, 1418>,
      <1416, 1418, 818>,
      <1416, 818, 1419>,
      <1416, 1420, 1421>,
      <1416, 1421, 1417>,
      <1422, 1403, 1402>,
      <1422, 1402, 1417>,
      <1422, 1417, 1423>,
      <1422, 1423, 1424>,
      <1422, 1425, 809>,
      <1422, 809, 1385>,
      <1422, 1385, 1382>,
      <1422, 1382, 1403>,
      <1426, 1427, 1428>,
      <1426, 1428, 1429>,
      <1426, 1429, 1430>,
      <1426, 1430, 1431>,
      <1426, 1432, 1433>,
      <1426, 1433, 1393>,
      <1426, 1393, 1392>,
      <1426, 1392, 1427>,
      <1434, 1435, 1428>,
      <1434, 1428, 1427>,
      <1434, 1427, 1392>,
      <1434, 1392, 1399>,
      <1434, 1399, 832>,
      <1434, 832, 1436>,
      <1434, 1437, 1438>,
      <1434, 1438, 1435>,
      <1439, 1440, 1428>,
      <1439, 1428, 1435>,
      <1439, 1435, 1441>,
      <1439, 1441, 1442>,
      <1439, 1443, 824>,
      <1439, 824, 1444>,
      <1439, 1444, 1445>,
      <1439, 1445, 1440>,
      <1446, 1429, 1428>,
      <1446, 1428, 1440>,
      <1446, 1440, 1445>,
      <1446, 1445, 1447>,
      <1446, 1447, 1448>,
      <1446, 1448, 1449>,
      <1446, 1450, 1451>,
      <1446, 1451, 1429>,
      <1452, 1453, 1454>,
      <1452, 1454, 1455>,
      <1452, 1455, 1415>,
      <1452, 1415, 1414>,
      <1452, 1414, 1456>,
      <1452, 1456, 293>,
      <1452, 293, 292>,
      <1452, 292, 1453>,
      <1457, 1458, 1454>,
      <1457, 1454, 1453>,
      <1457, 1453, 292>,
      <1457, 292, 315>,
      <1457, 315, 1459>,
      <1457, 1459, 1154>,
      <1457, 1154, 1153>,
      <1457, 1153, 1458>,
      <1460, 1455, 1454>,
      <1460, 1454, 1458>,
      <1460, 1458, 1153>,
      <1460, 1153, 1171>,
      <1460, 1171, 818>,
      <1460, 818, 1418>,
      <1460, 1418, 1415>,
      <1460, 1415, 1455>,
      <1461, 1462, 1463>,
      <1461, 1463, 1464>,
      <1461, 1464, 358>,
      <1461, 358, 357>,
      <1461, 357, 1465>,
      <1461, 1465, 1447>,
      <1461, 1447, 1445>,
      <1461, 1445, 1462>,
      <1466, 1467, 1463>,
      <1466, 1463, 1462>,
      <1466, 1462, 1445>,
      <1466, 1445, 1444>,
      <1466, 1444, 824>,
      <1466, 824, 1169>,
      <1466, 1169, 1166>,
      <1466, 1166, 1467>,
      <1468, 1464, 1463>,
      <1468, 1463, 1467>,
      <1468, 1467, 1166>,
      <1468, 1166, 1165>,
      <1468, 1165, 1469>,
      <1468, 1469, 361>,
      <1468, 361, 358>,
      <1468, 358, 1464>,
      <1470, 1471, 1472>,
      <1470, 1472, 1473>,
      <1470, 1473, 554>,
      <1470, 554, 553>,
      <1470, 553, 1474>,
      <1470, 1474, 1475>,
      <1470, 1475, 1476>,
      <1470, 1476, 1471>,
      <1477, 1478, 1472>,
      <1477, 1472, 1471>,
      <1477, 1471, 1476>,
      <1477, 1476, 1479>,
      <1477, 1479, 989>,
      <1477, 989, 1261>,
      <1477, 1261, 1258>,
      <1477, 1258, 1478>,
      <1480, 1473, 1472>,
      <1480, 1472, 1478>,
      <1480, 1478, 1258>,
      <1480, 1258, 1257>,
      <1480, 1257, 1481>,
      <1480, 1481, 557>,
      <1480, 557, 554>,
      <1480, 554, 1473>,
      <1482, 1483, 1484>,
      <1482, 1484, 1485>,
      <1482, 1485, 1486>,
      <1482, 1486, 1487>,
      <1482, 1487, 1488>,
      <1482, 1488, 492>,
      <1482, 492, 491>,
      <1482, 491, 1483>,
      <1489, 1490, 1484>,
      <1489, 1484, 1483>,
      <1489, 1483, 491>,
      <1489, 491, 511>,
      <1489, 511, 1491>,
      <1489, 1491, 1246>,
      <1489, 1246, 1245>,
      <1489, 1245, 1490>,
      <1492, 1485, 1484>,
      <1492, 1484, 1490>,
      <1492, 1490, 1245>,
      <1492, 1245, 1263>,
      <1492, 1263, 983>,
      <1492, 983, 1493>,
      <1492, 1493, 1486>,
      <1492, 1486, 1485>,
      <1494, 1495, 1496>,
      <1494, 1496, 1497>,
      <1494, 1497, 1476>,
      <1494, 1476, 1475>,
      <1494, 1475, 1498>,
      <1494, 1498, 1499>,
      <1494, 1500, 1501>,
      <1494, 1501, 1495>,
      <1502, 1503, 1496>,
      <1502, 1496, 1495>,
      <1502, 1495, 1504>,
      <1502, 1504, 1505>,
      <1502, 1506, 1507>,
      <1502, 1507, 1508>,
      <1502, 1508, 1509>,
      <1502, 1509, 1503>,
      <1510, 1511, 1496>,
      <1510, 1496, 1503>,
      <1510, 1503, 1509>,
      <1510, 1509, 1512>,
      <1510, 1512, 998>,
      <1510, 998, 1513>,
      <1510, 1514, 1515>,
      <1510, 1515, 1511>,
      <1516, 1497, 1496>,
      <1516, 1496, 1511>,
      <1516, 1511, 1517>,
      <1516, 1517, 1518>,
      <1516, 1519, 989>,
      <1516, 989, 1479>,
      <1516, 1479, 1476>,
      <1516, 1476, 1497>,
      <1520, 1521, 1522>,
      <1520, 1522, 1523>,
      <1520, 1523, 1524>,
      <1520, 1524, 1525>,
      <1520, 1526, 1527>,
      <1520, 1527, 1487>,
      <1520, 1487, 1486>,
      <1520, 1486, 1521>,
      <1528, 1529, 1522>,
      <1528, 1522, 1521>,
      <1528, 1521, 1486>,
      <1528, 1486, 1493>,
      <1528, 1493, 983>,
      <1528, 983, 1530>,
      <1528, 1531, 1532>,
      <1528, 1532, 1529>,
      <1533, 1534, 1522>,
      <1533, 1522, 1529>,
      <1533, 1529, 1535>,
      <1533, 1535, 1536>,
      <1533, 1537, 1003>,
      <1533, 1003, 1538>,
      <1533, 1538, 1539>,
      <1533, 1539, 1534>,
      <1540, 1523, 1522>,
      <1540, 1522, 1534>,
      <1540, 1534, 1539>,
      <1540, 1539, 1541>,
      <1540, 1541, 1542>,
      <1540, 1542, 1543>,
      <1540, 1544, 1545>,
      <1540, 1545, 1523>,
      <1546, 1547, 1548>,
      <1546, 1548, 1549>,
      <1546, 1549, 1509>,
      <1546, 1509, 1508>,
      <1546, 1508, 1550>,
      <1546, 1550, 573>,
      <1546, 573, 572>,
      <1546, 572, 1547>,
      <1551, 1552, 1548>,
      <1551, 1548, 1547>,
      <1551, 1547, 572>,
      <1551, 572, 598>,
      <1551, 598, 1553>,
      <1551, 1553, 1269>,
      <1551, 1269, 1268>,
      <1551, 1268, 1552>,
      <1554, 1549, 1548>,
      <1554, 1548, 1552>,
      <1554, 1552, 1268>,
      <1554, 1268, 1286>,
      <1554, 1286, 998>,
      <1554, 998, 1512>,
      <1554, 1512, 1509>,
      <1554, 1509, 1549>,
      <1555, 1556, 1557>,
      <1555, 1557, 1558>,
      <1555, 1558, 529>,
      <1555, 529, 528>,
      <1555, 528, 1559>,
      <1555, 1559, 1541>,
      <1555, 1541, 1539>,
      <1555, 1539, 1556>,
      <1560, 1561, 1557>,
      <1560, 1557, 1556>,
      <1560, 1556, 1539>,
      <1560, 1539, 1538>,
      <1560, 1538, 1003>,
      <1560, 1003, 1284>,
      <1560, 1284, 1281>,
      <1560, 1281, 1561>,
      <1562, 1558, 1557>,
      <1562, 1557, 1561>,
      <1562, 1561, 1281>,
      <1562, 1281, 1280>,
      <1562, 1280, 1563>,
      <1562, 1563, 532>,
      <1562, 532, 529>,
      <1562, 529, 1558>,
      <1564, 1565, 1566>,
      <1564, 1566, 1567>,
      <1564, 1567, 1568>,
      <1564, 1568, 1569>,
      <1564, 1569, 1570>,
      <1564, 1570, 402>,
      <1564, 402, 401>,
      <1564, 401, 1565>,
      <1571, 1572, 1566>,
      <1571, 1566, 1565>,
      <1571, 1565, 401>,
      <1571, 401, 427>,
      <1571, 427, 1573>,
      <1571, 1573, 1012>,
      <1571, 1012, 1011>,
      <1571, 1011, 1572>,
      <1574, 1567, 1566>,
      <1574, 1566, 1572>,
      <1574, 1572, 1011>,
      <1574, 1011, 1029>,
      <1574, 1029, 688>,
      <1574, 688, 1575>,
      <1574, 1575, 1568>,
      <1574, 1568, 1567>,
      <1576, 1577, 1578>,
      <1576, 1578, 1579>,
      <1576, 1579, 473>,
      <1576, 473, 472>,
      <1576, 472, 1580>,
      <1576, 1580, 1581>,
      <1576, 1581, 1582>,
      <1576, 1582, 1577>,
      <1583, 1584, 1578>,
      <1583, 1578, 1577>,
      <1583, 1577, 1582>,
      <1583, 1582, 1585>,
      <1583, 1585, 694>,
      <1583, 694, 1027>,
      <1583, 1027, 1024>,
      <1583, 1024, 1584>,
      <1586, 1579, 1578>,
      <1586, 1578, 1584>,
      <1586, 1584, 1024>,
      <1586, 1024, 1023>,
      <1586, 1023, 1587>,
      <1586, 1587, 476>,
      <1586, 476, 473>,
      <1586, 473, 1579>,
      <1588, 1589, 1590>,
      <1588, 1590, 1591>,
      <1588, 1591, 1592>,
      <1588, 1592, 1593>,
      <1588, 1593, 1594>,
      <1588, 1594, 1595>,
      <1588, 1596, 1597>,
      <1588, 1597, 1589>,
      <1598, 1599, 1590>,
      <1598, 1590, 1589>,
      <1598, 1589, 1600>,
      <1598, 1600, 1601>,
      <1598, 1602, 1603>,
      <1598, 1603, 1569>,
      <1598, 1569, 1568>,
      <1598, 1568, 1599>,
      <1604, 1605, 1590>,
      <1604, 1590, 1599>,
      <1604, 1599, 1568>,
      <1604, 1568, 1575>,
      <1604, 1575, 688>,
      <1604, 688, 1606>,
      <1604, 1607, 1608>,
      <1604, 1608, 1605>,
      <1609, 1591, 1590>,
      <1609, 1590, 1605>,
      <1609, 1605, 1610>,
      <1609, 1610, 1611>,
      <1609, 1612, 679>,
      <1609, 679, 1613>,
      <1609, 1613, 1592>,
      <1609, 1592, 1591>,
      <1614, 1615, 1616>,
      <1614, 1616, 1617>,
      <1614, 1617, 1618>,
      <1614, 1618, 1619>,
      <1614, 1620, 1621>,
      <1614, 1621, 1622>,
      <1614, 1622, 1623>,
      <1614, 1623, 1615>,
      <1624, 1625, 1616>,
      <1624, 1616, 1615>,
      <1624, 1615, 1623>,
      <1624, 1623, 1626>,
      <1624, 1626, 702>,
      <1624, 702, 1627>,
      <1624, 1628, 1629>,
      <1624, 1629, 1625>,
      <1630, 1631, 1616>,
      <1630, 1616, 1625>,
      <1630, 1625, 1632>,
      <1630, 1632, 1633>,
      <1630, 1634, 694>,
      <1630, 694, 1585>,
      <1630, 1585, 1582>,
      <1630, 1582, 1631>,
      <1635, 1617, 1616>,
      <1635, 1616, 1631>,
      <1635, 1631, 1582>,
      <1635, 1582, 1581>,
      <1635, 1581, 1636>,
      <1635, 1636, 1637>,
      <1635, 1638, 1639>,
      <1635, 1639, 1617>,
      <1640, 1641, 1642>,
      <1640, 1642, 1643>,
      <1640, 1643, 383>,
      <1640, 383, 382>,
      <1640, 382, 1644>,
      <1640, 1644, 1593>,
      <1640, 1593, 1592>,
      <1640, 1592, 1641>,
      <1645, 1646, 1642>,
      <1645, 1642, 1641>,
      <1645, 1641, 1592>,
      <1645, 1592, 1613>,
      <1645, 1613, 679>,
      <1645, 679, 1050>,
      <1645, 1050, 1047>,
      <1645, 1047, 1646>,
      <1647, 1643, 1642>,
      <1647, 1642, 1646>,
      <1647, 1646, 1047>,
      <1647, 1047, 1046>,
      <1647, 1046, 1648>,
      <1647, 1648, 386>,
      <1647, 386, 383>,
      <1647, 383, 1643>,
      <1649, 1650, 1651>,
      <1649, 1651, 1652>,
      <1649, 1652, 1623>,
      <1649, 1623, 1622>,
      <1649, 1622, 1653>,
      <1649, 1653, 433>,
      <1649, 433, 432>,
      <1649, 432, 1650>,
      <1654, 1655, 1651>,
      <1654, 1651, 1650>,
      <1654, 1650, 432>,
      <1654, 432, 455>,
      <1654, 455, 1656>,
      <1654, 1656, 1035>,
      <1654, 1035, 1034>,
      <1654, 1034, 1655>,
      <1657, 1652, 1651>,
      <1657, 1651, 1655>,
      <1657, 1655, 1034>,
      <1657, 1034, 1052>,
      <1657, 1052, 702>,
      <1657, 702, 1626>,
      <1657, 1626, 1623>,
      <1657, 1623, 1652>,
      <1658, 1659, 1660>,
      <1658, 1660, 1661>,
      <1658, 1661, 1662>,
      <1658, 1662, 1663>,
      <1658, 1663, 1664>,
      <1658, 1664, 265>,
      <1658, 265, 264>,
      <1658, 264, 1659>,
      <1665, 1666, 1660>,
      <1665, 1660, 1659>,
      <1665, 1659, 264>,
      <1665, 264, 287>,
      <1665, 287, 1667>,
      <1665, 1667, 1108>,
      <1665, 1108, 1107>,
      <1665, 1107, 1666>,
      <1668, 1661, 1660>,
      <1668, 1660, 1666>,
      <1668, 1666, 1107>,
      <1668, 1107, 1125>,
      <1668, 1125, 742>,
      <1668, 742, 1669>,
      <1668, 1669, 1662>,
      <1668, 1662, 1661>,
      <1670, 1671, 1672>,
      <1670, 1672, 1673>,
      <1670, 1673, 330>,
      <1670, 330, 329>,
      <1670, 329, 1674>,
      <1670, 1674, 1675>,
      <1670, 1675, 1676>,
      <1670, 1676, 1671>,
      <1677, 1678, 1672>,
      <1677, 1672, 1671>,
      <1677, 1671, 1676>,
      <1677, 1676, 1679>,
      <1677, 1679, 748>,
      <1677, 748, 1123>,
      <1677, 1123, 1120>,
      <1677, 1120, 1678>,
      <1680, 1673, 1672>,
      <1680, 1672, 1678>,
      <1680, 1678, 1120>,
      <1680, 1120, 1119>,
      <1680, 1119, 1681>,
      <1680, 1681, 333>,
      <1680, 333, 330>,
      <1680, 330, 1673>,
      <1682, 1683, 1684>,
      <1682, 1684, 1685>,
      <1682, 1685, 1686>,
      <1682, 1686, 1687>,
      <1682, 1688, 1689>,
      <1682, 1689, 1663>,
      <1682, 1663, 1662>,
      <1682, 1662, 1683>,
      <1690, 1691, 1684>,
      <1690, 1684, 1683>,
      <1690, 1683, 1662>,
      <1690, 1662, 1669>,
      <1690, 1669, 742>,
      <1690, 742, 1692>,
      <1690, 1693, 1694>,
      <1690, 1694, 1691>,
      <1695, 1696, 1684>,
      <1695, 1684, 1691>,
      <1695, 1691, 1697>,
      <1695, 1697, 1698>,
      <1695, 1699, 762>,
      <1695, 762, 1700>,
      <1695, 1700, 1701>,
      <1695, 1701, 1696>,
      <1702, 1685, 1684>,
      <1702, 1684, 1696>,
      <1702, 1696, 1701>,
      <1702, 1701, 1703>,
      <1702, 1703, 1704>,
      <1702, 1704, 1705>,
      <1702, 1706, 1707>,
      <1702, 1707, 1685>,
      <1708, 1709, 1710>,
      <1708, 1710, 1711>,
      <1708, 1711, 1676>,
      <1708, 1676, 1675>,
      <1708, 1675, 1712>,
      <1708, 1712, 1713>,
      <1708, 1714, 1715>,
      <1708, 1715, 1709>,
      <1716, 1717, 1710>,
      <1716, 1710, 1709>,
      <1716, 1709, 1718>,
      <1716, 1718, 1719>,
      <1716, 1720, 1721>,
      <1716, 1721, 1722>,
      <1716, 1722, 1723>,
      <1716, 1723, 1717>,
      <1724, 1725, 1710>,
      <1724, 1710, 1717>,
      <1724, 1717, 1723>,
      <1724, 1723, 1726>,
      <1724, 1726, 757>,
      <1724, 757, 1727>,
      <1724, 1728, 1729>,
      <1724, 1729, 1725>,
      <1730, 1711, 1710>,
      <1730, 1710, 1725>,
      <1730, 1725, 1731>,
      <1730, 1731, 1732>,
      <1730, 1733, 748>,
      <1730, 748, 1679>,
      <1730, 1679, 1676>,
      <1730, 1676, 1711>,
      <1734, 1735, 1736>,
      <1734, 1736, 1737>,
      <1734, 1737, 302>,
      <1734, 302, 301>,
      <1734, 301, 1738>,
      <1734, 1738, 1703>,
      <1734, 1703, 1701>,
      <1734, 1701, 1735>,
      <1739, 1740, 1736>,
      <1739, 1736, 1735>,
      <1739, 1735, 1701>,
      <1739, 1701, 1700>,
      <1739, 1700, 762>,
      <1739, 762, 1146>,
      <1739, 1146, 1143>,
      <1739, 1143, 1740>,
      <1741, 1737, 1736>,
      <1741, 1736, 1740>,
      <1741, 1740, 1143>,
      <1741, 1143, 1142>,
      <1741, 1142, 1742>,
      <1741, 1742, 305>,
      <1741, 305, 302>,
      <1741, 302, 1737>,
      <1743, 1744, 1745>,
      <1743, 1745, 1746>,
      <1743, 1746, 1723>,
      <1743, 1723, 1722>,
      <1743, 1722, 1747>,
      <1743, 1747, 349>,
      <1743, 349, 348>,
      <1743, 348, 1744>,
      <1748, 1749, 1745>,
      <1748, 1745, 1744>,
      <1748, 1744, 348>,
      <1748, 348, 371>,
      <1748, 371, 1750>,
      <1748, 1750, 1131>,
      <1748, 1131, 1130>,
      <1748, 1130, 1749>,
      <1751, 1746, 1745>,
      <1751, 1745, 1749>,
      <1751, 1749, 1130>,
      <1751, 1130, 1148>,
      <1751, 1148, 757>,
      <1751, 757, 1726>,
      <1751, 1726, 1723>,
      <1751, 1723, 1746>,
      <1752, 1753, 1754>,
      <1752, 1754, 1755>,
      <1752, 1755, 1756>,
      <1752, 1756, 1757>,
      <1752, 1757, 1758>,
      <1752, 1758, 548>,
      <1752, 548, 547>,
      <1752, 547, 1753>,
      <1759, 1760, 1754>,
      <1759, 1754, 1753>,
      <1759, 1753, 547>,
      <1759, 547, 567>,
      <1759, 567, 1761>,
      <1759, 1761, 1223>,
      <1759, 1223, 1222>,
      <1759, 1222, 1760>,
      <1762, 1755, 1754>,
      <1762, 1754, 1760>,
      <1762, 1760, 1222>,
      <1762, 1222, 1240>,
      <1762, 1240, 937>,
      <1762, 937, 1763>,
      <1762, 1763, 1756>,
      <1762, 1756, 1755>,
      <1764, 1765, 1766>,
      <1764, 1766, 1767>,
      <1764, 1767, 498>,
      <1764, 498, 497>,
      <1764, 497, 1768>,
      <1764, 1768, 1769>,
      <1764, 1769, 1770>,
      <1764, 1770, 1765>,
      <1771, 1772, 1766>,
      <1771, 1766, 1765>,
      <1771, 1765, 1770>,
      <1771, 1770, 1773>,
      <1771, 1773, 914>,
      <1771, 914, 1238>,
      <1771, 1238, 1235>,
      <1771, 1235, 1772>,
      <1774, 1767, 1766>,
      <1774, 1766, 1772>,
      <1774, 1772, 1235>,
      <1774, 1235, 1234>,
      <1774, 1234, 1775>,
      <1774, 1775, 501>,
      <1774, 501, 498>,
      <1774, 498, 1767>,
      <1776, 1777, 1778>,
      <1776, 1778, 1779>,
      <1776, 1779, 1780>,
      <1776, 1780, 1781>,
      <1776, 1782, 1783>,
      <1776, 1783, 1757>,
      <1776, 1757, 1756>,
      <1776, 1756, 1777>,
      <1784, 1785, 1778>,
      <1784, 1778, 1777>,
      <1784, 1777, 1756>,
      <1784, 1756, 1763>,
      <1784, 1763, 937>,
      <1784, 937, 1786>,
      <1784, 1787, 1788>,
      <1784, 1788, 1785>,
      <1789, 1790, 1778>,
      <1789, 1778, 1785>,
      <1789, 1785, 1791>,
      <1789, 1791, 1792>,
      <1789, 1793, 929>,
      <1789, 929, 1794>,
      <1789, 1794, 1795>,
      <1789, 1795, 1790>,
      <1796, 1779, 1778>,
      <1796, 1778, 1790>,
      <1796, 1790, 1795>,
      <1796, 1795, 1797>,
      <1796, 1797, 1798>,
      <1796, 1798, 1799>,
      <1796, 1800, 1801>,
      <1796, 1801, 1779>,
      <1802, 1803, 1804>,
      <1802, 1804, 1805>,
      <1802, 1805, 1770>,
      <1802, 1770, 1769>,
      <1802, 1769, 1806>,
      <1802, 1806, 1807>,
      <1802, 1808, 1809>,
      <1802, 1809, 1803>,
      <1810, 1811, 1804>,
      <1810, 1804, 1803>,
      <1810, 1803, 1812>,
      <1810, 1812, 1813>,
      <1810, 1814, 1815>,
      <1810, 1815, 1816>,
      <1810, 1816, 1817>,
      <1810, 1817, 1811>,
      <1818, 1819, 1804>,
      <1818, 1804, 1811>,
      <1818, 1811, 1817>,
      <1818, 1817, 1820>,
      <1818, 1820, 923>,
      <1818, 923, 1821>,
      <1818, 1822, 1823>,
      <1818, 1823, 1819>,
      <1824, 1805, 1804>,
      <1824, 1804, 1819>,
      <1824, 1819, 1825>,
      <1824, 1825, 1826>,
      <1824, 1827, 914>,
      <1824, 914, 1773>,
      <1824, 1773, 1770>,
      <1824, 1770, 1805>,
      <1828, 1829, 1830>,
      <1828, 1830, 1831>,
      <1828, 1831, 585>,
      <1828, 585, 584>,
      <1828, 584, 1832>,
      <1828, 1832, 1797>,
      <1828, 1797, 1795>,
      <1828, 1795, 1829>,
      <1833, 1834, 1830>,
      <1833, 1830, 1829>,
      <1833, 1829, 1795>,
      <1833, 1795, 1794>,
      <1833, 1794, 929>,
      <1833, 929, 1215>,
      <1833, 1215, 1212>,
      <1833, 1212, 1834>,
      <1835, 1831, 1830>,
      <1835, 1830, 1834>,
      <1835, 1834, 1212>,
      <1835, 1212, 1211>,
      <1835, 1211, 1836>,
      <1835, 1836, 588>,
      <1835, 588, 585>,
      <1835, 585, 1831>,
      <1837, 1838, 1839>,
      <1837, 1839, 1840>,
      <1837, 1840, 1817>,
      <1837, 1817, 1816>,
      <1837, 1816, 1841>,
      <1837, 1841, 517>,
      <1837, 517, 516>,
      <1837, 516, 1838>,
      <1842, 1843, 1839>,
      <1842, 1839, 1838>,
      <1842, 1838, 516>,
      <1842, 516, 542>,
      <1842, 542, 1844>,
      <1842, 1844, 1200>,
      <1842, 1200, 1199>,
      <1842, 1199, 1843>,
      <1845, 1840, 1839>,
      <1845, 1839, 1843>,
      <1845, 1843, 1199>,
      <1845, 1199, 1217>,
      <1845, 1217, 923>,
      <1845, 923, 1820>,
      <1845, 1820, 1817>,
      <1845, 1817, 1840>
    }
    uv_indices {
      2344,   // from 0 triangles and 1172 quads
      <194, 202, 195>,
      <194, 195, 199>      <194, 199, 196>,
      <194, 196, 200>      <194, 200, 197>,
      <194, 197, 201>      <194, 201, 198>,
      <194, 198, 202>      <203, 211, 204>,
      <203, 204, 208>      <203, 208, 205>,
      <203, 205, 209>      <203, 209, 206>,
      <203, 206, 210>      <203, 210, 207>,
      <203, 207, 211>      <212, 220, 213>,
      <212, 213, 217>      <212, 217, 214>,
      <212, 214, 218>      <212, 218, 215>,
      <212, 215, 219>      <212, 219, 216>,
      <212, 216, 220>      <221, 229, 222>,
      <221, 222, 226>      <221, 226, 223>,
      <221, 223, 227>      <221, 227, 224>,
      <221, 224, 228>      <221, 228, 225>,
      <221, 225, 229>      <230, 238, 231>,
      <230, 231, 235>      <230, 235, 232>,
      <230, 232, 236>      <230, 236, 233>,
      <230, 233, 237>      <230, 237, 234>,
      <230, 234, 238>      <239, 247, 240>,
      <239, 240, 244>      <239, 244, 241>,
      <239, 241, 245>      <239, 245, 242>,
      <239, 242, 246>      <239, 246, 243>,
      <239, 243, 247>      <248, 256, 249>,
      <248, 249, 253>      <248, 253, 250>,
      <248, 250, 254>      <248, 254, 251>,
      <248, 251, 255>      <248, 255, 252>,
      <248, 252, 256>      <257, 265, 258>,
      <257, 258, 262>      <257, 262, 259>,
      <257, 259, 263>      <257, 263, 260>,
      <257, 260, 264>      <257, 264, 261>,
      <257, 261, 265>      <266, 274, 267>,
      <266, 267, 271>      <266, 271, 268>,
      <266, 268, 272>      <266, 272, 269>,
      <266, 269, 273>      <266, 273, 270>,
      <266, 270, 274>      <275, 283, 276>,
      <275, 276, 280>      <275, 280, 277>,
      <275, 277, 281>      <275, 281, 278>,
      <275, 278, 282>      <275, 282, 279>,
      <275, 279, 283>      <284, 292, 285>,
      <284, 285, 289>      <284, 289, 286>,
      <284, 286, 290>      <284, 290, 287>,
      <284, 287, 291>      <284, 291, 288>,
      <284, 288, 292>      <293, 301, 294>,
      <293, 294, 298>      <293, 298, 295>,
      <293, 295, 299>      <293, 299, 296>,
      <293, 296, 300>      <293, 300, 297>,
      <293, 297, 301>      <302, 310, 303>,
      <302, 303, 307>      <302, 307, 304>,
      <302, 304, 308>      <302, 308, 305>,
      <302, 305, 309>      <302, 309, 306>,
      <302, 306, 310>      <311, 319, 312>,
      <311, 312, 316>      <311, 316, 313>,
      <311, 313, 317>      <311, 317, 314>,
      <311, 314, 318>      <311, 318, 315>,
      <311, 315, 319>      <320, 328, 321>,
      <320, 321, 325>      <320, 325, 322>,
      <320, 322, 326>      <320, 326, 323>,
      <320, 323, 327>      <320, 327, 324>,
      <320, 324, 328>      <329, 337, 330>,
      <329, 330, 334>      <329, 334, 331>,
      <329, 331, 335>      <329, 335, 332>,
      <329, 332, 336>      <329, 336, 333>,
      <329, 333, 337>      <338, 346, 339>,
      <338, 339, 343>      <338, 343, 340>,
      <338, 340, 344>      <338, 344, 341>,
      <338, 341, 345>      <338, 345, 342>,
      <338, 342, 346>      <347, 355, 348>,
      <347, 348, 352>      <347, 352, 349>,
      <347, 349, 353>      <347, 353, 350>,
      <347, 350, 354>      <347, 354, 351>,
      <347, 351, 355>      <356, 364, 357>,
      <356, 357, 361>      <356, 361, 358>,
      <356, 358, 362>      <356, 362, 359>,
      <356, 359, 363>      <356, 363, 360>,
      <356, 360, 364>      <365, 373, 366>,
      <365, 366, 370>      <365, 370, 367>,
      <365, 367, 371>      <365, 371, 368>,
      <365, 368, 372>      <365, 372, 369>,
      <365, 369, 373>      <374, 382, 375>,
      <374, 375, 379>      <374, 379, 376>,
      <374, 376, 380>      <374, 380, 377>,
      <374, 377, 381>      <374, 381, 378>,
      <374, 378, 382>      <383, 391, 384>,
      <383, 384, 388>      <383, 388, 385>,
      <383, 385, 389>      <383, 389, 386>,
      <383, 386, 390>      <383, 390, 387>,
      <383, 387, 391>      <392, 400, 393>,
      <392, 393, 397>      <392, 397, 394>,
      <392, 394, 398>      <392, 398, 395>,
      <392, 395, 399>      <392, 399, 396>,
      <392, 396, 400>      <401, 409, 402>,
      <401, 402, 406>      <401, 406, 403>,
      <401, 403, 407>      <401, 407, 404>,
      <401, 404, 408>      <401, 408, 405>,
      <401, 405, 409>      <410, 418, 411>,
      <410, 411, 415>      <410, 415, 412>,
      <410, 412, 416>      <410, 416, 413>,
      <410, 413, 417>      <410, 417, 414>,
      <410, 414, 418>      <419, 427, 420>,
      <419, 420, 424>      <419, 424, 421>,
      <419, 421, 425>      <419, 425, 422>,
      <419, 422, 426>      <419, 426, 423>,
      <419, 423, 427>      <428, 436, 429>,
      <428, 429, 433>      <428, 433, 430>,
      <428, 430, 434>      <428, 434, 431>,
      <428, 431, 435>      <428, 435, 432>,
      <428, 432, 436>      <437, 445, 438>,
      <437, 438, 442>      <437, 442, 439>,
      <437, 439, 443>      <437, 443, 440>,
      <437, 440, 444>      <437, 444, 441>,
      <437, 441, 445>      <446, 454, 447>,
      <446, 447, 451>      <446, 451, 448>,
      <446, 448, 452>      <446, 452, 449>,
      <446, 449, 453>      <446, 453, 450>,
      <446, 450, 454>      <455, 463, 456>,
      <455, 456, 460>      <455, 460, 457>,
      <455, 457, 461>      <455, 461, 458>,
      <455, 458, 462>      <455, 462, 459>,
      <455, 459, 463>      <464, 472, 465>,
      <464, 465, 469>      <464, 469, 466>,
      <464, 466, 470>      <464, 470, 467>,
      <464, 467, 471>      <464, 471, 468>,
      <464, 468, 472>      <473, 481, 474>,
      <473, 474, 478>      <473, 478, 475>,
      <473, 475, 479>      <473, 479, 476>,
      <473, 476, 480>      <473, 480, 477>,
      <473, 477, 481>      <482, 490, 483>,
      <482, 483, 487>      <482, 487, 484>,
      <482, 484, 488>      <482, 488, 485>,
      <482, 485, 489>      <482, 489, 486>,
      <482, 486, 490>      <491, 499, 492>,
      <491, 492, 496>      <491, 496, 493>,
      <491, 493, 497>      <491, 497, 494>,
      <491, 494, 498>      <491, 498, 495>,
      <491, 495, 499>      <500, 508, 501>,
      <500, 501, 505>      <500, 505, 502>,
      <500, 502, 506>      <500, 506, 503>,
      <500, 503, 507>      <500, 507, 504>,
      <500, 504, 508>      <509, 517, 510>,
      <509, 510, 514>      <509, 514, 511>,
      <509, 511, 515>      <509, 515, 512>,
      <509, 512, 516>      <509, 516, 513>,
      <509, 513, 517>      <518, 526, 519>,
      <518, 519, 523>      <518, 523, 520>,
      <518, 520, 524>      <518, 524, 521>,
      <518, 521, 525>      <518, 525, 522>,
      <518, 522, 526>      <527, 535, 528>,
      <527, 528, 532>      <527, 532, 529>,
      <527, 529, 533>      <527, 533, 530>,
      <527, 530, 534>      <527, 534, 531>,
      <527, 531, 535>      <536, 544, 537>,
      <536, 537, 541>      <536, 541, 538>,
      <536, 538, 542>      <536, 542, 539>,
      <536, 539, 543>      <536, 543, 540>,
      <536, 540, 544>      <545, 553, 546>,
      <545, 546, 550>      <545, 550, 547>,
      <545, 547, 551>      <545, 551, 548>,
      <545, 548, 552>      <545, 552, 549>,
      <545, 549, 553>      <554, 562, 555>,
      <554, 555, 559>      <554, 559, 556>,
      <554, 556, 560>      <554, 560, 557>,
      <554, 557, 561>      <554, 561, 558>,
      <554, 558, 562>      <563, 571, 564>,
      <563, 564, 568>      <563, 568, 565>,
      <563, 565, 569>      <563, 569, 566>,
      <563, 566, 570>      <563, 570, 567>,
      <563, 567, 571>      <572, 580, 573>,
      <572, 573, 577>      <572, 577, 574>,
      <572, 574, 578>      <572, 578, 575>,
      <572, 575, 579>      <572, 579, 576>,
      <572, 576, 580>      <581, 589, 582>,
      <581, 582, 586>      <581, 586, 583>,
      <581, 583, 587>      <581, 587, 584>,
      <581, 584, 588>      <581, 588, 585>,
      <581, 585, 589>      <590, 598, 591>,
      <590, 591, 595>      <590, 595, 592>,
      <590, 592, 596>      <590, 596, 593>,
      <590, 593, 597>      <590, 597, 594>,
      <590, 594, 598>      <599, 607, 600>,
      <599, 600, 604>      <599, 604, 601>,
      <599, 601, 605>      <599, 605, 602>,
      <599, 602, 606>      <599, 606, 603>,
      <599, 603, 607>      <608, 616, 609>,
      <608, 609, 613>      <608, 613, 610>,
      <608, 610, 614>      <608, 614, 611>,
      <608, 611, 615>      <608, 615, 612>,
      <608, 612, 616>      <617, 625, 618>,
      <617, 618, 622>      <617, 622, 619>,
      <617, 619, 623>      <617, 623, 620>,
      <617, 620, 624>      <617, 624, 621>,
      <617, 621, 625>      <626, 634, 627>,
      <626, 627, 631>      <626, 631, 628>,
      <626, 628, 632>      <626, 632, 629>,
      <626, 629, 633>      <626, 633, 630>,
      <626, 630, 634>      <635, 643, 636>,
      <635, 636, 640>      <635, 640, 637>,
      <635, 637, 641>      <635, 641, 638>,
      <635, 638, 642>      <635, 642, 639>,
      <635, 639, 643>      <644, 652, 645>,
      <644, 645, 649>      <644, 649, 646>,
      <644, 646, 650>      <644, 650, 647>,
      <644, 647, 651>      <644, 651, 648>,
      <644, 648, 652>      <653, 661, 654>,
      <653, 654, 658>      <653, 658, 655>,
      <653, 655, 659>      <653, 659, 656>,
      <653, 656, 660>      <653, 660, 657>,
      <653, 657, 661>      <662, 670, 663>,
      <662, 663, 667>      <662, 667, 664>,
      <662, 664, 668>      <662, 668, 665>,
      <662, 665, 669>      <662, 669, 666>,
      <662, 666, 670>      <671, 679, 672>,
      <671, 672, 676>      <671, 676, 673>,
      <671, 673, 677>      <671, 677, 674>,
      <671, 674, 678>      <671, 678, 675>,
      <671, 675, 679>      <680, 688, 681>,
      <680, 681, 685>      <680, 685, 682>,
      <680, 682, 686>      <680, 686, 683>,
      <680, 683, 687>      <680, 687, 684>,
      <680, 684, 688>      <689, 697, 690>,
      <689, 690, 694>      <689, 694, 691>,
      <689, 691, 695>      <689, 695, 692>,
      <689, 692, 696>      <689, 696, 693>,
      <689, 693, 697>      <698, 706, 699>,
      <698, 699, 703>      <698, 703, 700>,
      <698, 700, 704>      <698, 704, 701>,
      <698, 701, 705>      <698, 705, 702>,
      <698, 702, 706>      <707, 715, 708>,
      <707, 708, 712>      <707, 712, 709>,
      <707, 709, 713>      <707, 713, 710>,
      <707, 710, 714>      <707, 714, 711>,
      <707, 711, 715>      <716, 724, 717>,
      <716, 717, 721>      <716, 721, 718>,
      <716, 718, 722>      <716, 722, 719>,
      <716, 719, 723>      <716, 723, 720>,
      <716, 720, 724>      <725, 733, 726>,
      <725, 726, 730>      <725, 730, 727>,
      <725, 727, 731>      <725, 731, 728>,
      <725, 728, 732>      <725, 732, 729>,
      <725, 729, 733>      <734, 742, 735>,
      <734, 735, 739>      <734, 739, 736>,
      <734, 736, 740>      <734, 740, 737>,
      <734, 737, 741>      <734, 741, 738>,
      <734, 738, 742>      <743, 751, 744>,
      <743, 744, 748>      <743, 748, 745>,
      <743, 745, 749>      <743, 749, 746>,
      <743, 746, 750>      <743, 750, 747>,
      <743, 747, 751>      <752, 760, 753>,
      <752, 753, 757>      <752, 757, 754>,
      <752, 754, 758>      <752, 758, 755>,
      <752, 755, 759>      <752, 759, 756>,
      <752, 756, 760>      <761, 769, 762>,
      <761, 762, 766>      <761, 766, 763>,
      <761, 763, 767>      <761, 767, 764>,
      <761, 764, 768>      <761, 768, 765>,
      <761, 765, 769>      <770, 778, 771>,
      <770, 771, 775>      <770, 775, 772>,
      <770, 772, 776>      <770, 776, 773>,
      <770, 773, 777>      <770, 777, 774>,
      <770, 774, 778>      <779, 787, 780>,
      <779, 780, 784>      <779, 784, 781>,
      <779, 781, 785>      <779, 785, 782>,
      <779, 782, 786>      <779, 786, 783>,
      <779, 783, 787>      <788, 796, 789>,
      <788, 789, 793>      <788, 793, 790>,
      <788, 790, 794>      <788, 794, 791>,
      <788, 791, 795>      <788, 795, 792>,
      <788, 792, 796>      <797, 805, 798>,
      <797, 798, 802>      <797, 802, 799>,
      <797, 799, 803>      <797, 803, 800>,
      <797, 800, 804>      <797, 804, 801>,
      <797, 801, 805>      <806, 814, 807>,
      <806, 807, 811>      <806, 811, 808>,
      <806, 808, 812>      <806, 812, 809>,
      <806, 809, 813>      <806, 813, 810>,
      <806, 810, 814>      <815, 823, 816>,
      <815, 816, 820>      <815, 820, 817>,
      <815, 817, 821>      <815, 821, 818>,
      <815, 818, 822>      <815, 822, 819>,
      <815, 819, 823>      <824, 832, 825>,
      <824, 825, 829>      <824, 829, 826>,
      <824, 826, 830>      <824, 830, 827>,
      <824, 827, 831>      <824, 831, 828>,
      <824, 828, 832>      <833, 841, 834>,
      <833, 834, 838>      <833, 838, 835>,
      <833, 835, 839>      <833, 839, 836>,
      <833, 836, 840>      <833, 840, 837>,
      <833, 837, 841>      <842, 850, 843>,
      <842, 843, 847>      <842, 847, 844>,
      <842, 844, 848>      <842, 848, 845>,
      <842, 845, 849>      <842, 849, 846>,
      <842, 846, 850>      <851, 859, 852>,
      <851, 852, 856>      <851, 856, 853>,
      <851, 853, 857>      <851, 857, 854>,
      <851, 854, 858>      <851, 858, 855>,
      <851, 855, 859>      <860, 868, 861>,
      <860, 861, 865>      <860, 865, 862>,
      <860, 862, 866>      <860, 866, 863>,
      <860, 863, 867>      <860, 867, 864>,
      <860, 864, 868>      <869, 877, 870>,
      <869, 870, 874>      <869, 874, 871>,
      <869, 871, 875>      <869, 875, 872>,
      <869, 872, 876>      <869, 876, 873>,
      <869, 873, 877>      <878, 886, 879>,
      <878, 879, 883>      <878, 883, 880>,
      <878, 880, 884>      <878, 884, 881>,
      <878, 881, 885>      <878, 885, 882>,
      <878, 882, 886>      <887, 895, 888>,
      <887, 888, 892>      <887, 892, 889>,
      <887, 889, 893>      <887, 893, 890>,
      <887, 890, 894>      <887, 894, 891>,
      <887, 891, 895>      <896, 904, 897>,
      <896, 897, 901>      <896, 901, 898>,
      <896, 898, 902>      <896, 902, 899>,
      <896, 899, 903>      <896, 903, 900>,
      <896, 900, 904>      <905, 913, 906>,
      <905, 906, 910>      <905, 910, 907>,
      <905, 907, 911>      <905, 911, 908>,
      <905, 908, 912>      <905, 912, 909>,
      <905, 909, 913>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>
    }
    scale <0.2, 0.2, 0.184549>
    rotate 90.0*z
    translate  <2.304382, 0.0, 21.474063>
}

#declare Cube020 = object {
  box { // Cube020
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    scale <0.15, 0.2, 0.8>
    translate  <2.325583, -0.297419, 20.856516>
  }
}
#declare Element_rembarde_ciment = union {
  object { Pilier_rambarde }
  object { Main_courrante }
  object { TMesh014 }
  object { // TMesh015 -> TMesh014
    TMesh014
    translate  0.579626*y
  }
  object { // TMesh016 -> TMesh014
    TMesh014
    translate  -0.593264*y
  }
  box { // Cube023
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    scale <0.135831, 2.0, 0.132518>
    rotate -38.659809*y
    translate  <2.378632, 0.0, 21.169348>
  }
  box { // Cube022
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    scale <0.2, 2.0, 0.12>
    translate  <2.329947, 0.0, 21.091452>
  }
  object { // Cube021 -> Cube020
    Cube020
    translate  0.595847*y
  }
  object { Cube020 }
  material {
    texture { M_granite2 }
  }
  scale 1.25
  translate  2.851914*z
}


#declare Cube099 = object {
  box { // Cube099
    <-1, -1, -1>, <1, 1, 1>
    translate  1.0*z
    scale <0.3, -0.718224, 0.15504>
    translate  6.457526*z
  }
}
#declare Cube098 = object {
  box { // Cube098
    <-1, -1, -1>, <1, 1, 1>
    translate  1.0*z
    scale <0.3, -0.579385, 0.15504>
    translate  6.142884*z
  }
}
#declare TransSweep006 = prism {
  linear_sweep
  linear_spline
  -1.0,0.0
  5  // control points
  <0.002925, 0.34287>,
  <0.320044, 0.458217>,
  <0.320044, 0.711028>,
  <0.002925, 0.711028>,
  <0.002925, 0.34287>
  rotate -x*90
  translate  -0.5*z
  scale <1.0, 1.0, 0.6>
  rotate -90.0*y
  translate  7.714479*z
}
#declare TransSweep008 = prism {
  linear_sweep
  linear_spline
  -1.0,0.0
  5  // control points
  <0.002925, 0.113392>,
  <0.413535, 0.203241>,
  <0.413535, 0.490162>,
  <0.002925, 0.339541>,
  <0.002925, 0.113392>
  rotate -x*90
  translate  -0.5*z
  scale <1.0, 1.0, 0.6>
  rotate -90.0*y
  translate  7.714479*z
}
#declare Corbeau_plein = mesh2 {
    vertex_vectors {
      582,
      <-0.0005270, 0.2008676, 0.0007341>,
      <0.0005389, 0.4033991, 0.0007341>,
      <-0.0798317, 0.4038104, 0.0007341>,
      <-0.0808949, 0.2012814, 0.0007341>,
      <0.0000059, 0.3021333, 0.0007341>,
      <-0.0396464, 0.4036048, 0.0007341>,
      <-0.0803633, 0.3025459, 0.0007341>,
      <-0.0407110, 0.2010745, 0.0007341>,
      <-0.0401787, 0.3023396, 0.0007341>,
      <-0.0819581, -0.0012476, 0.0007341>,
      <-0.0015930, -0.0016640, 0.0007341>,
      <-0.0814265, 0.1000169, 0.0007341>,
      <-0.0417755, -0.0014558, 0.0007341>,
      <-0.0010600, 0.0996018, 0.0007341>,
      <-0.0412432, 0.0998093, 0.0007341>,
      <0.0787721, -0.0020804, 0.0007341>,
      <0.0798408, 0.2004537, 0.0007341>,
      <0.0385896, -0.0018722, 0.0007341>,
      <0.0793065, 0.0991867, 0.0007341>,
      <0.0396569, 0.2006606, 0.0007341>,
      <0.0391232, 0.0993942, 0.0007341>,
      <0.0809094, 0.4029878, 0.0007341>,
      <0.0803751, 0.3017208, 0.0007341>,
      <0.0407241, 0.4031935, 0.0007341>,
      <0.0401905, 0.3019271, 0.0007341>,
      <-0.0803135, 0.3395405, -0.4222001>,
      <-0.0799937, 0.4015750, -0.4227514>,
      <-0.0799984, 0.4015097, -0.4212282>,
      <-0.0802622, 0.3500150, -0.4212282>,
      <-0.0801536, 0.3705578, -0.4224757>,
      <-0.0799961, 0.4015424, -0.4219898>,
      <-0.0801303, 0.3757624, -0.4212282>,
      <-0.0802878, 0.3447778, -0.4217141>,
      <-0.0801420, 0.3731601, -0.4218520>,
      <-0.0805260, 0.2985203, -0.4212282>,
      <-0.0806332, 0.2775061, -0.4216488>,
      <-0.0803941, 0.3242676, -0.4212282>,
      <-0.0805796, 0.2880132, -0.4214385>,
      <-0.0804733, 0.3085233, -0.4219245>,
      <-0.0804337, 0.3163955, -0.4215763>,
      <-0.0807404, 0.2564919, -0.4220695>,
      <-0.0803647, 0.3290660, -0.4231721>,
      <-0.0806868, 0.2669990, -0.4218592>,
      <-0.0805526, 0.2927790, -0.4226208>,
      <-0.0803391, 0.3343033, -0.4226861>,
      <-0.0805130, 0.3006511, -0.4222726>,
      <-0.0799890, 0.4016402, -0.4242746>,
      <-0.0801768, 0.3653531, -0.4237233>,
      <-0.0799913, 0.4016076, -0.4235130>,
      <-0.0801652, 0.3679555, -0.4230995>,
      <-0.0001069, 0.2770900, -0.4216488>,
      <0.0000051, 0.2981042, -0.4212282>,
      <-0.0403700, 0.2772980, -0.4216488>,
      <-0.0402605, 0.2983122, -0.4212282>,
      <-0.0000509, 0.2875971, -0.4214385>,
      <-0.0403152, 0.2878051, -0.4214385>,
      <0.0805361, 0.2976881, -0.4212282>,
      <0.0804195, 0.2766739, -0.4216488>,
      <0.0402706, 0.2978962, -0.4212282>,
      <0.0804778, 0.2871810, -0.4214385>,
      <0.0401563, 0.2768819, -0.4216488>,
      <0.0402135, 0.2873890, -0.4214385>,
      <0.0803028, 0.2556596, -0.4220695>,
      <-0.0002188, 0.2560758, -0.4220695>,
      <0.0803612, 0.2661668, -0.4218592>,
      <0.0400420, 0.2558677, -0.4220695>,
      <-0.0001628, 0.2665829, -0.4218592>,
      <0.0400992, 0.2663748, -0.4218592>,
      <-0.0404796, 0.2562838, -0.4220695>,
      <-0.0404248, 0.2667909, -0.4218592>,
      <0.0807436, 0.3387124, -0.4222001>,
      <0.0808042, 0.3491869, -0.4212282>,
      <0.0805815, 0.3076931, -0.4219245>,
      <0.0806702, 0.3234375, -0.4212282>,
      <0.0807739, 0.3439496, -0.4217141>,
      <0.0806259, 0.3155653, -0.4215763>,
      <0.0810723, 0.4006856, -0.4212282>,
      <0.0810677, 0.4007509, -0.4227514>,
      <0.0809383, 0.3749362, -0.4212282>,
      <0.0810700, 0.4007183, -0.4219898>,
      <0.0809057, 0.3697317, -0.4224757>,
      <0.0809220, 0.3723339, -0.4218520>,
      <0.0810631, 0.4008162, -0.4242746>,
      <0.0806830, 0.3282379, -0.4231721>,
      <0.0810654, 0.4007836, -0.4235130>,
      <0.0808730, 0.3645271, -0.4237233>,
      <0.0807133, 0.3334752, -0.4226861>,
      <0.0808893, 0.3671294, -0.4230995>,
      <0.0804929, 0.2919488, -0.4226208>,
      <0.0805372, 0.2998210, -0.4222726>,
      <-0.0803539, 0.3293346, -0.4053495>,
      <-0.0799791, 0.4017763, -0.4059008>,
      <-0.0801665, 0.3655555, -0.4056252>,
      <-0.0799840, 0.4017083, -0.4150877>,
      <-0.0803593, 0.3292003, -0.4142608>,
      <-0.0801717, 0.3654543, -0.4146742>,
      <-0.0807286, 0.2568930, -0.4047982>,
      <-0.0807345, 0.2566924, -0.4134339>,
      <-0.0805412, 0.2931138, -0.4050739>,
      <-0.0805469, 0.2929464, -0.4138473>,
      <-0.0807168, 0.2572941, -0.3875270>,
      <-0.0803430, 0.3296032, -0.3875270>,
      <-0.0807227, 0.2570936, -0.3961626>,
      <-0.0805299, 0.2934487, -0.3875270>,
      <-0.0803484, 0.3294689, -0.3964383>,
      <-0.0805356, 0.2932812, -0.3963004>,
      <-0.0799693, 0.4019124, -0.3875270>,
      <-0.0801561, 0.3657578, -0.3875270>,
      <-0.0799742, 0.4018443, -0.3967139>,
      <-0.0801613, 0.3656566, -0.3965761>,
      <-0.0002168, 0.2564769, -0.4047982>,
      <-0.0404727, 0.2566849, -0.4047982>,
      <-0.0002178, 0.2562763, -0.4134339>,
      <-0.0404762, 0.2564844, -0.4134339>,
      <0.0802950, 0.2560607, -0.4047982>,
      <0.0802989, 0.2558602, -0.4134339>,
      <0.0400391, 0.2562688, -0.4047982>,
      <0.0400406, 0.2560683, -0.4134339>,
      <0.0802872, 0.2564618, -0.3875270>,
      <-0.0002148, 0.2568780, -0.3875270>,
      <0.0802911, 0.2562613, -0.3961626>,
      <0.0400362, 0.2566699, -0.3875270>,
      <-0.0002158, 0.2566774, -0.3961626>,
      <0.0400377, 0.2564694, -0.3961626>,
      <-0.0404658, 0.2570860, -0.3875270>,
      <-0.0404692, 0.2568855, -0.3961626>,
      <0.0806742, 0.3285066, -0.4053495>,
      <0.0804846, 0.2922836, -0.4050739>,
      <0.0806786, 0.3283722, -0.4142608>,
      <0.0804888, 0.2921162, -0.4138473>,
      <0.0810534, 0.4009524, -0.4059008>,
      <0.0810583, 0.4008843, -0.4150877>,
      <0.0808638, 0.3647295, -0.4056252>,
      <0.0808684, 0.3646283, -0.4146742>,
      <0.0810438, 0.4010885, -0.3875270>,
      <0.0806655, 0.3287752, -0.3875270>,
      <0.0810486, 0.4010204, -0.3967139>,
      <0.0808547, 0.3649318, -0.3875270>,
      <0.0806699, 0.3286409, -0.3964383>,
      <0.0808593, 0.3648307, -0.3965761>,
      <0.0804764, 0.2926185, -0.3875270>,
      <0.0804805, 0.2924511, -0.3963004>,
      <-0.0803624, 0.3247152, -0.3856107>,
      <-0.0799623, 0.4020088, -0.3856107>,
      <-0.0801623, 0.3633620, -0.3856107>,
      <-0.0799658, 0.4019606, -0.3865689>,
      <-0.0803527, 0.3271592, -0.3865689>,
      <-0.0801592, 0.3645599, -0.3865689>,
      <-0.0807625, 0.2474216, -0.3856107>,
      <-0.0807396, 0.2523578, -0.3865689>,
      <-0.0805624, 0.2860684, -0.3856107>,
      <-0.0805462, 0.2897585, -0.3865689>,
      <-0.0808082, 0.2375490, -0.3836945>,
      <-0.0803817, 0.3198271, -0.3836945>,
      <-0.0807853, 0.2424853, -0.3846526>,
      <-0.0805950, 0.2786881, -0.3836945>,
      <-0.0803721, 0.3222711, -0.3846526>,
      <-0.0805787, 0.2823782, -0.3846526>,
      <-0.0799553, 0.4021052, -0.3836945>,
      <-0.0801685, 0.3609662, -0.3836945>,
      <-0.0799588, 0.4020570, -0.3846526>,
      <-0.0801654, 0.3621641, -0.3846526>,
      <-0.0002674, 0.2470054, -0.3856107>,
      <-0.0405150, 0.2472135, -0.3856107>,
      <-0.0002411, 0.2519417, -0.3865689>,
      <-0.0404904, 0.2521498, -0.3865689>,
      <0.0802276, 0.2465893, -0.3856107>,
      <0.0802574, 0.2515256, -0.3865689>,
      <0.0399801, 0.2467973, -0.3856107>,
      <0.0400082, 0.2517336, -0.3865689>,
      <0.0801680, 0.2367167, -0.3836945>,
      <-0.0003201, 0.2371328, -0.3836945>,
      <0.0801978, 0.2416530, -0.3846526>,
      <0.0399240, 0.2369248, -0.3836945>,
      <-0.0002937, 0.2420691, -0.3846526>,
      <0.0399520, 0.2418610, -0.3846526>,
      <-0.0405641, 0.2373409, -0.3836945>,
      <-0.0405395, 0.2422772, -0.3846526>,
      <0.0806323, 0.3238871, -0.3856107>,
      <0.0804300, 0.2852382, -0.3856107>,
      <0.0806489, 0.3263312, -0.3865689>,
      <0.0804532, 0.2889284, -0.3865689>,
      <0.0810370, 0.4011850, -0.3856107>,
      <0.0810404, 0.4011368, -0.3865689>,
      <0.0808346, 0.3625361, -0.3856107>,
      <0.0808447, 0.3637340, -0.3865689>,
      <0.0810302, 0.4012815, -0.3836945>,
      <0.0805991, 0.3189991, -0.3836945>,
      <0.0810336, 0.4012332, -0.3846526>,
      <0.0808146, 0.3601403, -0.3836945>,
      <0.0806157, 0.3214431, -0.3846526>,
      <0.0808246, 0.3613382, -0.3846526>,
      <0.0803836, 0.2778579, -0.3836945>,
      <0.0804068, 0.2815480, -0.3846526>,
      <-0.0803888, 0.2926490, -0.3504076>,
      <-0.0799552, 0.4024991, -0.3498433>,
      <-0.0801719, 0.3475738, -0.3500140>,
      <-0.0799553, 0.4023021, -0.3667689>,
      <-0.0803818, 0.3058280, -0.3678888>,
      <-0.0801685, 0.3540650, -0.3673288>,
      <-0.0808235, 0.1828021, -0.3523091>,
      <-0.0808083, 0.2093538, -0.3690087>,
      <-0.0806061, 0.2377253, -0.3512469>,
      <-0.0805951, 0.2575909, -0.3684488>,
      <-0.0809589, 0.1412035, -0.3048134>,
      <-0.0804508, 0.2720305, -0.3028251>,
      <-0.0808687, 0.1595375, -0.3315820>,
      <-0.0807043, 0.2066155, -0.3031506>,
      <-0.0804097, 0.2811105, -0.3295754>,
      <-0.0806388, 0.2203230, -0.3301329>,
      <-0.0799552, 0.4028929, -0.3159921>,
      <-0.0801995, 0.3374518, -0.3051740>,
      <-0.0799552, 0.4026960, -0.3329177>,
      <-0.0801821, 0.3419022, -0.3308008>,
      <-0.0003369, 0.1823859, -0.3523091>,
      <-0.0405802, 0.1825940, -0.3523091>,
      <-0.0003202, 0.2089376, -0.3690087>,
      <-0.0405643, 0.2091457, -0.3690087>,
      <0.0801497, 0.1819698, -0.3523091>,
      <0.0801678, 0.2085215, -0.3690087>,
      <0.0399064, 0.1821779, -0.3523091>,
      <0.0399238, 0.2087295, -0.3690087>,
      <0.0799877, 0.1403711, -0.3048134>,
      <-0.0004856, 0.1407873, -0.3048134>,
      <0.0800956, 0.1587052, -0.3315820>,
      <0.0397510, 0.1405792, -0.3048134>,
      <-0.0003865, 0.1591213, -0.3315820>,
      <0.0398545, 0.1589133, -0.3315820>,
      <-0.0407223, 0.1409954, -0.3048134>,
      <-0.0406276, 0.1593294, -0.3315820>,
      <0.0805894, 0.2918210, -0.3504076>,
      <0.0803694, 0.2368951, -0.3512469>,
      <0.0805990, 0.3049999, -0.3678888>,
      <0.0803834, 0.2567607, -0.3684488>,
      <0.0810301, 0.4016753, -0.3498433>,
      <0.0810301, 0.4014784, -0.3667689>,
      <0.0808096, 0.3467479, -0.3500140>,
      <0.0808146, 0.3532392, -0.3673288>,
      <0.0810301, 0.4020691, -0.3159921>,
      <0.0805027, 0.2712025, -0.3028251>,
      <0.0810301, 0.4018722, -0.3329177>,
      <0.0807630, 0.3366260, -0.3051740>,
      <0.0805607, 0.2802825, -0.3295754>,
      <0.0807950, 0.3410763, -0.3308008>,
      <0.0802446, 0.2057853, -0.3031506>,
      <0.0803278, 0.2194928, -0.3301329>,
      <-0.0805989, 0.2622808, -0.2285252>,
      <-0.0799078, 0.4031536, -0.2250858>,
      <-0.0802533, 0.3327165, -0.2268417>,
      <-0.0799315, 0.4030232, -0.2705389>,
      <-0.0805181, 0.2662272, -0.2675898>,
      <-0.0802244, 0.3346242, -0.2686186>,
      <-0.0812900, 0.1214165, -0.2315294>,
      <-0.0811092, 0.1294437, -0.2699896>,
      <-0.0809444, 0.1918480, -0.2300635>,
      <-0.0808133, 0.1978344, -0.2683440>,
      <-0.0816247, 0.1051945, -0.1613744>,
      <-0.0807485, 0.2542739, -0.1578207>,
      <-0.0814717, 0.1142806, -0.1938514>,
      <-0.0811872, 0.1797315, -0.1604838>,
      <-0.0806800, 0.2587715, -0.1902869>,
      <-0.0810762, 0.1865243, -0.1926599>,
      <-0.0798604, 0.4034142, -0.1341794>,
      <-0.0803078, 0.3288270, -0.1516128>,
      <-0.0798841, 0.4032839, -0.1796326>,
      <-0.0802824, 0.3310259, -0.1855505>,
      <-0.0008492, 0.1210003, -0.2315294>,
      <-0.0410696, 0.1212084, -0.2315294>,
      <-0.0006507, 0.1290275, -0.2699896>,
      <-0.0408799, 0.1292356, -0.2699896>,
      <0.0795916, 0.1205840, -0.2315294>,
      <0.0798079, 0.1286113, -0.2699896>,
      <0.0393712, 0.1207922, -0.2315294>,
      <0.0395786, 0.1288194, -0.2699896>,
      <0.0791907, 0.1043619, -0.1613744>,
      <-0.0012170, 0.1047782, -0.1613744>,
      <0.0793741, 0.1134481, -0.1938514>,
      <0.0389869, 0.1045700, -0.1613744>,
      <-0.0010488, 0.1138643, -0.1938514>,
      <0.0391626, 0.1136562, -0.1938514>,
      <-0.0414208, 0.1049863, -0.1613744>,
      <-0.0412602, 0.1140725, -0.1938514>,
      <0.0802876, 0.2614529, -0.2285252>,
      <0.0799396, 0.1910178, -0.2300635>,
      <0.0804052, 0.2653993, -0.2675898>,
      <0.0801062, 0.1970042, -0.2683440>,
      <0.0809838, 0.4023303, -0.2250858>,
      <0.0810069, 0.4021997, -0.2705389>,
      <0.0806357, 0.3318909, -0.2268417>,
      <0.0807057, 0.3337984, -0.2686186>,
      <0.0809375, 0.4025914, -0.1341794>,
      <0.0800700, 0.2534461, -0.1578207>,
      <0.0809606, 0.4024608, -0.1796326>,
      <0.0805070, 0.3280017, -0.1516128>,
      <0.0801694, 0.2579437, -0.1902869>,
      <0.0805654, 0.3302004, -0.1855505>,
      <0.0796309, 0.1789013, -0.1604838>,
      <0.0797721, 0.1856941, -0.1926599>,
      <-0.0808149, 0.2386426, -0.1217721>,
      <-0.0798581, 0.4034455, -0.1188970>,
      <-0.0803366, 0.3210436, -0.1204822>,
      <-0.0798593, 0.4034299, -0.1265382>,
      <-0.0807915, 0.2473625, -0.1360726>,
      <-0.0803257, 0.3253944, -0.1318962>,
      <-0.0817706, 0.0738450, -0.1228747>,
      <-0.0817195, 0.0913166, -0.1385172>,
      <-0.0812928, 0.1562433, -0.1224711>,
      <-0.0812558, 0.1693378, -0.1378857>,
      <-0.0818000, 0.0329121, -0.1036145>,
      <-0.0808279, 0.2181945, -0.1036145>,
      <-0.0817925, 0.0539775, -0.1120421>,
      <-0.0813139, 0.1255533, -0.1036145>,
      <-0.0808248, 0.2287194, -0.1116489>,
      <-0.0813087, 0.1413484, -0.1118455>,
      <-0.0798559, 0.4034768, -0.1036145>,
      <-0.0803419, 0.3108357, -0.1036145>,
      <-0.0798570, 0.4034612, -0.1112557>,
      <-0.0803409, 0.3160903, -0.1114523>,
      <-0.0013777, 0.0734287, -0.1228747>,
      <-0.0415742, 0.0736368, -0.1228747>,
      <-0.0013213, 0.0909003, -0.1385172>,
      <-0.0415204, 0.0911085, -0.1385172>,
      <0.0790151, 0.0730123, -0.1228747>,
      <0.0790769, 0.0904840, -0.1385172>,
      <0.0388187, 0.0732205, -0.1228747>,
      <0.0388778, 0.0906921, -0.1385172>,
      <0.0789784, 0.0320795, -0.1036145>,
      <-0.0014108, 0.0324958, -0.1036145>,
      <0.0789880, 0.0531449, -0.1120421>,
      <0.0387838, 0.0322876, -0.1036145>,
      <-0.0014023, 0.0535612, -0.1120421>,
      <0.0387929, 0.0533530, -0.1120421>,
      <-0.0416054, 0.0327040, -0.1036145>,
      <-0.0415974, 0.0537694, -0.1120421>,
      <0.0799757, 0.2378148, -0.1217721>,
      <0.0794955, 0.1554131, -0.1224711>,
      <0.0800087, 0.2465347, -0.1360726>,
      <0.0795431, 0.1685076, -0.1378857>,
      <0.0809353, 0.4026227, -0.1188970>,
      <0.0809364, 0.4026070, -0.1265382>,
      <0.0804556, 0.3202183, -0.1204822>,
      <0.0804729, 0.3245691, -0.1318962>,
      <0.0809330, 0.4026540, -0.1036145>,
      <0.0799557, 0.2173667, -0.1036145>,
      <0.0809341, 0.4026383, -0.1112557>,
      <0.0804444, 0.3100104, -0.1036145>,
      <0.0799611, 0.2278916, -0.1116489>,
      <0.0804476, 0.3152650, -0.1114523>,
      <0.0794670, 0.1247231, -0.1036145>,
      <0.0794746, 0.1405182, -0.1118455>,
      <-0.0808614, 0.2097379, -0.1036145>,
      <-0.0798438, 0.4036436, -0.1036145>,
      <-0.0803526, 0.3066908, -0.1036145>,
      <-0.0798498, 0.4035602, -0.1036145>,
      <-0.0808447, 0.2139662, -0.1036145>,
      <-0.0803472, 0.3087632, -0.1036145>,
      <-0.0818790, 0.0158323, -0.1036145>,
      <-0.0818395, 0.0243722, -0.1036145>,
      <-0.0813702, 0.1127851, -0.1036145>,
      <-0.0813421, 0.1191692, -0.1036145>,
      <-0.0819581, -0.0012476, -0.1036145>,
      <-0.0808949, 0.2012814, -0.1036145>,
      <-0.0819185, 0.0072923, -0.1036145>,
      <-0.0814265, 0.1000169, -0.1036145>,
      <-0.0808781, 0.2055097, -0.1036145>,
      <-0.0813983, 0.1064010, -0.1036145>,
      <-0.0798317, 0.4038104, -0.1036145>,
      <-0.0803633, 0.3025459, -0.1036145>,
      <-0.0798377, 0.4037270, -0.1036145>,
      <-0.0803579, 0.3046184, -0.1036145>,
      <-0.0015019, 0.0154159, -0.1036145>,
      <-0.0416904, 0.0156241, -0.1036145>,
      <-0.0014563, 0.0239559, -0.1036145>,
      <-0.0416479, 0.0241640, -0.1036145>,
      <0.0788753, 0.0149995, -0.1036145>,
      <0.0789268, 0.0235395, -0.1036145>,
      <0.0386867, 0.0152077, -0.1036145>,
      <0.0387352, 0.0237477, -0.1036145>,
      <0.0787721, -0.0020804, -0.1036145>,
      <-0.0015930, -0.0016640, -0.1036145>,
      <0.0788237, 0.0064596, -0.1036145>,
      <0.0385896, -0.0018722, -0.1036145>,
      <-0.0015474, 0.0068759, -0.1036145>,
      <0.0386381, 0.0066678, -0.1036145>,
      <-0.0417755, -0.0014558, -0.1036145>,
      <-0.0417330, 0.0070841, -0.1036145>,
      <0.0798982, 0.2089102, -0.1036145>,
      <0.0793868, 0.1119549, -0.1036145>,
      <0.0799270, 0.2131385, -0.1036145>,
      <0.0794269, 0.1183390, -0.1036145>,
      <0.0809212, 0.4028209, -0.1036145>,
      <0.0809271, 0.4027374, -0.1036145>,
      <0.0804097, 0.3058656, -0.1036145>,
      <0.0804271, 0.3079380, -0.1036145>,
      <0.0809094, 0.4029878, -0.1036145>,
      <0.0798408, 0.2004537, -0.1036145>,
      <0.0809153, 0.4029044, -0.1036145>,
      <0.0803751, 0.3017208, -0.1036145>,
      <0.0798695, 0.2046820, -0.1036145>,
      <0.0803924, 0.3037932, -0.1036145>,
      <0.0793065, 0.0991867, -0.1036145>,
      <0.0793466, 0.1055708, -0.1036145>,
      <-0.0808949, 0.2012814, -0.0514402>,
      <-0.0798317, 0.4038104, -0.0514402>,
      <-0.0803633, 0.3025459, -0.0514402>,
      <-0.0798317, 0.4038104, -0.0775273>,
      <-0.0808949, 0.2012814, -0.0775273>,
      <-0.0803633, 0.3025459, -0.0775273>,
      <-0.0819581, -0.0012476, -0.0514402>,
      <-0.0819581, -0.0012476, -0.0775273>,
      <-0.0814265, 0.1000169, -0.0514402>,
      <-0.0814265, 0.1000169, -0.0775273>,
      <-0.0819581, -0.0012476, -0.0253530>,
      <-0.0808949, 0.2012814, -0.0253530>,
      <-0.0814265, 0.1000169, -0.0253530>,
      <-0.0798317, 0.4038104, -0.0253530>,
      <-0.0803633, 0.3025459, -0.0253530>,
      <-0.0015930, -0.0016640, -0.0514402>,
      <-0.0417755, -0.0014558, -0.0514402>,
      <-0.0015930, -0.0016640, -0.0775273>,
      <-0.0417755, -0.0014558, -0.0775273>,
      <0.0787721, -0.0020804, -0.0514402>,
      <0.0787721, -0.0020804, -0.0775273>,
      <0.0385896, -0.0018722, -0.0514402>,
      <0.0385896, -0.0018722, -0.0775273>,
      <0.0787721, -0.0020804, -0.0253530>,
      <-0.0015930, -0.0016640, -0.0253530>,
      <0.0385896, -0.0018722, -0.0253530>,
      <-0.0417755, -0.0014558, -0.0253530>,
      <0.0798408, 0.2004537, -0.0514402>,
      <0.0793065, 0.0991867, -0.0514402>,
      <0.0798408, 0.2004537, -0.0775273>,
      <0.0793065, 0.0991867, -0.0775273>,
      <0.0809094, 0.4029878, -0.0514402>,
      <0.0809094, 0.4029878, -0.0775273>,
      <0.0803751, 0.3017208, -0.0514402>,
      <0.0803751, 0.3017208, -0.0775273>,
      <0.0809094, 0.4029878, -0.0253530>,
      <0.0798408, 0.2004537, -0.0253530>,
      <0.0803751, 0.3017208, -0.0253530>,
      <0.0793065, 0.0991867, -0.0253530>,
      <0.0005389, 0.4033991, -0.0514402>,
      <-0.0798317, 0.4038104, -0.0514402>,
      <0.0005389, 0.4033991, -0.1036145>,
      <-0.0396464, 0.4036048, -0.0514402>,
      <-0.0798317, 0.4038104, -0.0775273>,
      <-0.0396464, 0.4036048, -0.1036145>,
      <0.0005389, 0.4033991, -0.0775273>,
      <-0.0396464, 0.4036048, -0.0775273>,
      <0.0809094, 0.4029878, -0.0514402>,
      <0.0407241, 0.4031935, -0.1036145>,
      <0.0809094, 0.4029878, -0.0775273>,
      <0.0407241, 0.4031935, -0.0514402>,
      <0.0407241, 0.4031935, -0.0775273>,
      <0.0005389, 0.4033991, 0.0007341>,
      <0.0809094, 0.4029878, -0.0253530>,
      <0.0407241, 0.4031935, 0.0007341>,
      <0.0005389, 0.4033991, -0.0253530>,
      <0.0407241, 0.4031935, -0.0253530>,
      <-0.0396464, 0.4036048, 0.0007341>,
      <-0.0798317, 0.4038104, -0.0253530>,
      <-0.0396464, 0.4036048, -0.0253530>,
      <0.0005387, 0.4032323, -0.1036145>,
      <0.0005386, 0.4030654, -0.1036145>,
      <0.0005387, 0.4031488, -0.1036145>,
      <-0.0396586, 0.4032711, -0.1036145>,
      <-0.0396525, 0.4034380, -0.1036145>,
      <-0.0396556, 0.4033545, -0.1036145>,
      <0.0005389, 0.4033991, -0.1036145>,
      <-0.0396464, 0.4036048, -0.1036145>,
      <0.0005388, 0.4033157, -0.1036145>,
      <-0.0396495, 0.4035214, -0.1036145>,
      <0.0407241, 0.4031935, -0.1036145>,
      <0.0407300, 0.4030266, -0.1036145>,
      <0.0407271, 0.4031100, -0.1036145>,
      <0.0407358, 0.4028597, -0.1036145>,
      <0.0407329, 0.4029431, -0.1036145>,
      <0.0005386, 0.4030341, -0.1188970>,
      <-0.0798581, 0.4034455, -0.1188970>,
      <0.0005385, 0.4030028, -0.1341794>,
      <-0.0396598, 0.4032398, -0.1188970>,
      <-0.0798593, 0.4034299, -0.1265382>,
      <-0.0396609, 0.4032085, -0.1341794>,
      <0.0005385, 0.4030185, -0.1265382>,
      <-0.0396604, 0.4032242, -0.1265382>,
      <0.0809353, 0.4026227, -0.1188970>,
      <0.0407380, 0.4027971, -0.1341794>,
      <0.0809364, 0.4026070, -0.1265382>,
      <0.0407369, 0.4028284, -0.1188970>,
      <0.0407375, 0.4028127, -0.1265382>,
      <0.0005386, 0.4030654, -0.1036145>,
      <0.0809341, 0.4026383, -0.1112557>,
      <0.0407358, 0.4028597, -0.1036145>,
      <0.0005386, 0.4030498, -0.1112557>,
      <0.0407364, 0.4028440, -0.1112557>,
      <-0.0396586, 0.4032711, -0.1036145>,
      <-0.0798570, 0.4034612, -0.1112557>,
      <-0.0396592, 0.4032555, -0.1112557>,
      <0.0005380, 0.4027419, -0.2250858>,
      <0.0005374, 0.4024810, -0.3159921>,
      <0.0005377, 0.4026115, -0.2705389>,
      <-0.0397089, 0.4026869, -0.3159921>,
      <-0.0396849, 0.4029477, -0.2250858>,
      <-0.0396969, 0.4028173, -0.2705389>,
      <0.0005385, 0.4030028, -0.1341794>,
      <-0.0396609, 0.4032085, -0.1341794>,
      <0.0005383, 0.4028724, -0.1796326>,
      <-0.0396729, 0.4030781, -0.1796326>,
      <0.0407380, 0.4027971, -0.1341794>,
      <0.0407609, 0.4025361, -0.2250858>,
      <0.0407494, 0.4026666, -0.1796326>,
      <0.0407838, 0.4022751, -0.3159921>,
      <0.0407723, 0.4024056, -0.2705389>,
      <0.0005374, 0.4020872, -0.3498433>,
      <-0.0799552, 0.4024991, -0.3498433>,
      <0.0005374, 0.4016934, -0.3836945>,
      <-0.0397089, 0.4022931, -0.3498433>,
      <-0.0799553, 0.4023021, -0.3667689>,
      <-0.0397089, 0.4018993, -0.3836945>,
      <0.0005374, 0.4018903, -0.3667689>,
      <-0.0397089, 0.4020962, -0.3667689>,
      <0.0810301, 0.4016753, -0.3498433>,
      <0.0407838, 0.4014874, -0.3836945>,
      <0.0810301, 0.4014784, -0.3667689>,
      <0.0407838, 0.4018813, -0.3498433>,
      <0.0407838, 0.4016843, -0.3667689>,
      <0.0005374, 0.4024810, -0.3159921>,
      <0.0810301, 0.4018722, -0.3329177>,
      <0.0407838, 0.4022751, -0.3159921>,
      <0.0005374, 0.4022841, -0.3329177>,
      <0.0407838, 0.4020782, -0.3329177>,
      <-0.0397089, 0.4026869, -0.3159921>,
      <-0.0799552, 0.4026960, -0.3329177>,
      <-0.0397089, 0.4024900, -0.3329177>,
      <0.0005374, 0.4015969, -0.3856107>,
      <0.0005373, 0.4015004, -0.3875270>,
      <0.0005373, 0.4015487, -0.3865689>,
      <-0.0397160, 0.4017064, -0.3875270>,
      <-0.0397125, 0.4018029, -0.3856107>,
      <-0.0397142, 0.4017546, -0.3865689>,
      <0.0005374, 0.4016934, -0.3836945>,
      <-0.0397089, 0.4018993, -0.3836945>,
      <0.0005374, 0.4016451, -0.3846526>,
      <-0.0397107, 0.4018511, -0.3846526>,
      <0.0407838, 0.4014874, -0.3836945>,
      <0.0407872, 0.4013910, -0.3856107>,
      <0.0407855, 0.4014392, -0.3846526>,
      <0.0407905, 0.4012945, -0.3875270>,
      <0.0407889, 0.4013427, -0.3865689>,
      <0.0005371, 0.4013053, -0.4040183>,
      <-0.0799838, 0.4017111, -0.4043776>,
      <0.0005370, 0.4011685, -0.4171568>,
      <-0.0397234, 0.4015092, -0.4041381>,
      <-0.0799911, 0.4016104, -0.4128029>,
      <-0.0397295, 0.4013620, -0.4178753>,
      <0.0005370, 0.4012234, -0.4113659>,
      <-0.0397270, 0.4014211, -0.4118449>,
      <0.0810581, 0.4008871, -0.4043776>,
      <0.0408035, 0.4009500, -0.4178753>,
      <0.0810652, 0.4007863, -0.4128029>,
      <0.0407976, 0.4010972, -0.4041381>,
      <0.0408011, 0.4010090, -0.4118449>,
      <0.0005373, 0.4015004, -0.3875270>,
      <0.0810509, 0.4009878, -0.3959523>,
      <0.0407905, 0.4012945, -0.3875270>,
      <0.0005372, 0.4013998, -0.3959523>,
      <0.0407941, 0.4011938, -0.3959523>,
      <-0.0397160, 0.4017064, -0.3875270>,
      <-0.0799766, 0.4018117, -0.3959523>,
      <-0.0397197, 0.4016057, -0.3959523>,
      <0.0005370, 0.4011692, -0.4223922>,
      <0.0005370, 0.4011553, -0.4205528>,
      <-0.0397284, 0.4013731, -0.4225119>,
      <-0.0397295, 0.4013530, -0.4210318>,
      <0.0005371, 0.4012282, -0.4242746>,
      <-0.0397260, 0.4014342, -0.4242746>,
      <0.0005370, 0.4011956, -0.4235130>,
      <-0.0397272, 0.4014016, -0.4235130>,
      <0.0408001, 0.4010222, -0.4242746>,
      <0.0408024, 0.4009611, -0.4225119>,
      <0.0408012, 0.4009896, -0.4235130>,
      <0.0408035, 0.4009410, -0.4210318>
    }
    normal_vectors {
      1158,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.9999831, -0.0051265, 0.0027423>,
      <0.9999837, -0.0051275, 0.0025295>,
      <0.9999835, -0.0051315, 0.0025724>,
      <0.9999830, -0.0051299, 0.0027564>,
      <0.9999827, -0.0051287, 0.0028851>,
      <0.9999827, -0.0051258, 0.0028852>,
      <0.9999827, -0.0051258, 0.0028852>,
      <0.9999827, -0.0051223, 0.0028854>,
      <0.9999832, -0.0051223, 0.0027247>,
      <0.9999832, -0.0051223, 0.0027247>,
      <0.9999838, -0.0051223, 0.0024728>,
      <0.9999845, -0.0051292, 0.0021789>,
      <0.9999842, -0.0051340, 0.0022878>,
      <0.9999838, -0.0051223, 0.0024728>,
      <0.9999848, -0.0051223, 0.0020215>,
      <0.9999848, -0.0051223, 0.0020215>,
      <0.9999864, -0.0051223, 0.0009789>,
      <0.9999857, -0.0051326, 0.0014930>,
      <0.9999857, -0.0051326, 0.0014930>,
      <0.9999852, -0.0051385, 0.0017886>,
      <0.9999840, -0.0051376, 0.0023675>,
      <0.9999834, -0.0051346, 0.0026061>,
      <0.9999852, -0.0051385, 0.0017886>,
      <0.9999848, -0.0051423, 0.0019806>,
      <0.9999848, -0.0051423, 0.0019806>,
      <0.9999845, -0.0051450, 0.0021153>,
      <0.9999838, -0.0051403, 0.0024284>,
      <0.9999838, -0.0051403, 0.0024284>,
      <0.9999833, -0.0051371, 0.0026332>,
      <0.9999830, -0.0051326, 0.0027680>,
      <0.9999833, -0.0051371, 0.0026332>,
      <0.9999830, -0.0051349, 0.0027776>,
      <0.9999830, -0.0051349, 0.0027776>,
      <0.9999827, -0.0051333, 0.0028849>,
      <0.9999827, -0.0051312, 0.0028850>,
      <0.9999827, -0.0051312, 0.0028850>,
      <0.9999827, -0.0051287, 0.0028851>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <0.0001034, 0.0200136, -0.9997997>,
      <-0.9999506, 0.0052566, 0.0084329>,
      <-0.9999691, 0.0052442, 0.0058644>,
      <-0.9999707, 0.0052734, 0.0055497>,
      <-0.9999568, 0.0052919, 0.0076356>,
      <-0.9999221, 0.0053242, 0.0112929>,
      <-0.9998955, 0.0052807, 0.0134585>,
      <-0.9998955, 0.0052807, 0.0134585>,
      <-0.9998381, 0.0052050, 0.0172249>,
      <-0.9999405, 0.0052055, 0.0095864>,
      <-0.9999405, 0.0052055, 0.0095864>,
      <-0.9999667, 0.0052057, 0.0062797>,
      <-0.9999770, 0.0052367, 0.0043049>,
      <-0.9999773, 0.0052615, 0.0042015>,
      <-0.9999667, 0.0052057, 0.0062797>,
      <-0.9999766, 0.0052057, 0.0044341>,
      <-0.9999766, 0.0052057, 0.0044341>,
      <-0.9999811, 0.0052057, 0.0032565>,
      <-0.9999810, 0.0052316, 0.0032576>,
      <-0.9999810, 0.0052316, 0.0032576>,
      <-0.9999809, 0.0052531, 0.0032585>,
      <-0.9999776, 0.0052818, 0.0041169>,
      <-0.9999719, 0.0052963, 0.0053031>,
      <-0.9999809, 0.0052531, 0.0032585>,
      <-0.9999808, 0.0052713, 0.0032593>,
      <-0.9999808, 0.0052713, 0.0032593>,
      <-0.9999807, 0.0052868, 0.0032599>,
      <-0.9999778, 0.0052987, 0.0040463>,
      <-0.9999778, 0.0052987, 0.0040463>,
      <-0.9999728, 0.0053148, 0.0051046>,
      <-0.9999610, 0.0053178, 0.0070516>,
      <-0.9999728, 0.0053148, 0.0051046>,
      <-0.9999639, 0.0053375, 0.0066053>,
      <-0.9999639, 0.0053375, 0.0066053>,
      <-0.9999460, 0.0053723, 0.0088994>,
      <-0.9999368, 0.0053525, 0.0098864>,
      <-0.9999368, 0.0053525, 0.0098864>,
      <-0.9999221, 0.0053242, 0.0112929>,
      <-0.9999864, 0.0051810, 0.0005141>,
      <-0.9999864, 0.0051812, 0.0005303>,
      <-0.9999865, 0.0051771, 0.0005304>,
      <-0.9999865, 0.0051770, 0.0005142>,
      <-0.9999865, 0.0051769, 0.0004984>,
      <-0.9999865, 0.0051808, 0.0004984>,
      <-0.9999865, 0.0051808, 0.0004984>,
      <-0.9999864, 0.0051847, 0.0004983>,
      <-0.9999864, 0.0051850, 0.0005141>,
      <-0.9999864, 0.0051850, 0.0005141>,
      <-0.9999864, 0.0051852, 0.0005303>,
      <-0.9999864, 0.0051814, 0.0005471>,
      <-0.9999864, 0.0051772, 0.0005472>,
      <-0.9999864, 0.0051852, 0.0005303>,
      <-0.9999864, 0.0051855, 0.0005470>,
      <-0.9999864, 0.0051855, 0.0005470>,
      <-0.9999864, 0.0051857, 0.0005643>,
      <-0.9999864, 0.0051816, 0.0005644>,
      <-0.9999864, 0.0051816, 0.0005644>,
      <-0.9999864, 0.0051774, 0.0005645>,
      <-0.9999865, 0.0051731, 0.0005472>,
      <-0.9999865, 0.0051730, 0.0005305>,
      <-0.9999864, 0.0051774, 0.0005645>,
      <-0.9999865, 0.0051732, 0.0005646>,
      <-0.9999865, 0.0051732, 0.0005646>,
      <-0.9999865, 0.0051690, 0.0005647>,
      <-0.9999865, 0.0051690, 0.0005473>,
      <-0.9999865, 0.0051690, 0.0005473>,
      <-0.9999865, 0.0051690, 0.0005305>,
      <-0.9999865, 0.0051730, 0.0005142>,
      <-0.9999865, 0.0051690, 0.0005305>,
      <-0.9999865, 0.0051690, 0.0005142>,
      <-0.9999865, 0.0051690, 0.0005142>,
      <-0.9999865, 0.0051690, 0.0004984>,
      <-0.9999865, 0.0051729, 0.0004984>,
      <-0.9999865, 0.0051729, 0.0004984>,
      <-0.9999865, 0.0051769, 0.0004984>,
      <-0.0051665, -0.9997170, 0.0232204>,
      <-0.0051665, -0.9997171, 0.0232184>,
      <-0.0051670, -0.9997171, 0.0232184>,
      <-0.0051670, -0.9997170, 0.0232204>,
      <-0.0051670, -0.9997170, 0.0232224>,
      <-0.0051665, -0.9997170, 0.0232224>,
      <-0.0051665, -0.9997170, 0.0232224>,
      <-0.0051661, -0.9997170, 0.0232224>,
      <-0.0051661, -0.9997170, 0.0232204>,
      <-0.0051661, -0.9997170, 0.0232204>,
      <-0.0051661, -0.9997171, 0.0232184>,
      <-0.0051665, -0.9997171, 0.0232164>,
      <-0.0051670, -0.9997171, 0.0232164>,
      <-0.0051661, -0.9997171, 0.0232184>,
      <-0.0051661, -0.9997171, 0.0232164>,
      <-0.0051661, -0.9997171, 0.0232164>,
      <-0.0051661, -0.9997172, 0.0232145>,
      <-0.0051665, -0.9997172, 0.0232145>,
      <-0.0051665, -0.9997172, 0.0232145>,
      <-0.0051670, -0.9997172, 0.0232145>,
      <-0.0051674, -0.9997171, 0.0232164>,
      <-0.0051674, -0.9997171, 0.0232184>,
      <-0.0051670, -0.9997172, 0.0232145>,
      <-0.0051674, -0.9997172, 0.0232145>,
      <-0.0051674, -0.9997172, 0.0232145>,
      <-0.0051678, -0.9997172, 0.0232145>,
      <-0.0051678, -0.9997171, 0.0232164>,
      <-0.0051678, -0.9997171, 0.0232164>,
      <-0.0051678, -0.9997171, 0.0232184>,
      <-0.0051674, -0.9997170, 0.0232204>,
      <-0.0051678, -0.9997171, 0.0232184>,
      <-0.0051678, -0.9997170, 0.0232204>,
      <-0.0051678, -0.9997170, 0.0232204>,
      <-0.0051678, -0.9997170, 0.0232224>,
      <-0.0051674, -0.9997170, 0.0232224>,
      <-0.0051674, -0.9997170, 0.0232224>,
      <-0.0051670, -0.9997170, 0.0232224>,
      <0.9999862, -0.0052292, 0.0005706>,
      <0.9999862, -0.0052293, 0.0005680>,
      <0.9999862, -0.0052299, 0.0005681>,
      <0.9999862, -0.0052299, 0.0005706>,
      <0.9999862, -0.0052299, 0.0005733>,
      <0.9999862, -0.0052292, 0.0005733>,
      <0.9999862, -0.0052292, 0.0005733>,
      <0.9999862, -0.0052286, 0.0005733>,
      <0.9999862, -0.0052286, 0.0005706>,
      <0.9999862, -0.0052286, 0.0005706>,
      <0.9999862, -0.0052286, 0.0005680>,
      <0.9999862, -0.0052293, 0.0005655>,
      <0.9999862, -0.0052299, 0.0005656>,
      <0.9999862, -0.0052286, 0.0005680>,
      <0.9999862, -0.0052287, 0.0005655>,
      <0.9999862, -0.0052287, 0.0005655>,
      <0.9999862, -0.0052287, 0.0005631>,
      <0.9999862, -0.0052293, 0.0005631>,
      <0.9999862, -0.0052293, 0.0005631>,
      <0.9999862, -0.0052299, 0.0005631>,
      <0.9999862, -0.0052305, 0.0005656>,
      <0.9999862, -0.0052305, 0.0005681>,
      <0.9999862, -0.0052299, 0.0005631>,
      <0.9999862, -0.0052305, 0.0005631>,
      <0.9999862, -0.0052305, 0.0005631>,
      <0.9999862, -0.0052311, 0.0005631>,
      <0.9999862, -0.0052311, 0.0005656>,
      <0.9999862, -0.0052311, 0.0005656>,
      <0.9999862, -0.0052311, 0.0005681>,
      <0.9999862, -0.0052305, 0.0005706>,
      <0.9999862, -0.0052311, 0.0005681>,
      <0.9999862, -0.0052311, 0.0005707>,
      <0.9999862, -0.0052311, 0.0005707>,
      <0.9999862, -0.0052311, 0.0005733>,
      <0.9999862, -0.0052305, 0.0005733>,
      <0.9999862, -0.0052305, 0.0005733>,
      <0.9999862, -0.0052299, 0.0005733>,
      <-0.9999814, 0.0051728, 0.0032413>,
      <-0.9999818, 0.0051728, 0.0030960>,
      <-0.9999818, 0.0051764, 0.0031052>,
      <-0.9999813, 0.0051764, 0.0032458>,
      <-0.9999809, 0.0051764, 0.0033864>,
      <-0.9999809, 0.0051728, 0.0033866>,
      <-0.9999809, 0.0051728, 0.0033866>,
      <-0.9999809, 0.0051689, 0.0033868>,
      <-0.9999814, 0.0051690, 0.0032365>,
      <-0.9999814, 0.0051690, 0.0032365>,
      <-0.9999819, 0.0051690, 0.0030862>,
      <-0.9999823, 0.0051728, 0.0029508>,
      <-0.9999822, 0.0051764, 0.0029647>,
      <-0.9999819, 0.0051690, 0.0030862>,
      <-0.9999823, 0.0051690, 0.0029360>,
      <-0.9999823, 0.0051690, 0.0029360>,
      <-0.9999828, 0.0051690, 0.0027857>,
      <-0.9999827, 0.0051728, 0.0028055>,
      <-0.9999827, 0.0051728, 0.0028055>,
      <-0.9999826, 0.0051764, 0.0028241>,
      <-0.9999822, 0.0051798, 0.0029777>,
      <-0.9999817, 0.0051798, 0.0031138>,
      <-0.9999826, 0.0051764, 0.0028241>,
      <-0.9999825, 0.0051798, 0.0028415>,
      <-0.9999825, 0.0051798, 0.0028415>,
      <-0.9999825, 0.0051830, 0.0028578>,
      <-0.9999821, 0.0051830, 0.0029899>,
      <-0.9999821, 0.0051830, 0.0029899>,
      <-0.9999817, 0.0051830, 0.0031219>,
      <-0.9999813, 0.0051798, 0.0032500>,
      <-0.9999817, 0.0051830, 0.0031219>,
      <-0.9999813, 0.0051829, 0.0032540>,
      <-0.9999813, 0.0051829, 0.0032540>,
      <-0.9999808, 0.0051829, 0.0033861>,
      <-0.9999809, 0.0051798, 0.0033862>,
      <-0.9999809, 0.0051798, 0.0033862>,
      <-0.9999809, 0.0051764, 0.0033864>,
      <-0.0009850, -0.1905373, -0.9816795>,
      <-0.0009850, -0.1905369, -0.9816795>,
      <-0.0009851, -0.1905369, -0.9816795>,
      <-0.0009851, -0.1905373, -0.9816795>,
      <-0.0009851, -0.1905378, -0.9816794>,
      <-0.0009850, -0.1905378, -0.9816794>,
      <-0.0009850, -0.1905378, -0.9816794>,
      <-0.0009849, -0.1905378, -0.9816794>,
      <-0.0009849, -0.1905373, -0.9816795>,
      <-0.0009849, -0.1905373, -0.9816795>,
      <-0.0009849, -0.1905369, -0.9816795>,
      <-0.0009850, -0.1905364, -0.9816796>,
      <-0.0009850, -0.1905364, -0.9816796>,
      <-0.0009849, -0.1905369, -0.9816795>,
      <-0.0009849, -0.1905364, -0.9816796>,
      <-0.0009849, -0.1905364, -0.9816796>,
      <-0.0009849, -0.1905360, -0.9816797>,
      <-0.0009850, -0.1905360, -0.9816797>,
      <-0.0009850, -0.1905360, -0.9816797>,
      <-0.0009850, -0.1905360, -0.9816797>,
      <-0.0009851, -0.1905364, -0.9816796>,
      <-0.0009851, -0.1905369, -0.9816795>,
      <-0.0009850, -0.1905360, -0.9816797>,
      <-0.0009851, -0.1905360, -0.9816797>,
      <-0.0009851, -0.1905360, -0.9816797>,
      <-0.0009852, -0.1905360, -0.9816797>,
      <-0.0009852, -0.1905364, -0.9816796>,
      <-0.0009852, -0.1905364, -0.9816796>,
      <-0.0009852, -0.1905369, -0.9816795>,
      <-0.0009851, -0.1905373, -0.9816795>,
      <-0.0009852, -0.1905369, -0.9816795>,
      <-0.0009852, -0.1905373, -0.9816795>,
      <-0.0009852, -0.1905373, -0.9816795>,
      <-0.0009852, -0.1905378, -0.9816794>,
      <-0.0009851, -0.1905378, -0.9816794>,
      <-0.0009851, -0.1905378, -0.9816794>,
      <-0.0009851, -0.1905378, -0.9816794>,
      <0.9999781, -0.0052332, 0.0040632>,
      <0.9999784, -0.0052332, 0.0039843>,
      <0.9999784, -0.0052352, 0.0039793>,
      <0.9999781, -0.0052352, 0.0040557>,
      <0.9999778, -0.0052352, 0.0041320>,
      <0.9999777, -0.0052332, 0.0041421>,
      <0.9999777, -0.0052332, 0.0041421>,
      <0.9999777, -0.0052311, 0.0041529>,
      <0.9999780, -0.0052311, 0.0040712>,
      <0.9999780, -0.0052311, 0.0040712>,
      <0.9999784, -0.0052311, 0.0039896>,
      <0.9999787, -0.0052332, 0.0039053>,
      <0.9999787, -0.0052352, 0.0039029>,
      <0.9999784, -0.0052311, 0.0039896>,
      <0.9999787, -0.0052311, 0.0039079>,
      <0.9999787, -0.0052311, 0.0039079>,
      <0.9999790, -0.0052311, 0.0038263>,
      <0.9999790, -0.0052332, 0.0038264>,
      <0.9999790, -0.0052332, 0.0038264>,
      <0.9999790, -0.0052352, 0.0038265>,
      <0.9999787, -0.0052370, 0.0039006>,
      <0.9999784, -0.0052370, 0.0039746>,
      <0.9999790, -0.0052352, 0.0038265>,
      <0.9999790, -0.0052370, 0.0038266>,
      <0.9999790, -0.0052370, 0.0038266>,
      <0.9999790, -0.0052387, 0.0038267>,
      <0.9999787, -0.0052387, 0.0038984>,
      <0.9999787, -0.0052387, 0.0038984>,
      <0.9999784, -0.0052387, 0.0039702>,
      <0.9999781, -0.0052370, 0.0040486>,
      <0.9999784, -0.0052387, 0.0039702>,
      <0.9999781, -0.0052387, 0.0040420>,
      <0.9999781, -0.0052387, 0.0040420>,
      <0.9999778, -0.0052387, 0.0041137>,
      <0.9999778, -0.0052370, 0.0041226>,
      <0.9999778, -0.0052370, 0.0041226>,
      <0.9999778, -0.0052352, 0.0041320>,
      <-0.9999888, 0.0044250, 0.0016588>,
      <-0.9999845, 0.0044069, 0.0033912>,
      <-0.9999904, 0.0039697, 0.0018396>,
      <-0.9999916, 0.0039779, 0.0009534>,
      <-0.9999921, 0.0039755, -0.0000449>,
      <-0.9999901, 0.0044396, -0.0000503>,
      <-0.9999901, 0.0044396, -0.0000503>,
      <-0.9999866, 0.0051830, -0.0000590>,
      <-0.9999842, 0.0051830, 0.0021843>,
      <-0.9999842, 0.0051830, 0.0021843>,
      <-0.9999761, 0.0051829, 0.0045866>,
      <-0.9999769, 0.0043840, 0.0051974>,
      <-0.9999886, 0.0039474, 0.0027042>,
      <-0.9999761, 0.0051829, 0.0045866>,
      <-0.9999609, 0.0051828, 0.0071652>,
      <-0.9999609, 0.0051828, 0.0071652>,
      <-0.9999372, 0.0051827, 0.0099402>,
      <-0.9999652, 0.0043603, 0.0071181>,
      <-0.9999652, 0.0043603, 0.0071181>,
      <-0.9999858, 0.0039251, 0.0036118>,
      <-0.9999926, 0.0038153, 0.0004239>,
      <-0.9999927, 0.0038061, 0.0003433>,
      <-0.9999858, 0.0039251, 0.0036118>,
      <-0.9999926, 0.0038166, 0.0004914>,
      <-0.9999926, 0.0038166, 0.0004914>,
      <-0.9999901, 0.0040000, -0.0019508>,
      <-0.9999912, 0.0039655, -0.0013803>,
      <-0.9999920, 0.0039114, -0.0008097>,
      <-0.9999928, 0.0037865, 0.0002218>,
      <-0.9999926, 0.0038498, -0.0002304>,
      <-0.9999924, 0.0038724, 0.0003599>,
      <-0.9999929, 0.0037622, -0.0000424>,
      <-0.9999929, 0.0037622, -0.0000424>,
      <-0.9999921, 0.0039755, -0.0000449>,
      <-0.0025715, -0.4973477, -0.8675475>,
      <-0.0025715, -0.4973477, -0.8675475>,
      <-0.0031058, -0.6006571, -0.7995007>,
      <-0.0031058, -0.6006573, -0.7995006>,
      <-0.0031058, -0.6006575, -0.7995005>,
      <-0.0025715, -0.4973478, -0.8675475>,
      <-0.0025715, -0.4973478, -0.8675475>,
      <-0.0023885, -0.4619521, -0.8869017>,
      <-0.0023885, -0.4619521, -0.8869017>,
      <-0.0023885, -0.4619521, -0.8869017>,
      <-0.0023885, -0.4619521, -0.8869017>,
      <-0.0025715, -0.4973477, -0.8675475>,
      <-0.0031058, -0.6006570, -0.7995008>,
      <-0.0023885, -0.4619521, -0.8869017>,
      <-0.0023885, -0.4619521, -0.8869017>,
      <-0.0023885, -0.4619521, -0.8869017>,
      <-0.0023885, -0.4619521, -0.8869017>,
      <-0.0025715, -0.4973476, -0.8675475>,
      <-0.0025715, -0.4973476, -0.8675475>,
      <-0.0031058, -0.6006568, -0.7995009>,
      <-0.0038899, -0.7522519, -0.6588641>,
      <-0.0038899, -0.7522523, -0.6588637>,
      <-0.0031058, -0.6006568, -0.7995009>,
      <-0.0038899, -0.7522515, -0.6588646>,
      <-0.0038899, -0.7522515, -0.6588646>,
      <-0.0046467, -0.8984691, -0.4390121>,
      <-0.0046467, -0.8984696, -0.4390111>,
      <-0.0046467, -0.8984701, -0.4390101>,
      <-0.0038899, -0.7522526, -0.6588633>,
      <-0.0046468, -0.8984706, -0.4390092>,
      <-0.0046468, -0.8984710, -0.4390082>,
      <-0.0038899, -0.7522530, -0.6588629>,
      <-0.0038899, -0.7522530, -0.6588629>,
      <-0.0031058, -0.6006575, -0.7995005>,
      <0.9999768, -0.0044327, -0.0051672>,
      <0.9999844, -0.0044575, -0.0033562>,
      <0.9999906, -0.0040313, -0.0016198>,
      <0.9999890, -0.0039981, -0.0024496>,
      <0.9999865, -0.0039720, -0.0033571>,
      <0.9999650, -0.0044082, -0.0071049>,
      <0.9999650, -0.0044082, -0.0071049>,
      <0.9999358, -0.0052385, -0.0100442>,
      <0.9999601, -0.0052386, -0.0072394>,
      <0.9999601, -0.0052386, -0.0072394>,
      <0.9999755, -0.0052387, -0.0046331>,
      <0.9999886, -0.0044774, -0.0016351>,
      <0.9999915, -0.0040511, -0.0008207>,
      <0.9999755, -0.0052387, -0.0046331>,
      <0.9999838, -0.0052387, -0.0022051>,
      <0.9999838, -0.0052387, -0.0022051>,
      <0.9999863, -0.0052388, 0.0000623>,
      <0.9999899, -0.0044924, 0.0000536>,
      <0.9999899, -0.0044924, 0.0000536>,
      <0.9999918, -0.0040532, 0.0000485>,
      <0.9999924, -0.0039090, 0.0001384>,
      <0.9999924, -0.0038885, 0.0001306>,
      <0.9999918, -0.0040532, 0.0000485>,
      <0.9999923, -0.0039249, 0.0000470>,
      <0.9999923, -0.0039249, 0.0000470>,
      <0.9999917, -0.0040569, 0.0003928>,
      <0.9999916, -0.0039948, 0.0009688>,
      <0.9999908, -0.0039988, 0.0015478>,
      <0.9999925, -0.0038735, 0.0000862>,
      <0.9999896, -0.0040282, 0.0021203>,
      <0.9999882, -0.0040545, 0.0026907>,
      <0.9999925, -0.0038670, 0.0000244>,
      <0.9999925, -0.0038670, 0.0000244>,
      <0.9999865, -0.0039720, -0.0033571>,
      <-0.9999907, 0.0043038, -0.0004050>,
      <-0.9999896, 0.0043371, -0.0014103>,
      <-0.9999865, 0.0049463, -0.0015964>,
      <-0.9999878, 0.0049208, -0.0004797>,
      <-0.9999879, 0.0048952, 0.0005073>,
      <-0.9999905, 0.0043229, 0.0005089>,
      <-0.9999905, 0.0043229, 0.0005089>,
      <-0.9999924, 0.0038724, 0.0003599>,
      <-0.9999875, 0.0043946, -0.0023875>,
      <-0.9999840, 0.0049673, -0.0027156>,
      <-0.9999901, 0.0040000, -0.0019508>,
      <-0.9999847, 0.0044358, -0.0033199>,
      <-0.9999847, 0.0044358, -0.0033199>,
      <-0.9999805, 0.0049872, -0.0037673>,
      <-0.9999816, 0.0055147, -0.0025153>,
      <-0.9999836, 0.0055362, -0.0014732>,
      <-0.9999805, 0.0049872, -0.0037673>,
      <-0.9999787, 0.0055074, -0.0034974>,
      <-0.9999787, 0.0055074, -0.0034974>,
      <-0.9999808, 0.0058436, -0.0020530>,
      <-0.9999818, 0.0058575, -0.0014417>,
      <-0.9999823, 0.0058876, -0.0008173>,
      <-0.9999847, 0.0055199, -0.0004143>,
      <-0.9999825, 0.0059100, -0.0001872>,
      <-0.9999829, 0.0058350, 0.0004516>,
      <-0.9999850, 0.0054474, 0.0005057>,
      <-0.9999850, 0.0054474, 0.0005057>,
      <-0.9999879, 0.0048952, 0.0005073>,
      <-0.0049941, -0.9654100, -0.2606887>,
      <-0.0049941, -0.9654096, -0.2606901>,
      <-0.0050748, -0.9807224, -0.1953400>,
      <-0.0050748, -0.9807228, -0.1953385>,
      <-0.0050748, -0.9807231, -0.1953370>,
      <-0.0049941, -0.9654104, -0.2606873>,
      <-0.0049941, -0.9654104, -0.2606873>,
      <-0.0046468, -0.8984710, -0.4390082>,
      <-0.0049941, -0.9654092, -0.2606915>,
      <-0.0050748, -0.9807221, -0.1953416>,
      <-0.0046467, -0.8984691, -0.4390121>,
      <-0.0049941, -0.9654089, -0.2606929>,
      <-0.0049941, -0.9654089, -0.2606929>,
      <-0.0050748, -0.9807218, -0.1953431>,
      <-0.0050429, -0.9742736, -0.2253121>,
      <-0.0050429, -0.9742739, -0.2253106>,
      <-0.0050748, -0.9807218, -0.1953431>,
      <-0.0050429, -0.9742732, -0.2253136>,
      <-0.0050429, -0.9742732, -0.2253136>,
      <-0.0047818, -0.9236006, -0.3833264>,
      <-0.0047818, -0.9236011, -0.3833251>,
      <-0.0047818, -0.9236016, -0.3833239>,
      <-0.0050429, -0.9742743, -0.2253091>,
      <-0.0047818, -0.9236021, -0.3833227>,
      <-0.0047818, -0.9236026, -0.3833214>,
      <-0.0050429, -0.9742746, -0.2253075>,
      <-0.0050429, -0.9742746, -0.2253075>,
      <-0.0050748, -0.9807231, -0.1953370>,
      <0.9999847, -0.0044552, 0.0032655>,
      <0.9999876, -0.0044117, 0.0023060>,
      <0.9999842, -0.0050041, 0.0025511>,
      <0.9999807, -0.0050222, 0.0036502>,
      <0.9999763, -0.0050411, 0.0046933>,
      <0.9999811, -0.0044916, 0.0041921>,
      <0.9999811, -0.0044916, 0.0041921>,
      <0.9999882, -0.0040545, 0.0026907>,
      <0.9999894, -0.0043973, 0.0013487>,
      <0.9999865, -0.0049820, 0.0014705>,
      <0.9999917, -0.0040569, 0.0003928>,
      <0.9999901, -0.0044232, 0.0005220>,
      <0.9999901, -0.0044232, 0.0005220>,
      <0.9999876, -0.0049583, 0.0005236>,
      <0.9999836, -0.0055596, 0.0014038>,
      <0.9999815, -0.0055804, 0.0024324>,
      <0.9999876, -0.0049583, 0.0005236>,
      <0.9999848, -0.0054877, 0.0005251>,
      <0.9999848, -0.0054877, 0.0005251>,
      <0.9999829, -0.0058373, 0.0004730>,
      <0.9999818, -0.0059245, 0.0011021>,
      <0.9999810, -0.0059210, 0.0017188>,
      <0.9999786, -0.0055632, 0.0034568>,
      <0.9999799, -0.0058994, 0.0023293>,
      <0.9999784, -0.0058883, 0.0029276>,
      <0.9999748, -0.0055574, 0.0044283>,
      <0.9999748, -0.0055574, 0.0044283>,
      <0.9999763, -0.0050411, 0.0046933>,
      <-0.9999824, 0.0059028, 0.0005499>,
      <-0.9999824, 0.0058957, 0.0007182>,
      <-0.9999789, 0.0057362, 0.0030557>,
      <-0.9999817, 0.0057438, 0.0018853>,
      <-0.9999833, 0.0057827, 0.0001365>,
      <-0.9999824, 0.0059390, 0.0001362>,
      <-0.9999824, 0.0059390, 0.0001362>,
      <-0.9999829, 0.0058350, 0.0004516>,
      <-0.9999822, 0.0058964, 0.0008656>,
      <-0.9999748, 0.0057457, 0.0041744>,
      <-0.9999808, 0.0058436, -0.0020530>,
      <-0.9999821, 0.0058973, 0.0010132>,
      <-0.9999821, 0.0058973, 0.0010132>,
      <-0.9999692, 0.0057485, 0.0053475>,
      <-0.9999539, 0.0055074, 0.0078626>,
      <-0.9999696, 0.0055093, 0.0055134>,
      <-0.9999692, 0.0057485, 0.0053475>,
      <-0.9999331, 0.0055041, 0.0101719>,
      <-0.9999331, 0.0055041, 0.0101719>,
      <-0.9999114, 0.0052458, 0.0122327>,
      <-0.9999418, 0.0052460, 0.0094259>,
      <-0.9999418, 0.0052460, 0.0094259>,
      <-0.9999652, 0.0052461, 0.0064815>,
      <-0.9999802, 0.0055157, 0.0030313>,
      <-0.9999652, 0.0052461, 0.0064815>,
      <-0.9999805, 0.0052462, 0.0033892>,
      <-0.9999805, 0.0052462, 0.0033892>,
      <-0.9999862, 0.0052462, 0.0001376>,
      <-0.9999847, 0.0055282, 0.0001371>,
      <-0.9999847, 0.0055282, 0.0001371>,
      <-0.9999833, 0.0057827, 0.0001365>,
      <-0.0040153, -0.7754245, -0.6314275>,
      <-0.0040153, -0.7754240, -0.6314282>,
      <-0.0029953, -0.5783960, -0.8157507>,
      <-0.0029953, -0.5783962, -0.8157505>,
      <-0.0029953, -0.5783965, -0.8157503>,
      <-0.0040153, -0.7754250, -0.6314269>,
      <-0.0040153, -0.7754250, -0.6314269>,
      <-0.0047818, -0.9236026, -0.3833214>,
      <-0.0040153, -0.7754235, -0.6314288>,
      <-0.0029953, -0.5783957, -0.8157509>,
      <-0.0047818, -0.9236006, -0.3833264>,
      <-0.0040153, -0.7754229, -0.6314294>,
      <-0.0040153, -0.7754229, -0.6314294>,
      <-0.0029953, -0.5783954, -0.8157511>,
      <-0.0022049, -0.4257530, -0.9048367>,
      <-0.0022049, -0.4257531, -0.9048367>,
      <-0.0029953, -0.5783954, -0.8157511>,
      <-0.0022049, -0.4257529, -0.9048368>,
      <-0.0022049, -0.4257529, -0.9048368>,
      <-0.0019237, -0.3714460, -0.9284526>,
      <-0.0019237, -0.3714460, -0.9284526>,
      <-0.0019237, -0.3714460, -0.9284526>,
      <-0.0019237, -0.3714461, -0.9284525>,
      <-0.0022050, -0.4257532, -0.9048366>,
      <-0.0019237, -0.3714461, -0.9284525>,
      <-0.0019237, -0.3714461, -0.9284525>,
      <-0.0019237, -0.3714461, -0.9284525>,
      <-0.0019237, -0.3714462, -0.9284525>,
      <-0.0022050, -0.4257533, -0.9048366>,
      <-0.0022050, -0.4257533, -0.9048366>,
      <-0.0029953, -0.5783965, -0.8157503>,
      <0.9999824, -0.0059327, -0.0001088>,
      <0.9999825, -0.0059228, 0.0000391>,
      <0.9999803, -0.0057646, -0.0025023>,
      <0.9999768, -0.0057787, -0.0036111>,
      <0.9999718, -0.0057829, -0.0048015>,
      <0.9999823, -0.0059365, -0.0002718>,
      <0.9999823, -0.0059365, -0.0002718>,
      <0.9999784, -0.0058883, 0.0029276>,
      <0.9999825, -0.0059124, 0.0001472>,
      <0.9999824, -0.0057661, -0.0014089>,
      <0.9999829, -0.0058373, 0.0004730>,
      <0.9999826, -0.0059054, 0.0001571>,
      <0.9999826, -0.0059054, 0.0001571>,
      <0.9999832, -0.0057989, 0.0001568>,
      <0.9999810, -0.0055448, -0.0027023>,
      <0.9999713, -0.0055392, -0.0051690>,
      <0.9999832, -0.0057989, 0.0001568>,
      <0.9999845, -0.0055568, 0.0001563>,
      <0.9999845, -0.0055568, 0.0001563>,
      <0.9999861, -0.0052746, 0.0001558>,
      <0.9999812, -0.0052746, -0.0031217>,
      <0.9999812, -0.0052746, -0.0031217>,
      <0.9999666, -0.0052745, -0.0062387>,
      <0.9999563, -0.0055380, -0.0075269>,
      <0.9999666, -0.0052745, -0.0062387>,
      <0.9999437, -0.0052744, -0.0092067>,
      <0.9999437, -0.0052744, -0.0092067>,
      <0.9999137, -0.0052742, -0.0120359>,
      <0.9999361, -0.0055348, -0.0098572>,
      <0.9999361, -0.0055348, -0.0098572>,
      <0.9999718, -0.0057829, -0.0048015>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, -0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.9999862, 0.0052495, 0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, -0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <-0.0051811, -0.9999866, 0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, -0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <0.9999861, -0.0052762, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, -0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0051176, -0.9999869, 0.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0051174, -0.9999848, 0.0020479>,
      <-0.0051174, -0.9999848, 0.0020479>,
      <-0.0051174, -0.9999848, 0.0020479>,
      <-0.0051174, -0.9999848, 0.0020479>,
      <-0.0051174, -0.9999848, 0.0020480>,
      <-0.0051174, -0.9999848, 0.0020480>,
      <-0.0051174, -0.9999848, 0.0020480>,
      <-0.0051174, -0.9999848, 0.0020480>,
      <-0.0051174, -0.9999848, 0.0020479>,
      <-0.0051174, -0.9999848, 0.0020479>,
      <-0.0051174, -0.9999848, 0.0020479>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020479>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020479>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051174, -0.9999848, 0.0020478>,
      <-0.0051175, -0.9999848, 0.0020478>,
      <-0.0051175, -0.9999848, 0.0020478>,
      <-0.0051175, -0.9999848, 0.0020478>,
      <-0.0051175, -0.9999848, 0.0020479>,
      <-0.0051174, -0.9999848, 0.0020479>,
      <-0.0051175, -0.9999848, 0.0020479>,
      <-0.0051175, -0.9999848, 0.0020479>,
      <-0.0051175, -0.9999848, 0.0020479>,
      <-0.0051175, -0.9999848, 0.0020480>,
      <-0.0051174, -0.9999848, 0.0020480>,
      <-0.0051174, -0.9999848, 0.0020480>,
      <-0.0051174, -0.9999848, 0.0020480>,
      <0.0051169, 0.9999828, -0.0028701>,
      <0.0051171, 0.9999828, -0.0028701>,
      <0.0051171, 0.9999828, -0.0028699>,
      <0.0051169, 0.9999828, -0.0028699>,
      <0.0051167, 0.9999828, -0.0028699>,
      <0.0051167, 0.9999828, -0.0028701>,
      <0.0051167, 0.9999828, -0.0028701>,
      <0.0051167, 0.9999828, -0.0028702>,
      <0.0051169, 0.9999828, -0.0028702>,
      <0.0051169, 0.9999828, -0.0028702>,
      <0.0051171, 0.9999828, -0.0028702>,
      <0.0051172, 0.9999828, -0.0028701>,
      <0.0051172, 0.9999828, -0.0028699>,
      <0.0051171, 0.9999828, -0.0028702>,
      <0.0051172, 0.9999828, -0.0028702>,
      <0.0051172, 0.9999828, -0.0028702>,
      <0.0051174, 0.9999828, -0.0028702>,
      <0.0051174, 0.9999828, -0.0028701>,
      <0.0051174, 0.9999828, -0.0028701>,
      <0.0051174, 0.9999828, -0.0028699>,
      <0.0051172, 0.9999828, -0.0028698>,
      <0.0051171, 0.9999828, -0.0028698>,
      <0.0051174, 0.9999828, -0.0028699>,
      <0.0051174, 0.9999828, -0.0028698>,
      <0.0051174, 0.9999828, -0.0028698>,
      <0.0051174, 0.9999828, -0.0028696>,
      <0.0051172, 0.9999828, -0.0028696>,
      <0.0051172, 0.9999828, -0.0028696>,
      <0.0051171, 0.9999828, -0.0028696>,
      <0.0051169, 0.9999828, -0.0028698>,
      <0.0051171, 0.9999828, -0.0028696>,
      <0.0051169, 0.9999828, -0.0028696>,
      <0.0051169, 0.9999828, -0.0028696>,
      <0.0051167, 0.9999828, -0.0028696>,
      <0.0051167, 0.9999828, -0.0028698>,
      <0.0051167, 0.9999828, -0.0028698>,
      <0.0051167, 0.9999828, -0.0028699>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <-0.0051164, -0.9999192, 0.0116332>,
      <0.0051102, 0.9987225, -0.0502712>,
      <0.0051102, 0.9987225, -0.0502712>,
      <0.0051102, 0.9987226, -0.0502702>,
      <0.0051102, 0.9987226, -0.0502702>,
      <0.0051102, 0.9987226, -0.0502702>,
      <0.0051102, 0.9987225, -0.0502712>,
      <0.0051102, 0.9987225, -0.0502712>,
      <0.0051102, 0.9987225, -0.0502722>,
      <0.0051102, 0.9987225, -0.0502722>,
      <0.0051102, 0.9987225, -0.0502722>,
      <0.0051102, 0.9987225, -0.0502722>,
      <0.0051103, 0.9987225, -0.0502712>,
      <0.0051103, 0.9987226, -0.0502702>,
      <0.0051102, 0.9987225, -0.0502722>,
      <0.0051103, 0.9987225, -0.0502722>,
      <0.0051103, 0.9987225, -0.0502722>,
      <0.0051103, 0.9987225, -0.0502722>,
      <0.0051103, 0.9987225, -0.0502712>,
      <0.0051103, 0.9987225, -0.0502712>,
      <0.0051103, 0.9987226, -0.0502702>,
      <0.0051103, 0.9987226, -0.0502691>,
      <0.0051102, 0.9987226, -0.0502691>,
      <0.0051103, 0.9987226, -0.0502702>,
      <0.0051103, 0.9987226, -0.0502691>,
      <0.0051103, 0.9987226, -0.0502691>,
      <0.0051103, 0.9987227, -0.0502681>,
      <0.0051103, 0.9987227, -0.0502681>,
      <0.0051103, 0.9987227, -0.0502681>,
      <0.0051102, 0.9987227, -0.0502681>,
      <0.0051102, 0.9987226, -0.0502691>,
      <0.0051102, 0.9987227, -0.0502681>,
      <0.0051102, 0.9987227, -0.0502681>,
      <0.0051102, 0.9987227, -0.0502681>,
      <0.0051102, 0.9987227, -0.0502681>,
      <0.0051102, 0.9987226, -0.0502691>,
      <0.0051102, 0.9987226, -0.0502691>,
      <0.0051102, 0.9987226, -0.0502702>,
      <-0.0049797, -0.9999280, 0.0109141>,
      <-0.0051162, -0.9999316, 0.0105163>,
      <-0.0051162, -0.9999207, 0.0115037>,
      <-0.0050820, -0.9999192, 0.0116512>,
      <-0.0050730, -0.9999157, 0.0119507>,
      <-0.0049488, -0.9999163, 0.0119506>,
      <-0.0049488, -0.9999163, 0.0119506>,
      <-0.0044826, -0.9999625, 0.0074076>,
      <-0.0047203, -0.9999614, 0.0074077>,
      <-0.0051163, -0.9999595, 0.0074076>,
      <-0.0052528, -0.9999266, 0.0109136>,
      <-0.0051504, -0.9999189, 0.0116506>,
      <-0.0055124, -0.9999574, 0.0074074>,
      <-0.0057501, -0.9999560, 0.0074070>,
      <-0.0052835, -0.9999146, 0.0119496>,
      <-0.0052835, -0.9999146, 0.0119496>,
      <-0.0051594, -0.9999153, 0.0119498>,
      <-0.0051204, -0.9999163, 0.0118782>,
      <-0.0051163, -0.9999168, 0.0118451>,
      <-0.0051594, -0.9999153, 0.0119498>,
      <-0.0051217, -0.9999155, 0.0119498>,
      <-0.0051217, -0.9999155, 0.0119498>,
      <-0.0051163, -0.9999155, 0.0119498>,
      <-0.0051163, -0.9999155, 0.0119500>,
      <-0.0051163, -0.9999155, 0.0119500>,
      <-0.0051163, -0.9999155, 0.0119503>,
      <-0.0051122, -0.9999164, 0.0118787>,
      <-0.0051163, -0.9999155, 0.0119503>,
      <-0.0051163, -0.9999155, 0.0119505>,
      <-0.0051163, -0.9999155, 0.0119505>,
      <-0.0051163, -0.9999155, 0.0119508>,
      <-0.0051109, -0.9999155, 0.0119508>,
      <-0.0051109, -0.9999155, 0.0119508>,
      <-0.0050730, -0.9999157, 0.0119507>,
      <-0.0046581, -0.9999796, -0.0043628>,
      <-0.0048881, -0.9997714, -0.0208159>,
      <-0.0051159, -0.9998688, -0.0153711>,
      <-0.0051165, -0.9999866, -0.0008270>,
      <-0.0044826, -0.9999625, 0.0074076>,
      <-0.0032622, -0.9990779, -0.0428093>,
      <-0.0032622, -0.9990779, -0.0428093>,
      <-0.0046344, -0.9990723, -0.0428133>,
      <-0.0050742, -0.9993659, -0.0352415>,
      <-0.0051138, -0.9994621, -0.0323937>,
      <-0.0046344, -0.9990723, -0.0428133>,
      <-0.0050521, -0.9990703, -0.0428145>,
      <-0.0050521, -0.9990703, -0.0428145>,
      <-0.0051118, -0.9990700, -0.0428147>,
      <-0.0051118, -0.9990700, -0.0428138>,
      <-0.0051118, -0.9990700, -0.0428138>,
      <-0.0051118, -0.9990700, -0.0428129>,
      <-0.0051525, -0.9993656, -0.0352399>,
      <-0.0053426, -0.9997691, -0.0208147>,
      <-0.0051118, -0.9990700, -0.0428129>,
      <-0.0051118, -0.9990701, -0.0428121>,
      <-0.0051118, -0.9990701, -0.0428121>,
      <-0.0051118, -0.9990701, -0.0428112>,
      <-0.0051715, -0.9990698, -0.0428110>,
      <-0.0051715, -0.9990698, -0.0428110>,
      <-0.0055891, -0.9990676, -0.0428096>,
      <-0.0055748, -0.9999749, -0.0043624>,
      <-0.0055891, -0.9990676, -0.0428096>,
      <-0.0069612, -0.9990592, -0.0428051>,
      <-0.0069612, -0.9990592, -0.0428051>,
      <-0.0057501, -0.9999560, 0.0074070>
    }
    uv_vectors {
      1469,
      <0.3461295, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.2826137, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.2823938, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.2826137, 0.1538766>,
      <0.3461295, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.5000062, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.6538828, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.7173863, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.7176062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.6537273, 0.1538766>,
      <0.7173863, 0.1538766>,
      <0.6538828, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.5000062, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.3477037, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.3461295, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.2826137, 0.1538766>,
      <0.3240764, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.5000062, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.2826137, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.3756038, 0.9329566>,
      <0.3240764, 0.9329566>,
      <0.7173863, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.5000059, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.5000062, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.6244079, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.6537273, 0.1538766>,
      <0.7173863, 0.1538766>,
      <0.6759253, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3240764, 0.9329566>,
      <0.3214772, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.6244079, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.3240764, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3737658, 0.9324092>,
      <0.3214772, 0.9324092>,
      <0.6759253, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3214772, 0.9324092>,
      <0.3213383, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.3214772, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3736676, 0.9388315>,
      <0.3213383, 0.9388315>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3213383, 0.9388315>,
      <0.3176078, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.3213383, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3710297, 0.9395004>,
      <0.3176078, 0.9395004>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3176078, 0.9395004>,
      <0.3175836, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.3176078, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3710126, 0.9657316>,
      <0.3175836, 0.9657316>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3175836, 0.9657316>,
      <0.2922845, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.3175836, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3531234, 0.9671308>,
      <0.2922845, 0.9671308>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.2922845, 0.9671308>,
      <0.2910740, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.2922845, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3522674, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.2846200, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.2846200, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3477037, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.4373453, 0.9326829>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.4378048, 0.9329566>,
      <0.5000059, 0.9326829>,
      <0.4368858, 0.9324092>,
      <0.3746848, 0.9326829>,
      <0.5626664, 0.9326829>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5622069, 0.9329566>,
      <0.6253269, 0.9326829>,
      <0.5631259, 0.9324092>,
      <0.5000059, 0.9326829>,
      <0.6512759, 0.9326829>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6501666, 0.9329566>,
      <0.6772249, 0.9326829>,
      <0.6523852, 0.9324092>,
      <0.6253269, 0.9326829>,
      <0.4368613, 0.9356203>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.4368858, 0.9324092>,
      <0.5000059, 0.9356203>,
      <0.4368368, 0.9388315>,
      <0.3737167, 0.9356203>,
      <0.5631505, 0.9356203>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5631259, 0.9324092>,
      <0.6262950, 0.9356203>,
      <0.5631750, 0.9388315>,
      <0.5000059, 0.9356203>,
      <0.6524445, 0.9356203>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6523852, 0.9324092>,
      <0.6785939, 0.9356203>,
      <0.6525037, 0.9388315>,
      <0.6262950, 0.9356203>,
      <0.4361773, 0.9391659>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.4368368, 0.9388315>,
      <0.5000059, 0.9391659>,
      <0.4355178, 0.9395004>,
      <0.3723487, 0.9391659>,
      <0.5638345, 0.9391659>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5631750, 0.9388315>,
      <0.6276631, 0.9391659>,
      <0.5644940, 0.9395004>,
      <0.5000059, 0.9391659>,
      <0.6540958, 0.9391659>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6525037, 0.9388315>,
      <0.6805285, 0.9391659>,
      <0.6556879, 0.9395004>,
      <0.6276631, 0.9391659>,
      <0.4355135, 0.9526160>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.4355178, 0.9395004>,
      <0.5000059, 0.9525305>,
      <0.4354078, 0.9657316>,
      <0.3710212, 0.9526160>,
      <0.5644983, 0.9526160>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5644940, 0.9395004>,
      <0.6289906, 0.9525305>,
      <0.5645025, 0.9657316>,
      <0.5000059, 0.9525305>,
      <0.6556982, 0.9526160>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6556879, 0.9395004>,
      <0.6824058, 0.9526160>,
      <0.6557505, 0.9657316>,
      <0.6289906, 0.9525305>,
      <0.4310370, 0.9664312>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.4354078, 0.9657316>,
      <0.5000060, 0.9664142>,
      <0.4261989, 0.9671308>,
      <0.3620680, 0.9664312>,
      <0.5689750, 0.9664312>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5645025, 0.9657316>,
      <0.6377272, 0.9664142>,
      <0.5734474, 0.9671308>,
      <0.5000060, 0.9664142>,
      <0.6665054, 0.9664312>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6557505, 0.9657316>,
      <0.6950669, 0.9664312>,
      <0.6774538, 0.9671308>,
      <0.6377272, 0.9664142>,
      <0.4263507, 0.9777601>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.4261989, 0.9671308>,
      <0.5000061, 0.9773954>,
      <0.4261367, 0.9883895>,
      <0.3526954, 0.9777601>,
      <0.5736614, 0.9777601>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5734474, 0.9671308>,
      <0.6473021, 0.9773954>,
      <0.5738754, 0.9883895>,
      <0.5000061, 0.9773954>,
      <0.6778190, 0.9777601>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6774538, 0.9671308>,
      <0.7083211, 0.9777601>,
      <0.6783356, 0.9883895>,
      <0.6473021, 0.9773954>,
      <0.4249958, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.4238549, 0.9941947>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.4238549, 0.9883895>,
      <0.5000061, 0.9941947>,
      <0.4238549, 1.0000000>,
      <0.3477037, 0.9941947>,
      <0.5761574, 0.9941947>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5761574, 0.9883895>,
      <0.6523086, 0.9941947>,
      <0.5761574, 1.0000000>,
      <0.5000061, 0.9941947>,
      <0.6838443, 0.9941947>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6838443, 0.9883895>,
      <0.7153801, 0.9941947>,
      <0.6838443, 1.0000000>,
      <0.6523086, 0.9941947>,
      <0.4642375, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5426958, 1.0000000>,
      <0.4396228, 1.0000000>,
      <0.3857793, 1.0000000>,
      <0.4888523, 1.0000000>,
      <0.5134670, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.4888523, 1.0000000>,
      <0.4619305, 1.0000000>,
      <0.5380817, 1.0000000>,
      <0.5650035, 1.0000000>,
      <0.6165400, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.5650035, 1.0000000>,
      <0.6142330, 1.0000000>,
      <0.6680764, 1.0000000>,
      <0.6188470, 1.0000000>,
      <0.6211540, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.6188470, 1.0000000>,
      <0.6996122, 1.0000000>,
      <0.6234610, 1.0000000>,
      <0.5426958, 1.0000000>,
      <0.4063597, 0.9328198>,
      <0.4373453, 0.9326829>,
      <0.3746848, 0.9326829>,
      <0.3756038, 0.9329566>,
      <0.4378048, 0.9329566>,
      <0.4060151, 0.9326829>,
      <0.3751443, 0.9328198>,
      <0.4067043, 0.9329566>,
      <0.4375751, 0.9328198>,
      <0.4687905, 0.9328198>,
      <0.4373453, 0.9326829>,
      <0.4378048, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9326829>,
      <0.4375751, 0.9328198>,
      <0.4689053, 0.9329566>,
      <0.5000059, 0.9328198>,
      <0.4686756, 0.9326829>,
      <0.4685607, 0.9325460>,
      <0.4373453, 0.9326829>,
      <0.5000059, 0.9326829>,
      <0.5000059, 0.9324092>,
      <0.4368858, 0.9324092>,
      <0.4686756, 0.9326829>,
      <0.5000059, 0.9325460>,
      <0.4684459, 0.9324092>,
      <0.4371156, 0.9325460>,
      <0.4056704, 0.9325460>,
      <0.4373453, 0.9326829>,
      <0.4368858, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3746848, 0.9326829>,
      <0.4371156, 0.9325460>,
      <0.4053258, 0.9324092>,
      <0.3742253, 0.9325460>,
      <0.4060151, 0.9326829>,
      <0.5312213, 0.9328198>,
      <0.5626664, 0.9326829>,
      <0.5000059, 0.9326829>,
      <0.5000059, 0.9329566>,
      <0.5622069, 0.9329566>,
      <0.5313361, 0.9326829>,
      <0.5000059, 0.9328198>,
      <0.5311064, 0.9329566>,
      <0.5624367, 0.9328198>,
      <0.5936520, 0.9328198>,
      <0.5626664, 0.9326829>,
      <0.5622069, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6253269, 0.9326829>,
      <0.5624367, 0.9328198>,
      <0.5933074, 0.9329566>,
      <0.6248674, 0.9328198>,
      <0.5939967, 0.9326829>,
      <0.5943413, 0.9325460>,
      <0.5626664, 0.9326829>,
      <0.6253269, 0.9326829>,
      <0.6262459, 0.9324092>,
      <0.5631259, 0.9324092>,
      <0.5939967, 0.9326829>,
      <0.6257864, 0.9325460>,
      <0.5946859, 0.9324092>,
      <0.5628962, 0.9325460>,
      <0.5314510, 0.9325460>,
      <0.5626664, 0.9326829>,
      <0.5631259, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9326829>,
      <0.5628962, 0.9325460>,
      <0.5315659, 0.9324092>,
      <0.5000059, 0.9325460>,
      <0.5313361, 0.9326829>,
      <0.6377944, 0.9328198>,
      <0.6512759, 0.9326829>,
      <0.6253269, 0.9326829>,
      <0.6244079, 0.9329566>,
      <0.6501666, 0.9329566>,
      <0.6383014, 0.9326829>,
      <0.6248674, 0.9328198>,
      <0.6372873, 0.9329566>,
      <0.6507213, 0.9328198>,
      <0.6636482, 0.9328198>,
      <0.6512759, 0.9326829>,
      <0.6501666, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6772249, 0.9326829>,
      <0.6507213, 0.9328198>,
      <0.6630460, 0.9329566>,
      <0.6765751, 0.9328198>,
      <0.6642504, 0.9326829>,
      <0.6648526, 0.9325460>,
      <0.6512759, 0.9326829>,
      <0.6772249, 0.9326829>,
      <0.6785245, 0.9324092>,
      <0.6523852, 0.9324092>,
      <0.6642504, 0.9326829>,
      <0.6778747, 0.9325460>,
      <0.6654549, 0.9324092>,
      <0.6518306, 0.9325460>,
      <0.6388085, 0.9325460>,
      <0.6512759, 0.9326829>,
      <0.6523852, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6253269, 0.9326829>,
      <0.6518306, 0.9325460>,
      <0.6393156, 0.9324092>,
      <0.6257864, 0.9325460>,
      <0.6383014, 0.9326829>,
      <0.4053074, 0.9340147>,
      <0.4368613, 0.9356203>,
      <0.3737167, 0.9356203>,
      <0.3737658, 0.9324092>,
      <0.4368858, 0.9324092>,
      <0.4052890, 0.9356203>,
      <0.3737413, 0.9340147>,
      <0.4053258, 0.9324092>,
      <0.4368736, 0.9340147>,
      <0.4684397, 0.9340147>,
      <0.4368613, 0.9356203>,
      <0.4368858, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9356203>,
      <0.4368736, 0.9340147>,
      <0.4684459, 0.9324092>,
      <0.5000059, 0.9340147>,
      <0.4684336, 0.9356203>,
      <0.4684275, 0.9372259>,
      <0.4368613, 0.9356203>,
      <0.5000059, 0.9356203>,
      <0.5000059, 0.9388315>,
      <0.4368368, 0.9388315>,
      <0.4684336, 0.9356203>,
      <0.5000059, 0.9372259>,
      <0.4684213, 0.9388315>,
      <0.4368490, 0.9372259>,
      <0.4052706, 0.9372259>,
      <0.4368613, 0.9356203>,
      <0.4368368, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3737167, 0.9356203>,
      <0.4368490, 0.9372259>,
      <0.4052522, 0.9388315>,
      <0.3736922, 0.9372259>,
      <0.4052890, 0.9356203>,
      <0.5315720, 0.9340147>,
      <0.5631505, 0.9356203>,
      <0.5000059, 0.9356203>,
      <0.5000059, 0.9324092>,
      <0.5631259, 0.9324092>,
      <0.5315782, 0.9356203>,
      <0.5000059, 0.9340147>,
      <0.5315659, 0.9324092>,
      <0.5631382, 0.9340147>,
      <0.5947043, 0.9340147>,
      <0.5631505, 0.9356203>,
      <0.5631259, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6262950, 0.9356203>,
      <0.5631382, 0.9340147>,
      <0.5946859, 0.9324092>,
      <0.6262705, 0.9340147>,
      <0.5947227, 0.9356203>,
      <0.5947412, 0.9372259>,
      <0.5631505, 0.9356203>,
      <0.6262950, 0.9356203>,
      <0.6263441, 0.9388315>,
      <0.5631750, 0.9388315>,
      <0.5947227, 0.9356203>,
      <0.6263196, 0.9372259>,
      <0.5947596, 0.9388315>,
      <0.5631627, 0.9372259>,
      <0.5315843, 0.9372259>,
      <0.5631505, 0.9356203>,
      <0.5631750, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9356203>,
      <0.5631627, 0.9372259>,
      <0.5315904, 0.9388315>,
      <0.5000059, 0.9372259>,
      <0.5315782, 0.9356203>,
      <0.6393427, 0.9340147>,
      <0.6524445, 0.9356203>,
      <0.6262950, 0.9356203>,
      <0.6262459, 0.9324092>,
      <0.6523852, 0.9324092>,
      <0.6393698, 0.9356203>,
      <0.6262705, 0.9340147>,
      <0.6393156, 0.9324092>,
      <0.6524148, 0.9340147>,
      <0.6654870, 0.9340147>,
      <0.6524445, 0.9356203>,
      <0.6523852, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6785939, 0.9356203>,
      <0.6524148, 0.9340147>,
      <0.6654549, 0.9324092>,
      <0.6785592, 0.9340147>,
      <0.6655192, 0.9356203>,
      <0.6655513, 0.9372259>,
      <0.6524445, 0.9356203>,
      <0.6785939, 0.9356203>,
      <0.6786633, 0.9388315>,
      <0.6525037, 0.9388315>,
      <0.6655192, 0.9356203>,
      <0.6786286, 0.9372259>,
      <0.6655835, 0.9388315>,
      <0.6524741, 0.9372259>,
      <0.6393968, 0.9372259>,
      <0.6524445, 0.9356203>,
      <0.6525037, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6262950, 0.9356203>,
      <0.6524741, 0.9372259>,
      <0.6394239, 0.9388315>,
      <0.6263196, 0.9372259>,
      <0.6393698, 0.9356203>,
      <0.4047576, 0.9389987>,
      <0.4361773, 0.9391659>,
      <0.3723487, 0.9391659>,
      <0.3736676, 0.9388315>,
      <0.4368368, 0.9388315>,
      <0.4042630, 0.9391659>,
      <0.3730082, 0.9389987>,
      <0.4052522, 0.9388315>,
      <0.4365070, 0.9389987>,
      <0.4682565, 0.9389987>,
      <0.4361773, 0.9391659>,
      <0.4368368, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9391659>,
      <0.4365070, 0.9389987>,
      <0.4684213, 0.9388315>,
      <0.5000059, 0.9389987>,
      <0.4680916, 0.9391659>,
      <0.4679267, 0.9393332>,
      <0.4361773, 0.9391659>,
      <0.5000059, 0.9391659>,
      <0.5000059, 0.9395004>,
      <0.4355178, 0.9395004>,
      <0.4680916, 0.9391659>,
      <0.5000059, 0.9393332>,
      <0.4677619, 0.9395004>,
      <0.4358475, 0.9393332>,
      <0.4037684, 0.9393332>,
      <0.4361773, 0.9391659>,
      <0.4355178, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3723487, 0.9391659>,
      <0.4358475, 0.9393332>,
      <0.4032738, 0.9395004>,
      <0.3716892, 0.9393332>,
      <0.4042630, 0.9391659>,
      <0.5317553, 0.9389987>,
      <0.5638345, 0.9391659>,
      <0.5000059, 0.9391659>,
      <0.5000059, 0.9388315>,
      <0.5631750, 0.9388315>,
      <0.5319202, 0.9391659>,
      <0.5000059, 0.9389987>,
      <0.5315904, 0.9388315>,
      <0.5635047, 0.9389987>,
      <0.5952542, 0.9389987>,
      <0.5638345, 0.9391659>,
      <0.5631750, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6276631, 0.9391659>,
      <0.5635047, 0.9389987>,
      <0.5947596, 0.9388315>,
      <0.6270036, 0.9389987>,
      <0.5957488, 0.9391659>,
      <0.5962434, 0.9393332>,
      <0.5638345, 0.9391659>,
      <0.6276631, 0.9391659>,
      <0.6289821, 0.9395004>,
      <0.5644940, 0.9395004>,
      <0.5957488, 0.9391659>,
      <0.6283226, 0.9393332>,
      <0.5967380, 0.9395004>,
      <0.5641643, 0.9393332>,
      <0.5320851, 0.9393332>,
      <0.5638345, 0.9391659>,
      <0.5644940, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9391659>,
      <0.5641643, 0.9393332>,
      <0.5322500, 0.9395004>,
      <0.5000059, 0.9393332>,
      <0.5319202, 0.9391659>,
      <0.6401517, 0.9389987>,
      <0.6540958, 0.9391659>,
      <0.6276631, 0.9391659>,
      <0.6263441, 0.9388315>,
      <0.6525037, 0.9388315>,
      <0.6408795, 0.9391659>,
      <0.6270036, 0.9389987>,
      <0.6394239, 0.9388315>,
      <0.6532998, 0.9389987>,
      <0.6664478, 0.9389987>,
      <0.6540958, 0.9391659>,
      <0.6525037, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6805285, 0.9391659>,
      <0.6532998, 0.9389987>,
      <0.6655835, 0.9388315>,
      <0.6795959, 0.9389987>,
      <0.6673122, 0.9391659>,
      <0.6681765, 0.9393332>,
      <0.6540958, 0.9391659>,
      <0.6805285, 0.9391659>,
      <0.6823937, 0.9395004>,
      <0.6556879, 0.9395004>,
      <0.6673122, 0.9391659>,
      <0.6814611, 0.9393332>,
      <0.6690408, 0.9395004>,
      <0.6548919, 0.9393332>,
      <0.6416072, 0.9393332>,
      <0.6540958, 0.9391659>,
      <0.6556879, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6276631, 0.9391659>,
      <0.6548919, 0.9393332>,
      <0.6423350, 0.9395004>,
      <0.6283226, 0.9393332>,
      <0.6408795, 0.9391659>,
      <0.4032706, 0.9460582>,
      <0.4355135, 0.9526160>,
      <0.3710212, 0.9526160>,
      <0.3710297, 0.9395004>,
      <0.4355178, 0.9395004>,
      <0.4032675, 0.9526160>,
      <0.3710254, 0.9460582>,
      <0.4032738, 0.9395004>,
      <0.4355156, 0.9461769>,
      <0.4677608, 0.9460368>,
      <0.4355135, 0.9526160>,
      <0.4355178, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9525305>,
      <0.4355156, 0.9461769>,
      <0.4677619, 0.9395004>,
      <0.5000059, 0.9459717>,
      <0.4677607, 0.9525733>,
      <0.4677333, 0.9591524>,
      <0.4355135, 0.9526160>,
      <0.5000059, 0.9525305>,
      <0.5000059, 0.9657316>,
      <0.4354078, 0.9657316>,
      <0.4677607, 0.9525733>,
      <0.5000059, 0.9592646>,
      <0.4677111, 0.9657316>,
      <0.4354562, 0.9597324>,
      <0.4032388, 0.9591738>,
      <0.4355135, 0.9526160>,
      <0.4354078, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3710212, 0.9526160>,
      <0.4354562, 0.9597324>,
      <0.4029987, 0.9657316>,
      <0.3710169, 0.9591738>,
      <0.4032675, 0.9526160>,
      <0.5322510, 0.9460368>,
      <0.5644983, 0.9526160>,
      <0.5000059, 0.9525305>,
      <0.5000059, 0.9395004>,
      <0.5644940, 0.9395004>,
      <0.5322521, 0.9525733>,
      <0.5000059, 0.9459717>,
      <0.5322500, 0.9395004>,
      <0.5644961, 0.9460142>,
      <0.5967412, 0.9460368>,
      <0.5644983, 0.9526160>,
      <0.5644940, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289906, 0.9525305>,
      <0.5644961, 0.9460142>,
      <0.5967380, 0.9395004>,
      <0.6289863, 0.9459717>,
      <0.5967444, 0.9525733>,
      <0.5967476, 0.9591524>,
      <0.5644983, 0.9526160>,
      <0.6289906, 0.9525305>,
      <0.6289992, 0.9657316>,
      <0.5645025, 0.9657316>,
      <0.5967444, 0.9525733>,
      <0.6289950, 0.9592646>,
      <0.5967509, 0.9657316>,
      <0.5645005, 0.9593065>,
      <0.5322532, 0.9591524>,
      <0.5644983, 0.9526160>,
      <0.5645025, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000059, 0.9525305>,
      <0.5645005, 0.9593065>,
      <0.5322542, 0.9657316>,
      <0.5000059, 0.9592646>,
      <0.5322521, 0.9525733>,
      <0.6423397, 0.9460368>,
      <0.6556982, 0.9526160>,
      <0.6289906, 0.9525305>,
      <0.6289821, 0.9395004>,
      <0.6556879, 0.9395004>,
      <0.6423440, 0.9525733>,
      <0.6289863, 0.9459717>,
      <0.6423350, 0.9395004>,
      <0.6556932, 0.9461769>,
      <0.6690464, 0.9460582>,
      <0.6556982, 0.9526160>,
      <0.6556879, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824058, 0.9526160>,
      <0.6556932, 0.9461769>,
      <0.6690408, 0.9395004>,
      <0.6823998, 0.9460582>,
      <0.6690519, 0.9526160>,
      <0.6690681, 0.9591738>,
      <0.6556982, 0.9526160>,
      <0.6824058, 0.9526160>,
      <0.6824179, 0.9657316>,
      <0.6557505, 0.9657316>,
      <0.6690519, 0.9526160>,
      <0.6824118, 0.9591738>,
      <0.6691718, 0.9657316>,
      <0.6557266, 0.9597324>,
      <0.6423596, 0.9591524>,
      <0.6556982, 0.9526160>,
      <0.6557505, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6289906, 0.9525305>,
      <0.6557266, 0.9597324>,
      <0.6423731, 0.9657316>,
      <0.6289950, 0.9592646>,
      <0.6423440, 0.9525733>,
      <0.3998814, 0.9660814>,
      <0.4310370, 0.9664312>,
      <0.3620680, 0.9664312>,
      <0.3710126, 0.9657316>,
      <0.4354078, 0.9657316>,
      <0.3965517, 0.9664312>,
      <0.3665403, 0.9660814>,
      <0.4029987, 0.9657316>,
      <0.4331188, 0.9660980>,
      <0.4666142, 0.9660772>,
      <0.4310370, 0.9664312>,
      <0.4354078, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000060, 0.9664142>,
      <0.4331188, 0.9660980>,
      <0.4677111, 0.9657316>,
      <0.5000060, 0.9660843>,
      <0.4655208, 0.9664227>,
      <0.4643120, 0.9667768>,
      <0.4310370, 0.9664312>,
      <0.5000060, 0.9664142>,
      <0.5000061, 0.9671308>,
      <0.4261989, 0.9671308>,
      <0.4655208, 0.9664227>,
      <0.5000060, 0.9667495>,
      <0.4630907, 0.9671308>,
      <0.4288090, 0.9667534>,
      <0.3931068, 0.9667810>,
      <0.4310370, 0.9664312>,
      <0.4261989, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3620680, 0.9664312>,
      <0.4288090, 0.9667534>,
      <0.3892301, 0.9671308>,
      <0.3575957, 0.9667810>,
      <0.3965517, 0.9664312>,
      <0.5333724, 0.9660772>,
      <0.5689750, 0.9664312>,
      <0.5000060, 0.9664142>,
      <0.5000059, 0.9657316>,
      <0.5645025, 0.9657316>,
      <0.5344905, 0.9664227>,
      <0.5000060, 0.9660843>,
      <0.5322542, 0.9657316>,
      <0.5668133, 0.9660931>,
      <0.6000510, 0.9660772>,
      <0.5689750, 0.9664312>,
      <0.5645025, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6377272, 0.9664142>,
      <0.5668133, 0.9660931>,
      <0.5967509, 0.9657316>,
      <0.6335086, 0.9660843>,
      <0.6033511, 0.9664227>,
      <0.6067596, 0.9667768>,
      <0.5689750, 0.9664312>,
      <0.6377272, 0.9664142>,
      <0.6468888, 0.9671308>,
      <0.5734474, 0.9671308>,
      <0.6033511, 0.9664227>,
      <0.6420141, 0.9667495>,
      <0.6101681, 0.9671308>,
      <0.5710678, 0.9667586>,
      <0.5356086, 0.9667768>,
      <0.5689750, 0.9664312>,
      <0.5734474, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000060, 0.9664142>,
      <0.5710678, 0.9667586>,
      <0.5367268, 0.9671308>,
      <0.5000060, 0.9667495>,
      <0.5344905, 0.9664227>,
      <0.6472456, 0.9660772>,
      <0.6665054, 0.9664312>,
      <0.6377272, 0.9664142>,
      <0.6289992, 0.9657316>,
      <0.6557505, 0.9657316>,
      <0.6521166, 0.9664227>,
      <0.6335086, 0.9660843>,
      <0.6423731, 0.9657316>,
      <0.6613829, 0.9660980>,
      <0.6749352, 0.9660814>,
      <0.6665054, 0.9664312>,
      <0.6557505, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.6950669, 0.9664312>,
      <0.6613829, 0.9660980>,
      <0.6691718, 0.9657316>,
      <0.6887424, 0.9660814>,
      <0.6807865, 0.9664312>,
      <0.6866855, 0.9667810>,
      <0.6665054, 0.9664312>,
      <0.6950669, 0.9664312>,
      <0.7077159, 0.9671308>,
      <0.6774538, 0.9671308>,
      <0.6807865, 0.9664312>,
      <0.7013914, 0.9667810>,
      <0.6927634, 0.9671308>,
      <0.6715472, 0.9667534>,
      <0.6571438, 0.9667768>,
      <0.6665054, 0.9664312>,
      <0.6774538, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6377272, 0.9664142>,
      <0.6715472, 0.9667534>,
      <0.6621762, 0.9671308>,
      <0.6420141, 0.9667495>,
      <0.6521166, 0.9664227>,
      <0.3895921, 0.9724455>,
      <0.4263507, 0.9777601>,
      <0.3526954, 0.9777601>,
      <0.3531234, 0.9671308>,
      <0.4261989, 0.9671308>,
      <0.3895217, 0.9777601>,
      <0.3529094, 0.9724455>,
      <0.3892301, 0.9671308>,
      <0.4262632, 0.9716301>,
      <0.4631405, 0.9723543>,
      <0.4263507, 0.9777601>,
      <0.4261989, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9773954>,
      <0.4262632, 0.9716301>,
      <0.4630907, 0.9671308>,
      <0.5000061, 0.9719267>,
      <0.4631778, 0.9775778>,
      <0.4631249, 0.9829836>,
      <0.4263507, 0.9777601>,
      <0.5000061, 0.9773954>,
      <0.5000061, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.4631778, 0.9775778>,
      <0.5000061, 0.9828997>,
      <0.4630714, 0.9883895>,
      <0.4262474, 0.9828936>,
      <0.3893626, 0.9830748>,
      <0.4263507, 0.9777601>,
      <0.4261367, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3526954, 0.9777601>,
      <0.4262474, 0.9828936>,
      <0.3892021, 0.9883895>,
      <0.3524814, 0.9830748>,
      <0.3895217, 0.9777601>,
      <0.5367803, 0.9723543>,
      <0.5736614, 0.9777601>,
      <0.5000061, 0.9773954>,
      <0.5000061, 0.9671308>,
      <0.5734474, 0.9671308>,
      <0.5368338, 0.9775778>,
      <0.5000061, 0.9719267>,
      <0.5367268, 0.9671308>,
      <0.5735474, 0.9720971>,
      <0.6103250, 0.9723543>,
      <0.5736614, 0.9777601>,
      <0.5734474, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6473021, 0.9773954>,
      <0.5735474, 0.9720971>,
      <0.6101681, 0.9671308>,
      <0.6470819, 0.9719267>,
      <0.6104818, 0.9775778>,
      <0.6106459, 0.9829836>,
      <0.5736614, 0.9777601>,
      <0.6473021, 0.9773954>,
      <0.6477448, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6104818, 0.9775778>,
      <0.6475237, 0.9828997>,
      <0.6108101, 0.9883895>,
      <0.5737686, 0.9830818>,
      <0.5368873, 0.9829836>,
      <0.5736614, 0.9777601>,
      <0.5738754, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9773954>,
      <0.5737686, 0.9830818>,
      <0.5369408, 0.9883895>,
      <0.5000061, 0.9828997>,
      <0.5368338, 0.9775778>,
      <0.6623659, 0.9723543>,
      <0.6778190, 0.9777601>,
      <0.6473021, 0.9773954>,
      <0.6468888, 0.9671308>,
      <0.6774538, 0.9671308>,
      <0.6625608, 0.9775778>,
      <0.6470819, 0.9719267>,
      <0.6621762, 0.9671308>,
      <0.6776084, 0.9716301>,
      <0.6928274, 0.9724455>,
      <0.6778190, 0.9777601>,
      <0.6774538, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7083211, 0.9777601>,
      <0.6776084, 0.9716301>,
      <0.6927634, 0.9671308>,
      <0.7080185, 0.9724455>,
      <0.6930706, 0.9777601>,
      <0.6933505, 0.9830748>,
      <0.6778190, 0.9777601>,
      <0.7083211, 0.9777601>,
      <0.7089263, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.6930706, 0.9777601>,
      <0.7086237, 0.9830748>,
      <0.6936309, 0.9883895>,
      <0.6780685, 0.9828936>,
      <0.6628004, 0.9829836>,
      <0.6778190, 0.9777601>,
      <0.6783356, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6473021, 0.9773954>,
      <0.6780685, 0.9828936>,
      <0.6630402, 0.9883895>,
      <0.6475237, 0.9828997>,
      <0.6625608, 0.9775778>,
      <0.3883464, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.3874907, 0.9883895>,
      <0.3511265, 0.9883895>,
      <0.3892021, 0.9883895>,
      <0.4255663, 0.9883895>,
      <0.4627862, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4255663, 0.9883895>,
      <0.4630714, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4625010, 0.9883895>,
      <0.4622158, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.4625010, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4619305, 0.9883895>,
      <0.4244254, 0.9883895>,
      <0.3866350, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.4244254, 0.9883895>,
      <0.3857793, 0.9883895>,
      <0.3488446, 0.9883895>,
      <0.3874907, 0.9883895>,
      <0.5372260, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.5375113, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5369408, 0.9883895>,
      <0.5744459, 0.9883895>,
      <0.6116658, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.5744459, 0.9883895>,
      <0.6108101, 0.9883895>,
      <0.6488857, 0.9883895>,
      <0.6125215, 0.9883895>,
      <0.6133773, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.6125215, 0.9883895>,
      <0.6511676, 0.9883895>,
      <0.6142330, 0.9883895>,
      <0.5755869, 0.9883895>,
      <0.5377965, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5755869, 0.9883895>,
      <0.5380817, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5375113, 0.9883895>,
      <0.6642992, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.6655583, 0.9883895>,
      <0.6488857, 0.9883895>,
      <0.6630402, 0.9883895>,
      <0.6797127, 0.9883895>,
      <0.6951263, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.6797127, 0.9883895>,
      <0.6936309, 0.9883895>,
      <0.7105398, 0.9883895>,
      <0.6966216, 0.9883895>,
      <0.6981169, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6966216, 0.9883895>,
      <0.7137666, 0.9883895>,
      <0.6996122, 0.9883895>,
      <0.6824671, 0.9883895>,
      <0.6668174, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6824671, 0.9883895>,
      <0.6680764, 0.9883895>,
      <0.6511676, 0.9883895>,
      <0.6655583, 0.9883895>,
      <0.3857793, 0.9912921>,
      <0.4238549, 0.9941947>,
      <0.3477037, 0.9941947>,
      <0.3477037, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3857793, 0.9941947>,
      <0.3477037, 0.9912921>,
      <0.3857793, 0.9883895>,
      <0.4238549, 0.9912921>,
      <0.4619305, 0.9912921>,
      <0.4238549, 0.9941947>,
      <0.4238549, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9941947>,
      <0.4238549, 0.9912921>,
      <0.4619305, 0.9883895>,
      <0.5000061, 0.9912921>,
      <0.4619305, 0.9941947>,
      <0.4619305, 0.9970974>,
      <0.4238549, 0.9941947>,
      <0.5000061, 0.9941947>,
      <0.5000061, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.4619305, 0.9941947>,
      <0.5000061, 0.9970974>,
      <0.4619305, 1.0000000>,
      <0.4238549, 0.9970974>,
      <0.3857793, 0.9970974>,
      <0.4238549, 0.9941947>,
      <0.4238549, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.3477037, 0.9941947>,
      <0.4238549, 0.9970974>,
      <0.3857793, 1.0000000>,
      <0.3477037, 0.9970974>,
      <0.3857793, 0.9941947>,
      <0.5380817, 0.9912921>,
      <0.5761574, 0.9941947>,
      <0.5000061, 0.9941947>,
      <0.5000061, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5380817, 0.9941947>,
      <0.5000061, 0.9912921>,
      <0.5380817, 0.9883895>,
      <0.5761574, 0.9912921>,
      <0.6142330, 0.9912921>,
      <0.5761574, 0.9941947>,
      <0.5761574, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 0.9941947>,
      <0.5761574, 0.9912921>,
      <0.6142330, 0.9883895>,
      <0.6523086, 0.9912921>,
      <0.6142330, 0.9941947>,
      <0.6142330, 0.9970974>,
      <0.5761574, 0.9941947>,
      <0.6523086, 0.9941947>,
      <0.6523086, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6142330, 0.9941947>,
      <0.6523086, 0.9970974>,
      <0.6142330, 1.0000000>,
      <0.5761574, 0.9970974>,
      <0.5380817, 0.9970974>,
      <0.5761574, 0.9941947>,
      <0.5761574, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5000061, 0.9941947>,
      <0.5761574, 0.9970974>,
      <0.5380817, 1.0000000>,
      <0.5000061, 0.9970974>,
      <0.5380817, 0.9941947>,
      <0.6680764, 0.9912921>,
      <0.6838443, 0.9941947>,
      <0.6523086, 0.9941947>,
      <0.6523086, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6680765, 0.9941947>,
      <0.6523086, 0.9912921>,
      <0.6680764, 0.9883895>,
      <0.6838443, 0.9912921>,
      <0.6996122, 0.9912921>,
      <0.6838443, 0.9941947>,
      <0.6838443, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 0.9941947>,
      <0.6838443, 0.9912921>,
      <0.6996122, 0.9883895>,
      <0.7153801, 0.9912921>,
      <0.6996122, 0.9941947>,
      <0.6996122, 0.9970974>,
      <0.6838443, 0.9941947>,
      <0.7153801, 0.9941947>,
      <0.7153801, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.6996122, 0.9941947>,
      <0.7153801, 0.9970974>,
      <0.6996122, 1.0000000>,
      <0.6838443, 0.9970974>,
      <0.6680764, 0.9970974>,
      <0.6838443, 0.9941947>,
      <0.6838443, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6523086, 0.9941947>,
      <0.6838443, 0.9970974>,
      <0.6680764, 1.0000000>,
      <0.6523086, 0.9970974>,
      <0.6680765, 0.9941947>
    }
    texture_list {
      1,
      texture { T_Pierre }
    }
    face_indices {
      1056,   // 0 triangles and 528 quads
      <8, 7, 0>, 0,
      <8, 0, 4>, 0,
      <8, 4, 1>, 0,
      <8, 1, 5>, 0,
      <8, 5, 2>, 0,
      <8, 2, 6>, 0,
      <8, 6, 3>, 0,
      <8, 3, 7>, 0,
      <14, 13, 0>, 0,
      <14, 0, 7>, 0,
      <14, 7, 3>, 0,
      <14, 3, 11>, 0,
      <14, 11, 9>, 0,
      <14, 9, 12>, 0,
      <14, 12, 10>, 0,
      <14, 10, 13>, 0,
      <20, 19, 0>, 0,
      <20, 0, 13>, 0,
      <20, 13, 10>, 0,
      <20, 10, 17>, 0,
      <20, 17, 15>, 0,
      <20, 15, 18>, 0,
      <20, 18, 16>, 0,
      <20, 16, 19>, 0,
      <24, 4, 0>, 0,
      <24, 0, 19>, 0,
      <24, 19, 16>, 0,
      <24, 16, 22>, 0,
      <24, 22, 21>, 0,
      <24, 21, 23>, 0,
      <24, 23, 1>, 0,
      <24, 1, 4>, 0,
      <33, 32, 25>, 0,
      <33, 25, 29>, 0,
      <33, 29, 26>, 0,
      <33, 26, 30>, 0,
      <33, 30, 27>, 0,
      <33, 27, 31>, 0,
      <33, 31, 28>, 0,
      <33, 28, 32>, 0,
      <39, 38, 25>, 0,
      <39, 25, 32>, 0,
      <39, 32, 28>, 0,
      <39, 28, 36>, 0,
      <39, 36, 34>, 0,
      <39, 34, 37>, 0,
      <39, 37, 35>, 0,
      <39, 35, 38>, 0,
      <45, 44, 25>, 0,
      <45, 25, 38>, 0,
      <45, 38, 35>, 0,
      <45, 35, 42>, 0,
      <45, 42, 40>, 0,
      <45, 40, 43>, 0,
      <45, 43, 41>, 0,
      <45, 41, 44>, 0,
      <49, 29, 25>, 0,
      <49, 25, 44>, 0,
      <49, 44, 41>, 0,
      <49, 41, 47>, 0,
      <49, 47, 46>, 0,
      <49, 46, 48>, 0,
      <49, 48, 26>, 0,
      <49, 26, 29>, 0,
      <55, 54, 50>, 0,
      <55, 50, 52>, 0,
      <55, 52, 35>, 0,
      <55, 35, 37>, 0,
      <55, 37, 34>, 0,
      <55, 34, 53>, 0,
      <55, 53, 51>, 0,
      <55, 51, 54>, 0,
      <61, 60, 50>, 0,
      <61, 50, 54>, 0,
      <61, 54, 51>, 0,
      <61, 51, 58>, 0,
      <61, 58, 56>, 0,
      <61, 56, 59>, 0,
      <61, 59, 57>, 0,
      <61, 57, 60>, 0,
      <67, 66, 50>, 0,
      <67, 50, 60>, 0,
      <67, 60, 57>, 0,
      <67, 57, 64>, 0,
      <67, 64, 62>, 0,
      <67, 62, 65>, 0,
      <67, 65, 63>, 0,
      <67, 63, 66>, 0,
      <69, 52, 50>, 0,
      <69, 50, 66>, 0,
      <69, 66, 63>, 0,
      <69, 63, 68>, 0,
      <69, 68, 40>, 0,
      <69, 40, 42>, 0,
      <69, 42, 35>, 0,
      <69, 35, 52>, 0,
      <75, 74, 70>, 0,
      <75, 70, 72>, 0,
      <75, 72, 57>, 0,
      <75, 57, 59>, 0,
      <75, 59, 56>, 0,
      <75, 56, 73>, 0,
      <75, 73, 71>, 0,
      <75, 71, 74>, 0,
      <81, 80, 70>, 0,
      <81, 70, 74>, 0,
      <81, 74, 71>, 0,
      <81, 71, 78>, 0,
      <81, 78, 76>, 0,
      <81, 76, 79>, 0,
      <81, 79, 77>, 0,
      <81, 77, 80>, 0,
      <87, 86, 70>, 0,
      <87, 70, 80>, 0,
      <87, 80, 77>, 0,
      <87, 77, 84>, 0,
      <87, 84, 82>, 0,
      <87, 82, 85>, 0,
      <87, 85, 83>, 0,
      <87, 83, 86>, 0,
      <89, 72, 70>, 0,
      <89, 70, 86>, 0,
      <89, 86, 83>, 0,
      <89, 83, 88>, 0,
      <89, 88, 62>, 0,
      <89, 62, 64>, 0,
      <89, 64, 57>, 0,
      <89, 57, 72>, 0,
      <95, 94, 90>, 0,
      <95, 90, 92>, 0,
      <95, 92, 91>, 0,
      <95, 91, 93>, 0,
      <95, 93, 46>, 0,
      <95, 46, 47>, 0,
      <95, 47, 41>, 0,
      <95, 41, 94>, 0,
      <99, 98, 90>, 0,
      <99, 90, 94>, 0,
      <99, 94, 41>, 0,
      <99, 41, 43>, 0,
      <99, 43, 40>, 0,
      <99, 40, 97>, 0,
      <99, 97, 96>, 0,
      <99, 96, 98>, 0,
      <105, 104, 90>, 0,
      <105, 90, 98>, 0,
      <105, 98, 96>, 0,
      <105, 96, 102>, 0,
      <105, 102, 100>, 0,
      <105, 100, 103>, 0,
      <105, 103, 101>, 0,
      <105, 101, 104>, 0,
      <109, 92, 90>, 0,
      <109, 90, 104>, 0,
      <109, 104, 101>, 0,
      <109, 101, 107>, 0,
      <109, 107, 106>, 0,
      <109, 106, 108>, 0,
      <109, 108, 91>, 0,
      <109, 91, 92>, 0,
      <113, 112, 110>, 0,
      <113, 110, 111>, 0,
      <113, 111, 96>, 0,
      <113, 96, 97>, 0,
      <113, 97, 40>, 0,
      <113, 40, 68>, 0,
      <113, 68, 63>, 0,
      <113, 63, 112>, 0,
      <117, 116, 110>, 0,
      <117, 110, 112>, 0,
      <117, 112, 63>, 0,
      <117, 63, 65>, 0,
      <117, 65, 62>, 0,
      <117, 62, 115>, 0,
      <117, 115, 114>, 0,
      <117, 114, 116>, 0,
      <123, 122, 110>, 0,
      <123, 110, 116>, 0,
      <123, 116, 114>, 0,
      <123, 114, 120>, 0,
      <123, 120, 118>, 0,
      <123, 118, 121>, 0,
      <123, 121, 119>, 0,
      <123, 119, 122>, 0,
      <125, 111, 110>, 0,
      <125, 110, 122>, 0,
      <125, 122, 119>, 0,
      <125, 119, 124>, 0,
      <125, 124, 100>, 0,
      <125, 100, 102>, 0,
      <125, 102, 96>, 0,
      <125, 96, 111>, 0,
      <129, 128, 126>, 0,
      <129, 126, 127>, 0,
      <129, 127, 114>, 0,
      <129, 114, 115>, 0,
      <129, 115, 62>, 0,
      <129, 62, 88>, 0,
      <129, 88, 83>, 0,
      <129, 83, 128>, 0,
      <133, 132, 126>, 0,
      <133, 126, 128>, 0,
      <133, 128, 83>, 0,
      <133, 83, 85>, 0,
      <133, 85, 82>, 0,
      <133, 82, 131>, 0,
      <133, 131, 130>, 0,
      <133, 130, 132>, 0,
      <139, 138, 126>, 0,
      <139, 126, 132>, 0,
      <139, 132, 130>, 0,
      <139, 130, 136>, 0,
      <139, 136, 134>, 0,
      <139, 134, 137>, 0,
      <139, 137, 135>, 0,
      <139, 135, 138>, 0,
      <141, 127, 126>, 0,
      <141, 126, 138>, 0,
      <141, 138, 135>, 0,
      <141, 135, 140>, 0,
      <141, 140, 118>, 0,
      <141, 118, 120>, 0,
      <141, 120, 114>, 0,
      <141, 114, 127>, 0,
      <147, 146, 142>, 0,
      <147, 142, 144>, 0,
      <147, 144, 143>, 0,
      <147, 143, 145>, 0,
      <147, 145, 106>, 0,
      <147, 106, 107>, 0,
      <147, 107, 101>, 0,
      <147, 101, 146>, 0,
      <151, 150, 142>, 0,
      <151, 142, 146>, 0,
      <151, 146, 101>, 0,
      <151, 101, 103>, 0,
      <151, 103, 100>, 0,
      <151, 100, 149>, 0,
      <151, 149, 148>, 0,
      <151, 148, 150>, 0,
      <157, 156, 142>, 0,
      <157, 142, 150>, 0,
      <157, 150, 148>, 0,
      <157, 148, 154>, 0,
      <157, 154, 152>, 0,
      <157, 152, 155>, 0,
      <157, 155, 153>, 0,
      <157, 153, 156>, 0,
      <161, 144, 142>, 0,
      <161, 142, 156>, 0,
      <161, 156, 153>, 0,
      <161, 153, 159>, 0,
      <161, 159, 158>, 0,
      <161, 158, 160>, 0,
      <161, 160, 143>, 0,
      <161, 143, 144>, 0,
      <165, 164, 162>, 0,
      <165, 162, 163>, 0,
      <165, 163, 148>, 0,
      <165, 148, 149>, 0,
      <165, 149, 100>, 0,
      <165, 100, 124>, 0,
      <165, 124, 119>, 0,
      <165, 119, 164>, 0,
      <169, 168, 162>, 0,
      <169, 162, 164>, 0,
      <169, 164, 119>, 0,
      <169, 119, 121>, 0,
      <169, 121, 118>, 0,
      <169, 118, 167>, 0,
      <169, 167, 166>, 0,
      <169, 166, 168>, 0,
      <175, 174, 162>, 0,
      <175, 162, 168>, 0,
      <175, 168, 166>, 0,
      <175, 166, 172>, 0,
      <175, 172, 170>, 0,
      <175, 170, 173>, 0,
      <175, 173, 171>, 0,
      <175, 171, 174>, 0,
      <177, 163, 162>, 0,
      <177, 162, 174>, 0,
      <177, 174, 171>, 0,
      <177, 171, 176>, 0,
      <177, 176, 152>, 0,
      <177, 152, 154>, 0,
      <177, 154, 148>, 0,
      <177, 148, 163>, 0,
      <181, 180, 178>, 0,
      <181, 178, 179>, 0,
      <181, 179, 166>, 0,
      <181, 166, 167>, 0,
      <181, 167, 118>, 0,
      <181, 118, 140>, 0,
      <181, 140, 135>, 0,
      <181, 135, 180>, 0,
      <185, 184, 178>, 0,
      <185, 178, 180>, 0,
      <185, 180, 135>, 0,
      <185, 135, 137>, 0,
      <185, 137, 134>, 0,
      <185, 134, 183>, 0,
      <185, 183, 182>, 0,
      <185, 182, 184>, 0,
      <191, 190, 178>, 0,
      <191, 178, 184>, 0,
      <191, 184, 182>, 0,
      <191, 182, 188>, 0,
      <191, 188, 186>, 0,
      <191, 186, 189>, 0,
      <191, 189, 187>, 0,
      <191, 187, 190>, 0,
      <193, 179, 178>, 0,
      <193, 178, 190>, 0,
      <193, 190, 187>, 0,
      <193, 187, 192>, 0,
      <193, 192, 170>, 0,
      <193, 170, 172>, 0,
      <193, 172, 166>, 0,
      <193, 166, 179>, 0,
      <199, 198, 194>, 0,
      <199, 194, 196>, 0,
      <199, 196, 195>, 0,
      <199, 195, 197>, 0,
      <199, 197, 158>, 0,
      <199, 158, 159>, 0,
      <199, 159, 153>, 0,
      <199, 153, 198>, 0,
      <203, 202, 194>, 0,
      <203, 194, 198>, 0,
      <203, 198, 153>, 0,
      <203, 153, 155>, 0,
      <203, 155, 152>, 0,
      <203, 152, 201>, 0,
      <203, 201, 200>, 0,
      <203, 200, 202>, 0,
      <209, 208, 194>, 0,
      <209, 194, 202>, 0,
      <209, 202, 200>, 0,
      <209, 200, 206>, 0,
      <209, 206, 204>, 0,
      <209, 204, 207>, 0,
      <209, 207, 205>, 0,
      <209, 205, 208>, 0,
      <213, 196, 194>, 0,
      <213, 194, 208>, 0,
      <213, 208, 205>, 0,
      <213, 205, 211>, 0,
      <213, 211, 210>, 0,
      <213, 210, 212>, 0,
      <213, 212, 195>, 0,
      <213, 195, 196>, 0,
      <217, 216, 214>, 0,
      <217, 214, 215>, 0,
      <217, 215, 200>, 0,
      <217, 200, 201>, 0,
      <217, 201, 152>, 0,
      <217, 152, 176>, 0,
      <217, 176, 171>, 0,
      <217, 171, 216>, 0,
      <221, 220, 214>, 0,
      <221, 214, 216>, 0,
      <221, 216, 171>, 0,
      <221, 171, 173>, 0,
      <221, 173, 170>, 0,
      <221, 170, 219>, 0,
      <221, 219, 218>, 0,
      <221, 218, 220>, 0,
      <227, 226, 214>, 0,
      <227, 214, 220>, 0,
      <227, 220, 218>, 0,
      <227, 218, 224>, 0,
      <227, 224, 222>, 0,
      <227, 222, 225>, 0,
      <227, 225, 223>, 0,
      <227, 223, 226>, 0,
      <229, 215, 214>, 0,
      <229, 214, 226>, 0,
      <229, 226, 223>, 0,
      <229, 223, 228>, 0,
      <229, 228, 204>, 0,
      <229, 204, 206>, 0,
      <229, 206, 200>, 0,
      <229, 200, 215>, 0,
      <233, 232, 230>, 0,
      <233, 230, 231>, 0,
      <233, 231, 218>, 0,
      <233, 218, 219>, 0,
      <233, 219, 170>, 0,
      <233, 170, 192>, 0,
      <233, 192, 187>, 0,
      <233, 187, 232>, 0,
      <237, 236, 230>, 0,
      <237, 230, 232>, 0,
      <237, 232, 187>, 0,
      <237, 187, 189>, 0,
      <237, 189, 186>, 0,
      <237, 186, 235>, 0,
      <237, 235, 234>, 0,
      <237, 234, 236>, 0,
      <243, 242, 230>, 0,
      <243, 230, 236>, 0,
      <243, 236, 234>, 0,
      <243, 234, 240>, 0,
      <243, 240, 238>, 0,
      <243, 238, 241>, 0,
      <243, 241, 239>, 0,
      <243, 239, 242>, 0,
      <245, 231, 230>, 0,
      <245, 230, 242>, 0,
      <245, 242, 239>, 0,
      <245, 239, 244>, 0,
      <245, 244, 222>, 0,
      <245, 222, 224>, 0,
      <245, 224, 218>, 0,
      <245, 218, 231>, 0,
      <251, 250, 246>, 0,
      <251, 246, 248>, 0,
      <251, 248, 247>, 0,
      <251, 247, 249>, 0,
      <251, 249, 210>, 0,
      <251, 210, 211>, 0,
      <251, 211, 205>, 0,
      <251, 205, 250>, 0,
      <255, 254, 246>, 0,
      <255, 246, 250>, 0,
      <255, 250, 205>, 0,
      <255, 205, 207>, 0,
      <255, 207, 204>, 0,
      <255, 204, 253>, 0,
      <255, 253, 252>, 0,
      <255, 252, 254>, 0,
      <261, 260, 246>, 0,
      <261, 246, 254>, 0,
      <261, 254, 252>, 0,
      <261, 252, 258>, 0,
      <261, 258, 256>, 0,
      <261, 256, 259>, 0,
      <261, 259, 257>, 0,
      <261, 257, 260>, 0,
      <265, 248, 246>, 0,
      <265, 246, 260>, 0,
      <265, 260, 257>, 0,
      <265, 257, 263>, 0,
      <265, 263, 262>, 0,
      <265, 262, 264>, 0,
      <265, 264, 247>, 0,
      <265, 247, 248>, 0,
      <269, 268, 266>, 0,
      <269, 266, 267>, 0,
      <269, 267, 252>, 0,
      <269, 252, 253>, 0,
      <269, 253, 204>, 0,
      <269, 204, 228>, 0,
      <269, 228, 223>, 0,
      <269, 223, 268>, 0,
      <273, 272, 266>, 0,
      <273, 266, 268>, 0,
      <273, 268, 223>, 0,
      <273, 223, 225>, 0,
      <273, 225, 222>, 0,
      <273, 222, 271>, 0,
      <273, 271, 270>, 0,
      <273, 270, 272>, 0,
      <279, 278, 266>, 0,
      <279, 266, 272>, 0,
      <279, 272, 270>, 0,
      <279, 270, 276>, 0,
      <279, 276, 274>, 0,
      <279, 274, 277>, 0,
      <279, 277, 275>, 0,
      <279, 275, 278>, 0,
      <281, 267, 266>, 0,
      <281, 266, 278>, 0,
      <281, 278, 275>, 0,
      <281, 275, 280>, 0,
      <281, 280, 256>, 0,
      <281, 256, 258>, 0,
      <281, 258, 252>, 0,
      <281, 252, 267>, 0,
      <285, 284, 282>, 0,
      <285, 282, 283>, 0,
      <285, 283, 270>, 0,
      <285, 270, 271>, 0,
      <285, 271, 222>, 0,
      <285, 222, 244>, 0,
      <285, 244, 239>, 0,
      <285, 239, 284>, 0,
      <289, 288, 282>, 0,
      <289, 282, 284>, 0,
      <289, 284, 239>, 0,
      <289, 239, 241>, 0,
      <289, 241, 238>, 0,
      <289, 238, 287>, 0,
      <289, 287, 286>, 0,
      <289, 286, 288>, 0,
      <295, 294, 282>, 0,
      <295, 282, 288>, 0,
      <295, 288, 286>, 0,
      <295, 286, 292>, 0,
      <295, 292, 290>, 0,
      <295, 290, 293>, 0,
      <295, 293, 291>, 0,
      <295, 291, 294>, 0,
      <297, 283, 282>, 0,
      <297, 282, 294>, 0,
      <297, 294, 291>, 0,
      <297, 291, 296>, 0,
      <297, 296, 274>, 0,
      <297, 274, 276>, 0,
      <297, 276, 270>, 0,
      <297, 270, 283>, 0,
      <303, 302, 298>, 0,
      <303, 298, 300>, 0,
      <303, 300, 299>, 0,
      <303, 299, 301>, 0,
      <303, 301, 262>, 0,
      <303, 262, 263>, 0,
      <303, 263, 257>, 0,
      <303, 257, 302>, 0,
      <307, 306, 298>, 0,
      <307, 298, 302>, 0,
      <307, 302, 257>, 0,
      <307, 257, 259>, 0,
      <307, 259, 256>, 0,
      <307, 256, 305>, 0,
      <307, 305, 304>, 0,
      <307, 304, 306>, 0,
      <313, 312, 298>, 0,
      <313, 298, 306>, 0,
      <313, 306, 304>, 0,
      <313, 304, 310>, 0,
      <313, 310, 308>, 0,
      <313, 308, 311>, 0,
      <313, 311, 309>, 0,
      <313, 309, 312>, 0,
      <317, 300, 298>, 0,
      <317, 298, 312>, 0,
      <317, 312, 309>, 0,
      <317, 309, 315>, 0,
      <317, 315, 314>, 0,
      <317, 314, 316>, 0,
      <317, 316, 299>, 0,
      <317, 299, 300>, 0,
      <321, 320, 318>, 0,
      <321, 318, 319>, 0,
      <321, 319, 304>, 0,
      <321, 304, 305>, 0,
      <321, 305, 256>, 0,
      <321, 256, 280>, 0,
      <321, 280, 275>, 0,
      <321, 275, 320>, 0,
      <325, 324, 318>, 0,
      <325, 318, 320>, 0,
      <325, 320, 275>, 0,
      <325, 275, 277>, 0,
      <325, 277, 274>, 0,
      <325, 274, 323>, 0,
      <325, 323, 322>, 0,
      <325, 322, 324>, 0,
      <331, 330, 318>, 0,
      <331, 318, 324>, 0,
      <331, 324, 322>, 0,
      <331, 322, 328>, 0,
      <331, 328, 326>, 0,
      <331, 326, 329>, 0,
      <331, 329, 327>, 0,
      <331, 327, 330>, 0,
      <333, 319, 318>, 0,
      <333, 318, 330>, 0,
      <333, 330, 327>, 0,
      <333, 327, 332>, 0,
      <333, 332, 308>, 0,
      <333, 308, 310>, 0,
      <333, 310, 304>, 0,
      <333, 304, 319>, 0,
      <337, 336, 334>, 0,
      <337, 334, 335>, 0,
      <337, 335, 322>, 0,
      <337, 322, 323>, 0,
      <337, 323, 274>, 0,
      <337, 274, 296>, 0,
      <337, 296, 291>, 0,
      <337, 291, 336>, 0,
      <341, 340, 334>, 0,
      <341, 334, 336>, 0,
      <341, 336, 291>, 0,
      <341, 291, 293>, 0,
      <341, 293, 290>, 0,
      <341, 290, 339>, 0,
      <341, 339, 338>, 0,
      <341, 338, 340>, 0,
      <347, 346, 334>, 0,
      <347, 334, 340>, 0,
      <347, 340, 338>, 0,
      <347, 338, 344>, 0,
      <347, 344, 342>, 0,
      <347, 342, 345>, 0,
      <347, 345, 343>, 0,
      <347, 343, 346>, 0,
      <349, 335, 334>, 0,
      <349, 334, 346>, 0,
      <349, 346, 343>, 0,
      <349, 343, 348>, 0,
      <349, 348, 326>, 0,
      <349, 326, 328>, 0,
      <349, 328, 322>, 0,
      <349, 322, 335>, 0,
      <355, 354, 350>, 0,
      <355, 350, 352>, 0,
      <355, 352, 351>, 0,
      <355, 351, 353>, 0,
      <355, 353, 314>, 0,
      <355, 314, 315>, 0,
      <355, 315, 309>, 0,
      <355, 309, 354>, 0,
      <359, 358, 350>, 0,
      <359, 350, 354>, 0,
      <359, 354, 309>, 0,
      <359, 309, 311>, 0,
      <359, 311, 308>, 0,
      <359, 308, 357>, 0,
      <359, 357, 356>, 0,
      <359, 356, 358>, 0,
      <365, 364, 350>, 0,
      <365, 350, 358>, 0,
      <365, 358, 356>, 0,
      <365, 356, 362>, 0,
      <365, 362, 360>, 0,
      <365, 360, 363>, 0,
      <365, 363, 361>, 0,
      <365, 361, 364>, 0,
      <369, 352, 350>, 0,
      <369, 350, 364>, 0,
      <369, 364, 361>, 0,
      <369, 361, 367>, 0,
      <369, 367, 366>, 0,
      <369, 366, 368>, 0,
      <369, 368, 351>, 0,
      <369, 351, 352>, 0,
      <373, 372, 370>, 0,
      <373, 370, 371>, 0,
      <373, 371, 356>, 0,
      <373, 356, 357>, 0,
      <373, 357, 308>, 0,
      <373, 308, 332>, 0,
      <373, 332, 327>, 0,
      <373, 327, 372>, 0,
      <377, 376, 370>, 0,
      <377, 370, 372>, 0,
      <377, 372, 327>, 0,
      <377, 327, 329>, 0,
      <377, 329, 326>, 0,
      <377, 326, 375>, 0,
      <377, 375, 374>, 0,
      <377, 374, 376>, 0,
      <383, 382, 370>, 0,
      <383, 370, 376>, 0,
      <383, 376, 374>, 0,
      <383, 374, 380>, 0,
      <383, 380, 378>, 0,
      <383, 378, 381>, 0,
      <383, 381, 379>, 0,
      <383, 379, 382>, 0,
      <385, 371, 370>, 0,
      <385, 370, 382>, 0,
      <385, 382, 379>, 0,
      <385, 379, 384>, 0,
      <385, 384, 360>, 0,
      <385, 360, 362>, 0,
      <385, 362, 356>, 0,
      <385, 356, 371>, 0,
      <389, 388, 386>, 0,
      <389, 386, 387>, 0,
      <389, 387, 374>, 0,
      <389, 374, 375>, 0,
      <389, 375, 326>, 0,
      <389, 326, 348>, 0,
      <389, 348, 343>, 0,
      <389, 343, 388>, 0,
      <393, 392, 386>, 0,
      <393, 386, 388>, 0,
      <393, 388, 343>, 0,
      <393, 343, 345>, 0,
      <393, 345, 342>, 0,
      <393, 342, 391>, 0,
      <393, 391, 390>, 0,
      <393, 390, 392>, 0,
      <399, 398, 386>, 0,
      <399, 386, 392>, 0,
      <399, 392, 390>, 0,
      <399, 390, 396>, 0,
      <399, 396, 394>, 0,
      <399, 394, 397>, 0,
      <399, 397, 395>, 0,
      <399, 395, 398>, 0,
      <401, 387, 386>, 0,
      <401, 386, 398>, 0,
      <401, 398, 395>, 0,
      <401, 395, 400>, 0,
      <401, 400, 378>, 0,
      <401, 378, 380>, 0,
      <401, 380, 374>, 0,
      <401, 374, 387>, 0,
      <407, 406, 402>, 0,
      <407, 402, 404>, 0,
      <407, 404, 403>, 0,
      <407, 403, 405>, 0,
      <407, 405, 366>, 0,
      <407, 366, 367>, 0,
      <407, 367, 361>, 0,
      <407, 361, 406>, 0,
      <411, 410, 402>, 0,
      <411, 402, 406>, 0,
      <411, 406, 361>, 0,
      <411, 361, 363>, 0,
      <411, 363, 360>, 0,
      <411, 360, 409>, 0,
      <411, 409, 408>, 0,
      <411, 408, 410>, 0,
      <414, 413, 402>, 0,
      <414, 402, 410>, 0,
      <414, 410, 408>, 0,
      <414, 408, 412>, 0,
      <414, 412, 9>, 0,
      <414, 9, 11>, 0,
      <414, 11, 3>, 0,
      <414, 3, 413>, 0,
      <416, 404, 402>, 0,
      <416, 402, 413>, 0,
      <416, 413, 3>, 0,
      <416, 3, 6>, 0,
      <416, 6, 2>, 0,
      <416, 2, 415>, 0,
      <416, 415, 403>, 0,
      <416, 403, 404>, 0,
      <420, 419, 417>, 0,
      <420, 417, 418>, 0,
      <420, 418, 408>, 0,
      <420, 408, 409>, 0,
      <420, 409, 360>, 0,
      <420, 360, 384>, 0,
      <420, 384, 379>, 0,
      <420, 379, 419>, 0,
      <424, 423, 417>, 0,
      <424, 417, 419>, 0,
      <424, 419, 379>, 0,
      <424, 379, 381>, 0,
      <424, 381, 378>, 0,
      <424, 378, 422>, 0,
      <424, 422, 421>, 0,
      <424, 421, 423>, 0,
      <427, 426, 417>, 0,
      <427, 417, 423>, 0,
      <427, 423, 421>, 0,
      <427, 421, 425>, 0,
      <427, 425, 15>, 0,
      <427, 15, 17>, 0,
      <427, 17, 10>, 0,
      <427, 10, 426>, 0,
      <428, 418, 417>, 0,
      <428, 417, 426>, 0,
      <428, 426, 10>, 0,
      <428, 10, 12>, 0,
      <428, 12, 9>, 0,
      <428, 9, 412>, 0,
      <428, 412, 408>, 0,
      <428, 408, 418>, 0,
      <432, 431, 429>, 0,
      <432, 429, 430>, 0,
      <432, 430, 421>, 0,
      <432, 421, 422>, 0,
      <432, 422, 378>, 0,
      <432, 378, 400>, 0,
      <432, 400, 395>, 0,
      <432, 395, 431>, 0,
      <436, 435, 429>, 0,
      <436, 429, 431>, 0,
      <436, 431, 395>, 0,
      <436, 395, 397>, 0,
      <436, 397, 394>, 0,
      <436, 394, 434>, 0,
      <436, 434, 433>, 0,
      <436, 433, 435>, 0,
      <439, 438, 429>, 0,
      <439, 429, 435>, 0,
      <439, 435, 433>, 0,
      <439, 433, 437>, 0,
      <439, 437, 21>, 0,
      <439, 21, 22>, 0,
      <439, 22, 16>, 0,
      <439, 16, 438>, 0,
      <440, 430, 429>, 0,
      <440, 429, 438>, 0,
      <440, 438, 16>, 0,
      <440, 16, 18>, 0,
      <440, 18, 15>, 0,
      <440, 15, 425>, 0,
      <440, 425, 421>, 0,
      <440, 421, 430>, 0,
      <448, 447, 441>, 0,
      <448, 441, 444>, 0,
      <448, 444, 442>, 0,
      <448, 442, 445>, 0,
      <448, 445, 366>, 0,
      <448, 366, 446>, 0,
      <448, 446, 443>, 0,
      <448, 443, 447>, 0,
      <453, 452, 441>, 0,
      <453, 441, 447>, 0,
      <453, 447, 443>, 0,
      <453, 443, 450>, 0,
      <453, 450, 394>, 0,
      <453, 394, 451>, 0,
      <453, 451, 449>, 0,
      <453, 449, 452>, 0,
      <458, 457, 441>, 0,
      <458, 441, 452>, 0,
      <458, 452, 449>, 0,
      <458, 449, 455>, 0,
      <458, 455, 21>, 0,
      <458, 21, 456>, 0,
      <458, 456, 454>, 0,
      <458, 454, 457>, 0,
      <461, 444, 441>, 0,
      <461, 441, 457>, 0,
      <461, 457, 454>, 0,
      <461, 454, 459>, 0,
      <461, 459, 2>, 0,
      <461, 2, 460>, 0,
      <461, 460, 442>, 0,
      <461, 442, 444>, 0,
      <467, 466, 462>, 0,
      <467, 462, 464>, 0,
      <467, 464, 463>, 0,
      <467, 463, 465>, 0,
      <467, 465, 314>, 0,
      <467, 314, 353>, 0,
      <467, 353, 351>, 0,
      <467, 351, 466>, 0,
      <471, 470, 462>, 0,
      <471, 462, 466>, 0,
      <471, 466, 351>, 0,
      <471, 351, 368>, 0,
      <471, 368, 366>, 0,
      <471, 366, 469>, 0,
      <471, 469, 468>, 0,
      <471, 468, 470>, 0,
      <474, 473, 462>, 0,
      <474, 462, 470>, 0,
      <474, 470, 468>, 0,
      <474, 468, 472>, 0,
      <474, 472, 394>, 0,
      <474, 394, 396>, 0,
      <474, 396, 390>, 0,
      <474, 390, 473>, 0,
      <476, 464, 462>, 0,
      <476, 462, 473>, 0,
      <476, 473, 390>, 0,
      <476, 390, 391>, 0,
      <476, 391, 342>, 0,
      <476, 342, 475>, 0,
      <476, 475, 463>, 0,
      <476, 463, 464>, 0,
      <484, 483, 477>, 0,
      <484, 477, 480>, 0,
      <484, 480, 478>, 0,
      <484, 478, 481>, 0,
      <484, 481, 262>, 0,
      <484, 262, 482>, 0,
      <484, 482, 479>, 0,
      <484, 479, 483>, 0,
      <489, 488, 477>, 0,
      <489, 477, 483>, 0,
      <489, 483, 479>, 0,
      <489, 479, 486>, 0,
      <489, 486, 290>, 0,
      <489, 290, 487>, 0,
      <489, 487, 485>, 0,
      <489, 485, 488>, 0,
      <494, 493, 477>, 0,
      <494, 477, 488>, 0,
      <494, 488, 485>, 0,
      <494, 485, 491>, 0,
      <494, 491, 342>, 0,
      <494, 342, 492>, 0,
      <494, 492, 490>, 0,
      <494, 490, 493>, 0,
      <497, 480, 477>, 0,
      <497, 477, 493>, 0,
      <497, 493, 490>, 0,
      <497, 490, 495>, 0,
      <497, 495, 314>, 0,
      <497, 314, 496>, 0,
      <497, 496, 478>, 0,
      <497, 478, 480>, 0,
      <503, 502, 498>, 0,
      <503, 498, 500>, 0,
      <503, 500, 499>, 0,
      <503, 499, 501>, 0,
      <503, 501, 210>, 0,
      <503, 210, 249>, 0,
      <503, 249, 247>, 0,
      <503, 247, 502>, 0,
      <507, 506, 498>, 0,
      <507, 498, 502>, 0,
      <507, 502, 247>, 0,
      <507, 247, 264>, 0,
      <507, 264, 262>, 0,
      <507, 262, 505>, 0,
      <507, 505, 504>, 0,
      <507, 504, 506>, 0,
      <510, 509, 498>, 0,
      <510, 498, 506>, 0,
      <510, 506, 504>, 0,
      <510, 504, 508>, 0,
      <510, 508, 290>, 0,
      <510, 290, 292>, 0,
      <510, 292, 286>, 0,
      <510, 286, 509>, 0,
      <512, 500, 498>, 0,
      <512, 498, 509>, 0,
      <512, 509, 286>, 0,
      <512, 286, 287>, 0,
      <512, 287, 238>, 0,
      <512, 238, 511>, 0,
      <512, 511, 499>, 0,
      <512, 499, 500>, 0,
      <520, 519, 513>, 0,
      <520, 513, 516>, 0,
      <520, 516, 514>, 0,
      <520, 514, 517>, 0,
      <520, 517, 158>, 0,
      <520, 158, 518>, 0,
      <520, 518, 515>, 0,
      <520, 515, 519>, 0,
      <525, 524, 513>, 0,
      <525, 513, 519>, 0,
      <525, 519, 515>, 0,
      <525, 515, 522>, 0,
      <525, 522, 186>, 0,
      <525, 186, 523>, 0,
      <525, 523, 521>, 0,
      <525, 521, 524>, 0,
      <530, 529, 513>, 0,
      <530, 513, 524>, 0,
      <530, 524, 521>, 0,
      <530, 521, 527>, 0,
      <530, 527, 238>, 0,
      <530, 238, 528>, 0,
      <530, 528, 526>, 0,
      <530, 526, 529>, 0,
      <533, 516, 513>, 0,
      <533, 513, 529>, 0,
      <533, 529, 526>, 0,
      <533, 526, 531>, 0,
      <533, 531, 210>, 0,
      <533, 210, 532>, 0,
      <533, 532, 514>, 0,
      <533, 514, 516>, 0,
      <539, 538, 534>, 0,
      <539, 534, 536>, 0,
      <539, 536, 535>, 0,
      <539, 535, 537>, 0,
      <539, 537, 106>, 0,
      <539, 106, 145>, 0,
      <539, 145, 143>, 0,
      <539, 143, 538>, 0,
      <543, 542, 534>, 0,
      <543, 534, 538>, 0,
      <543, 538, 143>, 0,
      <543, 143, 160>, 0,
      <543, 160, 158>, 0,
      <543, 158, 541>, 0,
      <543, 541, 540>, 0,
      <543, 540, 542>, 0,
      <546, 545, 534>, 0,
      <546, 534, 542>, 0,
      <546, 542, 540>, 0,
      <546, 540, 544>, 0,
      <546, 544, 186>, 0,
      <546, 186, 188>, 0,
      <546, 188, 182>, 0,
      <546, 182, 545>, 0,
      <548, 536, 534>, 0,
      <548, 534, 545>, 0,
      <548, 545, 182>, 0,
      <548, 182, 183>, 0,
      <548, 183, 134>, 0,
      <548, 134, 547>, 0,
      <548, 547, 535>, 0,
      <548, 535, 536>, 0,
      <556, 555, 549>, 0,
      <556, 549, 552>, 0,
      <556, 552, 550>, 0,
      <556, 550, 553>, 0,
      <556, 553, 27>, 0,
      <556, 27, 554>, 0,
      <556, 554, 551>, 0,
      <556, 551, 555>, 0,
      <561, 560, 549>, 0,
      <561, 549, 555>, 0,
      <561, 555, 551>, 0,
      <561, 551, 558>, 0,
      <561, 558, 76>, 0,
      <561, 76, 559>, 0,
      <561, 559, 557>, 0,
      <561, 557, 560>, 0,
      <566, 565, 549>, 0,
      <566, 549, 560>, 0,
      <566, 560, 557>, 0,
      <566, 557, 563>, 0,
      <566, 563, 134>, 0,
      <566, 134, 564>, 0,
      <566, 564, 562>, 0,
      <566, 562, 565>, 0,
      <569, 552, 549>, 0,
      <569, 549, 565>, 0,
      <569, 565, 562>, 0,
      <569, 562, 567>, 0,
      <569, 567, 106>, 0,
      <569, 106, 568>, 0,
      <569, 568, 550>, 0,
      <569, 550, 552>, 0,
      <573, 572, 570>, 0,
      <573, 570, 571>, 0,
      <573, 571, 551>, 0,
      <573, 551, 554>, 0,
      <573, 554, 27>, 0,
      <573, 27, 30>, 0,
      <573, 30, 26>, 0,
      <573, 26, 572>, 0,
      <577, 576, 570>, 0,
      <577, 570, 572>, 0,
      <577, 572, 26>, 0,
      <577, 26, 48>, 0,
      <577, 48, 46>, 0,
      <577, 46, 575>, 0,
      <577, 575, 574>, 0,
      <577, 574, 576>, 0,
      <580, 579, 570>, 0,
      <580, 570, 576>, 0,
      <580, 576, 574>, 0,
      <580, 574, 578>, 0,
      <580, 578, 82>, 0,
      <580, 82, 84>, 0,
      <580, 84, 77>, 0,
      <580, 77, 579>, 0,
      <581, 571, 570>, 0,
      <581, 570, 579>, 0,
      <581, 579, 77>, 0,
      <581, 77, 79>, 0,
      <581, 79, 76>, 0,
      <581, 76, 558>, 0,
      <581, 558, 551>, 0,
      <581, 551, 571>, 0
    }
    normal_indices {
      1056,   // from 0 triangles and 528 quads
      <0, 1, 2>,
      <0, 2, 3>,
      <0, 3, 4>,
      <0, 4, 5>,
      <0, 6, 7>,
      <0, 7, 8>,
      <0, 9, 10>,
      <0, 10, 1>,
      <11, 12, 2>,
      <11, 2, 1>,
      <11, 1, 13>,
      <11, 13, 14>,
      <11, 15, 16>,
      <11, 16, 17>,
      <11, 18, 19>,
      <11, 19, 12>,
      <20, 21, 2>,
      <20, 2, 12>,
      <20, 12, 22>,
      <20, 22, 23>,
      <20, 24, 25>,
      <20, 25, 26>,
      <20, 27, 28>,
      <20, 28, 21>,
      <29, 3, 2>,
      <29, 2, 21>,
      <29, 21, 30>,
      <29, 30, 31>,
      <29, 32, 33>,
      <29, 33, 34>,
      <29, 35, 36>,
      <29, 36, 3>,
      <37, 38, 39>,
      <37, 39, 40>,
      <37, 40, 41>,
      <37, 41, 42>,
      <37, 43, 44>,
      <37, 44, 45>,
      <37, 46, 47>,
      <37, 47, 38>,
      <48, 49, 39>,
      <48, 39, 38>,
      <48, 38, 50>,
      <48, 50, 51>,
      <48, 52, 53>,
      <48, 53, 54>,
      <48, 55, 56>,
      <48, 56, 49>,
      <57, 58, 39>,
      <57, 39, 49>,
      <57, 49, 59>,
      <57, 59, 60>,
      <57, 61, 62>,
      <57, 62, 63>,
      <57, 64, 65>,
      <57, 65, 58>,
      <66, 40, 39>,
      <66, 39, 58>,
      <66, 58, 67>,
      <66, 67, 68>,
      <66, 69, 70>,
      <66, 70, 71>,
      <66, 72, 73>,
      <66, 73, 40>,
      <74, 75, 76>,
      <74, 76, 77>,
      <74, 77, 78>,
      <74, 78, 79>,
      <74, 80, 81>,
      <74, 81, 82>,
      <74, 83, 84>,
      <74, 84, 75>,
      <85, 86, 76>,
      <85, 76, 75>,
      <85, 75, 87>,
      <85, 87, 88>,
      <85, 89, 90>,
      <85, 90, 91>,
      <85, 92, 93>,
      <85, 93, 86>,
      <94, 95, 76>,
      <94, 76, 86>,
      <94, 86, 96>,
      <94, 96, 97>,
      <94, 98, 99>,
      <94, 99, 100>,
      <94, 101, 102>,
      <94, 102, 95>,
      <103, 77, 76>,
      <103, 76, 95>,
      <103, 95, 104>,
      <103, 104, 105>,
      <103, 106, 107>,
      <103, 107, 108>,
      <103, 109, 110>,
      <103, 110, 77>,
      <111, 112, 113>,
      <111, 113, 114>,
      <111, 114, 115>,
      <111, 115, 116>,
      <111, 117, 118>,
      <111, 118, 119>,
      <111, 120, 121>,
      <111, 121, 112>,
      <122, 123, 113>,
      <122, 113, 112>,
      <122, 112, 124>,
      <122, 124, 125>,
      <122, 126, 127>,
      <122, 127, 128>,
      <122, 129, 130>,
      <122, 130, 123>,
      <131, 132, 113>,
      <131, 113, 123>,
      <131, 123, 133>,
      <131, 133, 134>,
      <131, 135, 136>,
      <131, 136, 137>,
      <131, 138, 139>,
      <131, 139, 132>,
      <140, 114, 113>,
      <140, 113, 132>,
      <140, 132, 141>,
      <140, 141, 142>,
      <140, 143, 144>,
      <140, 144, 145>,
      <140, 146, 147>,
      <140, 147, 114>,
      <148, 149, 150>,
      <148, 150, 151>,
      <148, 151, 152>,
      <148, 152, 153>,
      <148, 154, 155>,
      <148, 155, 156>,
      <148, 157, 158>,
      <148, 158, 149>,
      <159, 160, 150>,
      <159, 150, 149>,
      <159, 149, 161>,
      <159, 161, 162>,
      <159, 163, 164>,
      <159, 164, 165>,
      <159, 166, 167>,
      <159, 167, 160>,
      <168, 169, 150>,
      <168, 150, 160>,
      <168, 160, 170>,
      <168, 170, 171>,
      <168, 172, 173>,
      <168, 173, 174>,
      <168, 175, 176>,
      <168, 176, 169>,
      <177, 151, 150>,
      <177, 150, 169>,
      <177, 169, 178>,
      <177, 178, 179>,
      <177, 180, 181>,
      <177, 181, 182>,
      <177, 183, 184>,
      <177, 184, 151>,
      <185, 186, 187>,
      <185, 187, 188>,
      <185, 188, 189>,
      <185, 189, 190>,
      <185, 191, 192>,
      <185, 192, 193>,
      <185, 194, 195>,
      <185, 195, 186>,
      <196, 197, 187>,
      <196, 187, 186>,
      <196, 186, 198>,
      <196, 198, 199>,
      <196, 200, 201>,
      <196, 201, 202>,
      <196, 203, 204>,
      <196, 204, 197>,
      <205, 206, 187>,
      <205, 187, 197>,
      <205, 197, 207>,
      <205, 207, 208>,
      <205, 209, 210>,
      <205, 210, 211>,
      <205, 212, 213>,
      <205, 213, 206>,
      <214, 188, 187>,
      <214, 187, 206>,
      <214, 206, 215>,
      <214, 215, 216>,
      <214, 217, 218>,
      <214, 218, 219>,
      <214, 220, 221>,
      <214, 221, 188>,
      <222, 223, 224>,
      <222, 224, 225>,
      <222, 225, 226>,
      <222, 226, 227>,
      <222, 228, 229>,
      <222, 229, 230>,
      <222, 231, 232>,
      <222, 232, 223>,
      <233, 234, 224>,
      <233, 224, 223>,
      <233, 223, 235>,
      <233, 235, 236>,
      <233, 237, 238>,
      <233, 238, 239>,
      <233, 240, 241>,
      <233, 241, 234>,
      <242, 243, 224>,
      <242, 224, 234>,
      <242, 234, 244>,
      <242, 244, 245>,
      <242, 246, 247>,
      <242, 247, 248>,
      <242, 249, 250>,
      <242, 250, 243>,
      <251, 225, 224>,
      <251, 224, 243>,
      <251, 243, 252>,
      <251, 252, 253>,
      <251, 254, 255>,
      <251, 255, 256>,
      <251, 257, 258>,
      <251, 258, 225>,
      <259, 260, 261>,
      <259, 261, 262>,
      <259, 262, 263>,
      <259, 263, 264>,
      <259, 265, 266>,
      <259, 266, 267>,
      <259, 268, 269>,
      <259, 269, 260>,
      <270, 271, 261>,
      <270, 261, 260>,
      <270, 260, 272>,
      <270, 272, 273>,
      <270, 274, 275>,
      <270, 275, 276>,
      <270, 277, 278>,
      <270, 278, 271>,
      <279, 280, 261>,
      <279, 261, 271>,
      <279, 271, 281>,
      <279, 281, 282>,
      <279, 283, 284>,
      <279, 284, 285>,
      <279, 286, 287>,
      <279, 287, 280>,
      <288, 262, 261>,
      <288, 261, 280>,
      <288, 280, 289>,
      <288, 289, 290>,
      <288, 291, 292>,
      <288, 292, 293>,
      <288, 294, 295>,
      <288, 295, 262>,
      <296, 297, 298>,
      <296, 298, 299>,
      <296, 299, 300>,
      <296, 300, 301>,
      <296, 302, 303>,
      <296, 303, 304>,
      <296, 305, 306>,
      <296, 306, 297>,
      <307, 308, 298>,
      <307, 298, 297>,
      <307, 297, 309>,
      <307, 309, 310>,
      <307, 311, 312>,
      <307, 312, 313>,
      <307, 314, 315>,
      <307, 315, 308>,
      <316, 317, 298>,
      <316, 298, 308>,
      <316, 308, 318>,
      <316, 318, 319>,
      <316, 320, 321>,
      <316, 321, 322>,
      <316, 323, 324>,
      <316, 324, 317>,
      <325, 299, 298>,
      <325, 298, 317>,
      <325, 317, 326>,
      <325, 326, 327>,
      <325, 328, 329>,
      <325, 329, 330>,
      <325, 331, 332>,
      <325, 332, 299>,
      <333, 334, 335>,
      <333, 335, 336>,
      <333, 336, 337>,
      <333, 337, 338>,
      <333, 339, 340>,
      <333, 340, 341>,
      <333, 342, 343>,
      <333, 343, 334>,
      <344, 345, 335>,
      <344, 335, 334>,
      <344, 334, 346>,
      <344, 346, 347>,
      <344, 348, 349>,
      <344, 349, 350>,
      <344, 351, 352>,
      <344, 352, 345>,
      <353, 354, 335>,
      <353, 335, 345>,
      <353, 345, 355>,
      <353, 355, 356>,
      <353, 357, 358>,
      <353, 358, 359>,
      <353, 360, 361>,
      <353, 361, 354>,
      <362, 336, 335>,
      <362, 335, 354>,
      <362, 354, 363>,
      <362, 363, 364>,
      <362, 365, 366>,
      <362, 366, 367>,
      <362, 368, 369>,
      <362, 369, 336>,
      <370, 371, 372>,
      <370, 372, 373>,
      <370, 373, 374>,
      <370, 374, 375>,
      <370, 376, 377>,
      <370, 377, 378>,
      <370, 379, 380>,
      <370, 380, 371>,
      <381, 382, 372>,
      <381, 372, 371>,
      <381, 371, 383>,
      <381, 383, 384>,
      <381, 385, 386>,
      <381, 386, 387>,
      <381, 388, 389>,
      <381, 389, 382>,
      <390, 391, 372>,
      <390, 372, 382>,
      <390, 382, 392>,
      <390, 392, 393>,
      <390, 394, 395>,
      <390, 395, 396>,
      <390, 396, 397>,
      <390, 397, 391>,
      <398, 373, 372>,
      <398, 372, 391>,
      <398, 391, 397>,
      <398, 397, 399>,
      <398, 399, 400>,
      <398, 400, 401>,
      <398, 402, 403>,
      <398, 403, 373>,
      <404, 405, 406>,
      <404, 406, 407>,
      <404, 407, 408>,
      <404, 408, 409>,
      <404, 410, 411>,
      <404, 411, 412>,
      <404, 413, 414>,
      <404, 414, 405>,
      <415, 416, 406>,
      <415, 406, 405>,
      <415, 405, 417>,
      <415, 417, 418>,
      <415, 419, 420>,
      <415, 420, 421>,
      <415, 422, 423>,
      <415, 423, 416>,
      <424, 425, 406>,
      <424, 406, 416>,
      <424, 416, 426>,
      <424, 426, 427>,
      <424, 428, 429>,
      <424, 429, 430>,
      <424, 430, 431>,
      <424, 431, 425>,
      <432, 407, 406>,
      <432, 406, 425>,
      <432, 425, 431>,
      <432, 431, 433>,
      <432, 433, 434>,
      <432, 434, 435>,
      <432, 436, 437>,
      <432, 437, 407>,
      <438, 439, 440>,
      <438, 440, 441>,
      <438, 441, 442>,
      <438, 442, 443>,
      <438, 444, 445>,
      <438, 445, 446>,
      <438, 447, 448>,
      <438, 448, 439>,
      <449, 450, 440>,
      <449, 440, 439>,
      <449, 439, 451>,
      <449, 451, 452>,
      <449, 453, 454>,
      <449, 454, 455>,
      <449, 456, 457>,
      <449, 457, 450>,
      <458, 459, 440>,
      <458, 440, 450>,
      <458, 450, 460>,
      <458, 460, 461>,
      <458, 462, 463>,
      <458, 463, 464>,
      <458, 464, 465>,
      <458, 465, 459>,
      <466, 441, 440>,
      <466, 440, 459>,
      <466, 459, 465>,
      <466, 465, 467>,
      <466, 467, 468>,
      <466, 468, 469>,
      <466, 470, 471>,
      <466, 471, 441>,
      <472, 473, 474>,
      <472, 474, 475>,
      <472, 475, 476>,
      <472, 476, 477>,
      <472, 478, 479>,
      <472, 479, 399>,
      <472, 399, 397>,
      <472, 397, 473>,
      <480, 481, 474>,
      <480, 474, 473>,
      <480, 473, 397>,
      <480, 397, 396>,
      <480, 396, 482>,
      <480, 482, 483>,
      <480, 484, 485>,
      <480, 485, 481>,
      <486, 487, 474>,
      <486, 474, 481>,
      <486, 481, 488>,
      <486, 488, 489>,
      <486, 490, 491>,
      <486, 491, 492>,
      <486, 492, 493>,
      <486, 493, 487>,
      <494, 475, 474>,
      <494, 474, 487>,
      <494, 487, 493>,
      <494, 493, 495>,
      <494, 495, 496>,
      <494, 496, 497>,
      <494, 498, 499>,
      <494, 499, 475>,
      <500, 501, 502>,
      <500, 502, 503>,
      <500, 503, 504>,
      <500, 504, 505>,
      <500, 506, 507>,
      <500, 507, 433>,
      <500, 433, 431>,
      <500, 431, 501>,
      <508, 509, 502>,
      <508, 502, 501>,
      <508, 501, 431>,
      <508, 431, 430>,
      <508, 430, 510>,
      <508, 510, 511>,
      <508, 512, 513>,
      <508, 513, 509>,
      <514, 515, 502>,
      <514, 502, 509>,
      <514, 509, 516>,
      <514, 516, 517>,
      <514, 518, 519>,
      <514, 519, 520>,
      <514, 520, 521>,
      <514, 521, 515>,
      <522, 503, 502>,
      <522, 502, 515>,
      <522, 515, 521>,
      <522, 521, 523>,
      <522, 523, 524>,
      <522, 524, 525>,
      <522, 526, 527>,
      <522, 527, 503>,
      <528, 529, 530>,
      <528, 530, 531>,
      <528, 531, 532>,
      <528, 532, 533>,
      <528, 534, 535>,
      <528, 535, 467>,
      <528, 467, 465>,
      <528, 465, 529>,
      <536, 537, 530>,
      <536, 530, 529>,
      <536, 529, 465>,
      <536, 465, 464>,
      <536, 464, 538>,
      <536, 538, 539>,
      <536, 540, 541>,
      <536, 541, 537>,
      <542, 543, 530>,
      <542, 530, 537>,
      <542, 537, 544>,
      <542, 544, 545>,
      <542, 546, 547>,
      <542, 547, 548>,
      <542, 548, 549>,
      <542, 549, 543>,
      <550, 531, 530>,
      <550, 530, 543>,
      <550, 543, 549>,
      <550, 549, 551>,
      <550, 551, 552>,
      <550, 552, 553>,
      <550, 554, 555>,
      <550, 555, 531>,
      <556, 557, 558>,
      <556, 558, 559>,
      <556, 559, 560>,
      <556, 560, 561>,
      <556, 562, 563>,
      <556, 563, 495>,
      <556, 495, 493>,
      <556, 493, 557>,
      <564, 565, 558>,
      <564, 558, 557>,
      <564, 557, 493>,
      <564, 493, 492>,
      <564, 492, 566>,
      <564, 566, 567>,
      <564, 568, 569>,
      <564, 569, 565>,
      <570, 571, 558>,
      <570, 558, 565>,
      <570, 565, 572>,
      <570, 572, 573>,
      <570, 574, 575>,
      <570, 575, 576>,
      <570, 577, 578>,
      <570, 578, 571>,
      <579, 559, 558>,
      <579, 558, 571>,
      <579, 571, 580>,
      <579, 580, 581>,
      <579, 582, 583>,
      <579, 583, 584>,
      <579, 585, 586>,
      <579, 586, 559>,
      <587, 588, 589>,
      <587, 589, 590>,
      <587, 590, 591>,
      <587, 591, 592>,
      <587, 593, 594>,
      <587, 594, 523>,
      <587, 523, 521>,
      <587, 521, 588>,
      <595, 596, 589>,
      <595, 589, 588>,
      <595, 588, 521>,
      <595, 521, 520>,
      <595, 520, 597>,
      <595, 597, 598>,
      <595, 599, 600>,
      <595, 600, 596>,
      <601, 602, 589>,
      <601, 589, 596>,
      <601, 596, 603>,
      <601, 603, 604>,
      <601, 605, 606>,
      <601, 606, 607>,
      <601, 608, 609>,
      <601, 609, 602>,
      <610, 590, 589>,
      <610, 589, 602>,
      <610, 602, 611>,
      <610, 611, 612>,
      <610, 613, 614>,
      <610, 614, 615>,
      <610, 616, 617>,
      <610, 617, 590>,
      <618, 619, 620>,
      <618, 620, 621>,
      <618, 621, 622>,
      <618, 622, 623>,
      <618, 624, 625>,
      <618, 625, 551>,
      <618, 551, 549>,
      <618, 549, 619>,
      <626, 627, 620>,
      <626, 620, 619>,
      <626, 619, 549>,
      <626, 549, 548>,
      <626, 548, 628>,
      <626, 628, 629>,
      <626, 630, 631>,
      <626, 631, 627>,
      <632, 633, 620>,
      <632, 620, 627>,
      <632, 627, 634>,
      <632, 634, 635>,
      <632, 636, 637>,
      <632, 637, 638>,
      <632, 639, 640>,
      <632, 640, 633>,
      <641, 621, 620>,
      <641, 620, 633>,
      <641, 633, 642>,
      <641, 642, 643>,
      <641, 644, 645>,
      <641, 645, 646>,
      <641, 647, 648>,
      <641, 648, 621>,
      <649, 650, 651>,
      <649, 651, 652>,
      <649, 652, 653>,
      <649, 653, 654>,
      <649, 655, 656>,
      <649, 656, 657>,
      <649, 658, 659>,
      <649, 659, 650>,
      <660, 661, 651>,
      <660, 651, 650>,
      <660, 650, 662>,
      <660, 662, 663>,
      <660, 664, 665>,
      <660, 665, 666>,
      <660, 667, 668>,
      <660, 668, 661>,
      <669, 670, 651>,
      <669, 651, 661>,
      <669, 661, 671>,
      <669, 671, 672>,
      <669, 673, 674>,
      <669, 674, 675>,
      <669, 676, 677>,
      <669, 677, 670>,
      <678, 652, 651>,
      <678, 651, 670>,
      <678, 670, 679>,
      <678, 679, 680>,
      <678, 681, 682>,
      <678, 682, 683>,
      <678, 684, 685>,
      <678, 685, 652>,
      <686, 687, 688>,
      <686, 688, 689>,
      <686, 689, 690>,
      <686, 690, 691>,
      <686, 692, 693>,
      <686, 693, 694>,
      <686, 695, 696>,
      <686, 696, 687>,
      <697, 698, 688>,
      <697, 688, 687>,
      <697, 687, 699>,
      <697, 699, 700>,
      <697, 701, 702>,
      <697, 702, 703>,
      <697, 704, 705>,
      <697, 705, 698>,
      <706, 707, 688>,
      <706, 688, 698>,
      <706, 698, 708>,
      <706, 708, 709>,
      <706, 710, 711>,
      <706, 711, 712>,
      <706, 713, 714>,
      <706, 714, 707>,
      <715, 689, 688>,
      <715, 688, 707>,
      <715, 707, 716>,
      <715, 716, 717>,
      <715, 718, 719>,
      <715, 719, 720>,
      <715, 721, 722>,
      <715, 722, 689>,
      <723, 724, 725>,
      <723, 725, 726>,
      <723, 726, 727>,
      <723, 727, 728>,
      <723, 729, 730>,
      <723, 730, 731>,
      <723, 732, 733>,
      <723, 733, 724>,
      <734, 735, 725>,
      <734, 725, 724>,
      <734, 724, 736>,
      <734, 736, 737>,
      <734, 738, 739>,
      <734, 739, 740>,
      <734, 741, 742>,
      <734, 742, 735>,
      <743, 744, 725>,
      <743, 725, 735>,
      <743, 735, 745>,
      <743, 745, 746>,
      <743, 747, 748>,
      <743, 748, 749>,
      <743, 750, 751>,
      <743, 751, 744>,
      <752, 726, 725>,
      <752, 725, 744>,
      <752, 744, 753>,
      <752, 753, 754>,
      <752, 755, 756>,
      <752, 756, 757>,
      <752, 758, 759>,
      <752, 759, 726>,
      <760, 761, 762>,
      <760, 762, 763>,
      <760, 763, 764>,
      <760, 764, 765>,
      <760, 766, 767>,
      <760, 767, 768>,
      <760, 769, 770>,
      <760, 770, 761>,
      <771, 772, 762>,
      <771, 762, 761>,
      <771, 761, 773>,
      <771, 773, 774>,
      <771, 775, 776>,
      <771, 776, 777>,
      <771, 778, 779>,
      <771, 779, 772>,
      <780, 781, 762>,
      <780, 762, 772>,
      <780, 772, 782>,
      <780, 782, 783>,
      <780, 784, 785>,
      <780, 785, 786>,
      <780, 787, 788>,
      <780, 788, 781>,
      <789, 763, 762>,
      <789, 762, 781>,
      <789, 781, 790>,
      <789, 790, 791>,
      <789, 792, 793>,
      <789, 793, 794>,
      <789, 795, 796>,
      <789, 796, 763>,
      <797, 798, 799>,
      <797, 799, 800>,
      <797, 800, 801>,
      <797, 801, 802>,
      <797, 803, 804>,
      <797, 804, 805>,
      <797, 806, 807>,
      <797, 807, 798>,
      <808, 809, 799>,
      <808, 799, 798>,
      <808, 798, 810>,
      <808, 810, 811>,
      <808, 812, 813>,
      <808, 813, 814>,
      <808, 815, 816>,
      <808, 816, 809>,
      <817, 818, 799>,
      <817, 799, 809>,
      <817, 809, 819>,
      <817, 819, 820>,
      <817, 821, 822>,
      <817, 822, 823>,
      <817, 824, 825>,
      <817, 825, 818>,
      <826, 800, 799>,
      <826, 799, 818>,
      <826, 818, 827>,
      <826, 827, 828>,
      <826, 829, 830>,
      <826, 830, 831>,
      <826, 832, 833>,
      <826, 833, 800>,
      <834, 835, 836>,
      <834, 836, 837>,
      <834, 837, 838>,
      <834, 838, 839>,
      <834, 840, 841>,
      <834, 841, 842>,
      <834, 843, 844>,
      <834, 844, 835>,
      <845, 846, 836>,
      <845, 836, 835>,
      <845, 835, 847>,
      <845, 847, 848>,
      <845, 849, 850>,
      <845, 850, 851>,
      <845, 852, 853>,
      <845, 853, 846>,
      <854, 855, 836>,
      <854, 836, 846>,
      <854, 846, 856>,
      <854, 856, 857>,
      <854, 858, 859>,
      <854, 859, 860>,
      <854, 861, 862>,
      <854, 862, 855>,
      <863, 837, 836>,
      <863, 836, 855>,
      <863, 855, 864>,
      <863, 864, 865>,
      <863, 866, 867>,
      <863, 867, 868>,
      <863, 869, 870>,
      <863, 870, 837>,
      <871, 872, 873>,
      <871, 873, 874>,
      <871, 874, 875>,
      <871, 875, 876>,
      <871, 877, 878>,
      <871, 878, 879>,
      <871, 880, 881>,
      <871, 881, 872>,
      <882, 883, 873>,
      <882, 873, 872>,
      <882, 872, 884>,
      <882, 884, 885>,
      <882, 886, 887>,
      <882, 887, 888>,
      <882, 889, 890>,
      <882, 890, 883>,
      <891, 892, 873>,
      <891, 873, 883>,
      <891, 883, 893>,
      <891, 893, 894>,
      <891, 895, 896>,
      <891, 896, 897>,
      <891, 898, 899>,
      <891, 899, 892>,
      <900, 874, 873>,
      <900, 873, 892>,
      <900, 892, 901>,
      <900, 901, 902>,
      <900, 903, 904>,
      <900, 904, 905>,
      <900, 906, 907>,
      <900, 907, 874>,
      <908, 909, 910>,
      <908, 910, 911>,
      <908, 911, 912>,
      <908, 912, 913>,
      <908, 914, 915>,
      <908, 915, 916>,
      <908, 917, 918>,
      <908, 918, 909>,
      <919, 920, 910>,
      <919, 910, 909>,
      <919, 909, 921>,
      <919, 921, 922>,
      <919, 923, 924>,
      <919, 924, 925>,
      <919, 926, 927>,
      <919, 927, 920>,
      <928, 929, 910>,
      <928, 910, 920>,
      <928, 920, 930>,
      <928, 930, 931>,
      <928, 932, 933>,
      <928, 933, 934>,
      <928, 935, 936>,
      <928, 936, 929>,
      <937, 911, 910>,
      <937, 910, 929>,
      <937, 929, 938>,
      <937, 938, 939>,
      <937, 940, 941>,
      <937, 941, 942>,
      <937, 943, 944>,
      <937, 944, 911>,
      <945, 946, 947>,
      <945, 947, 948>,
      <945, 948, 949>,
      <945, 949, 950>,
      <945, 951, 952>,
      <945, 952, 953>,
      <945, 954, 955>,
      <945, 955, 946>,
      <956, 957, 947>,
      <956, 947, 946>,
      <956, 946, 958>,
      <956, 958, 959>,
      <956, 960, 961>,
      <956, 961, 962>,
      <956, 963, 964>,
      <956, 964, 957>,
      <965, 966, 947>,
      <965, 947, 957>,
      <965, 957, 967>,
      <965, 967, 968>,
      <965, 969, 970>,
      <965, 970, 971>,
      <965, 972, 973>,
      <965, 973, 966>,
      <974, 948, 947>,
      <974, 947, 966>,
      <974, 966, 975>,
      <974, 975, 976>,
      <974, 977, 978>,
      <974, 978, 979>,
      <974, 980, 981>,
      <974, 981, 948>,
      <982, 983, 984>,
      <982, 984, 985>,
      <982, 985, 986>,
      <982, 986, 987>,
      <982, 988, 989>,
      <982, 989, 990>,
      <982, 991, 992>,
      <982, 992, 983>,
      <993, 994, 984>,
      <993, 984, 983>,
      <993, 983, 995>,
      <993, 995, 996>,
      <993, 997, 998>,
      <993, 998, 999>,
      <993, 1000, 1001>,
      <993, 1001, 994>,
      <1002, 1003, 984>,
      <1002, 984, 994>,
      <1002, 994, 1004>,
      <1002, 1004, 1005>,
      <1002, 1006, 1007>,
      <1002, 1007, 1008>,
      <1002, 1009, 1010>,
      <1002, 1010, 1003>,
      <1011, 985, 984>,
      <1011, 984, 1003>,
      <1011, 1003, 1012>,
      <1011, 1012, 1013>,
      <1011, 1014, 1015>,
      <1011, 1015, 1016>,
      <1011, 1017, 1018>,
      <1011, 1018, 985>,
      <1019, 1020, 1021>,
      <1019, 1021, 1022>,
      <1019, 1022, 1023>,
      <1019, 1023, 1024>,
      <1019, 1025, 1026>,
      <1019, 1026, 1027>,
      <1019, 1028, 1029>,
      <1019, 1029, 1020>,
      <1030, 1031, 1021>,
      <1030, 1021, 1020>,
      <1030, 1020, 1032>,
      <1030, 1032, 1033>,
      <1030, 1034, 1035>,
      <1030, 1035, 1036>,
      <1030, 1037, 1038>,
      <1030, 1038, 1031>,
      <1039, 1040, 1021>,
      <1039, 1021, 1031>,
      <1039, 1031, 1041>,
      <1039, 1041, 1042>,
      <1039, 1043, 1044>,
      <1039, 1044, 1045>,
      <1039, 1046, 1047>,
      <1039, 1047, 1040>,
      <1048, 1022, 1021>,
      <1048, 1021, 1040>,
      <1048, 1040, 1049>,
      <1048, 1049, 1050>,
      <1048, 1051, 1052>,
      <1048, 1052, 1053>,
      <1048, 1054, 1055>,
      <1048, 1055, 1022>,
      <1056, 1057, 1058>,
      <1056, 1058, 1059>,
      <1056, 1059, 1060>,
      <1056, 1060, 1061>,
      <1056, 1062, 1063>,
      <1056, 1063, 1064>,
      <1056, 1065, 1066>,
      <1056, 1066, 1057>,
      <1067, 1068, 1058>,
      <1067, 1058, 1057>,
      <1067, 1057, 1069>,
      <1067, 1069, 1070>,
      <1067, 1071, 1072>,
      <1067, 1072, 1073>,
      <1067, 1074, 1075>,
      <1067, 1075, 1068>,
      <1076, 1077, 1058>,
      <1076, 1058, 1068>,
      <1076, 1068, 1078>,
      <1076, 1078, 1079>,
      <1076, 1080, 1081>,
      <1076, 1081, 1082>,
      <1076, 1083, 1084>,
      <1076, 1084, 1077>,
      <1085, 1059, 1058>,
      <1085, 1058, 1077>,
      <1085, 1077, 1086>,
      <1085, 1086, 1087>,
      <1085, 1088, 1089>,
      <1085, 1089, 1090>,
      <1085, 1091, 1092>,
      <1085, 1092, 1059>,
      <1093, 1094, 1095>,
      <1093, 1095, 1096>,
      <1093, 1096, 1097>,
      <1093, 1097, 1098>,
      <1093, 1099, 1100>,
      <1093, 1100, 1101>,
      <1093, 1101, 1102>,
      <1093, 1102, 1094>,
      <1103, 1104, 1095>,
      <1103, 1095, 1094>,
      <1103, 1094, 1102>,
      <1103, 1102, 1105>,
      <1103, 1105, 1106>,
      <1103, 1106, 1107>,
      <1103, 1108, 1109>,
      <1103, 1109, 1104>,
      <1110, 1111, 1095>,
      <1110, 1095, 1104>,
      <1110, 1104, 1112>,
      <1110, 1112, 1113>,
      <1110, 1114, 1115>,
      <1110, 1115, 1116>,
      <1110, 1117, 1118>,
      <1110, 1118, 1111>,
      <1119, 1096, 1095>,
      <1119, 1095, 1111>,
      <1119, 1111, 1120>,
      <1119, 1120, 1121>,
      <1119, 1122, 1123>,
      <1119, 1123, 1124>,
      <1119, 1125, 1126>,
      <1119, 1126, 1096>,
      <1127, 1128, 1129>,
      <1127, 1129, 1130>,
      <1127, 1130, 1102>,
      <1127, 1102, 1101>,
      <1127, 1101, 1131>,
      <1127, 1131, 1132>,
      <1127, 1133, 1134>,
      <1127, 1134, 1128>,
      <1135, 1136, 1129>,
      <1135, 1129, 1128>,
      <1135, 1128, 1137>,
      <1135, 1137, 1138>,
      <1135, 1139, 1140>,
      <1135, 1140, 1141>,
      <1135, 1142, 1143>,
      <1135, 1143, 1136>,
      <1144, 1145, 1129>,
      <1144, 1129, 1136>,
      <1144, 1136, 1146>,
      <1144, 1146, 1147>,
      <1144, 1148, 1149>,
      <1144, 1149, 1150>,
      <1144, 1151, 1152>,
      <1144, 1152, 1145>,
      <1153, 1130, 1129>,
      <1153, 1129, 1145>,
      <1153, 1145, 1154>,
      <1153, 1154, 1155>,
      <1153, 1156, 1157>,
      <1153, 1157, 1105>,
      <1153, 1105, 1102>,
      <1153, 1102, 1130>
    }
    uv_indices {
      1056,   // from 0 triangles and 528 quads
      <569, 577, 570>,
      <569, 570, 574>      <569, 574, 571>,
      <569, 571, 575>      <569, 575, 572>,
      <569, 572, 576>      <569, 576, 573>,
      <569, 573, 577>      <578, 586, 579>,
      <578, 579, 583>      <578, 583, 580>,
      <578, 580, 584>      <578, 584, 581>,
      <578, 581, 585>      <578, 585, 582>,
      <578, 582, 586>      <587, 595, 588>,
      <587, 588, 592>      <587, 592, 589>,
      <587, 589, 593>      <587, 593, 590>,
      <587, 590, 594>      <587, 594, 591>,
      <587, 591, 595>      <596, 604, 597>,
      <596, 597, 601>      <596, 601, 598>,
      <596, 598, 602>      <596, 602, 599>,
      <596, 599, 603>      <596, 603, 600>,
      <596, 600, 604>      <605, 613, 606>,
      <605, 606, 610>      <605, 610, 607>,
      <605, 607, 611>      <605, 611, 608>,
      <605, 608, 612>      <605, 612, 609>,
      <605, 609, 613>      <614, 622, 615>,
      <614, 615, 619>      <614, 619, 616>,
      <614, 616, 620>      <614, 620, 617>,
      <614, 617, 621>      <614, 621, 618>,
      <614, 618, 622>      <623, 631, 624>,
      <623, 624, 628>      <623, 628, 625>,
      <623, 625, 629>      <623, 629, 626>,
      <623, 626, 630>      <623, 630, 627>,
      <623, 627, 631>      <632, 640, 633>,
      <632, 633, 637>      <632, 637, 634>,
      <632, 634, 638>      <632, 638, 635>,
      <632, 635, 639>      <632, 639, 636>,
      <632, 636, 640>      <641, 649, 642>,
      <641, 642, 646>      <641, 646, 643>,
      <641, 643, 647>      <641, 647, 644>,
      <641, 644, 648>      <641, 648, 645>,
      <641, 645, 649>      <650, 658, 651>,
      <650, 651, 655>      <650, 655, 652>,
      <650, 652, 656>      <650, 656, 653>,
      <650, 653, 657>      <650, 657, 654>,
      <650, 654, 658>      <659, 667, 660>,
      <659, 660, 664>      <659, 664, 661>,
      <659, 661, 665>      <659, 665, 662>,
      <659, 662, 666>      <659, 666, 663>,
      <659, 663, 667>      <668, 676, 669>,
      <668, 669, 673>      <668, 673, 670>,
      <668, 670, 674>      <668, 674, 671>,
      <668, 671, 675>      <668, 675, 672>,
      <668, 672, 676>      <677, 685, 678>,
      <677, 678, 682>      <677, 682, 679>,
      <677, 679, 683>      <677, 683, 680>,
      <677, 680, 684>      <677, 684, 681>,
      <677, 681, 685>      <686, 694, 687>,
      <686, 687, 691>      <686, 691, 688>,
      <686, 688, 692>      <686, 692, 689>,
      <686, 689, 693>      <686, 693, 690>,
      <686, 690, 694>      <695, 703, 696>,
      <695, 696, 700>      <695, 700, 697>,
      <695, 697, 701>      <695, 701, 698>,
      <695, 698, 702>      <695, 702, 699>,
      <695, 699, 703>      <704, 712, 705>,
      <704, 705, 709>      <704, 709, 706>,
      <704, 706, 710>      <704, 710, 707>,
      <704, 707, 711>      <704, 711, 708>,
      <704, 708, 712>      <713, 721, 714>,
      <713, 714, 718>      <713, 718, 715>,
      <713, 715, 719>      <713, 719, 716>,
      <713, 716, 720>      <713, 720, 717>,
      <713, 717, 721>      <722, 730, 723>,
      <722, 723, 727>      <722, 727, 724>,
      <722, 724, 728>      <722, 728, 725>,
      <722, 725, 729>      <722, 729, 726>,
      <722, 726, 730>      <731, 739, 732>,
      <731, 732, 736>      <731, 736, 733>,
      <731, 733, 737>      <731, 737, 734>,
      <731, 734, 738>      <731, 738, 735>,
      <731, 735, 739>      <740, 748, 741>,
      <740, 741, 745>      <740, 745, 742>,
      <740, 742, 746>      <740, 746, 743>,
      <740, 743, 747>      <740, 747, 744>,
      <740, 744, 748>      <749, 757, 750>,
      <749, 750, 754>      <749, 754, 751>,
      <749, 751, 755>      <749, 755, 752>,
      <749, 752, 756>      <749, 756, 753>,
      <749, 753, 757>      <758, 766, 759>,
      <758, 759, 763>      <758, 763, 760>,
      <758, 760, 764>      <758, 764, 761>,
      <758, 761, 765>      <758, 765, 762>,
      <758, 762, 766>      <767, 775, 768>,
      <767, 768, 772>      <767, 772, 769>,
      <767, 769, 773>      <767, 773, 770>,
      <767, 770, 774>      <767, 774, 771>,
      <767, 771, 775>      <776, 784, 777>,
      <776, 777, 781>      <776, 781, 778>,
      <776, 778, 782>      <776, 782, 779>,
      <776, 779, 783>      <776, 783, 780>,
      <776, 780, 784>      <785, 793, 786>,
      <785, 786, 790>      <785, 790, 787>,
      <785, 787, 791>      <785, 791, 788>,
      <785, 788, 792>      <785, 792, 789>,
      <785, 789, 793>      <794, 802, 795>,
      <794, 795, 799>      <794, 799, 796>,
      <794, 796, 800>      <794, 800, 797>,
      <794, 797, 801>      <794, 801, 798>,
      <794, 798, 802>      <803, 811, 804>,
      <803, 804, 808>      <803, 808, 805>,
      <803, 805, 809>      <803, 809, 806>,
      <803, 806, 810>      <803, 810, 807>,
      <803, 807, 811>      <812, 820, 813>,
      <812, 813, 817>      <812, 817, 814>,
      <812, 814, 818>      <812, 818, 815>,
      <812, 815, 819>      <812, 819, 816>,
      <812, 816, 820>      <821, 829, 822>,
      <821, 822, 826>      <821, 826, 823>,
      <821, 823, 827>      <821, 827, 824>,
      <821, 824, 828>      <821, 828, 825>,
      <821, 825, 829>      <830, 838, 831>,
      <830, 831, 835>      <830, 835, 832>,
      <830, 832, 836>      <830, 836, 833>,
      <830, 833, 837>      <830, 837, 834>,
      <830, 834, 838>      <839, 847, 840>,
      <839, 840, 844>      <839, 844, 841>,
      <839, 841, 845>      <839, 845, 842>,
      <839, 842, 846>      <839, 846, 843>,
      <839, 843, 847>      <848, 856, 849>,
      <848, 849, 853>      <848, 853, 850>,
      <848, 850, 854>      <848, 854, 851>,
      <848, 851, 855>      <848, 855, 852>,
      <848, 852, 856>      <857, 865, 858>,
      <857, 858, 862>      <857, 862, 859>,
      <857, 859, 863>      <857, 863, 860>,
      <857, 860, 864>      <857, 864, 861>,
      <857, 861, 865>      <866, 874, 867>,
      <866, 867, 871>      <866, 871, 868>,
      <866, 868, 872>      <866, 872, 869>,
      <866, 869, 873>      <866, 873, 870>,
      <866, 870, 874>      <875, 883, 876>,
      <875, 876, 880>      <875, 880, 877>,
      <875, 877, 881>      <875, 881, 878>,
      <875, 878, 882>      <875, 882, 879>,
      <875, 879, 883>      <884, 892, 885>,
      <884, 885, 889>      <884, 889, 886>,
      <884, 886, 890>      <884, 890, 887>,
      <884, 887, 891>      <884, 891, 888>,
      <884, 888, 892>      <893, 901, 894>,
      <893, 894, 898>      <893, 898, 895>,
      <893, 895, 899>      <893, 899, 896>,
      <893, 896, 900>      <893, 900, 897>,
      <893, 897, 901>      <902, 910, 903>,
      <902, 903, 907>      <902, 907, 904>,
      <902, 904, 908>      <902, 908, 905>,
      <902, 905, 909>      <902, 909, 906>,
      <902, 906, 910>      <911, 919, 912>,
      <911, 912, 916>      <911, 916, 913>,
      <911, 913, 917>      <911, 917, 914>,
      <911, 914, 918>      <911, 918, 915>,
      <911, 915, 919>      <920, 928, 921>,
      <920, 921, 925>      <920, 925, 922>,
      <920, 922, 926>      <920, 926, 923>,
      <920, 923, 927>      <920, 927, 924>,
      <920, 924, 928>      <929, 937, 930>,
      <929, 930, 934>      <929, 934, 931>,
      <929, 931, 935>      <929, 935, 932>,
      <929, 932, 936>      <929, 936, 933>,
      <929, 933, 937>      <938, 946, 939>,
      <938, 939, 943>      <938, 943, 940>,
      <938, 940, 944>      <938, 944, 941>,
      <938, 941, 945>      <938, 945, 942>,
      <938, 942, 946>      <947, 955, 948>,
      <947, 948, 952>      <947, 952, 949>,
      <947, 949, 953>      <947, 953, 950>,
      <947, 950, 954>      <947, 954, 951>,
      <947, 951, 955>      <956, 964, 957>,
      <956, 957, 961>      <956, 961, 958>,
      <956, 958, 962>      <956, 962, 959>,
      <956, 959, 963>      <956, 963, 960>,
      <956, 960, 964>      <965, 973, 966>,
      <965, 966, 970>      <965, 970, 967>,
      <965, 967, 971>      <965, 971, 968>,
      <965, 968, 972>      <965, 972, 969>,
      <965, 969, 973>      <974, 982, 975>,
      <974, 975, 979>      <974, 979, 976>,
      <974, 976, 980>      <974, 980, 977>,
      <974, 977, 981>      <974, 981, 978>,
      <974, 978, 982>      <983, 991, 984>,
      <983, 984, 988>      <983, 988, 985>,
      <983, 985, 989>      <983, 989, 986>,
      <983, 986, 990>      <983, 990, 987>,
      <983, 987, 991>      <992, 1000, 993>,
      <992, 993, 997>      <992, 997, 994>,
      <992, 994, 998>      <992, 998, 995>,
      <992, 995, 999>      <992, 999, 996>,
      <992, 996, 1000>      <1001, 1009, 1002>,
      <1001, 1002, 1006>      <1001, 1006, 1003>,
      <1001, 1003, 1007>      <1001, 1007, 1004>,
      <1001, 1004, 1008>      <1001, 1008, 1005>,
      <1001, 1005, 1009>      <1010, 1018, 1011>,
      <1010, 1011, 1015>      <1010, 1015, 1012>,
      <1010, 1012, 1016>      <1010, 1016, 1013>,
      <1010, 1013, 1017>      <1010, 1017, 1014>,
      <1010, 1014, 1018>      <1019, 1027, 1020>,
      <1019, 1020, 1024>      <1019, 1024, 1021>,
      <1019, 1021, 1025>      <1019, 1025, 1022>,
      <1019, 1022, 1026>      <1019, 1026, 1023>,
      <1019, 1023, 1027>      <1028, 1036, 1029>,
      <1028, 1029, 1033>      <1028, 1033, 1030>,
      <1028, 1030, 1034>      <1028, 1034, 1031>,
      <1028, 1031, 1035>      <1028, 1035, 1032>,
      <1028, 1032, 1036>      <1037, 1045, 1038>,
      <1037, 1038, 1042>      <1037, 1042, 1039>,
      <1037, 1039, 1043>      <1037, 1043, 1040>,
      <1037, 1040, 1044>      <1037, 1044, 1041>,
      <1037, 1041, 1045>      <1046, 1054, 1047>,
      <1046, 1047, 1051>      <1046, 1051, 1048>,
      <1046, 1048, 1052>      <1046, 1052, 1049>,
      <1046, 1049, 1053>      <1046, 1053, 1050>,
      <1046, 1050, 1054>      <1055, 1063, 1056>,
      <1055, 1056, 1060>      <1055, 1060, 1057>,
      <1055, 1057, 1061>      <1055, 1061, 1058>,
      <1055, 1058, 1062>      <1055, 1062, 1059>,
      <1055, 1059, 1063>      <1064, 1072, 1065>,
      <1064, 1065, 1069>      <1064, 1069, 1066>,
      <1064, 1066, 1070>      <1064, 1070, 1067>,
      <1064, 1067, 1071>      <1064, 1071, 1068>,
      <1064, 1068, 1072>      <1073, 1081, 1074>,
      <1073, 1074, 1078>      <1073, 1078, 1075>,
      <1073, 1075, 1079>      <1073, 1079, 1076>,
      <1073, 1076, 1080>      <1073, 1080, 1077>,
      <1073, 1077, 1081>      <1082, 1090, 1083>,
      <1082, 1083, 1087>      <1082, 1087, 1084>,
      <1082, 1084, 1088>      <1082, 1088, 1085>,
      <1082, 1085, 1089>      <1082, 1089, 1086>,
      <1082, 1086, 1090>      <1091, 1099, 1092>,
      <1091, 1092, 1096>      <1091, 1096, 1093>,
      <1091, 1093, 1097>      <1091, 1097, 1094>,
      <1091, 1094, 1098>      <1091, 1098, 1095>,
      <1091, 1095, 1099>      <1100, 1108, 1101>,
      <1100, 1101, 1105>      <1100, 1105, 1102>,
      <1100, 1102, 1106>      <1100, 1106, 1103>,
      <1100, 1103, 1107>      <1100, 1107, 1104>,
      <1100, 1104, 1108>      <1109, 1117, 1110>,
      <1109, 1110, 1114>      <1109, 1114, 1111>,
      <1109, 1111, 1115>      <1109, 1115, 1112>,
      <1109, 1112, 1116>      <1109, 1116, 1113>,
      <1109, 1113, 1117>      <1118, 1126, 1119>,
      <1118, 1119, 1123>      <1118, 1123, 1120>,
      <1118, 1120, 1124>      <1118, 1124, 1121>,
      <1118, 1121, 1125>      <1118, 1125, 1122>,
      <1118, 1122, 1126>      <1127, 1135, 1128>,
      <1127, 1128, 1132>      <1127, 1132, 1129>,
      <1127, 1129, 1133>      <1127, 1133, 1130>,
      <1127, 1130, 1134>      <1127, 1134, 1131>,
      <1127, 1131, 1135>      <1136, 1144, 1137>,
      <1136, 1137, 1141>      <1136, 1141, 1138>,
      <1136, 1138, 1142>      <1136, 1142, 1139>,
      <1136, 1139, 1143>      <1136, 1143, 1140>,
      <1136, 1140, 1144>      <1145, 1153, 1146>,
      <1145, 1146, 1150>      <1145, 1150, 1147>,
      <1145, 1147, 1151>      <1145, 1151, 1148>,
      <1145, 1148, 1152>      <1145, 1152, 1149>,
      <1145, 1149, 1153>      <1154, 1162, 1155>,
      <1154, 1155, 1159>      <1154, 1159, 1156>,
      <1154, 1156, 1160>      <1154, 1160, 1157>,
      <1154, 1157, 1161>      <1154, 1161, 1158>,
      <1154, 1158, 1162>      <1163, 1171, 1164>,
      <1163, 1164, 1168>      <1163, 1168, 1165>,
      <1163, 1165, 1169>      <1163, 1169, 1166>,
      <1163, 1166, 1170>      <1163, 1170, 1167>,
      <1163, 1167, 1171>      <1172, 1180, 1173>,
      <1172, 1173, 1177>      <1172, 1177, 1174>,
      <1172, 1174, 1178>      <1172, 1178, 1175>,
      <1172, 1175, 1179>      <1172, 1179, 1176>,
      <1172, 1176, 1180>      <1181, 1189, 1182>,
      <1181, 1182, 1186>      <1181, 1186, 1183>,
      <1181, 1183, 1187>      <1181, 1187, 1184>,
      <1181, 1184, 1188>      <1181, 1188, 1185>,
      <1181, 1185, 1189>      <1190, 1198, 1191>,
      <1190, 1191, 1195>      <1190, 1195, 1192>,
      <1190, 1192, 1196>      <1190, 1196, 1193>,
      <1190, 1193, 1197>      <1190, 1197, 1194>,
      <1190, 1194, 1198>      <1199, 1207, 1200>,
      <1199, 1200, 1204>      <1199, 1204, 1201>,
      <1199, 1201, 1205>      <1199, 1205, 1202>,
      <1199, 1202, 1206>      <1199, 1206, 1203>,
      <1199, 1203, 1207>      <1208, 1216, 1209>,
      <1208, 1209, 1213>      <1208, 1213, 1210>,
      <1208, 1210, 1214>      <1208, 1214, 1211>,
      <1208, 1211, 1215>      <1208, 1215, 1212>,
      <1208, 1212, 1216>      <1217, 1225, 1218>,
      <1217, 1218, 1222>      <1217, 1222, 1219>,
      <1217, 1219, 1223>      <1217, 1223, 1220>,
      <1217, 1220, 1224>      <1217, 1224, 1221>,
      <1217, 1221, 1225>      <1226, 1234, 1227>,
      <1226, 1227, 1231>      <1226, 1231, 1228>,
      <1226, 1228, 1232>      <1226, 1232, 1229>,
      <1226, 1229, 1233>      <1226, 1233, 1230>,
      <1226, 1230, 1234>      <1235, 1243, 1236>,
      <1235, 1236, 1240>      <1235, 1240, 1237>,
      <1235, 1237, 1241>      <1235, 1241, 1238>,
      <1235, 1238, 1242>      <1235, 1242, 1239>,
      <1235, 1239, 1243>      <1244, 1252, 1245>,
      <1244, 1245, 1249>      <1244, 1249, 1246>,
      <1244, 1246, 1250>      <1244, 1250, 1247>,
      <1244, 1247, 1251>      <1244, 1251, 1248>,
      <1244, 1248, 1252>      <1253, 1261, 1254>,
      <1253, 1254, 1258>      <1253, 1258, 1255>,
      <1253, 1255, 1259>      <1253, 1259, 1256>,
      <1253, 1256, 1260>      <1253, 1260, 1257>,
      <1253, 1257, 1261>      <1262, 1270, 1263>,
      <1262, 1263, 1267>      <1262, 1267, 1264>,
      <1262, 1264, 1268>      <1262, 1268, 1265>,
      <1262, 1265, 1269>      <1262, 1269, 1266>,
      <1262, 1266, 1270>      <1271, 1279, 1272>,
      <1271, 1272, 1276>      <1271, 1276, 1273>,
      <1271, 1273, 1277>      <1271, 1277, 1274>,
      <1271, 1274, 1278>      <1271, 1278, 1275>,
      <1271, 1275, 1279>      <1280, 1288, 1281>,
      <1280, 1281, 1285>      <1280, 1285, 1282>,
      <1280, 1282, 1286>      <1280, 1286, 1283>,
      <1280, 1283, 1287>      <1280, 1287, 1284>,
      <1280, 1284, 1288>      <1289, 1297, 1290>,
      <1289, 1290, 1294>      <1289, 1294, 1291>,
      <1289, 1291, 1295>      <1289, 1295, 1292>,
      <1289, 1292, 1296>      <1289, 1296, 1293>,
      <1289, 1293, 1297>      <1298, 1306, 1299>,
      <1298, 1299, 1303>      <1298, 1303, 1300>,
      <1298, 1300, 1304>      <1298, 1304, 1301>,
      <1298, 1301, 1305>      <1298, 1305, 1302>,
      <1298, 1302, 1306>      <1307, 1315, 1308>,
      <1307, 1308, 1312>      <1307, 1312, 1309>,
      <1307, 1309, 1313>      <1307, 1313, 1310>,
      <1307, 1310, 1314>      <1307, 1314, 1311>,
      <1307, 1311, 1315>      <1316, 1324, 1317>,
      <1316, 1317, 1321>      <1316, 1321, 1318>,
      <1316, 1318, 1322>      <1316, 1322, 1319>,
      <1316, 1319, 1323>      <1316, 1323, 1320>,
      <1316, 1320, 1324>      <1325, 1333, 1326>,
      <1325, 1326, 1330>      <1325, 1330, 1327>,
      <1325, 1327, 1331>      <1325, 1331, 1328>,
      <1325, 1328, 1332>      <1325, 1332, 1329>,
      <1325, 1329, 1333>      <1334, 1342, 1335>,
      <1334, 1335, 1339>      <1334, 1339, 1336>,
      <1334, 1336, 1340>      <1334, 1340, 1337>,
      <1334, 1337, 1341>      <1334, 1341, 1338>,
      <1334, 1338, 1342>      <1343, 1351, 1344>,
      <1343, 1344, 1348>      <1343, 1348, 1345>,
      <1343, 1345, 1349>      <1343, 1349, 1346>,
      <1343, 1346, 1350>      <1343, 1350, 1347>,
      <1343, 1347, 1351>      <1352, 1360, 1353>,
      <1352, 1353, 1357>      <1352, 1357, 1354>,
      <1352, 1354, 1358>      <1352, 1358, 1355>,
      <1352, 1355, 1359>      <1352, 1359, 1356>,
      <1352, 1356, 1360>      <1361, 1369, 1362>,
      <1361, 1362, 1366>      <1361, 1366, 1363>,
      <1361, 1363, 1367>      <1361, 1367, 1364>,
      <1361, 1364, 1368>      <1361, 1368, 1365>,
      <1361, 1365, 1369>      <1370, 1378, 1371>,
      <1370, 1371, 1375>      <1370, 1375, 1372>,
      <1370, 1372, 1376>      <1370, 1376, 1373>,
      <1370, 1373, 1377>      <1370, 1377, 1374>,
      <1370, 1374, 1378>      <1379, 1387, 1380>,
      <1379, 1380, 1384>      <1379, 1384, 1381>,
      <1379, 1381, 1385>      <1379, 1385, 1382>,
      <1379, 1382, 1386>      <1379, 1386, 1383>,
      <1379, 1383, 1387>      <1388, 1396, 1389>,
      <1388, 1389, 1393>      <1388, 1393, 1390>,
      <1388, 1390, 1394>      <1388, 1394, 1391>,
      <1388, 1391, 1395>      <1388, 1395, 1392>,
      <1388, 1392, 1396>      <1397, 1405, 1398>,
      <1397, 1398, 1402>      <1397, 1402, 1399>,
      <1397, 1399, 1403>      <1397, 1403, 1400>,
      <1397, 1400, 1404>      <1397, 1404, 1401>,
      <1397, 1401, 1405>      <1406, 1414, 1407>,
      <1406, 1407, 1411>      <1406, 1411, 1408>,
      <1406, 1408, 1412>      <1406, 1412, 1409>,
      <1406, 1409, 1413>      <1406, 1413, 1410>,
      <1406, 1410, 1414>      <1415, 1423, 1416>,
      <1415, 1416, 1420>      <1415, 1420, 1417>,
      <1415, 1417, 1421>      <1415, 1421, 1418>,
      <1415, 1418, 1422>      <1415, 1422, 1419>,
      <1415, 1419, 1423>      <1424, 1432, 1425>,
      <1424, 1425, 1429>      <1424, 1429, 1426>,
      <1424, 1426, 1430>      <1424, 1430, 1427>,
      <1424, 1427, 1431>      <1424, 1431, 1428>,
      <1424, 1428, 1432>      <1433, 1441, 1434>,
      <1433, 1434, 1438>      <1433, 1438, 1435>,
      <1433, 1435, 1439>      <1433, 1439, 1436>,
      <1433, 1436, 1440>      <1433, 1440, 1437>,
      <1433, 1437, 1441>      <1442, 1450, 1443>,
      <1442, 1443, 1447>      <1442, 1447, 1444>,
      <1442, 1444, 1448>      <1442, 1448, 1445>,
      <1442, 1445, 1449>      <1442, 1449, 1446>,
      <1442, 1446, 1450>      <1451, 1459, 1452>,
      <1451, 1452, 1456>      <1451, 1456, 1453>,
      <1451, 1453, 1457>      <1451, 1457, 1454>,
      <1451, 1454, 1458>      <1451, 1458, 1455>,
      <1451, 1455, 1459>      <1460, 1468, 1461>,
      <1460, 1461, 1465>      <1460, 1465, 1462>,
      <1460, 1462, 1466>      <1460, 1466, 1463>,
      <1460, 1463, 1467>      <1460, 1467, 1464>,
      <1460, 1464, 1468>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>
    }
    translate  <0.0, 0.0, 0.0>
}

#declare Corbeau_coin = mesh2 {
    vertex_vectors {
      582,
      <0.1681260, 0.2008758, 0.0005625>,
      <0.2312264, 0.4033089, 0.0005625>,
      <0.1658216, 0.4032168, 0.0005625>,
      <0.0815379, 0.2008970, 0.0005625>,
      <0.1996762, 0.3020923, 0.0005625>,
      <0.1985240, 0.4032629, 0.0005625>,
      <0.1236798, 0.3020569, 0.0005625>,
      <0.1248320, 0.2008864, 0.0005625>,
      <0.1616780, 0.3020746, 0.0005625>,
      <-0.0027459, -0.0014227, 0.0005625>,
      <0.1050256, -0.0015573, 0.0005625>,
      <0.0393960, 0.0997371, 0.0005625>,
      <0.0511399, -0.0014900, 0.0005625>,
      <0.1365758, 0.0996592, 0.0005625>,
      <0.0879859, 0.0996982, 0.0005625>,
      <0.2127972, -0.0016919, 0.0005625>,
      <0.2547142, 0.2008545, 0.0005625>,
      <0.1589114, -0.0016246, 0.0005625>,
      <0.2337557, 0.0995813, 0.0005625>,
      <0.2114201, 0.2008652, 0.0005625>,
      <0.1851658, 0.0996203, 0.0005625>,
      <0.2966312, 0.4034010, 0.0005625>,
      <0.2756727, 0.3021278, 0.0005625>,
      <0.2639288, 0.4033549, 0.0005625>,
      <0.2376744, 0.3021101, 0.0005625>,
      <0.1377236, 0.3388860, -0.4226335>,
      <0.1641403, 0.4011489, -0.4231848>,
      <0.1640913, 0.4010886, -0.4216615>,
      <0.1416648, 0.3491201, -0.4216615>,
      <0.1509320, 0.3700174, -0.4229091>,
      <0.1641158, 0.4011187, -0.4224232>,
      <0.1528780, 0.3751043, -0.4216615>,
      <0.1396942, 0.3440030, -0.4221475>,
      <0.1519050, 0.3725609, -0.4222853>,
      <0.1192383, 0.2971517, -0.4216615>,
      <0.1113068, 0.2766230, -0.4220822>,
      <0.1304515, 0.3231359, -0.4216615>,
      <0.1152725, 0.2868873, -0.4218719>,
      <0.1245152, 0.3077545, -0.4223578>,
      <0.1274834, 0.3154452, -0.4220097>,
      <0.1033754, 0.2560943, -0.4225029>,
      <0.1337824, 0.3286518, -0.4236054>,
      <0.1073411, 0.2663586, -0.4222925>,
      <0.1185789, 0.2923730, -0.4230541>,
      <0.1357530, 0.3337689, -0.4231195>,
      <0.1215470, 0.3000637, -0.4227060>,
      <0.1641894, 0.4012093, -0.4247080>,
      <0.1489859, 0.3649305, -0.4241567>,
      <0.1641649, 0.4011791, -0.4239464>,
      <0.1499589, 0.3674740, -0.4235329>,
      <0.1902410, 0.2764994, -0.4220822>,
      <0.1963722, 0.2970285, -0.4216615>,
      <0.1507739, 0.2765612, -0.4220822>,
      <0.1578053, 0.2970901, -0.4216615>,
      <0.1933066, 0.2867639, -0.4218719>,
      <0.1542896, 0.2868256, -0.4218719>,
      <0.2735062, 0.2969052, -0.4216615>,
      <0.2691751, 0.2763759, -0.4220822>,
      <0.2349392, 0.2969668, -0.4216615>,
      <0.2713406, 0.2866405, -0.4218719>,
      <0.2297080, 0.2764376, -0.4220822>,
      <0.2323236, 0.2867022, -0.4218719>,
      <0.2648441, 0.2558465, -0.4225029>,
      <0.1841097, 0.2559704, -0.4225029>,
      <0.2670096, 0.2661112, -0.4222925>,
      <0.2244769, 0.2559084, -0.4225029>,
      <0.1871753, 0.2662349, -0.4222925>,
      <0.2270925, 0.2661730, -0.4222925>,
      <0.1437425, 0.2560323, -0.4225029>,
      <0.1472582, 0.2662968, -0.4222925>,
      <0.2829446, 0.3387090, -0.4226335>,
      <0.2851113, 0.3489392, -0.4216615>,
      <0.2760599, 0.3075424, -0.4223578>,
      <0.2793088, 0.3229222, -0.4216615>,
      <0.2840280, 0.3438241, -0.4221475>,
      <0.2776843, 0.3152323, -0.4220097>,
      <0.2967165, 0.4009732, -0.4216615>,
      <0.2967141, 0.4010421, -0.4231848>,
      <0.2909139, 0.3749562, -0.4216615>,
      <0.2967153, 0.4010076, -0.4224232>,
      <0.2898293, 0.3698755, -0.4229091>,
      <0.2903716, 0.3724159, -0.4222853>,
      <0.2967117, 0.4011109, -0.4247080>,
      <0.2807779, 0.3284787, -0.4236054>,
      <0.2967129, 0.4010765, -0.4239464>,
      <0.2887448, 0.3647948, -0.4241567>,
      <0.2818612, 0.3335938, -0.4231195>,
      <0.2892871, 0.3673352, -0.4235329>,
      <0.2728110, 0.2921626, -0.4230541>,
      <0.2744354, 0.2998525, -0.4227060>,
      <0.1339139, 0.3285714, -0.4057829>,
      <0.1642918, 0.4013351, -0.4063342>,
      <0.1491028, 0.3649533, -0.4060585>,
      <0.1642406, 0.4012722, -0.4155211>,
      <0.1338481, 0.3286116, -0.4146942>,
      <0.1490444, 0.3649419, -0.4151076>,
      <0.1035359, 0.2558076, -0.4052316>,
      <0.1034556, 0.2559509, -0.4138672>,
      <0.1187249, 0.2921895, -0.4055073>,
      <0.1186519, 0.2922812, -0.4142807>,
      <0.1036965, 0.2555209, -0.3879604>,
      <0.1340453, 0.3284909, -0.3879604>,
      <0.1036162, 0.2556642, -0.3965960>,
      <0.1188709, 0.2920059, -0.3879604>,
      <0.1339796, 0.3285311, -0.3968716>,
      <0.1187979, 0.2920977, -0.3967338>,
      <0.1643941, 0.4014610, -0.3879604>,
      <0.1492197, 0.3649760, -0.3879604>,
      <0.1643429, 0.4013981, -0.3971473>,
      <0.1491613, 0.3649646, -0.3970094>,
      <0.1839061, 0.2556830, -0.4052316>,
      <0.1437210, 0.2557453, -0.4052316>,
      <0.1840079, 0.2558267, -0.4138672>,
      <0.1437318, 0.2558888, -0.4138672>,
      <0.2642762, 0.2555585, -0.4052316>,
      <0.2645602, 0.2557025, -0.4138672>,
      <0.2240912, 0.2556207, -0.4052316>,
      <0.2242840, 0.2557646, -0.4138672>,
      <0.2637084, 0.2552704, -0.3879604>,
      <0.1837025, 0.2553956, -0.3879604>,
      <0.2639923, 0.2554144, -0.3965960>,
      <0.2237055, 0.2553330, -0.3879604>,
      <0.1838043, 0.2555393, -0.3965960>,
      <0.2238983, 0.2554769, -0.3965960>,
      <0.1436995, 0.2554582, -0.3879604>,
      <0.1437103, 0.2556018, -0.3965960>,
      <0.2804914, 0.3284065, -0.4057829>,
      <0.2723838, 0.2919825, -0.4055073>,
      <0.2806346, 0.3284426, -0.4146942>,
      <0.2725974, 0.2920725, -0.4142807>,
      <0.2967066, 0.4012545, -0.4063342>,
      <0.2967091, 0.4011827, -0.4155211>,
      <0.2885990, 0.3648305, -0.4060585>,
      <0.2886719, 0.3648127, -0.4151076>,
      <0.2967016, 0.4013981, -0.3879604>,
      <0.2802050, 0.3283342, -0.3879604>,
      <0.2967041, 0.4013263, -0.3971473>,
      <0.2884533, 0.3648662, -0.3879604>,
      <0.2803482, 0.3283704, -0.3968716>,
      <0.2885262, 0.3648483, -0.3970094>,
      <0.2719567, 0.2918023, -0.3879604>,
      <0.2721703, 0.2918924, -0.3967338>,
      <0.1318660, 0.3235508, -0.3860441>,
      <0.1644666, 0.4015502, -0.3860441>,
      <0.1481663, 0.3625505, -0.3860441>,
      <0.1644304, 0.4015056, -0.3870022>,
      <0.1329557, 0.3260209, -0.3870022>,
      <0.1486930, 0.3637632, -0.3870022>,
      <0.0992655, 0.2455514, -0.3860441>,
      <0.1014810, 0.2505361, -0.3870022>,
      <0.1155658, 0.2845511, -0.3860441>,
      <0.1172183, 0.2882785, -0.3870022>,
      <0.0948344, 0.2355819, -0.3841279>,
      <0.1296868, 0.3186107, -0.3841279>,
      <0.0970499, 0.2405667, -0.3850860>,
      <0.1122606, 0.2770963, -0.3841279>,
      <0.1307764, 0.3210807, -0.3850860>,
      <0.1139132, 0.2808237, -0.3850860>,
      <0.1645391, 0.4016394, -0.3841279>,
      <0.1471130, 0.3601250, -0.3841279>,
      <0.1645029, 0.4015948, -0.3850860>,
      <0.1476396, 0.3613378, -0.3850860>,
      <0.1805581, 0.2454257, -0.3860441>,
      <0.1399118, 0.2454885, -0.3860441>,
      <0.1821303, 0.2504107, -0.3870022>,
      <0.1418056, 0.2504734, -0.3870022>,
      <0.2618507, 0.2453000, -0.3860441>,
      <0.2627796, 0.2502852, -0.3870022>,
      <0.2212044, 0.2453628, -0.3860441>,
      <0.2224549, 0.2503479, -0.3870022>,
      <0.2599929, 0.2353296, -0.3841279>,
      <0.1774137, 0.2354557, -0.3841279>,
      <0.2609218, 0.2403148, -0.3850860>,
      <0.2187033, 0.2353926, -0.3841279>,
      <0.1789859, 0.2404407, -0.3850860>,
      <0.2199538, 0.2403777, -0.3850860>,
      <0.1361240, 0.2355188, -0.3841279>,
      <0.1380179, 0.2405037, -0.3850860>,
      <0.2792743, 0.3233999, -0.3860441>,
      <0.2705625, 0.2843499, -0.3860441>,
      <0.2797397, 0.3258671, -0.3870022>,
      <0.2712596, 0.2880761, -0.3870022>,
      <0.2966980, 0.4014998, -0.3860441>,
      <0.2966998, 0.4014490, -0.3870022>,
      <0.2879862, 0.3624499, -0.3860441>,
      <0.2882197, 0.3636580, -0.3870022>,
      <0.2966944, 0.4016016, -0.3841279>,
      <0.2783437, 0.3184656, -0.3841279>,
      <0.2966962, 0.4015507, -0.3850860>,
      <0.2875190, 0.3600336, -0.3841279>,
      <0.2788090, 0.3209327, -0.3850860>,
      <0.2877526, 0.3612417, -0.3850860>,
      <0.2691683, 0.2768976, -0.3841279>,
      <0.2698654, 0.2806238, -0.3850860>,
      <0.1189730, 0.2914994, -0.3502018>,
      <0.1645396, 0.4020332, -0.3494903>,
      <0.1417573, 0.3467667, -0.3497385>,
      <0.1645394, 0.4018363, -0.3668091>,
      <0.1241716, 0.3046359, -0.3679887>,
      <0.1443555, 0.3532361, -0.3673989>,
      <0.0733948, 0.1809606, -0.3522046>,
      <0.0838038, 0.2074354, -0.3691683>,
      <0.0961849, 0.2362304, -0.3510956>,
      <0.1039877, 0.2560357, -0.3685785>,
      <0.0569280, 0.1397127, -0.3042481>,
      <0.1107993, 0.2710979, -0.3022338>,
      <0.0642290, 0.1578292, -0.3312325>,
      <0.0838694, 0.2054077, -0.3025954>,
      <0.1144075, 0.2800395, -0.3291197>,
      <0.0893221, 0.2189360, -0.3297457>,
      <0.1645401, 0.4024270, -0.3148527>,
      <0.1377062, 0.3367781, -0.3044546>,
      <0.1645398, 0.4022301, -0.3321715>,
      <0.1394775, 0.3411364, -0.3302152>,
      <0.1614358, 0.1808343, -0.3522046>,
      <0.1174153, 0.1808975, -0.3522046>,
      <0.1692003, 0.2073093, -0.3691683>,
      <0.1265021, 0.2073724, -0.3691683>,
      <0.2494767, 0.1807081, -0.3522046>,
      <0.2545968, 0.2071831, -0.3691683>,
      <0.2054562, 0.1807712, -0.3522046>,
      <0.2118985, 0.2072462, -0.3691683>,
      <0.2411690, 0.1394583, -0.3042481>,
      <0.1490485, 0.1395855, -0.3042481>,
      <0.2449088, 0.1575760, -0.3312325>,
      <0.1951088, 0.1395219, -0.3042481>,
      <0.1545689, 0.1577026, -0.3312325>,
      <0.1997388, 0.1576393, -0.3312325>,
      <0.1029883, 0.1396491, -0.3042481>,
      <0.1093990, 0.1577659, -0.3312325>,
      <0.2730853, 0.2913552, -0.3502018>,
      <0.2612809, 0.2360322, -0.3510956>,
      <0.2756456, 0.3044908, -0.3679887>,
      <0.2651212, 0.2558369, -0.3685785>,
      <0.2966944, 0.4019954, -0.3494903>,
      <0.2966944, 0.4017985, -0.3668091>,
      <0.2848898, 0.3466759, -0.3497385>,
      <0.2861700, 0.3531447, -0.3673989>,
      <0.2966944, 0.4023893, -0.3148527>,
      <0.2689285, 0.2709631, -0.3022338>,
      <0.2966944, 0.4021924, -0.3321715>,
      <0.2828096, 0.3366982, -0.3044546>,
      <0.2708004, 0.2798981, -0.3291197>,
      <0.2837472, 0.3410475, -0.3302152>,
      <0.2550485, 0.2052142, -0.3025954>,
      <0.2578544, 0.2187393, -0.3297457>,
      <0.1068658, 0.2618260, -0.2281204>,
      <0.1650319, 0.4030318, -0.2251259>,
      <0.1359489, 0.3324275, -0.2266602>,
      <0.1647860, 0.4027294, -0.2699893>,
      <0.1084727, 0.2655160, -0.2670358>,
      <0.1366332, 0.3341244, -0.2680822>,
      <0.0486992, 0.1206380, -0.2306704>,
      <0.0521134, 0.1282829, -0.2692470>,
      <0.0777826, 0.1912305, -0.2294324>,
      <0.0802969, 0.1969011, -0.2677110>,
      <0.0417281, 0.1050960, -0.1605554>,
      <0.1035637, 0.2542376, -0.1578122>,
      <0.0455994, 0.1138763, -0.1929595>,
      <0.0726404, 0.1796555, -0.1600516>,
      <0.1054166, 0.2585599, -0.1900822>,
      <0.0755044, 0.1862105, -0.1920994>,
      <0.1655237, 0.4036367, -0.1353992>,
      <0.1345089, 0.3288653, -0.1521017>,
      <0.1652778, 0.4033343, -0.1802626>,
      <0.1353435, 0.3309395, -0.1857509>,
      <0.1426240, 0.1205086, -0.2306704>,
      <0.0956616, 0.1205733, -0.2306704>,
      <0.1453235, 0.1281547, -0.2692470>,
      <0.0987185, 0.1282188, -0.2692470>,
      <0.2365489, 0.1203792, -0.2306704>,
      <0.2385335, 0.1280265, -0.2692470>,
      <0.1895865, 0.1204439, -0.2306704>,
      <0.1919285, 0.1280906, -0.2692470>,
      <0.2327185, 0.1048326, -0.1605554>,
      <0.1372233, 0.1049643, -0.1605554>,
      <0.2347617, 0.1136150, -0.1929595>,
      <0.1849709, 0.1048985, -0.1605554>,
      <0.1401805, 0.1137456, -0.1929595>,
      <0.1874711, 0.1136803, -0.1929595>,
      <0.0894757, 0.1050301, -0.1605554>,
      <0.0928900, 0.1138110, -0.1929595>,
      <0.2666095, 0.2617204, -0.2281204>,
      <0.2515792, 0.1910483, -0.2294324>,
      <0.2676068, 0.2653943, -0.2670358>,
      <0.2530700, 0.1967127, -0.2677110>,
      <0.2966701, 0.4030793, -0.2251259>,
      <0.2966822, 0.4027343, -0.2699893>,
      <0.2816398, 0.3323984, -0.2266602>,
      <0.2821443, 0.3340666, -0.2680822>,
      <0.2966459, 0.4037693, -0.1353992>,
      <0.2646852, 0.2541615, -0.1578122>,
      <0.2966580, 0.4034243, -0.1802626>,
      <0.2806673, 0.3288875, -0.1521017>,
      <0.2657109, 0.2584704, -0.1900822>,
      <0.2811846, 0.3309392, -0.1857509>,
      <0.2487021, 0.1794847, -0.1600516>,
      <0.2502365, 0.1860345, -0.1920994>,
      <0.0972067, 0.2386271, -0.1220064>,
      <0.1655472, 0.4032725, -0.1197235>,
      <0.1313761, 0.3209479, -0.1210096>,
      <0.1655354, 0.4034546, -0.1275614>,
      <0.1007454, 0.2473795, -0.1362014>,
      <0.1331367, 0.3254095, -0.1324599>,
      <0.0288772, 0.0740045, -0.1225537>,
      <0.0359992, 0.0913954, -0.1378991>,
      <0.0630411, 0.1563139, -0.1224247>,
      <0.0683687, 0.1693799, -0.1376288>,
      <0.0123114, 0.0330724, -0.1040479>,
      <0.0889410, 0.2179903, -0.1040479>,
      <0.0208265, 0.0541535, -0.1120823>,
      <0.0506262, 0.1255313, -0.1040479>,
      <0.0931927, 0.2286219, -0.1119840>,
      <0.0570096, 0.1413877, -0.1120332>,
      <0.1655707, 0.4029082, -0.1040479>,
      <0.1272559, 0.3104492, -0.1040479>,
      <0.1655590, 0.4030903, -0.1118857>,
      <0.1293758, 0.3158561, -0.1119349>,
      <0.1277792, 0.0738718, -0.1225537>,
      <0.0783282, 0.0739381, -0.1225537>,
      <0.1329826, 0.0912630, -0.1378991>,
      <0.0844909, 0.0913292, -0.1378991>,
      <0.2266812, 0.0737391, -0.1225537>,
      <0.2299659, 0.0911307, -0.1378991>,
      <0.1772302, 0.0738054, -0.1225537>,
      <0.1814742, 0.0911969, -0.1378991>,
      <0.2192252, 0.0328065, -0.1040479>,
      <0.1157683, 0.0329394, -0.1040479>,
      <0.2230419, 0.0538877, -0.1120823>,
      <0.1674967, 0.0328729, -0.1040479>,
      <0.1219342, 0.0540206, -0.1120823>,
      <0.1724880, 0.0539542, -0.1120823>,
      <0.0640398, 0.0330059, -0.1040479>,
      <0.0713803, 0.0540870, -0.1120823>,
      <0.2616632, 0.2385618, -0.1220064>,
      <0.2441723, 0.1561484, -0.1224247>,
      <0.2633067, 0.2473107, -0.1362014>,
      <0.2466364, 0.1692125, -0.1376288>,
      <0.2966447, 0.4034091, -0.1197235>,
      <0.2966453, 0.4035892, -0.1275614>,
      <0.2791540, 0.3209834, -0.1210096>,
      <0.2799761, 0.3254418, -0.1324599>,
      <0.2966435, 0.4030489, -0.1040479>,
      <0.2579344, 0.2179277, -0.1040479>,
      <0.2966441, 0.4032290, -0.1118857>,
      <0.2772889, 0.3104883, -0.1040479>,
      <0.2598430, 0.2285584, -0.1119840>,
      <0.2782436, 0.3158937, -0.1119349>,
      <0.2385798, 0.1253671, -0.1040479>,
      <0.2414424, 0.1412230, -0.1120332>,
      <0.0852395, 0.2094437, -0.1040479>,
      <0.1656962, 0.4030625, -0.1040479>,
      <0.1254678, 0.3062531, -0.1040479>,
      <0.1656335, 0.4029853, -0.1040479>,
      <0.0870903, 0.2137170, -0.1040479>,
      <0.1263619, 0.3083512, -0.1040479>,
      <0.0047827, 0.0158248, -0.1040479>,
      <0.0085470, 0.0244486, -0.1040479>,
      <0.0450111, 0.1126342, -0.1040479>,
      <0.0478186, 0.1190828, -0.1040479>,
      <-0.0027459, -0.0014227, -0.1040479>,
      <0.0815379, 0.2008970, -0.1040479>,
      <0.0010184, 0.0072010, -0.1040479>,
      <0.0393960, 0.0997371, -0.1040479>,
      <0.0833887, 0.2051703, -0.1040479>,
      <0.0422035, 0.1061857, -0.1040479>,
      <0.1658216, 0.4032168, -0.1040479>,
      <0.1236798, 0.3020569, -0.1040479>,
      <0.1657589, 0.4031397, -0.1040479>,
      <0.1245738, 0.3041550, -0.1040479>,
      <0.1103970, 0.0156910, -0.1040479>,
      <0.0575898, 0.0157579, -0.1040479>,
      <0.1130826, 0.0243152, -0.1040479>,
      <0.0608148, 0.0243819, -0.1040479>,
      <0.2160112, 0.0155573, -0.1040479>,
      <0.2176182, 0.0241819, -0.1040479>,
      <0.1632041, 0.0156241, -0.1040479>,
      <0.1653504, 0.0242485, -0.1040479>,
      <0.2127972, -0.0016919, -0.1040479>,
      <0.1050256, -0.0015573, -0.1040479>,
      <0.2144042, 0.0069327, -0.1040479>,
      <0.1589114, -0.0016246, -0.1040479>,
      <0.1077113, 0.0070668, -0.1040479>,
      <0.1610577, 0.0069998, -0.1040479>,
      <0.0511399, -0.0014900, -0.1040479>,
      <0.0543649, 0.0071339, -0.1040479>,
      <0.2563243, 0.2093911, -0.1040479>,
      <0.2361677, 0.1124742, -0.1040479>,
      <0.2571293, 0.2136594, -0.1040479>,
      <0.2373737, 0.1189206, -0.1040479>,
      <0.2966373, 0.4032250, -0.1040479>,
      <0.2966404, 0.4031370, -0.1040479>,
      <0.2764808, 0.3063080, -0.1040479>,
      <0.2768849, 0.3083982, -0.1040479>,
      <0.2966312, 0.4034010, -0.1040479>,
      <0.2547142, 0.2008545, -0.1040479>,
      <0.2966343, 0.4033130, -0.1040479>,
      <0.2756727, 0.3021278, -0.1040479>,
      <0.2555192, 0.2051228, -0.1040479>,
      <0.2760767, 0.3042179, -0.1040479>,
      <0.2337557, 0.0995813, -0.1040479>,
      <0.2349617, 0.1060277, -0.1040479>,
      <0.0815379, 0.2008970, -0.0517427>,
      <0.1658216, 0.4032168, -0.0517427>,
      <0.1236798, 0.3020569, -0.0517427>,
      <0.1658216, 0.4032168, -0.0778953>,
      <0.0815379, 0.2008970, -0.0778953>,
      <0.1236798, 0.3020569, -0.0778953>,
      <-0.0027459, -0.0014227, -0.0517427>,
      <-0.0027459, -0.0014227, -0.0778953>,
      <0.0393960, 0.0997371, -0.0517427>,
      <0.0393960, 0.0997371, -0.0778953>,
      <-0.0027459, -0.0014227, -0.0255901>,
      <0.0815379, 0.2008970, -0.0255901>,
      <0.0393960, 0.0997371, -0.0255901>,
      <0.1658216, 0.4032168, -0.0255901>,
      <0.1236798, 0.3020569, -0.0255901>,
      <0.1050256, -0.0015573, -0.0517427>,
      <0.0511399, -0.0014900, -0.0517427>,
      <0.1050256, -0.0015573, -0.0778953>,
      <0.0511399, -0.0014900, -0.0778953>,
      <0.2127972, -0.0016919, -0.0517427>,
      <0.2127972, -0.0016919, -0.0778953>,
      <0.1589114, -0.0016246, -0.0517427>,
      <0.1589114, -0.0016246, -0.0778953>,
      <0.2127972, -0.0016919, -0.0255901>,
      <0.1050256, -0.0015573, -0.0255901>,
      <0.1589114, -0.0016246, -0.0255901>,
      <0.0511399, -0.0014900, -0.0255901>,
      <0.2547142, 0.2008545, -0.0517427>,
      <0.2337557, 0.0995813, -0.0517427>,
      <0.2547142, 0.2008545, -0.0778953>,
      <0.2337557, 0.0995813, -0.0778953>,
      <0.2966312, 0.4034010, -0.0517427>,
      <0.2966312, 0.4034010, -0.0778953>,
      <0.2756727, 0.3021278, -0.0517427>,
      <0.2756727, 0.3021278, -0.0778953>,
      <0.2966312, 0.4034010, -0.0255901>,
      <0.2547142, 0.2008545, -0.0255901>,
      <0.2756727, 0.3021278, -0.0255901>,
      <0.2337557, 0.0995813, -0.0255901>,
      <0.2312264, 0.4033089, -0.0517427>,
      <0.1658216, 0.4032168, -0.0517427>,
      <0.2312264, 0.4033089, -0.1040479>,
      <0.1985240, 0.4032629, -0.0517427>,
      <0.1658216, 0.4032168, -0.0778953>,
      <0.1985240, 0.4032629, -0.1040479>,
      <0.2312264, 0.4033089, -0.0778953>,
      <0.1985240, 0.4032629, -0.0778953>,
      <0.2966312, 0.4034010, -0.0517427>,
      <0.2639288, 0.4033549, -0.1040479>,
      <0.2966312, 0.4034010, -0.0778953>,
      <0.2639288, 0.4033549, -0.0517427>,
      <0.2639288, 0.4033549, -0.0778953>,
      <0.2312264, 0.4033089, 0.0005625>,
      <0.2966312, 0.4034010, -0.0255901>,
      <0.2639288, 0.4033549, 0.0005625>,
      <0.2312264, 0.4033089, -0.0255901>,
      <0.2639288, 0.4033549, -0.0255901>,
      <0.1985240, 0.4032629, 0.0005625>,
      <0.1658216, 0.4032168, -0.0255901>,
      <0.1985240, 0.4032629, -0.0255901>,
      <0.2311668, 0.4031437, -0.1040479>,
      <0.2311071, 0.4029786, -0.1040479>,
      <0.2311369, 0.4030612, -0.1040479>,
      <0.1983389, 0.4029434, -0.1040479>,
      <0.1984315, 0.4031031, -0.1040479>,
      <0.1983852, 0.4030233, -0.1040479>,
      <0.2312264, 0.4033089, -0.1040479>,
      <0.1985240, 0.4032629, -0.1040479>,
      <0.2311966, 0.4032263, -0.1040479>,
      <0.1984778, 0.4031830, -0.1040479>,
      <0.2639288, 0.4033549, -0.1040479>,
      <0.2639021, 0.4031844, -0.1040479>,
      <0.2639154, 0.4032696, -0.1040479>,
      <0.2638753, 0.4030138, -0.1040479>,
      <0.2638887, 0.4030991, -0.1040479>,
      <0.2310959, 0.4033408, -0.1197235>,
      <0.1655472, 0.4032725, -0.1197235>,
      <0.2310848, 0.4037030, -0.1353992>,
      <0.1983216, 0.4033066, -0.1197235>,
      <0.1655354, 0.4034546, -0.1275614>,
      <0.1983042, 0.4036699, -0.1353992>,
      <0.2310904, 0.4035219, -0.1275614>,
      <0.1983129, 0.4034882, -0.1275614>,
      <0.2966447, 0.4034091, -0.1197235>,
      <0.2638653, 0.4037362, -0.1353992>,
      <0.2966453, 0.4035892, -0.1275614>,
      <0.2638703, 0.4033750, -0.1197235>,
      <0.2638678, 0.4035556, -0.1275614>,
      <0.2311071, 0.4029786, -0.1040479>,
      <0.2966441, 0.4032290, -0.1118857>,
      <0.2638753, 0.4030138, -0.1040479>,
      <0.2311015, 0.4031597, -0.1118857>,
      <0.2638728, 0.4031944, -0.1118857>,
      <0.1983389, 0.4029434, -0.1040479>,
      <0.1655590, 0.4030903, -0.1118857>,
      <0.1983302, 0.4031250, -0.1118857>,
      <0.2308510, 0.4030556, -0.2251259>,
      <0.2306172, 0.4024081, -0.3148527>,
      <0.2307341, 0.4027319, -0.2699893>,
      <0.1975787, 0.4024176, -0.3148527>,
      <0.1979414, 0.4030437, -0.2251259>,
      <0.1977600, 0.4027306, -0.2699893>,
      <0.2310848, 0.4037030, -0.1353992>,
      <0.1983042, 0.4036699, -0.1353992>,
      <0.2309679, 0.4033793, -0.1802626>,
      <0.1981228, 0.4033568, -0.1802626>,
      <0.2638653, 0.4037362, -0.1353992>,
      <0.2637606, 0.4030674, -0.2251259>,
      <0.2638129, 0.4034018, -0.1802626>,
      <0.2636558, 0.4023987, -0.3148527>,
      <0.2637082, 0.4027331, -0.2699893>,
      <0.2306170, 0.4020143, -0.3494903>,
      <0.1645396, 0.4020332, -0.3494903>,
      <0.2306168, 0.4016205, -0.3841279>,
      <0.1975783, 0.4020237, -0.3494903>,
      <0.1645394, 0.4018363, -0.3668091>,
      <0.1975780, 0.4016299, -0.3841279>,
      <0.2306169, 0.4018174, -0.3668091>,
      <0.1975781, 0.4018268, -0.3668091>,
      <0.2966944, 0.4019954, -0.3494903>,
      <0.2636556, 0.4016110, -0.3841279>,
      <0.2966944, 0.4017985, -0.3668091>,
      <0.2636557, 0.4020049, -0.3494903>,
      <0.2636557, 0.4018080, -0.3668091>,
      <0.2306172, 0.4024081, -0.3148527>,
      <0.2966944, 0.4021924, -0.3321715>,
      <0.2636558, 0.4023987, -0.3148527>,
      <0.2306171, 0.4022112, -0.3321715>,
      <0.2636558, 0.4022018, -0.3321715>,
      <0.1975787, 0.4024176, -0.3148527>,
      <0.1645398, 0.4022301, -0.3321715>,
      <0.1975785, 0.4022207, -0.3321715>,
      <0.2305823, 0.4015250, -0.3860441>,
      <0.2305478, 0.4014295, -0.3879604>,
      <0.2305651, 0.4014773, -0.3870022>,
      <0.1974710, 0.4014453, -0.3879604>,
      <0.1975245, 0.4015376, -0.3860441>,
      <0.1974977, 0.4014914, -0.3870022>,
      <0.2306168, 0.4016205, -0.3841279>,
      <0.1975780, 0.4016299, -0.3841279>,
      <0.2305995, 0.4015728, -0.3850860>,
      <0.1975512, 0.4015838, -0.3850860>,
      <0.2636556, 0.4016110, -0.3841279>,
      <0.2636402, 0.4015124, -0.3860441>,
      <0.2636479, 0.4015617, -0.3850860>,
      <0.2636247, 0.4014138, -0.3879604>,
      <0.2636324, 0.4014631, -0.3870022>,
      <0.2304781, 0.4012364, -0.4044517>,
      <0.1642427, 0.4012748, -0.4048110>,
      <0.2304292, 0.4011010, -0.4175902>,
      <0.1973608, 0.4012566, -0.4045715>,
      <0.1641670, 0.4011817, -0.4132362>,
      <0.1972750, 0.4011164, -0.4183087>,
      <0.2304488, 0.4011553, -0.4117993>,
      <0.1973094, 0.4011726, -0.4122783>,
      <0.2967090, 0.4011856, -0.4048110>,
      <0.2635745, 0.4010609, -0.4183087>,
      <0.2967128, 0.4010794, -0.4132362>,
      <0.2635939, 0.4012121, -0.4045715>,
      <0.2635823, 0.4011215, -0.4122783>,
      <0.2305478, 0.4014295, -0.3879604>,
      <0.2967053, 0.4012919, -0.3963857>,
      <0.2636247, 0.4014138, -0.3879604>,
      <0.2305119, 0.4013299, -0.3963857>,
      <0.2636086, 0.4013109, -0.3963857>,
      <0.1974710, 0.4014453, -0.3879604>,
      <0.1643184, 0.4013679, -0.3963857>,
      <0.1974151, 0.4013489, -0.3963857>,
      <0.2304295, 0.4011017, -0.4228255>,
      <0.2304245, 0.4010879, -0.4209862>,
      <0.1972853, 0.4011263, -0.4229453>,
      <0.1972716, 0.4011075, -0.4214652>,
      <0.2304505, 0.4011601, -0.4247080>,
      <0.1973200, 0.4011847, -0.4247080>,
      <0.2304389, 0.4011278, -0.4239464>,
      <0.1973019, 0.4011534, -0.4239464>,
      <0.2635811, 0.4011355, -0.4247080>,
      <0.2635721, 0.4010729, -0.4229453>,
      <0.2635759, 0.4011021, -0.4239464>,
      <0.2635714, 0.4010519, -0.4214652>
    }
    normal_vectors {
      1158,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.9074082, -0.3872029, 0.1633530>,
      <0.8567776, -0.3645825, 0.3647078>,
      <0.8705311, -0.3664383, 0.3284792>,
      <0.9106993, -0.3850654, 0.1495039>,
      <0.9205227, -0.3904314, 0.0141866>,
      <0.9194080, -0.3930543, 0.0140467>,
      <0.9194080, -0.3930543, 0.0140467>,
      <0.9180666, -0.3961832, 0.0138795>,
      <0.9030988, -0.3897240, 0.1803547>,
      <0.9030988, -0.3897240, 0.1803547>,
      <0.8376078, -0.3614620, 0.4095832>,
      <0.7312002, -0.3097147, 0.6078019>,
      <0.7723338, -0.3228401, 0.5470601>,
      <0.8376078, -0.3614620, 0.4095832>,
      <0.6740621, -0.2908853, 0.6789889>,
      <0.6740621, -0.2908853, 0.6789889>,
      <0.4066350, -0.1754796, 0.8965796>,
      <0.5111599, -0.2145461, 0.8322773>,
      <0.5111599, -0.2145461, 0.8322773>,
      <0.5933909, -0.2449737, 0.7667302>,
      <0.8024955, -0.3321537, 0.4956560>,
      <0.8807173, -0.3675379, 0.2987522>,
      <0.5933909, -0.2449737, 0.7667302>,
      <0.6571014, -0.2683123, 0.7044333>,
      <0.6571014, -0.2683123, 0.7044333>,
      <0.7063056, -0.2861560, 0.6474929>,
      <0.8250642, -0.3388934, 0.4521287>,
      <0.8250642, -0.3388934, 0.4521287>,
      <0.8884690, -0.3681717, 0.2739935>,
      <0.9132819, -0.3832349, 0.1380115>,
      <0.8884690, -0.3681717, 0.2739935>,
      <0.9153546, -0.3816523, 0.1283255>,
      <0.9153546, -0.3816523, 0.1283255>,
      <0.9222687, -0.3862809, 0.0144073>,
      <0.9214638, -0.3882008, 0.0143053>,
      <0.9214638, -0.3882008, 0.0143053>,
      <0.9205227, -0.3904314, 0.0141866>,
      <0.0000324, 0.0204760, -0.9997903>,
      <0.0000324, 0.0204773, -0.9997903>,
      <0.0000321, 0.0204774, -0.9997903>,
      <0.0000321, 0.0204761, -0.9997903>,
      <0.0000321, 0.0204749, -0.9997904>,
      <0.0000324, 0.0204748, -0.9997904>,
      <0.0000324, 0.0204748, -0.9997904>,
      <0.0000327, 0.0204746, -0.9997904>,
      <0.0000327, 0.0204759, -0.9997903>,
      <0.0000327, 0.0204759, -0.9997903>,
      <0.0000327, 0.0204772, -0.9997903>,
      <0.0000324, 0.0204785, -0.9997903>,
      <0.0000321, 0.0204786, -0.9997903>,
      <0.0000327, 0.0204772, -0.9997903>,
      <0.0000327, 0.0204785, -0.9997903>,
      <0.0000327, 0.0204785, -0.9997903>,
      <0.0000327, 0.0204797, -0.9997903>,
      <0.0000324, 0.0204798, -0.9997903>,
      <0.0000324, 0.0204798, -0.9997903>,
      <0.0000321, 0.0204799, -0.9997903>,
      <0.0000317, 0.0204787, -0.9997903>,
      <0.0000317, 0.0204775, -0.9997903>,
      <0.0000321, 0.0204799, -0.9997903>,
      <0.0000317, 0.0204799, -0.9997903>,
      <0.0000317, 0.0204799, -0.9997903>,
      <0.0000314, 0.0204800, -0.9997903>,
      <0.0000314, 0.0204788, -0.9997903>,
      <0.0000314, 0.0204788, -0.9997903>,
      <0.0000314, 0.0204776, -0.9997903>,
      <0.0000317, 0.0204763, -0.9997903>,
      <0.0000314, 0.0204776, -0.9997903>,
      <0.0000314, 0.0204764, -0.9997903>,
      <0.0000314, 0.0204764, -0.9997903>,
      <0.0000314, 0.0204751, -0.9997904>,
      <0.0000317, 0.0204750, -0.9997904>,
      <0.0000317, 0.0204750, -0.9997904>,
      <0.0000321, 0.0204749, -0.9997904>,
      <-0.9561763, 0.2111695, -0.2028159>,
      <-0.9716563, 0.2151090, -0.0980419>,
      <-0.9730587, 0.2141959, -0.0853041>,
      <-0.9622750, 0.2110496, -0.1717117>,
      <-0.9276272, 0.2021366, -0.3140838>,
      <-0.9002818, 0.1978768, -0.3877338>,
      <-0.9002818, 0.1978768, -0.3877338>,
      <-0.8463004, 0.1887508, -0.4981454>,
      <-0.9459633, 0.2109787, -0.2462549>,
      <-0.9459633, 0.2109787, -0.2462549>,
      <-0.9695852, 0.2162471, -0.1146373>,
      <-0.9757699, 0.2163365, -0.0327341>,
      <-0.9761155, 0.2153734, -0.0285115>,
      <-0.9695852, 0.2162471, -0.1146373>,
      <-0.9753159, 0.2175252, -0.0379696>,
      <-0.9753159, 0.2175252, -0.0379696>,
      <-0.9759564, 0.2176680, 0.0113907>,
      <-0.9761854, 0.2166412, 0.0113447>,
      <-0.9761854, 0.2166412, 0.0113447>,
      <-0.9763759, 0.2157831, 0.0113062>,
      <-0.9763861, 0.2145773, -0.0250339>,
      <-0.9740539, 0.2134489, -0.0752237>,
      <-0.9763759, 0.2157831, 0.0113062>,
      <-0.9765368, 0.2150553, 0.0112736>,
      <-0.9765368, 0.2150553, 0.0112736>,
      <-0.9766746, 0.2144303, 0.0112455>,
      <-0.9766033, 0.2139081, -0.0221202>,
      <-0.9766033, 0.2139081, -0.0221202>,
      <-0.9747865, 0.2128276, -0.0670499>,
      <-0.9661931, 0.2108222, -0.1484076>,
      <-0.9747865, 0.2128276, -0.0670499>,
      <-0.9688537, 0.2105655, -0.1303249>,
      <-0.9688537, 0.2105655, -0.1303249>,
      <-0.9525448, 0.2055580, -0.2245089>,
      <-0.9430695, 0.2043359, -0.2624249>,
      <-0.9430695, 0.2043359, -0.2624249>,
      <-0.9276272, 0.2021366, -0.3140838>,
      <-0.9225117, 0.3859302, 0.0054741>,
      <-0.9224794, 0.3859517, 0.0085459>,
      <-0.9227513, 0.3853011, 0.0085450>,
      <-0.9227795, 0.3852896, 0.0054766>,
      <-0.9227984, 0.3852750, 0.0025004>,
      <-0.9225347, 0.3859060, 0.0024946>,
      <-0.9225347, 0.3859060, 0.0024946>,
      <-0.9222701, 0.3865382, 0.0024888>,
      <-0.9222429, 0.3865721, 0.0054716>,
      <-0.9222429, 0.3865721, 0.0054716>,
      <-0.9222064, 0.3866036, 0.0085468>,
      <-0.9224370, 0.3859700, 0.0117143>,
      <-0.9227132, 0.3853092, 0.0117097>,
      <-0.9222064, 0.3866036, 0.0085468>,
      <-0.9221596, 0.3866321, 0.0117189>,
      <-0.9221596, 0.3866321, 0.0117189>,
      <-0.9221015, 0.3866575, 0.0149923>,
      <-0.9223834, 0.3859848, 0.0149838>,
      <-0.9223834, 0.3859848, 0.0149838>,
      <-0.9226642, 0.3853135, 0.0149753>,
      <-0.9229884, 0.3846497, 0.0117051>,
      <-0.9230222, 0.3846518, 0.0085440>,
      <-0.9226642, 0.3853135, 0.0149753>,
      <-0.9229439, 0.3846435, 0.0149667>,
      <-0.9229439, 0.3846435, 0.0149667>,
      <-0.9232224, 0.3839749, 0.0149582>,
      <-0.9232625, 0.3839916, 0.0117005>,
      <-0.9232625, 0.3839916, 0.0117005>,
      <-0.9232920, 0.3840038, 0.0085431>,
      <-0.9230461, 0.3846502, 0.0054792>,
      <-0.9232920, 0.3840038, 0.0085431>,
      <-0.9233118, 0.3840121, 0.0054817>,
      <-0.9233118, 0.3840121, 0.0054817>,
      <-0.9233228, 0.3840166, 0.0025120>,
      <-0.9230611, 0.3846452, 0.0025062>,
      <-0.9230611, 0.3846452, 0.0025062>,
      <-0.9227984, 0.3852750, 0.0025004>,
      <-0.0015419, -0.9998607, -0.0166193>,
      <-0.0015419, -0.9998601, -0.0166549>,
      <-0.0015496, -0.9998601, -0.0166550>,
      <-0.0015496, -0.9998607, -0.0166193>,
      <-0.0015496, -0.9998613, -0.0165835>,
      <-0.0015419, -0.9998613, -0.0165836>,
      <-0.0015419, -0.9998613, -0.0165836>,
      <-0.0015343, -0.9998613, -0.0165836>,
      <-0.0015343, -0.9998607, -0.0166192>,
      <-0.0015343, -0.9998607, -0.0166192>,
      <-0.0015343, -0.9998601, -0.0166549>,
      <-0.0015419, -0.9998595, -0.0166906>,
      <-0.0015496, -0.9998595, -0.0166908>,
      <-0.0015343, -0.9998601, -0.0166549>,
      <-0.0015343, -0.9998595, -0.0166905>,
      <-0.0015343, -0.9998595, -0.0166905>,
      <-0.0015343, -0.9998589, -0.0167261>,
      <-0.0015419, -0.9998589, -0.0167263>,
      <-0.0015419, -0.9998589, -0.0167263>,
      <-0.0015496, -0.9998589, -0.0167266>,
      <-0.0015573, -0.9998595, -0.0166910>,
      <-0.0015573, -0.9998601, -0.0166551>,
      <-0.0015496, -0.9998589, -0.0167266>,
      <-0.0015573, -0.9998589, -0.0167268>,
      <-0.0015573, -0.9998589, -0.0167268>,
      <-0.0015650, -0.9998589, -0.0167271>,
      <-0.0015650, -0.9998595, -0.0166912>,
      <-0.0015650, -0.9998595, -0.0166912>,
      <-0.0015650, -0.9998601, -0.0166552>,
      <-0.0015573, -0.9998607, -0.0166193>,
      <-0.0015650, -0.9998601, -0.0166552>,
      <-0.0015650, -0.9998607, -0.0166193>,
      <-0.0015650, -0.9998607, -0.0166193>,
      <-0.0015650, -0.9998613, -0.0165833>,
      <-0.0015573, -0.9998613, -0.0165834>,
      <-0.0015573, -0.9998613, -0.0165834>,
      <-0.0015496, -0.9998613, -0.0165835>,
      <0.9762669, -0.2154957, 0.0215514>,
      <0.9763704, -0.2155951, 0.0148175>,
      <0.9760279, -0.2171413, 0.0148057>,
      <0.9759195, -0.2170663, 0.0215268>,
      <0.9757614, -0.2169786, 0.0284601>,
      <0.9761138, -0.2153828, 0.0284983>,
      <0.9761138, -0.2153828, 0.0284983>,
      <0.9764649, -0.2137804, 0.0285366>,
      <0.9766132, -0.2139186, 0.0215760>,
      <0.9766132, -0.2139186, 0.0215760>,
      <0.9767118, -0.2140426, 0.0148293>,
      <0.9764285, -0.2156821, 0.0082879>,
      <0.9760909, -0.2172046, 0.0082882>,
      <0.9767118, -0.2140426, 0.0148293>,
      <0.9767648, -0.2141536, 0.0082876>,
      <0.9767648, -0.2141536, 0.0082876>,
      <0.9767764, -0.2142524, 0.0019426>,
      <0.9764450, -0.2157578, 0.0019543>,
      <0.9764450, -0.2157578, 0.0019543>,
      <0.9761124, -0.2172573, 0.0019659>,
      <0.9757522, -0.2187211, 0.0082885>,
      <0.9756842, -0.2186812, 0.0147940>,
      <0.9761124, -0.2172573, 0.0019659>,
      <0.9757787, -0.2187508, 0.0019775>,
      <0.9757787, -0.2187508, 0.0019775>,
      <0.9754440, -0.2202386, 0.0019891>,
      <0.9754124, -0.2202315, 0.0082887>,
      <0.9754124, -0.2202315, 0.0082887>,
      <0.9753394, -0.2202150, 0.0147822>,
      <0.9755708, -0.2186305, 0.0215023>,
      <0.9753394, -0.2202150, 0.0147822>,
      <0.9752209, -0.2201882, 0.0214777>,
      <0.9752209, -0.2201882, 0.0214777>,
      <0.9750529, -0.2201503, 0.0283840>,
      <0.9754078, -0.2185678, 0.0284220>,
      <0.9754078, -0.2185678, 0.0284220>,
      <0.9757614, -0.2169786, 0.0284601>,
      <-0.9227892, 0.3847731, -0.0202417>,
      <-0.9214559, 0.3842171, -0.0574129>,
      <-0.9212541, 0.3850467, -0.0550447>,
      <-0.9224850, 0.3855612, -0.0190770>,
      <-0.9225202, 0.3855759, 0.0169650>,
      <-0.9228447, 0.3847962, 0.0170136>,
      <-0.9228447, 0.3847962, 0.0170136>,
      <-0.9231912, 0.3839619, 0.0170655>,
      <-0.9231125, 0.3839292, -0.0214876>,
      <-0.9231125, 0.3839292, -0.0214876>,
      <-0.9216652, 0.3833273, -0.0599450>,
      <-0.9188613, 0.3831352, -0.0943469>,
      <-0.9188416, 0.3840384, -0.0907996>,
      <-0.9216652, 0.3833273, -0.0599450>,
      <-0.9188686, 0.3821641, -0.0981375>,
      <-0.9188686, 0.3821641, -0.0981375>,
      <-0.9147594, 0.3804551, -0.1359014>,
      <-0.9150372, 0.3815407, -0.1308956>,
      <-0.9150372, 0.3815407, -0.1308956>,
      <-0.9152754, 0.3825478, -0.1262068>,
      <-0.9188120, 0.3848804, -0.0874729>,
      <-0.9210597, 0.3858219, -0.0528251>,
      <-0.9152754, 0.3825478, -0.1262068>,
      <-0.9154796, 0.3834845, -0.1218061>,
      <-0.9154796, 0.3834845, -0.1218061>,
      <-0.9156546, 0.3843577, -0.1176680>,
      <-0.9187744, 0.3856672, -0.0843470>,
      <-0.9187744, 0.3856672, -0.0843470>,
      <-0.9208725, 0.3865479, -0.0507406>,
      <-0.9221983, 0.3862989, -0.0179856>,
      <-0.9208725, 0.3865479, -0.0507406>,
      <-0.9219276, 0.3869908, -0.0169610>,
      <-0.9219276, 0.3869908, -0.0169610>,
      <-0.9219289, 0.3869913, 0.0168767>,
      <-0.9222155, 0.3863060, 0.0169195>,
      <-0.9222155, 0.3863060, 0.0169195>,
      <-0.9225202, 0.3855759, 0.0169650>,
      <-0.0002935, -0.1886445, -0.9820454>,
      <-0.0002935, -0.1886584, -0.9820427>,
      <-0.0002917, -0.1886589, -0.9820426>,
      <-0.0002917, -0.1886451, -0.9820453>,
      <-0.0002917, -0.1886313, -0.9820479>,
      <-0.0002935, -0.1886306, -0.9820481>,
      <-0.0002935, -0.1886306, -0.9820481>,
      <-0.0002953, -0.1886298, -0.9820482>,
      <-0.0002953, -0.1886438, -0.9820455>,
      <-0.0002953, -0.1886438, -0.9820455>,
      <-0.0002953, -0.1886579, -0.9820428>,
      <-0.0002935, -0.1886723, -0.9820401>,
      <-0.0002918, -0.1886727, -0.9820400>,
      <-0.0002953, -0.1886579, -0.9820428>,
      <-0.0002953, -0.1886719, -0.9820401>,
      <-0.0002953, -0.1886719, -0.9820401>,
      <-0.0002953, -0.1886859, -0.9820374>,
      <-0.0002935, -0.1886862, -0.9820374>,
      <-0.0002935, -0.1886862, -0.9820374>,
      <-0.0002918, -0.1886866, -0.9820373>,
      <-0.0002900, -0.1886732, -0.9820399>,
      <-0.0002900, -0.1886595, -0.9820425>,
      <-0.0002918, -0.1886866, -0.9820373>,
      <-0.0002900, -0.1886869, -0.9820373>,
      <-0.0002900, -0.1886869, -0.9820373>,
      <-0.0002883, -0.1886872, -0.9820372>,
      <-0.0002883, -0.1886736, -0.9820398>,
      <-0.0002883, -0.1886736, -0.9820398>,
      <-0.0002883, -0.1886600, -0.9820424>,
      <-0.0002900, -0.1886458, -0.9820452>,
      <-0.0002883, -0.1886600, -0.9820424>,
      <-0.0002883, -0.1886464, -0.9820450>,
      <-0.0002883, -0.1886464, -0.9820450>,
      <-0.0002882, -0.1886328, -0.9820476>,
      <-0.0002899, -0.1886321, -0.9820478>,
      <-0.0002899, -0.1886321, -0.9820478>,
      <-0.0002917, -0.1886313, -0.9820479>,
      <0.9661014, -0.2167873, -0.1401832>,
      <0.9718166, -0.2180697, -0.0895440>,
      <0.9723617, -0.2169285, -0.0863406>,
      <0.9670146, -0.2157356, -0.1354288>,
      <0.9594263, -0.2140427, -0.1835401>,
      <0.9580102, -0.2149716, -0.1897465>,
      <0.9580102, -0.2149716, -0.1897465>,
      <0.9564575, -0.2159518, -0.1963514>,
      <0.9651011, -0.2179033, -0.1452515>,
      <0.9651011, -0.2179033, -0.1452515>,
      <0.9712218, -0.2192853, -0.0929630>,
      <0.9750240, -0.2187894, -0.0382011>,
      <0.9753520, -0.2175956, -0.0366158>,
      <0.9712218, -0.2192853, -0.0929630>,
      <0.9746694, -0.2200637, -0.0398943>,
      <0.9746694, -0.2200637, -0.0398943>,
      <0.9753569, -0.2202189, 0.0135138>,
      <0.9756480, -0.2189295, 0.0134459>,
      <0.9756480, -0.2189295, 0.0134459>,
      <0.9759191, -0.2177221, 0.0133823>,
      <0.9756560, -0.2164748, -0.0351285>,
      <0.9728629, -0.2158551, -0.0833332>,
      <0.9759191, -0.2177221, 0.0133823>,
      <0.9761719, -0.2165893, 0.0133226>,
      <0.9761719, -0.2165893, 0.0133226>,
      <0.9764084, -0.2155243, 0.0132665>,
      <0.9759386, -0.2154206, -0.0337302>,
      <0.9759386, -0.2154206, -0.0337302>,
      <0.9733248, -0.2148436, -0.0805044>,
      <0.9678506, -0.2147430, -0.1309603>,
      <0.9733248, -0.2148436, -0.0805044>,
      <0.9686182, -0.2138047, -0.1267529>,
      <0.9686182, -0.2138047, -0.1267529>,
      <0.9619092, -0.2123238, -0.1721898>,
      <0.9607214, -0.2131612, -0.1776981>,
      <0.9607214, -0.2131612, -0.1776981>,
      <0.9594263, -0.2140427, -0.1835401>,
      <-0.9235099, 0.3835399, 0.0051572>,
      <-0.9234561, 0.3834188, 0.0147920>,
      <-0.9244676, 0.3811547, 0.0089797>,
      <-0.9244922, 0.3811912, 0.0027440>,
      <-0.9244935, 0.3811732, -0.0043209>,
      <-0.9234835, 0.3836134, -0.0043486>,
      <-0.9234835, 0.3836134, -0.0043486>,
      <-0.9220513, 0.3870427, -0.0043877>,
      <-0.9220350, 0.3870359, 0.0073996>,
      <-0.9220350, 0.3870359, 0.0073996>,
      <-0.9218750, 0.3869687, 0.0200449>,
      <-0.9233173, 0.3832368, 0.0247929>,
      <-0.9244438, 0.3810262, 0.0149251>,
      <-0.9218750, 0.3869687, 0.0200449>,
      <-0.9215384, 0.3868274, 0.0336385>,
      <-0.9215384, 0.3868274, 0.0336385>,
      <-0.9209848, 0.3865951, 0.0482830>,
      <-0.9230697, 0.3830011, 0.0353910>,
      <-0.9230697, 0.3830011, 0.0353910>,
      <-0.9243919, 0.3808631, 0.0210471>,
      <-0.9250271, 0.3798454, 0.0065090>,
      <-0.9250446, 0.3798383, 0.0039033>,
      <-0.9243919, 0.3808631, 0.0210471>,
      <-0.9250294, 0.3797881, 0.0090334>,
      <-0.9250294, 0.3797881, 0.0090334>,
      <-0.9251577, 0.3795830, 0.0001033>,
      <-0.9251789, 0.3795313, 0.0002098>,
      <-0.9252394, 0.3793838, 0.0003046>,
      <-0.9251174, 0.3796802, 0.0008127>,
      <-0.9253765, 0.3790491, 0.0004163>,
      <-0.9254663, 0.3788294, 0.0006212>,
      <-0.9252316, 0.3793785, -0.0043005>,
      <-0.9252316, 0.3793785, -0.0043005>,
      <-0.9244935, 0.3811732, -0.0043209>,
      <-0.0007457, -0.5043979, -0.8634710>,
      <-0.0007457, -0.5044253, -0.8634550>,
      <-0.0008719, -0.6072999, -0.7944722>,
      <-0.0008719, -0.6072741, -0.7944919>,
      <-0.0008718, -0.6072482, -0.7945117>,
      <-0.0007456, -0.5043705, -0.8634870>,
      <-0.0007456, -0.5043705, -0.8634870>,
      <-0.0007168, -0.4691014, -0.8831440>,
      <-0.0007168, -0.4691293, -0.8831292>,
      <-0.0007168, -0.4691293, -0.8831292>,
      <-0.0007169, -0.4691573, -0.8831143>,
      <-0.0007457, -0.5044528, -0.8634390>,
      <-0.0008719, -0.6073257, -0.7944524>,
      <-0.0007169, -0.4691573, -0.8831143>,
      <-0.0007169, -0.4691852, -0.8830995>,
      <-0.0007169, -0.4691852, -0.8830995>,
      <-0.0007170, -0.4692132, -0.8830846>,
      <-0.0007458, -0.5044802, -0.8634229>,
      <-0.0007458, -0.5044802, -0.8634229>,
      <-0.0008720, -0.6073516, -0.7944327>,
      <-0.0010636, -0.7580187, -0.6522319>,
      <-0.0010636, -0.7579999, -0.6522538>,
      <-0.0008720, -0.6073516, -0.7944327>,
      <-0.0010636, -0.7580376, -0.6522100>,
      <-0.0010636, -0.7580376, -0.6522100>,
      <-0.0012485, -0.9026257, -0.4304246>,
      <-0.0012485, -0.9026190, -0.4304385>,
      <-0.0012485, -0.9026124, -0.4304525>,
      <-0.0010636, -0.7579811, -0.6522756>,
      <-0.0012485, -0.9026057, -0.4304665>,
      <-0.0012485, -0.9025990, -0.4304804>,
      <-0.0010635, -0.7579623, -0.6522975>,
      <-0.0010635, -0.7579623, -0.6522975>,
      <-0.0008718, -0.6072482, -0.7945117>,
      <0.9770666, -0.2110995, -0.0278894>,
      <0.9772695, -0.2112852, -0.0174058>,
      <0.9779280, -0.2086917, -0.0102259>,
      <0.9778898, -0.2084890, -0.0162465>,
      <0.9778027, -0.2082977, -0.0226722>,
      <0.9767302, -0.2108828, -0.0390701>,
      <0.9767302, -0.2108828, -0.0390701>,
      <0.9751097, -0.2152376, -0.0532343>,
      <0.9757980, -0.2153896, -0.0377562>,
      <0.9757980, -0.2153896, -0.0377562>,
      <0.9762273, -0.2154843, -0.0233849>,
      <0.9773671, -0.2114205, -0.0074051>,
      <0.9779498, -0.2087971, -0.0042309>,
      <0.9762273, -0.2154843, -0.0233849>,
      <0.9764453, -0.2155324, -0.0100138>,
      <0.9764453, -0.2155324, -0.0100138>,
      <0.9764914, -0.2155426, 0.0024516>,
      <0.9773723, -0.2115127, 0.0024058>,
      <0.9773723, -0.2115127, 0.0024058>,
      <0.9779543, -0.2088056, 0.0023750>,
      <0.9782722, -0.2073230, -0.0008121>,
      <0.9782795, -0.2072628, -0.0033727>,
      <0.9779543, -0.2088056, 0.0023750>,
      <0.9782937, -0.2072099, 0.0023568>,
      <0.9782937, -0.2072099, 0.0023568>,
      <0.9784051, -0.2066871, 0.0019924>,
      <0.9784014, -0.2067044, 0.0020168>,
      <0.9783955, -0.2067321, 0.0020342>,
      <0.9782969, -0.2071232, -0.0059228>,
      <0.9783928, -0.2067447, 0.0020503>,
      <0.9783918, -0.2067494, 0.0020672>,
      <0.9783011, -0.2070102, -0.0085849>,
      <0.9783011, -0.2070102, -0.0085849>,
      <0.9778027, -0.2082977, -0.0226722>,
      <-0.9250932, 0.3797398, 0.0004487>,
      <-0.9250339, 0.3798815, -0.0015276>,
      <-0.9245895, 0.3809583, -0.0022328>,
      <-0.9246218, 0.3808864, 0.0002635>,
      <-0.9246411, 0.3808314, 0.0025007>,
      <-0.9250934, 0.3797314, 0.0025106>,
      <-0.9250934, 0.3797314, 0.0025106>,
      <-0.9254663, 0.3788294, 0.0006212>,
      <-0.9249679, 0.3800310, -0.0032856>,
      <-0.9245555, 0.3810184, -0.0046941>,
      <-0.9251577, 0.3795830, 0.0001033>,
      <-0.9249285, 0.3801096, -0.0049011>,
      <-0.9249285, 0.3801096, -0.0049011>,
      <-0.9245263, 0.3810542, -0.0069824>,
      <-0.9241027, 0.3821152, -0.0047147>,
      <-0.9241067, 0.3821286, -0.0021292>,
      <-0.9245263, 0.3810542, -0.0069824>,
      <-0.9240928, 0.3821008, -0.0071788>,
      <-0.9240928, 0.3821008, -0.0071788>,
      <-0.9237662, 0.3829278, -0.0047177>,
      <-0.9237654, 0.3829495, -0.0026888>,
      <-0.9237653, 0.3829586, -0.0006228>,
      <-0.9241427, 0.3820472, 0.0004183>,
      <-0.9238165, 0.3828327, 0.0014709>,
      <-0.9239550, 0.3824839, 0.0036442>,
      <-0.9242054, 0.3818877, 0.0024912>,
      <-0.9242054, 0.3818877, 0.0024912>,
      <-0.9246411, 0.3808314, 0.0025007>,
      <-0.0013326, -0.9679634, -0.2510877>,
      <-0.0013326, -0.9679638, -0.2510861>,
      <-0.0013541, -0.9826085, -0.1856846>,
      <-0.0013541, -0.9826091, -0.1856812>,
      <-0.0013541, -0.9826098, -0.1856777>,
      <-0.0013326, -0.9679630, -0.2510893>,
      <-0.0013326, -0.9679630, -0.2510893>,
      <-0.0012485, -0.9025990, -0.4304804>,
      <-0.0013326, -0.9679642, -0.2510846>,
      <-0.0013541, -0.9826078, -0.1856880>,
      <-0.0012485, -0.9026257, -0.4304246>,
      <-0.0013326, -0.9679647, -0.2510830>,
      <-0.0013326, -0.9679647, -0.2510830>,
      <-0.0013541, -0.9826072, -0.1856915>,
      <-0.0013476, -0.9762726, -0.2165408>,
      <-0.0013476, -0.9762728, -0.2165401>,
      <-0.0013541, -0.9826072, -0.1856915>,
      <-0.0013476, -0.9762725, -0.2165414>,
      <-0.0013476, -0.9762725, -0.2165414>,
      <-0.0012747, -0.9257454, -0.3781454>,
      <-0.0012747, -0.9257406, -0.3781570>,
      <-0.0012746, -0.9257358, -0.3781687>,
      <-0.0013476, -0.9762729, -0.2165395>,
      <-0.0012746, -0.9257311, -0.3781803>,
      <-0.0012746, -0.9257263, -0.3781919>,
      <-0.0013476, -0.9762731, -0.2165389>,
      <-0.0013476, -0.9762731, -0.2165389>,
      <-0.0013541, -0.9826098, -0.1856777>,
      <0.9782711, -0.2072356, 0.0062496>,
      <0.9782955, -0.2071600, 0.0047581>,
      <0.9780907, -0.2081105, 0.0053472>,
      <0.9780709, -0.2081464, 0.0072362>,
      <0.9780502, -0.2081738, 0.0090314>,
      <0.9782495, -0.2072896, 0.0076755>,
      <0.9782495, -0.2072896, 0.0076755>,
      <0.9783918, -0.2067494, 0.0020672>,
      <0.9783103, -0.2071195, 0.0032347>,
      <0.9781083, -0.2080671, 0.0034936>,
      <0.9784051, -0.2066871, 0.0019924>,
      <0.9783075, -0.2071498, 0.0018575>,
      <0.9783075, -0.2071498, 0.0018575>,
      <0.9781209, -0.2080291, 0.0018642>,
      <0.9779345, -0.2088914, 0.0029271>,
      <0.9779156, -0.2089563, 0.0042896>,
      <0.9781209, -0.2080291, 0.0018642>,
      <0.9779582, -0.2087923, 0.0018700>,
      <0.9779582, -0.2087923, 0.0018700>,
      <0.9779512, -0.2088315, 0.0008893>,
      <0.9779329, -0.2089181, 0.0006251>,
      <0.9778970, -0.2090868, 0.0003298>,
      <0.9779074, -0.2089607, 0.0057140>,
      <0.9778796, -0.2091688, 0.0000323>,
      <0.9778731, -0.2091988, -0.0002543>,
      <0.9778990, -0.2089576, 0.0070912>,
      <0.9778990, -0.2089576, 0.0070912>,
      <0.9780502, -0.2081738, 0.0090314>,
      <-0.9237007, 0.3830860, 0.0046989>,
      <-0.9236460, 0.3832341, 0.0031285>,
      <-0.9236124, 0.3832242, 0.0089099>,
      <-0.9236319, 0.3831706, 0.0091837>,
      <-0.9236369, 0.3831305, 0.0102895>,
      <-0.9238434, 0.3826327, 0.0102782>,
      <-0.9238434, 0.3826327, 0.0102782>,
      <-0.9239550, 0.3824839, 0.0036442>,
      <-0.9236272, 0.3832860, 0.0021421>,
      <-0.9235893, 0.3832696, 0.0093418>,
      <-0.9237662, 0.3829278, -0.0047177>,
      <-0.9236242, 0.3832973, 0.0012613>,
      <-0.9236242, 0.3832973, 0.0012613>,
      <-0.9235758, 0.3832826, 0.0101093>,
      <-0.9235618, 0.3830393, 0.0177318>,
      <-0.9236044, 0.3830475, 0.0151483>,
      <-0.9235758, 0.3832826, 0.0101093>,
      <-0.9235122, 0.3830217, 0.0204852>,
      <-0.9235122, 0.3830217, 0.0204852>,
      <-0.9235215, 0.3827058, 0.0253849>,
      <-0.9236020, 0.3827392, 0.0216801>,
      <-0.9236020, 0.3827392, 0.0216801>,
      <-0.9236707, 0.3827676, 0.0179286>,
      <-0.9236372, 0.3830552, 0.0127702>,
      <-0.9236707, 0.3827676, 0.0179286>,
      <-0.9237269, 0.3827909, 0.0141295>,
      <-0.9237269, 0.3827909, 0.0141295>,
      <-0.9237703, 0.3828089, 0.0102822>,
      <-0.9236623, 0.3830694, 0.0102881>,
      <-0.9236623, 0.3830694, 0.0102881>,
      <-0.9236369, 0.3831305, 0.0102895>,
      <-0.0010547, -0.7738077, -0.6334197>,
      <-0.0010547, -0.7738258, -0.6333976>,
      <-0.0007637, -0.5695572, -0.8219514>,
      <-0.0007636, -0.5695314, -0.8219692>,
      <-0.0007636, -0.5695056, -0.8219871>,
      <-0.0010547, -0.7737896, -0.6334418>,
      <-0.0010547, -0.7737896, -0.6334418>,
      <-0.0012746, -0.9257263, -0.3781919>,
      <-0.0010548, -0.7738439, -0.6333755>,
      <-0.0007637, -0.5695830, -0.8219335>,
      <-0.0012747, -0.9257454, -0.3781454>,
      <-0.0010548, -0.7738619, -0.6333534>,
      <-0.0010548, -0.7738619, -0.6333534>,
      <-0.0007637, -0.5696087, -0.8219156>,
      <-0.0005411, -0.4118535, -0.9112499>,
      <-0.0005410, -0.4118295, -0.9112608>,
      <-0.0007637, -0.5696087, -0.8219156>,
      <-0.0005411, -0.4118774, -0.9112391>,
      <-0.0005411, -0.4118774, -0.9112391>,
      <-0.0004576, -0.3560579, -0.9344638>,
      <-0.0004575, -0.3560362, -0.9344720>,
      <-0.0004575, -0.3560362, -0.9344720>,
      <-0.0004575, -0.3560145, -0.9344803>,
      <-0.0005410, -0.4118056, -0.9112716>,
      <-0.0004575, -0.3560145, -0.9344803>,
      <-0.0004575, -0.3559929, -0.9344886>,
      <-0.0004575, -0.3559929, -0.9344886>,
      <-0.0004575, -0.3559712, -0.9344968>,
      <-0.0005410, -0.4117816, -0.9112824>,
      <-0.0005410, -0.4117816, -0.9112824>,
      <-0.0007636, -0.5695056, -0.8219871>,
      <0.9779475, -0.2085234, -0.0116891>,
      <0.9780232, -0.2083278, -0.0083749>,
      <0.9780624, -0.2072529, -0.0209828>,
      <0.9778507, -0.2073474, -0.0285483>,
      <0.9775697, -0.2073479, -0.0369360>,
      <0.9778806, -0.2086018, -0.0153272>,
      <0.9778806, -0.2086018, -0.0153272>,
      <0.9778731, -0.2091988, -0.0002543>,
      <0.9780819, -0.2081390, -0.0058300>,
      <0.9781908, -0.2072364, -0.0139940>,
      <0.9779512, -0.2088315, 0.0008893>,
      <0.9781007, -0.2080789, -0.0047087>,
      <0.9781007, -0.2080789, -0.0047087>,
      <0.9782455, -0.2073973, -0.0046931>,
      <0.9783411, -0.2060335, -0.0199741>,
      <0.9779791, -0.2059527, -0.0337700>,
      <0.9782455, -0.2073973, -0.0046931>,
      <0.9785182, -0.2061077, -0.0046634>,
      <0.9785182, -0.2061077, -0.0046634>,
      <0.9788195, -0.2046729, -0.0046304>,
      <0.9785974, -0.2046264, -0.0217963>,
      <0.9785974, -0.2046264, -0.0217963>,
      <0.9780955, -0.2045215, -0.0387308>,
      <0.9774296, -0.2058553, -0.0474873>,
      <0.9780955, -0.2045215, -0.0387308>,
      <0.9773254, -0.2043605, -0.0554241>,
      <0.9773254, -0.2043605, -0.0554241>,
      <0.9762989, -0.2041458, -0.0718677>,
      <0.9766812, -0.2057029, -0.0614826>,
      <0.9766812, -0.2057029, -0.0614826>,
      <0.9775697, -0.2073479, -0.0369360>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, -0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.9231031, 0.3845526, 0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, -0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <-0.0012489, -0.9999992, 0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, -0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.9792500, -0.2026558, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, -0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0014080, -0.9999990, 0.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0010266, -0.9997311, -0.0231674>,
      <0.0010266, -0.9997326, -0.0231021>,
      <0.0010422, -0.9997326, -0.0231021>,
      <0.0010422, -0.9997311, -0.0231675>,
      <0.0010422, -0.9997295, -0.0232328>,
      <0.0010266, -0.9997296, -0.0232327>,
      <0.0010266, -0.9997296, -0.0232327>,
      <0.0010110, -0.9997296, -0.0232327>,
      <0.0010110, -0.9997311, -0.0231674>,
      <0.0010110, -0.9997311, -0.0231674>,
      <0.0010110, -0.9997326, -0.0231021>,
      <0.0010266, -0.9997341, -0.0230368>,
      <0.0010422, -0.9997341, -0.0230368>,
      <0.0010110, -0.9997326, -0.0231021>,
      <0.0010110, -0.9997341, -0.0230368>,
      <0.0010110, -0.9997341, -0.0230368>,
      <0.0010110, -0.9997356, -0.0229715>,
      <0.0010266, -0.9997356, -0.0229715>,
      <0.0010266, -0.9997356, -0.0229715>,
      <0.0010422, -0.9997356, -0.0229715>,
      <0.0010579, -0.9997341, -0.0230368>,
      <0.0010579, -0.9997326, -0.0231021>,
      <0.0010422, -0.9997356, -0.0229715>,
      <0.0010579, -0.9997356, -0.0229715>,
      <0.0010579, -0.9997356, -0.0229715>,
      <0.0010735, -0.9997355, -0.0229715>,
      <0.0010735, -0.9997340, -0.0230368>,
      <0.0010735, -0.9997340, -0.0230368>,
      <0.0010735, -0.9997325, -0.0231022>,
      <0.0010579, -0.9997310, -0.0231675>,
      <0.0010735, -0.9997325, -0.0231022>,
      <0.0010735, -0.9997310, -0.0231675>,
      <0.0010735, -0.9997310, -0.0231675>,
      <0.0010735, -0.9997295, -0.0232328>,
      <0.0010579, -0.9997295, -0.0232328>,
      <0.0010579, -0.9997295, -0.0232328>,
      <0.0010422, -0.9997295, -0.0232328>,
      <-0.0000372, 0.9999757, -0.0069782>,
      <-0.0003606, 0.9999756, -0.0069769>,
      <-0.0003606, 0.9999739, -0.0072146>,
      <-0.0000372, 0.9999740, -0.0072154>,
      <0.0002850, 0.9999739, -0.0072163>,
      <0.0002850, 0.9999756, -0.0069795>,
      <0.0002850, 0.9999756, -0.0069795>,
      <0.0002850, 0.9999772, -0.0067427>,
      <-0.0000372, 0.9999773, -0.0067410>,
      <-0.0000372, 0.9999773, -0.0067410>,
      <-0.0003606, 0.9999772, -0.0067392>,
      <-0.0006853, 0.9999754, -0.0069756>,
      <-0.0006853, 0.9999737, -0.0072137>,
      <-0.0003606, 0.9999772, -0.0067392>,
      <-0.0006853, 0.9999771, -0.0067374>,
      <-0.0006853, 0.9999771, -0.0067374>,
      <-0.0010112, 0.9999768, -0.0067356>,
      <-0.0010112, 0.9999752, -0.0069743>,
      <-0.0010112, 0.9999752, -0.0069743>,
      <-0.0010112, 0.9999735, -0.0072129>,
      <-0.0006853, 0.9999720, -0.0074519>,
      <-0.0003606, 0.9999722, -0.0074523>,
      <-0.0010112, 0.9999735, -0.0072129>,
      <-0.0010112, 0.9999717, -0.0074515>,
      <-0.0010112, 0.9999717, -0.0074515>,
      <-0.0010112, 0.9999699, -0.0076901>,
      <-0.0006853, 0.9999702, -0.0076900>,
      <-0.0006853, 0.9999702, -0.0076900>,
      <-0.0003606, 0.9999704, -0.0076900>,
      <-0.0000372, 0.9999722, -0.0074527>,
      <-0.0003606, 0.9999704, -0.0076900>,
      <-0.0000372, 0.9999704, -0.0076899>,
      <-0.0000372, 0.9999704, -0.0076899>,
      <0.0002850, 0.9999704, -0.0076898>,
      <0.0002850, 0.9999722, -0.0074530>,
      <0.0002850, 0.9999722, -0.0074530>,
      <0.0002850, 0.9999739, -0.0072163>,
      <-0.0002859, -0.9999353, 0.0113685>,
      <-0.0002859, -0.9999353, 0.0113691>,
      <-0.0002856, -0.9999353, 0.0113691>,
      <-0.0002856, -0.9999353, 0.0113685>,
      <-0.0002856, -0.9999353, 0.0113679>,
      <-0.0002859, -0.9999353, 0.0113679>,
      <-0.0002859, -0.9999353, 0.0113679>,
      <-0.0002862, -0.9999353, 0.0113679>,
      <-0.0002862, -0.9999353, 0.0113685>,
      <-0.0002862, -0.9999353, 0.0113685>,
      <-0.0002862, -0.9999353, 0.0113691>,
      <-0.0002859, -0.9999353, 0.0113697>,
      <-0.0002856, -0.9999353, 0.0113697>,
      <-0.0002862, -0.9999353, 0.0113691>,
      <-0.0002862, -0.9999353, 0.0113697>,
      <-0.0002862, -0.9999353, 0.0113697>,
      <-0.0002862, -0.9999353, 0.0113703>,
      <-0.0002859, -0.9999353, 0.0113703>,
      <-0.0002859, -0.9999353, 0.0113703>,
      <-0.0002856, -0.9999353, 0.0113703>,
      <-0.0002853, -0.9999353, 0.0113697>,
      <-0.0002853, -0.9999353, 0.0113691>,
      <-0.0002856, -0.9999353, 0.0113703>,
      <-0.0002853, -0.9999353, 0.0113703>,
      <-0.0002853, -0.9999353, 0.0113703>,
      <-0.0002850, -0.9999353, 0.0113703>,
      <-0.0002850, -0.9999353, 0.0113697>,
      <-0.0002850, -0.9999353, 0.0113697>,
      <-0.0002850, -0.9999353, 0.0113691>,
      <-0.0002853, -0.9999353, 0.0113685>,
      <-0.0002850, -0.9999353, 0.0113691>,
      <-0.0002850, -0.9999353, 0.0113685>,
      <-0.0002850, -0.9999353, 0.0113685>,
      <-0.0002850, -0.9999353, 0.0113679>,
      <-0.0002853, -0.9999353, 0.0113679>,
      <-0.0002853, -0.9999353, 0.0113679>,
      <-0.0002856, -0.9999353, 0.0113679>,
      <0.0004278, 0.9988405, -0.0481401>,
      <0.0003805, 0.9988406, -0.0481388>,
      <0.0003805, 0.9987608, -0.0497668>,
      <0.0004278, 0.9987607, -0.0497677>,
      <0.0004750, 0.9987607, -0.0497685>,
      <0.0004751, 0.9988404, -0.0481414>,
      <0.0004751, 0.9988404, -0.0481414>,
      <0.0004751, 0.9989175, -0.0465139>,
      <0.0004279, 0.9989176, -0.0465121>,
      <0.0004279, 0.9989176, -0.0465121>,
      <0.0003806, 0.9989177, -0.0465103>,
      <0.0003332, 0.9988407, -0.0481374>,
      <0.0003332, 0.9987609, -0.0497660>,
      <0.0003806, 0.9989177, -0.0465103>,
      <0.0003332, 0.9989178, -0.0465085>,
      <0.0003332, 0.9989178, -0.0465085>,
      <0.0002859, 0.9989179, -0.0465067>,
      <0.0002859, 0.9988407, -0.0481361>,
      <0.0002859, 0.9988407, -0.0481361>,
      <0.0002859, 0.9987609, -0.0497651>,
      <0.0003332, 0.9986784, -0.0513941>,
      <0.0003805, 0.9986784, -0.0513945>,
      <0.0002859, 0.9987609, -0.0497651>,
      <0.0002858, 0.9986784, -0.0513937>,
      <0.0002858, 0.9986784, -0.0513937>,
      <0.0002858, 0.9985933, -0.0530219>,
      <0.0003331, 0.9985933, -0.0530218>,
      <0.0003331, 0.9985933, -0.0530218>,
      <0.0003804, 0.9985933, -0.0530217>,
      <0.0004278, 0.9986783, -0.0513949>,
      <0.0003804, 0.9985933, -0.0530217>,
      <0.0004277, 0.9985933, -0.0530216>,
      <0.0004277, 0.9985933, -0.0530216>,
      <0.0004750, 0.9985933, -0.0530216>,
      <0.0004750, 0.9986783, -0.0513952>,
      <0.0004750, 0.9986783, -0.0513952>,
      <0.0004750, 0.9987607, -0.0497685>,
      <-0.0005966, -0.9999458, 0.0103950>,
      <-0.0007659, -0.9999455, 0.0104122>,
      <-0.0006729, -0.9999349, 0.0113894>,
      <-0.0006288, -0.9999379, 0.0111264>,
      <-0.0006134, -0.9999387, 0.0110567>,
      <-0.0005465, -0.9999387, 0.0110561>,
      <-0.0005465, -0.9999387, 0.0110561>,
      <-0.0000708, -0.9999765, 0.0068507>,
      <-0.0003602, -0.9999748, 0.0070928>,
      <-0.0008263, -0.9999728, 0.0073345>,
      <-0.0009252, -0.9999367, 0.0112159>,
      <-0.0007111, -0.9999284, 0.0119437>,
      <-0.0013129, -0.9999704, 0.0075748>,
      <-0.0015952, -0.9999682, 0.0078139>,
      <-0.0009492, -0.9999201, 0.0126058>,
      <-0.0009492, -0.9999201, 0.0126058>,
      <-0.0007174, -0.9999203, 0.0126059>,
      <-0.0005789, -0.9999260, 0.0121526>,
      <-0.0005743, -0.9999311, 0.0117270>,
      <-0.0007174, -0.9999203, 0.0126059>,
      <-0.0005799, -0.9999204, 0.0126060>,
      <-0.0005799, -0.9999204, 0.0126060>,
      <-0.0004756, -0.9999204, 0.0126060>,
      <-0.0004756, -0.9999252, 0.0122184>,
      <-0.0004756, -0.9999252, 0.0122184>,
      <-0.0004756, -0.9999299, 0.0118308>,
      <-0.0005690, -0.9999352, 0.0113674>,
      <-0.0004756, -0.9999299, 0.0118308>,
      <-0.0004756, -0.9999344, 0.0114431>,
      <-0.0004756, -0.9999344, 0.0114431>,
      <-0.0004756, -0.9999388, 0.0110554>,
      <-0.0005669, -0.9999387, 0.0110563>,
      <-0.0005669, -0.9999387, 0.0110563>,
      <-0.0006134, -0.9999387, 0.0110567>,
      <-0.0002952, -0.9999920, -0.0039873>,
      <-0.0005389, -0.9998053, -0.0197268>,
      <-0.0008059, -0.9998839, -0.0152192>,
      <-0.0008325, -0.9999993, -0.0008188>,
      <-0.0000708, -0.9999765, 0.0068507>,
      <0.0012757, -0.9992166, -0.0395555>,
      <0.0012757, -0.9992166, -0.0395555>,
      <-0.0002580, -0.9992154, -0.0396049>,
      <-0.0007277, -0.9994324, -0.0336807>,
      <-0.0007737, -0.9994852, -0.0320734>,
      <-0.0002580, -0.9992154, -0.0396049>,
      <-0.0007050, -0.9992146, -0.0396193>,
      <-0.0007050, -0.9992146, -0.0396193>,
      <-0.0007416, -0.9992145, -0.0396204>,
      <-0.0007416, -0.9991587, -0.0410051>,
      <-0.0007416, -0.9991587, -0.0410051>,
      <-0.0007415, -0.9991009, -0.0423895>,
      <-0.0008218, -0.9993477, -0.0361033>,
      <-0.0010856, -0.9997685, -0.0214899>,
      <-0.0007415, -0.9991009, -0.0423895>,
      <-0.0007415, -0.9990412, -0.0437736>,
      <-0.0007415, -0.9990412, -0.0437736>,
      <-0.0007415, -0.9989796, -0.0451575>,
      <-0.0008484, -0.9989795, -0.0451573>,
      <-0.0008484, -0.9989795, -0.0451573>,
      <-0.0014061, -0.9989789, -0.0451564>,
      <-0.0013977, -0.9999882, -0.0046499>,
      <-0.0014061, -0.9989789, -0.0451564>,
      <-0.0031706, -0.9989750, -0.0451534>,
      <-0.0031706, -0.9989750, -0.0451534>,
      <-0.0015952, -0.9999682, 0.0078139>
    }
    uv_vectors {
      1469,
      <0.3461295, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.2826137, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.2823938, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.2826137, 0.1538766>,
      <0.3461295, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.5000062, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.6538828, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.7173863, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.7176062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.6537273, 0.1538766>,
      <0.7173863, 0.1538766>,
      <0.6538828, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.5000062, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.3477037, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.3461295, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.2826137, 0.1538766>,
      <0.3240764, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.5000062, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.2826137, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.3756038, 0.9329566>,
      <0.3240764, 0.9329566>,
      <0.7173863, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.5000059, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.5000062, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.6244079, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.6537273, 0.1538766>,
      <0.7173863, 0.1538766>,
      <0.6759253, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3240764, 0.9329566>,
      <0.3214772, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.6244079, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.3240764, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3737658, 0.9324092>,
      <0.3214772, 0.9324092>,
      <0.6759253, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3214772, 0.9324092>,
      <0.3213383, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.3214772, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3736676, 0.9388315>,
      <0.3213383, 0.9388315>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3213383, 0.9388315>,
      <0.3176078, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.3213383, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3710297, 0.9395004>,
      <0.3176078, 0.9395004>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3176078, 0.9395004>,
      <0.3175836, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.3176078, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3710126, 0.9657316>,
      <0.3175836, 0.9657316>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3175836, 0.9657316>,
      <0.2922845, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.3175836, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3531234, 0.9671308>,
      <0.2922845, 0.9671308>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.2922845, 0.9671308>,
      <0.2910740, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.2922845, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3522674, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.2846200, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.2846200, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3477037, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.4373453, 0.9326829>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.4378048, 0.9329566>,
      <0.5000059, 0.9326829>,
      <0.4368858, 0.9324092>,
      <0.3746848, 0.9326829>,
      <0.5626664, 0.9326829>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5622069, 0.9329566>,
      <0.6253269, 0.9326829>,
      <0.5631259, 0.9324092>,
      <0.5000059, 0.9326829>,
      <0.6512759, 0.9326829>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6501666, 0.9329566>,
      <0.6772249, 0.9326829>,
      <0.6523852, 0.9324092>,
      <0.6253269, 0.9326829>,
      <0.4368613, 0.9356203>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.4368858, 0.9324092>,
      <0.5000059, 0.9356203>,
      <0.4368368, 0.9388315>,
      <0.3737167, 0.9356203>,
      <0.5631505, 0.9356203>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5631259, 0.9324092>,
      <0.6262950, 0.9356203>,
      <0.5631750, 0.9388315>,
      <0.5000059, 0.9356203>,
      <0.6524445, 0.9356203>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6523852, 0.9324092>,
      <0.6785939, 0.9356203>,
      <0.6525037, 0.9388315>,
      <0.6262950, 0.9356203>,
      <0.4361773, 0.9391659>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.4368368, 0.9388315>,
      <0.5000059, 0.9391659>,
      <0.4355178, 0.9395004>,
      <0.3723487, 0.9391659>,
      <0.5638345, 0.9391659>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5631750, 0.9388315>,
      <0.6276631, 0.9391659>,
      <0.5644940, 0.9395004>,
      <0.5000059, 0.9391659>,
      <0.6540958, 0.9391659>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6525037, 0.9388315>,
      <0.6805285, 0.9391659>,
      <0.6556879, 0.9395004>,
      <0.6276631, 0.9391659>,
      <0.4355135, 0.9526160>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.4355178, 0.9395004>,
      <0.5000059, 0.9523886>,
      <0.4354599, 0.9657316>,
      <0.3710212, 0.9526160>,
      <0.5644983, 0.9526160>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5644940, 0.9395004>,
      <0.6289906, 0.9524938>,
      <0.5645025, 0.9657316>,
      <0.5000059, 0.9523886>,
      <0.6556982, 0.9526160>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6556879, 0.9395004>,
      <0.6824058, 0.9526160>,
      <0.6557342, 0.9657316>,
      <0.6289906, 0.9524938>,
      <0.4310370, 0.9664312>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.4354599, 0.9657316>,
      <0.5000060, 0.9664126>,
      <0.4262372, 0.9671308>,
      <0.3620680, 0.9664312>,
      <0.5689750, 0.9664312>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5645025, 0.9657316>,
      <0.6377087, 0.9664128>,
      <0.5734474, 0.9671308>,
      <0.5000060, 0.9664126>,
      <0.6665054, 0.9664312>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6557342, 0.9657316>,
      <0.6950669, 0.9664312>,
      <0.6774510, 0.9671308>,
      <0.6377087, 0.9664128>,
      <0.4263507, 0.9777601>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.4262372, 0.9671308>,
      <0.5000061, 0.9775824>,
      <0.4261367, 0.9883895>,
      <0.3526954, 0.9777601>,
      <0.5736614, 0.9777601>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5734474, 0.9671308>,
      <0.6473045, 0.9774559>,
      <0.5738754, 0.9883895>,
      <0.5000061, 0.9775824>,
      <0.6778190, 0.9777601>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6774510, 0.9671308>,
      <0.7083211, 0.9777601>,
      <0.6783356, 0.9883895>,
      <0.6473045, 0.9774559>,
      <0.4249958, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.4238549, 0.9941947>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.4238549, 0.9883895>,
      <0.5000061, 0.9941947>,
      <0.4238549, 1.0000000>,
      <0.3477037, 0.9941947>,
      <0.5761574, 0.9941947>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5761574, 0.9883895>,
      <0.6523086, 0.9941947>,
      <0.5761574, 1.0000000>,
      <0.5000061, 0.9941947>,
      <0.6838443, 0.9941947>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6838443, 0.9883895>,
      <0.7153801, 0.9941947>,
      <0.6838443, 1.0000000>,
      <0.6523086, 0.9941947>,
      <0.4642375, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5426958, 1.0000000>,
      <0.4396228, 1.0000000>,
      <0.3857793, 1.0000000>,
      <0.4888523, 1.0000000>,
      <0.5134670, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.4888523, 1.0000000>,
      <0.4619305, 1.0000000>,
      <0.5380817, 1.0000000>,
      <0.5650035, 1.0000000>,
      <0.6165400, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.5650035, 1.0000000>,
      <0.6142330, 1.0000000>,
      <0.6680764, 1.0000000>,
      <0.6188470, 1.0000000>,
      <0.6211540, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.6188470, 1.0000000>,
      <0.6996122, 1.0000000>,
      <0.6234610, 1.0000000>,
      <0.5426958, 1.0000000>,
      <0.4063597, 0.9328198>,
      <0.4373453, 0.9326829>,
      <0.3746848, 0.9326829>,
      <0.3756038, 0.9329566>,
      <0.4378048, 0.9329566>,
      <0.4060151, 0.9326829>,
      <0.3751443, 0.9328198>,
      <0.4067043, 0.9329566>,
      <0.4375751, 0.9328198>,
      <0.4687905, 0.9328198>,
      <0.4373453, 0.9326829>,
      <0.4378048, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9326829>,
      <0.4375751, 0.9328198>,
      <0.4689053, 0.9329566>,
      <0.5000059, 0.9328198>,
      <0.4686756, 0.9326829>,
      <0.4685607, 0.9325460>,
      <0.4373453, 0.9326829>,
      <0.5000059, 0.9326829>,
      <0.5000059, 0.9324092>,
      <0.4368858, 0.9324092>,
      <0.4686756, 0.9326829>,
      <0.5000059, 0.9325460>,
      <0.4684459, 0.9324092>,
      <0.4371156, 0.9325460>,
      <0.4056704, 0.9325460>,
      <0.4373453, 0.9326829>,
      <0.4368858, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3746848, 0.9326829>,
      <0.4371156, 0.9325460>,
      <0.4053258, 0.9324092>,
      <0.3742253, 0.9325460>,
      <0.4060151, 0.9326829>,
      <0.5312213, 0.9328198>,
      <0.5626664, 0.9326829>,
      <0.5000059, 0.9326829>,
      <0.5000059, 0.9329566>,
      <0.5622069, 0.9329566>,
      <0.5313361, 0.9326829>,
      <0.5000059, 0.9328198>,
      <0.5311064, 0.9329566>,
      <0.5624367, 0.9328198>,
      <0.5936520, 0.9328198>,
      <0.5626664, 0.9326829>,
      <0.5622069, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6253269, 0.9326829>,
      <0.5624367, 0.9328198>,
      <0.5933074, 0.9329566>,
      <0.6248674, 0.9328198>,
      <0.5939967, 0.9326829>,
      <0.5943413, 0.9325460>,
      <0.5626664, 0.9326829>,
      <0.6253269, 0.9326829>,
      <0.6262459, 0.9324092>,
      <0.5631259, 0.9324092>,
      <0.5939967, 0.9326829>,
      <0.6257864, 0.9325460>,
      <0.5946859, 0.9324092>,
      <0.5628962, 0.9325460>,
      <0.5314510, 0.9325460>,
      <0.5626664, 0.9326829>,
      <0.5631259, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9326829>,
      <0.5628962, 0.9325460>,
      <0.5315659, 0.9324092>,
      <0.5000059, 0.9325460>,
      <0.5313361, 0.9326829>,
      <0.6377944, 0.9328198>,
      <0.6512759, 0.9326829>,
      <0.6253269, 0.9326829>,
      <0.6244079, 0.9329566>,
      <0.6501666, 0.9329566>,
      <0.6383014, 0.9326829>,
      <0.6248674, 0.9328198>,
      <0.6372873, 0.9329566>,
      <0.6507213, 0.9328198>,
      <0.6636482, 0.9328198>,
      <0.6512759, 0.9326829>,
      <0.6501666, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6772249, 0.9326829>,
      <0.6507213, 0.9328198>,
      <0.6630460, 0.9329566>,
      <0.6765751, 0.9328198>,
      <0.6642504, 0.9326829>,
      <0.6648526, 0.9325460>,
      <0.6512759, 0.9326829>,
      <0.6772249, 0.9326829>,
      <0.6785245, 0.9324092>,
      <0.6523852, 0.9324092>,
      <0.6642504, 0.9326829>,
      <0.6778747, 0.9325460>,
      <0.6654549, 0.9324092>,
      <0.6518306, 0.9325460>,
      <0.6388085, 0.9325460>,
      <0.6512759, 0.9326829>,
      <0.6523852, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6253269, 0.9326829>,
      <0.6518306, 0.9325460>,
      <0.6393156, 0.9324092>,
      <0.6257864, 0.9325460>,
      <0.6383014, 0.9326829>,
      <0.4053074, 0.9340147>,
      <0.4368613, 0.9356203>,
      <0.3737167, 0.9356203>,
      <0.3737658, 0.9324092>,
      <0.4368858, 0.9324092>,
      <0.4052890, 0.9356203>,
      <0.3737413, 0.9340147>,
      <0.4053258, 0.9324092>,
      <0.4368736, 0.9340147>,
      <0.4684397, 0.9340147>,
      <0.4368613, 0.9356203>,
      <0.4368858, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9356203>,
      <0.4368736, 0.9340147>,
      <0.4684459, 0.9324092>,
      <0.5000059, 0.9340147>,
      <0.4684336, 0.9356203>,
      <0.4684275, 0.9372259>,
      <0.4368613, 0.9356203>,
      <0.5000059, 0.9356203>,
      <0.5000059, 0.9388315>,
      <0.4368368, 0.9388315>,
      <0.4684336, 0.9356203>,
      <0.5000059, 0.9372259>,
      <0.4684213, 0.9388315>,
      <0.4368490, 0.9372259>,
      <0.4052706, 0.9372259>,
      <0.4368613, 0.9356203>,
      <0.4368368, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3737167, 0.9356203>,
      <0.4368490, 0.9372259>,
      <0.4052522, 0.9388315>,
      <0.3736922, 0.9372259>,
      <0.4052890, 0.9356203>,
      <0.5315720, 0.9340147>,
      <0.5631505, 0.9356203>,
      <0.5000059, 0.9356203>,
      <0.5000059, 0.9324092>,
      <0.5631259, 0.9324092>,
      <0.5315782, 0.9356203>,
      <0.5000059, 0.9340147>,
      <0.5315659, 0.9324092>,
      <0.5631382, 0.9340147>,
      <0.5947043, 0.9340147>,
      <0.5631505, 0.9356203>,
      <0.5631259, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6262950, 0.9356203>,
      <0.5631382, 0.9340147>,
      <0.5946859, 0.9324092>,
      <0.6262705, 0.9340147>,
      <0.5947227, 0.9356203>,
      <0.5947412, 0.9372259>,
      <0.5631505, 0.9356203>,
      <0.6262950, 0.9356203>,
      <0.6263441, 0.9388315>,
      <0.5631750, 0.9388315>,
      <0.5947227, 0.9356203>,
      <0.6263196, 0.9372259>,
      <0.5947596, 0.9388315>,
      <0.5631627, 0.9372259>,
      <0.5315843, 0.9372259>,
      <0.5631505, 0.9356203>,
      <0.5631750, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9356203>,
      <0.5631627, 0.9372259>,
      <0.5315904, 0.9388315>,
      <0.5000059, 0.9372259>,
      <0.5315782, 0.9356203>,
      <0.6393427, 0.9340147>,
      <0.6524445, 0.9356203>,
      <0.6262950, 0.9356203>,
      <0.6262459, 0.9324092>,
      <0.6523852, 0.9324092>,
      <0.6393698, 0.9356203>,
      <0.6262705, 0.9340147>,
      <0.6393156, 0.9324092>,
      <0.6524148, 0.9340147>,
      <0.6654870, 0.9340147>,
      <0.6524445, 0.9356203>,
      <0.6523852, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6785939, 0.9356203>,
      <0.6524148, 0.9340147>,
      <0.6654549, 0.9324092>,
      <0.6785592, 0.9340147>,
      <0.6655192, 0.9356203>,
      <0.6655513, 0.9372259>,
      <0.6524445, 0.9356203>,
      <0.6785939, 0.9356203>,
      <0.6786633, 0.9388315>,
      <0.6525037, 0.9388315>,
      <0.6655192, 0.9356203>,
      <0.6786286, 0.9372259>,
      <0.6655835, 0.9388315>,
      <0.6524741, 0.9372259>,
      <0.6393968, 0.9372259>,
      <0.6524445, 0.9356203>,
      <0.6525037, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6262950, 0.9356203>,
      <0.6524741, 0.9372259>,
      <0.6394239, 0.9388315>,
      <0.6263196, 0.9372259>,
      <0.6393698, 0.9356203>,
      <0.4047576, 0.9389987>,
      <0.4361773, 0.9391659>,
      <0.3723487, 0.9391659>,
      <0.3736676, 0.9388315>,
      <0.4368368, 0.9388315>,
      <0.4042630, 0.9391659>,
      <0.3730082, 0.9389987>,
      <0.4052522, 0.9388315>,
      <0.4365070, 0.9389987>,
      <0.4682565, 0.9389987>,
      <0.4361773, 0.9391659>,
      <0.4368368, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9391659>,
      <0.4365070, 0.9389987>,
      <0.4684213, 0.9388315>,
      <0.5000059, 0.9389987>,
      <0.4680916, 0.9391659>,
      <0.4679267, 0.9393332>,
      <0.4361773, 0.9391659>,
      <0.5000059, 0.9391659>,
      <0.5000059, 0.9395004>,
      <0.4355178, 0.9395004>,
      <0.4680916, 0.9391659>,
      <0.5000059, 0.9393332>,
      <0.4677619, 0.9395004>,
      <0.4358475, 0.9393332>,
      <0.4037684, 0.9393332>,
      <0.4361773, 0.9391659>,
      <0.4355178, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3723487, 0.9391659>,
      <0.4358475, 0.9393332>,
      <0.4032738, 0.9395004>,
      <0.3716892, 0.9393332>,
      <0.4042630, 0.9391659>,
      <0.5317553, 0.9389987>,
      <0.5638345, 0.9391659>,
      <0.5000059, 0.9391659>,
      <0.5000059, 0.9388315>,
      <0.5631750, 0.9388315>,
      <0.5319202, 0.9391659>,
      <0.5000059, 0.9389987>,
      <0.5315904, 0.9388315>,
      <0.5635047, 0.9389987>,
      <0.5952542, 0.9389987>,
      <0.5638345, 0.9391659>,
      <0.5631750, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6276631, 0.9391659>,
      <0.5635047, 0.9389987>,
      <0.5947596, 0.9388315>,
      <0.6270036, 0.9389987>,
      <0.5957488, 0.9391659>,
      <0.5962434, 0.9393332>,
      <0.5638345, 0.9391659>,
      <0.6276631, 0.9391659>,
      <0.6289821, 0.9395004>,
      <0.5644940, 0.9395004>,
      <0.5957488, 0.9391659>,
      <0.6283226, 0.9393332>,
      <0.5967380, 0.9395004>,
      <0.5641643, 0.9393332>,
      <0.5320851, 0.9393332>,
      <0.5638345, 0.9391659>,
      <0.5644940, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9391659>,
      <0.5641643, 0.9393332>,
      <0.5322500, 0.9395004>,
      <0.5000059, 0.9393332>,
      <0.5319202, 0.9391659>,
      <0.6401517, 0.9389987>,
      <0.6540958, 0.9391659>,
      <0.6276631, 0.9391659>,
      <0.6263441, 0.9388315>,
      <0.6525037, 0.9388315>,
      <0.6408795, 0.9391659>,
      <0.6270036, 0.9389987>,
      <0.6394239, 0.9388315>,
      <0.6532998, 0.9389987>,
      <0.6664478, 0.9389987>,
      <0.6540958, 0.9391659>,
      <0.6525037, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6805285, 0.9391659>,
      <0.6532998, 0.9389987>,
      <0.6655835, 0.9388315>,
      <0.6795959, 0.9389987>,
      <0.6673122, 0.9391659>,
      <0.6681765, 0.9393332>,
      <0.6540958, 0.9391659>,
      <0.6805285, 0.9391659>,
      <0.6823937, 0.9395004>,
      <0.6556879, 0.9395004>,
      <0.6673122, 0.9391659>,
      <0.6814611, 0.9393332>,
      <0.6690408, 0.9395004>,
      <0.6548919, 0.9393332>,
      <0.6416072, 0.9393332>,
      <0.6540958, 0.9391659>,
      <0.6556879, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6276631, 0.9391659>,
      <0.6548919, 0.9393332>,
      <0.6423350, 0.9395004>,
      <0.6283226, 0.9393332>,
      <0.6408795, 0.9391659>,
      <0.4032706, 0.9460582>,
      <0.4355135, 0.9526160>,
      <0.3710212, 0.9526160>,
      <0.3710297, 0.9395004>,
      <0.4355178, 0.9395004>,
      <0.4032681, 0.9526160>,
      <0.3710254, 0.9460582>,
      <0.4032738, 0.9395004>,
      <0.4355156, 0.9461557>,
      <0.4677608, 0.9460014>,
      <0.4355135, 0.9526160>,
      <0.4355178, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9523886>,
      <0.4355156, 0.9461557>,
      <0.4677619, 0.9395004>,
      <0.5000059, 0.9458859>,
      <0.4677611, 0.9525023>,
      <0.4677463, 0.9591169>,
      <0.4355135, 0.9526160>,
      <0.5000059, 0.9523886>,
      <0.5000059, 0.9657316>,
      <0.4354599, 0.9657316>,
      <0.4677611, 0.9525023>,
      <0.5000059, 0.9591382>,
      <0.4677391, 0.9657316>,
      <0.4354846, 0.9596857>,
      <0.4032518, 0.9591738>,
      <0.4355135, 0.9526160>,
      <0.4354599, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3710212, 0.9526160>,
      <0.4354846, 0.9596857>,
      <0.4030857, 0.9657316>,
      <0.3710169, 0.9591738>,
      <0.4032681, 0.9526160>,
      <0.5322510, 0.9460014>,
      <0.5644983, 0.9526160>,
      <0.5000059, 0.9523886>,
      <0.5000059, 0.9395004>,
      <0.5644940, 0.9395004>,
      <0.5322521, 0.9525023>,
      <0.5000059, 0.9458859>,
      <0.5322500, 0.9395004>,
      <0.5644961, 0.9460052>,
      <0.5967412, 0.9460277>,
      <0.5644983, 0.9526160>,
      <0.5644940, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289906, 0.9524938>,
      <0.5644961, 0.9460052>,
      <0.5967380, 0.9395004>,
      <0.6289863, 0.9459494>,
      <0.5967444, 0.9525549>,
      <0.5967476, 0.9591432>,
      <0.5644983, 0.9526160>,
      <0.6289906, 0.9524938>,
      <0.6289992, 0.9657316>,
      <0.5645025, 0.9657316>,
      <0.5967444, 0.9525549>,
      <0.6289950, 0.9592322>,
      <0.5967509, 0.9657316>,
      <0.5645004, 0.9592746>,
      <0.5322532, 0.9591169>,
      <0.5644983, 0.9526160>,
      <0.5645025, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000059, 0.9523886>,
      <0.5645004, 0.9592746>,
      <0.5322542, 0.9657316>,
      <0.5000059, 0.9591382>,
      <0.5322521, 0.9525023>,
      <0.6423397, 0.9460277>,
      <0.6556982, 0.9526160>,
      <0.6289906, 0.9524938>,
      <0.6289821, 0.9395004>,
      <0.6556879, 0.9395004>,
      <0.6423438, 0.9525549>,
      <0.6289863, 0.9459494>,
      <0.6423350, 0.9395004>,
      <0.6556931, 0.9461692>,
      <0.6690464, 0.9460582>,
      <0.6556982, 0.9526160>,
      <0.6556879, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824058, 0.9526160>,
      <0.6556931, 0.9461692>,
      <0.6690408, 0.9395004>,
      <0.6823998, 0.9460582>,
      <0.6690517, 0.9526160>,
      <0.6690640, 0.9591738>,
      <0.6556982, 0.9526160>,
      <0.6824058, 0.9526160>,
      <0.6824179, 0.9657316>,
      <0.6557342, 0.9657316>,
      <0.6690517, 0.9526160>,
      <0.6824118, 0.9591738>,
      <0.6691473, 0.9657316>,
      <0.6557177, 0.9597098>,
      <0.6423555, 0.9591432>,
      <0.6556982, 0.9526160>,
      <0.6557342, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6289906, 0.9524938>,
      <0.6557177, 0.9597098>,
      <0.6423641, 0.9657316>,
      <0.6289950, 0.9592322>,
      <0.6423438, 0.9525549>,
      <0.3998944, 0.9660814>,
      <0.4310370, 0.9664312>,
      <0.3620680, 0.9664312>,
      <0.3710126, 0.9657316>,
      <0.4354599, 0.9657316>,
      <0.3965516, 0.9664312>,
      <0.3665403, 0.9660814>,
      <0.4030857, 0.9657316>,
      <0.4331477, 0.9660973>,
      <0.4666272, 0.9660767>,
      <0.4310370, 0.9664312>,
      <0.4354599, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000060, 0.9664126>,
      <0.4331477, 0.9660973>,
      <0.4677391, 0.9657316>,
      <0.5000060, 0.9660825>,
      <0.4655206, 0.9664219>,
      <0.4643216, 0.9667763>,
      <0.4310370, 0.9664312>,
      <0.5000060, 0.9664126>,
      <0.5000061, 0.9671308>,
      <0.4262372, 0.9671308>,
      <0.4655206, 0.9664219>,
      <0.5000060, 0.9667486>,
      <0.4631092, 0.9671308>,
      <0.4288267, 0.9667534>,
      <0.3931164, 0.9667810>,
      <0.4310370, 0.9664312>,
      <0.4262372, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3620680, 0.9664312>,
      <0.4288267, 0.9667534>,
      <0.3893088, 0.9671308>,
      <0.3575957, 0.9667810>,
      <0.3965516, 0.9664312>,
      <0.5333724, 0.9660767>,
      <0.5689750, 0.9664312>,
      <0.5000060, 0.9664126>,
      <0.5000059, 0.9657316>,
      <0.5645025, 0.9657316>,
      <0.5344905, 0.9664219>,
      <0.5000060, 0.9660825>,
      <0.5322542, 0.9657316>,
      <0.5668093, 0.9660924>,
      <0.6000463, 0.9660768>,
      <0.5689750, 0.9664312>,
      <0.5645025, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6377087, 0.9664128>,
      <0.5668093, 0.9660924>,
      <0.5967509, 0.9657316>,
      <0.6334945, 0.9660832>,
      <0.6033418, 0.9664220>,
      <0.6067550, 0.9667764>,
      <0.5689750, 0.9664312>,
      <0.6377087, 0.9664128>,
      <0.6468888, 0.9671308>,
      <0.5734474, 0.9671308>,
      <0.6033418, 0.9664220>,
      <0.6419978, 0.9667483>,
      <0.6101681, 0.9671308>,
      <0.5710658, 0.9667583>,
      <0.5356086, 0.9667763>,
      <0.5689750, 0.9664312>,
      <0.5734474, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000060, 0.9664126>,
      <0.5710658, 0.9667583>,
      <0.5367268, 0.9671308>,
      <0.5000060, 0.9667486>,
      <0.5344905, 0.9664219>,
      <0.6472369, 0.9660768>,
      <0.6665054, 0.9664312>,
      <0.6377087, 0.9664128>,
      <0.6289992, 0.9657316>,
      <0.6557342, 0.9657316>,
      <0.6521075, 0.9664220>,
      <0.6334945, 0.9660832>,
      <0.6423641, 0.9657316>,
      <0.6613677, 0.9660975>,
      <0.6749311, 0.9660814>,
      <0.6665054, 0.9664312>,
      <0.6557342, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.6950669, 0.9664312>,
      <0.6613677, 0.9660975>,
      <0.6691473, 0.9657316>,
      <0.6887424, 0.9660814>,
      <0.6807866, 0.9664312>,
      <0.6866848, 0.9667810>,
      <0.6665054, 0.9664312>,
      <0.6950669, 0.9664312>,
      <0.7077159, 0.9671308>,
      <0.6774510, 0.9671308>,
      <0.6807866, 0.9664312>,
      <0.7013914, 0.9667810>,
      <0.6927532, 0.9671308>,
      <0.6715439, 0.9667532>,
      <0.6571385, 0.9667764>,
      <0.6665054, 0.9664312>,
      <0.6774510, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6377087, 0.9664128>,
      <0.6715439, 0.9667532>,
      <0.6621754, 0.9671308>,
      <0.6419978, 0.9667483>,
      <0.6521075, 0.9664220>,
      <0.3896017, 0.9724455>,
      <0.4263507, 0.9777601>,
      <0.3526954, 0.9777601>,
      <0.3531234, 0.9671308>,
      <0.4262372, 0.9671308>,
      <0.3895214, 0.9777601>,
      <0.3529094, 0.9724455>,
      <0.3893088, 0.9671308>,
      <0.4262857, 0.9716729>,
      <0.4631500, 0.9724010>,
      <0.4263507, 0.9777601>,
      <0.4262372, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9775824>,
      <0.4262857, 0.9716729>,
      <0.4631092, 0.9671308>,
      <0.5000061, 0.9720689>,
      <0.4631774, 0.9776713>,
      <0.4631249, 0.9830304>,
      <0.4263507, 0.9777601>,
      <0.5000061, 0.9775824>,
      <0.5000061, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.4631774, 0.9776713>,
      <0.5000061, 0.9830163>,
      <0.4630714, 0.9883895>,
      <0.4262467, 0.9829287>,
      <0.3893626, 0.9830748>,
      <0.4263507, 0.9777601>,
      <0.4261367, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3526954, 0.9777601>,
      <0.4262467, 0.9829287>,
      <0.3892021, 0.9883895>,
      <0.3524814, 0.9830748>,
      <0.3895214, 0.9777601>,
      <0.5367803, 0.9724010>,
      <0.5736614, 0.9777601>,
      <0.5000061, 0.9775824>,
      <0.5000061, 0.9671308>,
      <0.5734474, 0.9671308>,
      <0.5368338, 0.9776713>,
      <0.5000061, 0.9720689>,
      <0.5367268, 0.9671308>,
      <0.5735480, 0.9721256>,
      <0.6103256, 0.9723694>,
      <0.5736614, 0.9777601>,
      <0.5734474, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6473045, 0.9774559>,
      <0.5735480, 0.9721256>,
      <0.6101681, 0.9671308>,
      <0.6470834, 0.9719638>,
      <0.6104830, 0.9776080>,
      <0.6106466, 0.9829987>,
      <0.5736614, 0.9777601>,
      <0.6473045, 0.9774559>,
      <0.6477448, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6104830, 0.9776080>,
      <0.6475254, 0.9829399>,
      <0.6108101, 0.9883895>,
      <0.5737689, 0.9830971>,
      <0.5368873, 0.9830304>,
      <0.5736614, 0.9777601>,
      <0.5738754, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9775824>,
      <0.5737689, 0.9830971>,
      <0.5369408, 0.9883895>,
      <0.5000061, 0.9830163>,
      <0.5368338, 0.9776713>,
      <0.6623658, 0.9723694>,
      <0.6778190, 0.9777601>,
      <0.6473045, 0.9774559>,
      <0.6468888, 0.9671308>,
      <0.6774510, 0.9671308>,
      <0.6625622, 0.9776080>,
      <0.6470834, 0.9719638>,
      <0.6621754, 0.9671308>,
      <0.6776072, 0.9716433>,
      <0.6928267, 0.9724455>,
      <0.6778190, 0.9777601>,
      <0.6774510, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7083211, 0.9777601>,
      <0.6776072, 0.9716433>,
      <0.6927532, 0.9671308>,
      <0.7080185, 0.9724455>,
      <0.6930707, 0.9777601>,
      <0.6933505, 0.9830748>,
      <0.6778190, 0.9777601>,
      <0.7083211, 0.9777601>,
      <0.7089263, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.6930707, 0.9777601>,
      <0.7086237, 0.9830748>,
      <0.6936309, 0.9883895>,
      <0.6780691, 0.9829070>,
      <0.6628010, 0.9829987>,
      <0.6778190, 0.9777601>,
      <0.6783356, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6473045, 0.9774559>,
      <0.6780691, 0.9829070>,
      <0.6630402, 0.9883895>,
      <0.6475254, 0.9829399>,
      <0.6625622, 0.9776080>,
      <0.3883464, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.3874907, 0.9883895>,
      <0.3511265, 0.9883895>,
      <0.3892021, 0.9883895>,
      <0.4255663, 0.9883895>,
      <0.4627862, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4255663, 0.9883895>,
      <0.4630714, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4625010, 0.9883895>,
      <0.4622158, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.4625010, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4619305, 0.9883895>,
      <0.4244254, 0.9883895>,
      <0.3866350, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.4244254, 0.9883895>,
      <0.3857793, 0.9883895>,
      <0.3488446, 0.9883895>,
      <0.3874907, 0.9883895>,
      <0.5372260, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.5375113, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5369408, 0.9883895>,
      <0.5744459, 0.9883895>,
      <0.6116658, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.5744459, 0.9883895>,
      <0.6108101, 0.9883895>,
      <0.6488857, 0.9883895>,
      <0.6125215, 0.9883895>,
      <0.6133773, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.6125215, 0.9883895>,
      <0.6511676, 0.9883895>,
      <0.6142330, 0.9883895>,
      <0.5755869, 0.9883895>,
      <0.5377965, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5755869, 0.9883895>,
      <0.5380817, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5375113, 0.9883895>,
      <0.6642992, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.6655583, 0.9883895>,
      <0.6488857, 0.9883895>,
      <0.6630402, 0.9883895>,
      <0.6797127, 0.9883895>,
      <0.6951263, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.6797127, 0.9883895>,
      <0.6936309, 0.9883895>,
      <0.7105398, 0.9883895>,
      <0.6966216, 0.9883895>,
      <0.6981169, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6966216, 0.9883895>,
      <0.7137666, 0.9883895>,
      <0.6996122, 0.9883895>,
      <0.6824671, 0.9883895>,
      <0.6668174, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6824671, 0.9883895>,
      <0.6680764, 0.9883895>,
      <0.6511676, 0.9883895>,
      <0.6655583, 0.9883895>,
      <0.3857793, 0.9912921>,
      <0.4238549, 0.9941947>,
      <0.3477037, 0.9941947>,
      <0.3477037, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3857793, 0.9941947>,
      <0.3477037, 0.9912921>,
      <0.3857793, 0.9883895>,
      <0.4238549, 0.9912921>,
      <0.4619305, 0.9912921>,
      <0.4238549, 0.9941947>,
      <0.4238549, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9941947>,
      <0.4238549, 0.9912921>,
      <0.4619305, 0.9883895>,
      <0.5000061, 0.9912921>,
      <0.4619305, 0.9941947>,
      <0.4619305, 0.9970974>,
      <0.4238549, 0.9941947>,
      <0.5000061, 0.9941947>,
      <0.5000061, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.4619305, 0.9941947>,
      <0.5000061, 0.9970974>,
      <0.4619305, 1.0000000>,
      <0.4238549, 0.9970974>,
      <0.3857793, 0.9970974>,
      <0.4238549, 0.9941947>,
      <0.4238549, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.3477037, 0.9941947>,
      <0.4238549, 0.9970974>,
      <0.3857793, 1.0000000>,
      <0.3477037, 0.9970974>,
      <0.3857793, 0.9941947>,
      <0.5380817, 0.9912921>,
      <0.5761574, 0.9941947>,
      <0.5000061, 0.9941947>,
      <0.5000061, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5380817, 0.9941947>,
      <0.5000061, 0.9912921>,
      <0.5380817, 0.9883895>,
      <0.5761574, 0.9912921>,
      <0.6142330, 0.9912921>,
      <0.5761574, 0.9941947>,
      <0.5761574, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 0.9941947>,
      <0.5761574, 0.9912921>,
      <0.6142330, 0.9883895>,
      <0.6523086, 0.9912921>,
      <0.6142330, 0.9941947>,
      <0.6142330, 0.9970974>,
      <0.5761574, 0.9941947>,
      <0.6523086, 0.9941947>,
      <0.6523086, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6142330, 0.9941947>,
      <0.6523086, 0.9970974>,
      <0.6142330, 1.0000000>,
      <0.5761574, 0.9970974>,
      <0.5380817, 0.9970974>,
      <0.5761574, 0.9941947>,
      <0.5761574, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5000061, 0.9941947>,
      <0.5761574, 0.9970974>,
      <0.5380817, 1.0000000>,
      <0.5000061, 0.9970974>,
      <0.5380817, 0.9941947>,
      <0.6680764, 0.9912921>,
      <0.6838443, 0.9941947>,
      <0.6523086, 0.9941947>,
      <0.6523086, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6680765, 0.9941947>,
      <0.6523086, 0.9912921>,
      <0.6680764, 0.9883895>,
      <0.6838443, 0.9912921>,
      <0.6996122, 0.9912921>,
      <0.6838443, 0.9941947>,
      <0.6838443, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 0.9941947>,
      <0.6838443, 0.9912921>,
      <0.6996122, 0.9883895>,
      <0.7153801, 0.9912921>,
      <0.6996122, 0.9941947>,
      <0.6996122, 0.9970974>,
      <0.6838443, 0.9941947>,
      <0.7153801, 0.9941947>,
      <0.7153801, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.6996122, 0.9941947>,
      <0.7153801, 0.9970974>,
      <0.6996122, 1.0000000>,
      <0.6838443, 0.9970974>,
      <0.6680764, 0.9970974>,
      <0.6838443, 0.9941947>,
      <0.6838443, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6523086, 0.9941947>,
      <0.6838443, 0.9970974>,
      <0.6680764, 1.0000000>,
      <0.6523086, 0.9970974>,
      <0.6680765, 0.9941947>
    }
    texture_list {
      1,
      texture { T_Pierre }
    }
    face_indices {
      1056,   // 0 triangles and 528 quads
      <8, 7, 0>, 0,
      <8, 0, 4>, 0,
      <8, 4, 1>, 0,
      <8, 1, 5>, 0,
      <8, 5, 2>, 0,
      <8, 2, 6>, 0,
      <8, 6, 3>, 0,
      <8, 3, 7>, 0,
      <14, 13, 0>, 0,
      <14, 0, 7>, 0,
      <14, 7, 3>, 0,
      <14, 3, 11>, 0,
      <14, 11, 9>, 0,
      <14, 9, 12>, 0,
      <14, 12, 10>, 0,
      <14, 10, 13>, 0,
      <20, 19, 0>, 0,
      <20, 0, 13>, 0,
      <20, 13, 10>, 0,
      <20, 10, 17>, 0,
      <20, 17, 15>, 0,
      <20, 15, 18>, 0,
      <20, 18, 16>, 0,
      <20, 16, 19>, 0,
      <24, 4, 0>, 0,
      <24, 0, 19>, 0,
      <24, 19, 16>, 0,
      <24, 16, 22>, 0,
      <24, 22, 21>, 0,
      <24, 21, 23>, 0,
      <24, 23, 1>, 0,
      <24, 1, 4>, 0,
      <33, 32, 25>, 0,
      <33, 25, 29>, 0,
      <33, 29, 26>, 0,
      <33, 26, 30>, 0,
      <33, 30, 27>, 0,
      <33, 27, 31>, 0,
      <33, 31, 28>, 0,
      <33, 28, 32>, 0,
      <39, 38, 25>, 0,
      <39, 25, 32>, 0,
      <39, 32, 28>, 0,
      <39, 28, 36>, 0,
      <39, 36, 34>, 0,
      <39, 34, 37>, 0,
      <39, 37, 35>, 0,
      <39, 35, 38>, 0,
      <45, 44, 25>, 0,
      <45, 25, 38>, 0,
      <45, 38, 35>, 0,
      <45, 35, 42>, 0,
      <45, 42, 40>, 0,
      <45, 40, 43>, 0,
      <45, 43, 41>, 0,
      <45, 41, 44>, 0,
      <49, 29, 25>, 0,
      <49, 25, 44>, 0,
      <49, 44, 41>, 0,
      <49, 41, 47>, 0,
      <49, 47, 46>, 0,
      <49, 46, 48>, 0,
      <49, 48, 26>, 0,
      <49, 26, 29>, 0,
      <55, 54, 50>, 0,
      <55, 50, 52>, 0,
      <55, 52, 35>, 0,
      <55, 35, 37>, 0,
      <55, 37, 34>, 0,
      <55, 34, 53>, 0,
      <55, 53, 51>, 0,
      <55, 51, 54>, 0,
      <61, 60, 50>, 0,
      <61, 50, 54>, 0,
      <61, 54, 51>, 0,
      <61, 51, 58>, 0,
      <61, 58, 56>, 0,
      <61, 56, 59>, 0,
      <61, 59, 57>, 0,
      <61, 57, 60>, 0,
      <67, 66, 50>, 0,
      <67, 50, 60>, 0,
      <67, 60, 57>, 0,
      <67, 57, 64>, 0,
      <67, 64, 62>, 0,
      <67, 62, 65>, 0,
      <67, 65, 63>, 0,
      <67, 63, 66>, 0,
      <69, 52, 50>, 0,
      <69, 50, 66>, 0,
      <69, 66, 63>, 0,
      <69, 63, 68>, 0,
      <69, 68, 40>, 0,
      <69, 40, 42>, 0,
      <69, 42, 35>, 0,
      <69, 35, 52>, 0,
      <75, 74, 70>, 0,
      <75, 70, 72>, 0,
      <75, 72, 57>, 0,
      <75, 57, 59>, 0,
      <75, 59, 56>, 0,
      <75, 56, 73>, 0,
      <75, 73, 71>, 0,
      <75, 71, 74>, 0,
      <81, 80, 70>, 0,
      <81, 70, 74>, 0,
      <81, 74, 71>, 0,
      <81, 71, 78>, 0,
      <81, 78, 76>, 0,
      <81, 76, 79>, 0,
      <81, 79, 77>, 0,
      <81, 77, 80>, 0,
      <87, 86, 70>, 0,
      <87, 70, 80>, 0,
      <87, 80, 77>, 0,
      <87, 77, 84>, 0,
      <87, 84, 82>, 0,
      <87, 82, 85>, 0,
      <87, 85, 83>, 0,
      <87, 83, 86>, 0,
      <89, 72, 70>, 0,
      <89, 70, 86>, 0,
      <89, 86, 83>, 0,
      <89, 83, 88>, 0,
      <89, 88, 62>, 0,
      <89, 62, 64>, 0,
      <89, 64, 57>, 0,
      <89, 57, 72>, 0,
      <95, 94, 90>, 0,
      <95, 90, 92>, 0,
      <95, 92, 91>, 0,
      <95, 91, 93>, 0,
      <95, 93, 46>, 0,
      <95, 46, 47>, 0,
      <95, 47, 41>, 0,
      <95, 41, 94>, 0,
      <99, 98, 90>, 0,
      <99, 90, 94>, 0,
      <99, 94, 41>, 0,
      <99, 41, 43>, 0,
      <99, 43, 40>, 0,
      <99, 40, 97>, 0,
      <99, 97, 96>, 0,
      <99, 96, 98>, 0,
      <105, 104, 90>, 0,
      <105, 90, 98>, 0,
      <105, 98, 96>, 0,
      <105, 96, 102>, 0,
      <105, 102, 100>, 0,
      <105, 100, 103>, 0,
      <105, 103, 101>, 0,
      <105, 101, 104>, 0,
      <109, 92, 90>, 0,
      <109, 90, 104>, 0,
      <109, 104, 101>, 0,
      <109, 101, 107>, 0,
      <109, 107, 106>, 0,
      <109, 106, 108>, 0,
      <109, 108, 91>, 0,
      <109, 91, 92>, 0,
      <113, 112, 110>, 0,
      <113, 110, 111>, 0,
      <113, 111, 96>, 0,
      <113, 96, 97>, 0,
      <113, 97, 40>, 0,
      <113, 40, 68>, 0,
      <113, 68, 63>, 0,
      <113, 63, 112>, 0,
      <117, 116, 110>, 0,
      <117, 110, 112>, 0,
      <117, 112, 63>, 0,
      <117, 63, 65>, 0,
      <117, 65, 62>, 0,
      <117, 62, 115>, 0,
      <117, 115, 114>, 0,
      <117, 114, 116>, 0,
      <123, 122, 110>, 0,
      <123, 110, 116>, 0,
      <123, 116, 114>, 0,
      <123, 114, 120>, 0,
      <123, 120, 118>, 0,
      <123, 118, 121>, 0,
      <123, 121, 119>, 0,
      <123, 119, 122>, 0,
      <125, 111, 110>, 0,
      <125, 110, 122>, 0,
      <125, 122, 119>, 0,
      <125, 119, 124>, 0,
      <125, 124, 100>, 0,
      <125, 100, 102>, 0,
      <125, 102, 96>, 0,
      <125, 96, 111>, 0,
      <129, 128, 126>, 0,
      <129, 126, 127>, 0,
      <129, 127, 114>, 0,
      <129, 114, 115>, 0,
      <129, 115, 62>, 0,
      <129, 62, 88>, 0,
      <129, 88, 83>, 0,
      <129, 83, 128>, 0,
      <133, 132, 126>, 0,
      <133, 126, 128>, 0,
      <133, 128, 83>, 0,
      <133, 83, 85>, 0,
      <133, 85, 82>, 0,
      <133, 82, 131>, 0,
      <133, 131, 130>, 0,
      <133, 130, 132>, 0,
      <139, 138, 126>, 0,
      <139, 126, 132>, 0,
      <139, 132, 130>, 0,
      <139, 130, 136>, 0,
      <139, 136, 134>, 0,
      <139, 134, 137>, 0,
      <139, 137, 135>, 0,
      <139, 135, 138>, 0,
      <141, 127, 126>, 0,
      <141, 126, 138>, 0,
      <141, 138, 135>, 0,
      <141, 135, 140>, 0,
      <141, 140, 118>, 0,
      <141, 118, 120>, 0,
      <141, 120, 114>, 0,
      <141, 114, 127>, 0,
      <147, 146, 142>, 0,
      <147, 142, 144>, 0,
      <147, 144, 143>, 0,
      <147, 143, 145>, 0,
      <147, 145, 106>, 0,
      <147, 106, 107>, 0,
      <147, 107, 101>, 0,
      <147, 101, 146>, 0,
      <151, 150, 142>, 0,
      <151, 142, 146>, 0,
      <151, 146, 101>, 0,
      <151, 101, 103>, 0,
      <151, 103, 100>, 0,
      <151, 100, 149>, 0,
      <151, 149, 148>, 0,
      <151, 148, 150>, 0,
      <157, 156, 142>, 0,
      <157, 142, 150>, 0,
      <157, 150, 148>, 0,
      <157, 148, 154>, 0,
      <157, 154, 152>, 0,
      <157, 152, 155>, 0,
      <157, 155, 153>, 0,
      <157, 153, 156>, 0,
      <161, 144, 142>, 0,
      <161, 142, 156>, 0,
      <161, 156, 153>, 0,
      <161, 153, 159>, 0,
      <161, 159, 158>, 0,
      <161, 158, 160>, 0,
      <161, 160, 143>, 0,
      <161, 143, 144>, 0,
      <165, 164, 162>, 0,
      <165, 162, 163>, 0,
      <165, 163, 148>, 0,
      <165, 148, 149>, 0,
      <165, 149, 100>, 0,
      <165, 100, 124>, 0,
      <165, 124, 119>, 0,
      <165, 119, 164>, 0,
      <169, 168, 162>, 0,
      <169, 162, 164>, 0,
      <169, 164, 119>, 0,
      <169, 119, 121>, 0,
      <169, 121, 118>, 0,
      <169, 118, 167>, 0,
      <169, 167, 166>, 0,
      <169, 166, 168>, 0,
      <175, 174, 162>, 0,
      <175, 162, 168>, 0,
      <175, 168, 166>, 0,
      <175, 166, 172>, 0,
      <175, 172, 170>, 0,
      <175, 170, 173>, 0,
      <175, 173, 171>, 0,
      <175, 171, 174>, 0,
      <177, 163, 162>, 0,
      <177, 162, 174>, 0,
      <177, 174, 171>, 0,
      <177, 171, 176>, 0,
      <177, 176, 152>, 0,
      <177, 152, 154>, 0,
      <177, 154, 148>, 0,
      <177, 148, 163>, 0,
      <181, 180, 178>, 0,
      <181, 178, 179>, 0,
      <181, 179, 166>, 0,
      <181, 166, 167>, 0,
      <181, 167, 118>, 0,
      <181, 118, 140>, 0,
      <181, 140, 135>, 0,
      <181, 135, 180>, 0,
      <185, 184, 178>, 0,
      <185, 178, 180>, 0,
      <185, 180, 135>, 0,
      <185, 135, 137>, 0,
      <185, 137, 134>, 0,
      <185, 134, 183>, 0,
      <185, 183, 182>, 0,
      <185, 182, 184>, 0,
      <191, 190, 178>, 0,
      <191, 178, 184>, 0,
      <191, 184, 182>, 0,
      <191, 182, 188>, 0,
      <191, 188, 186>, 0,
      <191, 186, 189>, 0,
      <191, 189, 187>, 0,
      <191, 187, 190>, 0,
      <193, 179, 178>, 0,
      <193, 178, 190>, 0,
      <193, 190, 187>, 0,
      <193, 187, 192>, 0,
      <193, 192, 170>, 0,
      <193, 170, 172>, 0,
      <193, 172, 166>, 0,
      <193, 166, 179>, 0,
      <199, 198, 194>, 0,
      <199, 194, 196>, 0,
      <199, 196, 195>, 0,
      <199, 195, 197>, 0,
      <199, 197, 158>, 0,
      <199, 158, 159>, 0,
      <199, 159, 153>, 0,
      <199, 153, 198>, 0,
      <203, 202, 194>, 0,
      <203, 194, 198>, 0,
      <203, 198, 153>, 0,
      <203, 153, 155>, 0,
      <203, 155, 152>, 0,
      <203, 152, 201>, 0,
      <203, 201, 200>, 0,
      <203, 200, 202>, 0,
      <209, 208, 194>, 0,
      <209, 194, 202>, 0,
      <209, 202, 200>, 0,
      <209, 200, 206>, 0,
      <209, 206, 204>, 0,
      <209, 204, 207>, 0,
      <209, 207, 205>, 0,
      <209, 205, 208>, 0,
      <213, 196, 194>, 0,
      <213, 194, 208>, 0,
      <213, 208, 205>, 0,
      <213, 205, 211>, 0,
      <213, 211, 210>, 0,
      <213, 210, 212>, 0,
      <213, 212, 195>, 0,
      <213, 195, 196>, 0,
      <217, 216, 214>, 0,
      <217, 214, 215>, 0,
      <217, 215, 200>, 0,
      <217, 200, 201>, 0,
      <217, 201, 152>, 0,
      <217, 152, 176>, 0,
      <217, 176, 171>, 0,
      <217, 171, 216>, 0,
      <221, 220, 214>, 0,
      <221, 214, 216>, 0,
      <221, 216, 171>, 0,
      <221, 171, 173>, 0,
      <221, 173, 170>, 0,
      <221, 170, 219>, 0,
      <221, 219, 218>, 0,
      <221, 218, 220>, 0,
      <227, 226, 214>, 0,
      <227, 214, 220>, 0,
      <227, 220, 218>, 0,
      <227, 218, 224>, 0,
      <227, 224, 222>, 0,
      <227, 222, 225>, 0,
      <227, 225, 223>, 0,
      <227, 223, 226>, 0,
      <229, 215, 214>, 0,
      <229, 214, 226>, 0,
      <229, 226, 223>, 0,
      <229, 223, 228>, 0,
      <229, 228, 204>, 0,
      <229, 204, 206>, 0,
      <229, 206, 200>, 0,
      <229, 200, 215>, 0,
      <233, 232, 230>, 0,
      <233, 230, 231>, 0,
      <233, 231, 218>, 0,
      <233, 218, 219>, 0,
      <233, 219, 170>, 0,
      <233, 170, 192>, 0,
      <233, 192, 187>, 0,
      <233, 187, 232>, 0,
      <237, 236, 230>, 0,
      <237, 230, 232>, 0,
      <237, 232, 187>, 0,
      <237, 187, 189>, 0,
      <237, 189, 186>, 0,
      <237, 186, 235>, 0,
      <237, 235, 234>, 0,
      <237, 234, 236>, 0,
      <243, 242, 230>, 0,
      <243, 230, 236>, 0,
      <243, 236, 234>, 0,
      <243, 234, 240>, 0,
      <243, 240, 238>, 0,
      <243, 238, 241>, 0,
      <243, 241, 239>, 0,
      <243, 239, 242>, 0,
      <245, 231, 230>, 0,
      <245, 230, 242>, 0,
      <245, 242, 239>, 0,
      <245, 239, 244>, 0,
      <245, 244, 222>, 0,
      <245, 222, 224>, 0,
      <245, 224, 218>, 0,
      <245, 218, 231>, 0,
      <251, 250, 246>, 0,
      <251, 246, 248>, 0,
      <251, 248, 247>, 0,
      <251, 247, 249>, 0,
      <251, 249, 210>, 0,
      <251, 210, 211>, 0,
      <251, 211, 205>, 0,
      <251, 205, 250>, 0,
      <255, 254, 246>, 0,
      <255, 246, 250>, 0,
      <255, 250, 205>, 0,
      <255, 205, 207>, 0,
      <255, 207, 204>, 0,
      <255, 204, 253>, 0,
      <255, 253, 252>, 0,
      <255, 252, 254>, 0,
      <261, 260, 246>, 0,
      <261, 246, 254>, 0,
      <261, 254, 252>, 0,
      <261, 252, 258>, 0,
      <261, 258, 256>, 0,
      <261, 256, 259>, 0,
      <261, 259, 257>, 0,
      <261, 257, 260>, 0,
      <265, 248, 246>, 0,
      <265, 246, 260>, 0,
      <265, 260, 257>, 0,
      <265, 257, 263>, 0,
      <265, 263, 262>, 0,
      <265, 262, 264>, 0,
      <265, 264, 247>, 0,
      <265, 247, 248>, 0,
      <269, 268, 266>, 0,
      <269, 266, 267>, 0,
      <269, 267, 252>, 0,
      <269, 252, 253>, 0,
      <269, 253, 204>, 0,
      <269, 204, 228>, 0,
      <269, 228, 223>, 0,
      <269, 223, 268>, 0,
      <273, 272, 266>, 0,
      <273, 266, 268>, 0,
      <273, 268, 223>, 0,
      <273, 223, 225>, 0,
      <273, 225, 222>, 0,
      <273, 222, 271>, 0,
      <273, 271, 270>, 0,
      <273, 270, 272>, 0,
      <279, 278, 266>, 0,
      <279, 266, 272>, 0,
      <279, 272, 270>, 0,
      <279, 270, 276>, 0,
      <279, 276, 274>, 0,
      <279, 274, 277>, 0,
      <279, 277, 275>, 0,
      <279, 275, 278>, 0,
      <281, 267, 266>, 0,
      <281, 266, 278>, 0,
      <281, 278, 275>, 0,
      <281, 275, 280>, 0,
      <281, 280, 256>, 0,
      <281, 256, 258>, 0,
      <281, 258, 252>, 0,
      <281, 252, 267>, 0,
      <285, 284, 282>, 0,
      <285, 282, 283>, 0,
      <285, 283, 270>, 0,
      <285, 270, 271>, 0,
      <285, 271, 222>, 0,
      <285, 222, 244>, 0,
      <285, 244, 239>, 0,
      <285, 239, 284>, 0,
      <289, 288, 282>, 0,
      <289, 282, 284>, 0,
      <289, 284, 239>, 0,
      <289, 239, 241>, 0,
      <289, 241, 238>, 0,
      <289, 238, 287>, 0,
      <289, 287, 286>, 0,
      <289, 286, 288>, 0,
      <295, 294, 282>, 0,
      <295, 282, 288>, 0,
      <295, 288, 286>, 0,
      <295, 286, 292>, 0,
      <295, 292, 290>, 0,
      <295, 290, 293>, 0,
      <295, 293, 291>, 0,
      <295, 291, 294>, 0,
      <297, 283, 282>, 0,
      <297, 282, 294>, 0,
      <297, 294, 291>, 0,
      <297, 291, 296>, 0,
      <297, 296, 274>, 0,
      <297, 274, 276>, 0,
      <297, 276, 270>, 0,
      <297, 270, 283>, 0,
      <303, 302, 298>, 0,
      <303, 298, 300>, 0,
      <303, 300, 299>, 0,
      <303, 299, 301>, 0,
      <303, 301, 262>, 0,
      <303, 262, 263>, 0,
      <303, 263, 257>, 0,
      <303, 257, 302>, 0,
      <307, 306, 298>, 0,
      <307, 298, 302>, 0,
      <307, 302, 257>, 0,
      <307, 257, 259>, 0,
      <307, 259, 256>, 0,
      <307, 256, 305>, 0,
      <307, 305, 304>, 0,
      <307, 304, 306>, 0,
      <313, 312, 298>, 0,
      <313, 298, 306>, 0,
      <313, 306, 304>, 0,
      <313, 304, 310>, 0,
      <313, 310, 308>, 0,
      <313, 308, 311>, 0,
      <313, 311, 309>, 0,
      <313, 309, 312>, 0,
      <317, 300, 298>, 0,
      <317, 298, 312>, 0,
      <317, 312, 309>, 0,
      <317, 309, 315>, 0,
      <317, 315, 314>, 0,
      <317, 314, 316>, 0,
      <317, 316, 299>, 0,
      <317, 299, 300>, 0,
      <321, 320, 318>, 0,
      <321, 318, 319>, 0,
      <321, 319, 304>, 0,
      <321, 304, 305>, 0,
      <321, 305, 256>, 0,
      <321, 256, 280>, 0,
      <321, 280, 275>, 0,
      <321, 275, 320>, 0,
      <325, 324, 318>, 0,
      <325, 318, 320>, 0,
      <325, 320, 275>, 0,
      <325, 275, 277>, 0,
      <325, 277, 274>, 0,
      <325, 274, 323>, 0,
      <325, 323, 322>, 0,
      <325, 322, 324>, 0,
      <331, 330, 318>, 0,
      <331, 318, 324>, 0,
      <331, 324, 322>, 0,
      <331, 322, 328>, 0,
      <331, 328, 326>, 0,
      <331, 326, 329>, 0,
      <331, 329, 327>, 0,
      <331, 327, 330>, 0,
      <333, 319, 318>, 0,
      <333, 318, 330>, 0,
      <333, 330, 327>, 0,
      <333, 327, 332>, 0,
      <333, 332, 308>, 0,
      <333, 308, 310>, 0,
      <333, 310, 304>, 0,
      <333, 304, 319>, 0,
      <337, 336, 334>, 0,
      <337, 334, 335>, 0,
      <337, 335, 322>, 0,
      <337, 322, 323>, 0,
      <337, 323, 274>, 0,
      <337, 274, 296>, 0,
      <337, 296, 291>, 0,
      <337, 291, 336>, 0,
      <341, 340, 334>, 0,
      <341, 334, 336>, 0,
      <341, 336, 291>, 0,
      <341, 291, 293>, 0,
      <341, 293, 290>, 0,
      <341, 290, 339>, 0,
      <341, 339, 338>, 0,
      <341, 338, 340>, 0,
      <347, 346, 334>, 0,
      <347, 334, 340>, 0,
      <347, 340, 338>, 0,
      <347, 338, 344>, 0,
      <347, 344, 342>, 0,
      <347, 342, 345>, 0,
      <347, 345, 343>, 0,
      <347, 343, 346>, 0,
      <349, 335, 334>, 0,
      <349, 334, 346>, 0,
      <349, 346, 343>, 0,
      <349, 343, 348>, 0,
      <349, 348, 326>, 0,
      <349, 326, 328>, 0,
      <349, 328, 322>, 0,
      <349, 322, 335>, 0,
      <355, 354, 350>, 0,
      <355, 350, 352>, 0,
      <355, 352, 351>, 0,
      <355, 351, 353>, 0,
      <355, 353, 314>, 0,
      <355, 314, 315>, 0,
      <355, 315, 309>, 0,
      <355, 309, 354>, 0,
      <359, 358, 350>, 0,
      <359, 350, 354>, 0,
      <359, 354, 309>, 0,
      <359, 309, 311>, 0,
      <359, 311, 308>, 0,
      <359, 308, 357>, 0,
      <359, 357, 356>, 0,
      <359, 356, 358>, 0,
      <365, 364, 350>, 0,
      <365, 350, 358>, 0,
      <365, 358, 356>, 0,
      <365, 356, 362>, 0,
      <365, 362, 360>, 0,
      <365, 360, 363>, 0,
      <365, 363, 361>, 0,
      <365, 361, 364>, 0,
      <369, 352, 350>, 0,
      <369, 350, 364>, 0,
      <369, 364, 361>, 0,
      <369, 361, 367>, 0,
      <369, 367, 366>, 0,
      <369, 366, 368>, 0,
      <369, 368, 351>, 0,
      <369, 351, 352>, 0,
      <373, 372, 370>, 0,
      <373, 370, 371>, 0,
      <373, 371, 356>, 0,
      <373, 356, 357>, 0,
      <373, 357, 308>, 0,
      <373, 308, 332>, 0,
      <373, 332, 327>, 0,
      <373, 327, 372>, 0,
      <377, 376, 370>, 0,
      <377, 370, 372>, 0,
      <377, 372, 327>, 0,
      <377, 327, 329>, 0,
      <377, 329, 326>, 0,
      <377, 326, 375>, 0,
      <377, 375, 374>, 0,
      <377, 374, 376>, 0,
      <383, 382, 370>, 0,
      <383, 370, 376>, 0,
      <383, 376, 374>, 0,
      <383, 374, 380>, 0,
      <383, 380, 378>, 0,
      <383, 378, 381>, 0,
      <383, 381, 379>, 0,
      <383, 379, 382>, 0,
      <385, 371, 370>, 0,
      <385, 370, 382>, 0,
      <385, 382, 379>, 0,
      <385, 379, 384>, 0,
      <385, 384, 360>, 0,
      <385, 360, 362>, 0,
      <385, 362, 356>, 0,
      <385, 356, 371>, 0,
      <389, 388, 386>, 0,
      <389, 386, 387>, 0,
      <389, 387, 374>, 0,
      <389, 374, 375>, 0,
      <389, 375, 326>, 0,
      <389, 326, 348>, 0,
      <389, 348, 343>, 0,
      <389, 343, 388>, 0,
      <393, 392, 386>, 0,
      <393, 386, 388>, 0,
      <393, 388, 343>, 0,
      <393, 343, 345>, 0,
      <393, 345, 342>, 0,
      <393, 342, 391>, 0,
      <393, 391, 390>, 0,
      <393, 390, 392>, 0,
      <399, 398, 386>, 0,
      <399, 386, 392>, 0,
      <399, 392, 390>, 0,
      <399, 390, 396>, 0,
      <399, 396, 394>, 0,
      <399, 394, 397>, 0,
      <399, 397, 395>, 0,
      <399, 395, 398>, 0,
      <401, 387, 386>, 0,
      <401, 386, 398>, 0,
      <401, 398, 395>, 0,
      <401, 395, 400>, 0,
      <401, 400, 378>, 0,
      <401, 378, 380>, 0,
      <401, 380, 374>, 0,
      <401, 374, 387>, 0,
      <407, 406, 402>, 0,
      <407, 402, 404>, 0,
      <407, 404, 403>, 0,
      <407, 403, 405>, 0,
      <407, 405, 366>, 0,
      <407, 366, 367>, 0,
      <407, 367, 361>, 0,
      <407, 361, 406>, 0,
      <411, 410, 402>, 0,
      <411, 402, 406>, 0,
      <411, 406, 361>, 0,
      <411, 361, 363>, 0,
      <411, 363, 360>, 0,
      <411, 360, 409>, 0,
      <411, 409, 408>, 0,
      <411, 408, 410>, 0,
      <414, 413, 402>, 0,
      <414, 402, 410>, 0,
      <414, 410, 408>, 0,
      <414, 408, 412>, 0,
      <414, 412, 9>, 0,
      <414, 9, 11>, 0,
      <414, 11, 3>, 0,
      <414, 3, 413>, 0,
      <416, 404, 402>, 0,
      <416, 402, 413>, 0,
      <416, 413, 3>, 0,
      <416, 3, 6>, 0,
      <416, 6, 2>, 0,
      <416, 2, 415>, 0,
      <416, 415, 403>, 0,
      <416, 403, 404>, 0,
      <420, 419, 417>, 0,
      <420, 417, 418>, 0,
      <420, 418, 408>, 0,
      <420, 408, 409>, 0,
      <420, 409, 360>, 0,
      <420, 360, 384>, 0,
      <420, 384, 379>, 0,
      <420, 379, 419>, 0,
      <424, 423, 417>, 0,
      <424, 417, 419>, 0,
      <424, 419, 379>, 0,
      <424, 379, 381>, 0,
      <424, 381, 378>, 0,
      <424, 378, 422>, 0,
      <424, 422, 421>, 0,
      <424, 421, 423>, 0,
      <427, 426, 417>, 0,
      <427, 417, 423>, 0,
      <427, 423, 421>, 0,
      <427, 421, 425>, 0,
      <427, 425, 15>, 0,
      <427, 15, 17>, 0,
      <427, 17, 10>, 0,
      <427, 10, 426>, 0,
      <428, 418, 417>, 0,
      <428, 417, 426>, 0,
      <428, 426, 10>, 0,
      <428, 10, 12>, 0,
      <428, 12, 9>, 0,
      <428, 9, 412>, 0,
      <428, 412, 408>, 0,
      <428, 408, 418>, 0,
      <432, 431, 429>, 0,
      <432, 429, 430>, 0,
      <432, 430, 421>, 0,
      <432, 421, 422>, 0,
      <432, 422, 378>, 0,
      <432, 378, 400>, 0,
      <432, 400, 395>, 0,
      <432, 395, 431>, 0,
      <436, 435, 429>, 0,
      <436, 429, 431>, 0,
      <436, 431, 395>, 0,
      <436, 395, 397>, 0,
      <436, 397, 394>, 0,
      <436, 394, 434>, 0,
      <436, 434, 433>, 0,
      <436, 433, 435>, 0,
      <439, 438, 429>, 0,
      <439, 429, 435>, 0,
      <439, 435, 433>, 0,
      <439, 433, 437>, 0,
      <439, 437, 21>, 0,
      <439, 21, 22>, 0,
      <439, 22, 16>, 0,
      <439, 16, 438>, 0,
      <440, 430, 429>, 0,
      <440, 429, 438>, 0,
      <440, 438, 16>, 0,
      <440, 16, 18>, 0,
      <440, 18, 15>, 0,
      <440, 15, 425>, 0,
      <440, 425, 421>, 0,
      <440, 421, 430>, 0,
      <448, 447, 441>, 0,
      <448, 441, 444>, 0,
      <448, 444, 442>, 0,
      <448, 442, 445>, 0,
      <448, 445, 366>, 0,
      <448, 366, 446>, 0,
      <448, 446, 443>, 0,
      <448, 443, 447>, 0,
      <453, 452, 441>, 0,
      <453, 441, 447>, 0,
      <453, 447, 443>, 0,
      <453, 443, 450>, 0,
      <453, 450, 394>, 0,
      <453, 394, 451>, 0,
      <453, 451, 449>, 0,
      <453, 449, 452>, 0,
      <458, 457, 441>, 0,
      <458, 441, 452>, 0,
      <458, 452, 449>, 0,
      <458, 449, 455>, 0,
      <458, 455, 21>, 0,
      <458, 21, 456>, 0,
      <458, 456, 454>, 0,
      <458, 454, 457>, 0,
      <461, 444, 441>, 0,
      <461, 441, 457>, 0,
      <461, 457, 454>, 0,
      <461, 454, 459>, 0,
      <461, 459, 2>, 0,
      <461, 2, 460>, 0,
      <461, 460, 442>, 0,
      <461, 442, 444>, 0,
      <467, 466, 462>, 0,
      <467, 462, 464>, 0,
      <467, 464, 463>, 0,
      <467, 463, 465>, 0,
      <467, 465, 314>, 0,
      <467, 314, 353>, 0,
      <467, 353, 351>, 0,
      <467, 351, 466>, 0,
      <471, 470, 462>, 0,
      <471, 462, 466>, 0,
      <471, 466, 351>, 0,
      <471, 351, 368>, 0,
      <471, 368, 366>, 0,
      <471, 366, 469>, 0,
      <471, 469, 468>, 0,
      <471, 468, 470>, 0,
      <474, 473, 462>, 0,
      <474, 462, 470>, 0,
      <474, 470, 468>, 0,
      <474, 468, 472>, 0,
      <474, 472, 394>, 0,
      <474, 394, 396>, 0,
      <474, 396, 390>, 0,
      <474, 390, 473>, 0,
      <476, 464, 462>, 0,
      <476, 462, 473>, 0,
      <476, 473, 390>, 0,
      <476, 390, 391>, 0,
      <476, 391, 342>, 0,
      <476, 342, 475>, 0,
      <476, 475, 463>, 0,
      <476, 463, 464>, 0,
      <484, 483, 477>, 0,
      <484, 477, 480>, 0,
      <484, 480, 478>, 0,
      <484, 478, 481>, 0,
      <484, 481, 262>, 0,
      <484, 262, 482>, 0,
      <484, 482, 479>, 0,
      <484, 479, 483>, 0,
      <489, 488, 477>, 0,
      <489, 477, 483>, 0,
      <489, 483, 479>, 0,
      <489, 479, 486>, 0,
      <489, 486, 290>, 0,
      <489, 290, 487>, 0,
      <489, 487, 485>, 0,
      <489, 485, 488>, 0,
      <494, 493, 477>, 0,
      <494, 477, 488>, 0,
      <494, 488, 485>, 0,
      <494, 485, 491>, 0,
      <494, 491, 342>, 0,
      <494, 342, 492>, 0,
      <494, 492, 490>, 0,
      <494, 490, 493>, 0,
      <497, 480, 477>, 0,
      <497, 477, 493>, 0,
      <497, 493, 490>, 0,
      <497, 490, 495>, 0,
      <497, 495, 314>, 0,
      <497, 314, 496>, 0,
      <497, 496, 478>, 0,
      <497, 478, 480>, 0,
      <503, 502, 498>, 0,
      <503, 498, 500>, 0,
      <503, 500, 499>, 0,
      <503, 499, 501>, 0,
      <503, 501, 210>, 0,
      <503, 210, 249>, 0,
      <503, 249, 247>, 0,
      <503, 247, 502>, 0,
      <507, 506, 498>, 0,
      <507, 498, 502>, 0,
      <507, 502, 247>, 0,
      <507, 247, 264>, 0,
      <507, 264, 262>, 0,
      <507, 262, 505>, 0,
      <507, 505, 504>, 0,
      <507, 504, 506>, 0,
      <510, 509, 498>, 0,
      <510, 498, 506>, 0,
      <510, 506, 504>, 0,
      <510, 504, 508>, 0,
      <510, 508, 290>, 0,
      <510, 290, 292>, 0,
      <510, 292, 286>, 0,
      <510, 286, 509>, 0,
      <512, 500, 498>, 0,
      <512, 498, 509>, 0,
      <512, 509, 286>, 0,
      <512, 286, 287>, 0,
      <512, 287, 238>, 0,
      <512, 238, 511>, 0,
      <512, 511, 499>, 0,
      <512, 499, 500>, 0,
      <520, 519, 513>, 0,
      <520, 513, 516>, 0,
      <520, 516, 514>, 0,
      <520, 514, 517>, 0,
      <520, 517, 158>, 0,
      <520, 158, 518>, 0,
      <520, 518, 515>, 0,
      <520, 515, 519>, 0,
      <525, 524, 513>, 0,
      <525, 513, 519>, 0,
      <525, 519, 515>, 0,
      <525, 515, 522>, 0,
      <525, 522, 186>, 0,
      <525, 186, 523>, 0,
      <525, 523, 521>, 0,
      <525, 521, 524>, 0,
      <530, 529, 513>, 0,
      <530, 513, 524>, 0,
      <530, 524, 521>, 0,
      <530, 521, 527>, 0,
      <530, 527, 238>, 0,
      <530, 238, 528>, 0,
      <530, 528, 526>, 0,
      <530, 526, 529>, 0,
      <533, 516, 513>, 0,
      <533, 513, 529>, 0,
      <533, 529, 526>, 0,
      <533, 526, 531>, 0,
      <533, 531, 210>, 0,
      <533, 210, 532>, 0,
      <533, 532, 514>, 0,
      <533, 514, 516>, 0,
      <539, 538, 534>, 0,
      <539, 534, 536>, 0,
      <539, 536, 535>, 0,
      <539, 535, 537>, 0,
      <539, 537, 106>, 0,
      <539, 106, 145>, 0,
      <539, 145, 143>, 0,
      <539, 143, 538>, 0,
      <543, 542, 534>, 0,
      <543, 534, 538>, 0,
      <543, 538, 143>, 0,
      <543, 143, 160>, 0,
      <543, 160, 158>, 0,
      <543, 158, 541>, 0,
      <543, 541, 540>, 0,
      <543, 540, 542>, 0,
      <546, 545, 534>, 0,
      <546, 534, 542>, 0,
      <546, 542, 540>, 0,
      <546, 540, 544>, 0,
      <546, 544, 186>, 0,
      <546, 186, 188>, 0,
      <546, 188, 182>, 0,
      <546, 182, 545>, 0,
      <548, 536, 534>, 0,
      <548, 534, 545>, 0,
      <548, 545, 182>, 0,
      <548, 182, 183>, 0,
      <548, 183, 134>, 0,
      <548, 134, 547>, 0,
      <548, 547, 535>, 0,
      <548, 535, 536>, 0,
      <556, 555, 549>, 0,
      <556, 549, 552>, 0,
      <556, 552, 550>, 0,
      <556, 550, 553>, 0,
      <556, 553, 27>, 0,
      <556, 27, 554>, 0,
      <556, 554, 551>, 0,
      <556, 551, 555>, 0,
      <561, 560, 549>, 0,
      <561, 549, 555>, 0,
      <561, 555, 551>, 0,
      <561, 551, 558>, 0,
      <561, 558, 76>, 0,
      <561, 76, 559>, 0,
      <561, 559, 557>, 0,
      <561, 557, 560>, 0,
      <566, 565, 549>, 0,
      <566, 549, 560>, 0,
      <566, 560, 557>, 0,
      <566, 557, 563>, 0,
      <566, 563, 134>, 0,
      <566, 134, 564>, 0,
      <566, 564, 562>, 0,
      <566, 562, 565>, 0,
      <569, 552, 549>, 0,
      <569, 549, 565>, 0,
      <569, 565, 562>, 0,
      <569, 562, 567>, 0,
      <569, 567, 106>, 0,
      <569, 106, 568>, 0,
      <569, 568, 550>, 0,
      <569, 550, 552>, 0,
      <573, 572, 570>, 0,
      <573, 570, 571>, 0,
      <573, 571, 551>, 0,
      <573, 551, 554>, 0,
      <573, 554, 27>, 0,
      <573, 27, 30>, 0,
      <573, 30, 26>, 0,
      <573, 26, 572>, 0,
      <577, 576, 570>, 0,
      <577, 570, 572>, 0,
      <577, 572, 26>, 0,
      <577, 26, 48>, 0,
      <577, 48, 46>, 0,
      <577, 46, 575>, 0,
      <577, 575, 574>, 0,
      <577, 574, 576>, 0,
      <580, 579, 570>, 0,
      <580, 570, 576>, 0,
      <580, 576, 574>, 0,
      <580, 574, 578>, 0,
      <580, 578, 82>, 0,
      <580, 82, 84>, 0,
      <580, 84, 77>, 0,
      <580, 77, 579>, 0,
      <581, 571, 570>, 0,
      <581, 570, 579>, 0,
      <581, 579, 77>, 0,
      <581, 77, 79>, 0,
      <581, 79, 76>, 0,
      <581, 76, 558>, 0,
      <581, 558, 551>, 0,
      <581, 551, 571>, 0
    }
    normal_indices {
      1056,   // from 0 triangles and 528 quads
      <0, 1, 2>,
      <0, 2, 3>,
      <0, 3, 4>,
      <0, 4, 5>,
      <0, 6, 7>,
      <0, 7, 8>,
      <0, 9, 10>,
      <0, 10, 1>,
      <11, 12, 2>,
      <11, 2, 1>,
      <11, 1, 13>,
      <11, 13, 14>,
      <11, 15, 16>,
      <11, 16, 17>,
      <11, 18, 19>,
      <11, 19, 12>,
      <20, 21, 2>,
      <20, 2, 12>,
      <20, 12, 22>,
      <20, 22, 23>,
      <20, 24, 25>,
      <20, 25, 26>,
      <20, 27, 28>,
      <20, 28, 21>,
      <29, 3, 2>,
      <29, 2, 21>,
      <29, 21, 30>,
      <29, 30, 31>,
      <29, 32, 33>,
      <29, 33, 34>,
      <29, 35, 36>,
      <29, 36, 3>,
      <37, 38, 39>,
      <37, 39, 40>,
      <37, 40, 41>,
      <37, 41, 42>,
      <37, 43, 44>,
      <37, 44, 45>,
      <37, 46, 47>,
      <37, 47, 38>,
      <48, 49, 39>,
      <48, 39, 38>,
      <48, 38, 50>,
      <48, 50, 51>,
      <48, 52, 53>,
      <48, 53, 54>,
      <48, 55, 56>,
      <48, 56, 49>,
      <57, 58, 39>,
      <57, 39, 49>,
      <57, 49, 59>,
      <57, 59, 60>,
      <57, 61, 62>,
      <57, 62, 63>,
      <57, 64, 65>,
      <57, 65, 58>,
      <66, 40, 39>,
      <66, 39, 58>,
      <66, 58, 67>,
      <66, 67, 68>,
      <66, 69, 70>,
      <66, 70, 71>,
      <66, 72, 73>,
      <66, 73, 40>,
      <74, 75, 76>,
      <74, 76, 77>,
      <74, 77, 78>,
      <74, 78, 79>,
      <74, 80, 81>,
      <74, 81, 82>,
      <74, 83, 84>,
      <74, 84, 75>,
      <85, 86, 76>,
      <85, 76, 75>,
      <85, 75, 87>,
      <85, 87, 88>,
      <85, 89, 90>,
      <85, 90, 91>,
      <85, 92, 93>,
      <85, 93, 86>,
      <94, 95, 76>,
      <94, 76, 86>,
      <94, 86, 96>,
      <94, 96, 97>,
      <94, 98, 99>,
      <94, 99, 100>,
      <94, 101, 102>,
      <94, 102, 95>,
      <103, 77, 76>,
      <103, 76, 95>,
      <103, 95, 104>,
      <103, 104, 105>,
      <103, 106, 107>,
      <103, 107, 108>,
      <103, 109, 110>,
      <103, 110, 77>,
      <111, 112, 113>,
      <111, 113, 114>,
      <111, 114, 115>,
      <111, 115, 116>,
      <111, 117, 118>,
      <111, 118, 119>,
      <111, 120, 121>,
      <111, 121, 112>,
      <122, 123, 113>,
      <122, 113, 112>,
      <122, 112, 124>,
      <122, 124, 125>,
      <122, 126, 127>,
      <122, 127, 128>,
      <122, 129, 130>,
      <122, 130, 123>,
      <131, 132, 113>,
      <131, 113, 123>,
      <131, 123, 133>,
      <131, 133, 134>,
      <131, 135, 136>,
      <131, 136, 137>,
      <131, 138, 139>,
      <131, 139, 132>,
      <140, 114, 113>,
      <140, 113, 132>,
      <140, 132, 141>,
      <140, 141, 142>,
      <140, 143, 144>,
      <140, 144, 145>,
      <140, 146, 147>,
      <140, 147, 114>,
      <148, 149, 150>,
      <148, 150, 151>,
      <148, 151, 152>,
      <148, 152, 153>,
      <148, 154, 155>,
      <148, 155, 156>,
      <148, 157, 158>,
      <148, 158, 149>,
      <159, 160, 150>,
      <159, 150, 149>,
      <159, 149, 161>,
      <159, 161, 162>,
      <159, 163, 164>,
      <159, 164, 165>,
      <159, 166, 167>,
      <159, 167, 160>,
      <168, 169, 150>,
      <168, 150, 160>,
      <168, 160, 170>,
      <168, 170, 171>,
      <168, 172, 173>,
      <168, 173, 174>,
      <168, 175, 176>,
      <168, 176, 169>,
      <177, 151, 150>,
      <177, 150, 169>,
      <177, 169, 178>,
      <177, 178, 179>,
      <177, 180, 181>,
      <177, 181, 182>,
      <177, 183, 184>,
      <177, 184, 151>,
      <185, 186, 187>,
      <185, 187, 188>,
      <185, 188, 189>,
      <185, 189, 190>,
      <185, 191, 192>,
      <185, 192, 193>,
      <185, 194, 195>,
      <185, 195, 186>,
      <196, 197, 187>,
      <196, 187, 186>,
      <196, 186, 198>,
      <196, 198, 199>,
      <196, 200, 201>,
      <196, 201, 202>,
      <196, 203, 204>,
      <196, 204, 197>,
      <205, 206, 187>,
      <205, 187, 197>,
      <205, 197, 207>,
      <205, 207, 208>,
      <205, 209, 210>,
      <205, 210, 211>,
      <205, 212, 213>,
      <205, 213, 206>,
      <214, 188, 187>,
      <214, 187, 206>,
      <214, 206, 215>,
      <214, 215, 216>,
      <214, 217, 218>,
      <214, 218, 219>,
      <214, 220, 221>,
      <214, 221, 188>,
      <222, 223, 224>,
      <222, 224, 225>,
      <222, 225, 226>,
      <222, 226, 227>,
      <222, 228, 229>,
      <222, 229, 230>,
      <222, 231, 232>,
      <222, 232, 223>,
      <233, 234, 224>,
      <233, 224, 223>,
      <233, 223, 235>,
      <233, 235, 236>,
      <233, 237, 238>,
      <233, 238, 239>,
      <233, 240, 241>,
      <233, 241, 234>,
      <242, 243, 224>,
      <242, 224, 234>,
      <242, 234, 244>,
      <242, 244, 245>,
      <242, 246, 247>,
      <242, 247, 248>,
      <242, 249, 250>,
      <242, 250, 243>,
      <251, 225, 224>,
      <251, 224, 243>,
      <251, 243, 252>,
      <251, 252, 253>,
      <251, 254, 255>,
      <251, 255, 256>,
      <251, 257, 258>,
      <251, 258, 225>,
      <259, 260, 261>,
      <259, 261, 262>,
      <259, 262, 263>,
      <259, 263, 264>,
      <259, 265, 266>,
      <259, 266, 267>,
      <259, 268, 269>,
      <259, 269, 260>,
      <270, 271, 261>,
      <270, 261, 260>,
      <270, 260, 272>,
      <270, 272, 273>,
      <270, 274, 275>,
      <270, 275, 276>,
      <270, 277, 278>,
      <270, 278, 271>,
      <279, 280, 261>,
      <279, 261, 271>,
      <279, 271, 281>,
      <279, 281, 282>,
      <279, 283, 284>,
      <279, 284, 285>,
      <279, 286, 287>,
      <279, 287, 280>,
      <288, 262, 261>,
      <288, 261, 280>,
      <288, 280, 289>,
      <288, 289, 290>,
      <288, 291, 292>,
      <288, 292, 293>,
      <288, 294, 295>,
      <288, 295, 262>,
      <296, 297, 298>,
      <296, 298, 299>,
      <296, 299, 300>,
      <296, 300, 301>,
      <296, 302, 303>,
      <296, 303, 304>,
      <296, 305, 306>,
      <296, 306, 297>,
      <307, 308, 298>,
      <307, 298, 297>,
      <307, 297, 309>,
      <307, 309, 310>,
      <307, 311, 312>,
      <307, 312, 313>,
      <307, 314, 315>,
      <307, 315, 308>,
      <316, 317, 298>,
      <316, 298, 308>,
      <316, 308, 318>,
      <316, 318, 319>,
      <316, 320, 321>,
      <316, 321, 322>,
      <316, 323, 324>,
      <316, 324, 317>,
      <325, 299, 298>,
      <325, 298, 317>,
      <325, 317, 326>,
      <325, 326, 327>,
      <325, 328, 329>,
      <325, 329, 330>,
      <325, 331, 332>,
      <325, 332, 299>,
      <333, 334, 335>,
      <333, 335, 336>,
      <333, 336, 337>,
      <333, 337, 338>,
      <333, 339, 340>,
      <333, 340, 341>,
      <333, 342, 343>,
      <333, 343, 334>,
      <344, 345, 335>,
      <344, 335, 334>,
      <344, 334, 346>,
      <344, 346, 347>,
      <344, 348, 349>,
      <344, 349, 350>,
      <344, 351, 352>,
      <344, 352, 345>,
      <353, 354, 335>,
      <353, 335, 345>,
      <353, 345, 355>,
      <353, 355, 356>,
      <353, 357, 358>,
      <353, 358, 359>,
      <353, 360, 361>,
      <353, 361, 354>,
      <362, 336, 335>,
      <362, 335, 354>,
      <362, 354, 363>,
      <362, 363, 364>,
      <362, 365, 366>,
      <362, 366, 367>,
      <362, 368, 369>,
      <362, 369, 336>,
      <370, 371, 372>,
      <370, 372, 373>,
      <370, 373, 374>,
      <370, 374, 375>,
      <370, 376, 377>,
      <370, 377, 378>,
      <370, 379, 380>,
      <370, 380, 371>,
      <381, 382, 372>,
      <381, 372, 371>,
      <381, 371, 383>,
      <381, 383, 384>,
      <381, 385, 386>,
      <381, 386, 387>,
      <381, 388, 389>,
      <381, 389, 382>,
      <390, 391, 372>,
      <390, 372, 382>,
      <390, 382, 392>,
      <390, 392, 393>,
      <390, 394, 395>,
      <390, 395, 396>,
      <390, 396, 397>,
      <390, 397, 391>,
      <398, 373, 372>,
      <398, 372, 391>,
      <398, 391, 397>,
      <398, 397, 399>,
      <398, 399, 400>,
      <398, 400, 401>,
      <398, 402, 403>,
      <398, 403, 373>,
      <404, 405, 406>,
      <404, 406, 407>,
      <404, 407, 408>,
      <404, 408, 409>,
      <404, 410, 411>,
      <404, 411, 412>,
      <404, 413, 414>,
      <404, 414, 405>,
      <415, 416, 406>,
      <415, 406, 405>,
      <415, 405, 417>,
      <415, 417, 418>,
      <415, 419, 420>,
      <415, 420, 421>,
      <415, 422, 423>,
      <415, 423, 416>,
      <424, 425, 406>,
      <424, 406, 416>,
      <424, 416, 426>,
      <424, 426, 427>,
      <424, 428, 429>,
      <424, 429, 430>,
      <424, 430, 431>,
      <424, 431, 425>,
      <432, 407, 406>,
      <432, 406, 425>,
      <432, 425, 431>,
      <432, 431, 433>,
      <432, 433, 434>,
      <432, 434, 435>,
      <432, 436, 437>,
      <432, 437, 407>,
      <438, 439, 440>,
      <438, 440, 441>,
      <438, 441, 442>,
      <438, 442, 443>,
      <438, 444, 445>,
      <438, 445, 446>,
      <438, 447, 448>,
      <438, 448, 439>,
      <449, 450, 440>,
      <449, 440, 439>,
      <449, 439, 451>,
      <449, 451, 452>,
      <449, 453, 454>,
      <449, 454, 455>,
      <449, 456, 457>,
      <449, 457, 450>,
      <458, 459, 440>,
      <458, 440, 450>,
      <458, 450, 460>,
      <458, 460, 461>,
      <458, 462, 463>,
      <458, 463, 464>,
      <458, 464, 465>,
      <458, 465, 459>,
      <466, 441, 440>,
      <466, 440, 459>,
      <466, 459, 465>,
      <466, 465, 467>,
      <466, 467, 468>,
      <466, 468, 469>,
      <466, 470, 471>,
      <466, 471, 441>,
      <472, 473, 474>,
      <472, 474, 475>,
      <472, 475, 476>,
      <472, 476, 477>,
      <472, 478, 479>,
      <472, 479, 399>,
      <472, 399, 397>,
      <472, 397, 473>,
      <480, 481, 474>,
      <480, 474, 473>,
      <480, 473, 397>,
      <480, 397, 396>,
      <480, 396, 482>,
      <480, 482, 483>,
      <480, 484, 485>,
      <480, 485, 481>,
      <486, 487, 474>,
      <486, 474, 481>,
      <486, 481, 488>,
      <486, 488, 489>,
      <486, 490, 491>,
      <486, 491, 492>,
      <486, 492, 493>,
      <486, 493, 487>,
      <494, 475, 474>,
      <494, 474, 487>,
      <494, 487, 493>,
      <494, 493, 495>,
      <494, 495, 496>,
      <494, 496, 497>,
      <494, 498, 499>,
      <494, 499, 475>,
      <500, 501, 502>,
      <500, 502, 503>,
      <500, 503, 504>,
      <500, 504, 505>,
      <500, 506, 507>,
      <500, 507, 433>,
      <500, 433, 431>,
      <500, 431, 501>,
      <508, 509, 502>,
      <508, 502, 501>,
      <508, 501, 431>,
      <508, 431, 430>,
      <508, 430, 510>,
      <508, 510, 511>,
      <508, 512, 513>,
      <508, 513, 509>,
      <514, 515, 502>,
      <514, 502, 509>,
      <514, 509, 516>,
      <514, 516, 517>,
      <514, 518, 519>,
      <514, 519, 520>,
      <514, 520, 521>,
      <514, 521, 515>,
      <522, 503, 502>,
      <522, 502, 515>,
      <522, 515, 521>,
      <522, 521, 523>,
      <522, 523, 524>,
      <522, 524, 525>,
      <522, 526, 527>,
      <522, 527, 503>,
      <528, 529, 530>,
      <528, 530, 531>,
      <528, 531, 532>,
      <528, 532, 533>,
      <528, 534, 535>,
      <528, 535, 467>,
      <528, 467, 465>,
      <528, 465, 529>,
      <536, 537, 530>,
      <536, 530, 529>,
      <536, 529, 465>,
      <536, 465, 464>,
      <536, 464, 538>,
      <536, 538, 539>,
      <536, 540, 541>,
      <536, 541, 537>,
      <542, 543, 530>,
      <542, 530, 537>,
      <542, 537, 544>,
      <542, 544, 545>,
      <542, 546, 547>,
      <542, 547, 548>,
      <542, 548, 549>,
      <542, 549, 543>,
      <550, 531, 530>,
      <550, 530, 543>,
      <550, 543, 549>,
      <550, 549, 551>,
      <550, 551, 552>,
      <550, 552, 553>,
      <550, 554, 555>,
      <550, 555, 531>,
      <556, 557, 558>,
      <556, 558, 559>,
      <556, 559, 560>,
      <556, 560, 561>,
      <556, 562, 563>,
      <556, 563, 495>,
      <556, 495, 493>,
      <556, 493, 557>,
      <564, 565, 558>,
      <564, 558, 557>,
      <564, 557, 493>,
      <564, 493, 492>,
      <564, 492, 566>,
      <564, 566, 567>,
      <564, 568, 569>,
      <564, 569, 565>,
      <570, 571, 558>,
      <570, 558, 565>,
      <570, 565, 572>,
      <570, 572, 573>,
      <570, 574, 575>,
      <570, 575, 576>,
      <570, 577, 578>,
      <570, 578, 571>,
      <579, 559, 558>,
      <579, 558, 571>,
      <579, 571, 580>,
      <579, 580, 581>,
      <579, 582, 583>,
      <579, 583, 584>,
      <579, 585, 586>,
      <579, 586, 559>,
      <587, 588, 589>,
      <587, 589, 590>,
      <587, 590, 591>,
      <587, 591, 592>,
      <587, 593, 594>,
      <587, 594, 523>,
      <587, 523, 521>,
      <587, 521, 588>,
      <595, 596, 589>,
      <595, 589, 588>,
      <595, 588, 521>,
      <595, 521, 520>,
      <595, 520, 597>,
      <595, 597, 598>,
      <595, 599, 600>,
      <595, 600, 596>,
      <601, 602, 589>,
      <601, 589, 596>,
      <601, 596, 603>,
      <601, 603, 604>,
      <601, 605, 606>,
      <601, 606, 607>,
      <601, 608, 609>,
      <601, 609, 602>,
      <610, 590, 589>,
      <610, 589, 602>,
      <610, 602, 611>,
      <610, 611, 612>,
      <610, 613, 614>,
      <610, 614, 615>,
      <610, 616, 617>,
      <610, 617, 590>,
      <618, 619, 620>,
      <618, 620, 621>,
      <618, 621, 622>,
      <618, 622, 623>,
      <618, 624, 625>,
      <618, 625, 551>,
      <618, 551, 549>,
      <618, 549, 619>,
      <626, 627, 620>,
      <626, 620, 619>,
      <626, 619, 549>,
      <626, 549, 548>,
      <626, 548, 628>,
      <626, 628, 629>,
      <626, 630, 631>,
      <626, 631, 627>,
      <632, 633, 620>,
      <632, 620, 627>,
      <632, 627, 634>,
      <632, 634, 635>,
      <632, 636, 637>,
      <632, 637, 638>,
      <632, 639, 640>,
      <632, 640, 633>,
      <641, 621, 620>,
      <641, 620, 633>,
      <641, 633, 642>,
      <641, 642, 643>,
      <641, 644, 645>,
      <641, 645, 646>,
      <641, 647, 648>,
      <641, 648, 621>,
      <649, 650, 651>,
      <649, 651, 652>,
      <649, 652, 653>,
      <649, 653, 654>,
      <649, 655, 656>,
      <649, 656, 657>,
      <649, 658, 659>,
      <649, 659, 650>,
      <660, 661, 651>,
      <660, 651, 650>,
      <660, 650, 662>,
      <660, 662, 663>,
      <660, 664, 665>,
      <660, 665, 666>,
      <660, 667, 668>,
      <660, 668, 661>,
      <669, 670, 651>,
      <669, 651, 661>,
      <669, 661, 671>,
      <669, 671, 672>,
      <669, 673, 674>,
      <669, 674, 675>,
      <669, 676, 677>,
      <669, 677, 670>,
      <678, 652, 651>,
      <678, 651, 670>,
      <678, 670, 679>,
      <678, 679, 680>,
      <678, 681, 682>,
      <678, 682, 683>,
      <678, 684, 685>,
      <678, 685, 652>,
      <686, 687, 688>,
      <686, 688, 689>,
      <686, 689, 690>,
      <686, 690, 691>,
      <686, 692, 693>,
      <686, 693, 694>,
      <686, 695, 696>,
      <686, 696, 687>,
      <697, 698, 688>,
      <697, 688, 687>,
      <697, 687, 699>,
      <697, 699, 700>,
      <697, 701, 702>,
      <697, 702, 703>,
      <697, 704, 705>,
      <697, 705, 698>,
      <706, 707, 688>,
      <706, 688, 698>,
      <706, 698, 708>,
      <706, 708, 709>,
      <706, 710, 711>,
      <706, 711, 712>,
      <706, 713, 714>,
      <706, 714, 707>,
      <715, 689, 688>,
      <715, 688, 707>,
      <715, 707, 716>,
      <715, 716, 717>,
      <715, 718, 719>,
      <715, 719, 720>,
      <715, 721, 722>,
      <715, 722, 689>,
      <723, 724, 725>,
      <723, 725, 726>,
      <723, 726, 727>,
      <723, 727, 728>,
      <723, 729, 730>,
      <723, 730, 731>,
      <723, 732, 733>,
      <723, 733, 724>,
      <734, 735, 725>,
      <734, 725, 724>,
      <734, 724, 736>,
      <734, 736, 737>,
      <734, 738, 739>,
      <734, 739, 740>,
      <734, 741, 742>,
      <734, 742, 735>,
      <743, 744, 725>,
      <743, 725, 735>,
      <743, 735, 745>,
      <743, 745, 746>,
      <743, 747, 748>,
      <743, 748, 749>,
      <743, 750, 751>,
      <743, 751, 744>,
      <752, 726, 725>,
      <752, 725, 744>,
      <752, 744, 753>,
      <752, 753, 754>,
      <752, 755, 756>,
      <752, 756, 757>,
      <752, 758, 759>,
      <752, 759, 726>,
      <760, 761, 762>,
      <760, 762, 763>,
      <760, 763, 764>,
      <760, 764, 765>,
      <760, 766, 767>,
      <760, 767, 768>,
      <760, 769, 770>,
      <760, 770, 761>,
      <771, 772, 762>,
      <771, 762, 761>,
      <771, 761, 773>,
      <771, 773, 774>,
      <771, 775, 776>,
      <771, 776, 777>,
      <771, 778, 779>,
      <771, 779, 772>,
      <780, 781, 762>,
      <780, 762, 772>,
      <780, 772, 782>,
      <780, 782, 783>,
      <780, 784, 785>,
      <780, 785, 786>,
      <780, 787, 788>,
      <780, 788, 781>,
      <789, 763, 762>,
      <789, 762, 781>,
      <789, 781, 790>,
      <789, 790, 791>,
      <789, 792, 793>,
      <789, 793, 794>,
      <789, 795, 796>,
      <789, 796, 763>,
      <797, 798, 799>,
      <797, 799, 800>,
      <797, 800, 801>,
      <797, 801, 802>,
      <797, 803, 804>,
      <797, 804, 805>,
      <797, 806, 807>,
      <797, 807, 798>,
      <808, 809, 799>,
      <808, 799, 798>,
      <808, 798, 810>,
      <808, 810, 811>,
      <808, 812, 813>,
      <808, 813, 814>,
      <808, 815, 816>,
      <808, 816, 809>,
      <817, 818, 799>,
      <817, 799, 809>,
      <817, 809, 819>,
      <817, 819, 820>,
      <817, 821, 822>,
      <817, 822, 823>,
      <817, 824, 825>,
      <817, 825, 818>,
      <826, 800, 799>,
      <826, 799, 818>,
      <826, 818, 827>,
      <826, 827, 828>,
      <826, 829, 830>,
      <826, 830, 831>,
      <826, 832, 833>,
      <826, 833, 800>,
      <834, 835, 836>,
      <834, 836, 837>,
      <834, 837, 838>,
      <834, 838, 839>,
      <834, 840, 841>,
      <834, 841, 842>,
      <834, 843, 844>,
      <834, 844, 835>,
      <845, 846, 836>,
      <845, 836, 835>,
      <845, 835, 847>,
      <845, 847, 848>,
      <845, 849, 850>,
      <845, 850, 851>,
      <845, 852, 853>,
      <845, 853, 846>,
      <854, 855, 836>,
      <854, 836, 846>,
      <854, 846, 856>,
      <854, 856, 857>,
      <854, 858, 859>,
      <854, 859, 860>,
      <854, 861, 862>,
      <854, 862, 855>,
      <863, 837, 836>,
      <863, 836, 855>,
      <863, 855, 864>,
      <863, 864, 865>,
      <863, 866, 867>,
      <863, 867, 868>,
      <863, 869, 870>,
      <863, 870, 837>,
      <871, 872, 873>,
      <871, 873, 874>,
      <871, 874, 875>,
      <871, 875, 876>,
      <871, 877, 878>,
      <871, 878, 879>,
      <871, 880, 881>,
      <871, 881, 872>,
      <882, 883, 873>,
      <882, 873, 872>,
      <882, 872, 884>,
      <882, 884, 885>,
      <882, 886, 887>,
      <882, 887, 888>,
      <882, 889, 890>,
      <882, 890, 883>,
      <891, 892, 873>,
      <891, 873, 883>,
      <891, 883, 893>,
      <891, 893, 894>,
      <891, 895, 896>,
      <891, 896, 897>,
      <891, 898, 899>,
      <891, 899, 892>,
      <900, 874, 873>,
      <900, 873, 892>,
      <900, 892, 901>,
      <900, 901, 902>,
      <900, 903, 904>,
      <900, 904, 905>,
      <900, 906, 907>,
      <900, 907, 874>,
      <908, 909, 910>,
      <908, 910, 911>,
      <908, 911, 912>,
      <908, 912, 913>,
      <908, 914, 915>,
      <908, 915, 916>,
      <908, 917, 918>,
      <908, 918, 909>,
      <919, 920, 910>,
      <919, 910, 909>,
      <919, 909, 921>,
      <919, 921, 922>,
      <919, 923, 924>,
      <919, 924, 925>,
      <919, 926, 927>,
      <919, 927, 920>,
      <928, 929, 910>,
      <928, 910, 920>,
      <928, 920, 930>,
      <928, 930, 931>,
      <928, 932, 933>,
      <928, 933, 934>,
      <928, 935, 936>,
      <928, 936, 929>,
      <937, 911, 910>,
      <937, 910, 929>,
      <937, 929, 938>,
      <937, 938, 939>,
      <937, 940, 941>,
      <937, 941, 942>,
      <937, 943, 944>,
      <937, 944, 911>,
      <945, 946, 947>,
      <945, 947, 948>,
      <945, 948, 949>,
      <945, 949, 950>,
      <945, 951, 952>,
      <945, 952, 953>,
      <945, 954, 955>,
      <945, 955, 946>,
      <956, 957, 947>,
      <956, 947, 946>,
      <956, 946, 958>,
      <956, 958, 959>,
      <956, 960, 961>,
      <956, 961, 962>,
      <956, 963, 964>,
      <956, 964, 957>,
      <965, 966, 947>,
      <965, 947, 957>,
      <965, 957, 967>,
      <965, 967, 968>,
      <965, 969, 970>,
      <965, 970, 971>,
      <965, 972, 973>,
      <965, 973, 966>,
      <974, 948, 947>,
      <974, 947, 966>,
      <974, 966, 975>,
      <974, 975, 976>,
      <974, 977, 978>,
      <974, 978, 979>,
      <974, 980, 981>,
      <974, 981, 948>,
      <982, 983, 984>,
      <982, 984, 985>,
      <982, 985, 986>,
      <982, 986, 987>,
      <982, 988, 989>,
      <982, 989, 990>,
      <982, 991, 992>,
      <982, 992, 983>,
      <993, 994, 984>,
      <993, 984, 983>,
      <993, 983, 995>,
      <993, 995, 996>,
      <993, 997, 998>,
      <993, 998, 999>,
      <993, 1000, 1001>,
      <993, 1001, 994>,
      <1002, 1003, 984>,
      <1002, 984, 994>,
      <1002, 994, 1004>,
      <1002, 1004, 1005>,
      <1002, 1006, 1007>,
      <1002, 1007, 1008>,
      <1002, 1009, 1010>,
      <1002, 1010, 1003>,
      <1011, 985, 984>,
      <1011, 984, 1003>,
      <1011, 1003, 1012>,
      <1011, 1012, 1013>,
      <1011, 1014, 1015>,
      <1011, 1015, 1016>,
      <1011, 1017, 1018>,
      <1011, 1018, 985>,
      <1019, 1020, 1021>,
      <1019, 1021, 1022>,
      <1019, 1022, 1023>,
      <1019, 1023, 1024>,
      <1019, 1025, 1026>,
      <1019, 1026, 1027>,
      <1019, 1028, 1029>,
      <1019, 1029, 1020>,
      <1030, 1031, 1021>,
      <1030, 1021, 1020>,
      <1030, 1020, 1032>,
      <1030, 1032, 1033>,
      <1030, 1034, 1035>,
      <1030, 1035, 1036>,
      <1030, 1037, 1038>,
      <1030, 1038, 1031>,
      <1039, 1040, 1021>,
      <1039, 1021, 1031>,
      <1039, 1031, 1041>,
      <1039, 1041, 1042>,
      <1039, 1043, 1044>,
      <1039, 1044, 1045>,
      <1039, 1046, 1047>,
      <1039, 1047, 1040>,
      <1048, 1022, 1021>,
      <1048, 1021, 1040>,
      <1048, 1040, 1049>,
      <1048, 1049, 1050>,
      <1048, 1051, 1052>,
      <1048, 1052, 1053>,
      <1048, 1054, 1055>,
      <1048, 1055, 1022>,
      <1056, 1057, 1058>,
      <1056, 1058, 1059>,
      <1056, 1059, 1060>,
      <1056, 1060, 1061>,
      <1056, 1062, 1063>,
      <1056, 1063, 1064>,
      <1056, 1065, 1066>,
      <1056, 1066, 1057>,
      <1067, 1068, 1058>,
      <1067, 1058, 1057>,
      <1067, 1057, 1069>,
      <1067, 1069, 1070>,
      <1067, 1071, 1072>,
      <1067, 1072, 1073>,
      <1067, 1074, 1075>,
      <1067, 1075, 1068>,
      <1076, 1077, 1058>,
      <1076, 1058, 1068>,
      <1076, 1068, 1078>,
      <1076, 1078, 1079>,
      <1076, 1080, 1081>,
      <1076, 1081, 1082>,
      <1076, 1083, 1084>,
      <1076, 1084, 1077>,
      <1085, 1059, 1058>,
      <1085, 1058, 1077>,
      <1085, 1077, 1086>,
      <1085, 1086, 1087>,
      <1085, 1088, 1089>,
      <1085, 1089, 1090>,
      <1085, 1091, 1092>,
      <1085, 1092, 1059>,
      <1093, 1094, 1095>,
      <1093, 1095, 1096>,
      <1093, 1096, 1097>,
      <1093, 1097, 1098>,
      <1093, 1099, 1100>,
      <1093, 1100, 1101>,
      <1093, 1101, 1102>,
      <1093, 1102, 1094>,
      <1103, 1104, 1095>,
      <1103, 1095, 1094>,
      <1103, 1094, 1102>,
      <1103, 1102, 1105>,
      <1103, 1105, 1106>,
      <1103, 1106, 1107>,
      <1103, 1108, 1109>,
      <1103, 1109, 1104>,
      <1110, 1111, 1095>,
      <1110, 1095, 1104>,
      <1110, 1104, 1112>,
      <1110, 1112, 1113>,
      <1110, 1114, 1115>,
      <1110, 1115, 1116>,
      <1110, 1117, 1118>,
      <1110, 1118, 1111>,
      <1119, 1096, 1095>,
      <1119, 1095, 1111>,
      <1119, 1111, 1120>,
      <1119, 1120, 1121>,
      <1119, 1122, 1123>,
      <1119, 1123, 1124>,
      <1119, 1125, 1126>,
      <1119, 1126, 1096>,
      <1127, 1128, 1129>,
      <1127, 1129, 1130>,
      <1127, 1130, 1102>,
      <1127, 1102, 1101>,
      <1127, 1101, 1131>,
      <1127, 1131, 1132>,
      <1127, 1133, 1134>,
      <1127, 1134, 1128>,
      <1135, 1136, 1129>,
      <1135, 1129, 1128>,
      <1135, 1128, 1137>,
      <1135, 1137, 1138>,
      <1135, 1139, 1140>,
      <1135, 1140, 1141>,
      <1135, 1142, 1143>,
      <1135, 1143, 1136>,
      <1144, 1145, 1129>,
      <1144, 1129, 1136>,
      <1144, 1136, 1146>,
      <1144, 1146, 1147>,
      <1144, 1148, 1149>,
      <1144, 1149, 1150>,
      <1144, 1151, 1152>,
      <1144, 1152, 1145>,
      <1153, 1130, 1129>,
      <1153, 1129, 1145>,
      <1153, 1145, 1154>,
      <1153, 1154, 1155>,
      <1153, 1156, 1157>,
      <1153, 1157, 1105>,
      <1153, 1105, 1102>,
      <1153, 1102, 1130>
    }
    uv_indices {
      1056,   // from 0 triangles and 528 quads
      <569, 577, 570>,
      <569, 570, 574>      <569, 574, 571>,
      <569, 571, 575>      <569, 575, 572>,
      <569, 572, 576>      <569, 576, 573>,
      <569, 573, 577>      <578, 586, 579>,
      <578, 579, 583>      <578, 583, 580>,
      <578, 580, 584>      <578, 584, 581>,
      <578, 581, 585>      <578, 585, 582>,
      <578, 582, 586>      <587, 595, 588>,
      <587, 588, 592>      <587, 592, 589>,
      <587, 589, 593>      <587, 593, 590>,
      <587, 590, 594>      <587, 594, 591>,
      <587, 591, 595>      <596, 604, 597>,
      <596, 597, 601>      <596, 601, 598>,
      <596, 598, 602>      <596, 602, 599>,
      <596, 599, 603>      <596, 603, 600>,
      <596, 600, 604>      <605, 613, 606>,
      <605, 606, 610>      <605, 610, 607>,
      <605, 607, 611>      <605, 611, 608>,
      <605, 608, 612>      <605, 612, 609>,
      <605, 609, 613>      <614, 622, 615>,
      <614, 615, 619>      <614, 619, 616>,
      <614, 616, 620>      <614, 620, 617>,
      <614, 617, 621>      <614, 621, 618>,
      <614, 618, 622>      <623, 631, 624>,
      <623, 624, 628>      <623, 628, 625>,
      <623, 625, 629>      <623, 629, 626>,
      <623, 626, 630>      <623, 630, 627>,
      <623, 627, 631>      <632, 640, 633>,
      <632, 633, 637>      <632, 637, 634>,
      <632, 634, 638>      <632, 638, 635>,
      <632, 635, 639>      <632, 639, 636>,
      <632, 636, 640>      <641, 649, 642>,
      <641, 642, 646>      <641, 646, 643>,
      <641, 643, 647>      <641, 647, 644>,
      <641, 644, 648>      <641, 648, 645>,
      <641, 645, 649>      <650, 658, 651>,
      <650, 651, 655>      <650, 655, 652>,
      <650, 652, 656>      <650, 656, 653>,
      <650, 653, 657>      <650, 657, 654>,
      <650, 654, 658>      <659, 667, 660>,
      <659, 660, 664>      <659, 664, 661>,
      <659, 661, 665>      <659, 665, 662>,
      <659, 662, 666>      <659, 666, 663>,
      <659, 663, 667>      <668, 676, 669>,
      <668, 669, 673>      <668, 673, 670>,
      <668, 670, 674>      <668, 674, 671>,
      <668, 671, 675>      <668, 675, 672>,
      <668, 672, 676>      <677, 685, 678>,
      <677, 678, 682>      <677, 682, 679>,
      <677, 679, 683>      <677, 683, 680>,
      <677, 680, 684>      <677, 684, 681>,
      <677, 681, 685>      <686, 694, 687>,
      <686, 687, 691>      <686, 691, 688>,
      <686, 688, 692>      <686, 692, 689>,
      <686, 689, 693>      <686, 693, 690>,
      <686, 690, 694>      <695, 703, 696>,
      <695, 696, 700>      <695, 700, 697>,
      <695, 697, 701>      <695, 701, 698>,
      <695, 698, 702>      <695, 702, 699>,
      <695, 699, 703>      <704, 712, 705>,
      <704, 705, 709>      <704, 709, 706>,
      <704, 706, 710>      <704, 710, 707>,
      <704, 707, 711>      <704, 711, 708>,
      <704, 708, 712>      <713, 721, 714>,
      <713, 714, 718>      <713, 718, 715>,
      <713, 715, 719>      <713, 719, 716>,
      <713, 716, 720>      <713, 720, 717>,
      <713, 717, 721>      <722, 730, 723>,
      <722, 723, 727>      <722, 727, 724>,
      <722, 724, 728>      <722, 728, 725>,
      <722, 725, 729>      <722, 729, 726>,
      <722, 726, 730>      <731, 739, 732>,
      <731, 732, 736>      <731, 736, 733>,
      <731, 733, 737>      <731, 737, 734>,
      <731, 734, 738>      <731, 738, 735>,
      <731, 735, 739>      <740, 748, 741>,
      <740, 741, 745>      <740, 745, 742>,
      <740, 742, 746>      <740, 746, 743>,
      <740, 743, 747>      <740, 747, 744>,
      <740, 744, 748>      <749, 757, 750>,
      <749, 750, 754>      <749, 754, 751>,
      <749, 751, 755>      <749, 755, 752>,
      <749, 752, 756>      <749, 756, 753>,
      <749, 753, 757>      <758, 766, 759>,
      <758, 759, 763>      <758, 763, 760>,
      <758, 760, 764>      <758, 764, 761>,
      <758, 761, 765>      <758, 765, 762>,
      <758, 762, 766>      <767, 775, 768>,
      <767, 768, 772>      <767, 772, 769>,
      <767, 769, 773>      <767, 773, 770>,
      <767, 770, 774>      <767, 774, 771>,
      <767, 771, 775>      <776, 784, 777>,
      <776, 777, 781>      <776, 781, 778>,
      <776, 778, 782>      <776, 782, 779>,
      <776, 779, 783>      <776, 783, 780>,
      <776, 780, 784>      <785, 793, 786>,
      <785, 786, 790>      <785, 790, 787>,
      <785, 787, 791>      <785, 791, 788>,
      <785, 788, 792>      <785, 792, 789>,
      <785, 789, 793>      <794, 802, 795>,
      <794, 795, 799>      <794, 799, 796>,
      <794, 796, 800>      <794, 800, 797>,
      <794, 797, 801>      <794, 801, 798>,
      <794, 798, 802>      <803, 811, 804>,
      <803, 804, 808>      <803, 808, 805>,
      <803, 805, 809>      <803, 809, 806>,
      <803, 806, 810>      <803, 810, 807>,
      <803, 807, 811>      <812, 820, 813>,
      <812, 813, 817>      <812, 817, 814>,
      <812, 814, 818>      <812, 818, 815>,
      <812, 815, 819>      <812, 819, 816>,
      <812, 816, 820>      <821, 829, 822>,
      <821, 822, 826>      <821, 826, 823>,
      <821, 823, 827>      <821, 827, 824>,
      <821, 824, 828>      <821, 828, 825>,
      <821, 825, 829>      <830, 838, 831>,
      <830, 831, 835>      <830, 835, 832>,
      <830, 832, 836>      <830, 836, 833>,
      <830, 833, 837>      <830, 837, 834>,
      <830, 834, 838>      <839, 847, 840>,
      <839, 840, 844>      <839, 844, 841>,
      <839, 841, 845>      <839, 845, 842>,
      <839, 842, 846>      <839, 846, 843>,
      <839, 843, 847>      <848, 856, 849>,
      <848, 849, 853>      <848, 853, 850>,
      <848, 850, 854>      <848, 854, 851>,
      <848, 851, 855>      <848, 855, 852>,
      <848, 852, 856>      <857, 865, 858>,
      <857, 858, 862>      <857, 862, 859>,
      <857, 859, 863>      <857, 863, 860>,
      <857, 860, 864>      <857, 864, 861>,
      <857, 861, 865>      <866, 874, 867>,
      <866, 867, 871>      <866, 871, 868>,
      <866, 868, 872>      <866, 872, 869>,
      <866, 869, 873>      <866, 873, 870>,
      <866, 870, 874>      <875, 883, 876>,
      <875, 876, 880>      <875, 880, 877>,
      <875, 877, 881>      <875, 881, 878>,
      <875, 878, 882>      <875, 882, 879>,
      <875, 879, 883>      <884, 892, 885>,
      <884, 885, 889>      <884, 889, 886>,
      <884, 886, 890>      <884, 890, 887>,
      <884, 887, 891>      <884, 891, 888>,
      <884, 888, 892>      <893, 901, 894>,
      <893, 894, 898>      <893, 898, 895>,
      <893, 895, 899>      <893, 899, 896>,
      <893, 896, 900>      <893, 900, 897>,
      <893, 897, 901>      <902, 910, 903>,
      <902, 903, 907>      <902, 907, 904>,
      <902, 904, 908>      <902, 908, 905>,
      <902, 905, 909>      <902, 909, 906>,
      <902, 906, 910>      <911, 919, 912>,
      <911, 912, 916>      <911, 916, 913>,
      <911, 913, 917>      <911, 917, 914>,
      <911, 914, 918>      <911, 918, 915>,
      <911, 915, 919>      <920, 928, 921>,
      <920, 921, 925>      <920, 925, 922>,
      <920, 922, 926>      <920, 926, 923>,
      <920, 923, 927>      <920, 927, 924>,
      <920, 924, 928>      <929, 937, 930>,
      <929, 930, 934>      <929, 934, 931>,
      <929, 931, 935>      <929, 935, 932>,
      <929, 932, 936>      <929, 936, 933>,
      <929, 933, 937>      <938, 946, 939>,
      <938, 939, 943>      <938, 943, 940>,
      <938, 940, 944>      <938, 944, 941>,
      <938, 941, 945>      <938, 945, 942>,
      <938, 942, 946>      <947, 955, 948>,
      <947, 948, 952>      <947, 952, 949>,
      <947, 949, 953>      <947, 953, 950>,
      <947, 950, 954>      <947, 954, 951>,
      <947, 951, 955>      <956, 964, 957>,
      <956, 957, 961>      <956, 961, 958>,
      <956, 958, 962>      <956, 962, 959>,
      <956, 959, 963>      <956, 963, 960>,
      <956, 960, 964>      <965, 973, 966>,
      <965, 966, 970>      <965, 970, 967>,
      <965, 967, 971>      <965, 971, 968>,
      <965, 968, 972>      <965, 972, 969>,
      <965, 969, 973>      <974, 982, 975>,
      <974, 975, 979>      <974, 979, 976>,
      <974, 976, 980>      <974, 980, 977>,
      <974, 977, 981>      <974, 981, 978>,
      <974, 978, 982>      <983, 991, 984>,
      <983, 984, 988>      <983, 988, 985>,
      <983, 985, 989>      <983, 989, 986>,
      <983, 986, 990>      <983, 990, 987>,
      <983, 987, 991>      <992, 1000, 993>,
      <992, 993, 997>      <992, 997, 994>,
      <992, 994, 998>      <992, 998, 995>,
      <992, 995, 999>      <992, 999, 996>,
      <992, 996, 1000>      <1001, 1009, 1002>,
      <1001, 1002, 1006>      <1001, 1006, 1003>,
      <1001, 1003, 1007>      <1001, 1007, 1004>,
      <1001, 1004, 1008>      <1001, 1008, 1005>,
      <1001, 1005, 1009>      <1010, 1018, 1011>,
      <1010, 1011, 1015>      <1010, 1015, 1012>,
      <1010, 1012, 1016>      <1010, 1016, 1013>,
      <1010, 1013, 1017>      <1010, 1017, 1014>,
      <1010, 1014, 1018>      <1019, 1027, 1020>,
      <1019, 1020, 1024>      <1019, 1024, 1021>,
      <1019, 1021, 1025>      <1019, 1025, 1022>,
      <1019, 1022, 1026>      <1019, 1026, 1023>,
      <1019, 1023, 1027>      <1028, 1036, 1029>,
      <1028, 1029, 1033>      <1028, 1033, 1030>,
      <1028, 1030, 1034>      <1028, 1034, 1031>,
      <1028, 1031, 1035>      <1028, 1035, 1032>,
      <1028, 1032, 1036>      <1037, 1045, 1038>,
      <1037, 1038, 1042>      <1037, 1042, 1039>,
      <1037, 1039, 1043>      <1037, 1043, 1040>,
      <1037, 1040, 1044>      <1037, 1044, 1041>,
      <1037, 1041, 1045>      <1046, 1054, 1047>,
      <1046, 1047, 1051>      <1046, 1051, 1048>,
      <1046, 1048, 1052>      <1046, 1052, 1049>,
      <1046, 1049, 1053>      <1046, 1053, 1050>,
      <1046, 1050, 1054>      <1055, 1063, 1056>,
      <1055, 1056, 1060>      <1055, 1060, 1057>,
      <1055, 1057, 1061>      <1055, 1061, 1058>,
      <1055, 1058, 1062>      <1055, 1062, 1059>,
      <1055, 1059, 1063>      <1064, 1072, 1065>,
      <1064, 1065, 1069>      <1064, 1069, 1066>,
      <1064, 1066, 1070>      <1064, 1070, 1067>,
      <1064, 1067, 1071>      <1064, 1071, 1068>,
      <1064, 1068, 1072>      <1073, 1081, 1074>,
      <1073, 1074, 1078>      <1073, 1078, 1075>,
      <1073, 1075, 1079>      <1073, 1079, 1076>,
      <1073, 1076, 1080>      <1073, 1080, 1077>,
      <1073, 1077, 1081>      <1082, 1090, 1083>,
      <1082, 1083, 1087>      <1082, 1087, 1084>,
      <1082, 1084, 1088>      <1082, 1088, 1085>,
      <1082, 1085, 1089>      <1082, 1089, 1086>,
      <1082, 1086, 1090>      <1091, 1099, 1092>,
      <1091, 1092, 1096>      <1091, 1096, 1093>,
      <1091, 1093, 1097>      <1091, 1097, 1094>,
      <1091, 1094, 1098>      <1091, 1098, 1095>,
      <1091, 1095, 1099>      <1100, 1108, 1101>,
      <1100, 1101, 1105>      <1100, 1105, 1102>,
      <1100, 1102, 1106>      <1100, 1106, 1103>,
      <1100, 1103, 1107>      <1100, 1107, 1104>,
      <1100, 1104, 1108>      <1109, 1117, 1110>,
      <1109, 1110, 1114>      <1109, 1114, 1111>,
      <1109, 1111, 1115>      <1109, 1115, 1112>,
      <1109, 1112, 1116>      <1109, 1116, 1113>,
      <1109, 1113, 1117>      <1118, 1126, 1119>,
      <1118, 1119, 1123>      <1118, 1123, 1120>,
      <1118, 1120, 1124>      <1118, 1124, 1121>,
      <1118, 1121, 1125>      <1118, 1125, 1122>,
      <1118, 1122, 1126>      <1127, 1135, 1128>,
      <1127, 1128, 1132>      <1127, 1132, 1129>,
      <1127, 1129, 1133>      <1127, 1133, 1130>,
      <1127, 1130, 1134>      <1127, 1134, 1131>,
      <1127, 1131, 1135>      <1136, 1144, 1137>,
      <1136, 1137, 1141>      <1136, 1141, 1138>,
      <1136, 1138, 1142>      <1136, 1142, 1139>,
      <1136, 1139, 1143>      <1136, 1143, 1140>,
      <1136, 1140, 1144>      <1145, 1153, 1146>,
      <1145, 1146, 1150>      <1145, 1150, 1147>,
      <1145, 1147, 1151>      <1145, 1151, 1148>,
      <1145, 1148, 1152>      <1145, 1152, 1149>,
      <1145, 1149, 1153>      <1154, 1162, 1155>,
      <1154, 1155, 1159>      <1154, 1159, 1156>,
      <1154, 1156, 1160>      <1154, 1160, 1157>,
      <1154, 1157, 1161>      <1154, 1161, 1158>,
      <1154, 1158, 1162>      <1163, 1171, 1164>,
      <1163, 1164, 1168>      <1163, 1168, 1165>,
      <1163, 1165, 1169>      <1163, 1169, 1166>,
      <1163, 1166, 1170>      <1163, 1170, 1167>,
      <1163, 1167, 1171>      <1172, 1180, 1173>,
      <1172, 1173, 1177>      <1172, 1177, 1174>,
      <1172, 1174, 1178>      <1172, 1178, 1175>,
      <1172, 1175, 1179>      <1172, 1179, 1176>,
      <1172, 1176, 1180>      <1181, 1189, 1182>,
      <1181, 1182, 1186>      <1181, 1186, 1183>,
      <1181, 1183, 1187>      <1181, 1187, 1184>,
      <1181, 1184, 1188>      <1181, 1188, 1185>,
      <1181, 1185, 1189>      <1190, 1198, 1191>,
      <1190, 1191, 1195>      <1190, 1195, 1192>,
      <1190, 1192, 1196>      <1190, 1196, 1193>,
      <1190, 1193, 1197>      <1190, 1197, 1194>,
      <1190, 1194, 1198>      <1199, 1207, 1200>,
      <1199, 1200, 1204>      <1199, 1204, 1201>,
      <1199, 1201, 1205>      <1199, 1205, 1202>,
      <1199, 1202, 1206>      <1199, 1206, 1203>,
      <1199, 1203, 1207>      <1208, 1216, 1209>,
      <1208, 1209, 1213>      <1208, 1213, 1210>,
      <1208, 1210, 1214>      <1208, 1214, 1211>,
      <1208, 1211, 1215>      <1208, 1215, 1212>,
      <1208, 1212, 1216>      <1217, 1225, 1218>,
      <1217, 1218, 1222>      <1217, 1222, 1219>,
      <1217, 1219, 1223>      <1217, 1223, 1220>,
      <1217, 1220, 1224>      <1217, 1224, 1221>,
      <1217, 1221, 1225>      <1226, 1234, 1227>,
      <1226, 1227, 1231>      <1226, 1231, 1228>,
      <1226, 1228, 1232>      <1226, 1232, 1229>,
      <1226, 1229, 1233>      <1226, 1233, 1230>,
      <1226, 1230, 1234>      <1235, 1243, 1236>,
      <1235, 1236, 1240>      <1235, 1240, 1237>,
      <1235, 1237, 1241>      <1235, 1241, 1238>,
      <1235, 1238, 1242>      <1235, 1242, 1239>,
      <1235, 1239, 1243>      <1244, 1252, 1245>,
      <1244, 1245, 1249>      <1244, 1249, 1246>,
      <1244, 1246, 1250>      <1244, 1250, 1247>,
      <1244, 1247, 1251>      <1244, 1251, 1248>,
      <1244, 1248, 1252>      <1253, 1261, 1254>,
      <1253, 1254, 1258>      <1253, 1258, 1255>,
      <1253, 1255, 1259>      <1253, 1259, 1256>,
      <1253, 1256, 1260>      <1253, 1260, 1257>,
      <1253, 1257, 1261>      <1262, 1270, 1263>,
      <1262, 1263, 1267>      <1262, 1267, 1264>,
      <1262, 1264, 1268>      <1262, 1268, 1265>,
      <1262, 1265, 1269>      <1262, 1269, 1266>,
      <1262, 1266, 1270>      <1271, 1279, 1272>,
      <1271, 1272, 1276>      <1271, 1276, 1273>,
      <1271, 1273, 1277>      <1271, 1277, 1274>,
      <1271, 1274, 1278>      <1271, 1278, 1275>,
      <1271, 1275, 1279>      <1280, 1288, 1281>,
      <1280, 1281, 1285>      <1280, 1285, 1282>,
      <1280, 1282, 1286>      <1280, 1286, 1283>,
      <1280, 1283, 1287>      <1280, 1287, 1284>,
      <1280, 1284, 1288>      <1289, 1297, 1290>,
      <1289, 1290, 1294>      <1289, 1294, 1291>,
      <1289, 1291, 1295>      <1289, 1295, 1292>,
      <1289, 1292, 1296>      <1289, 1296, 1293>,
      <1289, 1293, 1297>      <1298, 1306, 1299>,
      <1298, 1299, 1303>      <1298, 1303, 1300>,
      <1298, 1300, 1304>      <1298, 1304, 1301>,
      <1298, 1301, 1305>      <1298, 1305, 1302>,
      <1298, 1302, 1306>      <1307, 1315, 1308>,
      <1307, 1308, 1312>      <1307, 1312, 1309>,
      <1307, 1309, 1313>      <1307, 1313, 1310>,
      <1307, 1310, 1314>      <1307, 1314, 1311>,
      <1307, 1311, 1315>      <1316, 1324, 1317>,
      <1316, 1317, 1321>      <1316, 1321, 1318>,
      <1316, 1318, 1322>      <1316, 1322, 1319>,
      <1316, 1319, 1323>      <1316, 1323, 1320>,
      <1316, 1320, 1324>      <1325, 1333, 1326>,
      <1325, 1326, 1330>      <1325, 1330, 1327>,
      <1325, 1327, 1331>      <1325, 1331, 1328>,
      <1325, 1328, 1332>      <1325, 1332, 1329>,
      <1325, 1329, 1333>      <1334, 1342, 1335>,
      <1334, 1335, 1339>      <1334, 1339, 1336>,
      <1334, 1336, 1340>      <1334, 1340, 1337>,
      <1334, 1337, 1341>      <1334, 1341, 1338>,
      <1334, 1338, 1342>      <1343, 1351, 1344>,
      <1343, 1344, 1348>      <1343, 1348, 1345>,
      <1343, 1345, 1349>      <1343, 1349, 1346>,
      <1343, 1346, 1350>      <1343, 1350, 1347>,
      <1343, 1347, 1351>      <1352, 1360, 1353>,
      <1352, 1353, 1357>      <1352, 1357, 1354>,
      <1352, 1354, 1358>      <1352, 1358, 1355>,
      <1352, 1355, 1359>      <1352, 1359, 1356>,
      <1352, 1356, 1360>      <1361, 1369, 1362>,
      <1361, 1362, 1366>      <1361, 1366, 1363>,
      <1361, 1363, 1367>      <1361, 1367, 1364>,
      <1361, 1364, 1368>      <1361, 1368, 1365>,
      <1361, 1365, 1369>      <1370, 1378, 1371>,
      <1370, 1371, 1375>      <1370, 1375, 1372>,
      <1370, 1372, 1376>      <1370, 1376, 1373>,
      <1370, 1373, 1377>      <1370, 1377, 1374>,
      <1370, 1374, 1378>      <1379, 1387, 1380>,
      <1379, 1380, 1384>      <1379, 1384, 1381>,
      <1379, 1381, 1385>      <1379, 1385, 1382>,
      <1379, 1382, 1386>      <1379, 1386, 1383>,
      <1379, 1383, 1387>      <1388, 1396, 1389>,
      <1388, 1389, 1393>      <1388, 1393, 1390>,
      <1388, 1390, 1394>      <1388, 1394, 1391>,
      <1388, 1391, 1395>      <1388, 1395, 1392>,
      <1388, 1392, 1396>      <1397, 1405, 1398>,
      <1397, 1398, 1402>      <1397, 1402, 1399>,
      <1397, 1399, 1403>      <1397, 1403, 1400>,
      <1397, 1400, 1404>      <1397, 1404, 1401>,
      <1397, 1401, 1405>      <1406, 1414, 1407>,
      <1406, 1407, 1411>      <1406, 1411, 1408>,
      <1406, 1408, 1412>      <1406, 1412, 1409>,
      <1406, 1409, 1413>      <1406, 1413, 1410>,
      <1406, 1410, 1414>      <1415, 1423, 1416>,
      <1415, 1416, 1420>      <1415, 1420, 1417>,
      <1415, 1417, 1421>      <1415, 1421, 1418>,
      <1415, 1418, 1422>      <1415, 1422, 1419>,
      <1415, 1419, 1423>      <1424, 1432, 1425>,
      <1424, 1425, 1429>      <1424, 1429, 1426>,
      <1424, 1426, 1430>      <1424, 1430, 1427>,
      <1424, 1427, 1431>      <1424, 1431, 1428>,
      <1424, 1428, 1432>      <1433, 1441, 1434>,
      <1433, 1434, 1438>      <1433, 1438, 1435>,
      <1433, 1435, 1439>      <1433, 1439, 1436>,
      <1433, 1436, 1440>      <1433, 1440, 1437>,
      <1433, 1437, 1441>      <1442, 1450, 1443>,
      <1442, 1443, 1447>      <1442, 1447, 1444>,
      <1442, 1444, 1448>      <1442, 1448, 1445>,
      <1442, 1445, 1449>      <1442, 1449, 1446>,
      <1442, 1446, 1450>      <1451, 1459, 1452>,
      <1451, 1452, 1456>      <1451, 1456, 1453>,
      <1451, 1453, 1457>      <1451, 1457, 1454>,
      <1451, 1454, 1458>      <1451, 1458, 1455>,
      <1451, 1455, 1459>      <1460, 1468, 1461>,
      <1460, 1461, 1465>      <1460, 1465, 1462>,
      <1460, 1462, 1466>      <1460, 1466, 1463>,
      <1460, 1463, 1467>      <1460, 1467, 1464>,
      <1460, 1464, 1468>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>
    }
    translate  <0.0, 0.0, 0.0>
}

#declare Moulure_pleine = mesh2 {
    vertex_vectors {
      582,
      <-0.2535933, -0.0318764, 0.4233096>,
      <-0.2539571, 0.1385576, 0.4233096>,
      <-0.5029634, 0.1380753, 0.4233096>,
      <-0.5025915, -0.0323561, 0.4233096>,
      <-0.2537752, 0.0533406, 0.4233096>,
      <-0.3784603, 0.1383165, 0.4233096>,
      <-0.5027775, 0.0528596, 0.4233096>,
      <-0.3780924, -0.0321163, 0.4233096>,
      <-0.3782763, 0.0531001, 0.4233096>,
      <-0.5022195, -0.2027876, 0.4233096>,
      <-0.2532295, -0.2023105, 0.4233096>,
      <-0.5024055, -0.1175719, 0.4233096>,
      <-0.3777245, -0.2025490, 0.4233096>,
      <-0.2534114, -0.1170935, 0.4233096>,
      <-0.3779085, -0.1173327, 0.4233096>,
      <-0.0042396, -0.2018333, 0.4233096>,
      <-0.0045951, -0.0313967, 0.4233096>,
      <-0.1287346, -0.2020719, 0.4233096>,
      <-0.0044174, -0.1166150, 0.4233096>,
      <-0.1290942, -0.0316366, 0.4233096>,
      <-0.1289144, -0.1168542, 0.4233096>,
      <-0.0049507, 0.1390399, 0.4233096>,
      <-0.0047729, 0.0538216, 0.4233096>,
      <-0.1294539, 0.1387987, 0.4233096>,
      <-0.1292741, 0.0535811, 0.4233096>,
      <-0.5032764, 0.0661265, 0.0017507>,
      <-0.5034133, 0.1358382, 0.0017507>,
      <-0.5034264, 0.1357729, 0.0032739>,
      <-0.5032964, 0.0694345, 0.0032739>,
      <-0.5033449, 0.1009824, 0.0017507>,
      <-0.5034199, 0.1358055, 0.0025123>,
      <-0.5033614, 0.1026037, 0.0032739>,
      <-0.5032864, 0.0677805, 0.0025123>,
      <-0.5033531, 0.1017930, 0.0025123>,
      <-0.5031664, 0.0030961, 0.0032739>,
      <-0.5031395, -0.0035851, 0.0017507>,
      <-0.5032314, 0.0362653, 0.0032739>,
      <-0.5031530, -0.0002445, 0.0025123>,
      <-0.5032080, 0.0312707, 0.0017507>,
      <-0.5032197, 0.0337680, 0.0025123>,
      <-0.5031127, -0.0102663, 0.0002275>,
      <-0.5032564, 0.0628186, 0.0002275>,
      <-0.5031261, -0.0069257, 0.0009891>,
      <-0.5031845, 0.0262761, 0.0002275>,
      <-0.5032664, 0.0644726, 0.0009891>,
      <-0.5031963, 0.0287734, 0.0009891>,
      <-0.5034002, 0.1359035, 0.0002275>,
      <-0.5033283, 0.0993610, 0.0002275>,
      <-0.5034067, 0.1358708, 0.0009891>,
      <-0.5033366, 0.1001717, 0.0009891>,
      <-0.2536617, -0.0031059, 0.0017507>,
      <-0.2536744, 0.0035754, 0.0032739>,
      <-0.3784006, -0.0033455, 0.0017507>,
      <-0.3784204, 0.0033358, 0.0032739>,
      <-0.2536680, 0.0002348, 0.0025123>,
      <-0.3784105, -0.0000049, 0.0025123>,
      <-0.0041823, 0.0040547, 0.0032739>,
      <-0.0041839, -0.0026267, 0.0017507>,
      <-0.1289283, 0.0038151, 0.0032739>,
      <-0.0041831, 0.0007140, 0.0025123>,
      <-0.1289228, -0.0028663, 0.0017507>,
      <-0.1289256, 0.0004744, 0.0025123>,
      <-0.0041856, -0.0093080, 0.0002275>,
      <-0.2536491, -0.0097872, 0.0002275>,
      <-0.0041848, -0.0059673, 0.0009891>,
      <-0.1289173, -0.0095476, 0.0002275>,
      <-0.2536554, -0.0064465, 0.0009891>,
      <-0.1289201, -0.0062069, 0.0009891>,
      <-0.3783809, -0.0100268, 0.0002275>,
      <-0.3783908, -0.0066861, 0.0009891>,
      <-0.0043077, 0.0670891, 0.0017507>,
      <-0.0042993, 0.0703971, 0.0032739>,
      <-0.0042458, 0.0322312, 0.0017507>,
      <-0.0042408, 0.0372259, 0.0032739>,
      <-0.0043035, 0.0687431, 0.0025123>,
      <-0.0042433, 0.0347286, 0.0025123>,
      <-0.0044164, 0.1367396, 0.0032739>,
      <-0.0044315, 0.1368048, 0.0017507>,
      <-0.0043579, 0.1035684, 0.0032739>,
      <-0.0044239, 0.1367722, 0.0025123>,
      <-0.0043696, 0.1019469, 0.0017507>,
      <-0.0043637, 0.1027576, 0.0025123>,
      <-0.0044467, 0.1368701, 0.0002275>,
      <-0.0043161, 0.0637810, 0.0002275>,
      <-0.0044391, 0.1368374, 0.0009891>,
      <-0.0043814, 0.1003255, 0.0002275>,
      <-0.0043119, 0.0654350, 0.0009891>,
      <-0.0043755, 0.1011362, 0.0009891>,
      <-0.0042508, 0.0272365, 0.0002275>,
      <-0.0042483, 0.0297339, 0.0009891>,
      <-0.5032147, 0.0633422, 0.0186013>,
      <-0.5033728, 0.1360396, 0.0186013>,
      <-0.5032938, 0.0996909, 0.0186013>,
      <-0.5033865, 0.1359716, 0.0094144>,
      <-0.5032356, 0.0630804, 0.0094144>,
      <-0.5033110, 0.0995260, 0.0094144>,
      <-0.5030567, -0.0093552, 0.0186013>,
      <-0.5030847, -0.0098107, 0.0094144>,
      <-0.5031357, 0.0269935, 0.0186013>,
      <-0.5031601, 0.0266348, 0.0094144>,
      <-0.5030007, -0.0084440, 0.0369751>,
      <-0.5031730, 0.0638659, 0.0369751>,
      <-0.5030287, -0.0088996, 0.0277882>,
      <-0.5030869, 0.0277110, 0.0369751>,
      <-0.5031939, 0.0636041, 0.0277882>,
      <-0.5031113, 0.0273523, 0.0277882>,
      <-0.5033454, 0.1361758, 0.0369751>,
      <-0.5032592, 0.1000209, 0.0369751>,
      <-0.5033591, 0.1361077, 0.0277882>,
      <-0.5032765, 0.0998559, 0.0277882>,
      <-0.2536228, -0.0088761, 0.0186013>,
      <-0.3783397, -0.0091156, 0.0186013>,
      <-0.2536360, -0.0093316, 0.0094144>,
      <-0.3783603, -0.0095712, 0.0094144>,
      <-0.0041890, -0.0083971, 0.0186013>,
      <-0.0041873, -0.0088526, 0.0094144>,
      <-0.1289059, -0.0086366, 0.0186013>,
      <-0.1289116, -0.0090921, 0.0094144>,
      <-0.0041923, -0.0074862, 0.0369751>,
      <-0.2535965, -0.0079651, 0.0369751>,
      <-0.0041906, -0.0079416, 0.0277882>,
      <-0.1288944, -0.0077256, 0.0369751>,
      <-0.2536097, -0.0084206, 0.0277882>,
      <-0.1289002, -0.0081811, 0.0277882>,
      <-0.3782986, -0.0082045, 0.0369751>,
      <-0.3783192, -0.0086601, 0.0277882>,
      <-0.0043336, 0.0643045, 0.0186013>,
      <-0.0042613, 0.0279537, 0.0186013>,
      <-0.0043249, 0.0640428, 0.0094144>,
      <-0.0042561, 0.0275951, 0.0094144>,
      <-0.0044783, 0.1370061, 0.0186013>,
      <-0.0044625, 0.1369381, 0.0094144>,
      <-0.0044060, 0.1006553, 0.0186013>,
      <-0.0043937, 0.1004904, 0.0094144>,
      <-0.0045099, 0.1371421, 0.0369751>,
      <-0.0043511, 0.0648280, 0.0369751>,
      <-0.0044941, 0.1370741, 0.0277882>,
      <-0.0044305, 0.1009851, 0.0369751>,
      <-0.0043424, 0.0645662, 0.0277882>,
      <-0.0044182, 0.1008202, 0.0277882>,
      <-0.0042717, 0.0286709, 0.0369751>,
      <-0.0042665, 0.0283123, 0.0277882>,
      <-0.5031435, 0.0589779, 0.0388913>,
      <-0.5033260, 0.1362723, 0.0388913>,
      <-0.5032347, 0.0976251, 0.0388913>,
      <-0.5033357, 0.1362241, 0.0379332>,
      <-0.5031583, 0.0614219, 0.0379332>,
      <-0.5032470, 0.0988230, 0.0379332>,
      <-0.5029610, -0.0183166, 0.0388913>,
      <-0.5029808, -0.0133803, 0.0379332>,
      <-0.5030522, 0.0203306, 0.0388913>,
      <-0.5030696, 0.0240208, 0.0379332>,
      <-0.5029213, -0.0281892, 0.0408076>,
      <-0.5031140, 0.0540898, 0.0408076>,
      <-0.5029412, -0.0232529, 0.0398495>,
      <-0.5030176, 0.0129503, 0.0408076>,
      <-0.5031287, 0.0565338, 0.0398495>,
      <-0.5030349, 0.0166405, 0.0398495>,
      <-0.5033066, 0.1363688, 0.0408076>,
      <-0.5032103, 0.0952293, 0.0408076>,
      <-0.5033163, 0.1363206, 0.0398495>,
      <-0.5032225, 0.0964272, 0.0398495>,
      <-0.2535779, -0.0178378, 0.0388913>,
      <-0.3782694, -0.0180772, 0.0388913>,
      <-0.2535872, -0.0129014, 0.0379332>,
      <-0.3782840, -0.0131409, 0.0379332>,
      <-0.0041947, -0.0173590, 0.0388913>,
      <-0.0041935, -0.0124226, 0.0379332>,
      <-0.1288863, -0.0175984, 0.0388913>,
      <-0.1288904, -0.0126620, 0.0379332>,
      <-0.0041971, -0.0272317, 0.0408076>,
      <-0.2535592, -0.0277105, 0.0408076>,
      <-0.0041959, -0.0222954, 0.0398495>,
      <-0.1288782, -0.0274711, 0.0408076>,
      <-0.2535685, -0.0227741, 0.0398495>,
      <-0.1288822, -0.0225347, 0.0398495>,
      <-0.3782403, -0.0279498, 0.0408076>,
      <-0.3782548, -0.0230135, 0.0398495>,
      <-0.0043635, 0.0599398, 0.0388913>,
      <-0.0042791, 0.0212904, 0.0388913>,
      <-0.0043573, 0.0623839, 0.0379332>,
      <-0.0042754, 0.0249807, 0.0379332>,
      <-0.0045323, 0.1372385, 0.0388913>,
      <-0.0045211, 0.1371903, 0.0379332>,
      <-0.0044479, 0.0985892, 0.0388913>,
      <-0.0044392, 0.0997871, 0.0379332>,
      <-0.0045547, 0.1373349, 0.0408076>,
      <-0.0043759, 0.0550516, 0.0408076>,
      <-0.0045435, 0.1372867, 0.0398495>,
      <-0.0044653, 0.0961933, 0.0408076>,
      <-0.0043697, 0.0574957, 0.0398495>,
      <-0.0044566, 0.0973912, 0.0398495>,
      <-0.0042865, 0.0139099, 0.0408076>,
      <-0.0042828, 0.0176002, 0.0398495>,
      <-0.5031080, 0.0530207, 0.1140004>,
      <-0.5033065, 0.1363694, 0.1159454>,
      <-0.5032070, 0.0946963, 0.1148339>,
      <-0.5033065, 0.1363691, 0.0783765>,
      <-0.5031139, 0.0540740, 0.0783765>,
      <-0.5032102, 0.0952215, 0.0783765>,
      <-0.5029127, -0.0303434, 0.1137225>,
      <-0.5029212, -0.0282212, 0.0783765>,
      <-0.5030101, 0.0113399, 0.1137225>,
      <-0.5030175, 0.0129264, 0.0783765>,
      <-0.5028368, -0.0492196, 0.1688550>,
      <-0.5030541, 0.0436621, 0.1705221>,
      <-0.5028873, -0.0366461, 0.1446230>,
      <-0.5029439, -0.0027711, 0.1688550>,
      <-0.5030907, 0.0498925, 0.1457344>,
      <-0.5029880, 0.0066283, 0.1446230>,
      <-0.5033063, 0.1363701, 0.1910831>,
      <-0.5031705, 0.0900646, 0.1755235>,
      <-0.5033064, 0.1363697, 0.1535142>,
      <-0.5031975, 0.0931362, 0.1490686>,
      <-0.2535552, -0.0298647, 0.1137225>,
      <-0.3782339, -0.0301040, 0.1137225>,
      <-0.2535592, -0.0277424, 0.0783765>,
      <-0.3782402, -0.0279818, 0.0783765>,
      <-0.0041977, -0.0293860, 0.1137225>,
      <-0.0041971, -0.0272637, 0.0783765>,
      <-0.1288764, -0.0296253, 0.1137225>,
      <-0.1288782, -0.0275031, 0.0783765>,
      <-0.0042022, -0.0482625, 0.1688550>,
      <-0.2535195, -0.0487410, 0.1688550>,
      <-0.0041992, -0.0356888, 0.1446230>,
      <-0.1288609, -0.0485018, 0.1688550>,
      <-0.2535433, -0.0361675, 0.1446230>,
      <-0.1288712, -0.0359281, 0.1446230>,
      <-0.3781781, -0.0489803, 0.1688550>,
      <-0.3782153, -0.0364068, 0.1446230>,
      <-0.0043780, 0.0539824, 0.1140004>,
      <-0.0042881, 0.0122995, 0.1137225>,
      <-0.0043759, 0.0550358, 0.0783765>,
      <-0.0042865, 0.0138860, 0.0783765>,
      <-0.0045548, 0.1373356, 0.1159454>,
      <-0.0045547, 0.1373353, 0.0783765>,
      <-0.0044667, 0.0956603, 0.1148339>,
      <-0.0044653, 0.0961855, 0.0783765>,
      <-0.0045550, 0.1373362, 0.1910831>,
      <-0.0043988, 0.0446236, 0.1705221>,
      <-0.0045549, 0.1373359, 0.1535142>,
      <-0.0044881, 0.0910284, 0.1755235>,
      <-0.0043842, 0.0508541, 0.1457344>,
      <-0.0044707, 0.0941001, 0.1490686>,
      <-0.0043023, -0.0018118, 0.1688550>,
      <-0.0042929, 0.0075878, 0.1446230>,
      <-0.5029129, 0.0208291, 0.1947016>,
      <-0.5031748, 0.1370244, 0.1950911>,
      <-0.5030438, 0.0789268, 0.1948685>,
      <-0.5032405, 0.1366972, 0.1930871>,
      <-0.5029904, 0.0333023, 0.1853073>,
      <-0.5031145, 0.0850049, 0.1886415>,
      <-0.5026513, -0.0953670, 0.1946459>,
      <-0.5027526, -0.0701540, 0.1841959>,
      <-0.5027821, -0.0372689, 0.1946459>,
      <-0.5028705, -0.0184208, 0.1841959>,
      <-0.5024626, -0.1422994, 0.2168760>,
      <-0.5027695, -0.0023930, 0.2155427>,
      <-0.5025492, -0.1207763, 0.2042058>,
      <-0.5026176, -0.0723535, 0.2168760>,
      <-0.5028349, 0.0082585, 0.2033170>,
      <-0.5026930, -0.0562638, 0.2042058>,
      <-0.5030432, 0.1376788, 0.1990990>,
      <-0.5029157, 0.0675967, 0.2115429>,
      <-0.5031090, 0.1373516, 0.1970950>,
      <-0.5029729, 0.0728002, 0.2006504>,
      <-0.2534324, -0.0948889, 0.1946459>,
      <-0.3780418, -0.0951280, 0.1946459>,
      <-0.2534800, -0.0696757, 0.1841959>,
      <-0.3781163, -0.0699148, 0.1841959>,
      <-0.0042135, -0.0944108, 0.1946459>,
      <-0.0042073, -0.0691973, 0.1841959>,
      <-0.1288229, -0.0946499, 0.1946459>,
      <-0.1288437, -0.0694365, 0.1841959>,
      <-0.0042249, -0.1413440, 0.2168760>,
      <-0.2533438, -0.1418217, 0.2168760>,
      <-0.0042196, -0.1198205, 0.2042058>,
      <-0.1287843, -0.1415829, 0.2168760>,
      <-0.2533844, -0.1202984, 0.2042058>,
      <-0.1288020, -0.1200595, 0.2042058>,
      <-0.3779032, -0.1420605, 0.2168760>,
      <-0.3779668, -0.1205374, 0.2042058>,
      <-0.0044602, 0.0217899, 0.1947016>,
      <-0.0043369, -0.0363104, 0.1946459>,
      <-0.0044262, 0.0342635, 0.1853073>,
      <-0.0043180, -0.0174618, 0.1841959>,
      <-0.0047068, 0.1379900, 0.1950911>,
      <-0.0046309, 0.1376631, 0.1930871>,
      <-0.0045835, 0.0798900, 0.1948685>,
      <-0.0045297, 0.0859684, 0.1886415>,
      <-0.0048587, 0.1386437, 0.1990990>,
      <-0.0045226, -0.0014328, 0.2155427>,
      <-0.0047828, 0.1383168, 0.1970950>,
      <-0.0046799, 0.0685593, 0.2115429>,
      <-0.0044944, 0.0092190, 0.2033170>,
      <-0.0046375, 0.0737630, 0.2006504>,
      <-0.0043720, -0.0713957, 0.2168760>,
      <-0.0043559, -0.0553056, 0.2042058>,
      <-0.5027088, -0.0128683, 0.2615488>,
      <-0.5030369, 0.1377101, 0.2599933>,
      <-0.5028731, 0.0624197, 0.2608821>,
      <-0.5030400, 0.1376945, 0.2295461>,
      <-0.5027300, -0.0091089, 0.2357681>,
      <-0.5028860, 0.0642879, 0.2331015>,
      <-0.5023777, -0.1634321, 0.2617710>,
      <-0.5024082, -0.1558539, 0.2366569>,
      <-0.5025435, -0.0881514, 0.2617710>,
      <-0.5025700, -0.0824863, 0.2366569>,
      <-0.5023568, -0.1686277, 0.3208876>,
      <-0.5026937, -0.0154431, 0.3208876>,
      <-0.5023633, -0.1670259, 0.2904404>,
      <-0.5025253, -0.0920354, 0.3208876>,
      <-0.5026985, -0.0146501, 0.2904405>,
      <-0.5025309, -0.0908380, 0.2904404>,
      <-0.5030306, 0.1377414, 0.3208876>,
      <-0.5028621, 0.0611492, 0.3208876>,
      <-0.5030337, 0.1377258, 0.2904404>,
      <-0.5028661, 0.0615379, 0.2904404>,
      <-0.2533039, -0.1629546, 0.2617710>,
      <-0.3778408, -0.1631933, 0.2617710>,
      <-0.2533182, -0.1553764, 0.2366569>,
      <-0.3778632, -0.1556152, 0.2366569>,
      <-0.0042300, -0.1624771, 0.2617710>,
      <-0.0042282, -0.1548988, 0.2366569>,
      <-0.1287669, -0.1627158, 0.2617710>,
      <-0.1287732, -0.1551376, 0.2366569>,
      <-0.0042313, -0.1676728, 0.3208876>,
      <-0.2532940, -0.1681502, 0.3208876>,
      <-0.0042309, -0.1660710, 0.2904404>,
      <-0.1287627, -0.1679115, 0.3208876>,
      <-0.2532971, -0.1665485, 0.2904405>,
      <-0.1287640, -0.1663097, 0.2904404>,
      <-0.3778254, -0.1683890, 0.3208876>,
      <-0.3778302, -0.1667872, 0.2904404>,
      <-0.0045463, -0.0119083, 0.2615488>,
      <-0.0043879, -0.0871939, 0.2617710>,
      <-0.0045385, -0.0081489, 0.2357681>,
      <-0.0043822, -0.0815287, 0.2366569>,
      <-0.0048660, 0.1386750, 0.2599933>,
      <-0.0048623, 0.1386594, 0.2295461>,
      <-0.0047058, 0.0633821, 0.2608821>,
      <-0.0046993, 0.0652504, 0.2331015>,
      <-0.0048732, 0.1387063, 0.3208876>,
      <-0.0045522, -0.0144832, 0.3208876>,
      <-0.0048696, 0.1386907, 0.2904404>,
      <-0.0047127, 0.0621115, 0.3208876>,
      <-0.0045502, -0.0136902, 0.2904405>,
      <-0.0047099, 0.0625002, 0.2904404>,
      <-0.0043918, -0.0910780, 0.3208876>,
      <-0.0043906, -0.0898806, 0.2904404>,
      <-0.5026426, -0.0238996, 0.3208876>,
      <-0.5029970, 0.1379084, 0.3208876>,
      <-0.5028198, 0.0570044, 0.3208876>,
      <-0.5030138, 0.1378249, 0.3208876>,
      <-0.5026681, -0.0196714, 0.3208876>,
      <-0.5028410, 0.0590768, 0.3208876>,
      <-0.5022882, -0.1857076, 0.3208876>,
      <-0.5023225, -0.1771677, 0.3208876>,
      <-0.5024654, -0.1048036, 0.3208876>,
      <-0.5024953, -0.0984195, 0.3208876>,
      <-0.5022195, -0.2027876, 0.3208876>,
      <-0.5025915, -0.0323561, 0.3208876>,
      <-0.5022538, -0.1942476, 0.3208876>,
      <-0.5024055, -0.1175719, 0.3208876>,
      <-0.5026170, -0.0281279, 0.3208876>,
      <-0.5024354, -0.1111878, 0.3208876>,
      <-0.5029634, 0.1380753, 0.3208876>,
      <-0.5027775, 0.0528596, 0.3208876>,
      <-0.5029802, 0.1379919, 0.3208876>,
      <-0.5027986, 0.0549320, 0.3208876>,
      <-0.2532618, -0.1852303, 0.3208876>,
      <-0.3777750, -0.1854690, 0.3208876>,
      <-0.2532779, -0.1766903, 0.3208876>,
      <-0.3778002, -0.1769290, 0.3208876>,
      <-0.0042354, -0.1847531, 0.3208876>,
      <-0.0042333, -0.1762129, 0.3208876>,
      <-0.1287486, -0.1849917, 0.3208876>,
      <-0.1287556, -0.1764516, 0.3208876>,
      <-0.0042396, -0.2018333, 0.3208876>,
      <-0.2532295, -0.2023105, 0.3208876>,
      <-0.0042375, -0.1932932, 0.3208876>,
      <-0.1287346, -0.2020719, 0.3208876>,
      <-0.2532457, -0.1937704, 0.3208876>,
      <-0.1287416, -0.1935318, 0.3208876>,
      <-0.3777245, -0.2025490, 0.3208876>,
      <-0.3777498, -0.1940090, 0.3208876>,
      <-0.0045737, -0.0229400, 0.3208876>,
      <-0.0044046, -0.1038465, 0.3208876>,
      <-0.0045630, -0.0187116, 0.3208876>,
      <-0.0043982, -0.0974623, 0.3208876>,
      <-0.0049120, 0.1388731, 0.3208876>,
      <-0.0048926, 0.1387897, 0.3208876>,
      <-0.0047428, 0.0579665, 0.3208876>,
      <-0.0047278, 0.0600390, 0.3208876>,
      <-0.0049507, 0.1390399, 0.3208876>,
      <-0.0045951, -0.0313967, 0.3208876>,
      <-0.0049313, 0.1389565, 0.3208876>,
      <-0.0047729, 0.0538216, 0.3208876>,
      <-0.0045844, -0.0271684, 0.3208876>,
      <-0.0047579, 0.0558941, 0.3208876>,
      <-0.0044174, -0.1166150, 0.3208876>,
      <-0.0044110, -0.1102308, 0.3208876>,
      <-0.5025915, -0.0323561, 0.3720986>,
      <-0.5029634, 0.1380753, 0.3720986>,
      <-0.5027775, 0.0528596, 0.3720986>,
      <-0.5029634, 0.1380753, 0.3464931>,
      <-0.5025915, -0.0323561, 0.3464931>,
      <-0.5027775, 0.0528596, 0.3464931>,
      <-0.5022195, -0.2027876, 0.3720986>,
      <-0.5022195, -0.2027876, 0.3464931>,
      <-0.5024055, -0.1175719, 0.3720986>,
      <-0.5024055, -0.1175719, 0.3464931>,
      <-0.5022195, -0.2027876, 0.3977041>,
      <-0.5025915, -0.0323561, 0.3977041>,
      <-0.5024055, -0.1175719, 0.3977041>,
      <-0.5029634, 0.1380753, 0.3977041>,
      <-0.5027775, 0.0528596, 0.3977041>,
      <-0.2532295, -0.2023105, 0.3720986>,
      <-0.3777245, -0.2025490, 0.3720986>,
      <-0.2532295, -0.2023105, 0.3464931>,
      <-0.3777245, -0.2025490, 0.3464931>,
      <-0.0042396, -0.2018333, 0.3720986>,
      <-0.0042396, -0.2018333, 0.3464931>,
      <-0.1287346, -0.2020719, 0.3720986>,
      <-0.1287346, -0.2020719, 0.3464931>,
      <-0.0042396, -0.2018333, 0.3977041>,
      <-0.2532295, -0.2023105, 0.3977041>,
      <-0.1287346, -0.2020719, 0.3977041>,
      <-0.3777245, -0.2025490, 0.3977041>,
      <-0.0045951, -0.0313967, 0.3720986>,
      <-0.0044174, -0.1166150, 0.3720986>,
      <-0.0045951, -0.0313967, 0.3464931>,
      <-0.0044174, -0.1166150, 0.3464931>,
      <-0.0049507, 0.1390399, 0.3720986>,
      <-0.0049507, 0.1390399, 0.3464931>,
      <-0.0047729, 0.0538216, 0.3720986>,
      <-0.0047729, 0.0538216, 0.3464931>,
      <-0.0049507, 0.1390399, 0.3977041>,
      <-0.0045951, -0.0313967, 0.3977041>,
      <-0.0047729, 0.0538216, 0.3977041>,
      <-0.0044174, -0.1166150, 0.3977041>,
      <-0.2539571, 0.1385576, 0.3720986>,
      <-0.5029634, 0.1380753, 0.3720986>,
      <-0.2539571, 0.1385576, 0.3208876>,
      <-0.3784603, 0.1383165, 0.3720986>,
      <-0.5029634, 0.1380753, 0.3464931>,
      <-0.3784603, 0.1383165, 0.3208876>,
      <-0.2539571, 0.1385576, 0.3464931>,
      <-0.3784603, 0.1383165, 0.3464931>,
      <-0.0049507, 0.1390399, 0.3720986>,
      <-0.1294539, 0.1387987, 0.3208876>,
      <-0.0049507, 0.1390399, 0.3464931>,
      <-0.1294539, 0.1387987, 0.3720986>,
      <-0.1294539, 0.1387987, 0.3464931>,
      <-0.2539571, 0.1385576, 0.4233096>,
      <-0.0049507, 0.1390399, 0.3977041>,
      <-0.1294539, 0.1387987, 0.4233096>,
      <-0.2539571, 0.1385576, 0.3977041>,
      <-0.1294539, 0.1387987, 0.3977041>,
      <-0.3784603, 0.1383165, 0.4233096>,
      <-0.5029634, 0.1380753, 0.3977041>,
      <-0.3784603, 0.1383165, 0.3977041>,
      <-0.2539545, 0.1383907, 0.3208876>,
      <-0.2539519, 0.1382239, 0.3208876>,
      <-0.2539532, 0.1383073, 0.3208876>,
      <-0.3784912, 0.1379827, 0.3208876>,
      <-0.3784757, 0.1381496, 0.3208876>,
      <-0.3784835, 0.1380661, 0.3208876>,
      <-0.2539571, 0.1385576, 0.3208876>,
      <-0.3784603, 0.1383165, 0.3208876>,
      <-0.2539558, 0.1384742, 0.3208876>,
      <-0.3784680, 0.1382330, 0.3208876>,
      <-0.1294539, 0.1387987, 0.3208876>,
      <-0.1294332, 0.1386319, 0.3208876>,
      <-0.1294436, 0.1387153, 0.3208876>,
      <-0.1294126, 0.1384651, 0.3208876>,
      <-0.1294229, 0.1385485, 0.3208876>,
      <-0.2539514, 0.1381926, 0.2599933>,
      <-0.5030369, 0.1377101, 0.2599933>,
      <-0.2539509, 0.1381613, 0.1990990>,
      <-0.3784941, 0.1379514, 0.2599933>,
      <-0.5030400, 0.1376945, 0.2295461>,
      <-0.3784970, 0.1379200, 0.1990990>,
      <-0.2539512, 0.1381769, 0.2295461>,
      <-0.3784956, 0.1379357, 0.2295461>,
      <-0.0048660, 0.1386750, 0.2599933>,
      <-0.1294048, 0.1384025, 0.1990990>,
      <-0.0048623, 0.1386594, 0.2295461>,
      <-0.1294087, 0.1384338, 0.2599933>,
      <-0.1294068, 0.1384181, 0.2295461>,
      <-0.2539519, 0.1382239, 0.3208876>,
      <-0.0048696, 0.1386907, 0.2904404>,
      <-0.1294126, 0.1384651, 0.3208876>,
      <-0.2539517, 0.1382082, 0.2904405>,
      <-0.1294106, 0.1384494, 0.2904404>,
      <-0.3784912, 0.1379827, 0.3208876>,
      <-0.5030337, 0.1377258, 0.2904404>,
      <-0.3784927, 0.1379670, 0.2904404>,
      <-0.2539408, 0.1375072, 0.1950911>,
      <-0.2539307, 0.1368531, 0.1910831>,
      <-0.2539357, 0.1371802, 0.1930871>,
      <-0.3786185, 0.1366116, 0.1910831>,
      <-0.3785578, 0.1372658, 0.1950911>,
      <-0.3785881, 0.1369387, 0.1930871>,
      <-0.2539509, 0.1381613, 0.1990990>,
      <-0.3784970, 0.1379200, 0.1990990>,
      <-0.2539459, 0.1378342, 0.1970950>,
      <-0.3785274, 0.1375929, 0.1970950>,
      <-0.1294048, 0.1384025, 0.1990990>,
      <-0.1293238, 0.1377486, 0.1950911>,
      <-0.1293643, 0.1380755, 0.1970950>,
      <-0.1292428, 0.1370947, 0.1910831>,
      <-0.1292833, 0.1374216, 0.1930871>,
      <-0.2539306, 0.1368525, 0.1159454>,
      <-0.5033065, 0.1363694, 0.1159454>,
      <-0.2539306, 0.1368519, 0.0408076>,
      <-0.3786186, 0.1366110, 0.1159454>,
      <-0.5033065, 0.1363691, 0.0783765>,
      <-0.3786186, 0.1366103, 0.0408076>,
      <-0.2539306, 0.1368522, 0.0783765>,
      <-0.3786186, 0.1366106, 0.0783765>,
      <-0.0045548, 0.1373356, 0.1159454>,
      <-0.1292427, 0.1370934, 0.0408076>,
      <-0.0045547, 0.1373353, 0.0783765>,
      <-0.1292427, 0.1370940, 0.1159454>,
      <-0.1292427, 0.1370937, 0.0783765>,
      <-0.2539307, 0.1368531, 0.1910831>,
      <-0.0045549, 0.1373359, 0.1535142>,
      <-0.1292428, 0.1370947, 0.1910831>,
      <-0.2539306, 0.1368528, 0.1535142>,
      <-0.1292428, 0.1370943, 0.1535142>,
      <-0.3786185, 0.1366116, 0.1910831>,
      <-0.5033064, 0.1363697, 0.1535142>,
      <-0.3786185, 0.1366113, 0.1535142>,
      <-0.2539291, 0.1367554, 0.0388913>,
      <-0.2539276, 0.1366590, 0.0369751>,
      <-0.2539284, 0.1367072, 0.0379332>,
      <-0.3786365, 0.1364174, 0.0369751>,
      <-0.3786276, 0.1365139, 0.0388913>,
      <-0.3786320, 0.1364656, 0.0379332>,
      <-0.2539306, 0.1368519, 0.0408076>,
      <-0.3786186, 0.1366103, 0.0408076>,
      <-0.2539299, 0.1368036, 0.0398495>,
      <-0.3786231, 0.1365621, 0.0398495>,
      <-0.1292427, 0.1370934, 0.0408076>,
      <-0.1292307, 0.1369970, 0.0388913>,
      <-0.1292367, 0.1370452, 0.0398495>,
      <-0.1292188, 0.1369006, 0.0369751>,
      <-0.1292247, 0.1369488, 0.0379332>,
      <-0.2539246, 0.1364638, 0.0204837>,
      <-0.5033859, 0.1359743, 0.0201245>,
      <-0.2539225, 0.1363270, 0.0073453>,
      <-0.3786553, 0.1362201, 0.0203640>,
      <-0.5034062, 0.1358736, 0.0116992>,
      <-0.3786712, 0.1360729, 0.0066268>,
      <-0.2539234, 0.1363819, 0.0131362>,
      <-0.3786648, 0.1361319, 0.0126572>,
      <-0.0044631, 0.1369409, 0.0201245>,
      <-0.1291734, 0.1365562, 0.0066268>,
      <-0.0044397, 0.1368402, 0.0116992>,
      <-0.1291939, 0.1367034, 0.0203640>,
      <-0.1291816, 0.1366152, 0.0126572>,
      <-0.2539276, 0.1366590, 0.0369751>,
      <-0.0044865, 0.1370415, 0.0285498>,
      <-0.1292188, 0.1369006, 0.0369751>,
      <-0.2539261, 0.1365583, 0.0285498>,
      <-0.1292063, 0.1367999, 0.0285498>,
      <-0.3786365, 0.1364174, 0.0369751>,
      <-0.5033657, 0.1360751, 0.0285498>,
      <-0.3786459, 0.1363167, 0.0285498>,
      <-0.2539225, 0.1363277, 0.0021099>,
      <-0.2539223, 0.1363139, 0.0039492>,
      <-0.3786679, 0.1360840, 0.0019902>,
      <-0.3786711, 0.1360639, 0.0034703>,
      <-0.2539234, 0.1363868, 0.0002275>,
      <-0.3786618, 0.1361451, 0.0002275>,
      <-0.2539229, 0.1363541, 0.0009891>,
      <-0.3786648, 0.1361125, 0.0009891>,
      <-0.1291851, 0.1366284, 0.0002275>,
      <-0.1291770, 0.1365673, 0.0019902>,
      <-0.1291810, 0.1365958, 0.0009891>,
      <-0.1291732, 0.1365472, 0.0034703>
    }
    normal_vectors {
      1158,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.9999595, 0.0019618, 0.0087848>,
      <0.9999588, 0.0019618, 0.0088648>,
      <0.9999588, 0.0019635, 0.0088610>,
      <0.9999595, 0.0019635, 0.0087830>,
      <0.9999602, 0.0019635, 0.0087049>,
      <0.9999602, 0.0019618, 0.0087048>,
      <0.9999602, 0.0019618, 0.0087048>,
      <0.9999602, 0.0019599, 0.0087047>,
      <0.9999595, 0.0019599, 0.0087868>,
      <0.9999595, 0.0019599, 0.0087868>,
      <0.9999588, 0.0019599, 0.0088688>,
      <0.9999581, 0.0019618, 0.0089449>,
      <0.9999581, 0.0019635, 0.0089391>,
      <0.9999588, 0.0019599, 0.0088688>,
      <0.9999580, 0.0019599, 0.0089509>,
      <0.9999580, 0.0019599, 0.0089509>,
      <0.9999573, 0.0019599, 0.0090330>,
      <0.9999574, 0.0019618, 0.0090249>,
      <0.9999574, 0.0019618, 0.0090249>,
      <0.9999574, 0.0019635, 0.0090172>,
      <0.9999582, 0.0019652, 0.0089337>,
      <0.9999588, 0.0019652, 0.0088574>,
      <0.9999574, 0.0019635, 0.0090172>,
      <0.9999575, 0.0019652, 0.0090099>,
      <0.9999575, 0.0019652, 0.0090099>,
      <0.9999575, 0.0019668, 0.0090030>,
      <0.9999582, 0.0019668, 0.0089285>,
      <0.9999582, 0.0019668, 0.0089285>,
      <0.9999589, 0.0019668, 0.0088540>,
      <0.9999595, 0.0019652, 0.0087812>,
      <0.9999589, 0.0019668, 0.0088540>,
      <0.9999595, 0.0019668, 0.0087795>,
      <0.9999595, 0.0019668, 0.0087795>,
      <0.9999602, 0.0019668, 0.0087050>,
      <0.9999602, 0.0019652, 0.0087049>,
      <0.9999602, 0.0019652, 0.0087049>,
      <0.9999602, 0.0019635, 0.0087049>,
      <-0.0004270, 0.2222792, -0.9749830>,
      <-0.0004270, 0.2222786, -0.9749831>,
      <-0.0004270, 0.2222786, -0.9749831>,
      <-0.0004270, 0.2222792, -0.9749830>,
      <-0.0004270, 0.2222797, -0.9749828>,
      <-0.0004270, 0.2222797, -0.9749828>,
      <-0.0004270, 0.2222797, -0.9749828>,
      <-0.0004270, 0.2222797, -0.9749828>,
      <-0.0004270, 0.2222792, -0.9749830>,
      <-0.0004270, 0.2222792, -0.9749830>,
      <-0.0004270, 0.2222786, -0.9749831>,
      <-0.0004270, 0.2222781, -0.9749832>,
      <-0.0004270, 0.2222781, -0.9749832>,
      <-0.0004270, 0.2222786, -0.9749831>,
      <-0.0004270, 0.2222781, -0.9749832>,
      <-0.0004270, 0.2222781, -0.9749832>,
      <-0.0004270, 0.2222776, -0.9749833>,
      <-0.0004270, 0.2222776, -0.9749833>,
      <-0.0004270, 0.2222776, -0.9749833>,
      <-0.0004270, 0.2222776, -0.9749833>,
      <-0.0004270, 0.2222781, -0.9749832>,
      <-0.0004270, 0.2222786, -0.9749831>,
      <-0.0004270, 0.2222776, -0.9749833>,
      <-0.0004270, 0.2222776, -0.9749833>,
      <-0.0004270, 0.2222776, -0.9749833>,
      <-0.0004269, 0.2222776, -0.9749833>,
      <-0.0004269, 0.2222781, -0.9749832>,
      <-0.0004269, 0.2222781, -0.9749832>,
      <-0.0004269, 0.2222786, -0.9749831>,
      <-0.0004270, 0.2222792, -0.9749830>,
      <-0.0004269, 0.2222786, -0.9749831>,
      <-0.0004269, 0.2222792, -0.9749830>,
      <-0.0004269, 0.2222792, -0.9749830>,
      <-0.0004269, 0.2222797, -0.9749828>,
      <-0.0004270, 0.2222797, -0.9749828>,
      <-0.0004270, 0.2222797, -0.9749828>,
      <-0.0004270, 0.2222797, -0.9749828>,
      <-0.9999571, -0.0017699, 0.0090901>,
      <-0.9999547, -0.0017699, 0.0093511>,
      <-0.9999546, -0.0017756, 0.0093635>,
      <-0.9999569, -0.0017756, 0.0091088>,
      <-0.9999592, -0.0017756, 0.0088542>,
      <-0.9999595, -0.0017699, 0.0088292>,
      <-0.9999595, -0.0017699, 0.0088292>,
      <-0.9999597, -0.0017639, 0.0088029>,
      <-0.9999573, -0.0017639, 0.0090705>,
      <-0.9999573, -0.0017639, 0.0090705>,
      <-0.9999548, -0.0017639, 0.0093381>,
      <-0.9999522, -0.0017699, 0.0096121>,
      <-0.9999522, -0.0017756, 0.0096181>,
      <-0.9999548, -0.0017639, 0.0093381>,
      <-0.9999523, -0.0017639, 0.0096057>,
      <-0.9999523, -0.0017639, 0.0096057>,
      <-0.9999497, -0.0017639, 0.0098733>,
      <-0.9999497, -0.0017699, 0.0098730>,
      <-0.9999497, -0.0017699, 0.0098730>,
      <-0.9999497, -0.0017756, 0.0098728>,
      <-0.9999521, -0.0017810, 0.0096239>,
      <-0.9999545, -0.0017810, 0.0093753>,
      <-0.9999497, -0.0017756, 0.0098728>,
      <-0.9999497, -0.0017810, 0.0098726>,
      <-0.9999497, -0.0017810, 0.0098726>,
      <-0.9999497, -0.0017862, 0.0098723>,
      <-0.9999520, -0.0017862, 0.0096294>,
      <-0.9999520, -0.0017862, 0.0096294>,
      <-0.9999544, -0.0017862, 0.0093865>,
      <-0.9999568, -0.0017810, 0.0091267>,
      <-0.9999544, -0.0017862, 0.0093865>,
      <-0.9999566, -0.0017862, 0.0091436>,
      <-0.9999566, -0.0017862, 0.0091436>,
      <-0.9999588, -0.0017862, 0.0089007>,
      <-0.9999590, -0.0017810, 0.0088780>,
      <-0.9999590, -0.0017810, 0.0088780>,
      <-0.9999592, -0.0017756, 0.0088542>,
      <-0.9999960, -0.0020702, 0.0019168>,
      <-0.9999951, -0.0020702, 0.0023280>,
      <-0.9999949, -0.0021742, 0.0023310>,
      <-0.9999958, -0.0021742, 0.0019187>,
      <-0.9999965, -0.0021742, 0.0015064>,
      <-0.9999967, -0.0020702, 0.0015057>,
      <-0.9999967, -0.0020702, 0.0015057>,
      <-0.9999969, -0.0019669, 0.0015049>,
      <-0.9999962, -0.0019669, 0.0019150>,
      <-0.9999962, -0.0019669, 0.0019150>,
      <-0.9999954, -0.0019669, 0.0023251>,
      <-0.9999941, -0.0020702, 0.0027392>,
      <-0.9999939, -0.0021742, 0.0027433>,
      <-0.9999954, -0.0019669, 0.0023251>,
      <-0.9999943, -0.0019669, 0.0027352>,
      <-0.9999943, -0.0019669, 0.0027352>,
      <-0.9999931, -0.0019669, 0.0031453>,
      <-0.9999929, -0.0020702, 0.0031504>,
      <-0.9999929, -0.0020702, 0.0031504>,
      <-0.9999927, -0.0021742, 0.0031556>,
      <-0.9999936, -0.0022786, 0.0027474>,
      <-0.9999947, -0.0022786, 0.0023340>,
      <-0.9999927, -0.0021742, 0.0031556>,
      <-0.9999924, -0.0022786, 0.0031608>,
      <-0.9999924, -0.0022786, 0.0031608>,
      <-0.9999921, -0.0023837, 0.0031660>,
      <-0.9999934, -0.0023837, 0.0027515>,
      <-0.9999934, -0.0023837, 0.0027515>,
      <-0.9999944, -0.0023837, 0.0023370>,
      <-0.9999956, -0.0022786, 0.0019206>,
      <-0.9999944, -0.0023837, 0.0023370>,
      <-0.9999953, -0.0023837, 0.0019225>,
      <-0.9999953, -0.0023837, 0.0019225>,
      <-0.9999960, -0.0023837, 0.0015080>,
      <-0.9999963, -0.0022786, 0.0015072>,
      <-0.9999963, -0.0022786, 0.0015072>,
      <-0.9999965, -0.0021742, 0.0015064>,
      <0.0019183, -0.9987712, 0.0495221>,
      <0.0019183, -0.9987713, 0.0495202>,
      <0.0019181, -0.9987713, 0.0495202>,
      <0.0019181, -0.9987712, 0.0495221>,
      <0.0019181, -0.9987711, 0.0495240>,
      <0.0019183, -0.9987711, 0.0495240>,
      <0.0019183, -0.9987711, 0.0495240>,
      <0.0019184, -0.9987711, 0.0495240>,
      <0.0019184, -0.9987712, 0.0495221>,
      <0.0019184, -0.9987712, 0.0495221>,
      <0.0019184, -0.9987713, 0.0495202>,
      <0.0019183, -0.9987714, 0.0495184>,
      <0.0019181, -0.9987714, 0.0495184>,
      <0.0019184, -0.9987713, 0.0495202>,
      <0.0019184, -0.9987714, 0.0495184>,
      <0.0019184, -0.9987714, 0.0495184>,
      <0.0019184, -0.9987715, 0.0495165>,
      <0.0019183, -0.9987715, 0.0495165>,
      <0.0019183, -0.9987715, 0.0495165>,
      <0.0019181, -0.9987715, 0.0495165>,
      <0.0019180, -0.9987714, 0.0495184>,
      <0.0019180, -0.9987713, 0.0495202>,
      <0.0019181, -0.9987715, 0.0495165>,
      <0.0019180, -0.9987715, 0.0495165>,
      <0.0019180, -0.9987715, 0.0495165>,
      <0.0019178, -0.9987715, 0.0495165>,
      <0.0019178, -0.9987714, 0.0495184>,
      <0.0019178, -0.9987714, 0.0495184>,
      <0.0019178, -0.9987713, 0.0495202>,
      <0.0019180, -0.9987712, 0.0495221>,
      <0.0019178, -0.9987713, 0.0495202>,
      <0.0019178, -0.9987712, 0.0495221>,
      <0.0019178, -0.9987712, 0.0495221>,
      <0.0019178, -0.9987711, 0.0495240>,
      <0.0019180, -0.9987711, 0.0495240>,
      <0.0019180, -0.9987711, 0.0495240>,
      <0.0019181, -0.9987711, 0.0495240>,
      <0.9999981, 0.0018878, 0.0004945>,
      <0.9999978, 0.0018878, 0.0008983>,
      <0.9999976, 0.0019898, 0.0008954>,
      <0.9999979, 0.0019898, 0.0004905>,
      <0.9999980, 0.0019898, 0.0000856>,
      <0.9999982, 0.0018878, 0.0000907>,
      <0.9999982, 0.0018878, 0.0000907>,
      <0.9999984, 0.0017863, 0.0000957>,
      <0.9999983, 0.0017863, 0.0004985>,
      <0.9999983, 0.0017863, 0.0004985>,
      <0.9999980, 0.0017863, 0.0009012>,
      <0.9999974, 0.0018878, 0.0013021>,
      <0.9999972, 0.0019898, 0.0013003>,
      <0.9999980, 0.0017863, 0.0009012>,
      <0.9999976, 0.0017863, 0.0013040>,
      <0.9999976, 0.0017863, 0.0013040>,
      <0.9999969, 0.0017863, 0.0017067>,
      <0.9999968, 0.0018878, 0.0017060>,
      <0.9999968, 0.0018878, 0.0017060>,
      <0.9999966, 0.0019898, 0.0017052>,
      <0.9999970, 0.0020924, 0.0012985>,
      <0.9999974, 0.0020924, 0.0008925>,
      <0.9999966, 0.0019898, 0.0017052>,
      <0.9999964, 0.0020924, 0.0017044>,
      <0.9999964, 0.0020924, 0.0017044>,
      <0.9999961, 0.0021956, 0.0017037>,
      <0.9999967, 0.0021956, 0.0012966>,
      <0.9999967, 0.0021956, 0.0012966>,
      <0.9999972, 0.0021956, 0.0008895>,
      <0.9999977, 0.0020924, 0.0004865>,
      <0.9999972, 0.0021956, 0.0008895>,
      <0.9999975, 0.0021956, 0.0004825>,
      <0.9999975, 0.0021956, 0.0004825>,
      <0.9999976, 0.0021956, 0.0000754>,
      <0.9999978, 0.0020924, 0.0000805>,
      <0.9999978, 0.0020924, 0.0000805>,
      <0.9999980, 0.0019898, 0.0000856>,
      <-0.9999491, -0.0023719, 0.0098056>,
      <-0.9999533, -0.0023719, 0.0093662>,
      <-0.9999531, -0.0023610, 0.0093940>,
      <-0.9999490, -0.0023610, 0.0098193>,
      <-0.9999447, -0.0023610, 0.0102445>,
      <-0.9999447, -0.0023719, 0.0102451>,
      <-0.9999447, -0.0023719, 0.0102451>,
      <-0.9999447, -0.0023836, 0.0102456>,
      <-0.9999492, -0.0023836, 0.0097911>,
      <-0.9999492, -0.0023836, 0.0097911>,
      <-0.9999536, -0.0023836, 0.0093365>,
      <-0.9999573, -0.0023719, 0.0089268>,
      <-0.9999570, -0.0023611, 0.0089688>,
      <-0.9999536, -0.0023836, 0.0093365>,
      <-0.9999577, -0.0023836, 0.0088820>,
      <-0.9999577, -0.0023836, 0.0088820>,
      <-0.9999616, -0.0023836, 0.0084274>,
      <-0.9999612, -0.0023720, 0.0084874>,
      <-0.9999612, -0.0023720, 0.0084874>,
      <-0.9999607, -0.0023611, 0.0085435>,
      <-0.9999567, -0.0023508, 0.0090081>,
      <-0.9999529, -0.0023508, 0.0094201>,
      <-0.9999607, -0.0023611, 0.0085435>,
      <-0.9999603, -0.0023508, 0.0085961>,
      <-0.9999603, -0.0023508, 0.0085961>,
      <-0.9999599, -0.0023413, 0.0086456>,
      <-0.9999564, -0.0023412, 0.0090451>,
      <-0.9999564, -0.0023412, 0.0090451>,
      <-0.9999527, -0.0023412, 0.0094445>,
      <-0.9999489, -0.0023508, 0.0098320>,
      <-0.9999527, -0.0023412, 0.0094445>,
      <-0.9999488, -0.0023412, 0.0098440>,
      <-0.9999488, -0.0023412, 0.0098440>,
      <-0.9999448, -0.0023412, 0.0102435>,
      <-0.9999448, -0.0023508, 0.0102440>,
      <-0.9999448, -0.0023508, 0.0102440>,
      <-0.9999447, -0.0023610, 0.0102445>,
      <0.0003659, -0.1905395, -0.9816795>,
      <0.0003659, -0.1905391, -0.9816795>,
      <0.0003658, -0.1905391, -0.9816795>,
      <0.0003658, -0.1905395, -0.9816795>,
      <0.0003658, -0.1905400, -0.9816794>,
      <0.0003659, -0.1905400, -0.9816794>,
      <0.0003659, -0.1905400, -0.9816794>,
      <0.0003659, -0.1905400, -0.9816794>,
      <0.0003659, -0.1905395, -0.9816795>,
      <0.0003659, -0.1905395, -0.9816795>,
      <0.0003659, -0.1905391, -0.9816795>,
      <0.0003659, -0.1905386, -0.9816796>,
      <0.0003658, -0.1905386, -0.9816796>,
      <0.0003659, -0.1905391, -0.9816795>,
      <0.0003659, -0.1905386, -0.9816796>,
      <0.0003659, -0.1905386, -0.9816796>,
      <0.0003659, -0.1905382, -0.9816797>,
      <0.0003659, -0.1905382, -0.9816797>,
      <0.0003659, -0.1905382, -0.9816797>,
      <0.0003658, -0.1905382, -0.9816797>,
      <0.0003658, -0.1905386, -0.9816796>,
      <0.0003658, -0.1905391, -0.9816795>,
      <0.0003658, -0.1905382, -0.9816797>,
      <0.0003658, -0.1905382, -0.9816797>,
      <0.0003658, -0.1905382, -0.9816797>,
      <0.0003658, -0.1905382, -0.9816797>,
      <0.0003658, -0.1905386, -0.9816796>,
      <0.0003658, -0.1905386, -0.9816796>,
      <0.0003658, -0.1905391, -0.9816795>,
      <0.0003658, -0.1905395, -0.9816795>,
      <0.0003658, -0.1905391, -0.9816795>,
      <0.0003658, -0.1905395, -0.9816795>,
      <0.0003658, -0.1905395, -0.9816795>,
      <0.0003658, -0.1905400, -0.9816794>,
      <0.0003658, -0.1905400, -0.9816794>,
      <0.0003658, -0.1905400, -0.9816794>,
      <0.0003658, -0.1905400, -0.9816794>,
      <0.9999221, 0.0021891, 0.0122917>,
      <0.9999250, 0.0021891, 0.0120530>,
      <0.9999252, 0.0021832, 0.0120379>,
      <0.9999224, 0.0021832, 0.0122689>,
      <0.9999195, 0.0021832, 0.0125000>,
      <0.9999191, 0.0021891, 0.0125305>,
      <0.9999191, 0.0021891, 0.0125305>,
      <0.9999187, 0.0021954, 0.0125631>,
      <0.9999217, 0.0021954, 0.0123161>,
      <0.9999217, 0.0021954, 0.0123161>,
      <0.9999248, 0.0021954, 0.0120691>,
      <0.9999278, 0.0021891, 0.0118142>,
      <0.9999279, 0.0021832, 0.0118068>,
      <0.9999248, 0.0021954, 0.0120691>,
      <0.9999277, 0.0021954, 0.0118221>,
      <0.9999277, 0.0021954, 0.0118221>,
      <0.9999306, 0.0021955, 0.0115751>,
      <0.9999306, 0.0021891, 0.0115755>,
      <0.9999306, 0.0021891, 0.0115755>,
      <0.9999306, 0.0021832, 0.0115758>,
      <0.9999280, 0.0021776, 0.0117999>,
      <0.9999253, 0.0021776, 0.0120237>,
      <0.9999306, 0.0021832, 0.0115758>,
      <0.9999306, 0.0021777, 0.0115760>,
      <0.9999306, 0.0021777, 0.0115760>,
      <0.9999306, 0.0021724, 0.0115763>,
      <0.9999281, 0.0021724, 0.0117934>,
      <0.9999281, 0.0021724, 0.0117934>,
      <0.9999255, 0.0021724, 0.0120104>,
      <0.9999226, 0.0021776, 0.0122476>,
      <0.9999255, 0.0021724, 0.0120104>,
      <0.9999229, 0.0021724, 0.0122275>,
      <0.9999229, 0.0021724, 0.0122275>,
      <0.9999202, 0.0021724, 0.0124445>,
      <0.9999199, 0.0021776, 0.0124714>,
      <0.9999199, 0.0021776, 0.0124714>,
      <0.9999195, 0.0021832, 0.0125000>,
      <-0.9999972, -0.0023481, 0.0000263>,
      <-0.9999972, -0.0023449, 0.0000444>,
      <-0.9999972, -0.0023724, 0.0001852>,
      <-0.9999971, -0.0023972, 0.0001033>,
      <-0.9999971, -0.0024023, 0.0000017>,
      <-0.9999972, -0.0023490, 0.0000017>,
      <-0.9999972, -0.0023490, 0.0000017>,
      <-0.9999973, -0.0023413, 0.0000017>,
      <-0.9999973, -0.0023413, 0.0000016>,
      <-0.9999973, -0.0023413, 0.0000016>,
      <-0.9999973, -0.0023413, 0.0000016>,
      <-0.9999973, -0.0023417, 0.0000506>,
      <-0.9999972, -0.0023453, 0.0002171>,
      <-0.9999973, -0.0023413, 0.0000016>,
      <-0.9999973, -0.0023413, 0.0000015>,
      <-0.9999973, -0.0023413, 0.0000015>,
      <-0.9999973, -0.0023413, 0.0000014>,
      <-0.9999973, -0.0023406, 0.0000496>,
      <-0.9999973, -0.0023406, 0.0000496>,
      <-0.9999972, -0.0023361, 0.0002141>,
      <-0.9999971, -0.0023545, 0.0005874>,
      <-0.9999969, -0.0024419, 0.0005300>,
      <-0.9999972, -0.0023361, 0.0002141>,
      <-0.9999971, -0.0023244, 0.0005804>,
      <-0.9999971, -0.0023244, 0.0005804>,
      <-0.9999963, -0.0023042, 0.0014524>,
      <-0.9999961, -0.0023572, 0.0014766>,
      <-0.9999957, -0.0025163, 0.0014789>,
      <-0.9999967, -0.0025519, 0.0003445>,
      <-0.9999947, -0.0028927, 0.0015046>,
      <-0.9999934, -0.0032081, 0.0016908>,
      <-0.9999967, -0.0025715, 0.0000017>,
      <-0.9999967, -0.0025715, 0.0000017>,
      <-0.9999971, -0.0024023, 0.0000017>,
      <0.0019190, -0.9995620, -0.0295315>,
      <0.0019190, -0.9995620, -0.0295315>,
      <0.0019044, -0.9920080, -0.1261608>,
      <0.0019044, -0.9920080, -0.1261605>,
      <0.0019044, -0.9920081, -0.1261602>,
      <0.0019190, -0.9995620, -0.0295314>,
      <0.0019190, -0.9995620, -0.0295314>,
      <0.0019198, -0.9999978, -0.0008513>,
      <0.0019198, -0.9999978, -0.0008513>,
      <0.0019198, -0.9999978, -0.0008513>,
      <0.0019198, -0.9999978, -0.0008513>,
      <0.0019190, -0.9995620, -0.0295316>,
      <0.0019044, -0.9920079, -0.1261611>,
      <0.0019198, -0.9999978, -0.0008513>,
      <0.0019198, -0.9999978, -0.0008513>,
      <0.0019198, -0.9999978, -0.0008513>,
      <0.0019198, -0.9999978, -0.0008513>,
      <0.0019190, -0.9995620, -0.0295317>,
      <0.0019190, -0.9995620, -0.0295317>,
      <0.0019044, -0.9920079, -0.1261614>,
      <0.0018161, -0.9460818, -0.3239228>,
      <0.0018161, -0.9460820, -0.3239221>,
      <0.0019044, -0.9920079, -0.1261614>,
      <0.0018161, -0.9460815, -0.3239235>,
      <0.0018161, -0.9460815, -0.3239235>,
      <0.0014648, -0.7631595, -0.6462086>,
      <0.0014648, -0.7631603, -0.6462076>,
      <0.0014648, -0.7631611, -0.6462067>,
      <0.0018161, -0.9460823, -0.3239213>,
      <0.0014648, -0.7631619, -0.6462057>,
      <0.0014648, -0.7631627, -0.6462048>,
      <0.0018161, -0.9460825, -0.3239206>,
      <0.0018161, -0.9460825, -0.3239206>,
      <0.0019044, -0.9920081, -0.1261602>,
      <0.9999976, 0.0021710, 0.0000687>,
      <0.9999976, 0.0021673, 0.0000578>,
      <0.9999977, 0.0021280, 0.0002410>,
      <0.9999976, 0.0021591, 0.0002938>,
      <0.9999976, 0.0021697, 0.0003068>,
      <0.9999976, 0.0021722, 0.0000714>,
      <0.9999976, 0.0021722, 0.0000714>,
      <0.9999976, 0.0021726, 0.0000021>,
      <0.9999976, 0.0021726, 0.0000020>,
      <0.9999976, 0.0021726, 0.0000020>,
      <0.9999976, 0.0021726, 0.0000020>,
      <0.9999977, 0.0021638, 0.0000335>,
      <0.9999978, 0.0021002, 0.0001319>,
      <0.9999976, 0.0021726, 0.0000020>,
      <0.9999976, 0.0021726, 0.0000019>,
      <0.9999976, 0.0021726, 0.0000019>,
      <0.9999976, 0.0021726, 0.0000019>,
      <0.9999977, 0.0021627, 0.0000019>,
      <0.9999977, 0.0021627, 0.0000019>,
      <0.9999978, 0.0020948, 0.0000019>,
      <0.9999981, 0.0019025, 0.0004262>,
      <0.9999977, 0.0020267, 0.0006796>,
      <0.9999978, 0.0020948, 0.0000019>,
      <0.9999982, 0.0018841, 0.0000019>,
      <0.9999982, 0.0018841, 0.0000019>,
      <0.9999975, 0.0011306, 0.0019113>,
      <0.9999973, 0.0014709, 0.0017942>,
      <0.9999965, 0.0019006, 0.0018600>,
      <0.9999974, 0.0021279, 0.0007890>,
      <0.9999959, 0.0020880, 0.0019562>,
      <0.9999956, 0.0021524, 0.0020283>,
      <0.9999973, 0.0021634, 0.0008239>,
      <0.9999973, 0.0021634, 0.0008239>,
      <0.9999976, 0.0021697, 0.0003068>,
      <-0.9999804, -0.0028973, 0.0055500>,
      <-0.9999904, -0.0024940, 0.0036053>,
      <-0.9999808, -0.0022675, 0.0057696>,
      <-0.9999495, -0.0022972, 0.0097787>,
      <-0.9994455, -0.0024222, 0.0332100>,
      <-0.9994094, -0.0061240, 0.0338132>,
      <-0.9994094, -0.0061240, 0.0338132>,
      <-0.9999934, -0.0032081, 0.0016908>,
      <-0.9999921, -0.0023278, 0.0032130>,
      <-0.9999863, -0.0022549, 0.0047174>,
      <-0.9999963, -0.0023042, 0.0014524>,
      <-0.9999925, -0.0022776, 0.0031167>,
      <-0.9999925, -0.0022776, 0.0031167>,
      <-0.9999875, -0.0022516, 0.0044723>,
      <-0.9999896, -0.0021914, 0.0040074>,
      <-0.9999866, -0.0020555, 0.0047436>,
      <-0.9999875, -0.0022516, 0.0044723>,
      <-0.9999904, -0.0022305, 0.0037768>,
      <-0.9999904, -0.0022305, 0.0037768>,
      <-0.9999956, -0.0022157, 0.0019498>,
      <-0.9999956, -0.0021795, 0.0020286>,
      <-0.9999956, -0.0020675, 0.0021282>,
      <-0.9999717, -0.0017233, 0.0073266>,
      <-0.9999959, -0.0018009, 0.0022072>,
      <-0.9999964, -0.0016216, 0.0021417>,
      <-0.9994623, 0.0001679, 0.0327876>,
      <-0.9994623, 0.0001679, 0.0327876>,
      <-0.9994455, -0.0024222, 0.0332100>,
      <0.0009362, -0.4878550, -0.8729242>,
      <0.0009362, -0.4878540, -0.8729247>,
      <0.0007052, -0.3675992, -0.9299841>,
      <0.0007052, -0.3676000, -0.9299837>,
      <0.0007052, -0.3676008, -0.9299834>,
      <0.0009362, -0.4878559, -0.8729237>,
      <0.0009362, -0.4878559, -0.8729237>,
      <0.0014648, -0.7631627, -0.6462048>,
      <0.0009362, -0.4878531, -0.8729252>,
      <0.0007052, -0.3675984, -0.9299844>,
      <0.0014648, -0.7631595, -0.6462086>,
      <0.0009362, -0.4878522, -0.8729258>,
      <0.0009362, -0.4878522, -0.8729258>,
      <0.0007052, -0.3675976, -0.9299847>,
      <0.0008210, -0.4280640, -0.9037480>,
      <0.0008210, -0.4280649, -0.9037476>,
      <0.0007052, -0.3675976, -0.9299847>,
      <0.0008210, -0.4280631, -0.9037485>,
      <0.0008210, -0.4280631, -0.9037485>,
      <0.0013022, -0.6790835, -0.7340599>,
      <0.0013022, -0.6790844, -0.7340591>,
      <0.0013022, -0.6790853, -0.7340582>,
      <0.0008210, -0.4280658, -0.9037472>,
      <0.0013022, -0.6790862, -0.7340574>,
      <0.0013022, -0.6790871, -0.7340565>,
      <0.0008210, -0.4280666, -0.9037468>,
      <0.0008210, -0.4280666, -0.9037468>,
      <0.0007052, -0.3676008, -0.9299834>,
      <0.9999891, 0.0020757, 0.0041835>,
      <0.9999883, 0.0018779, 0.0044632>,
      <0.9999729, 0.0021045, 0.0070592>,
      <0.9999795, 0.0021196, 0.0060433>,
      <0.9999798, 0.0021238, 0.0059878>,
      <0.9999886, 0.0021379, 0.0042603>,
      <0.9999886, 0.0021379, 0.0042603>,
      <0.9999956, 0.0021524, 0.0020283>,
      <0.9999777, 0.0014158, 0.0065314>,
      <0.9999322, 0.0020703, 0.0114548>,
      <0.9999975, 0.0011306, 0.0019113>,
      <0.9992667, -0.0022132, 0.0382247>,
      <0.9992667, -0.0022132, 0.0382247>,
      <0.9992929, 0.0019281, 0.0375502>,
      <0.9999598, 0.0027000, 0.0085524>,
      <0.9999807, 0.0023201, 0.0057588>,
      <0.9992929, 0.0019281, 0.0375502>,
      <0.9993007, 0.0048218, 0.0370785>,
      <0.9993007, 0.0048218, 0.0370785>,
      <0.9999932, 0.0027763, 0.0024226>,
      <0.9999933, 0.0025814, 0.0025817>,
      <0.9999941, 0.0022777, 0.0025763>,
      <0.9999848, 0.0021600, 0.0050692>,
      <0.9999945, 0.0021474, 0.0025453>,
      <0.9999946, 0.0021043, 0.0025373>,
      <0.9999854, 0.0021124, 0.0049728>,
      <0.9999854, 0.0021124, 0.0049728>,
      <0.9999798, 0.0021238, 0.0059878>,
      <-0.9999977, -0.0020704, 0.0005685>,
      <-0.9999974, -0.0021362, 0.0008105>,
      <-0.9999976, -0.0021821, 0.0003406>,
      <-0.9999976, -0.0021684, 0.0002361>,
      <-0.9999976, -0.0021656, 0.0001045>,
      <-0.9999979, -0.0020607, 0.0001045>,
      <-0.9999979, -0.0020607, 0.0001045>,
      <-0.9999964, -0.0016216, 0.0021417>,
      <-0.9999972, -0.0021890, 0.0008673>,
      <-0.9999975, -0.0021973, 0.0003799>,
      <-0.9999956, -0.0022157, 0.0019498>,
      <-0.9999972, -0.0022070, 0.0008532>,
      <-0.9999972, -0.0022070, 0.0008532>,
      <-0.9999975, -0.0022024, 0.0003774>,
      <-0.9999976, -0.0021996, 0.0001621>,
      <-0.9999976, -0.0021979, 0.0001554>,
      <-0.9999975, -0.0022024, 0.0003774>,
      <-0.9999976, -0.0022002, 0.0001599>,
      <-0.9999976, -0.0022002, 0.0001599>,
      <-0.9999976, -0.0021991, 0.0000958>,
      <-0.9999976, -0.0021991, 0.0000980>,
      <-0.9999976, -0.0021991, 0.0000980>,
      <-0.9999976, -0.0021991, 0.0001001>,
      <-0.9999976, -0.0021962, 0.0001341>,
      <-0.9999976, -0.0021991, 0.0001001>,
      <-0.9999976, -0.0021991, 0.0001023>,
      <-0.9999976, -0.0021991, 0.0001023>,
      <-0.9999976, -0.0021991, 0.0001045>,
      <-0.9999976, -0.0021957, 0.0001045>,
      <-0.9999976, -0.0021957, 0.0001045>,
      <-0.9999976, -0.0021656, 0.0001045>,
      <0.0017347, -0.9047720, -0.4258927>,
      <0.0017347, -0.9047716, -0.4258936>,
      <0.0018770, -0.9790976, -0.2033825>,
      <0.0018770, -0.9790977, -0.2033820>,
      <0.0018770, -0.9790978, -0.2033815>,
      <0.0017347, -0.9047724, -0.4258918>,
      <0.0017347, -0.9047724, -0.4258918>,
      <0.0013022, -0.6790871, -0.7340565>,
      <0.0017347, -0.9047712, -0.4258945>,
      <0.0018770, -0.9790975, -0.2033830>,
      <0.0013022, -0.6790835, -0.7340599>,
      <0.0017347, -0.9047708, -0.4258953>,
      <0.0017347, -0.9047708, -0.4258953>,
      <0.0018770, -0.9790974, -0.2033835>,
      <0.0019097, -0.9961582, -0.0875510>,
      <0.0019097, -0.9961582, -0.0875508>,
      <0.0018770, -0.9790974, -0.2033835>,
      <0.0019097, -0.9961582, -0.0875512>,
      <0.0019097, -0.9961582, -0.0875512>,
      <0.0019143, -0.9986172, -0.0525351>,
      <0.0019143, -0.9986172, -0.0525350>,
      <0.0019143, -0.9986172, -0.0525350>,
      <0.0019143, -0.9986173, -0.0525349>,
      <0.0019097, -0.9961582, -0.0875506>,
      <0.0019143, -0.9986173, -0.0525349>,
      <0.0019143, -0.9986173, -0.0525347>,
      <0.0019143, -0.9986173, -0.0525347>,
      <0.0019143, -0.9986173, -0.0525346>,
      <0.0019097, -0.9961583, -0.0875503>,
      <0.0019097, -0.9961583, -0.0875503>,
      <0.0018770, -0.9790978, -0.2033815>,
      <0.9999972, 0.0021206, 0.0010841>,
      <0.9999971, 0.0021812, 0.0009839>,
      <0.9999977, 0.0021202, 0.0004143>,
      <0.9999977, 0.0021030, 0.0004740>,
      <0.9999977, 0.0020971, 0.0004861>,
      <0.9999972, 0.0020996, 0.0011027>,
      <0.9999972, 0.0020996, 0.0011027>,
      <0.9999946, 0.0021043, 0.0025373>,
      <0.9999972, 0.0022556, 0.0006738>,
      <0.9999977, 0.0021357, 0.0002809>,
      <0.9999932, 0.0027763, 0.0024226>,
      <0.9999974, 0.0022651, 0.0001182>,
      <0.9999974, 0.0022651, 0.0001182>,
      <0.9999977, 0.0021387, 0.0001182>,
      <0.9999978, 0.0021005, 0.0001577>,
      <0.9999978, 0.0020985, 0.0001881>,
      <0.9999977, 0.0021387, 0.0001182>,
      <0.9999978, 0.0021010, 0.0001182>,
      <0.9999978, 0.0021010, 0.0001182>,
      <0.9999978, 0.0020953, 0.0001183>,
      <0.9999978, 0.0020953, 0.0001194>,
      <0.9999978, 0.0020953, 0.0001194>,
      <0.9999978, 0.0020953, 0.0001206>,
      <0.9999978, 0.0020966, 0.0002019>,
      <0.9999978, 0.0020953, 0.0001206>,
      <0.9999978, 0.0020953, 0.0001218>,
      <0.9999978, 0.0020953, 0.0001218>,
      <0.9999978, 0.0020953, 0.0001230>,
      <0.9999978, 0.0020959, 0.0002056>,
      <0.9999978, 0.0020959, 0.0002056>,
      <0.9999977, 0.0020971, 0.0004861>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, -0.0000000, 1.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, -0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <-0.9999976, -0.0021824, 0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, -0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.0019163, -0.9999982, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, -0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.9999978, 0.0020863, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, -0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0019368, -0.9999981, 0.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0000000, -0.0000000, -1.0000000>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005139>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <0.0019368, -0.9999980, 0.0005140>,
      <-0.0019118, 0.9869406, -0.1610731>,
      <-0.0019117, 0.9869406, -0.1610731>,
      <-0.0019117, 0.9869413, -0.1610691>,
      <-0.0019118, 0.9869413, -0.1610691>,
      <-0.0019118, 0.9869413, -0.1610691>,
      <-0.0019118, 0.9869406, -0.1610731>,
      <-0.0019118, 0.9869406, -0.1610731>,
      <-0.0019118, 0.9869400, -0.1610771>,
      <-0.0019118, 0.9869400, -0.1610771>,
      <-0.0019118, 0.9869400, -0.1610771>,
      <-0.0019117, 0.9869400, -0.1610771>,
      <-0.0019116, 0.9869406, -0.1610731>,
      <-0.0019116, 0.9869413, -0.1610691>,
      <-0.0019117, 0.9869400, -0.1610771>,
      <-0.0019116, 0.9869400, -0.1610771>,
      <-0.0019116, 0.9869400, -0.1610771>,
      <-0.0019116, 0.9869400, -0.1610771>,
      <-0.0019116, 0.9869406, -0.1610731>,
      <-0.0019116, 0.9869406, -0.1610731>,
      <-0.0019116, 0.9869413, -0.1610691>,
      <-0.0019116, 0.9869419, -0.1610650>,
      <-0.0019117, 0.9869419, -0.1610650>,
      <-0.0019116, 0.9869413, -0.1610691>,
      <-0.0019116, 0.9869419, -0.1610650>,
      <-0.0019116, 0.9869419, -0.1610650>,
      <-0.0019116, 0.9869426, -0.1610610>,
      <-0.0019116, 0.9869426, -0.1610610>,
      <-0.0019116, 0.9869426, -0.1610610>,
      <-0.0019117, 0.9869426, -0.1610610>,
      <-0.0019118, 0.9869419, -0.1610650>,
      <-0.0019117, 0.9869426, -0.1610610>,
      <-0.0019118, 0.9869426, -0.1610610>,
      <-0.0019118, 0.9869426, -0.1610610>,
      <-0.0019118, 0.9869426, -0.1610610>,
      <-0.0019118, 0.9869419, -0.1610650>,
      <-0.0019118, 0.9869419, -0.1610650>,
      <-0.0019118, 0.9869413, -0.1610691>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <0.0019371, -0.9999981, 0.0000083>,
      <-0.0019347, 0.9987337, -0.0502714>,
      <-0.0019347, 0.9987337, -0.0502714>,
      <-0.0019347, 0.9987338, -0.0502701>,
      <-0.0019347, 0.9987338, -0.0502701>,
      <-0.0019347, 0.9987338, -0.0502701>,
      <-0.0019347, 0.9987337, -0.0502714>,
      <-0.0019347, 0.9987337, -0.0502714>,
      <-0.0019347, 0.9987337, -0.0502727>,
      <-0.0019347, 0.9987337, -0.0502727>,
      <-0.0019347, 0.9987337, -0.0502727>,
      <-0.0019347, 0.9987337, -0.0502727>,
      <-0.0019347, 0.9987337, -0.0502714>,
      <-0.0019347, 0.9987338, -0.0502701>,
      <-0.0019347, 0.9987337, -0.0502727>,
      <-0.0019347, 0.9987337, -0.0502727>,
      <-0.0019347, 0.9987337, -0.0502727>,
      <-0.0019347, 0.9987337, -0.0502727>,
      <-0.0019347, 0.9987337, -0.0502714>,
      <-0.0019347, 0.9987337, -0.0502714>,
      <-0.0019347, 0.9987338, -0.0502701>,
      <-0.0019347, 0.9987338, -0.0502688>,
      <-0.0019347, 0.9987338, -0.0502688>,
      <-0.0019347, 0.9987338, -0.0502701>,
      <-0.0019347, 0.9987338, -0.0502688>,
      <-0.0019347, 0.9987338, -0.0502688>,
      <-0.0019347, 0.9987339, -0.0502676>,
      <-0.0019347, 0.9987339, -0.0502676>,
      <-0.0019347, 0.9987339, -0.0502676>,
      <-0.0019347, 0.9987339, -0.0502676>,
      <-0.0019347, 0.9987338, -0.0502688>,
      <-0.0019347, 0.9987339, -0.0502676>,
      <-0.0019347, 0.9987339, -0.0502676>,
      <-0.0019347, 0.9987339, -0.0502676>,
      <-0.0019347, 0.9987339, -0.0502676>,
      <-0.0019347, 0.9987338, -0.0502688>,
      <-0.0019347, 0.9987338, -0.0502688>,
      <-0.0019347, 0.9987338, -0.0502701>,
      <0.0019812, -0.9999385, 0.0109142>,
      <0.0019371, -0.9999428, 0.0105163>,
      <0.0019371, -0.9999320, 0.0115037>,
      <0.0019481, -0.9999302, 0.0116512>,
      <0.0019510, -0.9999267, 0.0119509>,
      <0.0019911, -0.9999266, 0.0119508>,
      <0.0019911, -0.9999266, 0.0119508>,
      <0.0021417, -0.9999703, 0.0074077>,
      <0.0020650, -0.9999704, 0.0074077>,
      <0.0019372, -0.9999707, 0.0074076>,
      <0.0018930, -0.9999387, 0.0109135>,
      <0.0019260, -0.9999303, 0.0116506>,
      <0.0018093, -0.9999709, 0.0074073>,
      <0.0017326, -0.9999711, 0.0074069>,
      <0.0018831, -0.9999268, 0.0119495>,
      <0.0018831, -0.9999268, 0.0119495>,
      <0.0019231, -0.9999268, 0.0119496>,
      <0.0019357, -0.9999276, 0.0118781>,
      <0.0019370, -0.9999280, 0.0118451>,
      <0.0019231, -0.9999268, 0.0119496>,
      <0.0019353, -0.9999267, 0.0119497>,
      <0.0019353, -0.9999267, 0.0119497>,
      <0.0019370, -0.9999267, 0.0119497>,
      <0.0019370, -0.9999267, 0.0119500>,
      <0.0019370, -0.9999267, 0.0119500>,
      <0.0019370, -0.9999267, 0.0119503>,
      <0.0019384, -0.9999276, 0.0118787>,
      <0.0019370, -0.9999267, 0.0119503>,
      <0.0019370, -0.9999267, 0.0119506>,
      <0.0019370, -0.9999267, 0.0119506>,
      <0.0019370, -0.9999267, 0.0119509>,
      <0.0019388, -0.9999267, 0.0119509>,
      <0.0019388, -0.9999267, 0.0119509>,
      <0.0019510, -0.9999267, 0.0119509>,
      <0.0020852, -0.9999883, -0.0043629>,
      <0.0020102, -0.9997813, -0.0208160>,
      <0.0019370, -0.9998800, -0.0153711>,
      <0.0019372, -0.9999978, -0.0008270>,
      <0.0021417, -0.9999703, 0.0074077>,
      <0.0025325, -0.9990800, -0.0428099>,
      <0.0025325, -0.9990800, -0.0428099>,
      <0.0020895, -0.9990809, -0.0428138>,
      <0.0019486, -0.9993769, -0.0352416>,
      <0.0019362, -0.9994733, -0.0323937>,
      <0.0020895, -0.9990809, -0.0428138>,
      <0.0019547, -0.9990811, -0.0428149>,
      <0.0019547, -0.9990811, -0.0428149>,
      <0.0019354, -0.9990811, -0.0428151>,
      <0.0019354, -0.9990812, -0.0428140>,
      <0.0019354, -0.9990812, -0.0428140>,
      <0.0019354, -0.9990812, -0.0428129>,
      <0.0019234, -0.9993770, -0.0352397>,
      <0.0018635, -0.9997816, -0.0208146>,
      <0.0019354, -0.9990812, -0.0428129>,
      <0.0019354, -0.9990813, -0.0428118>,
      <0.0019354, -0.9990813, -0.0428118>,
      <0.0019354, -0.9990813, -0.0428107>,
      <0.0019162, -0.9990814, -0.0428105>,
      <0.0019162, -0.9990814, -0.0428105>,
      <0.0017814, -0.9990817, -0.0428092>,
      <0.0017893, -0.9999889, -0.0043623>,
      <0.0017814, -0.9990817, -0.0428092>,
      <0.0013385, -0.9990826, -0.0428048>,
      <0.0013385, -0.9990826, -0.0428048>,
      <0.0017326, -0.9999711, 0.0074069>
    }
    uv_vectors {
      1469,
      <0.3461295, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.2826137, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.2823938, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.2826137, 0.1538766>,
      <0.3461295, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.5000062, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.6538828, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.7173863, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.7176062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.6537273, 0.1538766>,
      <0.7173863, 0.1538766>,
      <0.6538828, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.5000062, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.3477037, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.3461295, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.2826137, 0.1538766>,
      <0.3240764, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.5000062, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.2826137, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.3756038, 0.9329566>,
      <0.3240764, 0.9329566>,
      <0.7173863, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.5000059, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.5000062, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.6244079, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.6537273, 0.1538766>,
      <0.7173863, 0.1538766>,
      <0.6759253, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3240764, 0.9329566>,
      <0.3214772, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.6244079, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.3240764, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3737658, 0.9324092>,
      <0.3214772, 0.9324092>,
      <0.6759253, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3214772, 0.9324092>,
      <0.3213383, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.3214772, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3736676, 0.9388315>,
      <0.3213383, 0.9388315>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3213383, 0.9388315>,
      <0.3176078, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.3213383, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3710297, 0.9395004>,
      <0.3176078, 0.9395004>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3176078, 0.9395004>,
      <0.3175836, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.3176078, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3710126, 0.9657316>,
      <0.3175836, 0.9657316>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3175836, 0.9657316>,
      <0.2922845, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.3175836, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3531234, 0.9671308>,
      <0.2922845, 0.9671308>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.2922845, 0.9671308>,
      <0.2910740, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.2922845, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3522674, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.2846200, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.2846200, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3477037, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.4373453, 0.9326829>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.4378048, 0.9329566>,
      <0.5000059, 0.9326829>,
      <0.4368858, 0.9324092>,
      <0.3746848, 0.9326829>,
      <0.5626664, 0.9326829>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5622069, 0.9329566>,
      <0.6253269, 0.9326829>,
      <0.5631259, 0.9324092>,
      <0.5000059, 0.9326829>,
      <0.6512759, 0.9326829>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6501666, 0.9329566>,
      <0.6772249, 0.9326829>,
      <0.6523852, 0.9324092>,
      <0.6253269, 0.9326829>,
      <0.4368613, 0.9356203>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.4368858, 0.9324092>,
      <0.5000059, 0.9356203>,
      <0.4368368, 0.9388315>,
      <0.3737167, 0.9356203>,
      <0.5631505, 0.9356203>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5631259, 0.9324092>,
      <0.6262950, 0.9356203>,
      <0.5631750, 0.9388315>,
      <0.5000059, 0.9356203>,
      <0.6524445, 0.9356203>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6523852, 0.9324092>,
      <0.6785939, 0.9356203>,
      <0.6525037, 0.9388315>,
      <0.6262950, 0.9356203>,
      <0.4361773, 0.9391659>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.4368368, 0.9388315>,
      <0.5000059, 0.9391659>,
      <0.4355178, 0.9395004>,
      <0.3723487, 0.9391659>,
      <0.5638345, 0.9391659>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5631750, 0.9388315>,
      <0.6276631, 0.9391659>,
      <0.5644940, 0.9395004>,
      <0.5000059, 0.9391659>,
      <0.6540958, 0.9391659>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6525037, 0.9388315>,
      <0.6805285, 0.9391659>,
      <0.6556879, 0.9395004>,
      <0.6276631, 0.9391659>,
      <0.4355135, 0.9526160>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.4355178, 0.9395004>,
      <0.5000059, 0.9511210>,
      <0.4349582, 0.9657316>,
      <0.3710212, 0.9526160>,
      <0.5644983, 0.9526160>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5644940, 0.9395004>,
      <0.6289897, 0.9511210>,
      <0.5645025, 0.9657316>,
      <0.5000059, 0.9511210>,
      <0.6556982, 0.9526160>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6556879, 0.9395004>,
      <0.6824058, 0.9526160>,
      <0.6559367, 0.9657316>,
      <0.6289897, 0.9511210>,
      <0.4310370, 0.9664312>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.4349582, 0.9657316>,
      <0.5000060, 0.9664275>,
      <0.4263414, 0.9671308>,
      <0.3620680, 0.9664312>,
      <0.5689750, 0.9664312>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5645025, 0.9657316>,
      <0.6378965, 0.9664275>,
      <0.5734474, 0.9671308>,
      <0.5000060, 0.9664275>,
      <0.6665054, 0.9664312>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6559367, 0.9657316>,
      <0.6950669, 0.9664312>,
      <0.6773948, 0.9671308>,
      <0.6378965, 0.9664275>,
      <0.4263507, 0.9777601>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.4263414, 0.9671308>,
      <0.5000061, 0.9787650>,
      <0.4261367, 0.9883895>,
      <0.3526954, 0.9777601>,
      <0.5736614, 0.9777601>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5734474, 0.9671308>,
      <0.6473573, 0.9787650>,
      <0.5738754, 0.9883895>,
      <0.5000061, 0.9787650>,
      <0.6778190, 0.9777601>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6773948, 0.9671308>,
      <0.7083211, 0.9777601>,
      <0.6783356, 0.9883895>,
      <0.6473573, 0.9787650>,
      <0.4249958, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.4238549, 0.9941947>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.4238549, 0.9883895>,
      <0.5000061, 0.9941947>,
      <0.4238549, 1.0000000>,
      <0.3477037, 0.9941947>,
      <0.5761574, 0.9941947>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5761574, 0.9883895>,
      <0.6523086, 0.9941947>,
      <0.5761574, 1.0000000>,
      <0.5000061, 0.9941947>,
      <0.6838443, 0.9941947>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6838443, 0.9883895>,
      <0.7153801, 0.9941947>,
      <0.6838443, 1.0000000>,
      <0.6523086, 0.9941947>,
      <0.4642375, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5426958, 1.0000000>,
      <0.4396228, 1.0000000>,
      <0.3857793, 1.0000000>,
      <0.4888523, 1.0000000>,
      <0.5134670, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.4888523, 1.0000000>,
      <0.4619305, 1.0000000>,
      <0.5380817, 1.0000000>,
      <0.5650035, 1.0000000>,
      <0.6165400, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.5650035, 1.0000000>,
      <0.6142330, 1.0000000>,
      <0.6680764, 1.0000000>,
      <0.6188470, 1.0000000>,
      <0.6211540, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.6188470, 1.0000000>,
      <0.6996122, 1.0000000>,
      <0.6234610, 1.0000000>,
      <0.5426958, 1.0000000>,
      <0.4063597, 0.9328198>,
      <0.4373453, 0.9326829>,
      <0.3746848, 0.9326829>,
      <0.3756038, 0.9329566>,
      <0.4378048, 0.9329566>,
      <0.4060151, 0.9326829>,
      <0.3751443, 0.9328198>,
      <0.4067043, 0.9329566>,
      <0.4375751, 0.9328198>,
      <0.4687905, 0.9328198>,
      <0.4373453, 0.9326829>,
      <0.4378048, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9326829>,
      <0.4375751, 0.9328198>,
      <0.4689053, 0.9329566>,
      <0.5000059, 0.9328198>,
      <0.4686756, 0.9326829>,
      <0.4685607, 0.9325460>,
      <0.4373453, 0.9326829>,
      <0.5000059, 0.9326829>,
      <0.5000059, 0.9324092>,
      <0.4368858, 0.9324092>,
      <0.4686756, 0.9326829>,
      <0.5000059, 0.9325460>,
      <0.4684459, 0.9324092>,
      <0.4371156, 0.9325460>,
      <0.4056704, 0.9325460>,
      <0.4373453, 0.9326829>,
      <0.4368858, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3746848, 0.9326829>,
      <0.4371156, 0.9325460>,
      <0.4053258, 0.9324092>,
      <0.3742253, 0.9325460>,
      <0.4060151, 0.9326829>,
      <0.5312213, 0.9328198>,
      <0.5626664, 0.9326829>,
      <0.5000059, 0.9326829>,
      <0.5000059, 0.9329566>,
      <0.5622069, 0.9329566>,
      <0.5313361, 0.9326829>,
      <0.5000059, 0.9328198>,
      <0.5311064, 0.9329566>,
      <0.5624367, 0.9328198>,
      <0.5936520, 0.9328198>,
      <0.5626664, 0.9326829>,
      <0.5622069, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6253269, 0.9326829>,
      <0.5624367, 0.9328198>,
      <0.5933074, 0.9329566>,
      <0.6248674, 0.9328198>,
      <0.5939967, 0.9326829>,
      <0.5943413, 0.9325460>,
      <0.5626664, 0.9326829>,
      <0.6253269, 0.9326829>,
      <0.6262459, 0.9324092>,
      <0.5631259, 0.9324092>,
      <0.5939967, 0.9326829>,
      <0.6257864, 0.9325460>,
      <0.5946859, 0.9324092>,
      <0.5628962, 0.9325460>,
      <0.5314510, 0.9325460>,
      <0.5626664, 0.9326829>,
      <0.5631259, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9326829>,
      <0.5628962, 0.9325460>,
      <0.5315659, 0.9324092>,
      <0.5000059, 0.9325460>,
      <0.5313361, 0.9326829>,
      <0.6377944, 0.9328198>,
      <0.6512759, 0.9326829>,
      <0.6253269, 0.9326829>,
      <0.6244079, 0.9329566>,
      <0.6501666, 0.9329566>,
      <0.6383014, 0.9326829>,
      <0.6248674, 0.9328198>,
      <0.6372873, 0.9329566>,
      <0.6507213, 0.9328198>,
      <0.6636482, 0.9328198>,
      <0.6512759, 0.9326829>,
      <0.6501666, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6772249, 0.9326829>,
      <0.6507213, 0.9328198>,
      <0.6630460, 0.9329566>,
      <0.6765751, 0.9328198>,
      <0.6642504, 0.9326829>,
      <0.6648526, 0.9325460>,
      <0.6512759, 0.9326829>,
      <0.6772249, 0.9326829>,
      <0.6785245, 0.9324092>,
      <0.6523852, 0.9324092>,
      <0.6642504, 0.9326829>,
      <0.6778747, 0.9325460>,
      <0.6654549, 0.9324092>,
      <0.6518306, 0.9325460>,
      <0.6388085, 0.9325460>,
      <0.6512759, 0.9326829>,
      <0.6523852, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6253269, 0.9326829>,
      <0.6518306, 0.9325460>,
      <0.6393156, 0.9324092>,
      <0.6257864, 0.9325460>,
      <0.6383014, 0.9326829>,
      <0.4053074, 0.9340147>,
      <0.4368613, 0.9356203>,
      <0.3737167, 0.9356203>,
      <0.3737658, 0.9324092>,
      <0.4368858, 0.9324092>,
      <0.4052890, 0.9356203>,
      <0.3737413, 0.9340147>,
      <0.4053258, 0.9324092>,
      <0.4368736, 0.9340147>,
      <0.4684397, 0.9340147>,
      <0.4368613, 0.9356203>,
      <0.4368858, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9356203>,
      <0.4368736, 0.9340147>,
      <0.4684459, 0.9324092>,
      <0.5000059, 0.9340147>,
      <0.4684336, 0.9356203>,
      <0.4684275, 0.9372259>,
      <0.4368613, 0.9356203>,
      <0.5000059, 0.9356203>,
      <0.5000059, 0.9388315>,
      <0.4368368, 0.9388315>,
      <0.4684336, 0.9356203>,
      <0.5000059, 0.9372259>,
      <0.4684213, 0.9388315>,
      <0.4368490, 0.9372259>,
      <0.4052706, 0.9372259>,
      <0.4368613, 0.9356203>,
      <0.4368368, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3737167, 0.9356203>,
      <0.4368490, 0.9372259>,
      <0.4052522, 0.9388315>,
      <0.3736922, 0.9372259>,
      <0.4052890, 0.9356203>,
      <0.5315720, 0.9340147>,
      <0.5631505, 0.9356203>,
      <0.5000059, 0.9356203>,
      <0.5000059, 0.9324092>,
      <0.5631259, 0.9324092>,
      <0.5315782, 0.9356203>,
      <0.5000059, 0.9340147>,
      <0.5315659, 0.9324092>,
      <0.5631382, 0.9340147>,
      <0.5947043, 0.9340147>,
      <0.5631505, 0.9356203>,
      <0.5631259, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6262950, 0.9356203>,
      <0.5631382, 0.9340147>,
      <0.5946859, 0.9324092>,
      <0.6262705, 0.9340147>,
      <0.5947227, 0.9356203>,
      <0.5947412, 0.9372259>,
      <0.5631505, 0.9356203>,
      <0.6262950, 0.9356203>,
      <0.6263441, 0.9388315>,
      <0.5631750, 0.9388315>,
      <0.5947227, 0.9356203>,
      <0.6263196, 0.9372259>,
      <0.5947596, 0.9388315>,
      <0.5631627, 0.9372259>,
      <0.5315843, 0.9372259>,
      <0.5631505, 0.9356203>,
      <0.5631750, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9356203>,
      <0.5631627, 0.9372259>,
      <0.5315904, 0.9388315>,
      <0.5000059, 0.9372259>,
      <0.5315782, 0.9356203>,
      <0.6393427, 0.9340147>,
      <0.6524445, 0.9356203>,
      <0.6262950, 0.9356203>,
      <0.6262459, 0.9324092>,
      <0.6523852, 0.9324092>,
      <0.6393698, 0.9356203>,
      <0.6262705, 0.9340147>,
      <0.6393156, 0.9324092>,
      <0.6524148, 0.9340147>,
      <0.6654870, 0.9340147>,
      <0.6524445, 0.9356203>,
      <0.6523852, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6785939, 0.9356203>,
      <0.6524148, 0.9340147>,
      <0.6654549, 0.9324092>,
      <0.6785592, 0.9340147>,
      <0.6655192, 0.9356203>,
      <0.6655513, 0.9372259>,
      <0.6524445, 0.9356203>,
      <0.6785939, 0.9356203>,
      <0.6786633, 0.9388315>,
      <0.6525037, 0.9388315>,
      <0.6655192, 0.9356203>,
      <0.6786286, 0.9372259>,
      <0.6655835, 0.9388315>,
      <0.6524741, 0.9372259>,
      <0.6393968, 0.9372259>,
      <0.6524445, 0.9356203>,
      <0.6525037, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6262950, 0.9356203>,
      <0.6524741, 0.9372259>,
      <0.6394239, 0.9388315>,
      <0.6263196, 0.9372259>,
      <0.6393698, 0.9356203>,
      <0.4047576, 0.9389987>,
      <0.4361773, 0.9391659>,
      <0.3723487, 0.9391659>,
      <0.3736676, 0.9388315>,
      <0.4368368, 0.9388315>,
      <0.4042630, 0.9391659>,
      <0.3730082, 0.9389987>,
      <0.4052522, 0.9388315>,
      <0.4365070, 0.9389987>,
      <0.4682565, 0.9389987>,
      <0.4361773, 0.9391659>,
      <0.4368368, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9391659>,
      <0.4365070, 0.9389987>,
      <0.4684213, 0.9388315>,
      <0.5000059, 0.9389987>,
      <0.4680916, 0.9391659>,
      <0.4679267, 0.9393332>,
      <0.4361773, 0.9391659>,
      <0.5000059, 0.9391659>,
      <0.5000059, 0.9395004>,
      <0.4355178, 0.9395004>,
      <0.4680916, 0.9391659>,
      <0.5000059, 0.9393332>,
      <0.4677619, 0.9395004>,
      <0.4358475, 0.9393332>,
      <0.4037684, 0.9393332>,
      <0.4361773, 0.9391659>,
      <0.4355178, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3723487, 0.9391659>,
      <0.4358475, 0.9393332>,
      <0.4032738, 0.9395004>,
      <0.3716892, 0.9393332>,
      <0.4042630, 0.9391659>,
      <0.5317553, 0.9389987>,
      <0.5638345, 0.9391659>,
      <0.5000059, 0.9391659>,
      <0.5000059, 0.9388315>,
      <0.5631750, 0.9388315>,
      <0.5319202, 0.9391659>,
      <0.5000059, 0.9389987>,
      <0.5315904, 0.9388315>,
      <0.5635047, 0.9389987>,
      <0.5952542, 0.9389987>,
      <0.5638345, 0.9391659>,
      <0.5631750, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6276631, 0.9391659>,
      <0.5635047, 0.9389987>,
      <0.5947596, 0.9388315>,
      <0.6270036, 0.9389987>,
      <0.5957488, 0.9391659>,
      <0.5962434, 0.9393332>,
      <0.5638345, 0.9391659>,
      <0.6276631, 0.9391659>,
      <0.6289821, 0.9395004>,
      <0.5644940, 0.9395004>,
      <0.5957488, 0.9391659>,
      <0.6283226, 0.9393332>,
      <0.5967380, 0.9395004>,
      <0.5641643, 0.9393332>,
      <0.5320851, 0.9393332>,
      <0.5638345, 0.9391659>,
      <0.5644940, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9391659>,
      <0.5641643, 0.9393332>,
      <0.5322500, 0.9395004>,
      <0.5000059, 0.9393332>,
      <0.5319202, 0.9391659>,
      <0.6401517, 0.9389987>,
      <0.6540958, 0.9391659>,
      <0.6276631, 0.9391659>,
      <0.6263441, 0.9388315>,
      <0.6525037, 0.9388315>,
      <0.6408795, 0.9391659>,
      <0.6270036, 0.9389987>,
      <0.6394239, 0.9388315>,
      <0.6532998, 0.9389987>,
      <0.6664478, 0.9389987>,
      <0.6540958, 0.9391659>,
      <0.6525037, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6805285, 0.9391659>,
      <0.6532998, 0.9389987>,
      <0.6655835, 0.9388315>,
      <0.6795959, 0.9389987>,
      <0.6673122, 0.9391659>,
      <0.6681765, 0.9393332>,
      <0.6540958, 0.9391659>,
      <0.6805285, 0.9391659>,
      <0.6823937, 0.9395004>,
      <0.6556879, 0.9395004>,
      <0.6673122, 0.9391659>,
      <0.6814611, 0.9393332>,
      <0.6690408, 0.9395004>,
      <0.6548919, 0.9393332>,
      <0.6416072, 0.9393332>,
      <0.6540958, 0.9391659>,
      <0.6556879, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6276631, 0.9391659>,
      <0.6548919, 0.9393332>,
      <0.6423350, 0.9395004>,
      <0.6283226, 0.9393332>,
      <0.6408795, 0.9391659>,
      <0.4032706, 0.9460582>,
      <0.4355135, 0.9526160>,
      <0.3710212, 0.9526160>,
      <0.3710297, 0.9395004>,
      <0.4355178, 0.9395004>,
      <0.4032658, 0.9526160>,
      <0.3710254, 0.9460582>,
      <0.4032738, 0.9395004>,
      <0.4355157, 0.9458854>,
      <0.4677608, 0.9456845>,
      <0.4355135, 0.9526160>,
      <0.4355178, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9511210>,
      <0.4355157, 0.9458854>,
      <0.4677619, 0.9395004>,
      <0.5000059, 0.9451388>,
      <0.4677604, 0.9518685>,
      <0.4676209, 0.9588001>,
      <0.4355135, 0.9526160>,
      <0.5000059, 0.9511210>,
      <0.5000059, 0.9657316>,
      <0.4349582, 0.9657316>,
      <0.4677604, 0.9518685>,
      <0.5000059, 0.9579003>,
      <0.4674769, 0.9657316>,
      <0.4352664, 0.9584513>,
      <0.4031264, 0.9591738>,
      <0.4355135, 0.9526160>,
      <0.4349582, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3710212, 0.9526160>,
      <0.4352664, 0.9584513>,
      <0.4022562, 0.9657316>,
      <0.3710169, 0.9591738>,
      <0.4032658, 0.9526160>,
      <0.5322510, 0.9456845>,
      <0.5644983, 0.9526160>,
      <0.5000059, 0.9511210>,
      <0.5000059, 0.9395004>,
      <0.5644940, 0.9395004>,
      <0.5322521, 0.9518685>,
      <0.5000059, 0.9451388>,
      <0.5322500, 0.9395004>,
      <0.5644961, 0.9458642>,
      <0.5967410, 0.9456845>,
      <0.5644983, 0.9526160>,
      <0.5644940, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289897, 0.9511210>,
      <0.5644961, 0.9458642>,
      <0.5967380, 0.9395004>,
      <0.6289858, 0.9451388>,
      <0.5967440, 0.9518685>,
      <0.5967474, 0.9588001>,
      <0.5644983, 0.9526160>,
      <0.6289897, 0.9511210>,
      <0.6289992, 0.9657316>,
      <0.5645025, 0.9657316>,
      <0.5967440, 0.9518685>,
      <0.6289941, 0.9579003>,
      <0.5967509, 0.9657316>,
      <0.5645003, 0.9587016>,
      <0.5322532, 0.9588001>,
      <0.5644983, 0.9526160>,
      <0.5645025, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000059, 0.9511210>,
      <0.5645003, 0.9587016>,
      <0.5322542, 0.9657316>,
      <0.5000059, 0.9579003>,
      <0.5322521, 0.9518685>,
      <0.6423395, 0.9456845>,
      <0.6556982, 0.9526160>,
      <0.6289897, 0.9511210>,
      <0.6289821, 0.9395004>,
      <0.6556879, 0.9395004>,
      <0.6423437, 0.9518685>,
      <0.6289858, 0.9451388>,
      <0.6423350, 0.9395004>,
      <0.6556929, 0.9458854>,
      <0.6690464, 0.9460582>,
      <0.6556982, 0.9526160>,
      <0.6556879, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824058, 0.9526160>,
      <0.6556929, 0.9458854>,
      <0.6690408, 0.9395004>,
      <0.6823998, 0.9460582>,
      <0.6690526, 0.9526160>,
      <0.6691147, 0.9591738>,
      <0.6556982, 0.9526160>,
      <0.6824058, 0.9526160>,
      <0.6824179, 0.9657316>,
      <0.6559367, 0.9657316>,
      <0.6690526, 0.9526160>,
      <0.6824118, 0.9591738>,
      <0.6694793, 0.9657316>,
      <0.6558043, 0.9584513>,
      <0.6424060, 0.9588001>,
      <0.6556982, 0.9526160>,
      <0.6559367, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6289897, 0.9511210>,
      <0.6558043, 0.9584513>,
      <0.6424701, 0.9657316>,
      <0.6289941, 0.9579003>,
      <0.6423437, 0.9518685>,
      <0.3997689, 0.9660814>,
      <0.4310370, 0.9664312>,
      <0.3620680, 0.9664312>,
      <0.3710126, 0.9657316>,
      <0.4349582, 0.9657316>,
      <0.3965525, 0.9664312>,
      <0.3665403, 0.9660814>,
      <0.4022562, 0.9657316>,
      <0.4331396, 0.9660561>,
      <0.4665018, 0.9660805>,
      <0.4310370, 0.9664312>,
      <0.4349582, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000060, 0.9664275>,
      <0.4331396, 0.9660561>,
      <0.4674769, 0.9657316>,
      <0.5000060, 0.9660883>,
      <0.4655215, 0.9664293>,
      <0.4643476, 0.9667801>,
      <0.4310370, 0.9664312>,
      <0.5000060, 0.9664275>,
      <0.5000061, 0.9671308>,
      <0.4263414, 0.9671308>,
      <0.4655215, 0.9664293>,
      <0.5000060, 0.9667645>,
      <0.4631665, 0.9671308>,
      <0.4286164, 0.9667919>,
      <0.3931424, 0.9667810>,
      <0.4310370, 0.9664312>,
      <0.4263414, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3620680, 0.9664312>,
      <0.4286164, 0.9667919>,
      <0.3894539, 0.9671308>,
      <0.3575957, 0.9667810>,
      <0.3965525, 0.9664312>,
      <0.5333724, 0.9660805>,
      <0.5689750, 0.9664312>,
      <0.5000060, 0.9664275>,
      <0.5000059, 0.9657316>,
      <0.5645025, 0.9657316>,
      <0.5344905, 0.9664293>,
      <0.5000060, 0.9660883>,
      <0.5322542, 0.9657316>,
      <0.5667950, 0.9660902>,
      <0.6000933, 0.9660805>,
      <0.5689750, 0.9664312>,
      <0.5645025, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6378965, 0.9664275>,
      <0.5667950, 0.9660902>,
      <0.5967509, 0.9657316>,
      <0.6335597, 0.9660883>,
      <0.6034357, 0.9664293>,
      <0.6068019, 0.9667801>,
      <0.5689750, 0.9664312>,
      <0.6378965, 0.9664275>,
      <0.6468888, 0.9671308>,
      <0.5734474, 0.9671308>,
      <0.6034357, 0.9664293>,
      <0.6422052, 0.9667645>,
      <0.6101681, 0.9671308>,
      <0.5711180, 0.9667664>,
      <0.5356086, 0.9667801>,
      <0.5689750, 0.9664312>,
      <0.5734474, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000060, 0.9664275>,
      <0.5711180, 0.9667664>,
      <0.5367268, 0.9671308>,
      <0.5000060, 0.9667645>,
      <0.5344905, 0.9664293>,
      <0.6473345, 0.9660805>,
      <0.6665054, 0.9664312>,
      <0.6378965, 0.9664275>,
      <0.6289992, 0.9657316>,
      <0.6559367, 0.9657316>,
      <0.6522009, 0.9664293>,
      <0.6335597, 0.9660883>,
      <0.6424701, 0.9657316>,
      <0.6608384, 0.9660561>,
      <0.6749817, 0.9660814>,
      <0.6665054, 0.9664312>,
      <0.6559367, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.6950669, 0.9664312>,
      <0.6608384, 0.9660561>,
      <0.6694793, 0.9657316>,
      <0.6887424, 0.9660814>,
      <0.6807862, 0.9664312>,
      <0.6866708, 0.9667810>,
      <0.6665054, 0.9664312>,
      <0.6950669, 0.9664312>,
      <0.7077159, 0.9671308>,
      <0.6773948, 0.9671308>,
      <0.6807862, 0.9664312>,
      <0.7013914, 0.9667810>,
      <0.6926707, 0.9671308>,
      <0.6721189, 0.9667919>,
      <0.6571714, 0.9667801>,
      <0.6665054, 0.9664312>,
      <0.6773948, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6378965, 0.9664275>,
      <0.6721189, 0.9667919>,
      <0.6621448, 0.9671308>,
      <0.6422052, 0.9667645>,
      <0.6522009, 0.9664293>,
      <0.3896277, 0.9724455>,
      <0.4263507, 0.9777601>,
      <0.3526954, 0.9777601>,
      <0.3531234, 0.9671308>,
      <0.4263414, 0.9671308>,
      <0.3895219, 0.9777601>,
      <0.3529094, 0.9724455>,
      <0.3894539, 0.9671308>,
      <0.4263465, 0.9729776>,
      <0.4631761, 0.9726967>,
      <0.4263507, 0.9777601>,
      <0.4263414, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9787650>,
      <0.4263465, 0.9729776>,
      <0.4631665, 0.9671308>,
      <0.5000061, 0.9732089>,
      <0.4631777, 0.9782626>,
      <0.4631249, 0.9833260>,
      <0.4263507, 0.9777601>,
      <0.5000061, 0.9787650>,
      <0.5000061, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.4631777, 0.9782626>,
      <0.5000061, 0.9837065>,
      <0.4630714, 0.9883895>,
      <0.4262410, 0.9832100>,
      <0.3893626, 0.9830748>,
      <0.4263507, 0.9777601>,
      <0.4261367, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3526954, 0.9777601>,
      <0.4262410, 0.9832100>,
      <0.3892021, 0.9883895>,
      <0.3524814, 0.9830748>,
      <0.3895219, 0.9777601>,
      <0.5367803, 0.9726967>,
      <0.5736614, 0.9777601>,
      <0.5000061, 0.9787650>,
      <0.5000061, 0.9671308>,
      <0.5734474, 0.9671308>,
      <0.5368338, 0.9782626>,
      <0.5000061, 0.9732089>,
      <0.5367268, 0.9671308>,
      <0.5735592, 0.9726839>,
      <0.6103387, 0.9726967>,
      <0.5736614, 0.9777601>,
      <0.5734474, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6473573, 0.9787650>,
      <0.5735592, 0.9726839>,
      <0.6101681, 0.9671308>,
      <0.6471335, 0.9732089>,
      <0.6105094, 0.9782626>,
      <0.6106597, 0.9833260>,
      <0.5736614, 0.9777601>,
      <0.6473573, 0.9787650>,
      <0.6477448, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6105094, 0.9782626>,
      <0.6475562, 0.9837065>,
      <0.6108101, 0.9883895>,
      <0.5737713, 0.9832176>,
      <0.5368873, 0.9833260>,
      <0.5736614, 0.9777601>,
      <0.5738754, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9787650>,
      <0.5737713, 0.9832176>,
      <0.5369408, 0.9883895>,
      <0.5000061, 0.9837065>,
      <0.5368338, 0.9782626>,
      <0.6623650, 0.9726967>,
      <0.6778190, 0.9777601>,
      <0.6473573, 0.9787650>,
      <0.6468888, 0.9671308>,
      <0.6773948, 0.9671308>,
      <0.6625884, 0.9782625>,
      <0.6471335, 0.9732089>,
      <0.6621448, 0.9671308>,
      <0.6776281, 0.9729776>,
      <0.6928127, 0.9724455>,
      <0.6778190, 0.9777601>,
      <0.6773948, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7083211, 0.9777601>,
      <0.6776281, 0.9729776>,
      <0.6926707, 0.9671308>,
      <0.7080185, 0.9724455>,
      <0.6930705, 0.9777601>,
      <0.6933505, 0.9830748>,
      <0.6778190, 0.9777601>,
      <0.7083211, 0.9777601>,
      <0.7089263, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.6930705, 0.9777601>,
      <0.7086237, 0.9830748>,
      <0.6936309, 0.9883895>,
      <0.6780838, 0.9832100>,
      <0.6628141, 0.9833260>,
      <0.6778190, 0.9777601>,
      <0.6783356, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6473573, 0.9787650>,
      <0.6780838, 0.9832100>,
      <0.6630402, 0.9883895>,
      <0.6475562, 0.9837065>,
      <0.6625884, 0.9782625>,
      <0.3883464, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.3874907, 0.9883895>,
      <0.3511265, 0.9883895>,
      <0.3892021, 0.9883895>,
      <0.4255663, 0.9883895>,
      <0.4627862, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4255663, 0.9883895>,
      <0.4630714, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4625010, 0.9883895>,
      <0.4622158, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.4625010, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4619305, 0.9883895>,
      <0.4244254, 0.9883895>,
      <0.3866350, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.4244254, 0.9883895>,
      <0.3857793, 0.9883895>,
      <0.3488446, 0.9883895>,
      <0.3874907, 0.9883895>,
      <0.5372260, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.5375113, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5369408, 0.9883895>,
      <0.5744459, 0.9883895>,
      <0.6116658, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.5744459, 0.9883895>,
      <0.6108101, 0.9883895>,
      <0.6488857, 0.9883895>,
      <0.6125215, 0.9883895>,
      <0.6133773, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.6125215, 0.9883895>,
      <0.6511676, 0.9883895>,
      <0.6142330, 0.9883895>,
      <0.5755869, 0.9883895>,
      <0.5377965, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5755869, 0.9883895>,
      <0.5380817, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5375113, 0.9883895>,
      <0.6642992, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.6655583, 0.9883895>,
      <0.6488857, 0.9883895>,
      <0.6630402, 0.9883895>,
      <0.6797127, 0.9883895>,
      <0.6951263, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.6797127, 0.9883895>,
      <0.6936309, 0.9883895>,
      <0.7105398, 0.9883895>,
      <0.6966216, 0.9883895>,
      <0.6981169, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6966216, 0.9883895>,
      <0.7137666, 0.9883895>,
      <0.6996122, 0.9883895>,
      <0.6824671, 0.9883895>,
      <0.6668174, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6824671, 0.9883895>,
      <0.6680764, 0.9883895>,
      <0.6511676, 0.9883895>,
      <0.6655583, 0.9883895>,
      <0.3857793, 0.9912921>,
      <0.4238549, 0.9941947>,
      <0.3477037, 0.9941947>,
      <0.3477037, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3857793, 0.9941947>,
      <0.3477037, 0.9912921>,
      <0.3857793, 0.9883895>,
      <0.4238549, 0.9912921>,
      <0.4619305, 0.9912921>,
      <0.4238549, 0.9941947>,
      <0.4238549, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9941947>,
      <0.4238549, 0.9912921>,
      <0.4619305, 0.9883895>,
      <0.5000061, 0.9912921>,
      <0.4619305, 0.9941947>,
      <0.4619305, 0.9970974>,
      <0.4238549, 0.9941947>,
      <0.5000061, 0.9941947>,
      <0.5000061, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.4619305, 0.9941947>,
      <0.5000061, 0.9970974>,
      <0.4619305, 1.0000000>,
      <0.4238549, 0.9970974>,
      <0.3857793, 0.9970974>,
      <0.4238549, 0.9941947>,
      <0.4238549, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.3477037, 0.9941947>,
      <0.4238549, 0.9970974>,
      <0.3857793, 1.0000000>,
      <0.3477037, 0.9970974>,
      <0.3857793, 0.9941947>,
      <0.5380817, 0.9912921>,
      <0.5761574, 0.9941947>,
      <0.5000061, 0.9941947>,
      <0.5000061, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5380817, 0.9941947>,
      <0.5000061, 0.9912921>,
      <0.5380817, 0.9883895>,
      <0.5761574, 0.9912921>,
      <0.6142330, 0.9912921>,
      <0.5761574, 0.9941947>,
      <0.5761574, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 0.9941947>,
      <0.5761574, 0.9912921>,
      <0.6142330, 0.9883895>,
      <0.6523086, 0.9912921>,
      <0.6142330, 0.9941947>,
      <0.6142330, 0.9970974>,
      <0.5761574, 0.9941947>,
      <0.6523086, 0.9941947>,
      <0.6523086, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6142330, 0.9941947>,
      <0.6523086, 0.9970974>,
      <0.6142330, 1.0000000>,
      <0.5761574, 0.9970974>,
      <0.5380817, 0.9970974>,
      <0.5761574, 0.9941947>,
      <0.5761574, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5000061, 0.9941947>,
      <0.5761574, 0.9970974>,
      <0.5380817, 1.0000000>,
      <0.5000061, 0.9970974>,
      <0.5380817, 0.9941947>,
      <0.6680764, 0.9912921>,
      <0.6838443, 0.9941947>,
      <0.6523086, 0.9941947>,
      <0.6523086, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6680765, 0.9941947>,
      <0.6523086, 0.9912921>,
      <0.6680764, 0.9883895>,
      <0.6838443, 0.9912921>,
      <0.6996122, 0.9912921>,
      <0.6838443, 0.9941947>,
      <0.6838443, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 0.9941947>,
      <0.6838443, 0.9912921>,
      <0.6996122, 0.9883895>,
      <0.7153801, 0.9912921>,
      <0.6996122, 0.9941947>,
      <0.6996122, 0.9970974>,
      <0.6838443, 0.9941947>,
      <0.7153801, 0.9941947>,
      <0.7153801, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.6996122, 0.9941947>,
      <0.7153801, 0.9970974>,
      <0.6996122, 1.0000000>,
      <0.6838443, 0.9970974>,
      <0.6680764, 0.9970974>,
      <0.6838443, 0.9941947>,
      <0.6838443, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6523086, 0.9941947>,
      <0.6838443, 0.9970974>,
      <0.6680764, 1.0000000>,
      <0.6523086, 0.9970974>,
      <0.6680765, 0.9941947>
    }
    face_indices {
      1056,   // 0 triangles and 528 quads
      <8, 7, 0>,
      <8, 0, 4>,
      <8, 4, 1>,
      <8, 1, 5>,
      <8, 5, 2>,
      <8, 2, 6>,
      <8, 6, 3>,
      <8, 3, 7>,
      <14, 13, 0>,
      <14, 0, 7>,
      <14, 7, 3>,
      <14, 3, 11>,
      <14, 11, 9>,
      <14, 9, 12>,
      <14, 12, 10>,
      <14, 10, 13>,
      <20, 19, 0>,
      <20, 0, 13>,
      <20, 13, 10>,
      <20, 10, 17>,
      <20, 17, 15>,
      <20, 15, 18>,
      <20, 18, 16>,
      <20, 16, 19>,
      <24, 4, 0>,
      <24, 0, 19>,
      <24, 19, 16>,
      <24, 16, 22>,
      <24, 22, 21>,
      <24, 21, 23>,
      <24, 23, 1>,
      <24, 1, 4>,
      <33, 32, 25>,
      <33, 25, 29>,
      <33, 29, 26>,
      <33, 26, 30>,
      <33, 30, 27>,
      <33, 27, 31>,
      <33, 31, 28>,
      <33, 28, 32>,
      <39, 38, 25>,
      <39, 25, 32>,
      <39, 32, 28>,
      <39, 28, 36>,
      <39, 36, 34>,
      <39, 34, 37>,
      <39, 37, 35>,
      <39, 35, 38>,
      <45, 44, 25>,
      <45, 25, 38>,
      <45, 38, 35>,
      <45, 35, 42>,
      <45, 42, 40>,
      <45, 40, 43>,
      <45, 43, 41>,
      <45, 41, 44>,
      <49, 29, 25>,
      <49, 25, 44>,
      <49, 44, 41>,
      <49, 41, 47>,
      <49, 47, 46>,
      <49, 46, 48>,
      <49, 48, 26>,
      <49, 26, 29>,
      <55, 54, 50>,
      <55, 50, 52>,
      <55, 52, 35>,
      <55, 35, 37>,
      <55, 37, 34>,
      <55, 34, 53>,
      <55, 53, 51>,
      <55, 51, 54>,
      <61, 60, 50>,
      <61, 50, 54>,
      <61, 54, 51>,
      <61, 51, 58>,
      <61, 58, 56>,
      <61, 56, 59>,
      <61, 59, 57>,
      <61, 57, 60>,
      <67, 66, 50>,
      <67, 50, 60>,
      <67, 60, 57>,
      <67, 57, 64>,
      <67, 64, 62>,
      <67, 62, 65>,
      <67, 65, 63>,
      <67, 63, 66>,
      <69, 52, 50>,
      <69, 50, 66>,
      <69, 66, 63>,
      <69, 63, 68>,
      <69, 68, 40>,
      <69, 40, 42>,
      <69, 42, 35>,
      <69, 35, 52>,
      <75, 74, 70>,
      <75, 70, 72>,
      <75, 72, 57>,
      <75, 57, 59>,
      <75, 59, 56>,
      <75, 56, 73>,
      <75, 73, 71>,
      <75, 71, 74>,
      <81, 80, 70>,
      <81, 70, 74>,
      <81, 74, 71>,
      <81, 71, 78>,
      <81, 78, 76>,
      <81, 76, 79>,
      <81, 79, 77>,
      <81, 77, 80>,
      <87, 86, 70>,
      <87, 70, 80>,
      <87, 80, 77>,
      <87, 77, 84>,
      <87, 84, 82>,
      <87, 82, 85>,
      <87, 85, 83>,
      <87, 83, 86>,
      <89, 72, 70>,
      <89, 70, 86>,
      <89, 86, 83>,
      <89, 83, 88>,
      <89, 88, 62>,
      <89, 62, 64>,
      <89, 64, 57>,
      <89, 57, 72>,
      <95, 94, 90>,
      <95, 90, 92>,
      <95, 92, 91>,
      <95, 91, 93>,
      <95, 93, 46>,
      <95, 46, 47>,
      <95, 47, 41>,
      <95, 41, 94>,
      <99, 98, 90>,
      <99, 90, 94>,
      <99, 94, 41>,
      <99, 41, 43>,
      <99, 43, 40>,
      <99, 40, 97>,
      <99, 97, 96>,
      <99, 96, 98>,
      <105, 104, 90>,
      <105, 90, 98>,
      <105, 98, 96>,
      <105, 96, 102>,
      <105, 102, 100>,
      <105, 100, 103>,
      <105, 103, 101>,
      <105, 101, 104>,
      <109, 92, 90>,
      <109, 90, 104>,
      <109, 104, 101>,
      <109, 101, 107>,
      <109, 107, 106>,
      <109, 106, 108>,
      <109, 108, 91>,
      <109, 91, 92>,
      <113, 112, 110>,
      <113, 110, 111>,
      <113, 111, 96>,
      <113, 96, 97>,
      <113, 97, 40>,
      <113, 40, 68>,
      <113, 68, 63>,
      <113, 63, 112>,
      <117, 116, 110>,
      <117, 110, 112>,
      <117, 112, 63>,
      <117, 63, 65>,
      <117, 65, 62>,
      <117, 62, 115>,
      <117, 115, 114>,
      <117, 114, 116>,
      <123, 122, 110>,
      <123, 110, 116>,
      <123, 116, 114>,
      <123, 114, 120>,
      <123, 120, 118>,
      <123, 118, 121>,
      <123, 121, 119>,
      <123, 119, 122>,
      <125, 111, 110>,
      <125, 110, 122>,
      <125, 122, 119>,
      <125, 119, 124>,
      <125, 124, 100>,
      <125, 100, 102>,
      <125, 102, 96>,
      <125, 96, 111>,
      <129, 128, 126>,
      <129, 126, 127>,
      <129, 127, 114>,
      <129, 114, 115>,
      <129, 115, 62>,
      <129, 62, 88>,
      <129, 88, 83>,
      <129, 83, 128>,
      <133, 132, 126>,
      <133, 126, 128>,
      <133, 128, 83>,
      <133, 83, 85>,
      <133, 85, 82>,
      <133, 82, 131>,
      <133, 131, 130>,
      <133, 130, 132>,
      <139, 138, 126>,
      <139, 126, 132>,
      <139, 132, 130>,
      <139, 130, 136>,
      <139, 136, 134>,
      <139, 134, 137>,
      <139, 137, 135>,
      <139, 135, 138>,
      <141, 127, 126>,
      <141, 126, 138>,
      <141, 138, 135>,
      <141, 135, 140>,
      <141, 140, 118>,
      <141, 118, 120>,
      <141, 120, 114>,
      <141, 114, 127>,
      <147, 146, 142>,
      <147, 142, 144>,
      <147, 144, 143>,
      <147, 143, 145>,
      <147, 145, 106>,
      <147, 106, 107>,
      <147, 107, 101>,
      <147, 101, 146>,
      <151, 150, 142>,
      <151, 142, 146>,
      <151, 146, 101>,
      <151, 101, 103>,
      <151, 103, 100>,
      <151, 100, 149>,
      <151, 149, 148>,
      <151, 148, 150>,
      <157, 156, 142>,
      <157, 142, 150>,
      <157, 150, 148>,
      <157, 148, 154>,
      <157, 154, 152>,
      <157, 152, 155>,
      <157, 155, 153>,
      <157, 153, 156>,
      <161, 144, 142>,
      <161, 142, 156>,
      <161, 156, 153>,
      <161, 153, 159>,
      <161, 159, 158>,
      <161, 158, 160>,
      <161, 160, 143>,
      <161, 143, 144>,
      <165, 164, 162>,
      <165, 162, 163>,
      <165, 163, 148>,
      <165, 148, 149>,
      <165, 149, 100>,
      <165, 100, 124>,
      <165, 124, 119>,
      <165, 119, 164>,
      <169, 168, 162>,
      <169, 162, 164>,
      <169, 164, 119>,
      <169, 119, 121>,
      <169, 121, 118>,
      <169, 118, 167>,
      <169, 167, 166>,
      <169, 166, 168>,
      <175, 174, 162>,
      <175, 162, 168>,
      <175, 168, 166>,
      <175, 166, 172>,
      <175, 172, 170>,
      <175, 170, 173>,
      <175, 173, 171>,
      <175, 171, 174>,
      <177, 163, 162>,
      <177, 162, 174>,
      <177, 174, 171>,
      <177, 171, 176>,
      <177, 176, 152>,
      <177, 152, 154>,
      <177, 154, 148>,
      <177, 148, 163>,
      <181, 180, 178>,
      <181, 178, 179>,
      <181, 179, 166>,
      <181, 166, 167>,
      <181, 167, 118>,
      <181, 118, 140>,
      <181, 140, 135>,
      <181, 135, 180>,
      <185, 184, 178>,
      <185, 178, 180>,
      <185, 180, 135>,
      <185, 135, 137>,
      <185, 137, 134>,
      <185, 134, 183>,
      <185, 183, 182>,
      <185, 182, 184>,
      <191, 190, 178>,
      <191, 178, 184>,
      <191, 184, 182>,
      <191, 182, 188>,
      <191, 188, 186>,
      <191, 186, 189>,
      <191, 189, 187>,
      <191, 187, 190>,
      <193, 179, 178>,
      <193, 178, 190>,
      <193, 190, 187>,
      <193, 187, 192>,
      <193, 192, 170>,
      <193, 170, 172>,
      <193, 172, 166>,
      <193, 166, 179>,
      <199, 198, 194>,
      <199, 194, 196>,
      <199, 196, 195>,
      <199, 195, 197>,
      <199, 197, 158>,
      <199, 158, 159>,
      <199, 159, 153>,
      <199, 153, 198>,
      <203, 202, 194>,
      <203, 194, 198>,
      <203, 198, 153>,
      <203, 153, 155>,
      <203, 155, 152>,
      <203, 152, 201>,
      <203, 201, 200>,
      <203, 200, 202>,
      <209, 208, 194>,
      <209, 194, 202>,
      <209, 202, 200>,
      <209, 200, 206>,
      <209, 206, 204>,
      <209, 204, 207>,
      <209, 207, 205>,
      <209, 205, 208>,
      <213, 196, 194>,
      <213, 194, 208>,
      <213, 208, 205>,
      <213, 205, 211>,
      <213, 211, 210>,
      <213, 210, 212>,
      <213, 212, 195>,
      <213, 195, 196>,
      <217, 216, 214>,
      <217, 214, 215>,
      <217, 215, 200>,
      <217, 200, 201>,
      <217, 201, 152>,
      <217, 152, 176>,
      <217, 176, 171>,
      <217, 171, 216>,
      <221, 220, 214>,
      <221, 214, 216>,
      <221, 216, 171>,
      <221, 171, 173>,
      <221, 173, 170>,
      <221, 170, 219>,
      <221, 219, 218>,
      <221, 218, 220>,
      <227, 226, 214>,
      <227, 214, 220>,
      <227, 220, 218>,
      <227, 218, 224>,
      <227, 224, 222>,
      <227, 222, 225>,
      <227, 225, 223>,
      <227, 223, 226>,
      <229, 215, 214>,
      <229, 214, 226>,
      <229, 226, 223>,
      <229, 223, 228>,
      <229, 228, 204>,
      <229, 204, 206>,
      <229, 206, 200>,
      <229, 200, 215>,
      <233, 232, 230>,
      <233, 230, 231>,
      <233, 231, 218>,
      <233, 218, 219>,
      <233, 219, 170>,
      <233, 170, 192>,
      <233, 192, 187>,
      <233, 187, 232>,
      <237, 236, 230>,
      <237, 230, 232>,
      <237, 232, 187>,
      <237, 187, 189>,
      <237, 189, 186>,
      <237, 186, 235>,
      <237, 235, 234>,
      <237, 234, 236>,
      <243, 242, 230>,
      <243, 230, 236>,
      <243, 236, 234>,
      <243, 234, 240>,
      <243, 240, 238>,
      <243, 238, 241>,
      <243, 241, 239>,
      <243, 239, 242>,
      <245, 231, 230>,
      <245, 230, 242>,
      <245, 242, 239>,
      <245, 239, 244>,
      <245, 244, 222>,
      <245, 222, 224>,
      <245, 224, 218>,
      <245, 218, 231>,
      <251, 250, 246>,
      <251, 246, 248>,
      <251, 248, 247>,
      <251, 247, 249>,
      <251, 249, 210>,
      <251, 210, 211>,
      <251, 211, 205>,
      <251, 205, 250>,
      <255, 254, 246>,
      <255, 246, 250>,
      <255, 250, 205>,
      <255, 205, 207>,
      <255, 207, 204>,
      <255, 204, 253>,
      <255, 253, 252>,
      <255, 252, 254>,
      <261, 260, 246>,
      <261, 246, 254>,
      <261, 254, 252>,
      <261, 252, 258>,
      <261, 258, 256>,
      <261, 256, 259>,
      <261, 259, 257>,
      <261, 257, 260>,
      <265, 248, 246>,
      <265, 246, 260>,
      <265, 260, 257>,
      <265, 257, 263>,
      <265, 263, 262>,
      <265, 262, 264>,
      <265, 264, 247>,
      <265, 247, 248>,
      <269, 268, 266>,
      <269, 266, 267>,
      <269, 267, 252>,
      <269, 252, 253>,
      <269, 253, 204>,
      <269, 204, 228>,
      <269, 228, 223>,
      <269, 223, 268>,
      <273, 272, 266>,
      <273, 266, 268>,
      <273, 268, 223>,
      <273, 223, 225>,
      <273, 225, 222>,
      <273, 222, 271>,
      <273, 271, 270>,
      <273, 270, 272>,
      <279, 278, 266>,
      <279, 266, 272>,
      <279, 272, 270>,
      <279, 270, 276>,
      <279, 276, 274>,
      <279, 274, 277>,
      <279, 277, 275>,
      <279, 275, 278>,
      <281, 267, 266>,
      <281, 266, 278>,
      <281, 278, 275>,
      <281, 275, 280>,
      <281, 280, 256>,
      <281, 256, 258>,
      <281, 258, 252>,
      <281, 252, 267>,
      <285, 284, 282>,
      <285, 282, 283>,
      <285, 283, 270>,
      <285, 270, 271>,
      <285, 271, 222>,
      <285, 222, 244>,
      <285, 244, 239>,
      <285, 239, 284>,
      <289, 288, 282>,
      <289, 282, 284>,
      <289, 284, 239>,
      <289, 239, 241>,
      <289, 241, 238>,
      <289, 238, 287>,
      <289, 287, 286>,
      <289, 286, 288>,
      <295, 294, 282>,
      <295, 282, 288>,
      <295, 288, 286>,
      <295, 286, 292>,
      <295, 292, 290>,
      <295, 290, 293>,
      <295, 293, 291>,
      <295, 291, 294>,
      <297, 283, 282>,
      <297, 282, 294>,
      <297, 294, 291>,
      <297, 291, 296>,
      <297, 296, 274>,
      <297, 274, 276>,
      <297, 276, 270>,
      <297, 270, 283>,
      <303, 302, 298>,
      <303, 298, 300>,
      <303, 300, 299>,
      <303, 299, 301>,
      <303, 301, 262>,
      <303, 262, 263>,
      <303, 263, 257>,
      <303, 257, 302>,
      <307, 306, 298>,
      <307, 298, 302>,
      <307, 302, 257>,
      <307, 257, 259>,
      <307, 259, 256>,
      <307, 256, 305>,
      <307, 305, 304>,
      <307, 304, 306>,
      <313, 312, 298>,
      <313, 298, 306>,
      <313, 306, 304>,
      <313, 304, 310>,
      <313, 310, 308>,
      <313, 308, 311>,
      <313, 311, 309>,
      <313, 309, 312>,
      <317, 300, 298>,
      <317, 298, 312>,
      <317, 312, 309>,
      <317, 309, 315>,
      <317, 315, 314>,
      <317, 314, 316>,
      <317, 316, 299>,
      <317, 299, 300>,
      <321, 320, 318>,
      <321, 318, 319>,
      <321, 319, 304>,
      <321, 304, 305>,
      <321, 305, 256>,
      <321, 256, 280>,
      <321, 280, 275>,
      <321, 275, 320>,
      <325, 324, 318>,
      <325, 318, 320>,
      <325, 320, 275>,
      <325, 275, 277>,
      <325, 277, 274>,
      <325, 274, 323>,
      <325, 323, 322>,
      <325, 322, 324>,
      <331, 330, 318>,
      <331, 318, 324>,
      <331, 324, 322>,
      <331, 322, 328>,
      <331, 328, 326>,
      <331, 326, 329>,
      <331, 329, 327>,
      <331, 327, 330>,
      <333, 319, 318>,
      <333, 318, 330>,
      <333, 330, 327>,
      <333, 327, 332>,
      <333, 332, 308>,
      <333, 308, 310>,
      <333, 310, 304>,
      <333, 304, 319>,
      <337, 336, 334>,
      <337, 334, 335>,
      <337, 335, 322>,
      <337, 322, 323>,
      <337, 323, 274>,
      <337, 274, 296>,
      <337, 296, 291>,
      <337, 291, 336>,
      <341, 340, 334>,
      <341, 334, 336>,
      <341, 336, 291>,
      <341, 291, 293>,
      <341, 293, 290>,
      <341, 290, 339>,
      <341, 339, 338>,
      <341, 338, 340>,
      <347, 346, 334>,
      <347, 334, 340>,
      <347, 340, 338>,
      <347, 338, 344>,
      <347, 344, 342>,
      <347, 342, 345>,
      <347, 345, 343>,
      <347, 343, 346>,
      <349, 335, 334>,
      <349, 334, 346>,
      <349, 346, 343>,
      <349, 343, 348>,
      <349, 348, 326>,
      <349, 326, 328>,
      <349, 328, 322>,
      <349, 322, 335>,
      <355, 354, 350>,
      <355, 350, 352>,
      <355, 352, 351>,
      <355, 351, 353>,
      <355, 353, 314>,
      <355, 314, 315>,
      <355, 315, 309>,
      <355, 309, 354>,
      <359, 358, 350>,
      <359, 350, 354>,
      <359, 354, 309>,
      <359, 309, 311>,
      <359, 311, 308>,
      <359, 308, 357>,
      <359, 357, 356>,
      <359, 356, 358>,
      <365, 364, 350>,
      <365, 350, 358>,
      <365, 358, 356>,
      <365, 356, 362>,
      <365, 362, 360>,
      <365, 360, 363>,
      <365, 363, 361>,
      <365, 361, 364>,
      <369, 352, 350>,
      <369, 350, 364>,
      <369, 364, 361>,
      <369, 361, 367>,
      <369, 367, 366>,
      <369, 366, 368>,
      <369, 368, 351>,
      <369, 351, 352>,
      <373, 372, 370>,
      <373, 370, 371>,
      <373, 371, 356>,
      <373, 356, 357>,
      <373, 357, 308>,
      <373, 308, 332>,
      <373, 332, 327>,
      <373, 327, 372>,
      <377, 376, 370>,
      <377, 370, 372>,
      <377, 372, 327>,
      <377, 327, 329>,
      <377, 329, 326>,
      <377, 326, 375>,
      <377, 375, 374>,
      <377, 374, 376>,
      <383, 382, 370>,
      <383, 370, 376>,
      <383, 376, 374>,
      <383, 374, 380>,
      <383, 380, 378>,
      <383, 378, 381>,
      <383, 381, 379>,
      <383, 379, 382>,
      <385, 371, 370>,
      <385, 370, 382>,
      <385, 382, 379>,
      <385, 379, 384>,
      <385, 384, 360>,
      <385, 360, 362>,
      <385, 362, 356>,
      <385, 356, 371>,
      <389, 388, 386>,
      <389, 386, 387>,
      <389, 387, 374>,
      <389, 374, 375>,
      <389, 375, 326>,
      <389, 326, 348>,
      <389, 348, 343>,
      <389, 343, 388>,
      <393, 392, 386>,
      <393, 386, 388>,
      <393, 388, 343>,
      <393, 343, 345>,
      <393, 345, 342>,
      <393, 342, 391>,
      <393, 391, 390>,
      <393, 390, 392>,
      <399, 398, 386>,
      <399, 386, 392>,
      <399, 392, 390>,
      <399, 390, 396>,
      <399, 396, 394>,
      <399, 394, 397>,
      <399, 397, 395>,
      <399, 395, 398>,
      <401, 387, 386>,
      <401, 386, 398>,
      <401, 398, 395>,
      <401, 395, 400>,
      <401, 400, 378>,
      <401, 378, 380>,
      <401, 380, 374>,
      <401, 374, 387>,
      <407, 406, 402>,
      <407, 402, 404>,
      <407, 404, 403>,
      <407, 403, 405>,
      <407, 405, 366>,
      <407, 366, 367>,
      <407, 367, 361>,
      <407, 361, 406>,
      <411, 410, 402>,
      <411, 402, 406>,
      <411, 406, 361>,
      <411, 361, 363>,
      <411, 363, 360>,
      <411, 360, 409>,
      <411, 409, 408>,
      <411, 408, 410>,
      <414, 413, 402>,
      <414, 402, 410>,
      <414, 410, 408>,
      <414, 408, 412>,
      <414, 412, 9>,
      <414, 9, 11>,
      <414, 11, 3>,
      <414, 3, 413>,
      <416, 404, 402>,
      <416, 402, 413>,
      <416, 413, 3>,
      <416, 3, 6>,
      <416, 6, 2>,
      <416, 2, 415>,
      <416, 415, 403>,
      <416, 403, 404>,
      <420, 419, 417>,
      <420, 417, 418>,
      <420, 418, 408>,
      <420, 408, 409>,
      <420, 409, 360>,
      <420, 360, 384>,
      <420, 384, 379>,
      <420, 379, 419>,
      <424, 423, 417>,
      <424, 417, 419>,
      <424, 419, 379>,
      <424, 379, 381>,
      <424, 381, 378>,
      <424, 378, 422>,
      <424, 422, 421>,
      <424, 421, 423>,
      <427, 426, 417>,
      <427, 417, 423>,
      <427, 423, 421>,
      <427, 421, 425>,
      <427, 425, 15>,
      <427, 15, 17>,
      <427, 17, 10>,
      <427, 10, 426>,
      <428, 418, 417>,
      <428, 417, 426>,
      <428, 426, 10>,
      <428, 10, 12>,
      <428, 12, 9>,
      <428, 9, 412>,
      <428, 412, 408>,
      <428, 408, 418>,
      <432, 431, 429>,
      <432, 429, 430>,
      <432, 430, 421>,
      <432, 421, 422>,
      <432, 422, 378>,
      <432, 378, 400>,
      <432, 400, 395>,
      <432, 395, 431>,
      <436, 435, 429>,
      <436, 429, 431>,
      <436, 431, 395>,
      <436, 395, 397>,
      <436, 397, 394>,
      <436, 394, 434>,
      <436, 434, 433>,
      <436, 433, 435>,
      <439, 438, 429>,
      <439, 429, 435>,
      <439, 435, 433>,
      <439, 433, 437>,
      <439, 437, 21>,
      <439, 21, 22>,
      <439, 22, 16>,
      <439, 16, 438>,
      <440, 430, 429>,
      <440, 429, 438>,
      <440, 438, 16>,
      <440, 16, 18>,
      <440, 18, 15>,
      <440, 15, 425>,
      <440, 425, 421>,
      <440, 421, 430>,
      <448, 447, 441>,
      <448, 441, 444>,
      <448, 444, 442>,
      <448, 442, 445>,
      <448, 445, 366>,
      <448, 366, 446>,
      <448, 446, 443>,
      <448, 443, 447>,
      <453, 452, 441>,
      <453, 441, 447>,
      <453, 447, 443>,
      <453, 443, 450>,
      <453, 450, 394>,
      <453, 394, 451>,
      <453, 451, 449>,
      <453, 449, 452>,
      <458, 457, 441>,
      <458, 441, 452>,
      <458, 452, 449>,
      <458, 449, 455>,
      <458, 455, 21>,
      <458, 21, 456>,
      <458, 456, 454>,
      <458, 454, 457>,
      <461, 444, 441>,
      <461, 441, 457>,
      <461, 457, 454>,
      <461, 454, 459>,
      <461, 459, 2>,
      <461, 2, 460>,
      <461, 460, 442>,
      <461, 442, 444>,
      <467, 466, 462>,
      <467, 462, 464>,
      <467, 464, 463>,
      <467, 463, 465>,
      <467, 465, 314>,
      <467, 314, 353>,
      <467, 353, 351>,
      <467, 351, 466>,
      <471, 470, 462>,
      <471, 462, 466>,
      <471, 466, 351>,
      <471, 351, 368>,
      <471, 368, 366>,
      <471, 366, 469>,
      <471, 469, 468>,
      <471, 468, 470>,
      <474, 473, 462>,
      <474, 462, 470>,
      <474, 470, 468>,
      <474, 468, 472>,
      <474, 472, 394>,
      <474, 394, 396>,
      <474, 396, 390>,
      <474, 390, 473>,
      <476, 464, 462>,
      <476, 462, 473>,
      <476, 473, 390>,
      <476, 390, 391>,
      <476, 391, 342>,
      <476, 342, 475>,
      <476, 475, 463>,
      <476, 463, 464>,
      <484, 483, 477>,
      <484, 477, 480>,
      <484, 480, 478>,
      <484, 478, 481>,
      <484, 481, 262>,
      <484, 262, 482>,
      <484, 482, 479>,
      <484, 479, 483>,
      <489, 488, 477>,
      <489, 477, 483>,
      <489, 483, 479>,
      <489, 479, 486>,
      <489, 486, 290>,
      <489, 290, 487>,
      <489, 487, 485>,
      <489, 485, 488>,
      <494, 493, 477>,
      <494, 477, 488>,
      <494, 488, 485>,
      <494, 485, 491>,
      <494, 491, 342>,
      <494, 342, 492>,
      <494, 492, 490>,
      <494, 490, 493>,
      <497, 480, 477>,
      <497, 477, 493>,
      <497, 493, 490>,
      <497, 490, 495>,
      <497, 495, 314>,
      <497, 314, 496>,
      <497, 496, 478>,
      <497, 478, 480>,
      <503, 502, 498>,
      <503, 498, 500>,
      <503, 500, 499>,
      <503, 499, 501>,
      <503, 501, 210>,
      <503, 210, 249>,
      <503, 249, 247>,
      <503, 247, 502>,
      <507, 506, 498>,
      <507, 498, 502>,
      <507, 502, 247>,
      <507, 247, 264>,
      <507, 264, 262>,
      <507, 262, 505>,
      <507, 505, 504>,
      <507, 504, 506>,
      <510, 509, 498>,
      <510, 498, 506>,
      <510, 506, 504>,
      <510, 504, 508>,
      <510, 508, 290>,
      <510, 290, 292>,
      <510, 292, 286>,
      <510, 286, 509>,
      <512, 500, 498>,
      <512, 498, 509>,
      <512, 509, 286>,
      <512, 286, 287>,
      <512, 287, 238>,
      <512, 238, 511>,
      <512, 511, 499>,
      <512, 499, 500>,
      <520, 519, 513>,
      <520, 513, 516>,
      <520, 516, 514>,
      <520, 514, 517>,
      <520, 517, 158>,
      <520, 158, 518>,
      <520, 518, 515>,
      <520, 515, 519>,
      <525, 524, 513>,
      <525, 513, 519>,
      <525, 519, 515>,
      <525, 515, 522>,
      <525, 522, 186>,
      <525, 186, 523>,
      <525, 523, 521>,
      <525, 521, 524>,
      <530, 529, 513>,
      <530, 513, 524>,
      <530, 524, 521>,
      <530, 521, 527>,
      <530, 527, 238>,
      <530, 238, 528>,
      <530, 528, 526>,
      <530, 526, 529>,
      <533, 516, 513>,
      <533, 513, 529>,
      <533, 529, 526>,
      <533, 526, 531>,
      <533, 531, 210>,
      <533, 210, 532>,
      <533, 532, 514>,
      <533, 514, 516>,
      <539, 538, 534>,
      <539, 534, 536>,
      <539, 536, 535>,
      <539, 535, 537>,
      <539, 537, 106>,
      <539, 106, 145>,
      <539, 145, 143>,
      <539, 143, 538>,
      <543, 542, 534>,
      <543, 534, 538>,
      <543, 538, 143>,
      <543, 143, 160>,
      <543, 160, 158>,
      <543, 158, 541>,
      <543, 541, 540>,
      <543, 540, 542>,
      <546, 545, 534>,
      <546, 534, 542>,
      <546, 542, 540>,
      <546, 540, 544>,
      <546, 544, 186>,
      <546, 186, 188>,
      <546, 188, 182>,
      <546, 182, 545>,
      <548, 536, 534>,
      <548, 534, 545>,
      <548, 545, 182>,
      <548, 182, 183>,
      <548, 183, 134>,
      <548, 134, 547>,
      <548, 547, 535>,
      <548, 535, 536>,
      <556, 555, 549>,
      <556, 549, 552>,
      <556, 552, 550>,
      <556, 550, 553>,
      <556, 553, 27>,
      <556, 27, 554>,
      <556, 554, 551>,
      <556, 551, 555>,
      <561, 560, 549>,
      <561, 549, 555>,
      <561, 555, 551>,
      <561, 551, 558>,
      <561, 558, 76>,
      <561, 76, 559>,
      <561, 559, 557>,
      <561, 557, 560>,
      <566, 565, 549>,
      <566, 549, 560>,
      <566, 560, 557>,
      <566, 557, 563>,
      <566, 563, 134>,
      <566, 134, 564>,
      <566, 564, 562>,
      <566, 562, 565>,
      <569, 552, 549>,
      <569, 549, 565>,
      <569, 565, 562>,
      <569, 562, 567>,
      <569, 567, 106>,
      <569, 106, 568>,
      <569, 568, 550>,
      <569, 550, 552>,
      <573, 572, 570>,
      <573, 570, 571>,
      <573, 571, 551>,
      <573, 551, 554>,
      <573, 554, 27>,
      <573, 27, 30>,
      <573, 30, 26>,
      <573, 26, 572>,
      <577, 576, 570>,
      <577, 570, 572>,
      <577, 572, 26>,
      <577, 26, 48>,
      <577, 48, 46>,
      <577, 46, 575>,
      <577, 575, 574>,
      <577, 574, 576>,
      <580, 579, 570>,
      <580, 570, 576>,
      <580, 576, 574>,
      <580, 574, 578>,
      <580, 578, 82>,
      <580, 82, 84>,
      <580, 84, 77>,
      <580, 77, 579>,
      <581, 571, 570>,
      <581, 570, 579>,
      <581, 579, 77>,
      <581, 77, 79>,
      <581, 79, 76>,
      <581, 76, 558>,
      <581, 558, 551>,
      <581, 551, 571>
    }
    normal_indices {
      1056,   // from 0 triangles and 528 quads
      <0, 1, 2>,
      <0, 2, 3>,
      <0, 3, 4>,
      <0, 4, 5>,
      <0, 6, 7>,
      <0, 7, 8>,
      <0, 9, 10>,
      <0, 10, 1>,
      <11, 12, 2>,
      <11, 2, 1>,
      <11, 1, 13>,
      <11, 13, 14>,
      <11, 15, 16>,
      <11, 16, 17>,
      <11, 18, 19>,
      <11, 19, 12>,
      <20, 21, 2>,
      <20, 2, 12>,
      <20, 12, 22>,
      <20, 22, 23>,
      <20, 24, 25>,
      <20, 25, 26>,
      <20, 27, 28>,
      <20, 28, 21>,
      <29, 3, 2>,
      <29, 2, 21>,
      <29, 21, 30>,
      <29, 30, 31>,
      <29, 32, 33>,
      <29, 33, 34>,
      <29, 35, 36>,
      <29, 36, 3>,
      <37, 38, 39>,
      <37, 39, 40>,
      <37, 40, 41>,
      <37, 41, 42>,
      <37, 43, 44>,
      <37, 44, 45>,
      <37, 46, 47>,
      <37, 47, 38>,
      <48, 49, 39>,
      <48, 39, 38>,
      <48, 38, 50>,
      <48, 50, 51>,
      <48, 52, 53>,
      <48, 53, 54>,
      <48, 55, 56>,
      <48, 56, 49>,
      <57, 58, 39>,
      <57, 39, 49>,
      <57, 49, 59>,
      <57, 59, 60>,
      <57, 61, 62>,
      <57, 62, 63>,
      <57, 64, 65>,
      <57, 65, 58>,
      <66, 40, 39>,
      <66, 39, 58>,
      <66, 58, 67>,
      <66, 67, 68>,
      <66, 69, 70>,
      <66, 70, 71>,
      <66, 72, 73>,
      <66, 73, 40>,
      <74, 75, 76>,
      <74, 76, 77>,
      <74, 77, 78>,
      <74, 78, 79>,
      <74, 80, 81>,
      <74, 81, 82>,
      <74, 83, 84>,
      <74, 84, 75>,
      <85, 86, 76>,
      <85, 76, 75>,
      <85, 75, 87>,
      <85, 87, 88>,
      <85, 89, 90>,
      <85, 90, 91>,
      <85, 92, 93>,
      <85, 93, 86>,
      <94, 95, 76>,
      <94, 76, 86>,
      <94, 86, 96>,
      <94, 96, 97>,
      <94, 98, 99>,
      <94, 99, 100>,
      <94, 101, 102>,
      <94, 102, 95>,
      <103, 77, 76>,
      <103, 76, 95>,
      <103, 95, 104>,
      <103, 104, 105>,
      <103, 106, 107>,
      <103, 107, 108>,
      <103, 109, 110>,
      <103, 110, 77>,
      <111, 112, 113>,
      <111, 113, 114>,
      <111, 114, 115>,
      <111, 115, 116>,
      <111, 117, 118>,
      <111, 118, 119>,
      <111, 120, 121>,
      <111, 121, 112>,
      <122, 123, 113>,
      <122, 113, 112>,
      <122, 112, 124>,
      <122, 124, 125>,
      <122, 126, 127>,
      <122, 127, 128>,
      <122, 129, 130>,
      <122, 130, 123>,
      <131, 132, 113>,
      <131, 113, 123>,
      <131, 123, 133>,
      <131, 133, 134>,
      <131, 135, 136>,
      <131, 136, 137>,
      <131, 138, 139>,
      <131, 139, 132>,
      <140, 114, 113>,
      <140, 113, 132>,
      <140, 132, 141>,
      <140, 141, 142>,
      <140, 143, 144>,
      <140, 144, 145>,
      <140, 146, 147>,
      <140, 147, 114>,
      <148, 149, 150>,
      <148, 150, 151>,
      <148, 151, 152>,
      <148, 152, 153>,
      <148, 154, 155>,
      <148, 155, 156>,
      <148, 157, 158>,
      <148, 158, 149>,
      <159, 160, 150>,
      <159, 150, 149>,
      <159, 149, 161>,
      <159, 161, 162>,
      <159, 163, 164>,
      <159, 164, 165>,
      <159, 166, 167>,
      <159, 167, 160>,
      <168, 169, 150>,
      <168, 150, 160>,
      <168, 160, 170>,
      <168, 170, 171>,
      <168, 172, 173>,
      <168, 173, 174>,
      <168, 175, 176>,
      <168, 176, 169>,
      <177, 151, 150>,
      <177, 150, 169>,
      <177, 169, 178>,
      <177, 178, 179>,
      <177, 180, 181>,
      <177, 181, 182>,
      <177, 183, 184>,
      <177, 184, 151>,
      <185, 186, 187>,
      <185, 187, 188>,
      <185, 188, 189>,
      <185, 189, 190>,
      <185, 191, 192>,
      <185, 192, 193>,
      <185, 194, 195>,
      <185, 195, 186>,
      <196, 197, 187>,
      <196, 187, 186>,
      <196, 186, 198>,
      <196, 198, 199>,
      <196, 200, 201>,
      <196, 201, 202>,
      <196, 203, 204>,
      <196, 204, 197>,
      <205, 206, 187>,
      <205, 187, 197>,
      <205, 197, 207>,
      <205, 207, 208>,
      <205, 209, 210>,
      <205, 210, 211>,
      <205, 212, 213>,
      <205, 213, 206>,
      <214, 188, 187>,
      <214, 187, 206>,
      <214, 206, 215>,
      <214, 215, 216>,
      <214, 217, 218>,
      <214, 218, 219>,
      <214, 220, 221>,
      <214, 221, 188>,
      <222, 223, 224>,
      <222, 224, 225>,
      <222, 225, 226>,
      <222, 226, 227>,
      <222, 228, 229>,
      <222, 229, 230>,
      <222, 231, 232>,
      <222, 232, 223>,
      <233, 234, 224>,
      <233, 224, 223>,
      <233, 223, 235>,
      <233, 235, 236>,
      <233, 237, 238>,
      <233, 238, 239>,
      <233, 240, 241>,
      <233, 241, 234>,
      <242, 243, 224>,
      <242, 224, 234>,
      <242, 234, 244>,
      <242, 244, 245>,
      <242, 246, 247>,
      <242, 247, 248>,
      <242, 249, 250>,
      <242, 250, 243>,
      <251, 225, 224>,
      <251, 224, 243>,
      <251, 243, 252>,
      <251, 252, 253>,
      <251, 254, 255>,
      <251, 255, 256>,
      <251, 257, 258>,
      <251, 258, 225>,
      <259, 260, 261>,
      <259, 261, 262>,
      <259, 262, 263>,
      <259, 263, 264>,
      <259, 265, 266>,
      <259, 266, 267>,
      <259, 268, 269>,
      <259, 269, 260>,
      <270, 271, 261>,
      <270, 261, 260>,
      <270, 260, 272>,
      <270, 272, 273>,
      <270, 274, 275>,
      <270, 275, 276>,
      <270, 277, 278>,
      <270, 278, 271>,
      <279, 280, 261>,
      <279, 261, 271>,
      <279, 271, 281>,
      <279, 281, 282>,
      <279, 283, 284>,
      <279, 284, 285>,
      <279, 286, 287>,
      <279, 287, 280>,
      <288, 262, 261>,
      <288, 261, 280>,
      <288, 280, 289>,
      <288, 289, 290>,
      <288, 291, 292>,
      <288, 292, 293>,
      <288, 294, 295>,
      <288, 295, 262>,
      <296, 297, 298>,
      <296, 298, 299>,
      <296, 299, 300>,
      <296, 300, 301>,
      <296, 302, 303>,
      <296, 303, 304>,
      <296, 305, 306>,
      <296, 306, 297>,
      <307, 308, 298>,
      <307, 298, 297>,
      <307, 297, 309>,
      <307, 309, 310>,
      <307, 311, 312>,
      <307, 312, 313>,
      <307, 314, 315>,
      <307, 315, 308>,
      <316, 317, 298>,
      <316, 298, 308>,
      <316, 308, 318>,
      <316, 318, 319>,
      <316, 320, 321>,
      <316, 321, 322>,
      <316, 323, 324>,
      <316, 324, 317>,
      <325, 299, 298>,
      <325, 298, 317>,
      <325, 317, 326>,
      <325, 326, 327>,
      <325, 328, 329>,
      <325, 329, 330>,
      <325, 331, 332>,
      <325, 332, 299>,
      <333, 334, 335>,
      <333, 335, 336>,
      <333, 336, 337>,
      <333, 337, 338>,
      <333, 339, 340>,
      <333, 340, 341>,
      <333, 342, 343>,
      <333, 343, 334>,
      <344, 345, 335>,
      <344, 335, 334>,
      <344, 334, 346>,
      <344, 346, 347>,
      <344, 348, 349>,
      <344, 349, 350>,
      <344, 351, 352>,
      <344, 352, 345>,
      <353, 354, 335>,
      <353, 335, 345>,
      <353, 345, 355>,
      <353, 355, 356>,
      <353, 357, 358>,
      <353, 358, 359>,
      <353, 360, 361>,
      <353, 361, 354>,
      <362, 336, 335>,
      <362, 335, 354>,
      <362, 354, 363>,
      <362, 363, 364>,
      <362, 365, 366>,
      <362, 366, 367>,
      <362, 368, 369>,
      <362, 369, 336>,
      <370, 371, 372>,
      <370, 372, 373>,
      <370, 373, 374>,
      <370, 374, 375>,
      <370, 376, 377>,
      <370, 377, 378>,
      <370, 379, 380>,
      <370, 380, 371>,
      <381, 382, 372>,
      <381, 372, 371>,
      <381, 371, 383>,
      <381, 383, 384>,
      <381, 385, 386>,
      <381, 386, 387>,
      <381, 388, 389>,
      <381, 389, 382>,
      <390, 391, 372>,
      <390, 372, 382>,
      <390, 382, 392>,
      <390, 392, 393>,
      <390, 394, 395>,
      <390, 395, 396>,
      <390, 396, 397>,
      <390, 397, 391>,
      <398, 373, 372>,
      <398, 372, 391>,
      <398, 391, 397>,
      <398, 397, 399>,
      <398, 399, 400>,
      <398, 400, 401>,
      <398, 402, 403>,
      <398, 403, 373>,
      <404, 405, 406>,
      <404, 406, 407>,
      <404, 407, 408>,
      <404, 408, 409>,
      <404, 410, 411>,
      <404, 411, 412>,
      <404, 413, 414>,
      <404, 414, 405>,
      <415, 416, 406>,
      <415, 406, 405>,
      <415, 405, 417>,
      <415, 417, 418>,
      <415, 419, 420>,
      <415, 420, 421>,
      <415, 422, 423>,
      <415, 423, 416>,
      <424, 425, 406>,
      <424, 406, 416>,
      <424, 416, 426>,
      <424, 426, 427>,
      <424, 428, 429>,
      <424, 429, 430>,
      <424, 430, 431>,
      <424, 431, 425>,
      <432, 407, 406>,
      <432, 406, 425>,
      <432, 425, 431>,
      <432, 431, 433>,
      <432, 433, 434>,
      <432, 434, 435>,
      <432, 436, 437>,
      <432, 437, 407>,
      <438, 439, 440>,
      <438, 440, 441>,
      <438, 441, 442>,
      <438, 442, 443>,
      <438, 444, 445>,
      <438, 445, 446>,
      <438, 447, 448>,
      <438, 448, 439>,
      <449, 450, 440>,
      <449, 440, 439>,
      <449, 439, 451>,
      <449, 451, 452>,
      <449, 453, 454>,
      <449, 454, 455>,
      <449, 456, 457>,
      <449, 457, 450>,
      <458, 459, 440>,
      <458, 440, 450>,
      <458, 450, 460>,
      <458, 460, 461>,
      <458, 462, 463>,
      <458, 463, 464>,
      <458, 464, 465>,
      <458, 465, 459>,
      <466, 441, 440>,
      <466, 440, 459>,
      <466, 459, 465>,
      <466, 465, 467>,
      <466, 467, 468>,
      <466, 468, 469>,
      <466, 470, 471>,
      <466, 471, 441>,
      <472, 473, 474>,
      <472, 474, 475>,
      <472, 475, 476>,
      <472, 476, 477>,
      <472, 478, 479>,
      <472, 479, 399>,
      <472, 399, 397>,
      <472, 397, 473>,
      <480, 481, 474>,
      <480, 474, 473>,
      <480, 473, 397>,
      <480, 397, 396>,
      <480, 396, 482>,
      <480, 482, 483>,
      <480, 484, 485>,
      <480, 485, 481>,
      <486, 487, 474>,
      <486, 474, 481>,
      <486, 481, 488>,
      <486, 488, 489>,
      <486, 490, 491>,
      <486, 491, 492>,
      <486, 492, 493>,
      <486, 493, 487>,
      <494, 475, 474>,
      <494, 474, 487>,
      <494, 487, 493>,
      <494, 493, 495>,
      <494, 495, 496>,
      <494, 496, 497>,
      <494, 498, 499>,
      <494, 499, 475>,
      <500, 501, 502>,
      <500, 502, 503>,
      <500, 503, 504>,
      <500, 504, 505>,
      <500, 506, 507>,
      <500, 507, 433>,
      <500, 433, 431>,
      <500, 431, 501>,
      <508, 509, 502>,
      <508, 502, 501>,
      <508, 501, 431>,
      <508, 431, 430>,
      <508, 430, 510>,
      <508, 510, 511>,
      <508, 512, 513>,
      <508, 513, 509>,
      <514, 515, 502>,
      <514, 502, 509>,
      <514, 509, 516>,
      <514, 516, 517>,
      <514, 518, 519>,
      <514, 519, 520>,
      <514, 520, 521>,
      <514, 521, 515>,
      <522, 503, 502>,
      <522, 502, 515>,
      <522, 515, 521>,
      <522, 521, 523>,
      <522, 523, 524>,
      <522, 524, 525>,
      <522, 526, 527>,
      <522, 527, 503>,
      <528, 529, 530>,
      <528, 530, 531>,
      <528, 531, 532>,
      <528, 532, 533>,
      <528, 534, 535>,
      <528, 535, 467>,
      <528, 467, 465>,
      <528, 465, 529>,
      <536, 537, 530>,
      <536, 530, 529>,
      <536, 529, 465>,
      <536, 465, 464>,
      <536, 464, 538>,
      <536, 538, 539>,
      <536, 540, 541>,
      <536, 541, 537>,
      <542, 543, 530>,
      <542, 530, 537>,
      <542, 537, 544>,
      <542, 544, 545>,
      <542, 546, 547>,
      <542, 547, 548>,
      <542, 548, 549>,
      <542, 549, 543>,
      <550, 531, 530>,
      <550, 530, 543>,
      <550, 543, 549>,
      <550, 549, 551>,
      <550, 551, 552>,
      <550, 552, 553>,
      <550, 554, 555>,
      <550, 555, 531>,
      <556, 557, 558>,
      <556, 558, 559>,
      <556, 559, 560>,
      <556, 560, 561>,
      <556, 562, 563>,
      <556, 563, 495>,
      <556, 495, 493>,
      <556, 493, 557>,
      <564, 565, 558>,
      <564, 558, 557>,
      <564, 557, 493>,
      <564, 493, 492>,
      <564, 492, 566>,
      <564, 566, 567>,
      <564, 568, 569>,
      <564, 569, 565>,
      <570, 571, 558>,
      <570, 558, 565>,
      <570, 565, 572>,
      <570, 572, 573>,
      <570, 574, 575>,
      <570, 575, 576>,
      <570, 577, 578>,
      <570, 578, 571>,
      <579, 559, 558>,
      <579, 558, 571>,
      <579, 571, 580>,
      <579, 580, 581>,
      <579, 582, 583>,
      <579, 583, 584>,
      <579, 585, 586>,
      <579, 586, 559>,
      <587, 588, 589>,
      <587, 589, 590>,
      <587, 590, 591>,
      <587, 591, 592>,
      <587, 593, 594>,
      <587, 594, 523>,
      <587, 523, 521>,
      <587, 521, 588>,
      <595, 596, 589>,
      <595, 589, 588>,
      <595, 588, 521>,
      <595, 521, 520>,
      <595, 520, 597>,
      <595, 597, 598>,
      <595, 599, 600>,
      <595, 600, 596>,
      <601, 602, 589>,
      <601, 589, 596>,
      <601, 596, 603>,
      <601, 603, 604>,
      <601, 605, 606>,
      <601, 606, 607>,
      <601, 608, 609>,
      <601, 609, 602>,
      <610, 590, 589>,
      <610, 589, 602>,
      <610, 602, 611>,
      <610, 611, 612>,
      <610, 613, 614>,
      <610, 614, 615>,
      <610, 616, 617>,
      <610, 617, 590>,
      <618, 619, 620>,
      <618, 620, 621>,
      <618, 621, 622>,
      <618, 622, 623>,
      <618, 624, 625>,
      <618, 625, 551>,
      <618, 551, 549>,
      <618, 549, 619>,
      <626, 627, 620>,
      <626, 620, 619>,
      <626, 619, 549>,
      <626, 549, 548>,
      <626, 548, 628>,
      <626, 628, 629>,
      <626, 630, 631>,
      <626, 631, 627>,
      <632, 633, 620>,
      <632, 620, 627>,
      <632, 627, 634>,
      <632, 634, 635>,
      <632, 636, 637>,
      <632, 637, 638>,
      <632, 639, 640>,
      <632, 640, 633>,
      <641, 621, 620>,
      <641, 620, 633>,
      <641, 633, 642>,
      <641, 642, 643>,
      <641, 644, 645>,
      <641, 645, 646>,
      <641, 647, 648>,
      <641, 648, 621>,
      <649, 650, 651>,
      <649, 651, 652>,
      <649, 652, 653>,
      <649, 653, 654>,
      <649, 655, 656>,
      <649, 656, 657>,
      <649, 658, 659>,
      <649, 659, 650>,
      <660, 661, 651>,
      <660, 651, 650>,
      <660, 650, 662>,
      <660, 662, 663>,
      <660, 664, 665>,
      <660, 665, 666>,
      <660, 667, 668>,
      <660, 668, 661>,
      <669, 670, 651>,
      <669, 651, 661>,
      <669, 661, 671>,
      <669, 671, 672>,
      <669, 673, 674>,
      <669, 674, 675>,
      <669, 676, 677>,
      <669, 677, 670>,
      <678, 652, 651>,
      <678, 651, 670>,
      <678, 670, 679>,
      <678, 679, 680>,
      <678, 681, 682>,
      <678, 682, 683>,
      <678, 684, 685>,
      <678, 685, 652>,
      <686, 687, 688>,
      <686, 688, 689>,
      <686, 689, 690>,
      <686, 690, 691>,
      <686, 692, 693>,
      <686, 693, 694>,
      <686, 695, 696>,
      <686, 696, 687>,
      <697, 698, 688>,
      <697, 688, 687>,
      <697, 687, 699>,
      <697, 699, 700>,
      <697, 701, 702>,
      <697, 702, 703>,
      <697, 704, 705>,
      <697, 705, 698>,
      <706, 707, 688>,
      <706, 688, 698>,
      <706, 698, 708>,
      <706, 708, 709>,
      <706, 710, 711>,
      <706, 711, 712>,
      <706, 713, 714>,
      <706, 714, 707>,
      <715, 689, 688>,
      <715, 688, 707>,
      <715, 707, 716>,
      <715, 716, 717>,
      <715, 718, 719>,
      <715, 719, 720>,
      <715, 721, 722>,
      <715, 722, 689>,
      <723, 724, 725>,
      <723, 725, 726>,
      <723, 726, 727>,
      <723, 727, 728>,
      <723, 729, 730>,
      <723, 730, 731>,
      <723, 732, 733>,
      <723, 733, 724>,
      <734, 735, 725>,
      <734, 725, 724>,
      <734, 724, 736>,
      <734, 736, 737>,
      <734, 738, 739>,
      <734, 739, 740>,
      <734, 741, 742>,
      <734, 742, 735>,
      <743, 744, 725>,
      <743, 725, 735>,
      <743, 735, 745>,
      <743, 745, 746>,
      <743, 747, 748>,
      <743, 748, 749>,
      <743, 750, 751>,
      <743, 751, 744>,
      <752, 726, 725>,
      <752, 725, 744>,
      <752, 744, 753>,
      <752, 753, 754>,
      <752, 755, 756>,
      <752, 756, 757>,
      <752, 758, 759>,
      <752, 759, 726>,
      <760, 761, 762>,
      <760, 762, 763>,
      <760, 763, 764>,
      <760, 764, 765>,
      <760, 766, 767>,
      <760, 767, 768>,
      <760, 769, 770>,
      <760, 770, 761>,
      <771, 772, 762>,
      <771, 762, 761>,
      <771, 761, 773>,
      <771, 773, 774>,
      <771, 775, 776>,
      <771, 776, 777>,
      <771, 778, 779>,
      <771, 779, 772>,
      <780, 781, 762>,
      <780, 762, 772>,
      <780, 772, 782>,
      <780, 782, 783>,
      <780, 784, 785>,
      <780, 785, 786>,
      <780, 787, 788>,
      <780, 788, 781>,
      <789, 763, 762>,
      <789, 762, 781>,
      <789, 781, 790>,
      <789, 790, 791>,
      <789, 792, 793>,
      <789, 793, 794>,
      <789, 795, 796>,
      <789, 796, 763>,
      <797, 798, 799>,
      <797, 799, 800>,
      <797, 800, 801>,
      <797, 801, 802>,
      <797, 803, 804>,
      <797, 804, 805>,
      <797, 806, 807>,
      <797, 807, 798>,
      <808, 809, 799>,
      <808, 799, 798>,
      <808, 798, 810>,
      <808, 810, 811>,
      <808, 812, 813>,
      <808, 813, 814>,
      <808, 815, 816>,
      <808, 816, 809>,
      <817, 818, 799>,
      <817, 799, 809>,
      <817, 809, 819>,
      <817, 819, 820>,
      <817, 821, 822>,
      <817, 822, 823>,
      <817, 824, 825>,
      <817, 825, 818>,
      <826, 800, 799>,
      <826, 799, 818>,
      <826, 818, 827>,
      <826, 827, 828>,
      <826, 829, 830>,
      <826, 830, 831>,
      <826, 832, 833>,
      <826, 833, 800>,
      <834, 835, 836>,
      <834, 836, 837>,
      <834, 837, 838>,
      <834, 838, 839>,
      <834, 840, 841>,
      <834, 841, 842>,
      <834, 843, 844>,
      <834, 844, 835>,
      <845, 846, 836>,
      <845, 836, 835>,
      <845, 835, 847>,
      <845, 847, 848>,
      <845, 849, 850>,
      <845, 850, 851>,
      <845, 852, 853>,
      <845, 853, 846>,
      <854, 855, 836>,
      <854, 836, 846>,
      <854, 846, 856>,
      <854, 856, 857>,
      <854, 858, 859>,
      <854, 859, 860>,
      <854, 861, 862>,
      <854, 862, 855>,
      <863, 837, 836>,
      <863, 836, 855>,
      <863, 855, 864>,
      <863, 864, 865>,
      <863, 866, 867>,
      <863, 867, 868>,
      <863, 869, 870>,
      <863, 870, 837>,
      <871, 872, 873>,
      <871, 873, 874>,
      <871, 874, 875>,
      <871, 875, 876>,
      <871, 877, 878>,
      <871, 878, 879>,
      <871, 880, 881>,
      <871, 881, 872>,
      <882, 883, 873>,
      <882, 873, 872>,
      <882, 872, 884>,
      <882, 884, 885>,
      <882, 886, 887>,
      <882, 887, 888>,
      <882, 889, 890>,
      <882, 890, 883>,
      <891, 892, 873>,
      <891, 873, 883>,
      <891, 883, 893>,
      <891, 893, 894>,
      <891, 895, 896>,
      <891, 896, 897>,
      <891, 898, 899>,
      <891, 899, 892>,
      <900, 874, 873>,
      <900, 873, 892>,
      <900, 892, 901>,
      <900, 901, 902>,
      <900, 903, 904>,
      <900, 904, 905>,
      <900, 906, 907>,
      <900, 907, 874>,
      <908, 909, 910>,
      <908, 910, 911>,
      <908, 911, 912>,
      <908, 912, 913>,
      <908, 914, 915>,
      <908, 915, 916>,
      <908, 917, 918>,
      <908, 918, 909>,
      <919, 920, 910>,
      <919, 910, 909>,
      <919, 909, 921>,
      <919, 921, 922>,
      <919, 923, 924>,
      <919, 924, 925>,
      <919, 926, 927>,
      <919, 927, 920>,
      <928, 929, 910>,
      <928, 910, 920>,
      <928, 920, 930>,
      <928, 930, 931>,
      <928, 932, 933>,
      <928, 933, 934>,
      <928, 935, 936>,
      <928, 936, 929>,
      <937, 911, 910>,
      <937, 910, 929>,
      <937, 929, 938>,
      <937, 938, 939>,
      <937, 940, 941>,
      <937, 941, 942>,
      <937, 943, 944>,
      <937, 944, 911>,
      <945, 946, 947>,
      <945, 947, 948>,
      <945, 948, 949>,
      <945, 949, 950>,
      <945, 951, 952>,
      <945, 952, 953>,
      <945, 954, 955>,
      <945, 955, 946>,
      <956, 957, 947>,
      <956, 947, 946>,
      <956, 946, 958>,
      <956, 958, 959>,
      <956, 960, 961>,
      <956, 961, 962>,
      <956, 963, 964>,
      <956, 964, 957>,
      <965, 966, 947>,
      <965, 947, 957>,
      <965, 957, 967>,
      <965, 967, 968>,
      <965, 969, 970>,
      <965, 970, 971>,
      <965, 972, 973>,
      <965, 973, 966>,
      <974, 948, 947>,
      <974, 947, 966>,
      <974, 966, 975>,
      <974, 975, 976>,
      <974, 977, 978>,
      <974, 978, 979>,
      <974, 980, 981>,
      <974, 981, 948>,
      <982, 983, 984>,
      <982, 984, 985>,
      <982, 985, 986>,
      <982, 986, 987>,
      <982, 988, 989>,
      <982, 989, 990>,
      <982, 991, 992>,
      <982, 992, 983>,
      <993, 994, 984>,
      <993, 984, 983>,
      <993, 983, 995>,
      <993, 995, 996>,
      <993, 997, 998>,
      <993, 998, 999>,
      <993, 1000, 1001>,
      <993, 1001, 994>,
      <1002, 1003, 984>,
      <1002, 984, 994>,
      <1002, 994, 1004>,
      <1002, 1004, 1005>,
      <1002, 1006, 1007>,
      <1002, 1007, 1008>,
      <1002, 1009, 1010>,
      <1002, 1010, 1003>,
      <1011, 985, 984>,
      <1011, 984, 1003>,
      <1011, 1003, 1012>,
      <1011, 1012, 1013>,
      <1011, 1014, 1015>,
      <1011, 1015, 1016>,
      <1011, 1017, 1018>,
      <1011, 1018, 985>,
      <1019, 1020, 1021>,
      <1019, 1021, 1022>,
      <1019, 1022, 1023>,
      <1019, 1023, 1024>,
      <1019, 1025, 1026>,
      <1019, 1026, 1027>,
      <1019, 1028, 1029>,
      <1019, 1029, 1020>,
      <1030, 1031, 1021>,
      <1030, 1021, 1020>,
      <1030, 1020, 1032>,
      <1030, 1032, 1033>,
      <1030, 1034, 1035>,
      <1030, 1035, 1036>,
      <1030, 1037, 1038>,
      <1030, 1038, 1031>,
      <1039, 1040, 1021>,
      <1039, 1021, 1031>,
      <1039, 1031, 1041>,
      <1039, 1041, 1042>,
      <1039, 1043, 1044>,
      <1039, 1044, 1045>,
      <1039, 1046, 1047>,
      <1039, 1047, 1040>,
      <1048, 1022, 1021>,
      <1048, 1021, 1040>,
      <1048, 1040, 1049>,
      <1048, 1049, 1050>,
      <1048, 1051, 1052>,
      <1048, 1052, 1053>,
      <1048, 1054, 1055>,
      <1048, 1055, 1022>,
      <1056, 1057, 1058>,
      <1056, 1058, 1059>,
      <1056, 1059, 1060>,
      <1056, 1060, 1061>,
      <1056, 1062, 1063>,
      <1056, 1063, 1064>,
      <1056, 1065, 1066>,
      <1056, 1066, 1057>,
      <1067, 1068, 1058>,
      <1067, 1058, 1057>,
      <1067, 1057, 1069>,
      <1067, 1069, 1070>,
      <1067, 1071, 1072>,
      <1067, 1072, 1073>,
      <1067, 1074, 1075>,
      <1067, 1075, 1068>,
      <1076, 1077, 1058>,
      <1076, 1058, 1068>,
      <1076, 1068, 1078>,
      <1076, 1078, 1079>,
      <1076, 1080, 1081>,
      <1076, 1081, 1082>,
      <1076, 1083, 1084>,
      <1076, 1084, 1077>,
      <1085, 1059, 1058>,
      <1085, 1058, 1077>,
      <1085, 1077, 1086>,
      <1085, 1086, 1087>,
      <1085, 1088, 1089>,
      <1085, 1089, 1090>,
      <1085, 1091, 1092>,
      <1085, 1092, 1059>,
      <1093, 1094, 1095>,
      <1093, 1095, 1096>,
      <1093, 1096, 1097>,
      <1093, 1097, 1098>,
      <1093, 1099, 1100>,
      <1093, 1100, 1101>,
      <1093, 1101, 1102>,
      <1093, 1102, 1094>,
      <1103, 1104, 1095>,
      <1103, 1095, 1094>,
      <1103, 1094, 1102>,
      <1103, 1102, 1105>,
      <1103, 1105, 1106>,
      <1103, 1106, 1107>,
      <1103, 1108, 1109>,
      <1103, 1109, 1104>,
      <1110, 1111, 1095>,
      <1110, 1095, 1104>,
      <1110, 1104, 1112>,
      <1110, 1112, 1113>,
      <1110, 1114, 1115>,
      <1110, 1115, 1116>,
      <1110, 1117, 1118>,
      <1110, 1118, 1111>,
      <1119, 1096, 1095>,
      <1119, 1095, 1111>,
      <1119, 1111, 1120>,
      <1119, 1120, 1121>,
      <1119, 1122, 1123>,
      <1119, 1123, 1124>,
      <1119, 1125, 1126>,
      <1119, 1126, 1096>,
      <1127, 1128, 1129>,
      <1127, 1129, 1130>,
      <1127, 1130, 1102>,
      <1127, 1102, 1101>,
      <1127, 1101, 1131>,
      <1127, 1131, 1132>,
      <1127, 1133, 1134>,
      <1127, 1134, 1128>,
      <1135, 1136, 1129>,
      <1135, 1129, 1128>,
      <1135, 1128, 1137>,
      <1135, 1137, 1138>,
      <1135, 1139, 1140>,
      <1135, 1140, 1141>,
      <1135, 1142, 1143>,
      <1135, 1143, 1136>,
      <1144, 1145, 1129>,
      <1144, 1129, 1136>,
      <1144, 1136, 1146>,
      <1144, 1146, 1147>,
      <1144, 1148, 1149>,
      <1144, 1149, 1150>,
      <1144, 1151, 1152>,
      <1144, 1152, 1145>,
      <1153, 1130, 1129>,
      <1153, 1129, 1145>,
      <1153, 1145, 1154>,
      <1153, 1154, 1155>,
      <1153, 1156, 1157>,
      <1153, 1157, 1105>,
      <1153, 1105, 1102>,
      <1153, 1102, 1130>
    }
    uv_indices {
      1056,   // from 0 triangles and 528 quads
      <569, 577, 570>,
      <569, 570, 574>      <569, 574, 571>,
      <569, 571, 575>      <569, 575, 572>,
      <569, 572, 576>      <569, 576, 573>,
      <569, 573, 577>      <578, 586, 579>,
      <578, 579, 583>      <578, 583, 580>,
      <578, 580, 584>      <578, 584, 581>,
      <578, 581, 585>      <578, 585, 582>,
      <578, 582, 586>      <587, 595, 588>,
      <587, 588, 592>      <587, 592, 589>,
      <587, 589, 593>      <587, 593, 590>,
      <587, 590, 594>      <587, 594, 591>,
      <587, 591, 595>      <596, 604, 597>,
      <596, 597, 601>      <596, 601, 598>,
      <596, 598, 602>      <596, 602, 599>,
      <596, 599, 603>      <596, 603, 600>,
      <596, 600, 604>      <605, 613, 606>,
      <605, 606, 610>      <605, 610, 607>,
      <605, 607, 611>      <605, 611, 608>,
      <605, 608, 612>      <605, 612, 609>,
      <605, 609, 613>      <614, 622, 615>,
      <614, 615, 619>      <614, 619, 616>,
      <614, 616, 620>      <614, 620, 617>,
      <614, 617, 621>      <614, 621, 618>,
      <614, 618, 622>      <623, 631, 624>,
      <623, 624, 628>      <623, 628, 625>,
      <623, 625, 629>      <623, 629, 626>,
      <623, 626, 630>      <623, 630, 627>,
      <623, 627, 631>      <632, 640, 633>,
      <632, 633, 637>      <632, 637, 634>,
      <632, 634, 638>      <632, 638, 635>,
      <632, 635, 639>      <632, 639, 636>,
      <632, 636, 640>      <641, 649, 642>,
      <641, 642, 646>      <641, 646, 643>,
      <641, 643, 647>      <641, 647, 644>,
      <641, 644, 648>      <641, 648, 645>,
      <641, 645, 649>      <650, 658, 651>,
      <650, 651, 655>      <650, 655, 652>,
      <650, 652, 656>      <650, 656, 653>,
      <650, 653, 657>      <650, 657, 654>,
      <650, 654, 658>      <659, 667, 660>,
      <659, 660, 664>      <659, 664, 661>,
      <659, 661, 665>      <659, 665, 662>,
      <659, 662, 666>      <659, 666, 663>,
      <659, 663, 667>      <668, 676, 669>,
      <668, 669, 673>      <668, 673, 670>,
      <668, 670, 674>      <668, 674, 671>,
      <668, 671, 675>      <668, 675, 672>,
      <668, 672, 676>      <677, 685, 678>,
      <677, 678, 682>      <677, 682, 679>,
      <677, 679, 683>      <677, 683, 680>,
      <677, 680, 684>      <677, 684, 681>,
      <677, 681, 685>      <686, 694, 687>,
      <686, 687, 691>      <686, 691, 688>,
      <686, 688, 692>      <686, 692, 689>,
      <686, 689, 693>      <686, 693, 690>,
      <686, 690, 694>      <695, 703, 696>,
      <695, 696, 700>      <695, 700, 697>,
      <695, 697, 701>      <695, 701, 698>,
      <695, 698, 702>      <695, 702, 699>,
      <695, 699, 703>      <704, 712, 705>,
      <704, 705, 709>      <704, 709, 706>,
      <704, 706, 710>      <704, 710, 707>,
      <704, 707, 711>      <704, 711, 708>,
      <704, 708, 712>      <713, 721, 714>,
      <713, 714, 718>      <713, 718, 715>,
      <713, 715, 719>      <713, 719, 716>,
      <713, 716, 720>      <713, 720, 717>,
      <713, 717, 721>      <722, 730, 723>,
      <722, 723, 727>      <722, 727, 724>,
      <722, 724, 728>      <722, 728, 725>,
      <722, 725, 729>      <722, 729, 726>,
      <722, 726, 730>      <731, 739, 732>,
      <731, 732, 736>      <731, 736, 733>,
      <731, 733, 737>      <731, 737, 734>,
      <731, 734, 738>      <731, 738, 735>,
      <731, 735, 739>      <740, 748, 741>,
      <740, 741, 745>      <740, 745, 742>,
      <740, 742, 746>      <740, 746, 743>,
      <740, 743, 747>      <740, 747, 744>,
      <740, 744, 748>      <749, 757, 750>,
      <749, 750, 754>      <749, 754, 751>,
      <749, 751, 755>      <749, 755, 752>,
      <749, 752, 756>      <749, 756, 753>,
      <749, 753, 757>      <758, 766, 759>,
      <758, 759, 763>      <758, 763, 760>,
      <758, 760, 764>      <758, 764, 761>,
      <758, 761, 765>      <758, 765, 762>,
      <758, 762, 766>      <767, 775, 768>,
      <767, 768, 772>      <767, 772, 769>,
      <767, 769, 773>      <767, 773, 770>,
      <767, 770, 774>      <767, 774, 771>,
      <767, 771, 775>      <776, 784, 777>,
      <776, 777, 781>      <776, 781, 778>,
      <776, 778, 782>      <776, 782, 779>,
      <776, 779, 783>      <776, 783, 780>,
      <776, 780, 784>      <785, 793, 786>,
      <785, 786, 790>      <785, 790, 787>,
      <785, 787, 791>      <785, 791, 788>,
      <785, 788, 792>      <785, 792, 789>,
      <785, 789, 793>      <794, 802, 795>,
      <794, 795, 799>      <794, 799, 796>,
      <794, 796, 800>      <794, 800, 797>,
      <794, 797, 801>      <794, 801, 798>,
      <794, 798, 802>      <803, 811, 804>,
      <803, 804, 808>      <803, 808, 805>,
      <803, 805, 809>      <803, 809, 806>,
      <803, 806, 810>      <803, 810, 807>,
      <803, 807, 811>      <812, 820, 813>,
      <812, 813, 817>      <812, 817, 814>,
      <812, 814, 818>      <812, 818, 815>,
      <812, 815, 819>      <812, 819, 816>,
      <812, 816, 820>      <821, 829, 822>,
      <821, 822, 826>      <821, 826, 823>,
      <821, 823, 827>      <821, 827, 824>,
      <821, 824, 828>      <821, 828, 825>,
      <821, 825, 829>      <830, 838, 831>,
      <830, 831, 835>      <830, 835, 832>,
      <830, 832, 836>      <830, 836, 833>,
      <830, 833, 837>      <830, 837, 834>,
      <830, 834, 838>      <839, 847, 840>,
      <839, 840, 844>      <839, 844, 841>,
      <839, 841, 845>      <839, 845, 842>,
      <839, 842, 846>      <839, 846, 843>,
      <839, 843, 847>      <848, 856, 849>,
      <848, 849, 853>      <848, 853, 850>,
      <848, 850, 854>      <848, 854, 851>,
      <848, 851, 855>      <848, 855, 852>,
      <848, 852, 856>      <857, 865, 858>,
      <857, 858, 862>      <857, 862, 859>,
      <857, 859, 863>      <857, 863, 860>,
      <857, 860, 864>      <857, 864, 861>,
      <857, 861, 865>      <866, 874, 867>,
      <866, 867, 871>      <866, 871, 868>,
      <866, 868, 872>      <866, 872, 869>,
      <866, 869, 873>      <866, 873, 870>,
      <866, 870, 874>      <875, 883, 876>,
      <875, 876, 880>      <875, 880, 877>,
      <875, 877, 881>      <875, 881, 878>,
      <875, 878, 882>      <875, 882, 879>,
      <875, 879, 883>      <884, 892, 885>,
      <884, 885, 889>      <884, 889, 886>,
      <884, 886, 890>      <884, 890, 887>,
      <884, 887, 891>      <884, 891, 888>,
      <884, 888, 892>      <893, 901, 894>,
      <893, 894, 898>      <893, 898, 895>,
      <893, 895, 899>      <893, 899, 896>,
      <893, 896, 900>      <893, 900, 897>,
      <893, 897, 901>      <902, 910, 903>,
      <902, 903, 907>      <902, 907, 904>,
      <902, 904, 908>      <902, 908, 905>,
      <902, 905, 909>      <902, 909, 906>,
      <902, 906, 910>      <911, 919, 912>,
      <911, 912, 916>      <911, 916, 913>,
      <911, 913, 917>      <911, 917, 914>,
      <911, 914, 918>      <911, 918, 915>,
      <911, 915, 919>      <920, 928, 921>,
      <920, 921, 925>      <920, 925, 922>,
      <920, 922, 926>      <920, 926, 923>,
      <920, 923, 927>      <920, 927, 924>,
      <920, 924, 928>      <929, 937, 930>,
      <929, 930, 934>      <929, 934, 931>,
      <929, 931, 935>      <929, 935, 932>,
      <929, 932, 936>      <929, 936, 933>,
      <929, 933, 937>      <938, 946, 939>,
      <938, 939, 943>      <938, 943, 940>,
      <938, 940, 944>      <938, 944, 941>,
      <938, 941, 945>      <938, 945, 942>,
      <938, 942, 946>      <947, 955, 948>,
      <947, 948, 952>      <947, 952, 949>,
      <947, 949, 953>      <947, 953, 950>,
      <947, 950, 954>      <947, 954, 951>,
      <947, 951, 955>      <956, 964, 957>,
      <956, 957, 961>      <956, 961, 958>,
      <956, 958, 962>      <956, 962, 959>,
      <956, 959, 963>      <956, 963, 960>,
      <956, 960, 964>      <965, 973, 966>,
      <965, 966, 970>      <965, 970, 967>,
      <965, 967, 971>      <965, 971, 968>,
      <965, 968, 972>      <965, 972, 969>,
      <965, 969, 973>      <974, 982, 975>,
      <974, 975, 979>      <974, 979, 976>,
      <974, 976, 980>      <974, 980, 977>,
      <974, 977, 981>      <974, 981, 978>,
      <974, 978, 982>      <983, 991, 984>,
      <983, 984, 988>      <983, 988, 985>,
      <983, 985, 989>      <983, 989, 986>,
      <983, 986, 990>      <983, 990, 987>,
      <983, 987, 991>      <992, 1000, 993>,
      <992, 993, 997>      <992, 997, 994>,
      <992, 994, 998>      <992, 998, 995>,
      <992, 995, 999>      <992, 999, 996>,
      <992, 996, 1000>      <1001, 1009, 1002>,
      <1001, 1002, 1006>      <1001, 1006, 1003>,
      <1001, 1003, 1007>      <1001, 1007, 1004>,
      <1001, 1004, 1008>      <1001, 1008, 1005>,
      <1001, 1005, 1009>      <1010, 1018, 1011>,
      <1010, 1011, 1015>      <1010, 1015, 1012>,
      <1010, 1012, 1016>      <1010, 1016, 1013>,
      <1010, 1013, 1017>      <1010, 1017, 1014>,
      <1010, 1014, 1018>      <1019, 1027, 1020>,
      <1019, 1020, 1024>      <1019, 1024, 1021>,
      <1019, 1021, 1025>      <1019, 1025, 1022>,
      <1019, 1022, 1026>      <1019, 1026, 1023>,
      <1019, 1023, 1027>      <1028, 1036, 1029>,
      <1028, 1029, 1033>      <1028, 1033, 1030>,
      <1028, 1030, 1034>      <1028, 1034, 1031>,
      <1028, 1031, 1035>      <1028, 1035, 1032>,
      <1028, 1032, 1036>      <1037, 1045, 1038>,
      <1037, 1038, 1042>      <1037, 1042, 1039>,
      <1037, 1039, 1043>      <1037, 1043, 1040>,
      <1037, 1040, 1044>      <1037, 1044, 1041>,
      <1037, 1041, 1045>      <1046, 1054, 1047>,
      <1046, 1047, 1051>      <1046, 1051, 1048>,
      <1046, 1048, 1052>      <1046, 1052, 1049>,
      <1046, 1049, 1053>      <1046, 1053, 1050>,
      <1046, 1050, 1054>      <1055, 1063, 1056>,
      <1055, 1056, 1060>      <1055, 1060, 1057>,
      <1055, 1057, 1061>      <1055, 1061, 1058>,
      <1055, 1058, 1062>      <1055, 1062, 1059>,
      <1055, 1059, 1063>      <1064, 1072, 1065>,
      <1064, 1065, 1069>      <1064, 1069, 1066>,
      <1064, 1066, 1070>      <1064, 1070, 1067>,
      <1064, 1067, 1071>      <1064, 1071, 1068>,
      <1064, 1068, 1072>      <1073, 1081, 1074>,
      <1073, 1074, 1078>      <1073, 1078, 1075>,
      <1073, 1075, 1079>      <1073, 1079, 1076>,
      <1073, 1076, 1080>      <1073, 1080, 1077>,
      <1073, 1077, 1081>      <1082, 1090, 1083>,
      <1082, 1083, 1087>      <1082, 1087, 1084>,
      <1082, 1084, 1088>      <1082, 1088, 1085>,
      <1082, 1085, 1089>      <1082, 1089, 1086>,
      <1082, 1086, 1090>      <1091, 1099, 1092>,
      <1091, 1092, 1096>      <1091, 1096, 1093>,
      <1091, 1093, 1097>      <1091, 1097, 1094>,
      <1091, 1094, 1098>      <1091, 1098, 1095>,
      <1091, 1095, 1099>      <1100, 1108, 1101>,
      <1100, 1101, 1105>      <1100, 1105, 1102>,
      <1100, 1102, 1106>      <1100, 1106, 1103>,
      <1100, 1103, 1107>      <1100, 1107, 1104>,
      <1100, 1104, 1108>      <1109, 1117, 1110>,
      <1109, 1110, 1114>      <1109, 1114, 1111>,
      <1109, 1111, 1115>      <1109, 1115, 1112>,
      <1109, 1112, 1116>      <1109, 1116, 1113>,
      <1109, 1113, 1117>      <1118, 1126, 1119>,
      <1118, 1119, 1123>      <1118, 1123, 1120>,
      <1118, 1120, 1124>      <1118, 1124, 1121>,
      <1118, 1121, 1125>      <1118, 1125, 1122>,
      <1118, 1122, 1126>      <1127, 1135, 1128>,
      <1127, 1128, 1132>      <1127, 1132, 1129>,
      <1127, 1129, 1133>      <1127, 1133, 1130>,
      <1127, 1130, 1134>      <1127, 1134, 1131>,
      <1127, 1131, 1135>      <1136, 1144, 1137>,
      <1136, 1137, 1141>      <1136, 1141, 1138>,
      <1136, 1138, 1142>      <1136, 1142, 1139>,
      <1136, 1139, 1143>      <1136, 1143, 1140>,
      <1136, 1140, 1144>      <1145, 1153, 1146>,
      <1145, 1146, 1150>      <1145, 1150, 1147>,
      <1145, 1147, 1151>      <1145, 1151, 1148>,
      <1145, 1148, 1152>      <1145, 1152, 1149>,
      <1145, 1149, 1153>      <1154, 1162, 1155>,
      <1154, 1155, 1159>      <1154, 1159, 1156>,
      <1154, 1156, 1160>      <1154, 1160, 1157>,
      <1154, 1157, 1161>      <1154, 1161, 1158>,
      <1154, 1158, 1162>      <1163, 1171, 1164>,
      <1163, 1164, 1168>      <1163, 1168, 1165>,
      <1163, 1165, 1169>      <1163, 1169, 1166>,
      <1163, 1166, 1170>      <1163, 1170, 1167>,
      <1163, 1167, 1171>      <1172, 1180, 1173>,
      <1172, 1173, 1177>      <1172, 1177, 1174>,
      <1172, 1174, 1178>      <1172, 1178, 1175>,
      <1172, 1175, 1179>      <1172, 1179, 1176>,
      <1172, 1176, 1180>      <1181, 1189, 1182>,
      <1181, 1182, 1186>      <1181, 1186, 1183>,
      <1181, 1183, 1187>      <1181, 1187, 1184>,
      <1181, 1184, 1188>      <1181, 1188, 1185>,
      <1181, 1185, 1189>      <1190, 1198, 1191>,
      <1190, 1191, 1195>      <1190, 1195, 1192>,
      <1190, 1192, 1196>      <1190, 1196, 1193>,
      <1190, 1193, 1197>      <1190, 1197, 1194>,
      <1190, 1194, 1198>      <1199, 1207, 1200>,
      <1199, 1200, 1204>      <1199, 1204, 1201>,
      <1199, 1201, 1205>      <1199, 1205, 1202>,
      <1199, 1202, 1206>      <1199, 1206, 1203>,
      <1199, 1203, 1207>      <1208, 1216, 1209>,
      <1208, 1209, 1213>      <1208, 1213, 1210>,
      <1208, 1210, 1214>      <1208, 1214, 1211>,
      <1208, 1211, 1215>      <1208, 1215, 1212>,
      <1208, 1212, 1216>      <1217, 1225, 1218>,
      <1217, 1218, 1222>      <1217, 1222, 1219>,
      <1217, 1219, 1223>      <1217, 1223, 1220>,
      <1217, 1220, 1224>      <1217, 1224, 1221>,
      <1217, 1221, 1225>      <1226, 1234, 1227>,
      <1226, 1227, 1231>      <1226, 1231, 1228>,
      <1226, 1228, 1232>      <1226, 1232, 1229>,
      <1226, 1229, 1233>      <1226, 1233, 1230>,
      <1226, 1230, 1234>      <1235, 1243, 1236>,
      <1235, 1236, 1240>      <1235, 1240, 1237>,
      <1235, 1237, 1241>      <1235, 1241, 1238>,
      <1235, 1238, 1242>      <1235, 1242, 1239>,
      <1235, 1239, 1243>      <1244, 1252, 1245>,
      <1244, 1245, 1249>      <1244, 1249, 1246>,
      <1244, 1246, 1250>      <1244, 1250, 1247>,
      <1244, 1247, 1251>      <1244, 1251, 1248>,
      <1244, 1248, 1252>      <1253, 1261, 1254>,
      <1253, 1254, 1258>      <1253, 1258, 1255>,
      <1253, 1255, 1259>      <1253, 1259, 1256>,
      <1253, 1256, 1260>      <1253, 1260, 1257>,
      <1253, 1257, 1261>      <1262, 1270, 1263>,
      <1262, 1263, 1267>      <1262, 1267, 1264>,
      <1262, 1264, 1268>      <1262, 1268, 1265>,
      <1262, 1265, 1269>      <1262, 1269, 1266>,
      <1262, 1266, 1270>      <1271, 1279, 1272>,
      <1271, 1272, 1276>      <1271, 1276, 1273>,
      <1271, 1273, 1277>      <1271, 1277, 1274>,
      <1271, 1274, 1278>      <1271, 1278, 1275>,
      <1271, 1275, 1279>      <1280, 1288, 1281>,
      <1280, 1281, 1285>      <1280, 1285, 1282>,
      <1280, 1282, 1286>      <1280, 1286, 1283>,
      <1280, 1283, 1287>      <1280, 1287, 1284>,
      <1280, 1284, 1288>      <1289, 1297, 1290>,
      <1289, 1290, 1294>      <1289, 1294, 1291>,
      <1289, 1291, 1295>      <1289, 1295, 1292>,
      <1289, 1292, 1296>      <1289, 1296, 1293>,
      <1289, 1293, 1297>      <1298, 1306, 1299>,
      <1298, 1299, 1303>      <1298, 1303, 1300>,
      <1298, 1300, 1304>      <1298, 1304, 1301>,
      <1298, 1301, 1305>      <1298, 1305, 1302>,
      <1298, 1302, 1306>      <1307, 1315, 1308>,
      <1307, 1308, 1312>      <1307, 1312, 1309>,
      <1307, 1309, 1313>      <1307, 1313, 1310>,
      <1307, 1310, 1314>      <1307, 1314, 1311>,
      <1307, 1311, 1315>      <1316, 1324, 1317>,
      <1316, 1317, 1321>      <1316, 1321, 1318>,
      <1316, 1318, 1322>      <1316, 1322, 1319>,
      <1316, 1319, 1323>      <1316, 1323, 1320>,
      <1316, 1320, 1324>      <1325, 1333, 1326>,
      <1325, 1326, 1330>      <1325, 1330, 1327>,
      <1325, 1327, 1331>      <1325, 1331, 1328>,
      <1325, 1328, 1332>      <1325, 1332, 1329>,
      <1325, 1329, 1333>      <1334, 1342, 1335>,
      <1334, 1335, 1339>      <1334, 1339, 1336>,
      <1334, 1336, 1340>      <1334, 1340, 1337>,
      <1334, 1337, 1341>      <1334, 1341, 1338>,
      <1334, 1338, 1342>      <1343, 1351, 1344>,
      <1343, 1344, 1348>      <1343, 1348, 1345>,
      <1343, 1345, 1349>      <1343, 1349, 1346>,
      <1343, 1346, 1350>      <1343, 1350, 1347>,
      <1343, 1347, 1351>      <1352, 1360, 1353>,
      <1352, 1353, 1357>      <1352, 1357, 1354>,
      <1352, 1354, 1358>      <1352, 1358, 1355>,
      <1352, 1355, 1359>      <1352, 1359, 1356>,
      <1352, 1356, 1360>      <1361, 1369, 1362>,
      <1361, 1362, 1366>      <1361, 1366, 1363>,
      <1361, 1363, 1367>      <1361, 1367, 1364>,
      <1361, 1364, 1368>      <1361, 1368, 1365>,
      <1361, 1365, 1369>      <1370, 1378, 1371>,
      <1370, 1371, 1375>      <1370, 1375, 1372>,
      <1370, 1372, 1376>      <1370, 1376, 1373>,
      <1370, 1373, 1377>      <1370, 1377, 1374>,
      <1370, 1374, 1378>      <1379, 1387, 1380>,
      <1379, 1380, 1384>      <1379, 1384, 1381>,
      <1379, 1381, 1385>      <1379, 1385, 1382>,
      <1379, 1382, 1386>      <1379, 1386, 1383>,
      <1379, 1383, 1387>      <1388, 1396, 1389>,
      <1388, 1389, 1393>      <1388, 1393, 1390>,
      <1388, 1390, 1394>      <1388, 1394, 1391>,
      <1388, 1391, 1395>      <1388, 1395, 1392>,
      <1388, 1392, 1396>      <1397, 1405, 1398>,
      <1397, 1398, 1402>      <1397, 1402, 1399>,
      <1397, 1399, 1403>      <1397, 1403, 1400>,
      <1397, 1400, 1404>      <1397, 1404, 1401>,
      <1397, 1401, 1405>      <1406, 1414, 1407>,
      <1406, 1407, 1411>      <1406, 1411, 1408>,
      <1406, 1408, 1412>      <1406, 1412, 1409>,
      <1406, 1409, 1413>      <1406, 1413, 1410>,
      <1406, 1410, 1414>      <1415, 1423, 1416>,
      <1415, 1416, 1420>      <1415, 1420, 1417>,
      <1415, 1417, 1421>      <1415, 1421, 1418>,
      <1415, 1418, 1422>      <1415, 1422, 1419>,
      <1415, 1419, 1423>      <1424, 1432, 1425>,
      <1424, 1425, 1429>      <1424, 1429, 1426>,
      <1424, 1426, 1430>      <1424, 1430, 1427>,
      <1424, 1427, 1431>      <1424, 1431, 1428>,
      <1424, 1428, 1432>      <1433, 1441, 1434>,
      <1433, 1434, 1438>      <1433, 1438, 1435>,
      <1433, 1435, 1439>      <1433, 1439, 1436>,
      <1433, 1436, 1440>      <1433, 1440, 1437>,
      <1433, 1437, 1441>      <1442, 1450, 1443>,
      <1442, 1443, 1447>      <1442, 1447, 1444>,
      <1442, 1444, 1448>      <1442, 1448, 1445>,
      <1442, 1445, 1449>      <1442, 1449, 1446>,
      <1442, 1446, 1450>      <1451, 1459, 1452>,
      <1451, 1452, 1456>      <1451, 1456, 1453>,
      <1451, 1453, 1457>      <1451, 1457, 1454>,
      <1451, 1454, 1458>      <1451, 1458, 1455>,
      <1451, 1455, 1459>      <1460, 1468, 1461>,
      <1460, 1461, 1465>      <1460, 1465, 1462>,
      <1460, 1462, 1466>      <1460, 1466, 1463>,
      <1460, 1463, 1467>      <1460, 1467, 1464>,
      <1460, 1464, 1468>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>
    }
    translate  <0.0, 0.0, 0.0>
}

#declare Moulure_coin = mesh2 {
    vertex_vectors {
      582,
      <0.1672013, -0.0211416, 0.4225174>,
      <0.2026894, 0.1500277, 0.4225174>,
      <0.0613458, 0.1509047, 0.4225174>,
      <-0.0092506, -0.0209974, 0.4225174>,
      <0.1849454, 0.0644430, 0.4225174>,
      <0.1320176, 0.1504662, 0.4225174>,
      <0.0260476, 0.0649537, 0.4225174>,
      <0.0789753, -0.0210695, 0.4225174>,
      <0.1054965, 0.0646983, 0.4225174>,
      <-0.0798470, -0.1928995, 0.4225174>,
      <0.1317132, -0.1923110, 0.4225174>,
      <-0.0445488, -0.1069485, 0.4225174>,
      <0.0259331, -0.1926052, 0.4225174>,
      <0.1494572, -0.1067263, 0.4225174>,
      <0.0524542, -0.1068374, 0.4225174>,
      <0.3432733, -0.1917224, 0.4225174>,
      <0.3436532, -0.0212859, 0.4225174>,
      <0.2374932, -0.1920167, 0.4225174>,
      <0.3434632, -0.1065042, 0.4225174>,
      <0.2554273, -0.0212138, 0.4225174>,
      <0.2464602, -0.1066152, 0.4225174>,
      <0.3440331, 0.1491506, 0.4225174>,
      <0.3438432, 0.0639324, 0.4225174>,
      <0.2733613, 0.1495892, 0.4225174>,
      <0.2643943, 0.0641877, 0.4225174>,
      <0.0372518, 0.0786744, 0.0009585>,
      <0.0599623, 0.1488382, 0.0009585>,
      <0.0599219, 0.1487779, 0.0024817>,
      <0.0386092, 0.0820162, 0.0024817>,
      <0.0486070, 0.1137563, 0.0009585>,
      <0.0599421, 0.1488081, 0.0017201>,
      <0.0492655, 0.1153971, 0.0024817>,
      <0.0379305, 0.0803453, 0.0017201>,
      <0.0489363, 0.1145767, 0.0017201>,
      <0.0172964, 0.0152546, 0.0024817>,
      <0.0145413, 0.0085106, 0.0009585>,
      <0.0279528, 0.0486354, 0.0024817>,
      <0.0159189, 0.0118826, 0.0017201>,
      <0.0258965, 0.0435925, 0.0009585>,
      <0.0269247, 0.0461140, 0.0017201>,
      <0.0117861, 0.0017666, -0.0005647>,
      <0.0358944, 0.0753326, -0.0005647>,
      <0.0131637, 0.0051386, 0.0001969>,
      <0.0238402, 0.0385496, -0.0005647>,
      <0.0365731, 0.0770035, 0.0001969>,
      <0.0248684, 0.0410710, 0.0001969>,
      <0.0600027, 0.1488985, -0.0005647>,
      <0.0479485, 0.1121155, -0.0005647>,
      <0.0599825, 0.1488684, 0.0001969>,
      <0.0482778, 0.1129359, 0.0001969>,
      <0.1794290, 0.0080247, 0.0009585>,
      <0.1808218, 0.0147373, 0.0024817>,
      <0.0969851, 0.0082676, 0.0009585>,
      <0.0990591, 0.0149960, 0.0024817>,
      <0.1801254, 0.0113810, 0.0017201>,
      <0.0980221, 0.0116318, 0.0017201>,
      <0.3443471, 0.0142200, 0.0024817>,
      <0.3443166, 0.0075387, 0.0009585>,
      <0.2625844, 0.0144787, 0.0024817>,
      <0.3443319, 0.0108794, 0.0017201>,
      <0.2618728, 0.0077817, 0.0009585>,
      <0.2622286, 0.0111302, 0.0017201>,
      <0.3442862, 0.0008574, -0.0005647>,
      <0.1780361, 0.0013120, -0.0005647>,
      <0.3443014, 0.0041981, 0.0001969>,
      <0.2611612, 0.0010847, -0.0005647>,
      <0.1787325, 0.0046683, 0.0001969>,
      <0.2615170, 0.0044332, 0.0001969>,
      <0.0949111, 0.0015393, -0.0005647>,
      <0.0959481, 0.0049035, 0.0001969>,
      <0.3444296, 0.0772261, 0.0009585>,
      <0.3444523, 0.0805340, 0.0024817>,
      <0.3443731, 0.0423824, 0.0009585>,
      <0.3443997, 0.0473770, 0.0024817>,
      <0.3444410, 0.0788800, 0.0017201>,
      <0.3443864, 0.0448797, 0.0017201>,
      <0.3445575, 0.1468481, 0.0024817>,
      <0.3445426, 0.1469134, 0.0009585>,
      <0.3445049, 0.1136911, 0.0024817>,
      <0.3445501, 0.1468807, 0.0017201>,
      <0.3444861, 0.1120697, 0.0009585>,
      <0.3444955, 0.1128804, 0.0017201>,
      <0.3445278, 0.1469787, -0.0005647>,
      <0.3444070, 0.0739181, -0.0005647>,
      <0.3445352, 0.1469460, 0.0001969>,
      <0.3444674, 0.1104484, -0.0005647>,
      <0.3444183, 0.0755721, 0.0001969>,
      <0.3444768, 0.1112590, 0.0001969>,
      <0.3443466, 0.0373878, -0.0005647>,
      <0.3443599, 0.0398851, 0.0001969>,
      <0.0330639, 0.0757714, 0.0178091>,
      <0.0600869, 0.1490243, 0.0178091>,
      <0.0465754, 0.1123978, 0.0178091>,
      <0.0600448, 0.1489614, 0.0086222>,
      <0.0344791, 0.0755520, 0.0086222>,
      <0.0472619, 0.1122567, 0.0086222>,
      <0.0060409, 0.0025184, 0.0178091>,
      <0.0089135, 0.0021425, 0.0086222>,
      <0.0195524, 0.0391449, 0.0178091>,
      <0.0216963, 0.0388472, 0.0086222>,
      <0.0002957, 0.0032702, 0.0361829>,
      <0.0302334, 0.0762102, 0.0361829>,
      <0.0031683, 0.0028943, 0.0269960>,
      <0.0152645, 0.0397402, 0.0361829>,
      <0.0316486, 0.0759908, 0.0269960>,
      <0.0174085, 0.0394425, 0.0269960>,
      <0.0601711, 0.1491501, 0.0361829>,
      <0.0452022, 0.1126801, 0.0361829>,
      <0.0601290, 0.1490872, 0.0269960>,
      <0.0458888, 0.1125390, 0.0269960>,
      <0.1751318, 0.0021292, 0.0178091>,
      <0.0905863, 0.0023238, 0.0178091>,
      <0.1765840, 0.0017206, 0.0086222>,
      <0.0927487, 0.0019316, 0.0086222>,
      <0.3442227, 0.0017401, 0.0178091>,
      <0.3442544, 0.0012988, 0.0086222>,
      <0.2596772, 0.0019347, 0.0178091>,
      <0.2604192, 0.0015097, 0.0086222>,
      <0.3441592, 0.0026227, 0.0361829>,
      <0.1722274, 0.0029465, 0.0361829>,
      <0.3441909, 0.0021814, 0.0269960>,
      <0.2581933, 0.0027846, 0.0361829>,
      <0.1736796, 0.0025379, 0.0269960>,
      <0.2589353, 0.0023596, 0.0269960>,
      <0.0862616, 0.0031083, 0.0361829>,
      <0.0884239, 0.0027161, 0.0269960>,
      <0.3443597, 0.0744275, 0.0178091>,
      <0.3442912, 0.0380838, 0.0178091>,
      <0.3443834, 0.0741728, 0.0086222>,
      <0.3443189, 0.0377358, 0.0086222>,
      <0.3444968, 0.1471149, 0.0178091>,
      <0.3445123, 0.1470468, 0.0086222>,
      <0.3444282, 0.1107712, 0.0178091>,
      <0.3444478, 0.1106098, 0.0086222>,
      <0.3444657, 0.1472510, 0.0361829>,
      <0.3443125, 0.0749369, 0.0361829>,
      <0.3444812, 0.1471829, 0.0269960>,
      <0.3443891, 0.1110940, 0.0361829>,
      <0.3443361, 0.0746822, 0.0269960>,
      <0.3444087, 0.1109326, 0.0269960>,
      <0.3442358, 0.0387798, 0.0361829>,
      <0.3442635, 0.0384318, 0.0269960>,
      <0.0282276, 0.0712720, 0.0380992>,
      <0.0602307, 0.1492392, 0.0380992>,
      <0.0442292, 0.1102556, 0.0380992>,
      <0.0602009, 0.1491947, 0.0371410>,
      <0.0292305, 0.0737411, 0.0371410>,
      <0.0447157, 0.1114679, 0.0371410>,
      <-0.0037755, -0.0066951, 0.0380992>,
      <-0.0017399, -0.0017125, 0.0371410>,
      <0.0122260, 0.0322885, 0.0380992>,
      <0.0137453, 0.0360143, 0.0371410>,
      <-0.0078468, -0.0166605, 0.0400154>,
      <0.0262218, 0.0663339, 0.0400154>,
      <-0.0058112, -0.0116778, 0.0390573>,
      <0.0091875, 0.0248367, 0.0400154>,
      <0.0272247, 0.0688030, 0.0390573>,
      <0.0107068, 0.0285626, 0.0390573>,
      <0.0602904, 0.1493284, 0.0400154>,
      <0.0432561, 0.1078312, 0.0400154>,
      <0.0602606, 0.1492838, 0.0390573>,
      <0.0437426, 0.1090434, 0.0390573>,
      <0.1701693, -0.0069726, 0.0380992>,
      <0.0831969, -0.0068339, 0.0380992>,
      <0.1711984, -0.0020130, 0.0371410>,
      <0.0847292, -0.0018628, 0.0371410>,
      <0.3441142, -0.0072500, 0.0380992>,
      <0.3441367, -0.0023136, 0.0371410>,
      <0.2571417, -0.0071113, 0.0380992>,
      <0.2576675, -0.0021633, 0.0371410>,
      <0.3440692, -0.0171227, 0.0400154>,
      <0.1681112, -0.0168916, 0.0400154>,
      <0.3440917, -0.0121863, 0.0390573>,
      <0.2560902, -0.0170071, 0.0400154>,
      <0.1691403, -0.0119321, 0.0390573>,
      <0.2566160, -0.0120592, 0.0390573>,
      <0.0801322, -0.0167761, 0.0400154>,
      <0.0816646, -0.0118050, 0.0390573>,
      <0.3442790, 0.0700488, 0.0380992>,
      <0.3441966, 0.0313994, 0.0380992>,
      <0.3442957, 0.0724928, 0.0371410>,
      <0.3442162, 0.0350896, 0.0371410>,
      <0.3444438, 0.1473475, 0.0380992>,
      <0.3444548, 0.1472993, 0.0371410>,
      <0.3443614, 0.1086982, 0.0380992>,
      <0.3443752, 0.1098961, 0.0371410>,
      <0.3444218, 0.1474440, 0.0400154>,
      <0.3442455, 0.0651607, 0.0400154>,
      <0.3444328, 0.1473958, 0.0390573>,
      <0.3443336, 0.1063024, 0.0400154>,
      <0.3442622, 0.0676047, 0.0390573>,
      <0.3443475, 0.1075003, 0.0390573>,
      <0.3441573, 0.0240190, 0.0400154>,
      <0.3441770, 0.0277092, 0.0390573>,
      <0.0257826, 0.0652541, 0.1132082>,
      <0.0602908, 0.1493290, 0.1151532>,
      <0.0430375, 0.1072927, 0.1140418>,
      <0.0602906, 0.1493287, 0.0775843>,
      <0.0262153, 0.0663179, 0.0775843>,
      <0.0432530, 0.1078233, 0.0775843>,
      <-0.0087351, -0.0188350, 0.1129304>,
      <-0.0078600, -0.0166928, 0.0775843>,
      <0.0085245, 0.0232107, 0.1129304>,
      <0.0091777, 0.0248126, 0.0775843>,
      <-0.0165192, -0.0378885, 0.1680629>,
      <0.0219397, 0.0558007, 0.1697300>,
      <-0.0113342, -0.0251969, 0.1438308>,
      <0.0027150, 0.0089632, 0.1680629>,
      <0.0244974, 0.0620945, 0.1449422>,
      <0.0065847, 0.0184535, 0.1438308>,
      <0.0602912, 0.1493295, 0.1902909>,
      <0.0411455, 0.1026099, 0.1747313>,
      <0.0602910, 0.1493292, 0.1527220>,
      <0.0423973, 0.1057166, 0.1482764>,
      <0.1676621, -0.0190559, 0.1129304>,
      <0.0794635, -0.0189454, 0.1129304>,
      <0.1681045, -0.0169237, 0.0775843>,
      <0.0801223, -0.0168083, 0.0775843>,
      <0.3440594, -0.0192769, 0.1129304>,
      <0.3440690, -0.0171546, 0.0775843>,
      <0.2558607, -0.0191664, 0.1129304>,
      <0.2560868, -0.0170392, 0.0775843>,
      <0.3439733, -0.0381532, 0.1680629>,
      <0.1637271, -0.0380209, 0.1680629>,
      <0.3440306, -0.0255797, 0.1438308>,
      <0.2538502, -0.0380870, 0.1680629>,
      <0.1663482, -0.0253883, 0.1438308>,
      <0.2551894, -0.0254840, 0.1438308>,
      <0.0736039, -0.0379547, 0.1680629>,
      <0.0775070, -0.0252926, 0.1438308>,
      <0.3442388, 0.0640915, 0.1132082>,
      <0.3441488, 0.0224086, 0.1129304>,
      <0.3442454, 0.0651449, 0.0775843>,
      <0.3441572, 0.0239951, 0.0775843>,
      <0.3444216, 0.1474447, 0.1151532>,
      <0.3444217, 0.1474443, 0.0775843>,
      <0.3443299, 0.1057694, 0.1140418>,
      <0.3443335, 0.1062946, 0.0775843>,
      <0.3444215, 0.1474453, 0.1902909>,
      <0.3441776, 0.0547329, 0.1697300>,
      <0.3444216, 0.1474450, 0.1527220>,
      <0.3442885, 0.1011376, 0.1747313>,
      <0.3442191, 0.0609633, 0.1449422>,
      <0.3443192, 0.1042092, 0.1482764>,
      <0.3440737, 0.0082975, 0.1680629>,
      <0.3441237, 0.0176969, 0.1438308>,
      <0.0125735, 0.0327325, 0.1939094>,
      <0.0606959, 0.1499340, 0.1942989>,
      <0.0366347, 0.0913333, 0.1940763>,
      <0.0604935, 0.1496318, 0.1922949>,
      <0.0176897, 0.0453344, 0.1845151>,
      <0.0390948, 0.0974878, 0.1878493>,
      <-0.0355493, -0.0844696, 0.1938538>,
      <-0.0251521, -0.0590196, 0.1834037>,
      <-0.0114879, -0.0258685, 0.1938538>,
      <-0.0037280, -0.0068379, 0.1834037>,
      <-0.0549031, -0.1318429, 0.2160838>,
      <0.0030476, 0.0092713, 0.2147505>,
      <-0.0460275, -0.1101176, 0.2034136>,
      <-0.0259323, -0.0612925, 0.2160838>,
      <0.0074173, 0.0200323, 0.2025248>,
      <-0.0193081, -0.0450471, 0.2034136>,
      <0.0611006, 0.1505385, 0.1983068>,
      <0.0320455, 0.0798622, 0.2107507>,
      <0.0608982, 0.1502362, 0.1963028>,
      <0.0341548, 0.0851298, 0.1998582>,
      <0.1541068, -0.0843853, 0.1938538>,
      <0.0592788, -0.0844274, 0.1938538>,
      <0.1593629, -0.0590537, 0.1834037>,
      <0.0671054, -0.0590367, 0.1834037>,
      <0.3437630, -0.0843010, 0.1938538>,
      <0.3438779, -0.0590878, 0.1834037>,
      <0.2489349, -0.0843432, 0.1938538>,
      <0.2516204, -0.0590708, 0.1834037>,
      <0.3435490, -0.1312338, 0.2160838>,
      <0.1443230, -0.1315383, 0.2160838>,
      <0.3436471, -0.1097105, 0.2034136>,
      <0.2439360, -0.1313860, 0.2160838>,
      <0.1488098, -0.1099140, 0.2034136>,
      <0.2462285, -0.1098123, 0.2034136>,
      <0.0447099, -0.1316906, 0.2160838>,
      <0.0513912, -0.1100158, 0.2034136>,
      <0.3440176, 0.0318997, 0.1939094>,
      <0.3438903, -0.0262006, 0.1938538>,
      <0.3441055, 0.0443730, 0.1845151>,
      <0.3439905, -0.0073523, 0.1834037>,
      <0.3442725, 0.1480997, 0.1942989>,
      <0.3443470, 0.1477725, 0.1922949>,
      <0.3441450, 0.0899998, 0.1940763>,
      <0.3442251, 0.0960779, 0.1878493>,
      <0.3441234, 0.1487541, 0.1983068>,
      <0.3438551, 0.0086774, 0.2147505>,
      <0.3441979, 0.1484269, 0.1963028>,
      <0.3439998, 0.0786695, 0.2107507>,
      <0.3439292, 0.0193290, 0.2025248>,
      <0.3440647, 0.0838731, 0.1998582>,
      <0.3437037, -0.0612855, 0.2160838>,
      <0.3437893, -0.0451956, 0.2034136>,
      <-0.0012534, -0.0013101, 0.2607566>,
      <0.0611199, 0.1505674, 0.2592011>,
      <0.0299325, 0.0746275, 0.2600900>,
      <0.0611103, 0.1505529, 0.2287540>,
      <0.0002907, 0.0024871, 0.2349759>,
      <0.0306975, 0.0765155, 0.2323094>,
      <-0.0636177, -0.1531742, 0.2609788>,
      <-0.0604926, -0.1455248, 0.2358648>,
      <-0.0324363, -0.0772433, 0.2609788>,
      <-0.0301040, -0.0715234, 0.2358648>,
      <-0.0657602, -0.1584186, 0.3200954>,
      <-0.0023105, -0.0039111, 0.3200954>,
      <-0.0650997, -0.1568018, 0.2896483>,
      <-0.0340354, -0.0811649, 0.3200954>,
      <-0.0019851, -0.0031100, 0.2896483>,
      <-0.0335424, -0.0799559, 0.2896483>,
      <0.0611393, 0.1505963, 0.3200954>,
      <0.0294144, 0.0733426, 0.3200954>,
      <0.0611296, 0.1505819, 0.2896483>,
      <0.0295723, 0.0737359, 0.2896483>,
      <0.1399175, -0.1527704, 0.2609788>,
      <0.0381499, -0.1529723, 0.2609788>,
      <0.1414973, -0.1451566, 0.2358648>,
      <0.0405023, -0.1453407, 0.2358648>,
      <0.3434527, -0.1523666, 0.2609788>,
      <0.3434872, -0.1447884, 0.2358648>,
      <0.2416851, -0.1525685, 0.2609788>,
      <0.2424923, -0.1449725, 0.2358648>,
      <0.3434290, -0.1575622, 0.3200954>,
      <0.1388344, -0.1579904, 0.3200954>,
      <0.3434363, -0.1559605, 0.2896483>,
      <0.2411317, -0.1577763, 0.3200954>,
      <0.1391683, -0.1563812, 0.2896483>,
      <0.2413023, -0.1561708, 0.2896483>,
      <0.0365371, -0.1582045, 0.3200954>,
      <0.0370343, -0.1565915, 0.2896483>,
      <0.3437861, -0.0017979, 0.2607566>,
      <0.3436197, -0.0770835, 0.2609788>,
      <0.3438102, 0.0019615, 0.2349759>,
      <0.3436498, -0.0714183, 0.2358648>,
      <0.3441163, 0.1487854, 0.2592011>,
      <0.3441198, 0.1487698, 0.2287540>,
      <0.3439515, 0.0734926, 0.2600900>,
      <0.3439661, 0.0753608, 0.2323094>,
      <0.3441091, 0.1488167, 0.3200954>,
      <0.3437691, -0.0043727, 0.3200954>,
      <0.3441127, 0.1488011, 0.2896483>,
      <0.3439391, 0.0722220, 0.3200954>,
      <0.3437745, -0.0035797, 0.2896483>,
      <0.3439436, 0.0726107, 0.2896483>,
      <0.3435990, -0.0809675, 0.3200954>,
      <0.3436054, -0.0797701, 0.2896483>,
      <-0.0057805, -0.0124543, 0.3200954>,
      <0.0612425, 0.1507505, 0.3200954>,
      <0.0277310, 0.0691481, 0.3200954>,
      <0.0611909, 0.1506734, 0.3200954>,
      <-0.0040455, -0.0081827, 0.3200954>,
      <0.0285727, 0.0712454, 0.3200954>,
      <-0.0728036, -0.1756591, 0.3200954>,
      <-0.0692819, -0.1670388, 0.3200954>,
      <-0.0392921, -0.0940567, 0.3200954>,
      <-0.0366637, -0.0876108, 0.3200954>,
      <-0.0798470, -0.1928995, 0.3200954>,
      <-0.0092506, -0.0209974, 0.3200954>,
      <-0.0763253, -0.1842793, 0.3200954>,
      <-0.0445488, -0.1069485, 0.3200954>,
      <-0.0075156, -0.0167258, 0.3200954>,
      <-0.0419204, -0.1005026, 0.3200954>,
      <0.0613458, 0.1509047, 0.3200954>,
      <0.0260476, 0.0649537, 0.3200954>,
      <0.0612942, 0.1508276, 0.3200954>,
      <0.0268893, 0.0670509, 0.3200954>,
      <0.1352738, -0.1751507, 0.3200954>,
      <0.0312351, -0.1754049, 0.3200954>,
      <0.1370541, -0.1665706, 0.3200954>,
      <0.0338861, -0.1668047, 0.3200954>,
      <0.3433512, -0.1746423, 0.3200954>,
      <0.3433901, -0.1661023, 0.3200954>,
      <0.2393125, -0.1748965, 0.3200954>,
      <0.2402221, -0.1663364, 0.3200954>,
      <0.3432733, -0.1917224, 0.3200954>,
      <0.1317132, -0.1923110, 0.3200954>,
      <0.3433122, -0.1831824, 0.3200954>,
      <0.2374932, -0.1920167, 0.3200954>,
      <0.1334935, -0.1837308, 0.3200954>,
      <0.2384028, -0.1834566, 0.3200954>,
      <0.0259331, -0.1926052, 0.3200954>,
      <0.0285841, -0.1840051, 0.3200954>,
      <0.3437111, -0.0128293, 0.3200954>,
      <0.3435311, -0.0937358, 0.3200954>,
      <0.3437401, -0.0086010, 0.3200954>,
      <0.3435651, -0.0873517, 0.3200954>,
      <0.3440711, 0.1489837, 0.3200954>,
      <0.3440901, 0.1489002, 0.3200954>,
      <0.3438911, 0.0680772, 0.3200954>,
      <0.3439151, 0.0701496, 0.3200954>,
      <0.3440331, 0.1491506, 0.3200954>,
      <0.3436532, -0.0212859, 0.3200954>,
      <0.3440521, 0.1490672, 0.3200954>,
      <0.3438432, 0.0639324, 0.3200954>,
      <0.3436822, -0.0170576, 0.3200954>,
      <0.3438671, 0.0660048, 0.3200954>,
      <0.3434632, -0.1065042, 0.3200954>,
      <0.3434972, -0.1001200, 0.3200954>,
      <-0.0092506, -0.0209974, 0.3713064>,
      <0.0613458, 0.1509047, 0.3713064>,
      <0.0260476, 0.0649537, 0.3713064>,
      <0.0613458, 0.1509047, 0.3457009>,
      <-0.0092506, -0.0209974, 0.3457009>,
      <0.0260476, 0.0649537, 0.3457009>,
      <-0.0798470, -0.1928995, 0.3713064>,
      <-0.0798470, -0.1928995, 0.3457009>,
      <-0.0445488, -0.1069485, 0.3713064>,
      <-0.0445488, -0.1069485, 0.3457009>,
      <-0.0798470, -0.1928995, 0.3969119>,
      <-0.0092506, -0.0209974, 0.3969119>,
      <-0.0445488, -0.1069485, 0.3969119>,
      <0.0613458, 0.1509047, 0.3969119>,
      <0.0260476, 0.0649537, 0.3969119>,
      <0.1317132, -0.1923110, 0.3713064>,
      <0.0259331, -0.1926052, 0.3713064>,
      <0.1317132, -0.1923110, 0.3457009>,
      <0.0259331, -0.1926052, 0.3457009>,
      <0.3432733, -0.1917224, 0.3713064>,
      <0.3432733, -0.1917224, 0.3457009>,
      <0.2374932, -0.1920167, 0.3713064>,
      <0.2374932, -0.1920167, 0.3457009>,
      <0.3432733, -0.1917224, 0.3969119>,
      <0.1317132, -0.1923110, 0.3969119>,
      <0.2374932, -0.1920167, 0.3969119>,
      <0.0259331, -0.1926052, 0.3969119>,
      <0.3436532, -0.0212859, 0.3713064>,
      <0.3434632, -0.1065042, 0.3713064>,
      <0.3436532, -0.0212859, 0.3457009>,
      <0.3434632, -0.1065042, 0.3457009>,
      <0.3440331, 0.1491506, 0.3713064>,
      <0.3440331, 0.1491506, 0.3457009>,
      <0.3438432, 0.0639324, 0.3713064>,
      <0.3438432, 0.0639324, 0.3457009>,
      <0.3440331, 0.1491506, 0.3969119>,
      <0.3436532, -0.0212859, 0.3969119>,
      <0.3438432, 0.0639324, 0.3969119>,
      <0.3434632, -0.1065042, 0.3969119>,
      <0.2026894, 0.1500277, 0.3713064>,
      <0.0613458, 0.1509047, 0.3713064>,
      <0.2026894, 0.1500277, 0.3200954>,
      <0.1320176, 0.1504662, 0.3713064>,
      <0.0613458, 0.1509047, 0.3457009>,
      <0.1320176, 0.1504662, 0.3200954>,
      <0.2026894, 0.1500277, 0.3457009>,
      <0.1320176, 0.1504662, 0.3457009>,
      <0.3440331, 0.1491506, 0.3713064>,
      <0.2733613, 0.1495892, 0.3200954>,
      <0.3440331, 0.1491506, 0.3457009>,
      <0.2733613, 0.1495892, 0.3713064>,
      <0.2733613, 0.1495892, 0.3457009>,
      <0.2026894, 0.1500277, 0.4225174>,
      <0.3440331, 0.1491506, 0.3969119>,
      <0.2733613, 0.1495892, 0.4225174>,
      <0.2026894, 0.1500277, 0.3969119>,
      <0.2733613, 0.1495892, 0.3969119>,
      <0.1320176, 0.1504662, 0.4225174>,
      <0.0613458, 0.1509047, 0.3969119>,
      <0.1320176, 0.1504662, 0.3969119>,
      <0.2026568, 0.1498671, 0.3200954>,
      <0.2026242, 0.1497065, 0.3200954>,
      <0.2026405, 0.1497868, 0.3200954>,
      <0.1318818, 0.1501514, 0.3200954>,
      <0.1319497, 0.1503088, 0.3200954>,
      <0.1319157, 0.1502301, 0.3200954>,
      <0.2026894, 0.1500277, 0.3200954>,
      <0.1320176, 0.1504662, 0.3200954>,
      <0.2026731, 0.1499474, 0.3200954>,
      <0.1319836, 0.1503875, 0.3200954>,
      <0.2733613, 0.1495892, 0.3200954>,
      <0.2733640, 0.1494254, 0.3200954>,
      <0.2733626, 0.1495073, 0.3200954>,
      <0.2733667, 0.1492616, 0.3200954>,
      <0.2733653, 0.1493435, 0.3200954>,
      <0.2026181, 0.1496764, 0.2592011>,
      <0.0611199, 0.1505674, 0.2592011>,
      <0.2026120, 0.1496463, 0.1983068>,
      <0.1318690, 0.1501219, 0.2592011>,
      <0.0611103, 0.1505529, 0.2287540>,
      <0.1318563, 0.1500924, 0.1983068>,
      <0.2026150, 0.1496614, 0.2287540>,
      <0.1318627, 0.1501071, 0.2287540>,
      <0.3441163, 0.1487854, 0.2592011>,
      <0.2733677, 0.1492002, 0.1983068>,
      <0.3441198, 0.1487698, 0.2287540>,
      <0.2733672, 0.1492309, 0.2592011>,
      <0.2733674, 0.1492156, 0.2287540>,
      <0.2026242, 0.1497065, 0.3200954>,
      <0.3441127, 0.1488011, 0.2896483>,
      <0.2733667, 0.1492616, 0.3200954>,
      <0.2026212, 0.1496915, 0.2896483>,
      <0.2733669, 0.1492463, 0.2896483>,
      <0.1318818, 0.1501514, 0.3200954>,
      <0.0611296, 0.1505819, 0.2896483>,
      <0.1318754, 0.1501367, 0.2896483>,
      <0.2024842, 0.1490169, 0.1942989>,
      <0.2023563, 0.1483874, 0.1902909>,
      <0.2024203, 0.1487021, 0.1922949>,
      <0.1313238, 0.1488585, 0.1902909>,
      <0.1315900, 0.1494754, 0.1942989>,
      <0.1314569, 0.1491669, 0.1922949>,
      <0.2026120, 0.1496463, 0.1983068>,
      <0.1318563, 0.1500924, 0.1983068>,
      <0.2025481, 0.1493316, 0.1963028>,
      <0.1317232, 0.1497839, 0.1963028>,
      <0.2733677, 0.1492002, 0.1983068>,
      <0.2733783, 0.1485583, 0.1942989>,
      <0.2733730, 0.1488792, 0.1963028>,
      <0.2733889, 0.1479163, 0.1902909>,
      <0.2733836, 0.1482373, 0.1922949>,
      <0.2023562, 0.1483868, 0.1151532>,
      <0.0602908, 0.1493290, 0.1151532>,
      <0.2023561, 0.1483862, 0.0400154>,
      <0.1313235, 0.1488579, 0.1151532>,
      <0.0602906, 0.1493287, 0.0775843>,
      <0.1313233, 0.1488573, 0.0400154>,
      <0.2023562, 0.1483865, 0.0775843>,
      <0.1313234, 0.1488576, 0.0775843>,
      <0.3444216, 0.1474447, 0.1151532>,
      <0.2733889, 0.1479151, 0.0400154>,
      <0.3444217, 0.1474443, 0.0775843>,
      <0.2733889, 0.1479157, 0.1151532>,
      <0.2733889, 0.1479154, 0.0775843>,
      <0.2023563, 0.1483874, 0.1902909>,
      <0.3444216, 0.1474450, 0.1527220>,
      <0.2733889, 0.1479163, 0.1902909>,
      <0.2023563, 0.1483871, 0.1527220>,
      <0.2733889, 0.1479160, 0.1527220>,
      <0.1313238, 0.1488585, 0.1902909>,
      <0.0602910, 0.1493292, 0.1527220>,
      <0.1313236, 0.1488582, 0.1527220>,
      <0.2023373, 0.1482934, 0.0380992>,
      <0.2023184, 0.1482006, 0.0361829>,
      <0.2023278, 0.1482470, 0.0371410>,
      <0.1312447, 0.1486753, 0.0361829>,
      <0.1312840, 0.1487663, 0.0380992>,
      <0.1312644, 0.1487208, 0.0371410>,
      <0.2023561, 0.1483862, 0.0400154>,
      <0.1313233, 0.1488573, 0.0400154>,
      <0.2023467, 0.1483398, 0.0390573>,
      <0.1313036, 0.1488118, 0.0390573>,
      <0.2733889, 0.1479151, 0.0400154>,
      <0.2733905, 0.1478205, 0.0380992>,
      <0.2733897, 0.1478678, 0.0390573>,
      <0.2733921, 0.1477258, 0.0361829>,
      <0.2733913, 0.1477731, 0.0371410>,
      <0.2022803, 0.1480128, 0.0196916>,
      <0.0600465, 0.1489640, 0.0193323>,
      <0.2022535, 0.1478811, 0.0065531>,
      <0.1311636, 0.1484894, 0.0195718>,
      <0.0599842, 0.1488709, 0.0109070>,
      <0.1310992, 0.1483509, 0.0058346>,
      <0.2022643, 0.1479339, 0.0123440>,
      <0.1311250, 0.1484065, 0.0118650>,
      <0.3445116, 0.1470496, 0.0193323>,
      <0.2734030, 0.1473873, 0.0058346>,
      <0.3445346, 0.1469488, 0.0109070>,
      <0.2733962, 0.1475322, 0.0195718>,
      <0.2734002, 0.1474454, 0.0118650>,
      <0.2023184, 0.1482006, 0.0361829>,
      <0.3444887, 0.1471503, 0.0277576>,
      <0.2733921, 0.1477258, 0.0361829>,
      <0.2022987, 0.1481037, 0.0277576>,
      <0.2733937, 0.1476270, 0.0277576>,
      <0.1312447, 0.1486753, 0.0361829>,
      <0.0601088, 0.1490571, 0.0277576>,
      <0.1312038, 0.1485804, 0.0277576>,
      <0.2022537, 0.1478818, 0.0013178>,
      <0.2022510, 0.1478684, 0.0031571>,
      <0.1311082, 0.1483610, 0.0011980>,
      <0.1310973, 0.1483423, 0.0026781>,
      <0.2022652, 0.1479386, -0.0005647>,
      <0.1311339, 0.1484186, -0.0005647>,
      <0.2022588, 0.1479072, 0.0001969>,
      <0.1311206, 0.1483878, 0.0001969>,
      <0.2733965, 0.1474586, -0.0005647>,
      <0.2733984, 0.1473986, 0.0011980>,
      <0.2733970, 0.1474266, 0.0001969>,
      <0.2734013, 0.1473786, 0.0026781>
    }
    normal_vectors {
      1158,
      <-0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.0000000, 0.0000000, 1.0000000>,
      <0.9488313, -0.3050609, -0.0815899>,
      <0.9374591, -0.3014046, -0.1741425>,
      <0.9376015, -0.3034812, -0.1697135>,
      <0.9484038, -0.3069777, -0.0793404>,
      <0.9513223, -0.3079223, 0.0130279>,
      <0.9519234, -0.3060551, 0.0131178>,
      <0.9519234, -0.3060551, 0.0131178>,
      <0.9525520, -0.3040889, 0.0132123>,
      <0.9492719, -0.3030417, -0.0839554>,
      <0.9492719, -0.3030417, -0.0839554>,
      <0.9372854, -0.2992152, -0.1787912>,
      <0.9186701, -0.2953637, -0.2623082>,
      <0.9196976, -0.2976861, -0.2560066>,
      <0.9372854, -0.2992152, -0.1787912>,
      <0.9175472, -0.2929140, -0.2689025>,
      <0.9175472, -0.2929140, -0.2689025>,
      <0.8914950, -0.2845973, -0.3524784>,
      <0.8937744, -0.2873594, -0.3443718>,
      <0.8937744, -0.2873594, -0.3443718>,
      <0.8958882, -0.2899795, -0.3365949>,
      <0.9206389, -0.2998905, -0.2499794>,
      <0.9377162, -0.3054532, -0.1654892>,
      <0.8958882, -0.2899795, -0.3365949>,
      <0.8978510, -0.2924675, -0.3291298>,
      <0.8978510, -0.2924675, -0.3291298>,
      <0.8996755, -0.2948323, -0.3219596>,
      <0.9215023, -0.3019852, -0.2442098>,
      <0.9215023, -0.3019852, -0.2442098>,
      <0.9378066, -0.3073283, -0.1614561>,
      <0.9479890, -0.3087995, -0.0771987>,
      <0.9378066, -0.3073283, -0.1614561>,
      <0.9475867, -0.3105333, -0.0751572>,
      <0.9475867, -0.3105333, -0.0751572>,
      <0.9501957, -0.3113883, 0.0128608>,
      <0.9507469, -0.3096979, 0.0129424>,
      <0.9507469, -0.3096979, 0.0129424>,
      <0.9513223, -0.3079223, 0.0130279>,
      <0.0006739, 0.2206039, -0.9753633>,
      <0.0006756, 0.2211587, -0.9752376>,
      <0.0006518, 0.2211634, -0.9752365>,
      <0.0006501, 0.2206108, -0.9753617>,
      <0.0006485, 0.2200609, -0.9754859>,
      <0.0006722, 0.2200517, -0.9754880>,
      <0.0006722, 0.2200517, -0.9754880>,
      <0.0006961, 0.2200424, -0.9754901>,
      <0.0006978, 0.2205968, -0.9753648>,
      <0.0006978, 0.2205968, -0.9753648>,
      <0.0006996, 0.2211540, -0.9752386>,
      <0.0006773, 0.2217163, -0.9751110>,
      <0.0006534, 0.2217188, -0.9751104>,
      <0.0006996, 0.2211540, -0.9752386>,
      <0.0007014, 0.2217139, -0.9751115>,
      <0.0007014, 0.2217139, -0.9751115>,
      <0.0007031, 0.2222766, -0.9749834>,
      <0.0006790, 0.2222767, -0.9749834>,
      <0.0006790, 0.2222767, -0.9749834>,
      <0.0006551, 0.2222768, -0.9749834>,
      <0.0006297, 0.2217212, -0.9751099>,
      <0.0006282, 0.2211681, -0.9752355>,
      <0.0006551, 0.2222768, -0.9749834>,
      <0.0006313, 0.2222769, -0.9749834>,
      <0.0006313, 0.2222769, -0.9749834>,
      <0.0006078, 0.2222770, -0.9749834>,
      <0.0006062, 0.2217235, -0.9751094>,
      <0.0006062, 0.2217235, -0.9751094>,
      <0.0006047, 0.2211727, -0.9752345>,
      <0.0006266, 0.2206177, -0.9753601>,
      <0.0006047, 0.2211727, -0.9752345>,
      <0.0006032, 0.2206246, -0.9753586>,
      <0.0006032, 0.2206246, -0.9753586>,
      <0.0006017, 0.2200791, -0.9754818>,
      <0.0006250, 0.2200700, -0.9754839>,
      <0.0006250, 0.2200700, -0.9754839>,
      <0.0006485, 0.2200609, -0.9754859>,
      <-0.9999246, 0.0016043, 0.0121747>,
      <-0.9999338, 0.0016043, 0.0113941>,
      <-0.9999342, 0.0016214, 0.0113570>,
      <-0.9999253, 0.0016214, 0.0121188>,
      <-0.9999157, 0.0016214, 0.0128805>,
      <-0.9999148, 0.0016043, 0.0129554>,
      <-0.9999148, 0.0016043, 0.0129554>,
      <-0.9999138, 0.0015864, 0.0130340>,
      <-0.9999239, 0.0015864, 0.0122335>,
      <-0.9999239, 0.0015864, 0.0122335>,
      <-0.9999334, 0.0015864, 0.0114330>,
      <-0.9999424, 0.0016043, 0.0106134>,
      <-0.9999426, 0.0016214, 0.0105953>,
      <-0.9999334, 0.0015864, 0.0114330>,
      <-0.9999422, 0.0015864, 0.0106325>,
      <-0.9999422, 0.0015864, 0.0106325>,
      <-0.9999504, 0.0015864, 0.0098320>,
      <-0.9999504, 0.0016044, 0.0098327>,
      <-0.9999504, 0.0016044, 0.0098327>,
      <-0.9999503, 0.0016214, 0.0098335>,
      <-0.9999427, 0.0016377, 0.0105779>,
      <-0.9999346, 0.0016377, 0.0113217>,
      <-0.9999503, 0.0016214, 0.0098335>,
      <-0.9999503, 0.0016377, 0.0098342>,
      <-0.9999503, 0.0016377, 0.0098342>,
      <-0.9999503, 0.0016532, 0.0098348>,
      <-0.9999429, 0.0016532, 0.0105614>,
      <-0.9999429, 0.0016532, 0.0105614>,
      <-0.9999349, 0.0016532, 0.0112880>,
      <-0.9999259, 0.0016376, 0.0120655>,
      <-0.9999349, 0.0016532, 0.0112880>,
      <-0.9999265, 0.0016532, 0.0120146>,
      <-0.9999265, 0.0016532, 0.0120146>,
      <-0.9999175, 0.0016531, 0.0127412>,
      <-0.9999166, 0.0016376, 0.0128092>,
      <-0.9999166, 0.0016376, 0.0128092>,
      <-0.9999157, 0.0016214, 0.0128805>,
      <-0.9416801, 0.3279502, -0.0754138>,
      <-0.9334595, 0.3250873, -0.1515637>,
      <-0.9274337, 0.3421299, -0.1510424>,
      <-0.9355395, 0.3451202, -0.0752187>,
      <-0.9381956, 0.3461000, 0.0019306>,
      <-0.9443673, 0.3288861, 0.0020767>,
      <-0.9443673, 0.3288861, 0.0020767>,
      <-0.9502720, 0.3114133, 0.0022234>,
      <-0.9475559, 0.3105232, -0.0755852>,
      <-0.9475559, 0.3105232, -0.0755852>,
      <-0.9392269, 0.3077937, -0.1520391>,
      <-0.9201304, 0.3204453, -0.2251109>,
      <-0.9142935, 0.3372825, -0.2242943>,
      <-0.9392269, 0.3077937, -0.1520391>,
      <-0.9257186, 0.3033669, -0.2258617>,
      <-0.9257186, 0.3033669, -0.2258617>,
      <-0.9076927, 0.2974597, -0.2959928>,
      <-0.9023405, 0.3142498, -0.2950062>,
      <-0.9023405, 0.3142498, -0.2950062>,
      <-0.8967524, 0.3308116, -0.2939366>,
      <-0.9082203, 0.3538670, -0.2234144>,
      <-0.9211626, 0.3589097, -0.1504771>,
      <-0.8967524, 0.3308116, -0.2939366>,
      <-0.8909398, 0.3471341, -0.2927870>,
      <-0.8909398, 0.3471341, -0.2927870>,
      <-0.8849142, 0.3632069, -0.2915606>,
      <-0.9019235, 0.3701883, -0.2224737>,
      <-0.9019235, 0.3701883, -0.2224737>,
      <-0.9146596, 0.3754157, -0.1498695>,
      <-0.9291478, 0.3620210, -0.0750007>,
      <-0.9146596, 0.3754157, -0.1498695>,
      <-0.9225191, 0.3786416, -0.0747606>,
      <-0.9225191, 0.3786416, -0.0747606>,
      <-0.9251067, 0.3797037, 0.0016406>,
      <-0.9317707, 0.3630429, 0.0017852>,
      <-0.9317707, 0.3630429, 0.0017852>,
      <-0.9381956, 0.3461000, 0.0019306>,
      <-0.0025138, -0.9991116, 0.0420685>,
      <-0.0025136, -0.9990267, 0.0440373>,
      <-0.0022993, -0.9990258, 0.0440711>,
      <-0.0022995, -0.9991100, 0.0421189>,
      <-0.0022996, -0.9991904, 0.0401663>,
      <-0.0025140, -0.9991925, 0.0400993>,
      <-0.0025140, -0.9991925, 0.0400993>,
      <-0.0027320, -0.9991947, 0.0400312>,
      <-0.0027318, -0.9991131, 0.0420173>,
      <-0.0027318, -0.9991131, 0.0420173>,
      <-0.0027316, -0.9990277, 0.0440028>,
      <-0.0025134, -0.9989380, 0.0460055>,
      <-0.0022991, -0.9989377, 0.0460228>,
      <-0.0027316, -0.9990277, 0.0440028>,
      <-0.0027313, -0.9989383, 0.0459879>,
      <-0.0027313, -0.9989383, 0.0459879>,
      <-0.0027311, -0.9988449, 0.0479724>,
      <-0.0025131, -0.9988455, 0.0479731>,
      <-0.0025131, -0.9988455, 0.0479731>,
      <-0.0022988, -0.9988459, 0.0479739>,
      <-0.0020883, -0.9989374, 0.0460398>,
      <-0.0020885, -0.9990247, 0.0441044>,
      <-0.0022988, -0.9988459, 0.0479739>,
      <-0.0020881, -0.9988464, 0.0479746>,
      <-0.0020881, -0.9988464, 0.0479746>,
      <-0.0018809, -0.9988467, 0.0479754>,
      <-0.0018811, -0.9989371, 0.0460565>,
      <-0.0018811, -0.9989371, 0.0460565>,
      <-0.0018813, -0.9990237, 0.0441371>,
      <-0.0020887, -0.9991083, 0.0421685>,
      <-0.0018813, -0.9990237, 0.0441371>,
      <-0.0018814, -0.9991067, 0.0422172>,
      <-0.0018814, -0.9991067, 0.0422172>,
      <-0.0018816, -0.9991860, 0.0402968>,
      <-0.0020889, -0.9991882, 0.0402321>,
      <-0.0020889, -0.9991882, 0.0402321>,
      <-0.0022996, -0.9991904, 0.0401663>,
      <0.9999937, -0.0017690, 0.0030812>,
      <0.9999950, -0.0017690, 0.0026212>,
      <0.9999948, -0.0018853, 0.0026244>,
      <0.9999935, -0.0018853, 0.0030857>,
      <0.9999919, -0.0018852, 0.0035469>,
      <0.9999922, -0.0017690, 0.0035413>,
      <0.9999922, -0.0017690, 0.0035413>,
      <0.9999924, -0.0016533, 0.0035357>,
      <0.9999939, -0.0016533, 0.0030769>,
      <0.9999939, -0.0016533, 0.0030769>,
      <0.9999952, -0.0016533, 0.0026180>,
      <0.9999961, -0.0017690, 0.0021611>,
      <0.9999959, -0.0018853, 0.0021632>,
      <0.9999952, -0.0016533, 0.0026180>,
      <0.9999963, -0.0016533, 0.0021591>,
      <0.9999963, -0.0016533, 0.0021591>,
      <0.9999972, -0.0016533, 0.0017002>,
      <0.9999970, -0.0017690, 0.0017011>,
      <0.9999970, -0.0017690, 0.0017011>,
      <0.9999968, -0.0018853, 0.0017019>,
      <0.9999957, -0.0020021, 0.0021652>,
      <0.9999945, -0.0020021, 0.0026277>,
      <0.9999968, -0.0018853, 0.0017019>,
      <0.9999965, -0.0020022, 0.0017028>,
      <0.9999965, -0.0020022, 0.0017028>,
      <0.9999963, -0.0021196, 0.0017037>,
      <0.9999954, -0.0021196, 0.0021673>,
      <0.9999954, -0.0021196, 0.0021673>,
      <0.9999943, -0.0021196, 0.0026309>,
      <0.9999932, -0.0020021, 0.0030901>,
      <0.9999943, -0.0021196, 0.0026309>,
      <0.9999930, -0.0021196, 0.0030945>,
      <0.9999930, -0.0021196, 0.0030945>,
      <0.9999914, -0.0021196, 0.0035581>,
      <0.9999917, -0.0020021, 0.0035525>,
      <0.9999917, -0.0020021, 0.0035525>,
      <0.9999919, -0.0018852, 0.0035469>,
      <-0.9250509, 0.3796933, 0.0106678>,
      <-0.9250555, 0.3796952, 0.0101898>,
      <-0.9250511, 0.3797052, 0.0102200>,
      <-0.9250466, 0.3797033, 0.0106826>,
      <-0.9250420, 0.3797014, 0.0111453>,
      <-0.9250461, 0.3796913, 0.0111459>,
      <-0.9250461, 0.3796913, 0.0111459>,
      <-0.9250505, 0.3796806, 0.0111465>,
      <-0.9250555, 0.3796826, 0.0106520>,
      <-0.9250555, 0.3796826, 0.0106520>,
      <-0.9250602, 0.3796846, 0.0101575>,
      <-0.9250599, 0.3796970, 0.0097117>,
      <-0.9250554, 0.3797069, 0.0097574>,
      <-0.9250602, 0.3796846, 0.0101575>,
      <-0.9250648, 0.3796865, 0.0096629>,
      <-0.9250648, 0.3796865, 0.0096629>,
      <-0.9250691, 0.3796882, 0.0091684>,
      <-0.9250641, 0.3796987, 0.0092337>,
      <-0.9250641, 0.3796987, 0.0092337>,
      <-0.9250595, 0.3797086, 0.0092947>,
      <-0.9250511, 0.3797162, 0.0098002>,
      <-0.9250470, 0.3797145, 0.0102484>,
      <-0.9250595, 0.3797086, 0.0092947>,
      <-0.9250551, 0.3797178, 0.0093520>,
      <-0.9250551, 0.3797178, 0.0093520>,
      <-0.9250510, 0.3797265, 0.0094058>,
      <-0.9250471, 0.3797249, 0.0098404>,
      <-0.9250471, 0.3797249, 0.0098404>,
      <-0.9250431, 0.3797232, 0.0102750>,
      <-0.9250426, 0.3797127, 0.0106965>,
      <-0.9250431, 0.3797232, 0.0102750>,
      <-0.9250389, 0.3797215, 0.0107096>,
      <-0.9250389, 0.3797215, 0.0107096>,
      <-0.9250345, 0.3797197, 0.0111442>,
      <-0.9250381, 0.3797108, 0.0111447>,
      <-0.9250381, 0.3797108, 0.0111447>,
      <-0.9250420, 0.3797014, 0.0111453>,
      <-0.0003288, -0.1891579, -0.9819466>,
      <-0.0003296, -0.1896159, -0.9818583>,
      <-0.0003024, -0.1896213, -0.9818572>,
      <-0.0003017, -0.1891659, -0.9819451>,
      <-0.0003010, -0.1887126, -0.9820323>,
      <-0.0003280, -0.1887020, -0.9820343>,
      <-0.0003280, -0.1887020, -0.9820343>,
      <-0.0003553, -0.1886912, -0.9820364>,
      <-0.0003562, -0.1891497, -0.9819482>,
      <-0.0003562, -0.1891497, -0.9819482>,
      <-0.0003571, -0.1896104, -0.9818593>,
      <-0.0003304, -0.1900761, -0.9817693>,
      <-0.0003032, -0.1900789, -0.9817688>,
      <-0.0003571, -0.1896104, -0.9818593>,
      <-0.0003579, -0.1900733, -0.9817698>,
      <-0.0003579, -0.1900733, -0.9817698>,
      <-0.0003588, -0.1905384, -0.9816797>,
      <-0.0003312, -0.1905385, -0.9816797>,
      <-0.0003312, -0.1905385, -0.9816797>,
      <-0.0003039, -0.1905386, -0.9816796>,
      <-0.0002762, -0.1900817, -0.9817682>,
      <-0.0002756, -0.1896267, -0.9818562>,
      <-0.0003039, -0.1905386, -0.9816796>,
      <-0.0002769, -0.1905388, -0.9816796>,
      <-0.0002769, -0.1905388, -0.9816796>,
      <-0.0002502, -0.1905389, -0.9816796>,
      <-0.0002496, -0.1900844, -0.9817677>,
      <-0.0002496, -0.1900844, -0.9817677>,
      <-0.0002490, -0.1896320, -0.9818552>,
      <-0.0002749, -0.1891739, -0.9819436>,
      <-0.0002490, -0.1896320, -0.9818552>,
      <-0.0002484, -0.1891818, -0.9819421>,
      <-0.0002484, -0.1891818, -0.9819421>,
      <-0.0002479, -0.1887336, -0.9820283>,
      <-0.0002743, -0.1887232, -0.9820303>,
      <-0.0002743, -0.1887232, -0.9820303>,
      <-0.0003010, -0.1887126, -0.9820323>,
      <0.9999222, -0.0021258, 0.0122917>,
      <0.9999251, -0.0021258, 0.0120530>,
      <0.9999253, -0.0021317, 0.0120379>,
      <0.9999225, -0.0021317, 0.0122689>,
      <0.9999196, -0.0021317, 0.0125000>,
      <0.9999192, -0.0021258, 0.0125305>,
      <0.9999192, -0.0021258, 0.0125305>,
      <0.9999188, -0.0021195, 0.0125631>,
      <0.9999219, -0.0021195, 0.0123161>,
      <0.9999219, -0.0021195, 0.0123161>,
      <0.9999249, -0.0021195, 0.0120691>,
      <0.9999279, -0.0021258, 0.0118142>,
      <0.9999280, -0.0021317, 0.0118068>,
      <0.9999249, -0.0021195, 0.0120691>,
      <0.9999279, -0.0021195, 0.0118221>,
      <0.9999279, -0.0021195, 0.0118221>,
      <0.9999308, -0.0021195, 0.0115751>,
      <0.9999307, -0.0021258, 0.0115755>,
      <0.9999307, -0.0021258, 0.0115755>,
      <0.9999307, -0.0021318, 0.0115758>,
      <0.9999281, -0.0021373, 0.0117999>,
      <0.9999254, -0.0021373, 0.0120237>,
      <0.9999307, -0.0021318, 0.0115758>,
      <0.9999307, -0.0021373, 0.0115760>,
      <0.9999307, -0.0021373, 0.0115760>,
      <0.9999307, -0.0021425, 0.0115763>,
      <0.9999282, -0.0021425, 0.0117934>,
      <0.9999282, -0.0021425, 0.0117934>,
      <0.9999256, -0.0021425, 0.0120104>,
      <0.9999227, -0.0021373, 0.0122476>,
      <0.9999256, -0.0021425, 0.0120104>,
      <0.9999229, -0.0021425, 0.0122275>,
      <0.9999229, -0.0021425, 0.0122275>,
      <0.9999203, -0.0021425, 0.0124445>,
      <0.9999199, -0.0021373, 0.0124714>,
      <0.9999199, -0.0021373, 0.0124714>,
      <0.9999196, -0.0021317, 0.0125000>,
      <-0.9250945, 0.3797371, 0.0000286>,
      <-0.9250933, 0.3797400, 0.0000483>,
      <-0.9251037, 0.3797146, 0.0002015>,
      <-0.9251131, 0.3796917, 0.0001124>,
      <-0.9251150, 0.3796870, 0.0000018>,
      <-0.9250948, 0.3797362, 0.0000018>,
      <-0.9250948, 0.3797362, 0.0000018>,
      <-0.9250919, 0.3797433, 0.0000018>,
      <-0.9250919, 0.3797433, 0.0000018>,
      <-0.9250919, 0.3797433, 0.0000018>,
      <-0.9250919, 0.3797433, 0.0000017>,
      <-0.9250920, 0.3797429, 0.0000551>,
      <-0.9250934, 0.3797396, 0.0002362>,
      <-0.9250919, 0.3797433, 0.0000017>,
      <-0.9250919, 0.3797433, 0.0000016>,
      <-0.9250919, 0.3797433, 0.0000016>,
      <-0.9250919, 0.3797433, 0.0000016>,
      <-0.9250916, 0.3797439, 0.0000540>,
      <-0.9250916, 0.3797439, 0.0000540>,
      <-0.9250899, 0.3797481, 0.0002329>,
      <-0.9250967, 0.3797311, 0.0006391>,
      <-0.9251298, 0.3796504, 0.0005766>,
      <-0.9250899, 0.3797481, 0.0002329>,
      <-0.9250853, 0.3797588, 0.0006314>,
      <-0.9250853, 0.3797588, 0.0006314>,
      <-0.9250767, 0.3797771, 0.0015801>,
      <-0.9250967, 0.3797282, 0.0016064>,
      <-0.9251570, 0.3795812, 0.0016090>,
      <-0.9251716, 0.3795489, 0.0003748>,
      <-0.9252994, 0.3792338, 0.0016370>,
      <-0.9254184, 0.3789424, 0.0018395>,
      <-0.9251791, 0.3795308, 0.0000018>,
      <-0.9251791, 0.3795308, 0.0000018>,
      <-0.9251150, 0.3796870, 0.0000018>,
      <-0.0013019, -0.9995565, -0.0297511>,
      <-0.0013019, -0.9995587, -0.0296779>,
      <-0.0012232, -0.9919307, -0.1267750>,
      <-0.0012231, -0.9918915, -0.1270819>,
      <-0.0012231, -0.9918521, -0.1273888>,
      <-0.0013019, -0.9995543, -0.0298243>,
      <-0.0013019, -0.9995543, -0.0298243>,
      <-0.0013132, -0.9999988, -0.0008597>,
      <-0.0013132, -0.9999988, -0.0008576>,
      <-0.0013132, -0.9999988, -0.0008576>,
      <-0.0013132, -0.9999988, -0.0008555>,
      <-0.0013019, -0.9995608, -0.0296048>,
      <-0.0012232, -0.9919699, -0.1264680>,
      <-0.0013132, -0.9999988, -0.0008555>,
      <-0.0013132, -0.9999988, -0.0008534>,
      <-0.0013132, -0.9999988, -0.0008534>,
      <-0.0013132, -0.9999988, -0.0008513>,
      <-0.0013019, -0.9995630, -0.0295316>,
      <-0.0013019, -0.9995630, -0.0295316>,
      <-0.0012233, -0.9920090, -0.1261610>,
      <-0.0009914, -0.9458393, -0.3246336>,
      <-0.0009912, -0.9455951, -0.3253443>,
      <-0.0012233, -0.9920090, -0.1261610>,
      <-0.0009917, -0.9460831, -0.3239224>,
      <-0.0009917, -0.9460831, -0.3239224>,
      <-0.0005318, -0.7631623, -0.6462066>,
      <-0.0005313, -0.7623919, -0.6471154>,
      <-0.0005308, -0.7616220, -0.6480213>,
      <-0.0009909, -0.9453505, -0.3260544>,
      <-0.0005302, -0.7608526, -0.6489246>,
      <-0.0005297, -0.7600836, -0.6498250>,
      <-0.0009907, -0.9451055, -0.3267639>,
      <-0.0009907, -0.9451055, -0.3267639>,
      <-0.0012231, -0.9918521, -0.1273888>,
      <0.9999977, -0.0021443, 0.0000687>,
      <0.9999977, -0.0021479, 0.0000578>,
      <0.9999976, -0.0021872, 0.0002410>,
      <0.9999976, -0.0021562, 0.0002938>,
      <0.9999977, -0.0021455, 0.0003068>,
      <0.9999977, -0.0021430, 0.0000714>,
      <0.9999977, -0.0021430, 0.0000714>,
      <0.9999977, -0.0021427, 0.0000021>,
      <0.9999977, -0.0021427, 0.0000020>,
      <0.9999977, -0.0021427, 0.0000020>,
      <0.9999977, -0.0021427, 0.0000020>,
      <0.9999977, -0.0021515, 0.0000335>,
      <0.9999975, -0.0022151, 0.0001319>,
      <0.9999977, -0.0021427, 0.0000020>,
      <0.9999977, -0.0021427, 0.0000019>,
      <0.9999977, -0.0021427, 0.0000019>,
      <0.9999977, -0.0021427, 0.0000019>,
      <0.9999977, -0.0021525, 0.0000019>,
      <0.9999977, -0.0021525, 0.0000019>,
      <0.9999975, -0.0022204, 0.0000019>,
      <0.9999970, -0.0024127, 0.0004262>,
      <0.9999972, -0.0022886, 0.0006796>,
      <0.9999975, -0.0022204, 0.0000019>,
      <0.9999970, -0.0024311, 0.0000019>,
      <0.9999970, -0.0024311, 0.0000019>,
      <0.9999931, -0.0031846, 0.0019113>,
      <0.9999943, -0.0028444, 0.0017942>,
      <0.9999954, -0.0024146, 0.0018600>,
      <0.9999973, -0.0021874, 0.0007890>,
      <0.9999956, -0.0022273, 0.0019562>,
      <0.9999956, -0.0021628, 0.0020283>,
      <0.9999973, -0.0021519, 0.0008239>,
      <0.9999973, -0.0021519, 0.0008239>,
      <0.9999977, -0.0021455, 0.0003068>,
      <-0.9252856, 0.3792231, 0.0060381>,
      <-0.9251426, 0.3795995, 0.0039224>,
      <-0.9250457, 0.3798040, 0.0062769>,
      <-0.9250229, 0.3797624, 0.0106385>,
      <-0.9245192, 0.3794195, 0.0361267>,
      <-0.9258929, 0.3759912, 0.0367824>,
      <-0.9258929, 0.3759912, 0.0367824>,
      <-0.9254184, 0.3789424, 0.0018395>,
      <-0.9250811, 0.3797535, 0.0034955>,
      <-0.9250470, 0.3798180, 0.0051322>,
      <-0.9250767, 0.3797771, 0.0015801>,
      <-0.9250624, 0.3797999, 0.0033908>,
      <-0.9250624, 0.3797999, 0.0033908>,
      <-0.9250470, 0.3798216, 0.0048656>,
      <-0.9250263, 0.3798781, 0.0043598>,
      <-0.9249713, 0.3800020, 0.0051607>,
      <-0.9250470, 0.3798216, 0.0048656>,
      <-0.9250421, 0.3798423, 0.0041089>,
      <-0.9250421, 0.3798423, 0.0041089>,
      <-0.9250422, 0.3798584, 0.0021212>,
      <-0.9250283, 0.3798917, 0.0022070>,
      <-0.9249856, 0.3799950, 0.0023153>,
      <-0.9248282, 0.3803015, 0.0079709>,
      <-0.9248844, 0.3802409, 0.0024013>,
      <-0.9248165, 0.3804065, 0.0023300>,
      <-0.9235502, 0.3818152, 0.0356675>,
      <-0.9235502, 0.3818152, 0.0356675>,
      <-0.9245192, 0.3794195, 0.0361267>,
      <-0.0000808, -0.4852313, -0.8743858>,
      <-0.0000809, -0.4861035, -0.8739013>,
      <0.0001630, -0.3661433, -0.9305585>,
      <0.0001627, -0.3654181, -0.9308435>,
      <0.0001623, -0.3646957, -0.9311268>,
      <-0.0000806, -0.4843617, -0.8748678>,
      <-0.0000806, -0.4843617, -0.8748678>,
      <-0.0005297, -0.7600836, -0.6498250>,
      <-0.0000811, -0.4869783, -0.8734141>,
      <0.0001633, -0.3668710, -0.9302718>,
      <-0.0005318, -0.7631623, -0.6462066>,
      <-0.0000812, -0.4878558, -0.8729242>,
      <-0.0000812, -0.4878558, -0.8729242>,
      <0.0001636, -0.3676015, -0.9299834>,
      <0.0004400, -0.4272857, -0.9041166>,
      <0.0004392, -0.4265056, -0.9044848>,
      <0.0001636, -0.3676015, -0.9299834>,
      <0.0004408, -0.4280683, -0.9037463>,
      <0.0004408, -0.4280683, -0.9037463>,
      <0.0010184, -0.6790898, -0.7340545>,
      <0.0010172, -0.6782875, -0.7347960>,
      <0.0010160, -0.6774862, -0.7355348>,
      <0.0004384, -0.4257280, -0.9048511>,
      <0.0010148, -0.6766860, -0.7362710>,
      <0.0010136, -0.6758869, -0.7370047>,
      <0.0004376, -0.4249530, -0.9052153>,
      <0.0004376, -0.4249530, -0.9052153>,
      <0.0001623, -0.3646957, -0.9311268>,
      <0.9999887, -0.0022395, 0.0041835>,
      <0.9999871, -0.0024373, 0.0044632>,
      <0.9999726, -0.0022106, 0.0070592>,
      <0.9999793, -0.0021955, 0.0060433>,
      <0.9999797, -0.0021914, 0.0059878>,
      <0.9999886, -0.0021773, 0.0042603>,
      <0.9999886, -0.0021773, 0.0042603>,
      <0.9999956, -0.0021628, 0.0020283>,
      <0.9999745, -0.0028993, 0.0065314>,
      <0.9999319, -0.0022447, 0.0114548>,
      <0.9999931, -0.0031846, 0.0019113>,
      <0.9992479, -0.0065252, 0.0382247>,
      <0.9992479, -0.0065252, 0.0382247>,
      <0.9992919, -0.0023841, 0.0375502>,
      <0.9999621, -0.0016151, 0.0085524>,
      <0.9999814, -0.0019951, 0.0057588>,
      <0.9992919, -0.0023841, 0.0375502>,
      <0.9993122, 0.0005095, 0.0370785>,
      <0.9993122, 0.0005095, 0.0370785>,
      <0.9999959, -0.0015389, 0.0024226>,
      <0.9999952, -0.0017338, 0.0025817>,
      <0.9999946, -0.0020375, 0.0025763>,
      <0.9999848, -0.0021552, 0.0050692>,
      <0.9999944, -0.0021678, 0.0025453>,
      <0.9999943, -0.0022109, 0.0025373>,
      <0.9999852, -0.0022028, 0.0049728>,
      <0.9999852, -0.0022028, 0.0049728>,
      <0.9999797, -0.0021914, 0.0059878>,
      <-0.9249891, 0.3799932, 0.0006185>,
      <-0.9250138, 0.3799324, 0.0008818>,
      <-0.9250315, 0.3798902, 0.0003706>,
      <-0.9250263, 0.3799029, 0.0002568>,
      <-0.9250253, 0.3799055, 0.0001137>,
      <-0.9249855, 0.3800023, 0.0001136>,
      <-0.9249855, 0.3800023, 0.0001136>,
      <-0.9248165, 0.3804065, 0.0023300>,
      <-0.9250338, 0.3798837, 0.0009436>,
      <-0.9250372, 0.3798762, 0.0004133>,
      <-0.9250422, 0.3798584, 0.0021212>,
      <-0.9250406, 0.3798671, 0.0009282>,
      <-0.9250406, 0.3798671, 0.0009282>,
      <-0.9250392, 0.3798715, 0.0004106>,
      <-0.9250382, 0.3798741, 0.0001764>,
      <-0.9250375, 0.3798757, 0.0001691>,
      <-0.9250392, 0.3798715, 0.0004106>,
      <-0.9250384, 0.3798735, 0.0001740>,
      <-0.9250384, 0.3798735, 0.0001740>,
      <-0.9250380, 0.3798745, 0.0001042>,
      <-0.9250380, 0.3798745, 0.0001066>,
      <-0.9250380, 0.3798745, 0.0001066>,
      <-0.9250380, 0.3798745, 0.0001090>,
      <-0.9250369, 0.3798772, 0.0001458>,
      <-0.9250380, 0.3798745, 0.0001090>,
      <-0.9250380, 0.3798745, 0.0001113>,
      <-0.9250380, 0.3798745, 0.0001113>,
      <-0.9250380, 0.3798745, 0.0001137>,
      <-0.9250367, 0.3798777, 0.0001137>,
      <-0.9250367, 0.3798777, 0.0001137>,
      <-0.9250253, 0.3799055, 0.0001137>,
      <0.0016281, -0.9037072, -0.4281479>,
      <0.0016288, -0.9040631, -0.4273959>,
      <0.0019284, -0.9789239, -0.2042165>,
      <0.0019282, -0.9788365, -0.2046347>,
      <0.0019280, -0.9787490, -0.2050527>,
      <0.0016275, -0.9033510, -0.4288991>,
      <0.0016275, -0.9033510, -0.4288991>,
      <0.0010136, -0.6758869, -0.7370047>,
      <0.0016294, -0.9044187, -0.4266429>,
      <0.0019285, -0.9790110, -0.2037982>,
      <0.0010184, -0.6790898, -0.7340545>,
      <0.0016300, -0.9047739, -0.4258891>,
      <0.0016300, -0.9047739, -0.4258891>,
      <0.0019287, -0.9790980, -0.2033798>,
      <0.0020445, -0.9961417, -0.0877353>,
      <0.0020444, -0.9961254, -0.0879210>,
      <0.0019287, -0.9790980, -0.2033798>,
      <0.0020445, -0.9961581, -0.0875495>,
      <0.0020445, -0.9961581, -0.0875495>,
      <0.0020899, -0.9986169, -0.0525341>,
      <0.0020899, -0.9986111, -0.0526459>,
      <0.0020899, -0.9986111, -0.0526459>,
      <0.0020899, -0.9986052, -0.0527577>,
      <0.0020444, -0.9961089, -0.0881067>,
      <0.0020899, -0.9986052, -0.0527577>,
      <0.0020899, -0.9985992, -0.0528694>,
      <0.0020899, -0.9985992, -0.0528694>,
      <0.0020899, -0.9985933, -0.0529812>,
      <0.0020444, -0.9960925, -0.0882924>,
      <0.0020444, -0.9960925, -0.0882924>,
      <0.0019280, -0.9787490, -0.2050527>,
      <0.9999970, -0.0021947, 0.0010841>,
      <0.9999972, -0.0021341, 0.0009839>,
      <0.9999975, -0.0021950, 0.0004143>,
      <0.9999974, -0.0022123, 0.0004740>,
      <0.9999974, -0.0022182, 0.0004861>,
      <0.9999969, -0.0022157, 0.0011027>,
      <0.9999969, -0.0022157, 0.0011027>,
      <0.9999943, -0.0022109, 0.0025373>,
      <0.9999977, -0.0020597, 0.0006738>,
      <0.9999976, -0.0021795, 0.0002809>,
      <0.9999959, -0.0015389, 0.0024226>,
      <0.9999979, -0.0020501, 0.0001182>,
      <0.9999979, -0.0020501, 0.0001182>,
      <0.9999976, -0.0021766, 0.0001182>,
      <0.9999975, -0.0022148, 0.0001577>,
      <0.9999975, -0.0022167, 0.0001881>,
      <0.9999976, -0.0021766, 0.0001182>,
      <0.9999975, -0.0022142, 0.0001182>,
      <0.9999975, -0.0022142, 0.0001182>,
      <0.9999975, -0.0022199, 0.0001183>,
      <0.9999975, -0.0022199, 0.0001194>,
      <0.9999975, -0.0022199, 0.0001194>,
      <0.9999975, -0.0022199, 0.0001206>,
      <0.9999975, -0.0022187, 0.0002019>,
      <0.9999975, -0.0022199, 0.0001206>,
      <0.9999975, -0.0022199, 0.0001218>,
      <0.9999975, -0.0022199, 0.0001218>,
      <0.9999975, -0.0022199, 0.0001230>,
      <0.9999975, -0.0022193, 0.0002056>,
      <0.9999975, -0.0022193, 0.0002056>,
      <0.9999974, -0.0022182, 0.0004861>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <0.0000000, -0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, -1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.0000000, 0.0000000, 1.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, -0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <-0.9250317, 0.3798899, 0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, -0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.0027819, -0.9999961, 0.0000000>,
      <0.9999975, -0.0022290, -0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, -0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, -0.0000000>,
      <0.9999975, -0.0022290, -0.0000000>,
      <0.9999975, -0.0022290, -0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, -0.0000000>,
      <0.9999975, -0.0022290, -0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, -0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, -0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, -0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <0.9999975, -0.0022290, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, -0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0062049, -0.9999807, 0.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0000000, -0.0000000, -1.0000000>,
      <-0.0063006, -0.9999800, 0.0004861>,
      <-0.0063006, -0.9999800, 0.0004952>,
      <-0.0062966, -0.9999801, 0.0004952>,
      <-0.0062966, -0.9999801, 0.0004861>,
      <-0.0062966, -0.9999801, 0.0004770>,
      <-0.0063006, -0.9999800, 0.0004770>,
      <-0.0063006, -0.9999800, 0.0004770>,
      <-0.0063045, -0.9999800, 0.0004770>,
      <-0.0063045, -0.9999800, 0.0004861>,
      <-0.0063045, -0.9999800, 0.0004861>,
      <-0.0063045, -0.9999800, 0.0004952>,
      <-0.0063006, -0.9999800, 0.0005043>,
      <-0.0062966, -0.9999800, 0.0005043>,
      <-0.0063045, -0.9999800, 0.0004952>,
      <-0.0063045, -0.9999800, 0.0005043>,
      <-0.0063045, -0.9999800, 0.0005043>,
      <-0.0063045, -0.9999800, 0.0005135>,
      <-0.0063006, -0.9999800, 0.0005135>,
      <-0.0063006, -0.9999800, 0.0005135>,
      <-0.0062966, -0.9999800, 0.0005135>,
      <-0.0062927, -0.9999801, 0.0005043>,
      <-0.0062927, -0.9999801, 0.0004952>,
      <-0.0062966, -0.9999800, 0.0005135>,
      <-0.0062927, -0.9999801, 0.0005135>,
      <-0.0062927, -0.9999801, 0.0005135>,
      <-0.0062888, -0.9999801, 0.0005135>,
      <-0.0062888, -0.9999801, 0.0005043>,
      <-0.0062888, -0.9999801, 0.0005043>,
      <-0.0062888, -0.9999801, 0.0004952>,
      <-0.0062927, -0.9999801, 0.0004861>,
      <-0.0062888, -0.9999801, 0.0004952>,
      <-0.0062888, -0.9999801, 0.0004861>,
      <-0.0062888, -0.9999801, 0.0004861>,
      <-0.0062888, -0.9999801, 0.0004769>,
      <-0.0062927, -0.9999801, 0.0004769>,
      <-0.0062927, -0.9999801, 0.0004769>,
      <-0.0062966, -0.9999801, 0.0004770>,
      <0.0064733, 0.9882733, -0.1525584>,
      <0.0063926, 0.9882746, -0.1525533>,
      <0.0063898, 0.9878399, -0.1553432>,
      <0.0064705, 0.9878390, -0.1553457>,
      <0.0065510, 0.9878381, -0.1553481>,
      <0.0065538, 0.9882719, -0.1525636>,
      <0.0065538, 0.9882719, -0.1525636>,
      <0.0065567, 0.9886983, -0.1497754>,
      <0.0064761, 0.9887000, -0.1497676>,
      <0.0064761, 0.9887000, -0.1497676>,
      <0.0063954, 0.9887017, -0.1497597>,
      <0.0063117, 0.9882759, -0.1525481>,
      <0.0063089, 0.9878408, -0.1553408>,
      <0.0063954, 0.9887017, -0.1497597>,
      <0.0063145, 0.9887035, -0.1497518>,
      <0.0063145, 0.9887035, -0.1497518>,
      <0.0062334, 0.9887052, -0.1497438>,
      <0.0062307, 0.9882772, -0.1525429>,
      <0.0062307, 0.9882772, -0.1525429>,
      <0.0062280, 0.9878417, -0.1553384>,
      <0.0063061, 0.9873982, -0.1581298>,
      <0.0063869, 0.9873977, -0.1581295>,
      <0.0062280, 0.9878417, -0.1553384>,
      <0.0062252, 0.9873987, -0.1581301>,
      <0.0062252, 0.9873987, -0.1581301>,
      <0.0062223, 0.9869482, -0.1609180>,
      <0.0063032, 0.9869481, -0.1609150>,
      <0.0063032, 0.9869481, -0.1609150>,
      <0.0063840, 0.9869481, -0.1609119>,
      <0.0064676, 0.9873973, -0.1581292>,
      <0.0063840, 0.9869481, -0.1609119>,
      <0.0064646, 0.9869481, -0.1609089>,
      <0.0064646, 0.9869481, -0.1609089>,
      <0.0065451, 0.9869480, -0.1609059>,
      <0.0065480, 0.9873968, -0.1581289>,
      <0.0065480, 0.9873968, -0.1581289>,
      <0.0065510, 0.9878381, -0.1553481>,
      <-0.0066317, -0.9999780, 0.0000079>,
      <-0.0066317, -0.9999780, 0.0000080>,
      <-0.0066316, -0.9999780, 0.0000080>,
      <-0.0066316, -0.9999780, 0.0000079>,
      <-0.0066316, -0.9999780, 0.0000077>,
      <-0.0066317, -0.9999780, 0.0000077>,
      <-0.0066317, -0.9999780, 0.0000077>,
      <-0.0066318, -0.9999780, 0.0000077>,
      <-0.0066318, -0.9999780, 0.0000079>,
      <-0.0066318, -0.9999780, 0.0000079>,
      <-0.0066318, -0.9999780, 0.0000080>,
      <-0.0066317, -0.9999780, 0.0000082>,
      <-0.0066316, -0.9999780, 0.0000082>,
      <-0.0066318, -0.9999780, 0.0000080>,
      <-0.0066318, -0.9999780, 0.0000082>,
      <-0.0066318, -0.9999780, 0.0000082>,
      <-0.0066318, -0.9999780, 0.0000083>,
      <-0.0066317, -0.9999780, 0.0000083>,
      <-0.0066317, -0.9999780, 0.0000083>,
      <-0.0066316, -0.9999780, 0.0000083>,
      <-0.0066316, -0.9999780, 0.0000082>,
      <-0.0066316, -0.9999780, 0.0000080>,
      <-0.0066316, -0.9999780, 0.0000083>,
      <-0.0066316, -0.9999780, 0.0000083>,
      <-0.0066316, -0.9999780, 0.0000083>,
      <-0.0066315, -0.9999780, 0.0000083>,
      <-0.0066315, -0.9999780, 0.0000082>,
      <-0.0066315, -0.9999780, 0.0000082>,
      <-0.0066315, -0.9999780, 0.0000080>,
      <-0.0066316, -0.9999780, 0.0000079>,
      <-0.0066315, -0.9999780, 0.0000080>,
      <-0.0066315, -0.9999780, 0.0000079>,
      <-0.0066315, -0.9999780, 0.0000079>,
      <-0.0066315, -0.9999780, 0.0000077>,
      <-0.0066316, -0.9999780, 0.0000077>,
      <-0.0066316, -0.9999780, 0.0000077>,
      <-0.0066316, -0.9999780, 0.0000077>,
      <0.0066603, 0.9988463, -0.0475575>,
      <0.0066483, 0.9988464, -0.0475573>,
      <0.0066480, 0.9988038, -0.0484442>,
      <0.0066600, 0.9988037, -0.0484443>,
      <0.0066719, 0.9988036, -0.0484444>,
      <0.0066722, 0.9988462, -0.0475578>,
      <0.0066722, 0.9988462, -0.0475578>,
      <0.0066725, 0.9988880, -0.0466710>,
      <0.0066605, 0.9988881, -0.0466706>,
      <0.0066605, 0.9988881, -0.0466706>,
      <0.0066485, 0.9988882, -0.0466703>,
      <0.0066363, 0.9988465, -0.0475570>,
      <0.0066360, 0.9988039, -0.0484441>,
      <0.0066485, 0.9988882, -0.0466703>,
      <0.0066366, 0.9988883, -0.0466699>,
      <0.0066366, 0.9988883, -0.0466699>,
      <0.0066246, 0.9988884, -0.0466695>,
      <0.0066243, 0.9988466, -0.0475568>,
      <0.0066243, 0.9988466, -0.0475568>,
      <0.0066240, 0.9988039, -0.0484440>,
      <0.0066357, 0.9987604, -0.0493310>,
      <0.0066477, 0.9987604, -0.0493310>,
      <0.0066240, 0.9988039, -0.0484440>,
      <0.0066237, 0.9987605, -0.0493310>,
      <0.0066237, 0.9987605, -0.0493310>,
      <0.0066234, 0.9987163, -0.0502180>,
      <0.0066354, 0.9987162, -0.0502179>,
      <0.0066354, 0.9987162, -0.0502179>,
      <0.0066474, 0.9987162, -0.0502177>,
      <0.0066597, 0.9987603, -0.0493310>,
      <0.0066474, 0.9987162, -0.0502177>,
      <0.0066594, 0.9987161, -0.0502176>,
      <0.0066594, 0.9987161, -0.0502176>,
      <0.0066714, 0.9987160, -0.0502174>,
      <0.0066717, 0.9987602, -0.0493310>,
      <0.0066717, 0.9987602, -0.0493310>,
      <0.0066719, 0.9988036, -0.0484444>,
      <-0.0066774, -0.9999247, 0.0102930>,
      <-0.0067531, -0.9999258, 0.0101336>,
      <-0.0067294, -0.9999159, 0.0110851>,
      <-0.0067100, -0.9999169, 0.0110041>,
      <-0.0067040, -0.9999160, 0.0110930>,
      <-0.0066572, -0.9999163, 0.0110927>,
      <-0.0066572, -0.9999163, 0.0110927>,
      <-0.0064247, -0.9999557, 0.0068750>,
      <-0.0065552, -0.9999540, 0.0070067>,
      <-0.0067686, -0.9999516, 0.0071381>,
      <-0.0068263, -0.9999190, 0.0107402>,
      <-0.0067473, -0.9999117, 0.0114496>,
      <-0.0069872, -0.9999492, 0.0072689>,
      <-0.0071159, -0.9999473, 0.0073991>,
      <-0.0068397, -0.9999054, 0.0119373>,
      <-0.0068397, -0.9999054, 0.0119373>,
      <-0.0067510, -0.9999060, 0.0119375>,
      <-0.0067065, -0.9999095, 0.0116600>,
      <-0.0067044, -0.9999124, 0.0114140>,
      <-0.0067510, -0.9999060, 0.0119375>,
      <-0.0067071, -0.9999062, 0.0119376>,
      <-0.0067071, -0.9999062, 0.0119376>,
      <-0.0066793, -0.9999064, 0.0119377>,
      <-0.0066793, -0.9999089, 0.0117265>,
      <-0.0066793, -0.9999089, 0.0117265>,
      <-0.0066793, -0.9999114, 0.0115153>,
      <-0.0067021, -0.9999145, 0.0112321>,
      <-0.0066793, -0.9999114, 0.0115153>,
      <-0.0066794, -0.9999138, 0.0113041>,
      <-0.0066794, -0.9999138, 0.0113041>,
      <-0.0066794, -0.9999162, 0.0110929>,
      <-0.0067012, -0.9999160, 0.0110930>,
      <-0.0067012, -0.9999160, 0.0110930>,
      <-0.0067040, -0.9999160, 0.0110930>,
      <-0.0065239, -0.9999706, -0.0040230>,
      <-0.0066400, -0.9997863, -0.0195774>,
      <-0.0067629, -0.9998674, -0.0148119>,
      <-0.0067704, -0.9999768, -0.0007969>,
      <-0.0064247, -0.9999557, 0.0068750>,
      <-0.0057858, -0.9991940, -0.0397225>,
      <-0.0057858, -0.9991940, -0.0397225>,
      <-0.0065048, -0.9991888, -0.0397413>,
      <-0.0067307, -0.9994228, -0.0332992>,
      <-0.0067522, -0.9994899, -0.0312160>,
      <-0.0065048, -0.9991888, -0.0397413>,
      <-0.0067185, -0.9991872, -0.0397469>,
      <-0.0067185, -0.9991872, -0.0397469>,
      <-0.0067421, -0.9991870, -0.0397475>,
      <-0.0067419, -0.9991567, -0.0405026>,
      <-0.0067419, -0.9991567, -0.0405026>,
      <-0.0067417, -0.9991258, -0.0412576>,
      <-0.0067731, -0.9993776, -0.0346201>,
      <-0.0068878, -0.9997654, -0.0205378>,
      <-0.0067417, -0.9991258, -0.0412576>,
      <-0.0067415, -0.9990943, -0.0420125>,
      <-0.0067415, -0.9990943, -0.0420125>,
      <-0.0067413, -0.9990623, -0.0427673>,
      <-0.0067828, -0.9990621, -0.0427669>,
      <-0.0067828, -0.9990621, -0.0427669>,
      <-0.0070246, -0.9990605, -0.0427645>,
      <-0.0070238, -0.9999657, -0.0043839>,
      <-0.0070246, -0.9990605, -0.0427645>,
      <-0.0078017, -0.9990551, -0.0427566>,
      <-0.0078017, -0.9990551, -0.0427566>,
      <-0.0071159, -0.9999473, 0.0073991>
    }
    uv_vectors {
      1469,
      <0.3461295, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.2826137, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.2823938, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.2826137, 0.1538766>,
      <0.3461295, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.5000062, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.6538828, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.7173863, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.7176062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.6537273, 0.1538766>,
      <0.7173863, 0.1538766>,
      <0.6538828, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.5000062, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.3477037, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.3461295, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.7176062, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.3461295, 0.0000000>,
      <0.5000062, 0.0000000>,
      <0.6538828, 0.0000000>,
      <0.2823938, 0.0000000>,
      <0.3462850, 0.1538766>,
      <0.2826137, 0.1538766>,
      <0.3240764, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.6537273, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.5000062, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.2826137, 0.1538766>,
      <0.3462850, 0.1538766>,
      <0.3756038, 0.9329566>,
      <0.3240764, 0.9329566>,
      <0.7173863, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.3462850, 0.1538766>,
      <0.5000062, 0.1538766>,
      <0.5000059, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.5000062, 0.1538766>,
      <0.6537273, 0.1538766>,
      <0.6244079, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.6537273, 0.1538766>,
      <0.7173863, 0.1538766>,
      <0.6759253, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3240764, 0.9329566>,
      <0.3214772, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.6244079, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.3240764, 0.9329566>,
      <0.3756038, 0.9329566>,
      <0.3737658, 0.9324092>,
      <0.3214772, 0.9324092>,
      <0.6759253, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3214772, 0.9324092>,
      <0.3213383, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.3214772, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3736676, 0.9388315>,
      <0.3213383, 0.9388315>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3213383, 0.9388315>,
      <0.3176078, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.3213383, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3710297, 0.9395004>,
      <0.3176078, 0.9395004>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3176078, 0.9395004>,
      <0.3175836, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.3176078, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3710126, 0.9657316>,
      <0.3175836, 0.9657316>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3175836, 0.9657316>,
      <0.2922845, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.3175836, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3531234, 0.9671308>,
      <0.2922845, 0.9671308>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.2922845, 0.9671308>,
      <0.2910740, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.2922845, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3522674, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.2910740, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.2846200, 0.9883895>,
      <0.2846200, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.2846200, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3477037, 1.0000000>,
      <0.2846200, 1.0000000>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.4373453, 0.9326829>,
      <0.3756038, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.4378048, 0.9329566>,
      <0.5000059, 0.9326829>,
      <0.4368858, 0.9324092>,
      <0.3746848, 0.9326829>,
      <0.5626664, 0.9326829>,
      <0.5000059, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6262459, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5622069, 0.9329566>,
      <0.6253269, 0.9326829>,
      <0.5631259, 0.9324092>,
      <0.5000059, 0.9326829>,
      <0.6512759, 0.9326829>,
      <0.6244079, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6785245, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6501666, 0.9329566>,
      <0.6772249, 0.9326829>,
      <0.6523852, 0.9324092>,
      <0.6253269, 0.9326829>,
      <0.4368613, 0.9356203>,
      <0.3737658, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.4368858, 0.9324092>,
      <0.5000059, 0.9356203>,
      <0.4368368, 0.9388315>,
      <0.3737167, 0.9356203>,
      <0.5631505, 0.9356203>,
      <0.5000059, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6263441, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5631259, 0.9324092>,
      <0.6262950, 0.9356203>,
      <0.5631750, 0.9388315>,
      <0.5000059, 0.9356203>,
      <0.6524445, 0.9356203>,
      <0.6262459, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6786633, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6523852, 0.9324092>,
      <0.6785939, 0.9356203>,
      <0.6525037, 0.9388315>,
      <0.6262950, 0.9356203>,
      <0.4361773, 0.9391659>,
      <0.3736676, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.4368368, 0.9388315>,
      <0.5000059, 0.9391659>,
      <0.4355178, 0.9395004>,
      <0.3723487, 0.9391659>,
      <0.5638345, 0.9391659>,
      <0.5000059, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6289821, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5631750, 0.9388315>,
      <0.6276631, 0.9391659>,
      <0.5644940, 0.9395004>,
      <0.5000059, 0.9391659>,
      <0.6540958, 0.9391659>,
      <0.6263441, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6823937, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6525037, 0.9388315>,
      <0.6805285, 0.9391659>,
      <0.6556879, 0.9395004>,
      <0.6276631, 0.9391659>,
      <0.4355135, 0.9526160>,
      <0.3710297, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.4355178, 0.9395004>,
      <0.5000059, 0.9511689>,
      <0.4350534, 0.9657316>,
      <0.3710212, 0.9526160>,
      <0.5644983, 0.9526160>,
      <0.5000059, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289992, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5644940, 0.9395004>,
      <0.6289897, 0.9511210>,
      <0.5645025, 0.9657316>,
      <0.5000059, 0.9511689>,
      <0.6556982, 0.9526160>,
      <0.6289821, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824179, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6556879, 0.9395004>,
      <0.6824058, 0.9526160>,
      <0.6559367, 0.9657316>,
      <0.6289897, 0.9511210>,
      <0.4310370, 0.9664312>,
      <0.3710126, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000061, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.4350534, 0.9657316>,
      <0.5000060, 0.9664288>,
      <0.4263703, 0.9671308>,
      <0.3620680, 0.9664312>,
      <0.5689750, 0.9664312>,
      <0.5000059, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6468888, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5645025, 0.9657316>,
      <0.6378965, 0.9664275>,
      <0.5734474, 0.9671308>,
      <0.5000060, 0.9664288>,
      <0.6665054, 0.9664312>,
      <0.6289992, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.7077159, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6559367, 0.9657316>,
      <0.6950669, 0.9664312>,
      <0.6773948, 0.9671308>,
      <0.6378965, 0.9664275>,
      <0.4263507, 0.9777601>,
      <0.3531234, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.4263703, 0.9671308>,
      <0.5000061, 0.9786956>,
      <0.4261367, 0.9883895>,
      <0.3526954, 0.9777601>,
      <0.5736614, 0.9777601>,
      <0.5000061, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6477448, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5734474, 0.9671308>,
      <0.6473573, 0.9787650>,
      <0.5738754, 0.9883895>,
      <0.5000061, 0.9786956>,
      <0.6778190, 0.9777601>,
      <0.6468888, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7089263, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6773948, 0.9671308>,
      <0.7083211, 0.9777601>,
      <0.6783356, 0.9883895>,
      <0.6473573, 0.9787650>,
      <0.4249958, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.4238549, 0.9941947>,
      <0.3477037, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.4238549, 0.9883895>,
      <0.5000061, 0.9941947>,
      <0.4238549, 1.0000000>,
      <0.3477037, 0.9941947>,
      <0.5761574, 0.9941947>,
      <0.5000061, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5761574, 0.9883895>,
      <0.6523086, 0.9941947>,
      <0.5761574, 1.0000000>,
      <0.5000061, 0.9941947>,
      <0.6838443, 0.9941947>,
      <0.6523086, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6838443, 0.9883895>,
      <0.7153801, 0.9941947>,
      <0.6838443, 1.0000000>,
      <0.6523086, 0.9941947>,
      <0.4642375, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5426958, 1.0000000>,
      <0.4396228, 1.0000000>,
      <0.3857793, 1.0000000>,
      <0.4888523, 1.0000000>,
      <0.5134670, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.4888523, 1.0000000>,
      <0.4619305, 1.0000000>,
      <0.5380817, 1.0000000>,
      <0.5650035, 1.0000000>,
      <0.6165400, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.5650035, 1.0000000>,
      <0.6142330, 1.0000000>,
      <0.6680764, 1.0000000>,
      <0.6188470, 1.0000000>,
      <0.6211540, 1.0000000>,
      <0.5538496, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.7153801, 1.0000000>,
      <0.5315419, 1.0000000>,
      <0.6188470, 1.0000000>,
      <0.6996122, 1.0000000>,
      <0.6234610, 1.0000000>,
      <0.5426958, 1.0000000>,
      <0.4063597, 0.9328198>,
      <0.4373453, 0.9326829>,
      <0.3746848, 0.9326829>,
      <0.3756038, 0.9329566>,
      <0.4378048, 0.9329566>,
      <0.4060151, 0.9326829>,
      <0.3751443, 0.9328198>,
      <0.4067043, 0.9329566>,
      <0.4375751, 0.9328198>,
      <0.4687905, 0.9328198>,
      <0.4373453, 0.9326829>,
      <0.4378048, 0.9329566>,
      <0.5000059, 0.9329566>,
      <0.5000059, 0.9326829>,
      <0.4375751, 0.9328198>,
      <0.4689053, 0.9329566>,
      <0.5000059, 0.9328198>,
      <0.4686756, 0.9326829>,
      <0.4685607, 0.9325460>,
      <0.4373453, 0.9326829>,
      <0.5000059, 0.9326829>,
      <0.5000059, 0.9324092>,
      <0.4368858, 0.9324092>,
      <0.4686756, 0.9326829>,
      <0.5000059, 0.9325460>,
      <0.4684459, 0.9324092>,
      <0.4371156, 0.9325460>,
      <0.4056704, 0.9325460>,
      <0.4373453, 0.9326829>,
      <0.4368858, 0.9324092>,
      <0.3737658, 0.9324092>,
      <0.3746848, 0.9326829>,
      <0.4371156, 0.9325460>,
      <0.4053258, 0.9324092>,
      <0.3742253, 0.9325460>,
      <0.4060151, 0.9326829>,
      <0.5312213, 0.9328198>,
      <0.5626664, 0.9326829>,
      <0.5000059, 0.9326829>,
      <0.5000059, 0.9329566>,
      <0.5622069, 0.9329566>,
      <0.5313361, 0.9326829>,
      <0.5000059, 0.9328198>,
      <0.5311064, 0.9329566>,
      <0.5624367, 0.9328198>,
      <0.5936520, 0.9328198>,
      <0.5626664, 0.9326829>,
      <0.5622069, 0.9329566>,
      <0.6244079, 0.9329566>,
      <0.6253269, 0.9326829>,
      <0.5624367, 0.9328198>,
      <0.5933074, 0.9329566>,
      <0.6248674, 0.9328198>,
      <0.5939967, 0.9326829>,
      <0.5943413, 0.9325460>,
      <0.5626664, 0.9326829>,
      <0.6253269, 0.9326829>,
      <0.6262459, 0.9324092>,
      <0.5631259, 0.9324092>,
      <0.5939967, 0.9326829>,
      <0.6257864, 0.9325460>,
      <0.5946859, 0.9324092>,
      <0.5628962, 0.9325460>,
      <0.5314510, 0.9325460>,
      <0.5626664, 0.9326829>,
      <0.5631259, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9326829>,
      <0.5628962, 0.9325460>,
      <0.5315659, 0.9324092>,
      <0.5000059, 0.9325460>,
      <0.5313361, 0.9326829>,
      <0.6377944, 0.9328198>,
      <0.6512759, 0.9326829>,
      <0.6253269, 0.9326829>,
      <0.6244079, 0.9329566>,
      <0.6501666, 0.9329566>,
      <0.6383014, 0.9326829>,
      <0.6248674, 0.9328198>,
      <0.6372873, 0.9329566>,
      <0.6507213, 0.9328198>,
      <0.6636482, 0.9328198>,
      <0.6512759, 0.9326829>,
      <0.6501666, 0.9329566>,
      <0.6759253, 0.9329566>,
      <0.6772249, 0.9326829>,
      <0.6507213, 0.9328198>,
      <0.6630460, 0.9329566>,
      <0.6765751, 0.9328198>,
      <0.6642504, 0.9326829>,
      <0.6648526, 0.9325460>,
      <0.6512759, 0.9326829>,
      <0.6772249, 0.9326829>,
      <0.6785245, 0.9324092>,
      <0.6523852, 0.9324092>,
      <0.6642504, 0.9326829>,
      <0.6778747, 0.9325460>,
      <0.6654549, 0.9324092>,
      <0.6518306, 0.9325460>,
      <0.6388085, 0.9325460>,
      <0.6512759, 0.9326829>,
      <0.6523852, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6253269, 0.9326829>,
      <0.6518306, 0.9325460>,
      <0.6393156, 0.9324092>,
      <0.6257864, 0.9325460>,
      <0.6383014, 0.9326829>,
      <0.4053074, 0.9340147>,
      <0.4368613, 0.9356203>,
      <0.3737167, 0.9356203>,
      <0.3737658, 0.9324092>,
      <0.4368858, 0.9324092>,
      <0.4052890, 0.9356203>,
      <0.3737413, 0.9340147>,
      <0.4053258, 0.9324092>,
      <0.4368736, 0.9340147>,
      <0.4684397, 0.9340147>,
      <0.4368613, 0.9356203>,
      <0.4368858, 0.9324092>,
      <0.5000059, 0.9324092>,
      <0.5000059, 0.9356203>,
      <0.4368736, 0.9340147>,
      <0.4684459, 0.9324092>,
      <0.5000059, 0.9340147>,
      <0.4684336, 0.9356203>,
      <0.4684275, 0.9372259>,
      <0.4368613, 0.9356203>,
      <0.5000059, 0.9356203>,
      <0.5000059, 0.9388315>,
      <0.4368368, 0.9388315>,
      <0.4684336, 0.9356203>,
      <0.5000059, 0.9372259>,
      <0.4684213, 0.9388315>,
      <0.4368490, 0.9372259>,
      <0.4052706, 0.9372259>,
      <0.4368613, 0.9356203>,
      <0.4368368, 0.9388315>,
      <0.3736676, 0.9388315>,
      <0.3737167, 0.9356203>,
      <0.4368490, 0.9372259>,
      <0.4052522, 0.9388315>,
      <0.3736922, 0.9372259>,
      <0.4052890, 0.9356203>,
      <0.5315720, 0.9340147>,
      <0.5631505, 0.9356203>,
      <0.5000059, 0.9356203>,
      <0.5000059, 0.9324092>,
      <0.5631259, 0.9324092>,
      <0.5315782, 0.9356203>,
      <0.5000059, 0.9340147>,
      <0.5315659, 0.9324092>,
      <0.5631382, 0.9340147>,
      <0.5947043, 0.9340147>,
      <0.5631505, 0.9356203>,
      <0.5631259, 0.9324092>,
      <0.6262459, 0.9324092>,
      <0.6262950, 0.9356203>,
      <0.5631382, 0.9340147>,
      <0.5946859, 0.9324092>,
      <0.6262705, 0.9340147>,
      <0.5947227, 0.9356203>,
      <0.5947412, 0.9372259>,
      <0.5631505, 0.9356203>,
      <0.6262950, 0.9356203>,
      <0.6263441, 0.9388315>,
      <0.5631750, 0.9388315>,
      <0.5947227, 0.9356203>,
      <0.6263196, 0.9372259>,
      <0.5947596, 0.9388315>,
      <0.5631627, 0.9372259>,
      <0.5315843, 0.9372259>,
      <0.5631505, 0.9356203>,
      <0.5631750, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9356203>,
      <0.5631627, 0.9372259>,
      <0.5315904, 0.9388315>,
      <0.5000059, 0.9372259>,
      <0.5315782, 0.9356203>,
      <0.6393427, 0.9340147>,
      <0.6524445, 0.9356203>,
      <0.6262950, 0.9356203>,
      <0.6262459, 0.9324092>,
      <0.6523852, 0.9324092>,
      <0.6393698, 0.9356203>,
      <0.6262705, 0.9340147>,
      <0.6393156, 0.9324092>,
      <0.6524148, 0.9340147>,
      <0.6654870, 0.9340147>,
      <0.6524445, 0.9356203>,
      <0.6523852, 0.9324092>,
      <0.6785245, 0.9324092>,
      <0.6785939, 0.9356203>,
      <0.6524148, 0.9340147>,
      <0.6654549, 0.9324092>,
      <0.6785592, 0.9340147>,
      <0.6655192, 0.9356203>,
      <0.6655513, 0.9372259>,
      <0.6524445, 0.9356203>,
      <0.6785939, 0.9356203>,
      <0.6786633, 0.9388315>,
      <0.6525037, 0.9388315>,
      <0.6655192, 0.9356203>,
      <0.6786286, 0.9372259>,
      <0.6655835, 0.9388315>,
      <0.6524741, 0.9372259>,
      <0.6393968, 0.9372259>,
      <0.6524445, 0.9356203>,
      <0.6525037, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6262950, 0.9356203>,
      <0.6524741, 0.9372259>,
      <0.6394239, 0.9388315>,
      <0.6263196, 0.9372259>,
      <0.6393698, 0.9356203>,
      <0.4047576, 0.9389987>,
      <0.4361773, 0.9391659>,
      <0.3723487, 0.9391659>,
      <0.3736676, 0.9388315>,
      <0.4368368, 0.9388315>,
      <0.4042630, 0.9391659>,
      <0.3730082, 0.9389987>,
      <0.4052522, 0.9388315>,
      <0.4365070, 0.9389987>,
      <0.4682565, 0.9389987>,
      <0.4361773, 0.9391659>,
      <0.4368368, 0.9388315>,
      <0.5000059, 0.9388315>,
      <0.5000059, 0.9391659>,
      <0.4365070, 0.9389987>,
      <0.4684213, 0.9388315>,
      <0.5000059, 0.9389987>,
      <0.4680916, 0.9391659>,
      <0.4679267, 0.9393332>,
      <0.4361773, 0.9391659>,
      <0.5000059, 0.9391659>,
      <0.5000059, 0.9395004>,
      <0.4355178, 0.9395004>,
      <0.4680916, 0.9391659>,
      <0.5000059, 0.9393332>,
      <0.4677619, 0.9395004>,
      <0.4358475, 0.9393332>,
      <0.4037684, 0.9393332>,
      <0.4361773, 0.9391659>,
      <0.4355178, 0.9395004>,
      <0.3710297, 0.9395004>,
      <0.3723487, 0.9391659>,
      <0.4358475, 0.9393332>,
      <0.4032738, 0.9395004>,
      <0.3716892, 0.9393332>,
      <0.4042630, 0.9391659>,
      <0.5317553, 0.9389987>,
      <0.5638345, 0.9391659>,
      <0.5000059, 0.9391659>,
      <0.5000059, 0.9388315>,
      <0.5631750, 0.9388315>,
      <0.5319202, 0.9391659>,
      <0.5000059, 0.9389987>,
      <0.5315904, 0.9388315>,
      <0.5635047, 0.9389987>,
      <0.5952542, 0.9389987>,
      <0.5638345, 0.9391659>,
      <0.5631750, 0.9388315>,
      <0.6263441, 0.9388315>,
      <0.6276631, 0.9391659>,
      <0.5635047, 0.9389987>,
      <0.5947596, 0.9388315>,
      <0.6270036, 0.9389987>,
      <0.5957488, 0.9391659>,
      <0.5962434, 0.9393332>,
      <0.5638345, 0.9391659>,
      <0.6276631, 0.9391659>,
      <0.6289821, 0.9395004>,
      <0.5644940, 0.9395004>,
      <0.5957488, 0.9391659>,
      <0.6283226, 0.9393332>,
      <0.5967380, 0.9395004>,
      <0.5641643, 0.9393332>,
      <0.5320851, 0.9393332>,
      <0.5638345, 0.9391659>,
      <0.5644940, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9391659>,
      <0.5641643, 0.9393332>,
      <0.5322500, 0.9395004>,
      <0.5000059, 0.9393332>,
      <0.5319202, 0.9391659>,
      <0.6401517, 0.9389987>,
      <0.6540958, 0.9391659>,
      <0.6276631, 0.9391659>,
      <0.6263441, 0.9388315>,
      <0.6525037, 0.9388315>,
      <0.6408795, 0.9391659>,
      <0.6270036, 0.9389987>,
      <0.6394239, 0.9388315>,
      <0.6532998, 0.9389987>,
      <0.6664478, 0.9389987>,
      <0.6540958, 0.9391659>,
      <0.6525037, 0.9388315>,
      <0.6786633, 0.9388315>,
      <0.6805285, 0.9391659>,
      <0.6532998, 0.9389987>,
      <0.6655835, 0.9388315>,
      <0.6795959, 0.9389987>,
      <0.6673122, 0.9391659>,
      <0.6681765, 0.9393332>,
      <0.6540958, 0.9391659>,
      <0.6805285, 0.9391659>,
      <0.6823937, 0.9395004>,
      <0.6556879, 0.9395004>,
      <0.6673122, 0.9391659>,
      <0.6814611, 0.9393332>,
      <0.6690408, 0.9395004>,
      <0.6548919, 0.9393332>,
      <0.6416072, 0.9393332>,
      <0.6540958, 0.9391659>,
      <0.6556879, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6276631, 0.9391659>,
      <0.6548919, 0.9393332>,
      <0.6423350, 0.9395004>,
      <0.6283226, 0.9393332>,
      <0.6408795, 0.9391659>,
      <0.4032706, 0.9460582>,
      <0.4355135, 0.9526160>,
      <0.3710212, 0.9526160>,
      <0.3710297, 0.9395004>,
      <0.4355178, 0.9395004>,
      <0.4032662, 0.9526160>,
      <0.3710254, 0.9460582>,
      <0.4032738, 0.9395004>,
      <0.4355157, 0.9458857>,
      <0.4677608, 0.9456965>,
      <0.4355135, 0.9526160>,
      <0.4355178, 0.9395004>,
      <0.5000059, 0.9395004>,
      <0.5000059, 0.9511689>,
      <0.4355157, 0.9458857>,
      <0.4677619, 0.9395004>,
      <0.5000059, 0.9451631>,
      <0.4677604, 0.9518925>,
      <0.4676447, 0.9588120>,
      <0.4355135, 0.9526160>,
      <0.5000059, 0.9511689>,
      <0.5000059, 0.9657316>,
      <0.4350534, 0.9657316>,
      <0.4677604, 0.9518925>,
      <0.5000059, 0.9579835>,
      <0.4675262, 0.9657316>,
      <0.4353083, 0.9584665>,
      <0.4031502, 0.9591738>,
      <0.4355135, 0.9526160>,
      <0.4350534, 0.9657316>,
      <0.3710126, 0.9657316>,
      <0.3710212, 0.9526160>,
      <0.4353083, 0.9584665>,
      <0.4024181, 0.9657316>,
      <0.3710169, 0.9591738>,
      <0.4032662, 0.9526160>,
      <0.5322510, 0.9456965>,
      <0.5644983, 0.9526160>,
      <0.5000059, 0.9511689>,
      <0.5000059, 0.9395004>,
      <0.5644940, 0.9395004>,
      <0.5322521, 0.9518925>,
      <0.5000059, 0.9451631>,
      <0.5322500, 0.9395004>,
      <0.5644961, 0.9458645>,
      <0.5967410, 0.9456845>,
      <0.5644983, 0.9526160>,
      <0.5644940, 0.9395004>,
      <0.6289821, 0.9395004>,
      <0.6289897, 0.9511210>,
      <0.5644961, 0.9458645>,
      <0.5967380, 0.9395004>,
      <0.6289858, 0.9451388>,
      <0.5967440, 0.9518685>,
      <0.5967474, 0.9588001>,
      <0.5644983, 0.9526160>,
      <0.6289897, 0.9511210>,
      <0.6289992, 0.9657316>,
      <0.5645025, 0.9657316>,
      <0.5967440, 0.9518685>,
      <0.6289941, 0.9579003>,
      <0.5967509, 0.9657316>,
      <0.5645003, 0.9587163>,
      <0.5322532, 0.9588120>,
      <0.5644983, 0.9526160>,
      <0.5645025, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000059, 0.9511689>,
      <0.5645003, 0.9587163>,
      <0.5322542, 0.9657316>,
      <0.5000059, 0.9579835>,
      <0.5322521, 0.9518925>,
      <0.6423395, 0.9456845>,
      <0.6556982, 0.9526160>,
      <0.6289897, 0.9511210>,
      <0.6289821, 0.9395004>,
      <0.6556879, 0.9395004>,
      <0.6423437, 0.9518685>,
      <0.6289858, 0.9451388>,
      <0.6423350, 0.9395004>,
      <0.6556929, 0.9458854>,
      <0.6690464, 0.9460582>,
      <0.6556982, 0.9526160>,
      <0.6556879, 0.9395004>,
      <0.6823937, 0.9395004>,
      <0.6824058, 0.9526160>,
      <0.6556929, 0.9458854>,
      <0.6690408, 0.9395004>,
      <0.6823998, 0.9460582>,
      <0.6690526, 0.9526160>,
      <0.6691147, 0.9591738>,
      <0.6556982, 0.9526160>,
      <0.6824058, 0.9526160>,
      <0.6824179, 0.9657316>,
      <0.6559367, 0.9657316>,
      <0.6690526, 0.9526160>,
      <0.6824118, 0.9591738>,
      <0.6694793, 0.9657316>,
      <0.6558043, 0.9584513>,
      <0.6424060, 0.9588001>,
      <0.6556982, 0.9526160>,
      <0.6559367, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6289897, 0.9511210>,
      <0.6558043, 0.9584513>,
      <0.6424701, 0.9657316>,
      <0.6289941, 0.9579003>,
      <0.6423437, 0.9518685>,
      <0.3997928, 0.9660814>,
      <0.4310370, 0.9664312>,
      <0.3620680, 0.9664312>,
      <0.3710126, 0.9657316>,
      <0.4350534, 0.9657316>,
      <0.3965525, 0.9664312>,
      <0.3665403, 0.9660814>,
      <0.4024181, 0.9657316>,
      <0.4331639, 0.9660607>,
      <0.4665256, 0.9660808>,
      <0.4310370, 0.9664312>,
      <0.4350534, 0.9657316>,
      <0.5000059, 0.9657316>,
      <0.5000060, 0.9664288>,
      <0.4331639, 0.9660607>,
      <0.4675262, 0.9657316>,
      <0.5000060, 0.9660919>,
      <0.4655215, 0.9664300>,
      <0.4643549, 0.9667804>,
      <0.4310370, 0.9664312>,
      <0.5000060, 0.9664288>,
      <0.5000061, 0.9671308>,
      <0.4263703, 0.9671308>,
      <0.4655215, 0.9664300>,
      <0.5000060, 0.9667632>,
      <0.4631816, 0.9671308>,
      <0.4286561, 0.9667881>,
      <0.3931497, 0.9667810>,
      <0.4310370, 0.9664312>,
      <0.4263703, 0.9671308>,
      <0.3531234, 0.9671308>,
      <0.3620680, 0.9664312>,
      <0.4286561, 0.9667881>,
      <0.3895082, 0.9671308>,
      <0.3575957, 0.9667810>,
      <0.3965525, 0.9664312>,
      <0.5333724, 0.9660808>,
      <0.5689750, 0.9664312>,
      <0.5000060, 0.9664288>,
      <0.5000059, 0.9657316>,
      <0.5645025, 0.9657316>,
      <0.5344905, 0.9664300>,
      <0.5000060, 0.9660919>,
      <0.5322542, 0.9657316>,
      <0.5668008, 0.9660911>,
      <0.6000933, 0.9660805>,
      <0.5689750, 0.9664312>,
      <0.5645025, 0.9657316>,
      <0.6289992, 0.9657316>,
      <0.6378965, 0.9664275>,
      <0.5668008, 0.9660911>,
      <0.5967509, 0.9657316>,
      <0.6335597, 0.9660883>,
      <0.6034357, 0.9664293>,
      <0.6068019, 0.9667801>,
      <0.5689750, 0.9664312>,
      <0.6378965, 0.9664275>,
      <0.6468888, 0.9671308>,
      <0.5734474, 0.9671308>,
      <0.6034357, 0.9664293>,
      <0.6422052, 0.9667645>,
      <0.6101681, 0.9671308>,
      <0.5711142, 0.9667658>,
      <0.5356086, 0.9667804>,
      <0.5689750, 0.9664312>,
      <0.5734474, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000060, 0.9664288>,
      <0.5711142, 0.9667658>,
      <0.5367268, 0.9671308>,
      <0.5000060, 0.9667632>,
      <0.5344905, 0.9664300>,
      <0.6473345, 0.9660805>,
      <0.6665054, 0.9664312>,
      <0.6378965, 0.9664275>,
      <0.6289992, 0.9657316>,
      <0.6559367, 0.9657316>,
      <0.6522009, 0.9664293>,
      <0.6335597, 0.9660883>,
      <0.6424701, 0.9657316>,
      <0.6608384, 0.9660561>,
      <0.6749817, 0.9660814>,
      <0.6665054, 0.9664312>,
      <0.6559367, 0.9657316>,
      <0.6824179, 0.9657316>,
      <0.6950669, 0.9664312>,
      <0.6608384, 0.9660561>,
      <0.6694793, 0.9657316>,
      <0.6887424, 0.9660814>,
      <0.6807862, 0.9664312>,
      <0.6866708, 0.9667810>,
      <0.6665054, 0.9664312>,
      <0.6950669, 0.9664312>,
      <0.7077159, 0.9671308>,
      <0.6773948, 0.9671308>,
      <0.6807862, 0.9664312>,
      <0.7013914, 0.9667810>,
      <0.6926707, 0.9671308>,
      <0.6721189, 0.9667919>,
      <0.6571714, 0.9667801>,
      <0.6665054, 0.9664312>,
      <0.6773948, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6378965, 0.9664275>,
      <0.6721189, 0.9667919>,
      <0.6621448, 0.9671308>,
      <0.6422052, 0.9667645>,
      <0.6522009, 0.9664293>,
      <0.3896350, 0.9724455>,
      <0.4263507, 0.9777601>,
      <0.3526954, 0.9777601>,
      <0.3531234, 0.9671308>,
      <0.4263703, 0.9671308>,
      <0.3895220, 0.9777601>,
      <0.3529094, 0.9724455>,
      <0.3895082, 0.9671308>,
      <0.4263596, 0.9729583>,
      <0.4631833, 0.9726793>,
      <0.4263507, 0.9777601>,
      <0.4263703, 0.9671308>,
      <0.5000061, 0.9671308>,
      <0.5000061, 0.9786956>,
      <0.4263596, 0.9729583>,
      <0.4631816, 0.9671308>,
      <0.5000061, 0.9731107>,
      <0.4631777, 0.9782279>,
      <0.4631249, 0.9833087>,
      <0.4263507, 0.9777601>,
      <0.5000061, 0.9786956>,
      <0.5000061, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.4631777, 0.9782279>,
      <0.5000061, 0.9836699>,
      <0.4630714, 0.9883895>,
      <0.4262410, 0.9832092>,
      <0.3893626, 0.9830748>,
      <0.4263507, 0.9777601>,
      <0.4261367, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.3526954, 0.9777601>,
      <0.4262410, 0.9832092>,
      <0.3892021, 0.9883895>,
      <0.3524814, 0.9830748>,
      <0.3895220, 0.9777601>,
      <0.5367803, 0.9726793>,
      <0.5736614, 0.9777601>,
      <0.5000061, 0.9786956>,
      <0.5000061, 0.9671308>,
      <0.5734474, 0.9671308>,
      <0.5368338, 0.9782279>,
      <0.5000061, 0.9731107>,
      <0.5367268, 0.9671308>,
      <0.5735589, 0.9726676>,
      <0.6103387, 0.9726967>,
      <0.5736614, 0.9777601>,
      <0.5734474, 0.9671308>,
      <0.6468888, 0.9671308>,
      <0.6473573, 0.9787650>,
      <0.5735589, 0.9726676>,
      <0.6101681, 0.9671308>,
      <0.6471335, 0.9732089>,
      <0.6105094, 0.9782626>,
      <0.6106597, 0.9833260>,
      <0.5736614, 0.9777601>,
      <0.6473573, 0.9787650>,
      <0.6477448, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6105094, 0.9782626>,
      <0.6475562, 0.9837065>,
      <0.6108101, 0.9883895>,
      <0.5737713, 0.9832167>,
      <0.5368873, 0.9833087>,
      <0.5736614, 0.9777601>,
      <0.5738754, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9786956>,
      <0.5737713, 0.9832167>,
      <0.5369408, 0.9883895>,
      <0.5000061, 0.9836699>,
      <0.5368338, 0.9782279>,
      <0.6623650, 0.9726967>,
      <0.6778190, 0.9777601>,
      <0.6473573, 0.9787650>,
      <0.6468888, 0.9671308>,
      <0.6773948, 0.9671308>,
      <0.6625884, 0.9782625>,
      <0.6471335, 0.9732089>,
      <0.6621448, 0.9671308>,
      <0.6776281, 0.9729776>,
      <0.6928127, 0.9724455>,
      <0.6778190, 0.9777601>,
      <0.6773948, 0.9671308>,
      <0.7077159, 0.9671308>,
      <0.7083211, 0.9777601>,
      <0.6776281, 0.9729776>,
      <0.6926707, 0.9671308>,
      <0.7080185, 0.9724455>,
      <0.6930705, 0.9777601>,
      <0.6933505, 0.9830748>,
      <0.6778190, 0.9777601>,
      <0.7083211, 0.9777601>,
      <0.7089263, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.6930705, 0.9777601>,
      <0.7086237, 0.9830748>,
      <0.6936309, 0.9883895>,
      <0.6780838, 0.9832100>,
      <0.6628141, 0.9833260>,
      <0.6778190, 0.9777601>,
      <0.6783356, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6473573, 0.9787650>,
      <0.6780838, 0.9832100>,
      <0.6630402, 0.9883895>,
      <0.6475562, 0.9837065>,
      <0.6625884, 0.9782625>,
      <0.3883464, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.3522674, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.3874907, 0.9883895>,
      <0.3511265, 0.9883895>,
      <0.3892021, 0.9883895>,
      <0.4255663, 0.9883895>,
      <0.4627862, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.4261367, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4255663, 0.9883895>,
      <0.4630714, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4625010, 0.9883895>,
      <0.4622158, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.4625010, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.4619305, 0.9883895>,
      <0.4244254, 0.9883895>,
      <0.3866350, 0.9883895>,
      <0.4249958, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3477037, 0.9883895>,
      <0.3499856, 0.9883895>,
      <0.4244254, 0.9883895>,
      <0.3857793, 0.9883895>,
      <0.3488446, 0.9883895>,
      <0.3874907, 0.9883895>,
      <0.5372260, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.5375113, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5369408, 0.9883895>,
      <0.5744459, 0.9883895>,
      <0.6116658, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5738754, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.5744459, 0.9883895>,
      <0.6108101, 0.9883895>,
      <0.6488857, 0.9883895>,
      <0.6125215, 0.9883895>,
      <0.6133773, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.6125215, 0.9883895>,
      <0.6511676, 0.9883895>,
      <0.6142330, 0.9883895>,
      <0.5755869, 0.9883895>,
      <0.5377965, 0.9883895>,
      <0.5750164, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5755869, 0.9883895>,
      <0.5380817, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5375113, 0.9883895>,
      <0.6642992, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6477448, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.6655583, 0.9883895>,
      <0.6488857, 0.9883895>,
      <0.6630402, 0.9883895>,
      <0.6797127, 0.9883895>,
      <0.6951263, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6783356, 0.9883895>,
      <0.7089263, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.6797127, 0.9883895>,
      <0.6936309, 0.9883895>,
      <0.7105398, 0.9883895>,
      <0.6966216, 0.9883895>,
      <0.6981169, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.7121532, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6966216, 0.9883895>,
      <0.7137666, 0.9883895>,
      <0.6996122, 0.9883895>,
      <0.6824671, 0.9883895>,
      <0.6668174, 0.9883895>,
      <0.6810899, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6500267, 0.9883895>,
      <0.6824671, 0.9883895>,
      <0.6680764, 0.9883895>,
      <0.6511676, 0.9883895>,
      <0.6655583, 0.9883895>,
      <0.3857793, 0.9912921>,
      <0.4238549, 0.9941947>,
      <0.3477037, 0.9941947>,
      <0.3477037, 0.9883895>,
      <0.4238549, 0.9883895>,
      <0.3857793, 0.9941947>,
      <0.3477037, 0.9912921>,
      <0.3857793, 0.9883895>,
      <0.4238549, 0.9912921>,
      <0.4619305, 0.9912921>,
      <0.4238549, 0.9941947>,
      <0.4238549, 0.9883895>,
      <0.5000061, 0.9883895>,
      <0.5000061, 0.9941947>,
      <0.4238549, 0.9912921>,
      <0.4619305, 0.9883895>,
      <0.5000061, 0.9912921>,
      <0.4619305, 0.9941947>,
      <0.4619305, 0.9970974>,
      <0.4238549, 0.9941947>,
      <0.5000061, 0.9941947>,
      <0.5000061, 1.0000000>,
      <0.4238549, 1.0000000>,
      <0.4619305, 0.9941947>,
      <0.5000061, 0.9970974>,
      <0.4619305, 1.0000000>,
      <0.4238549, 0.9970974>,
      <0.3857793, 0.9970974>,
      <0.4238549, 0.9941947>,
      <0.4238549, 1.0000000>,
      <0.3477037, 1.0000000>,
      <0.3477037, 0.9941947>,
      <0.4238549, 0.9970974>,
      <0.3857793, 1.0000000>,
      <0.3477037, 0.9970974>,
      <0.3857793, 0.9941947>,
      <0.5380817, 0.9912921>,
      <0.5761574, 0.9941947>,
      <0.5000061, 0.9941947>,
      <0.5000061, 0.9883895>,
      <0.5761574, 0.9883895>,
      <0.5380817, 0.9941947>,
      <0.5000061, 0.9912921>,
      <0.5380817, 0.9883895>,
      <0.5761574, 0.9912921>,
      <0.6142330, 0.9912921>,
      <0.5761574, 0.9941947>,
      <0.5761574, 0.9883895>,
      <0.6523086, 0.9883895>,
      <0.6523086, 0.9941947>,
      <0.5761574, 0.9912921>,
      <0.6142330, 0.9883895>,
      <0.6523086, 0.9912921>,
      <0.6142330, 0.9941947>,
      <0.6142330, 0.9970974>,
      <0.5761574, 0.9941947>,
      <0.6523086, 0.9941947>,
      <0.6523086, 1.0000000>,
      <0.5761574, 1.0000000>,
      <0.6142330, 0.9941947>,
      <0.6523086, 0.9970974>,
      <0.6142330, 1.0000000>,
      <0.5761574, 0.9970974>,
      <0.5380817, 0.9970974>,
      <0.5761574, 0.9941947>,
      <0.5761574, 1.0000000>,
      <0.5000061, 1.0000000>,
      <0.5000061, 0.9941947>,
      <0.5761574, 0.9970974>,
      <0.5380817, 1.0000000>,
      <0.5000061, 0.9970974>,
      <0.5380817, 0.9941947>,
      <0.6680764, 0.9912921>,
      <0.6838443, 0.9941947>,
      <0.6523086, 0.9941947>,
      <0.6523086, 0.9883895>,
      <0.6838443, 0.9883895>,
      <0.6680765, 0.9941947>,
      <0.6523086, 0.9912921>,
      <0.6680764, 0.9883895>,
      <0.6838443, 0.9912921>,
      <0.6996122, 0.9912921>,
      <0.6838443, 0.9941947>,
      <0.6838443, 0.9883895>,
      <0.7153801, 0.9883895>,
      <0.7153801, 0.9941947>,
      <0.6838443, 0.9912921>,
      <0.6996122, 0.9883895>,
      <0.7153801, 0.9912921>,
      <0.6996122, 0.9941947>,
      <0.6996122, 0.9970974>,
      <0.6838443, 0.9941947>,
      <0.7153801, 0.9941947>,
      <0.7153801, 1.0000000>,
      <0.6838443, 1.0000000>,
      <0.6996122, 0.9941947>,
      <0.7153801, 0.9970974>,
      <0.6996122, 1.0000000>,
      <0.6838443, 0.9970974>,
      <0.6680764, 0.9970974>,
      <0.6838443, 0.9941947>,
      <0.6838443, 1.0000000>,
      <0.6523086, 1.0000000>,
      <0.6523086, 0.9941947>,
      <0.6838443, 0.9970974>,
      <0.6680764, 1.0000000>,
      <0.6523086, 0.9970974>,
      <0.6680765, 0.9941947>
    }
    face_indices {
      1056,   // 0 triangles and 528 quads
      <8, 7, 0>,
      <8, 0, 4>,
      <8, 4, 1>,
      <8, 1, 5>,
      <8, 5, 2>,
      <8, 2, 6>,
      <8, 6, 3>,
      <8, 3, 7>,
      <14, 13, 0>,
      <14, 0, 7>,
      <14, 7, 3>,
      <14, 3, 11>,
      <14, 11, 9>,
      <14, 9, 12>,
      <14, 12, 10>,
      <14, 10, 13>,
      <20, 19, 0>,
      <20, 0, 13>,
      <20, 13, 10>,
      <20, 10, 17>,
      <20, 17, 15>,
      <20, 15, 18>,
      <20, 18, 16>,
      <20, 16, 19>,
      <24, 4, 0>,
      <24, 0, 19>,
      <24, 19, 16>,
      <24, 16, 22>,
      <24, 22, 21>,
      <24, 21, 23>,
      <24, 23, 1>,
      <24, 1, 4>,
      <33, 32, 25>,
      <33, 25, 29>,
      <33, 29, 26>,
      <33, 26, 30>,
      <33, 30, 27>,
      <33, 27, 31>,
      <33, 31, 28>,
      <33, 28, 32>,
      <39, 38, 25>,
      <39, 25, 32>,
      <39, 32, 28>,
      <39, 28, 36>,
      <39, 36, 34>,
      <39, 34, 37>,
      <39, 37, 35>,
      <39, 35, 38>,
      <45, 44, 25>,
      <45, 25, 38>,
      <45, 38, 35>,
      <45, 35, 42>,
      <45, 42, 40>,
      <45, 40, 43>,
      <45, 43, 41>,
      <45, 41, 44>,
      <49, 29, 25>,
      <49, 25, 44>,
      <49, 44, 41>,
      <49, 41, 47>,
      <49, 47, 46>,
      <49, 46, 48>,
      <49, 48, 26>,
      <49, 26, 29>,
      <55, 54, 50>,
      <55, 50, 52>,
      <55, 52, 35>,
      <55, 35, 37>,
      <55, 37, 34>,
      <55, 34, 53>,
      <55, 53, 51>,
      <55, 51, 54>,
      <61, 60, 50>,
      <61, 50, 54>,
      <61, 54, 51>,
      <61, 51, 58>,
      <61, 58, 56>,
      <61, 56, 59>,
      <61, 59, 57>,
      <61, 57, 60>,
      <67, 66, 50>,
      <67, 50, 60>,
      <67, 60, 57>,
      <67, 57, 64>,
      <67, 64, 62>,
      <67, 62, 65>,
      <67, 65, 63>,
      <67, 63, 66>,
      <69, 52, 50>,
      <69, 50, 66>,
      <69, 66, 63>,
      <69, 63, 68>,
      <69, 68, 40>,
      <69, 40, 42>,
      <69, 42, 35>,
      <69, 35, 52>,
      <75, 74, 70>,
      <75, 70, 72>,
      <75, 72, 57>,
      <75, 57, 59>,
      <75, 59, 56>,
      <75, 56, 73>,
      <75, 73, 71>,
      <75, 71, 74>,
      <81, 80, 70>,
      <81, 70, 74>,
      <81, 74, 71>,
      <81, 71, 78>,
      <81, 78, 76>,
      <81, 76, 79>,
      <81, 79, 77>,
      <81, 77, 80>,
      <87, 86, 70>,
      <87, 70, 80>,
      <87, 80, 77>,
      <87, 77, 84>,
      <87, 84, 82>,
      <87, 82, 85>,
      <87, 85, 83>,
      <87, 83, 86>,
      <89, 72, 70>,
      <89, 70, 86>,
      <89, 86, 83>,
      <89, 83, 88>,
      <89, 88, 62>,
      <89, 62, 64>,
      <89, 64, 57>,
      <89, 57, 72>,
      <95, 94, 90>,
      <95, 90, 92>,
      <95, 92, 91>,
      <95, 91, 93>,
      <95, 93, 46>,
      <95, 46, 47>,
      <95, 47, 41>,
      <95, 41, 94>,
      <99, 98, 90>,
      <99, 90, 94>,
      <99, 94, 41>,
      <99, 41, 43>,
      <99, 43, 40>,
      <99, 40, 97>,
      <99, 97, 96>,
      <99, 96, 98>,
      <105, 104, 90>,
      <105, 90, 98>,
      <105, 98, 96>,
      <105, 96, 102>,
      <105, 102, 100>,
      <105, 100, 103>,
      <105, 103, 101>,
      <105, 101, 104>,
      <109, 92, 90>,
      <109, 90, 104>,
      <109, 104, 101>,
      <109, 101, 107>,
      <109, 107, 106>,
      <109, 106, 108>,
      <109, 108, 91>,
      <109, 91, 92>,
      <113, 112, 110>,
      <113, 110, 111>,
      <113, 111, 96>,
      <113, 96, 97>,
      <113, 97, 40>,
      <113, 40, 68>,
      <113, 68, 63>,
      <113, 63, 112>,
      <117, 116, 110>,
      <117, 110, 112>,
      <117, 112, 63>,
      <117, 63, 65>,
      <117, 65, 62>,
      <117, 62, 115>,
      <117, 115, 114>,
      <117, 114, 116>,
      <123, 122, 110>,
      <123, 110, 116>,
      <123, 116, 114>,
      <123, 114, 120>,
      <123, 120, 118>,
      <123, 118, 121>,
      <123, 121, 119>,
      <123, 119, 122>,
      <125, 111, 110>,
      <125, 110, 122>,
      <125, 122, 119>,
      <125, 119, 124>,
      <125, 124, 100>,
      <125, 100, 102>,
      <125, 102, 96>,
      <125, 96, 111>,
      <129, 128, 126>,
      <129, 126, 127>,
      <129, 127, 114>,
      <129, 114, 115>,
      <129, 115, 62>,
      <129, 62, 88>,
      <129, 88, 83>,
      <129, 83, 128>,
      <133, 132, 126>,
      <133, 126, 128>,
      <133, 128, 83>,
      <133, 83, 85>,
      <133, 85, 82>,
      <133, 82, 131>,
      <133, 131, 130>,
      <133, 130, 132>,
      <139, 138, 126>,
      <139, 126, 132>,
      <139, 132, 130>,
      <139, 130, 136>,
      <139, 136, 134>,
      <139, 134, 137>,
      <139, 137, 135>,
      <139, 135, 138>,
      <141, 127, 126>,
      <141, 126, 138>,
      <141, 138, 135>,
      <141, 135, 140>,
      <141, 140, 118>,
      <141, 118, 120>,
      <141, 120, 114>,
      <141, 114, 127>,
      <147, 146, 142>,
      <147, 142, 144>,
      <147, 144, 143>,
      <147, 143, 145>,
      <147, 145, 106>,
      <147, 106, 107>,
      <147, 107, 101>,
      <147, 101, 146>,
      <151, 150, 142>,
      <151, 142, 146>,
      <151, 146, 101>,
      <151, 101, 103>,
      <151, 103, 100>,
      <151, 100, 149>,
      <151, 149, 148>,
      <151, 148, 150>,
      <157, 156, 142>,
      <157, 142, 150>,
      <157, 150, 148>,
      <157, 148, 154>,
      <157, 154, 152>,
      <157, 152, 155>,
      <157, 155, 153>,
      <157, 153, 156>,
      <161, 144, 142>,
      <161, 142, 156>,
      <161, 156, 153>,
      <161, 153, 159>,
      <161, 159, 158>,
      <161, 158, 160>,
      <161, 160, 143>,
      <161, 143, 144>,
      <165, 164, 162>,
      <165, 162, 163>,
      <165, 163, 148>,
      <165, 148, 149>,
      <165, 149, 100>,
      <165, 100, 124>,
      <165, 124, 119>,
      <165, 119, 164>,
      <169, 168, 162>,
      <169, 162, 164>,
      <169, 164, 119>,
      <169, 119, 121>,
      <169, 121, 118>,
      <169, 118, 167>,
      <169, 167, 166>,
      <169, 166, 168>,
      <175, 174, 162>,
      <175, 162, 168>,
      <175, 168, 166>,
      <175, 166, 172>,
      <175, 172, 170>,
      <175, 170, 173>,
      <175, 173, 171>,
      <175, 171, 174>,
      <177, 163, 162>,
      <177, 162, 174>,
      <177, 174, 171>,
      <177, 171, 176>,
      <177, 176, 152>,
      <177, 152, 154>,
      <177, 154, 148>,
      <177, 148, 163>,
      <181, 180, 178>,
      <181, 178, 179>,
      <181, 179, 166>,
      <181, 166, 167>,
      <181, 167, 118>,
      <181, 118, 140>,
      <181, 140, 135>,
      <181, 135, 180>,
      <185, 184, 178>,
      <185, 178, 180>,
      <185, 180, 135>,
      <185, 135, 137>,
      <185, 137, 134>,
      <185, 134, 183>,
      <185, 183, 182>,
      <185, 182, 184>,
      <191, 190, 178>,
      <191, 178, 184>,
      <191, 184, 182>,
      <191, 182, 188>,
      <191, 188, 186>,
      <191, 186, 189>,
      <191, 189, 187>,
      <191, 187, 190>,
      <193, 179, 178>,
      <193, 178, 190>,
      <193, 190, 187>,
      <193, 187, 192>,
      <193, 192, 170>,
      <193, 170, 172>,
      <193, 172, 166>,
      <193, 166, 179>,
      <199, 198, 194>,
      <199, 194, 196>,
      <199, 196, 195>,
      <199, 195, 197>,
      <199, 197, 158>,
      <199, 158, 159>,
      <199, 159, 153>,
      <199, 153, 198>,
      <203, 202, 194>,
      <203, 194, 198>,
      <203, 198, 153>,
      <203, 153, 155>,
      <203, 155, 152>,
      <203, 152, 201>,
      <203, 201, 200>,
      <203, 200, 202>,
      <209, 208, 194>,
      <209, 194, 202>,
      <209, 202, 200>,
      <209, 200, 206>,
      <209, 206, 204>,
      <209, 204, 207>,
      <209, 207, 205>,
      <209, 205, 208>,
      <213, 196, 194>,
      <213, 194, 208>,
      <213, 208, 205>,
      <213, 205, 211>,
      <213, 211, 210>,
      <213, 210, 212>,
      <213, 212, 195>,
      <213, 195, 196>,
      <217, 216, 214>,
      <217, 214, 215>,
      <217, 215, 200>,
      <217, 200, 201>,
      <217, 201, 152>,
      <217, 152, 176>,
      <217, 176, 171>,
      <217, 171, 216>,
      <221, 220, 214>,
      <221, 214, 216>,
      <221, 216, 171>,
      <221, 171, 173>,
      <221, 173, 170>,
      <221, 170, 219>,
      <221, 219, 218>,
      <221, 218, 220>,
      <227, 226, 214>,
      <227, 214, 220>,
      <227, 220, 218>,
      <227, 218, 224>,
      <227, 224, 222>,
      <227, 222, 225>,
      <227, 225, 223>,
      <227, 223, 226>,
      <229, 215, 214>,
      <229, 214, 226>,
      <229, 226, 223>,
      <229, 223, 228>,
      <229, 228, 204>,
      <229, 204, 206>,
      <229, 206, 200>,
      <229, 200, 215>,
      <233, 232, 230>,
      <233, 230, 231>,
      <233, 231, 218>,
      <233, 218, 219>,
      <233, 219, 170>,
      <233, 170, 192>,
      <233, 192, 187>,
      <233, 187, 232>,
      <237, 236, 230>,
      <237, 230, 232>,
      <237, 232, 187>,
      <237, 187, 189>,
      <237, 189, 186>,
      <237, 186, 235>,
      <237, 235, 234>,
      <237, 234, 236>,
      <243, 242, 230>,
      <243, 230, 236>,
      <243, 236, 234>,
      <243, 234, 240>,
      <243, 240, 238>,
      <243, 238, 241>,
      <243, 241, 239>,
      <243, 239, 242>,
      <245, 231, 230>,
      <245, 230, 242>,
      <245, 242, 239>,
      <245, 239, 244>,
      <245, 244, 222>,
      <245, 222, 224>,
      <245, 224, 218>,
      <245, 218, 231>,
      <251, 250, 246>,
      <251, 246, 248>,
      <251, 248, 247>,
      <251, 247, 249>,
      <251, 249, 210>,
      <251, 210, 211>,
      <251, 211, 205>,
      <251, 205, 250>,
      <255, 254, 246>,
      <255, 246, 250>,
      <255, 250, 205>,
      <255, 205, 207>,
      <255, 207, 204>,
      <255, 204, 253>,
      <255, 253, 252>,
      <255, 252, 254>,
      <261, 260, 246>,
      <261, 246, 254>,
      <261, 254, 252>,
      <261, 252, 258>,
      <261, 258, 256>,
      <261, 256, 259>,
      <261, 259, 257>,
      <261, 257, 260>,
      <265, 248, 246>,
      <265, 246, 260>,
      <265, 260, 257>,
      <265, 257, 263>,
      <265, 263, 262>,
      <265, 262, 264>,
      <265, 264, 247>,
      <265, 247, 248>,
      <269, 268, 266>,
      <269, 266, 267>,
      <269, 267, 252>,
      <269, 252, 253>,
      <269, 253, 204>,
      <269, 204, 228>,
      <269, 228, 223>,
      <269, 223, 268>,
      <273, 272, 266>,
      <273, 266, 268>,
      <273, 268, 223>,
      <273, 223, 225>,
      <273, 225, 222>,
      <273, 222, 271>,
      <273, 271, 270>,
      <273, 270, 272>,
      <279, 278, 266>,
      <279, 266, 272>,
      <279, 272, 270>,
      <279, 270, 276>,
      <279, 276, 274>,
      <279, 274, 277>,
      <279, 277, 275>,
      <279, 275, 278>,
      <281, 267, 266>,
      <281, 266, 278>,
      <281, 278, 275>,
      <281, 275, 280>,
      <281, 280, 256>,
      <281, 256, 258>,
      <281, 258, 252>,
      <281, 252, 267>,
      <285, 284, 282>,
      <285, 282, 283>,
      <285, 283, 270>,
      <285, 270, 271>,
      <285, 271, 222>,
      <285, 222, 244>,
      <285, 244, 239>,
      <285, 239, 284>,
      <289, 288, 282>,
      <289, 282, 284>,
      <289, 284, 239>,
      <289, 239, 241>,
      <289, 241, 238>,
      <289, 238, 287>,
      <289, 287, 286>,
      <289, 286, 288>,
      <295, 294, 282>,
      <295, 282, 288>,
      <295, 288, 286>,
      <295, 286, 292>,
      <295, 292, 290>,
      <295, 290, 293>,
      <295, 293, 291>,
      <295, 291, 294>,
      <297, 283, 282>,
      <297, 282, 294>,
      <297, 294, 291>,
      <297, 291, 296>,
      <297, 296, 274>,
      <297, 274, 276>,
      <297, 276, 270>,
      <297, 270, 283>,
      <303, 302, 298>,
      <303, 298, 300>,
      <303, 300, 299>,
      <303, 299, 301>,
      <303, 301, 262>,
      <303, 262, 263>,
      <303, 263, 257>,
      <303, 257, 302>,
      <307, 306, 298>,
      <307, 298, 302>,
      <307, 302, 257>,
      <307, 257, 259>,
      <307, 259, 256>,
      <307, 256, 305>,
      <307, 305, 304>,
      <307, 304, 306>,
      <313, 312, 298>,
      <313, 298, 306>,
      <313, 306, 304>,
      <313, 304, 310>,
      <313, 310, 308>,
      <313, 308, 311>,
      <313, 311, 309>,
      <313, 309, 312>,
      <317, 300, 298>,
      <317, 298, 312>,
      <317, 312, 309>,
      <317, 309, 315>,
      <317, 315, 314>,
      <317, 314, 316>,
      <317, 316, 299>,
      <317, 299, 300>,
      <321, 320, 318>,
      <321, 318, 319>,
      <321, 319, 304>,
      <321, 304, 305>,
      <321, 305, 256>,
      <321, 256, 280>,
      <321, 280, 275>,
      <321, 275, 320>,
      <325, 324, 318>,
      <325, 318, 320>,
      <325, 320, 275>,
      <325, 275, 277>,
      <325, 277, 274>,
      <325, 274, 323>,
      <325, 323, 322>,
      <325, 322, 324>,
      <331, 330, 318>,
      <331, 318, 324>,
      <331, 324, 322>,
      <331, 322, 328>,
      <331, 328, 326>,
      <331, 326, 329>,
      <331, 329, 327>,
      <331, 327, 330>,
      <333, 319, 318>,
      <333, 318, 330>,
      <333, 330, 327>,
      <333, 327, 332>,
      <333, 332, 308>,
      <333, 308, 310>,
      <333, 310, 304>,
      <333, 304, 319>,
      <337, 336, 334>,
      <337, 334, 335>,
      <337, 335, 322>,
      <337, 322, 323>,
      <337, 323, 274>,
      <337, 274, 296>,
      <337, 296, 291>,
      <337, 291, 336>,
      <341, 340, 334>,
      <341, 334, 336>,
      <341, 336, 291>,
      <341, 291, 293>,
      <341, 293, 290>,
      <341, 290, 339>,
      <341, 339, 338>,
      <341, 338, 340>,
      <347, 346, 334>,
      <347, 334, 340>,
      <347, 340, 338>,
      <347, 338, 344>,
      <347, 344, 342>,
      <347, 342, 345>,
      <347, 345, 343>,
      <347, 343, 346>,
      <349, 335, 334>,
      <349, 334, 346>,
      <349, 346, 343>,
      <349, 343, 348>,
      <349, 348, 326>,
      <349, 326, 328>,
      <349, 328, 322>,
      <349, 322, 335>,
      <355, 354, 350>,
      <355, 350, 352>,
      <355, 352, 351>,
      <355, 351, 353>,
      <355, 353, 314>,
      <355, 314, 315>,
      <355, 315, 309>,
      <355, 309, 354>,
      <359, 358, 350>,
      <359, 350, 354>,
      <359, 354, 309>,
      <359, 309, 311>,
      <359, 311, 308>,
      <359, 308, 357>,
      <359, 357, 356>,
      <359, 356, 358>,
      <365, 364, 350>,
      <365, 350, 358>,
      <365, 358, 356>,
      <365, 356, 362>,
      <365, 362, 360>,
      <365, 360, 363>,
      <365, 363, 361>,
      <365, 361, 364>,
      <369, 352, 350>,
      <369, 350, 364>,
      <369, 364, 361>,
      <369, 361, 367>,
      <369, 367, 366>,
      <369, 366, 368>,
      <369, 368, 351>,
      <369, 351, 352>,
      <373, 372, 370>,
      <373, 370, 371>,
      <373, 371, 356>,
      <373, 356, 357>,
      <373, 357, 308>,
      <373, 308, 332>,
      <373, 332, 327>,
      <373, 327, 372>,
      <377, 376, 370>,
      <377, 370, 372>,
      <377, 372, 327>,
      <377, 327, 329>,
      <377, 329, 326>,
      <377, 326, 375>,
      <377, 375, 374>,
      <377, 374, 376>,
      <383, 382, 370>,
      <383, 370, 376>,
      <383, 376, 374>,
      <383, 374, 380>,
      <383, 380, 378>,
      <383, 378, 381>,
      <383, 381, 379>,
      <383, 379, 382>,
      <385, 371, 370>,
      <385, 370, 382>,
      <385, 382, 379>,
      <385, 379, 384>,
      <385, 384, 360>,
      <385, 360, 362>,
      <385, 362, 356>,
      <385, 356, 371>,
      <389, 388, 386>,
      <389, 386, 387>,
      <389, 387, 374>,
      <389, 374, 375>,
      <389, 375, 326>,
      <389, 326, 348>,
      <389, 348, 343>,
      <389, 343, 388>,
      <393, 392, 386>,
      <393, 386, 388>,
      <393, 388, 343>,
      <393, 343, 345>,
      <393, 345, 342>,
      <393, 342, 391>,
      <393, 391, 390>,
      <393, 390, 392>,
      <399, 398, 386>,
      <399, 386, 392>,
      <399, 392, 390>,
      <399, 390, 396>,
      <399, 396, 394>,
      <399, 394, 397>,
      <399, 397, 395>,
      <399, 395, 398>,
      <401, 387, 386>,
      <401, 386, 398>,
      <401, 398, 395>,
      <401, 395, 400>,
      <401, 400, 378>,
      <401, 378, 380>,
      <401, 380, 374>,
      <401, 374, 387>,
      <407, 406, 402>,
      <407, 402, 404>,
      <407, 404, 403>,
      <407, 403, 405>,
      <407, 405, 366>,
      <407, 366, 367>,
      <407, 367, 361>,
      <407, 361, 406>,
      <411, 410, 402>,
      <411, 402, 406>,
      <411, 406, 361>,
      <411, 361, 363>,
      <411, 363, 360>,
      <411, 360, 409>,
      <411, 409, 408>,
      <411, 408, 410>,
      <414, 413, 402>,
      <414, 402, 410>,
      <414, 410, 408>,
      <414, 408, 412>,
      <414, 412, 9>,
      <414, 9, 11>,
      <414, 11, 3>,
      <414, 3, 413>,
      <416, 404, 402>,
      <416, 402, 413>,
      <416, 413, 3>,
      <416, 3, 6>,
      <416, 6, 2>,
      <416, 2, 415>,
      <416, 415, 403>,
      <416, 403, 404>,
      <420, 419, 417>,
      <420, 417, 418>,
      <420, 418, 408>,
      <420, 408, 409>,
      <420, 409, 360>,
      <420, 360, 384>,
      <420, 384, 379>,
      <420, 379, 419>,
      <424, 423, 417>,
      <424, 417, 419>,
      <424, 419, 379>,
      <424, 379, 381>,
      <424, 381, 378>,
      <424, 378, 422>,
      <424, 422, 421>,
      <424, 421, 423>,
      <427, 426, 417>,
      <427, 417, 423>,
      <427, 423, 421>,
      <427, 421, 425>,
      <427, 425, 15>,
      <427, 15, 17>,
      <427, 17, 10>,
      <427, 10, 426>,
      <428, 418, 417>,
      <428, 417, 426>,
      <428, 426, 10>,
      <428, 10, 12>,
      <428, 12, 9>,
      <428, 9, 412>,
      <428, 412, 408>,
      <428, 408, 418>,
      <432, 431, 429>,
      <432, 429, 430>,
      <432, 430, 421>,
      <432, 421, 422>,
      <432, 422, 378>,
      <432, 378, 400>,
      <432, 400, 395>,
      <432, 395, 431>,
      <436, 435, 429>,
      <436, 429, 431>,
      <436, 431, 395>,
      <436, 395, 397>,
      <436, 397, 394>,
      <436, 394, 434>,
      <436, 434, 433>,
      <436, 433, 435>,
      <439, 438, 429>,
      <439, 429, 435>,
      <439, 435, 433>,
      <439, 433, 437>,
      <439, 437, 21>,
      <439, 21, 22>,
      <439, 22, 16>,
      <439, 16, 438>,
      <440, 430, 429>,
      <440, 429, 438>,
      <440, 438, 16>,
      <440, 16, 18>,
      <440, 18, 15>,
      <440, 15, 425>,
      <440, 425, 421>,
      <440, 421, 430>,
      <448, 447, 441>,
      <448, 441, 444>,
      <448, 444, 442>,
      <448, 442, 445>,
      <448, 445, 366>,
      <448, 366, 446>,
      <448, 446, 443>,
      <448, 443, 447>,
      <453, 452, 441>,
      <453, 441, 447>,
      <453, 447, 443>,
      <453, 443, 450>,
      <453, 450, 394>,
      <453, 394, 451>,
      <453, 451, 449>,
      <453, 449, 452>,
      <458, 457, 441>,
      <458, 441, 452>,
      <458, 452, 449>,
      <458, 449, 455>,
      <458, 455, 21>,
      <458, 21, 456>,
      <458, 456, 454>,
      <458, 454, 457>,
      <461, 444, 441>,
      <461, 441, 457>,
      <461, 457, 454>,
      <461, 454, 459>,
      <461, 459, 2>,
      <461, 2, 460>,
      <461, 460, 442>,
      <461, 442, 444>,
      <467, 466, 462>,
      <467, 462, 464>,
      <467, 464, 463>,
      <467, 463, 465>,
      <467, 465, 314>,
      <467, 314, 353>,
      <467, 353, 351>,
      <467, 351, 466>,
      <471, 470, 462>,
      <471, 462, 466>,
      <471, 466, 351>,
      <471, 351, 368>,
      <471, 368, 366>,
      <471, 366, 469>,
      <471, 469, 468>,
      <471, 468, 470>,
      <474, 473, 462>,
      <474, 462, 470>,
      <474, 470, 468>,
      <474, 468, 472>,
      <474, 472, 394>,
      <474, 394, 396>,
      <474, 396, 390>,
      <474, 390, 473>,
      <476, 464, 462>,
      <476, 462, 473>,
      <476, 473, 390>,
      <476, 390, 391>,
      <476, 391, 342>,
      <476, 342, 475>,
      <476, 475, 463>,
      <476, 463, 464>,
      <484, 483, 477>,
      <484, 477, 480>,
      <484, 480, 478>,
      <484, 478, 481>,
      <484, 481, 262>,
      <484, 262, 482>,
      <484, 482, 479>,
      <484, 479, 483>,
      <489, 488, 477>,
      <489, 477, 483>,
      <489, 483, 479>,
      <489, 479, 486>,
      <489, 486, 290>,
      <489, 290, 487>,
      <489, 487, 485>,
      <489, 485, 488>,
      <494, 493, 477>,
      <494, 477, 488>,
      <494, 488, 485>,
      <494, 485, 491>,
      <494, 491, 342>,
      <494, 342, 492>,
      <494, 492, 490>,
      <494, 490, 493>,
      <497, 480, 477>,
      <497, 477, 493>,
      <497, 493, 490>,
      <497, 490, 495>,
      <497, 495, 314>,
      <497, 314, 496>,
      <497, 496, 478>,
      <497, 478, 480>,
      <503, 502, 498>,
      <503, 498, 500>,
      <503, 500, 499>,
      <503, 499, 501>,
      <503, 501, 210>,
      <503, 210, 249>,
      <503, 249, 247>,
      <503, 247, 502>,
      <507, 506, 498>,
      <507, 498, 502>,
      <507, 502, 247>,
      <507, 247, 264>,
      <507, 264, 262>,
      <507, 262, 505>,
      <507, 505, 504>,
      <507, 504, 506>,
      <510, 509, 498>,
      <510, 498, 506>,
      <510, 506, 504>,
      <510, 504, 508>,
      <510, 508, 290>,
      <510, 290, 292>,
      <510, 292, 286>,
      <510, 286, 509>,
      <512, 500, 498>,
      <512, 498, 509>,
      <512, 509, 286>,
      <512, 286, 287>,
      <512, 287, 238>,
      <512, 238, 511>,
      <512, 511, 499>,
      <512, 499, 500>,
      <520, 519, 513>,
      <520, 513, 516>,
      <520, 516, 514>,
      <520, 514, 517>,
      <520, 517, 158>,
      <520, 158, 518>,
      <520, 518, 515>,
      <520, 515, 519>,
      <525, 524, 513>,
      <525, 513, 519>,
      <525, 519, 515>,
      <525, 515, 522>,
      <525, 522, 186>,
      <525, 186, 523>,
      <525, 523, 521>,
      <525, 521, 524>,
      <530, 529, 513>,
      <530, 513, 524>,
      <530, 524, 521>,
      <530, 521, 527>,
      <530, 527, 238>,
      <530, 238, 528>,
      <530, 528, 526>,
      <530, 526, 529>,
      <533, 516, 513>,
      <533, 513, 529>,
      <533, 529, 526>,
      <533, 526, 531>,
      <533, 531, 210>,
      <533, 210, 532>,
      <533, 532, 514>,
      <533, 514, 516>,
      <539, 538, 534>,
      <539, 534, 536>,
      <539, 536, 535>,
      <539, 535, 537>,
      <539, 537, 106>,
      <539, 106, 145>,
      <539, 145, 143>,
      <539, 143, 538>,
      <543, 542, 534>,
      <543, 534, 538>,
      <543, 538, 143>,
      <543, 143, 160>,
      <543, 160, 158>,
      <543, 158, 541>,
      <543, 541, 540>,
      <543, 540, 542>,
      <546, 545, 534>,
      <546, 534, 542>,
      <546, 542, 540>,
      <546, 540, 544>,
      <546, 544, 186>,
      <546, 186, 188>,
      <546, 188, 182>,
      <546, 182, 545>,
      <548, 536, 534>,
      <548, 534, 545>,
      <548, 545, 182>,
      <548, 182, 183>,
      <548, 183, 134>,
      <548, 134, 547>,
      <548, 547, 535>,
      <548, 535, 536>,
      <556, 555, 549>,
      <556, 549, 552>,
      <556, 552, 550>,
      <556, 550, 553>,
      <556, 553, 27>,
      <556, 27, 554>,
      <556, 554, 551>,
      <556, 551, 555>,
      <561, 560, 549>,
      <561, 549, 555>,
      <561, 555, 551>,
      <561, 551, 558>,
      <561, 558, 76>,
      <561, 76, 559>,
      <561, 559, 557>,
      <561, 557, 560>,
      <566, 565, 549>,
      <566, 549, 560>,
      <566, 560, 557>,
      <566, 557, 563>,
      <566, 563, 134>,
      <566, 134, 564>,
      <566, 564, 562>,
      <566, 562, 565>,
      <569, 552, 549>,
      <569, 549, 565>,
      <569, 565, 562>,
      <569, 562, 567>,
      <569, 567, 106>,
      <569, 106, 568>,
      <569, 568, 550>,
      <569, 550, 552>,
      <573, 572, 570>,
      <573, 570, 571>,
      <573, 571, 551>,
      <573, 551, 554>,
      <573, 554, 27>,
      <573, 27, 30>,
      <573, 30, 26>,
      <573, 26, 572>,
      <577, 576, 570>,
      <577, 570, 572>,
      <577, 572, 26>,
      <577, 26, 48>,
      <577, 48, 46>,
      <577, 46, 575>,
      <577, 575, 574>,
      <577, 574, 576>,
      <580, 579, 570>,
      <580, 570, 576>,
      <580, 576, 574>,
      <580, 574, 578>,
      <580, 578, 82>,
      <580, 82, 84>,
      <580, 84, 77>,
      <580, 77, 579>,
      <581, 571, 570>,
      <581, 570, 579>,
      <581, 579, 77>,
      <581, 77, 79>,
      <581, 79, 76>,
      <581, 76, 558>,
      <581, 558, 551>,
      <581, 551, 571>
    }
    normal_indices {
      1056,   // from 0 triangles and 528 quads
      <0, 1, 2>,
      <0, 2, 3>,
      <0, 3, 4>,
      <0, 4, 5>,
      <0, 6, 7>,
      <0, 7, 8>,
      <0, 9, 10>,
      <0, 10, 1>,
      <11, 12, 2>,
      <11, 2, 1>,
      <11, 1, 13>,
      <11, 13, 14>,
      <11, 15, 16>,
      <11, 16, 17>,
      <11, 18, 19>,
      <11, 19, 12>,
      <20, 21, 2>,
      <20, 2, 12>,
      <20, 12, 22>,
      <20, 22, 23>,
      <20, 24, 25>,
      <20, 25, 26>,
      <20, 27, 28>,
      <20, 28, 21>,
      <29, 3, 2>,
      <29, 2, 21>,
      <29, 21, 30>,
      <29, 30, 31>,
      <29, 32, 33>,
      <29, 33, 34>,
      <29, 35, 36>,
      <29, 36, 3>,
      <37, 38, 39>,
      <37, 39, 40>,
      <37, 40, 41>,
      <37, 41, 42>,
      <37, 43, 44>,
      <37, 44, 45>,
      <37, 46, 47>,
      <37, 47, 38>,
      <48, 49, 39>,
      <48, 39, 38>,
      <48, 38, 50>,
      <48, 50, 51>,
      <48, 52, 53>,
      <48, 53, 54>,
      <48, 55, 56>,
      <48, 56, 49>,
      <57, 58, 39>,
      <57, 39, 49>,
      <57, 49, 59>,
      <57, 59, 60>,
      <57, 61, 62>,
      <57, 62, 63>,
      <57, 64, 65>,
      <57, 65, 58>,
      <66, 40, 39>,
      <66, 39, 58>,
      <66, 58, 67>,
      <66, 67, 68>,
      <66, 69, 70>,
      <66, 70, 71>,
      <66, 72, 73>,
      <66, 73, 40>,
      <74, 75, 76>,
      <74, 76, 77>,
      <74, 77, 78>,
      <74, 78, 79>,
      <74, 80, 81>,
      <74, 81, 82>,
      <74, 83, 84>,
      <74, 84, 75>,
      <85, 86, 76>,
      <85, 76, 75>,
      <85, 75, 87>,
      <85, 87, 88>,
      <85, 89, 90>,
      <85, 90, 91>,
      <85, 92, 93>,
      <85, 93, 86>,
      <94, 95, 76>,
      <94, 76, 86>,
      <94, 86, 96>,
      <94, 96, 97>,
      <94, 98, 99>,
      <94, 99, 100>,
      <94, 101, 102>,
      <94, 102, 95>,
      <103, 77, 76>,
      <103, 76, 95>,
      <103, 95, 104>,
      <103, 104, 105>,
      <103, 106, 107>,
      <103, 107, 108>,
      <103, 109, 110>,
      <103, 110, 77>,
      <111, 112, 113>,
      <111, 113, 114>,
      <111, 114, 115>,
      <111, 115, 116>,
      <111, 117, 118>,
      <111, 118, 119>,
      <111, 120, 121>,
      <111, 121, 112>,
      <122, 123, 113>,
      <122, 113, 112>,
      <122, 112, 124>,
      <122, 124, 125>,
      <122, 126, 127>,
      <122, 127, 128>,
      <122, 129, 130>,
      <122, 130, 123>,
      <131, 132, 113>,
      <131, 113, 123>,
      <131, 123, 133>,
      <131, 133, 134>,
      <131, 135, 136>,
      <131, 136, 137>,
      <131, 138, 139>,
      <131, 139, 132>,
      <140, 114, 113>,
      <140, 113, 132>,
      <140, 132, 141>,
      <140, 141, 142>,
      <140, 143, 144>,
      <140, 144, 145>,
      <140, 146, 147>,
      <140, 147, 114>,
      <148, 149, 150>,
      <148, 150, 151>,
      <148, 151, 152>,
      <148, 152, 153>,
      <148, 154, 155>,
      <148, 155, 156>,
      <148, 157, 158>,
      <148, 158, 149>,
      <159, 160, 150>,
      <159, 150, 149>,
      <159, 149, 161>,
      <159, 161, 162>,
      <159, 163, 164>,
      <159, 164, 165>,
      <159, 166, 167>,
      <159, 167, 160>,
      <168, 169, 150>,
      <168, 150, 160>,
      <168, 160, 170>,
      <168, 170, 171>,
      <168, 172, 173>,
      <168, 173, 174>,
      <168, 175, 176>,
      <168, 176, 169>,
      <177, 151, 150>,
      <177, 150, 169>,
      <177, 169, 178>,
      <177, 178, 179>,
      <177, 180, 181>,
      <177, 181, 182>,
      <177, 183, 184>,
      <177, 184, 151>,
      <185, 186, 187>,
      <185, 187, 188>,
      <185, 188, 189>,
      <185, 189, 190>,
      <185, 191, 192>,
      <185, 192, 193>,
      <185, 194, 195>,
      <185, 195, 186>,
      <196, 197, 187>,
      <196, 187, 186>,
      <196, 186, 198>,
      <196, 198, 199>,
      <196, 200, 201>,
      <196, 201, 202>,
      <196, 203, 204>,
      <196, 204, 197>,
      <205, 206, 187>,
      <205, 187, 197>,
      <205, 197, 207>,
      <205, 207, 208>,
      <205, 209, 210>,
      <205, 210, 211>,
      <205, 212, 213>,
      <205, 213, 206>,
      <214, 188, 187>,
      <214, 187, 206>,
      <214, 206, 215>,
      <214, 215, 216>,
      <214, 217, 218>,
      <214, 218, 219>,
      <214, 220, 221>,
      <214, 221, 188>,
      <222, 223, 224>,
      <222, 224, 225>,
      <222, 225, 226>,
      <222, 226, 227>,
      <222, 228, 229>,
      <222, 229, 230>,
      <222, 231, 232>,
      <222, 232, 223>,
      <233, 234, 224>,
      <233, 224, 223>,
      <233, 223, 235>,
      <233, 235, 236>,
      <233, 237, 238>,
      <233, 238, 239>,
      <233, 240, 241>,
      <233, 241, 234>,
      <242, 243, 224>,
      <242, 224, 234>,
      <242, 234, 244>,
      <242, 244, 245>,
      <242, 246, 247>,
      <242, 247, 248>,
      <242, 249, 250>,
      <242, 250, 243>,
      <251, 225, 224>,
      <251, 224, 243>,
      <251, 243, 252>,
      <251, 252, 253>,
      <251, 254, 255>,
      <251, 255, 256>,
      <251, 257, 258>,
      <251, 258, 225>,
      <259, 260, 261>,
      <259, 261, 262>,
      <259, 262, 263>,
      <259, 263, 264>,
      <259, 265, 266>,
      <259, 266, 267>,
      <259, 268, 269>,
      <259, 269, 260>,
      <270, 271, 261>,
      <270, 261, 260>,
      <270, 260, 272>,
      <270, 272, 273>,
      <270, 274, 275>,
      <270, 275, 276>,
      <270, 277, 278>,
      <270, 278, 271>,
      <279, 280, 261>,
      <279, 261, 271>,
      <279, 271, 281>,
      <279, 281, 282>,
      <279, 283, 284>,
      <279, 284, 285>,
      <279, 286, 287>,
      <279, 287, 280>,
      <288, 262, 261>,
      <288, 261, 280>,
      <288, 280, 289>,
      <288, 289, 290>,
      <288, 291, 292>,
      <288, 292, 293>,
      <288, 294, 295>,
      <288, 295, 262>,
      <296, 297, 298>,
      <296, 298, 299>,
      <296, 299, 300>,
      <296, 300, 301>,
      <296, 302, 303>,
      <296, 303, 304>,
      <296, 305, 306>,
      <296, 306, 297>,
      <307, 308, 298>,
      <307, 298, 297>,
      <307, 297, 309>,
      <307, 309, 310>,
      <307, 311, 312>,
      <307, 312, 313>,
      <307, 314, 315>,
      <307, 315, 308>,
      <316, 317, 298>,
      <316, 298, 308>,
      <316, 308, 318>,
      <316, 318, 319>,
      <316, 320, 321>,
      <316, 321, 322>,
      <316, 323, 324>,
      <316, 324, 317>,
      <325, 299, 298>,
      <325, 298, 317>,
      <325, 317, 326>,
      <325, 326, 327>,
      <325, 328, 329>,
      <325, 329, 330>,
      <325, 331, 332>,
      <325, 332, 299>,
      <333, 334, 335>,
      <333, 335, 336>,
      <333, 336, 337>,
      <333, 337, 338>,
      <333, 339, 340>,
      <333, 340, 341>,
      <333, 342, 343>,
      <333, 343, 334>,
      <344, 345, 335>,
      <344, 335, 334>,
      <344, 334, 346>,
      <344, 346, 347>,
      <344, 348, 349>,
      <344, 349, 350>,
      <344, 351, 352>,
      <344, 352, 345>,
      <353, 354, 335>,
      <353, 335, 345>,
      <353, 345, 355>,
      <353, 355, 356>,
      <353, 357, 358>,
      <353, 358, 359>,
      <353, 360, 361>,
      <353, 361, 354>,
      <362, 336, 335>,
      <362, 335, 354>,
      <362, 354, 363>,
      <362, 363, 364>,
      <362, 365, 366>,
      <362, 366, 367>,
      <362, 368, 369>,
      <362, 369, 336>,
      <370, 371, 372>,
      <370, 372, 373>,
      <370, 373, 374>,
      <370, 374, 375>,
      <370, 376, 377>,
      <370, 377, 378>,
      <370, 379, 380>,
      <370, 380, 371>,
      <381, 382, 372>,
      <381, 372, 371>,
      <381, 371, 383>,
      <381, 383, 384>,
      <381, 385, 386>,
      <381, 386, 387>,
      <381, 388, 389>,
      <381, 389, 382>,
      <390, 391, 372>,
      <390, 372, 382>,
      <390, 382, 392>,
      <390, 392, 393>,
      <390, 394, 395>,
      <390, 395, 396>,
      <390, 396, 397>,
      <390, 397, 391>,
      <398, 373, 372>,
      <398, 372, 391>,
      <398, 391, 397>,
      <398, 397, 399>,
      <398, 399, 400>,
      <398, 400, 401>,
      <398, 402, 403>,
      <398, 403, 373>,
      <404, 405, 406>,
      <404, 406, 407>,
      <404, 407, 408>,
      <404, 408, 409>,
      <404, 410, 411>,
      <404, 411, 412>,
      <404, 413, 414>,
      <404, 414, 405>,
      <415, 416, 406>,
      <415, 406, 405>,
      <415, 405, 417>,
      <415, 417, 418>,
      <415, 419, 420>,
      <415, 420, 421>,
      <415, 422, 423>,
      <415, 423, 416>,
      <424, 425, 406>,
      <424, 406, 416>,
      <424, 416, 426>,
      <424, 426, 427>,
      <424, 428, 429>,
      <424, 429, 430>,
      <424, 430, 431>,
      <424, 431, 425>,
      <432, 407, 406>,
      <432, 406, 425>,
      <432, 425, 431>,
      <432, 431, 433>,
      <432, 433, 434>,
      <432, 434, 435>,
      <432, 436, 437>,
      <432, 437, 407>,
      <438, 439, 440>,
      <438, 440, 441>,
      <438, 441, 442>,
      <438, 442, 443>,
      <438, 444, 445>,
      <438, 445, 446>,
      <438, 447, 448>,
      <438, 448, 439>,
      <449, 450, 440>,
      <449, 440, 439>,
      <449, 439, 451>,
      <449, 451, 452>,
      <449, 453, 454>,
      <449, 454, 455>,
      <449, 456, 457>,
      <449, 457, 450>,
      <458, 459, 440>,
      <458, 440, 450>,
      <458, 450, 460>,
      <458, 460, 461>,
      <458, 462, 463>,
      <458, 463, 464>,
      <458, 464, 465>,
      <458, 465, 459>,
      <466, 441, 440>,
      <466, 440, 459>,
      <466, 459, 465>,
      <466, 465, 467>,
      <466, 467, 468>,
      <466, 468, 469>,
      <466, 470, 471>,
      <466, 471, 441>,
      <472, 473, 474>,
      <472, 474, 475>,
      <472, 475, 476>,
      <472, 476, 477>,
      <472, 478, 479>,
      <472, 479, 399>,
      <472, 399, 397>,
      <472, 397, 473>,
      <480, 481, 474>,
      <480, 474, 473>,
      <480, 473, 397>,
      <480, 397, 396>,
      <480, 396, 482>,
      <480, 482, 483>,
      <480, 484, 485>,
      <480, 485, 481>,
      <486, 487, 474>,
      <486, 474, 481>,
      <486, 481, 488>,
      <486, 488, 489>,
      <486, 490, 491>,
      <486, 491, 492>,
      <486, 492, 493>,
      <486, 493, 487>,
      <494, 475, 474>,
      <494, 474, 487>,
      <494, 487, 493>,
      <494, 493, 495>,
      <494, 495, 496>,
      <494, 496, 497>,
      <494, 498, 499>,
      <494, 499, 475>,
      <500, 501, 502>,
      <500, 502, 503>,
      <500, 503, 504>,
      <500, 504, 505>,
      <500, 506, 507>,
      <500, 507, 433>,
      <500, 433, 431>,
      <500, 431, 501>,
      <508, 509, 502>,
      <508, 502, 501>,
      <508, 501, 431>,
      <508, 431, 430>,
      <508, 430, 510>,
      <508, 510, 511>,
      <508, 512, 513>,
      <508, 513, 509>,
      <514, 515, 502>,
      <514, 502, 509>,
      <514, 509, 516>,
      <514, 516, 517>,
      <514, 518, 519>,
      <514, 519, 520>,
      <514, 520, 521>,
      <514, 521, 515>,
      <522, 503, 502>,
      <522, 502, 515>,
      <522, 515, 521>,
      <522, 521, 523>,
      <522, 523, 524>,
      <522, 524, 525>,
      <522, 526, 527>,
      <522, 527, 503>,
      <528, 529, 530>,
      <528, 530, 531>,
      <528, 531, 532>,
      <528, 532, 533>,
      <528, 534, 535>,
      <528, 535, 467>,
      <528, 467, 465>,
      <528, 465, 529>,
      <536, 537, 530>,
      <536, 530, 529>,
      <536, 529, 465>,
      <536, 465, 464>,
      <536, 464, 538>,
      <536, 538, 539>,
      <536, 540, 541>,
      <536, 541, 537>,
      <542, 543, 530>,
      <542, 530, 537>,
      <542, 537, 544>,
      <542, 544, 545>,
      <542, 546, 547>,
      <542, 547, 548>,
      <542, 548, 549>,
      <542, 549, 543>,
      <550, 531, 530>,
      <550, 530, 543>,
      <550, 543, 549>,
      <550, 549, 551>,
      <550, 551, 552>,
      <550, 552, 553>,
      <550, 554, 555>,
      <550, 555, 531>,
      <556, 557, 558>,
      <556, 558, 559>,
      <556, 559, 560>,
      <556, 560, 561>,
      <556, 562, 563>,
      <556, 563, 495>,
      <556, 495, 493>,
      <556, 493, 557>,
      <564, 565, 558>,
      <564, 558, 557>,
      <564, 557, 493>,
      <564, 493, 492>,
      <564, 492, 566>,
      <564, 566, 567>,
      <564, 568, 569>,
      <564, 569, 565>,
      <570, 571, 558>,
      <570, 558, 565>,
      <570, 565, 572>,
      <570, 572, 573>,
      <570, 574, 575>,
      <570, 575, 576>,
      <570, 577, 578>,
      <570, 578, 571>,
      <579, 559, 558>,
      <579, 558, 571>,
      <579, 571, 580>,
      <579, 580, 581>,
      <579, 582, 583>,
      <579, 583, 584>,
      <579, 585, 586>,
      <579, 586, 559>,
      <587, 588, 589>,
      <587, 589, 590>,
      <587, 590, 591>,
      <587, 591, 592>,
      <587, 593, 594>,
      <587, 594, 523>,
      <587, 523, 521>,
      <587, 521, 588>,
      <595, 596, 589>,
      <595, 589, 588>,
      <595, 588, 521>,
      <595, 521, 520>,
      <595, 520, 597>,
      <595, 597, 598>,
      <595, 599, 600>,
      <595, 600, 596>,
      <601, 602, 589>,
      <601, 589, 596>,
      <601, 596, 603>,
      <601, 603, 604>,
      <601, 605, 606>,
      <601, 606, 607>,
      <601, 608, 609>,
      <601, 609, 602>,
      <610, 590, 589>,
      <610, 589, 602>,
      <610, 602, 611>,
      <610, 611, 612>,
      <610, 613, 614>,
      <610, 614, 615>,
      <610, 616, 617>,
      <610, 617, 590>,
      <618, 619, 620>,
      <618, 620, 621>,
      <618, 621, 622>,
      <618, 622, 623>,
      <618, 624, 625>,
      <618, 625, 551>,
      <618, 551, 549>,
      <618, 549, 619>,
      <626, 627, 620>,
      <626, 620, 619>,
      <626, 619, 549>,
      <626, 549, 548>,
      <626, 548, 628>,
      <626, 628, 629>,
      <626, 630, 631>,
      <626, 631, 627>,
      <632, 633, 620>,
      <632, 620, 627>,
      <632, 627, 634>,
      <632, 634, 635>,
      <632, 636, 637>,
      <632, 637, 638>,
      <632, 639, 640>,
      <632, 640, 633>,
      <641, 621, 620>,
      <641, 620, 633>,
      <641, 633, 642>,
      <641, 642, 643>,
      <641, 644, 645>,
      <641, 645, 646>,
      <641, 647, 648>,
      <641, 648, 621>,
      <649, 650, 651>,
      <649, 651, 652>,
      <649, 652, 653>,
      <649, 653, 654>,
      <649, 655, 656>,
      <649, 656, 657>,
      <649, 658, 659>,
      <649, 659, 650>,
      <660, 661, 651>,
      <660, 651, 650>,
      <660, 650, 662>,
      <660, 662, 663>,
      <660, 664, 665>,
      <660, 665, 666>,
      <660, 667, 668>,
      <660, 668, 661>,
      <669, 670, 651>,
      <669, 651, 661>,
      <669, 661, 671>,
      <669, 671, 672>,
      <669, 673, 674>,
      <669, 674, 675>,
      <669, 676, 677>,
      <669, 677, 670>,
      <678, 652, 651>,
      <678, 651, 670>,
      <678, 670, 679>,
      <678, 679, 680>,
      <678, 681, 682>,
      <678, 682, 683>,
      <678, 684, 685>,
      <678, 685, 652>,
      <686, 687, 688>,
      <686, 688, 689>,
      <686, 689, 690>,
      <686, 690, 691>,
      <686, 692, 693>,
      <686, 693, 694>,
      <686, 695, 696>,
      <686, 696, 687>,
      <697, 698, 688>,
      <697, 688, 687>,
      <697, 687, 699>,
      <697, 699, 700>,
      <697, 701, 702>,
      <697, 702, 703>,
      <697, 704, 705>,
      <697, 705, 698>,
      <706, 707, 688>,
      <706, 688, 698>,
      <706, 698, 708>,
      <706, 708, 709>,
      <706, 710, 711>,
      <706, 711, 712>,
      <706, 713, 714>,
      <706, 714, 707>,
      <715, 689, 688>,
      <715, 688, 707>,
      <715, 707, 716>,
      <715, 716, 717>,
      <715, 718, 719>,
      <715, 719, 720>,
      <715, 721, 722>,
      <715, 722, 689>,
      <723, 724, 725>,
      <723, 725, 726>,
      <723, 726, 727>,
      <723, 727, 728>,
      <723, 729, 730>,
      <723, 730, 731>,
      <723, 732, 733>,
      <723, 733, 724>,
      <734, 735, 725>,
      <734, 725, 724>,
      <734, 724, 736>,
      <734, 736, 737>,
      <734, 738, 739>,
      <734, 739, 740>,
      <734, 741, 742>,
      <734, 742, 735>,
      <743, 744, 725>,
      <743, 725, 735>,
      <743, 735, 745>,
      <743, 745, 746>,
      <743, 747, 748>,
      <743, 748, 749>,
      <743, 750, 751>,
      <743, 751, 744>,
      <752, 726, 725>,
      <752, 725, 744>,
      <752, 744, 753>,
      <752, 753, 754>,
      <752, 755, 756>,
      <752, 756, 757>,
      <752, 758, 759>,
      <752, 759, 726>,
      <760, 761, 762>,
      <760, 762, 763>,
      <760, 763, 764>,
      <760, 764, 765>,
      <760, 766, 767>,
      <760, 767, 768>,
      <760, 769, 770>,
      <760, 770, 761>,
      <771, 772, 762>,
      <771, 762, 761>,
      <771, 761, 773>,
      <771, 773, 774>,
      <771, 775, 776>,
      <771, 776, 777>,
      <771, 778, 779>,
      <771, 779, 772>,
      <780, 781, 762>,
      <780, 762, 772>,
      <780, 772, 782>,
      <780, 782, 783>,
      <780, 784, 785>,
      <780, 785, 786>,
      <780, 787, 788>,
      <780, 788, 781>,
      <789, 763, 762>,
      <789, 762, 781>,
      <789, 781, 790>,
      <789, 790, 791>,
      <789, 792, 793>,
      <789, 793, 794>,
      <789, 795, 796>,
      <789, 796, 763>,
      <797, 798, 799>,
      <797, 799, 800>,
      <797, 800, 801>,
      <797, 801, 802>,
      <797, 803, 804>,
      <797, 804, 805>,
      <797, 806, 807>,
      <797, 807, 798>,
      <808, 809, 799>,
      <808, 799, 798>,
      <808, 798, 810>,
      <808, 810, 811>,
      <808, 812, 813>,
      <808, 813, 814>,
      <808, 815, 816>,
      <808, 816, 809>,
      <817, 818, 799>,
      <817, 799, 809>,
      <817, 809, 819>,
      <817, 819, 820>,
      <817, 821, 822>,
      <817, 822, 823>,
      <817, 824, 825>,
      <817, 825, 818>,
      <826, 800, 799>,
      <826, 799, 818>,
      <826, 818, 827>,
      <826, 827, 828>,
      <826, 829, 830>,
      <826, 830, 831>,
      <826, 832, 833>,
      <826, 833, 800>,
      <834, 835, 836>,
      <834, 836, 837>,
      <834, 837, 838>,
      <834, 838, 839>,
      <834, 840, 841>,
      <834, 841, 842>,
      <834, 843, 844>,
      <834, 844, 835>,
      <845, 846, 836>,
      <845, 836, 835>,
      <845, 835, 847>,
      <845, 847, 848>,
      <845, 849, 850>,
      <845, 850, 851>,
      <845, 852, 853>,
      <845, 853, 846>,
      <854, 855, 836>,
      <854, 836, 846>,
      <854, 846, 856>,
      <854, 856, 857>,
      <854, 858, 859>,
      <854, 859, 860>,
      <854, 861, 862>,
      <854, 862, 855>,
      <863, 837, 836>,
      <863, 836, 855>,
      <863, 855, 864>,
      <863, 864, 865>,
      <863, 866, 867>,
      <863, 867, 868>,
      <863, 869, 870>,
      <863, 870, 837>,
      <871, 872, 873>,
      <871, 873, 874>,
      <871, 874, 875>,
      <871, 875, 876>,
      <871, 877, 878>,
      <871, 878, 879>,
      <871, 880, 881>,
      <871, 881, 872>,
      <882, 883, 873>,
      <882, 873, 872>,
      <882, 872, 884>,
      <882, 884, 885>,
      <882, 886, 887>,
      <882, 887, 888>,
      <882, 889, 890>,
      <882, 890, 883>,
      <891, 892, 873>,
      <891, 873, 883>,
      <891, 883, 893>,
      <891, 893, 894>,
      <891, 895, 896>,
      <891, 896, 897>,
      <891, 898, 899>,
      <891, 899, 892>,
      <900, 874, 873>,
      <900, 873, 892>,
      <900, 892, 901>,
      <900, 901, 902>,
      <900, 903, 904>,
      <900, 904, 905>,
      <900, 906, 907>,
      <900, 907, 874>,
      <908, 909, 910>,
      <908, 910, 911>,
      <908, 911, 912>,
      <908, 912, 913>,
      <908, 914, 915>,
      <908, 915, 916>,
      <908, 917, 918>,
      <908, 918, 909>,
      <919, 920, 910>,
      <919, 910, 909>,
      <919, 909, 921>,
      <919, 921, 922>,
      <919, 923, 924>,
      <919, 924, 925>,
      <919, 926, 927>,
      <919, 927, 920>,
      <928, 929, 910>,
      <928, 910, 920>,
      <928, 920, 930>,
      <928, 930, 931>,
      <928, 932, 933>,
      <928, 933, 934>,
      <928, 935, 936>,
      <928, 936, 929>,
      <937, 911, 910>,
      <937, 910, 929>,
      <937, 929, 938>,
      <937, 938, 939>,
      <937, 940, 941>,
      <937, 941, 942>,
      <937, 943, 944>,
      <937, 944, 911>,
      <945, 946, 947>,
      <945, 947, 948>,
      <945, 948, 949>,
      <945, 949, 950>,
      <945, 951, 952>,
      <945, 952, 953>,
      <945, 954, 955>,
      <945, 955, 946>,
      <956, 957, 947>,
      <956, 947, 946>,
      <956, 946, 958>,
      <956, 958, 959>,
      <956, 960, 961>,
      <956, 961, 962>,
      <956, 963, 964>,
      <956, 964, 957>,
      <965, 966, 947>,
      <965, 947, 957>,
      <965, 957, 967>,
      <965, 967, 968>,
      <965, 969, 970>,
      <965, 970, 971>,
      <965, 972, 973>,
      <965, 973, 966>,
      <974, 948, 947>,
      <974, 947, 966>,
      <974, 966, 975>,
      <974, 975, 976>,
      <974, 977, 978>,
      <974, 978, 979>,
      <974, 980, 981>,
      <974, 981, 948>,
      <982, 983, 984>,
      <982, 984, 985>,
      <982, 985, 986>,
      <982, 986, 987>,
      <982, 988, 989>,
      <982, 989, 990>,
      <982, 991, 992>,
      <982, 992, 983>,
      <993, 994, 984>,
      <993, 984, 983>,
      <993, 983, 995>,
      <993, 995, 996>,
      <993, 997, 998>,
      <993, 998, 999>,
      <993, 1000, 1001>,
      <993, 1001, 994>,
      <1002, 1003, 984>,
      <1002, 984, 994>,
      <1002, 994, 1004>,
      <1002, 1004, 1005>,
      <1002, 1006, 1007>,
      <1002, 1007, 1008>,
      <1002, 1009, 1010>,
      <1002, 1010, 1003>,
      <1011, 985, 984>,
      <1011, 984, 1003>,
      <1011, 1003, 1012>,
      <1011, 1012, 1013>,
      <1011, 1014, 1015>,
      <1011, 1015, 1016>,
      <1011, 1017, 1018>,
      <1011, 1018, 985>,
      <1019, 1020, 1021>,
      <1019, 1021, 1022>,
      <1019, 1022, 1023>,
      <1019, 1023, 1024>,
      <1019, 1025, 1026>,
      <1019, 1026, 1027>,
      <1019, 1028, 1029>,
      <1019, 1029, 1020>,
      <1030, 1031, 1021>,
      <1030, 1021, 1020>,
      <1030, 1020, 1032>,
      <1030, 1032, 1033>,
      <1030, 1034, 1035>,
      <1030, 1035, 1036>,
      <1030, 1037, 1038>,
      <1030, 1038, 1031>,
      <1039, 1040, 1021>,
      <1039, 1021, 1031>,
      <1039, 1031, 1041>,
      <1039, 1041, 1042>,
      <1039, 1043, 1044>,
      <1039, 1044, 1045>,
      <1039, 1046, 1047>,
      <1039, 1047, 1040>,
      <1048, 1022, 1021>,
      <1048, 1021, 1040>,
      <1048, 1040, 1049>,
      <1048, 1049, 1050>,
      <1048, 1051, 1052>,
      <1048, 1052, 1053>,
      <1048, 1054, 1055>,
      <1048, 1055, 1022>,
      <1056, 1057, 1058>,
      <1056, 1058, 1059>,
      <1056, 1059, 1060>,
      <1056, 1060, 1061>,
      <1056, 1062, 1063>,
      <1056, 1063, 1064>,
      <1056, 1065, 1066>,
      <1056, 1066, 1057>,
      <1067, 1068, 1058>,
      <1067, 1058, 1057>,
      <1067, 1057, 1069>,
      <1067, 1069, 1070>,
      <1067, 1071, 1072>,
      <1067, 1072, 1073>,
      <1067, 1074, 1075>,
      <1067, 1075, 1068>,
      <1076, 1077, 1058>,
      <1076, 1058, 1068>,
      <1076, 1068, 1078>,
      <1076, 1078, 1079>,
      <1076, 1080, 1081>,
      <1076, 1081, 1082>,
      <1076, 1083, 1084>,
      <1076, 1084, 1077>,
      <1085, 1059, 1058>,
      <1085, 1058, 1077>,
      <1085, 1077, 1086>,
      <1085, 1086, 1087>,
      <1085, 1088, 1089>,
      <1085, 1089, 1090>,
      <1085, 1091, 1092>,
      <1085, 1092, 1059>,
      <1093, 1094, 1095>,
      <1093, 1095, 1096>,
      <1093, 1096, 1097>,
      <1093, 1097, 1098>,
      <1093, 1099, 1100>,
      <1093, 1100, 1101>,
      <1093, 1101, 1102>,
      <1093, 1102, 1094>,
      <1103, 1104, 1095>,
      <1103, 1095, 1094>,
      <1103, 1094, 1102>,
      <1103, 1102, 1105>,
      <1103, 1105, 1106>,
      <1103, 1106, 1107>,
      <1103, 1108, 1109>,
      <1103, 1109, 1104>,
      <1110, 1111, 1095>,
      <1110, 1095, 1104>,
      <1110, 1104, 1112>,
      <1110, 1112, 1113>,
      <1110, 1114, 1115>,
      <1110, 1115, 1116>,
      <1110, 1117, 1118>,
      <1110, 1118, 1111>,
      <1119, 1096, 1095>,
      <1119, 1095, 1111>,
      <1119, 1111, 1120>,
      <1119, 1120, 1121>,
      <1119, 1122, 1123>,
      <1119, 1123, 1124>,
      <1119, 1125, 1126>,
      <1119, 1126, 1096>,
      <1127, 1128, 1129>,
      <1127, 1129, 1130>,
      <1127, 1130, 1102>,
      <1127, 1102, 1101>,
      <1127, 1101, 1131>,
      <1127, 1131, 1132>,
      <1127, 1133, 1134>,
      <1127, 1134, 1128>,
      <1135, 1136, 1129>,
      <1135, 1129, 1128>,
      <1135, 1128, 1137>,
      <1135, 1137, 1138>,
      <1135, 1139, 1140>,
      <1135, 1140, 1141>,
      <1135, 1142, 1143>,
      <1135, 1143, 1136>,
      <1144, 1145, 1129>,
      <1144, 1129, 1136>,
      <1144, 1136, 1146>,
      <1144, 1146, 1147>,
      <1144, 1148, 1149>,
      <1144, 1149, 1150>,
      <1144, 1151, 1152>,
      <1144, 1152, 1145>,
      <1153, 1130, 1129>,
      <1153, 1129, 1145>,
      <1153, 1145, 1154>,
      <1153, 1154, 1155>,
      <1153, 1156, 1157>,
      <1153, 1157, 1105>,
      <1153, 1105, 1102>,
      <1153, 1102, 1130>
    }
    uv_indices {
      1056,   // from 0 triangles and 528 quads
      <569, 577, 570>,
      <569, 570, 574>      <569, 574, 571>,
      <569, 571, 575>      <569, 575, 572>,
      <569, 572, 576>      <569, 576, 573>,
      <569, 573, 577>      <578, 586, 579>,
      <578, 579, 583>      <578, 583, 580>,
      <578, 580, 584>      <578, 584, 581>,
      <578, 581, 585>      <578, 585, 582>,
      <578, 582, 586>      <587, 595, 588>,
      <587, 588, 592>      <587, 592, 589>,
      <587, 589, 593>      <587, 593, 590>,
      <587, 590, 594>      <587, 594, 591>,
      <587, 591, 595>      <596, 604, 597>,
      <596, 597, 601>      <596, 601, 598>,
      <596, 598, 602>      <596, 602, 599>,
      <596, 599, 603>      <596, 603, 600>,
      <596, 600, 604>      <605, 613, 606>,
      <605, 606, 610>      <605, 610, 607>,
      <605, 607, 611>      <605, 611, 608>,
      <605, 608, 612>      <605, 612, 609>,
      <605, 609, 613>      <614, 622, 615>,
      <614, 615, 619>      <614, 619, 616>,
      <614, 616, 620>      <614, 620, 617>,
      <614, 617, 621>      <614, 621, 618>,
      <614, 618, 622>      <623, 631, 624>,
      <623, 624, 628>      <623, 628, 625>,
      <623, 625, 629>      <623, 629, 626>,
      <623, 626, 630>      <623, 630, 627>,
      <623, 627, 631>      <632, 640, 633>,
      <632, 633, 637>      <632, 637, 634>,
      <632, 634, 638>      <632, 638, 635>,
      <632, 635, 639>      <632, 639, 636>,
      <632, 636, 640>      <641, 649, 642>,
      <641, 642, 646>      <641, 646, 643>,
      <641, 643, 647>      <641, 647, 644>,
      <641, 644, 648>      <641, 648, 645>,
      <641, 645, 649>      <650, 658, 651>,
      <650, 651, 655>      <650, 655, 652>,
      <650, 652, 656>      <650, 656, 653>,
      <650, 653, 657>      <650, 657, 654>,
      <650, 654, 658>      <659, 667, 660>,
      <659, 660, 664>      <659, 664, 661>,
      <659, 661, 665>      <659, 665, 662>,
      <659, 662, 666>      <659, 666, 663>,
      <659, 663, 667>      <668, 676, 669>,
      <668, 669, 673>      <668, 673, 670>,
      <668, 670, 674>      <668, 674, 671>,
      <668, 671, 675>      <668, 675, 672>,
      <668, 672, 676>      <677, 685, 678>,
      <677, 678, 682>      <677, 682, 679>,
      <677, 679, 683>      <677, 683, 680>,
      <677, 680, 684>      <677, 684, 681>,
      <677, 681, 685>      <686, 694, 687>,
      <686, 687, 691>      <686, 691, 688>,
      <686, 688, 692>      <686, 692, 689>,
      <686, 689, 693>      <686, 693, 690>,
      <686, 690, 694>      <695, 703, 696>,
      <695, 696, 700>      <695, 700, 697>,
      <695, 697, 701>      <695, 701, 698>,
      <695, 698, 702>      <695, 702, 699>,
      <695, 699, 703>      <704, 712, 705>,
      <704, 705, 709>      <704, 709, 706>,
      <704, 706, 710>      <704, 710, 707>,
      <704, 707, 711>      <704, 711, 708>,
      <704, 708, 712>      <713, 721, 714>,
      <713, 714, 718>      <713, 718, 715>,
      <713, 715, 719>      <713, 719, 716>,
      <713, 716, 720>      <713, 720, 717>,
      <713, 717, 721>      <722, 730, 723>,
      <722, 723, 727>      <722, 727, 724>,
      <722, 724, 728>      <722, 728, 725>,
      <722, 725, 729>      <722, 729, 726>,
      <722, 726, 730>      <731, 739, 732>,
      <731, 732, 736>      <731, 736, 733>,
      <731, 733, 737>      <731, 737, 734>,
      <731, 734, 738>      <731, 738, 735>,
      <731, 735, 739>      <740, 748, 741>,
      <740, 741, 745>      <740, 745, 742>,
      <740, 742, 746>      <740, 746, 743>,
      <740, 743, 747>      <740, 747, 744>,
      <740, 744, 748>      <749, 757, 750>,
      <749, 750, 754>      <749, 754, 751>,
      <749, 751, 755>      <749, 755, 752>,
      <749, 752, 756>      <749, 756, 753>,
      <749, 753, 757>      <758, 766, 759>,
      <758, 759, 763>      <758, 763, 760>,
      <758, 760, 764>      <758, 764, 761>,
      <758, 761, 765>      <758, 765, 762>,
      <758, 762, 766>      <767, 775, 768>,
      <767, 768, 772>      <767, 772, 769>,
      <767, 769, 773>      <767, 773, 770>,
      <767, 770, 774>      <767, 774, 771>,
      <767, 771, 775>      <776, 784, 777>,
      <776, 777, 781>      <776, 781, 778>,
      <776, 778, 782>      <776, 782, 779>,
      <776, 779, 783>      <776, 783, 780>,
      <776, 780, 784>      <785, 793, 786>,
      <785, 786, 790>      <785, 790, 787>,
      <785, 787, 791>      <785, 791, 788>,
      <785, 788, 792>      <785, 792, 789>,
      <785, 789, 793>      <794, 802, 795>,
      <794, 795, 799>      <794, 799, 796>,
      <794, 796, 800>      <794, 800, 797>,
      <794, 797, 801>      <794, 801, 798>,
      <794, 798, 802>      <803, 811, 804>,
      <803, 804, 808>      <803, 808, 805>,
      <803, 805, 809>      <803, 809, 806>,
      <803, 806, 810>      <803, 810, 807>,
      <803, 807, 811>      <812, 820, 813>,
      <812, 813, 817>      <812, 817, 814>,
      <812, 814, 818>      <812, 818, 815>,
      <812, 815, 819>      <812, 819, 816>,
      <812, 816, 820>      <821, 829, 822>,
      <821, 822, 826>      <821, 826, 823>,
      <821, 823, 827>      <821, 827, 824>,
      <821, 824, 828>      <821, 828, 825>,
      <821, 825, 829>      <830, 838, 831>,
      <830, 831, 835>      <830, 835, 832>,
      <830, 832, 836>      <830, 836, 833>,
      <830, 833, 837>      <830, 837, 834>,
      <830, 834, 838>      <839, 847, 840>,
      <839, 840, 844>      <839, 844, 841>,
      <839, 841, 845>      <839, 845, 842>,
      <839, 842, 846>      <839, 846, 843>,
      <839, 843, 847>      <848, 856, 849>,
      <848, 849, 853>      <848, 853, 850>,
      <848, 850, 854>      <848, 854, 851>,
      <848, 851, 855>      <848, 855, 852>,
      <848, 852, 856>      <857, 865, 858>,
      <857, 858, 862>      <857, 862, 859>,
      <857, 859, 863>      <857, 863, 860>,
      <857, 860, 864>      <857, 864, 861>,
      <857, 861, 865>      <866, 874, 867>,
      <866, 867, 871>      <866, 871, 868>,
      <866, 868, 872>      <866, 872, 869>,
      <866, 869, 873>      <866, 873, 870>,
      <866, 870, 874>      <875, 883, 876>,
      <875, 876, 880>      <875, 880, 877>,
      <875, 877, 881>      <875, 881, 878>,
      <875, 878, 882>      <875, 882, 879>,
      <875, 879, 883>      <884, 892, 885>,
      <884, 885, 889>      <884, 889, 886>,
      <884, 886, 890>      <884, 890, 887>,
      <884, 887, 891>      <884, 891, 888>,
      <884, 888, 892>      <893, 901, 894>,
      <893, 894, 898>      <893, 898, 895>,
      <893, 895, 899>      <893, 899, 896>,
      <893, 896, 900>      <893, 900, 897>,
      <893, 897, 901>      <902, 910, 903>,
      <902, 903, 907>      <902, 907, 904>,
      <902, 904, 908>      <902, 908, 905>,
      <902, 905, 909>      <902, 909, 906>,
      <902, 906, 910>      <911, 919, 912>,
      <911, 912, 916>      <911, 916, 913>,
      <911, 913, 917>      <911, 917, 914>,
      <911, 914, 918>      <911, 918, 915>,
      <911, 915, 919>      <920, 928, 921>,
      <920, 921, 925>      <920, 925, 922>,
      <920, 922, 926>      <920, 926, 923>,
      <920, 923, 927>      <920, 927, 924>,
      <920, 924, 928>      <929, 937, 930>,
      <929, 930, 934>      <929, 934, 931>,
      <929, 931, 935>      <929, 935, 932>,
      <929, 932, 936>      <929, 936, 933>,
      <929, 933, 937>      <938, 946, 939>,
      <938, 939, 943>      <938, 943, 940>,
      <938, 940, 944>      <938, 944, 941>,
      <938, 941, 945>      <938, 945, 942>,
      <938, 942, 946>      <947, 955, 948>,
      <947, 948, 952>      <947, 952, 949>,
      <947, 949, 953>      <947, 953, 950>,
      <947, 950, 954>      <947, 954, 951>,
      <947, 951, 955>      <956, 964, 957>,
      <956, 957, 961>      <956, 961, 958>,
      <956, 958, 962>      <956, 962, 959>,
      <956, 959, 963>      <956, 963, 960>,
      <956, 960, 964>      <965, 973, 966>,
      <965, 966, 970>      <965, 970, 967>,
      <965, 967, 971>      <965, 971, 968>,
      <965, 968, 972>      <965, 972, 969>,
      <965, 969, 973>      <974, 982, 975>,
      <974, 975, 979>      <974, 979, 976>,
      <974, 976, 980>      <974, 980, 977>,
      <974, 977, 981>      <974, 981, 978>,
      <974, 978, 982>      <983, 991, 984>,
      <983, 984, 988>      <983, 988, 985>,
      <983, 985, 989>      <983, 989, 986>,
      <983, 986, 990>      <983, 990, 987>,
      <983, 987, 991>      <992, 1000, 993>,
      <992, 993, 997>      <992, 997, 994>,
      <992, 994, 998>      <992, 998, 995>,
      <992, 995, 999>      <992, 999, 996>,
      <992, 996, 1000>      <1001, 1009, 1002>,
      <1001, 1002, 1006>      <1001, 1006, 1003>,
      <1001, 1003, 1007>      <1001, 1007, 1004>,
      <1001, 1004, 1008>      <1001, 1008, 1005>,
      <1001, 1005, 1009>      <1010, 1018, 1011>,
      <1010, 1011, 1015>      <1010, 1015, 1012>,
      <1010, 1012, 1016>      <1010, 1016, 1013>,
      <1010, 1013, 1017>      <1010, 1017, 1014>,
      <1010, 1014, 1018>      <1019, 1027, 1020>,
      <1019, 1020, 1024>      <1019, 1024, 1021>,
      <1019, 1021, 1025>      <1019, 1025, 1022>,
      <1019, 1022, 1026>      <1019, 1026, 1023>,
      <1019, 1023, 1027>      <1028, 1036, 1029>,
      <1028, 1029, 1033>      <1028, 1033, 1030>,
      <1028, 1030, 1034>      <1028, 1034, 1031>,
      <1028, 1031, 1035>      <1028, 1035, 1032>,
      <1028, 1032, 1036>      <1037, 1045, 1038>,
      <1037, 1038, 1042>      <1037, 1042, 1039>,
      <1037, 1039, 1043>      <1037, 1043, 1040>,
      <1037, 1040, 1044>      <1037, 1044, 1041>,
      <1037, 1041, 1045>      <1046, 1054, 1047>,
      <1046, 1047, 1051>      <1046, 1051, 1048>,
      <1046, 1048, 1052>      <1046, 1052, 1049>,
      <1046, 1049, 1053>      <1046, 1053, 1050>,
      <1046, 1050, 1054>      <1055, 1063, 1056>,
      <1055, 1056, 1060>      <1055, 1060, 1057>,
      <1055, 1057, 1061>      <1055, 1061, 1058>,
      <1055, 1058, 1062>      <1055, 1062, 1059>,
      <1055, 1059, 1063>      <1064, 1072, 1065>,
      <1064, 1065, 1069>      <1064, 1069, 1066>,
      <1064, 1066, 1070>      <1064, 1070, 1067>,
      <1064, 1067, 1071>      <1064, 1071, 1068>,
      <1064, 1068, 1072>      <1073, 1081, 1074>,
      <1073, 1074, 1078>      <1073, 1078, 1075>,
      <1073, 1075, 1079>      <1073, 1079, 1076>,
      <1073, 1076, 1080>      <1073, 1080, 1077>,
      <1073, 1077, 1081>      <1082, 1090, 1083>,
      <1082, 1083, 1087>      <1082, 1087, 1084>,
      <1082, 1084, 1088>      <1082, 1088, 1085>,
      <1082, 1085, 1089>      <1082, 1089, 1086>,
      <1082, 1086, 1090>      <1091, 1099, 1092>,
      <1091, 1092, 1096>      <1091, 1096, 1093>,
      <1091, 1093, 1097>      <1091, 1097, 1094>,
      <1091, 1094, 1098>      <1091, 1098, 1095>,
      <1091, 1095, 1099>      <1100, 1108, 1101>,
      <1100, 1101, 1105>      <1100, 1105, 1102>,
      <1100, 1102, 1106>      <1100, 1106, 1103>,
      <1100, 1103, 1107>      <1100, 1107, 1104>,
      <1100, 1104, 1108>      <1109, 1117, 1110>,
      <1109, 1110, 1114>      <1109, 1114, 1111>,
      <1109, 1111, 1115>      <1109, 1115, 1112>,
      <1109, 1112, 1116>      <1109, 1116, 1113>,
      <1109, 1113, 1117>      <1118, 1126, 1119>,
      <1118, 1119, 1123>      <1118, 1123, 1120>,
      <1118, 1120, 1124>      <1118, 1124, 1121>,
      <1118, 1121, 1125>      <1118, 1125, 1122>,
      <1118, 1122, 1126>      <1127, 1135, 1128>,
      <1127, 1128, 1132>      <1127, 1132, 1129>,
      <1127, 1129, 1133>      <1127, 1133, 1130>,
      <1127, 1130, 1134>      <1127, 1134, 1131>,
      <1127, 1131, 1135>      <1136, 1144, 1137>,
      <1136, 1137, 1141>      <1136, 1141, 1138>,
      <1136, 1138, 1142>      <1136, 1142, 1139>,
      <1136, 1139, 1143>      <1136, 1143, 1140>,
      <1136, 1140, 1144>      <1145, 1153, 1146>,
      <1145, 1146, 1150>      <1145, 1150, 1147>,
      <1145, 1147, 1151>      <1145, 1151, 1148>,
      <1145, 1148, 1152>      <1145, 1152, 1149>,
      <1145, 1149, 1153>      <1154, 1162, 1155>,
      <1154, 1155, 1159>      <1154, 1159, 1156>,
      <1154, 1156, 1160>      <1154, 1160, 1157>,
      <1154, 1157, 1161>      <1154, 1161, 1158>,
      <1154, 1158, 1162>      <1163, 1171, 1164>,
      <1163, 1164, 1168>      <1163, 1168, 1165>,
      <1163, 1165, 1169>      <1163, 1169, 1166>,
      <1163, 1166, 1170>      <1163, 1170, 1167>,
      <1163, 1167, 1171>      <1172, 1180, 1173>,
      <1172, 1173, 1177>      <1172, 1177, 1174>,
      <1172, 1174, 1178>      <1172, 1178, 1175>,
      <1172, 1175, 1179>      <1172, 1179, 1176>,
      <1172, 1176, 1180>      <1181, 1189, 1182>,
      <1181, 1182, 1186>      <1181, 1186, 1183>,
      <1181, 1183, 1187>      <1181, 1187, 1184>,
      <1181, 1184, 1188>      <1181, 1188, 1185>,
      <1181, 1185, 1189>      <1190, 1198, 1191>,
      <1190, 1191, 1195>      <1190, 1195, 1192>,
      <1190, 1192, 1196>      <1190, 1196, 1193>,
      <1190, 1193, 1197>      <1190, 1197, 1194>,
      <1190, 1194, 1198>      <1199, 1207, 1200>,
      <1199, 1200, 1204>      <1199, 1204, 1201>,
      <1199, 1201, 1205>      <1199, 1205, 1202>,
      <1199, 1202, 1206>      <1199, 1206, 1203>,
      <1199, 1203, 1207>      <1208, 1216, 1209>,
      <1208, 1209, 1213>      <1208, 1213, 1210>,
      <1208, 1210, 1214>      <1208, 1214, 1211>,
      <1208, 1211, 1215>      <1208, 1215, 1212>,
      <1208, 1212, 1216>      <1217, 1225, 1218>,
      <1217, 1218, 1222>      <1217, 1222, 1219>,
      <1217, 1219, 1223>      <1217, 1223, 1220>,
      <1217, 1220, 1224>      <1217, 1224, 1221>,
      <1217, 1221, 1225>      <1226, 1234, 1227>,
      <1226, 1227, 1231>      <1226, 1231, 1228>,
      <1226, 1228, 1232>      <1226, 1232, 1229>,
      <1226, 1229, 1233>      <1226, 1233, 1230>,
      <1226, 1230, 1234>      <1235, 1243, 1236>,
      <1235, 1236, 1240>      <1235, 1240, 1237>,
      <1235, 1237, 1241>      <1235, 1241, 1238>,
      <1235, 1238, 1242>      <1235, 1242, 1239>,
      <1235, 1239, 1243>      <1244, 1252, 1245>,
      <1244, 1245, 1249>      <1244, 1249, 1246>,
      <1244, 1246, 1250>      <1244, 1250, 1247>,
      <1244, 1247, 1251>      <1244, 1251, 1248>,
      <1244, 1248, 1252>      <1253, 1261, 1254>,
      <1253, 1254, 1258>      <1253, 1258, 1255>,
      <1253, 1255, 1259>      <1253, 1259, 1256>,
      <1253, 1256, 1260>      <1253, 1260, 1257>,
      <1253, 1257, 1261>      <1262, 1270, 1263>,
      <1262, 1263, 1267>      <1262, 1267, 1264>,
      <1262, 1264, 1268>      <1262, 1268, 1265>,
      <1262, 1265, 1269>      <1262, 1269, 1266>,
      <1262, 1266, 1270>      <1271, 1279, 1272>,
      <1271, 1272, 1276>      <1271, 1276, 1273>,
      <1271, 1273, 1277>      <1271, 1277, 1274>,
      <1271, 1274, 1278>      <1271, 1278, 1275>,
      <1271, 1275, 1279>      <1280, 1288, 1281>,
      <1280, 1281, 1285>      <1280, 1285, 1282>,
      <1280, 1282, 1286>      <1280, 1286, 1283>,
      <1280, 1283, 1287>      <1280, 1287, 1284>,
      <1280, 1284, 1288>      <1289, 1297, 1290>,
      <1289, 1290, 1294>      <1289, 1294, 1291>,
      <1289, 1291, 1295>      <1289, 1295, 1292>,
      <1289, 1292, 1296>      <1289, 1296, 1293>,
      <1289, 1293, 1297>      <1298, 1306, 1299>,
      <1298, 1299, 1303>      <1298, 1303, 1300>,
      <1298, 1300, 1304>      <1298, 1304, 1301>,
      <1298, 1301, 1305>      <1298, 1305, 1302>,
      <1298, 1302, 1306>      <1307, 1315, 1308>,
      <1307, 1308, 1312>      <1307, 1312, 1309>,
      <1307, 1309, 1313>      <1307, 1313, 1310>,
      <1307, 1310, 1314>      <1307, 1314, 1311>,
      <1307, 1311, 1315>      <1316, 1324, 1317>,
      <1316, 1317, 1321>      <1316, 1321, 1318>,
      <1316, 1318, 1322>      <1316, 1322, 1319>,
      <1316, 1319, 1323>      <1316, 1323, 1320>,
      <1316, 1320, 1324>      <1325, 1333, 1326>,
      <1325, 1326, 1330>      <1325, 1330, 1327>,
      <1325, 1327, 1331>      <1325, 1331, 1328>,
      <1325, 1328, 1332>      <1325, 1332, 1329>,
      <1325, 1329, 1333>      <1334, 1342, 1335>,
      <1334, 1335, 1339>      <1334, 1339, 1336>,
      <1334, 1336, 1340>      <1334, 1340, 1337>,
      <1334, 1337, 1341>      <1334, 1341, 1338>,
      <1334, 1338, 1342>      <1343, 1351, 1344>,
      <1343, 1344, 1348>      <1343, 1348, 1345>,
      <1343, 1345, 1349>      <1343, 1349, 1346>,
      <1343, 1346, 1350>      <1343, 1350, 1347>,
      <1343, 1347, 1351>      <1352, 1360, 1353>,
      <1352, 1353, 1357>      <1352, 1357, 1354>,
      <1352, 1354, 1358>      <1352, 1358, 1355>,
      <1352, 1355, 1359>      <1352, 1359, 1356>,
      <1352, 1356, 1360>      <1361, 1369, 1362>,
      <1361, 1362, 1366>      <1361, 1366, 1363>,
      <1361, 1363, 1367>      <1361, 1367, 1364>,
      <1361, 1364, 1368>      <1361, 1368, 1365>,
      <1361, 1365, 1369>      <1370, 1378, 1371>,
      <1370, 1371, 1375>      <1370, 1375, 1372>,
      <1370, 1372, 1376>      <1370, 1376, 1373>,
      <1370, 1373, 1377>      <1370, 1377, 1374>,
      <1370, 1374, 1378>      <1379, 1387, 1380>,
      <1379, 1380, 1384>      <1379, 1384, 1381>,
      <1379, 1381, 1385>      <1379, 1385, 1382>,
      <1379, 1382, 1386>      <1379, 1386, 1383>,
      <1379, 1383, 1387>      <1388, 1396, 1389>,
      <1388, 1389, 1393>      <1388, 1393, 1390>,
      <1388, 1390, 1394>      <1388, 1394, 1391>,
      <1388, 1391, 1395>      <1388, 1395, 1392>,
      <1388, 1392, 1396>      <1397, 1405, 1398>,
      <1397, 1398, 1402>      <1397, 1402, 1399>,
      <1397, 1399, 1403>      <1397, 1403, 1400>,
      <1397, 1400, 1404>      <1397, 1404, 1401>,
      <1397, 1401, 1405>      <1406, 1414, 1407>,
      <1406, 1407, 1411>      <1406, 1411, 1408>,
      <1406, 1408, 1412>      <1406, 1412, 1409>,
      <1406, 1409, 1413>      <1406, 1413, 1410>,
      <1406, 1410, 1414>      <1415, 1423, 1416>,
      <1415, 1416, 1420>      <1415, 1420, 1417>,
      <1415, 1417, 1421>      <1415, 1421, 1418>,
      <1415, 1418, 1422>      <1415, 1422, 1419>,
      <1415, 1419, 1423>      <1424, 1432, 1425>,
      <1424, 1425, 1429>      <1424, 1429, 1426>,
      <1424, 1426, 1430>      <1424, 1430, 1427>,
      <1424, 1427, 1431>      <1424, 1431, 1428>,
      <1424, 1428, 1432>      <1433, 1441, 1434>,
      <1433, 1434, 1438>      <1433, 1438, 1435>,
      <1433, 1435, 1439>      <1433, 1439, 1436>,
      <1433, 1436, 1440>      <1433, 1440, 1437>,
      <1433, 1437, 1441>      <1442, 1450, 1443>,
      <1442, 1443, 1447>      <1442, 1447, 1444>,
      <1442, 1444, 1448>      <1442, 1448, 1445>,
      <1442, 1445, 1449>      <1442, 1449, 1446>,
      <1442, 1446, 1450>      <1451, 1459, 1452>,
      <1451, 1452, 1456>      <1451, 1456, 1453>,
      <1451, 1453, 1457>      <1451, 1457, 1454>,
      <1451, 1454, 1458>      <1451, 1458, 1455>,
      <1451, 1455, 1459>      <1460, 1468, 1461>,
      <1460, 1461, 1465>      <1460, 1465, 1462>,
      <1460, 1462, 1466>      <1460, 1466, 1463>,
      <1460, 1463, 1467>      <1460, 1467, 1464>,
      <1460, 1464, 1468>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>      <0, 0, 0>,
      <0, 0, 0>
    }
    translate  <0.0, 0.0, 0.0>
    translate  <-0.00388, -0.010346, 0.0>
}



#declare Montant = union {
  box { // Cube047
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    scale <0.05, 0.05, 1.030942>
    translate  <-0.021841, 0.02, -0.014561>
  }
  box { // Cube048
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    scale <0.06, 0.02, 1.030942>
    translate  <-0.021841, 0.0, -0.014561>
  }
  rotate -0.0*y
  translate  <-0.294623, 0.0, 0.249524>
}
#declare Montant2 = object {
  object { // Montant2 -> Montant
    Montant
    // Montant2 does not inherit transformations, so do 
    // inverse transformations of Montant
      translate  <0.294623, 0.0, -0.249524>
      rotate 0.0*y
    // Now write the regular transformations of Montant2
    scale <1.0, 1.0, 0.58847>
    rotate -90.0*y
    translate  <0.308493, 0.0, 0.227878>
  }
}
#declare Dormant = union {
  object { Montant }
  object { // Montant1 -> Montant
    Montant
    scale <-1.0, 1.0, 1.0>
  }
  object { Montant2 }
  object { // Montant3 -> Montant2
    Montant2
    scale <1.0, 1.0, -1.0>
    translate  1.493887*z
  }
  material {
    T_peinture_Bois
  }
}
#declare Cube049 = object {
  box { // Cube049
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    scale <0.04, 0.02, 0.978939>
    translate  <-0.264902, 0.0, 0.257401>
  }
}
#declare Cube051 = object {
  box { // Cube051
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    scale <0.04, 0.02, 0.186177>
    rotate 90.0*y
    translate  <-0.225896, 0.0, 1.236381>
  }
}
#declare TransSweep001 = prism {
  linear_sweep
  cubic_spline
  -0.254,0.0
  10  // control points
  <-0.295423, 0.024141>,
  <-0.283615, 0.007071>,
  <-0.277961, -0.010756>,
  <-0.267287, -0.013866>,
  <-0.267287, -0.006713>,
  <-0.267287, 0.023709>,
  <-0.270397, 0.023519>,
  <-0.295423, 0.024141>,
  <-0.283615, 0.007071>,
  <-0.277961, -0.010756>
  rotate -x*90
  rotate 90.0*y
  translate  <-0.254743, -0.023427, 0.0>
}
#declare Battant1 = union {
  object { Cube049 }
  object { // Cube050 -> Cube049
    Cube049
    scale <-1.0, 1.0, 1.0>
    rotate -0.0*y
    translate  <-0.265629, 0.0, 0.0>
  }
  object { Cube051 }
  object { // Cube052 -> Cube051
    Cube051
    scale <1.0, 1.0, -1.0>
    translate  1.494099*z
  }
  box { // Cube053
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    scale <0.02, 0.02, 0.186177>
    rotate 90.0*y
    translate  <-0.225896, 0.0, 0.9>
  }
  box { // Cube054
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    scale <0.02, 0.02, 0.186177>
    rotate 90.0*y
    translate  <-0.225896, 0.0, 0.6>
  }
  object { TransSweep001 }
  box { // Cube055
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    material {
      Mat_verre
    }
    scale <0.209978, 0.003, 0.919431>
    translate  <-0.234364, 0.03246, 0.288709>
  }
  cylinder { // Cylndr125
    <0,0,1>, <0,0,0>, 1 
    scale <0.006, 0.006, 0.965758>
    translate  <0.0, 0.01021, 0.270129>
  }
  material {
    T_peinture_Bois
  }
  translate  0.023427*y
}
#declare Cube056 = object {
  box { // Cube056
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    scale <0.04, 0.02, 0.978939>
    translate  <-0.264902, 0.0, 0.257401>
  }
}
#declare Cube074 = object {
  box { // Cube074
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    scale <0.04, 0.02, 0.186177>
    rotate 90.0*y
    translate  <-0.225896, 0.0, 1.236381>
  }
}
#declare TransSweep002 = prism {
  linear_sweep
  cubic_spline
  -0.254,0.0
  10  // control points
  <-0.295423, 0.024141>,
  <-0.283615, 0.007071>,
  <-0.277961, -0.010756>,
  <-0.267287, -0.013866>,
  <-0.267287, -0.006713>,
  <-0.267287, 0.023709>,
  <-0.270397, 0.023519>,
  <-0.295423, 0.024141>,
  <-0.283615, 0.007071>,
  <-0.277961, -0.010756>
  rotate -x*90
  rotate 90.0*y
  translate  <-0.254743, -0.023427, 0.0>
}
#declare RndCube006 = merge {
  sphere { <0.0070, 0.0020, 0.4655>, 0.0030 }
  sphere { <0.0070, -0.0020, 0.4655>, 0.0030 }
  sphere { <-0.0070, -0.0020, 0.4655>, 0.0030 }
  sphere { <-0.0070, 0.0020, 0.4655>, 0.0030 }
  sphere { <0.0070, 0.0020, -0.4655>, 0.0030 }
  sphere { <0.0070, -0.0020, -0.4655>, 0.0030 }
  sphere { <-0.0070, -0.0020, -0.4655>, 0.0030 }
  sphere { <-0.0070, 0.0020, -0.4655>, 0.0030 }
  cylinder { <0.0070, 0.0020, 0.4655>, <-0.0070, 0.0020, 0.4655>, 0.0030 }
  cylinder { <0.0070, -0.0020, 0.4655>, <-0.0070, -0.0020, 0.4655>, 0.0030 }
  cylinder { <0.0070, -0.0020, -0.4655>, <-0.0070, -0.0020, -0.4655>, 0.0030 }
  cylinder { <0.0070, 0.0020, -0.4655>, <-0.0070, 0.0020, -0.4655>, 0.0030 }
  cylinder { <0.0070, 0.0020, -0.4655>, <0.0070, 0.0020, 0.4655>, 0.0030 }
  cylinder { <0.0070, -0.0020, -0.4655>, <0.0070, -0.0020, 0.4655>, 0.0030 }
  cylinder { <-0.0070, -0.0020, -0.4655>, <-0.0070, -0.0020, 0.4655>, 0.0030 }
  cylinder { <-0.0070, 0.0020, -0.4655>, <-0.0070, 0.0020, 0.4655>, 0.0030 }
  cylinder { <0.0070, 0.0020, 0.4655>, <0.0070, -0.0020, 0.4655>, 0.0030 }
  cylinder { <0.0070, 0.0020, -0.4655>, <0.0070, -0.0020, -0.4655>, 0.0030 }
  cylinder { <-0.0070, 0.0020, -0.4655>, <-0.0070, -0.0020, -0.4655>, 0.0030 }
  cylinder { <-0.0070, 0.0020, 0.4655>, <-0.0070, -0.0020, 0.4655>, 0.0030 }
  box { <-0.0070, -0.0020, -0.4685> <0.0070, 0.0020, 0.4685> }
  box { <-0.0070, -0.0050, -0.4655> <0.0070, 0.0050, 0.4655> }
  box { <-0.0100, -0.0020, -0.4655> <0.0100, 0.0020, 0.4655> }
  translate  1.0*z
  translate  -0.242626*z
}
#declare Battant2 = union {
  object { Cube056 }
  object { // Cube073 -> Cube056
    Cube056
    scale <-1.0, 1.0, 1.0>
    rotate -0.0*y
    translate  <-0.265629, 0.0, 0.0>
  }
  object { Cube074 }
  object { // Cube075 -> Cube074
    Cube074
    scale <1.0, 1.0, -1.0>
    translate  1.494099*z
  }
  box { // Cube076
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    scale <0.02, 0.02, 0.186177>
    rotate 90.0*y
    translate  <-0.225896, 0.0, 0.9>
  }
  box { // Cube077
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    scale <0.02, 0.02, 0.186177>
    rotate 90.0*y
    translate  <-0.225896, 0.0, 0.6>
  }
  object { TransSweep002 }
  box { // Cube078
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.5, 0.5, 0.5>
    material {
      Mat_verre
    }
    scale <0.209978, 0.003, 0.919431>
    translate  <-0.234364, 0.03246, 0.288709>
  }
  object { RndCube006 }
  material {
    T_peinture_Bois
  }
  scale <-1.0, 1.0, 1.0>
  translate  0.023427*y
}
#declare Menuiserie = union { // Menuiserie
  object { Dormant }
  object { Battant1 }
  object { Battant2 }
  translate  0.252265*y
}


#declare Pos_sphere1 = object {
  sphere { // Pos_sphere1
    <0,0,0>,1
    scale 0.1
    translate  <0.001748, -4.988189, 4.846022>
  }
}
#declare Pos_sphere2 = object {
  object { // Pos_sphere2 -> Pos_sphere1
    Pos_sphere1
    translate  <-2.768645, 1.981759, 0.0>
  }
}
#declare Pos_sphere3 = object {
  object { // Pos_sphere3 -> Pos_sphere1
    Pos_sphere1
    translate  <-3.482615, 4.970198, 0.0>
  }
}
#declare Pos_sphere4 = object {
  object { // Pos_sphere4 -> Pos_sphere1
    Pos_sphere1
    translate  <-2.729779, 8.068586, 0.0>
  }
}
#declare Pos_sphere5 = object {
  object { // Pos_sphere5 -> Pos_sphere1
    Pos_sphere1
    translate  <-0.004784, 10.005889, 0.0>
  }
}
#declare Pos_sphere6 = object {
  object { // Pos_sphere6 -> Pos_sphere1
    Pos_sphere1
    translate  <2.775054, 8.013267, 0.0>
  }
}
#declare Pos_sphere7 = object {
  object { // Pos_sphere7 -> Pos_sphere1
    Pos_sphere1
    translate  <3.520932, 4.977542, 0.0>
  }
}
#declare Pos_sphere8 = object {
  object { // Pos_sphere8 -> Pos_sphere1
    Pos_sphere1
    translate  <2.749006, 2.004572, 0.0>
  }
}


#declare Poteau = prism {
  linear_sweep
  cubic_spline
  -0.1,0.0
  15  // control points
  <-2.613373, 0.244148>,
  <-2.91151, 0.002064>,
  <-2.613373, -0.244148>,
  <-2.070491, -0.114092>,
  <0.349082, -0.114092>,
  <0.852604, 0.038396>,
  <0.900196, 0.668645>,
  <0.885632, 1.364046>,
  <0.657496, 1.368707>,
  <0.664832, 0.582103>,
  <0.359183, 0.149445>,
  <-2.070491, 0.114092>,
  <-2.613373, 0.244148>,
  <-2.91151, 0.002064>,
  <-2.613373, -0.244148>
  rotate -x*90
  material {
    M_rouille
  }
  scale 0.3
  rotate <-180.0, 0.0, -90.0>
  translate  0.105792*y
}
#declare Barres_mole = union { // Barres_mole
  sphere { // Sphere001
    <0,0,0>,1
    scale <0.03, 0.03, 0.1>
    translate  0.883888*y
  }
  sphere { // Sphere008
    <0,0,0>,1
    scale <0.02, 0.02, 0.09>
    translate  0.487572*y
  }
}




#declare TMesh007 = mesh2 {
  vertex_vectors {
    582,
    <2.2035487, -0.0476156, 18.5058918>,
    <2.0010508, 0.0169930, 18.5058918>,
    <2.0011917, -0.0317843, 18.5058918>,
    <2.2036094, -0.1294874, 18.5058918>,
    <2.1022998, -0.0153113, 18.5058918>,
    <2.0011213, -0.0073956, 18.5058918>,
    <2.1024005, -0.0806358, 18.5058918>,
    <2.2035790, -0.0885515, 18.5058918>,
    <2.1023502, -0.0479736, 18.5058918>,
    <2.4060270, -0.2271905, 18.5058918>,
    <2.4060466, -0.1122243, 18.5058918>,
    <2.3048182, -0.1783389, 18.5058918>,
    <2.4060368, -0.1697074, 18.5058918>,
    <2.3047976, -0.0799199, 18.5058918>,
    <2.3048079, -0.1291294, 18.5058918>,
    <2.4060661, 0.0027419, 18.5058918>,
    <2.2034880, 0.0342561, 18.5058918>,
    <2.4060563, -0.0547412, 18.5058918>,
    <2.3047771, 0.0184990, 18.5058918>,
    <2.2035184, -0.0066798, 18.5058918>,
    <2.3047874, -0.0307105, 18.5058918>,
    <2.0009099, 0.0657702, 18.5058918>,
    <2.1021990, 0.0500132, 18.5058918>,
    <2.0009804, 0.0413816, 18.5058918>,
    <2.1022494, 0.0173509, 18.5058918>,
    <2.0655560, -0.0651338, 18.1207908>,
    <2.0032615, -0.0337033, 18.1202395>,
    <2.0033220, -0.0337594, 18.1217627>,
    <2.0553199, -0.0632553, 18.1217627>,
    <2.0344088, -0.0494186, 18.1205151>,
    <2.0032917, -0.0337313, 18.1210011>,
    <2.0293209, -0.0485073, 18.1217627>,
    <2.0604380, -0.0641945, 18.1212767>,
    <2.0318649, -0.0489629, 18.1211389>,
    <2.1073179, -0.0927512, 18.1217627>,
    <2.1278504, -0.0965642, 18.1213420>,
    <2.0813189, -0.0780033, 18.1217627>,
    <2.1175842, -0.0946577, 18.1215524>,
    <2.0967032, -0.0808490, 18.1210664>,
    <2.0890111, -0.0794261, 18.1214145>,
    <2.1483830, -0.1003772, 18.1209214>,
    <2.0757921, -0.0670122, 18.1198188>,
    <2.1381167, -0.0984707, 18.1211317>,
    <2.1120875, -0.0836947, 18.1203701>,
    <2.0706740, -0.0660730, 18.1203048>,
    <2.1043954, -0.0822719, 18.1207182>,
    <2.0032011, -0.0336473, 18.1187163>,
    <2.0394966, -0.0503298, 18.1192675>,
    <2.0032313, -0.0336753, 18.1194779>,
    <2.0369527, -0.0498742, 18.1198913>,
    <2.1279029, -0.0254914, 18.1213420>,
    <2.1073713, -0.0229597, 18.1217627>,
    <2.1278767, -0.0610278, 18.1213420>,
    <2.1073446, -0.0578555, 18.1217627>,
    <2.1176371, -0.0242255, 18.1215524>,
    <2.1176106, -0.0594416, 18.1215524>,
    <2.1074247, 0.0468319, 18.1217627>,
    <2.1279553, 0.0455814, 18.1213420>,
    <2.1073980, 0.0119361, 18.1217627>,
    <2.1176900, 0.0462066, 18.1215524>,
    <2.1279291, 0.0100450, 18.1213420>,
    <2.1176635, 0.0109906, 18.1215524>,
    <2.1484859, 0.0443309, 18.1209214>,
    <2.1484345, -0.0280231, 18.1209214>,
    <2.1382206, 0.0449562, 18.1211317>,
    <2.1484602, 0.0081539, 18.1209214>,
    <2.1381687, -0.0267573, 18.1211317>,
    <2.1381946, 0.0090995, 18.1211317>,
    <2.1484087, -0.0642001, 18.1209214>,
    <2.1381427, -0.0626140, 18.1211317>,
    <2.0656120, 0.0557185, 18.1207908>,
    <2.0553811, 0.0563449, 18.1217627>,
    <2.0967837, 0.0506499, 18.1210664>,
    <2.0814029, 0.0515884, 18.1217627>,
    <2.0604966, 0.0560317, 18.1212767>,
    <2.0890933, 0.0511192, 18.1214145>,
    <2.0033376, 0.0658580, 18.1217627>,
    <2.0032688, 0.0658555, 18.1202395>,
    <2.0293594, 0.0611015, 18.1217627>,
    <2.0033032, 0.0658568, 18.1210011>,
    <2.0344404, 0.0607870, 18.1205151>,
    <2.0318999, 0.0609442, 18.1211389>,
    <2.0031999, 0.0658530, 18.1187163>,
    <2.0758429, 0.0550920, 18.1198188>,
    <2.0032343, 0.0658543, 18.1194779>,
    <2.0395214, 0.0604725, 18.1192675>,
    <2.0707275, 0.0554052, 18.1203048>,
    <2.0369809, 0.0606297, 18.1198913>,
    <2.1121644, 0.0497115, 18.1203701>,
    <2.1044740, 0.0501807, 18.1207182>,
    <2.0758764, -0.0709293, 18.1376413>,
    <2.0030751, -0.0335305, 18.1370901>,
    <2.0394758, -0.0522299, 18.1373657>,
    <2.0031381, -0.0335889, 18.1279032>,
    <2.0758342, -0.0689708, 18.1287301>,
    <2.0394862, -0.0512798, 18.1283166>,
    <2.1486776, -0.1083281, 18.1381926>,
    <2.1485303, -0.1043526, 18.1295570>,
    <2.1122770, -0.0896287, 18.1379170>,
    <2.1121823, -0.0866617, 18.1291435>,
    <2.1489723, -0.1162790, 18.1554639>,
    <2.0759607, -0.0748464, 18.1554639>,
    <2.1488250, -0.1123036, 18.1468283>,
    <2.1124665, -0.0955627, 18.1554639>,
    <2.0759186, -0.0728878, 18.1465526>,
    <2.1123718, -0.0925957, 18.1466904>,
    <2.0029492, -0.0334137, 18.1554639>,
    <2.0394549, -0.0541300, 18.1554639>,
    <2.0030121, -0.0334721, 18.1462770>,
    <2.0394654, -0.0531800, 18.1464148>,
    <2.1487271, -0.0333024, 18.1381926>,
    <2.1487024, -0.0708152, 18.1381926>,
    <2.1485808, -0.0306627, 18.1295570>,
    <2.1485556, -0.0675077, 18.1295570>,
    <2.1487766, 0.0417234, 18.1381926>,
    <2.1486313, 0.0430272, 18.1295570>,
    <2.1487519, 0.0042105, 18.1381926>,
    <2.1486060, 0.0061822, 18.1295570>,
    <2.1490672, 0.0391158, 18.1554639>,
    <2.1490198, -0.0385816, 18.1554639>,
    <2.1489219, 0.0404196, 18.1468283>,
    <2.1490435, 0.0002671, 18.1554639>,
    <2.1488734, -0.0359420, 18.1468283>,
    <2.1488977, 0.0022388, 18.1468283>,
    <2.1489960, -0.0774303, 18.1554639>,
    <2.1488492, -0.0741228, 18.1468283>,
    <2.0759165, 0.0537856, 18.1376413>,
    <2.1123465, 0.0477545, 18.1379170>,
    <2.0758797, 0.0544388, 18.1287301>,
    <2.1122555, 0.0487330, 18.1291435>,
    <2.0030563, 0.0658478, 18.1370901>,
    <2.0031281, 0.0658504, 18.1279032>,
    <2.0394864, 0.0598167, 18.1373657>,
    <2.0395039, 0.0601446, 18.1283166>,
    <2.0029127, 0.0658426, 18.1554639>,
    <2.0759900, 0.0524792, 18.1554639>,
    <2.0029845, 0.0658452, 18.1462770>,
    <2.0394514, 0.0591609, 18.1554639>,
    <2.0759532, 0.0531324, 18.1465526>,
    <2.0394689, 0.0594888, 18.1464148>,
    <2.1125286, 0.0457975, 18.1554639>,
    <2.1124376, 0.0467760, 18.1466904>,
    <2.0809036, -0.0776221, 18.1573801>,
    <2.0028599, -0.0333309, 18.1573801>,
    <2.0418818, -0.0554765, 18.1573801>,
    <2.0029045, -0.0333723, 18.1564220>,
    <2.0784322, -0.0762342, 18.1564220>,
    <2.0406684, -0.0548033, 18.1564220>,
    <2.1589474, -0.1219133, 18.1573801>,
    <2.1539599, -0.1190962, 18.1564220>,
    <2.1199255, -0.0997677, 18.1573801>,
    <2.1161960, -0.0976652, 18.1564220>,
    <2.1689225, -0.1275476, 18.1592964>,
    <2.0858466, -0.0803979, 18.1592964>,
    <2.1639350, -0.1247304, 18.1583383>,
    <2.1273846, -0.1039727, 18.1592964>,
    <2.0833751, -0.0790100, 18.1583383>,
    <2.1236550, -0.1018702, 18.1583383>,
    <2.0027706, -0.0332481, 18.1592964>,
    <2.0443086, -0.0568230, 18.1592964>,
    <2.0028152, -0.0332895, 18.1583383>,
    <2.0430952, -0.0561498, 18.1583383>,
    <2.1589935, -0.0423226, 18.1573801>,
    <2.1589704, -0.0821180, 18.1573801>,
    <2.1540066, -0.0404521, 18.1564220>,
    <2.1539832, -0.0797741, 18.1564220>,
    <2.1590395, 0.0372681, 18.1573801>,
    <2.1540534, 0.0381920, 18.1564220>,
    <2.1590165, -0.0025273, 18.1573801>,
    <2.1540300, -0.0011301, 18.1564220>,
    <2.1690118, 0.0354203, 18.1592964>,
    <2.1689672, -0.0460636, 18.1592964>,
    <2.1640257, 0.0363442, 18.1583383>,
    <2.1689895, -0.0053217, 18.1592964>,
    <2.1639803, -0.0441931, 18.1583383>,
    <2.1640030, -0.0039245, 18.1583383>,
    <2.1689449, -0.0868056, 18.1592964>,
    <2.1639576, -0.0844618, 18.1583383>,
    <2.0809253, 0.0515535, 18.1573801>,
    <2.1199824, 0.0444108, 18.1573801>,
    <2.0784576, 0.0520164, 18.1564220>,
    <2.1162555, 0.0451042, 18.1564220>,
    <2.0028110, 0.0658390, 18.1573801>,
    <2.0028619, 0.0658408, 18.1564220>,
    <2.0418681, 0.0586962, 18.1573801>,
    <2.0406598, 0.0589286, 18.1564220>,
    <2.0027093, 0.0658353, 18.1592964>,
    <2.0858605, 0.0506278, 18.1592964>,
    <2.0027601, 0.0658371, 18.1583383>,
    <2.0442849, 0.0582315, 18.1592964>,
    <2.0833929, 0.0510906, 18.1583383>,
    <2.0430765, 0.0584639, 18.1583383>,
    <2.1274362, 0.0430240, 18.1592964>,
    <2.1237093, 0.0437174, 18.1583383>,
    <2.0874016, -0.0810057, 18.2324892>,
    <2.0027700, -0.0332476, 18.2344341>,
    <2.0450846, -0.0571256, 18.2333227>,
    <2.0027703, -0.0332479, 18.1968653>,
    <2.0858626, -0.0804069, 18.1968653>,
    <2.0443164, -0.0568274, 18.1968653>,
    <2.1720474, -0.1287770, 18.2322113>,
    <2.1689548, -0.1275658, 18.1968653>,
    <2.1297234, -0.1048903, 18.2322113>,
    <2.1274087, -0.1039863, 18.1968653>,
    <2.1996546, -0.1395496, 18.2873438>,
    <2.1011317, -0.0863238, 18.2890109>,
    <2.1812606, -0.1323739, 18.2631118>,
    <2.1503860, -0.1129301, 18.2873438>,
    <2.0919868, -0.0827843, 18.2642232>,
    <2.1366190, -0.1075747, 18.2631118>,
    <2.0027694, -0.0332471, 18.3095719>,
    <2.0519057, -0.0597438, 18.2940122>,
    <2.0027697, -0.0332473, 18.2720030>,
    <2.0473735, -0.0580115, 18.2675574>,
    <2.1720918, -0.0468799, 18.2322113>,
    <2.1720696, -0.0878285, 18.2322113>,
    <2.1689995, -0.0460758, 18.1968653>,
    <2.1689772, -0.0868208, 18.1968653>,
    <2.1721361, 0.0350171, 18.2322113>,
    <2.1690441, 0.0354143, 18.1968653>,
    <2.1721139, -0.0059314, 18.2322113>,
    <2.1690218, -0.0053307, 18.1968653>,
    <2.1997378, 0.0314842, 18.2873438>,
    <2.1996962, -0.0540327, 18.2873438>,
    <2.1813474, 0.0338375, 18.2631118>,
    <2.1997170, -0.0112743, 18.2873438>,
    <2.1813040, -0.0492682, 18.2631118>,
    <2.1813257, -0.0077154, 18.2631118>,
    <2.1996754, -0.0967911, 18.2873438>,
    <2.1812823, -0.0908211, 18.2631118>,
    <2.0874143, 0.0504259, 18.2324892>,
    <2.1297738, 0.0427214, 18.2322113>,
    <2.0858765, 0.0506248, 18.1968653>,
    <2.1274603, 0.0430195, 18.1968653>,
    <2.0027086, 0.0658353, 18.2344341>,
    <2.0027089, 0.0658353, 18.1968653>,
    <2.0450601, 0.0581305, 18.2333227>,
    <2.0442927, 0.0582300, 18.1968653>,
    <2.0027079, 0.0658352, 18.3095719>,
    <2.1011313, 0.0486564, 18.2890109>,
    <2.0027083, 0.0658352, 18.2720030>,
    <2.0518685, 0.0572440, 18.2940122>,
    <2.0919955, 0.0498352, 18.2642232>,
    <2.0473465, 0.0578350, 18.2675574>,
    <2.1504265, 0.0400700, 18.2873438>,
    <2.1366661, 0.0418361, 18.2631118>,
    <2.1346539, -0.0992855, 18.3131904>,
    <2.0021640, -0.0326857, 18.3135798>,
    <2.0684089, -0.0659855, 18.3133573>,
    <2.0024667, -0.0329664, 18.3115759>,
    <2.1163499, -0.0922053, 18.3037960>,
    <2.0594036, -0.0625815, 18.3071303>,
    <2.2671445, -0.1658858, 18.3131347>,
    <2.2302897, -0.1514968, 18.3026846>,
    <2.2008992, -0.1325856, 18.3131347>,
    <2.1733151, -0.1218467, 18.3026846>,
    <2.3354274, -0.1926700, 18.3353648>,
    <2.1685696, -0.1124682, 18.3340315>,
    <2.3041976, -0.1803868, 18.3226946>,
    <2.2520053, -0.1525753, 18.3353648>,
    <2.1530564, -0.1064210, 18.3218058>,
    <2.2286315, -0.1434081, 18.3226946>,
    <2.0015586, -0.0321244, 18.3175878>,
    <2.0851068, -0.0723359, 18.3300317>,
    <2.0018613, -0.0324051, 18.3155838>,
    <2.0774634, -0.0694172, 18.3191392>,
    <2.2671795, -0.0715194, 18.3131347>,
    <2.2671620, -0.1187026, 18.3131347>,
    <2.2303283, -0.0619654, 18.3026846>,
    <2.2303090, -0.1067311, 18.3026846>,
    <2.2672145, 0.0228471, 18.3131347>,
    <2.2303669, 0.0275660, 18.3026846>,
    <2.2671970, -0.0243361, 18.3131347>,
    <2.2303476, -0.0171997, 18.3026846>,
    <2.3354839, 0.0140631, 18.3353648>,
    <2.3354557, -0.0893034, 18.3353648>,
    <2.3042602, 0.0180914, 18.3226946>,
    <2.3354698, -0.0376202, 18.3353648>,
    <2.3042289, -0.0811477, 18.3226946>,
    <2.3042446, -0.0315281, 18.3226946>,
    <2.3354416, -0.1409867, 18.3353648>,
    <2.3042132, -0.1307673, 18.3226946>,
    <2.1346158, 0.0443287, 18.3131904>,
    <2.2009151, 0.0335879, 18.3131347>,
    <2.1163326, 0.0466932, 18.3037960>,
    <2.1733444, 0.0371294, 18.3026846>,
    <2.0020180, 0.0658103, 18.3135798>,
    <2.0023629, 0.0658228, 18.3115759>,
    <2.0683168, 0.0550695, 18.3133573>,
    <2.0593424, 0.0562578, 18.3071303>,
    <2.0013280, 0.0657853, 18.3175878>,
    <2.1684932, 0.0399274, 18.3340315>,
    <2.0016730, 0.0657978, 18.3155838>,
    <2.0849593, 0.0528581, 18.3300317>,
    <2.1529974, 0.0419457, 18.3218058>,
    <2.0773403, 0.0538720, 18.3191392>,
    <2.2519963, 0.0269955, 18.3353648>,
    <2.2286339, 0.0300188, 18.3226946>,
    <2.1834288, -0.1184202, 18.3800376>,
    <2.0015296, -0.0320975, 18.3784821>,
    <2.0924803, -0.0752599, 18.3793709>,
    <2.0015441, -0.0321110, 18.3480349>,
    <2.1782054, -0.1162833, 18.3542569>,
    <2.0898793, -0.0742013, 18.3515903>,
    <2.3653145, -0.2047304, 18.3802598>,
    <2.3548127, -0.2004055, 18.3551457>,
    <2.2743728, -0.1615763, 18.3802598>,
    <2.2665136, -0.1583486, 18.3551457>,
    <2.3715124, -0.2076955, 18.4393764>,
    <2.1865065, -0.1198831, 18.4393764>,
    <2.3698941, -0.2067814, 18.4089292>,
    <2.2790095, -0.1637893, 18.4393764>,
    <2.1857046, -0.1194327, 18.4089292>,
    <2.2777993, -0.1631070, 18.4089292>,
    <2.0015006, -0.0320707, 18.4393764>,
    <2.0940036, -0.0759769, 18.4393764>,
    <2.0015151, -0.0320841, 18.4089292>,
    <2.0936098, -0.0757584, 18.4089292>,
    <2.3653397, -0.0973113, 18.3802598>,
    <2.3653271, -0.1510208, 18.3802598>,
    <2.3548390, -0.0944397, 18.3551457>,
    <2.3548259, -0.1474226, 18.3551457>,
    <2.3653649, 0.0101078, 18.3802598>,
    <2.3548653, 0.0115262, 18.3551457>,
    <2.3653523, -0.0436017, 18.3802598>,
    <2.3548521, -0.0414567, 18.3551457>,
    <2.3715613, 0.0091354, 18.4393764>,
    <2.3715369, -0.0992800, 18.4393764>,
    <2.3699434, 0.0094352, 18.4089292>,
    <2.3715491, -0.0450723, 18.4393764>,
    <2.3699187, -0.0986731, 18.4089292>,
    <2.3699311, -0.0446189, 18.4089292>,
    <2.3715246, -0.1534878, 18.4393764>,
    <2.3699064, -0.1527272, 18.4089292>,
    <2.1833376, 0.0379463, 18.3800376>,
    <2.2743526, 0.0240271, 18.3802598>,
    <2.1781192, 0.0386566, 18.3542569>,
    <2.2664974, 0.0250916, 18.3551457>,
    <2.0012950, 0.0657841, 18.3784821>,
    <2.0013115, 0.0657847, 18.3480349>,
    <2.0923176, 0.0518653, 18.3793709>,
    <2.0897205, 0.0522208, 18.3515903>,
    <2.0012619, 0.0657829, 18.4393764>,
    <2.1864116, 0.0374592, 18.4393764>,
    <2.0012785, 0.0657835, 18.4089292>,
    <2.0938368, 0.0516211, 18.4393764>,
    <2.1856109, 0.0376094, 18.4089292>,
    <2.0934447, 0.0516965, 18.4089292>,
    <2.2789865, 0.0232973, 18.4393764>,
    <2.2777772, 0.0235223, 18.4089292>,
    <2.1950579, -0.1246852, 18.4393764>,
    <2.0013462, -0.0319275, 18.4393764>,
    <2.0982021, -0.0783063, 18.4393764>,
    <2.0014234, -0.0319991, 18.4393764>,
    <2.1907822, -0.1222841, 18.4393764>,
    <2.0961028, -0.0771416, 18.4393764>,
    <2.3887697, -0.2174430, 18.4393764>,
    <2.3801411, -0.2125692, 18.4393764>,
    <2.2919138, -0.1710641, 18.4393764>,
    <2.2854617, -0.1674267, 18.4393764>,
    <2.4060270, -0.2271905, 18.4393764>,
    <2.2036094, -0.1294874, 18.4393764>,
    <2.3973984, -0.2223167, 18.4393764>,
    <2.3048182, -0.1783389, 18.4393764>,
    <2.1993337, -0.1270863, 18.4393764>,
    <2.2983660, -0.1747015, 18.4393764>,
    <2.0011917, -0.0317843, 18.4393764>,
    <2.1024005, -0.0806358, 18.4393764>,
    <2.0012689, -0.0318559, 18.4393764>,
    <2.1003013, -0.0794711, 18.4393764>,
    <2.3887917, -0.1057521, 18.4393764>,
    <2.3887807, -0.1615976, 18.4393764>,
    <2.3801643, -0.1025161, 18.4393764>,
    <2.3801527, -0.1575427, 18.4393764>,
    <2.3888137, 0.0059387, 18.4393764>,
    <2.3801875, 0.0075370, 18.4393764>,
    <2.3888027, -0.0499067, 18.4393764>,
    <2.3801759, -0.0474895, 18.4393764>,
    <2.4060661, 0.0027419, 18.4393764>,
    <2.4060466, -0.1122243, 18.4393764>,
    <2.3974399, 0.0043403, 18.4393764>,
    <2.4060563, -0.0547412, 18.4393764>,
    <2.3974192, -0.1089882, 18.4393764>,
    <2.3974295, -0.0523239, 18.4393764>,
    <2.4060368, -0.1697074, 18.4393764>,
    <2.3974088, -0.1656525, 18.4393764>,
    <2.1949498, 0.0358576, 18.4393764>,
    <2.2918818, 0.0208982, 18.4393764>,
    <2.1906807, 0.0366584, 18.4393764>,
    <2.2854341, 0.0220977, 18.4393764>,
    <2.0010859, 0.0657766, 18.4393764>,
    <2.0011739, 0.0657798, 18.4393764>,
    <2.0980179, 0.0508171, 18.4393764>,
    <2.0959273, 0.0512191, 18.4393764>,
    <2.0009099, 0.0657702, 18.4393764>,
    <2.2034880, 0.0342561, 18.4393764>,
    <2.0009979, 0.0657734, 18.4393764>,
    <2.1021990, 0.0500132, 18.4393764>,
    <2.1992189, 0.0350569, 18.4393764>,
    <2.1001084, 0.0504151, 18.4393764>,
    <2.3047771, 0.0184990, 18.4393764>,
    <2.2983294, 0.0196986, 18.4393764>,
    <2.2036094, -0.1294874, 18.4726341>,
    <2.0011917, -0.0317843, 18.4726341>,
    <2.1024005, -0.0806358, 18.4726341>,
    <2.0011917, -0.0317843, 18.4560052>,
    <2.2036094, -0.1294874, 18.4560052>,
    <2.1024005, -0.0806358, 18.4560052>,
    <2.4060270, -0.2271905, 18.4726341>,
    <2.4060270, -0.2271905, 18.4560052>,
    <2.3048182, -0.1783389, 18.4726341>,
    <2.3048182, -0.1783389, 18.4560052>,
    <2.4060270, -0.2271905, 18.4892630>,
    <2.2036094, -0.1294874, 18.4892630>,
    <2.3048182, -0.1783389, 18.4892630>,
    <2.0011917, -0.0317843, 18.4892630>,
    <2.1024005, -0.0806358, 18.4892630>,
    <2.4060466, -0.1122243, 18.4726341>,
    <2.4060368, -0.1697074, 18.4726341>,
    <2.4060466, -0.1122243, 18.4560052>,
    <2.4060368, -0.1697074, 18.4560052>,
    <2.4060661, 0.0027419, 18.4726341>,
    <2.4060661, 0.0027419, 18.4560052>,
    <2.4060563, -0.0547412, 18.4726341>,
    <2.4060563, -0.0547412, 18.4560052>,
    <2.4060661, 0.0027419, 18.4892630>,
    <2.4060466, -0.1122243, 18.4892630>,
    <2.4060563, -0.0547412, 18.4892630>,
    <2.4060368, -0.1697074, 18.4892630>,
    <2.2034880, 0.0342561, 18.4726341>,
    <2.3047771, 0.0184990, 18.4726341>,
    <2.2034880, 0.0342561, 18.4560052>,
    <2.3047771, 0.0184990, 18.4560052>,
    <2.0009099, 0.0657702, 18.4726341>,
    <2.0009099, 0.0657702, 18.4560052>,
    <2.1021990, 0.0500132, 18.4726341>,
    <2.1021990, 0.0500132, 18.4560052>,
    <2.0009099, 0.0657702, 18.4892630>,
    <2.2034880, 0.0342561, 18.4892630>,
    <2.1021990, 0.0500132, 18.4892630>,
    <2.3047771, 0.0184990, 18.4892630>,
    <2.0010508, 0.0169930, 18.4726341>,
    <2.0011917, -0.0317843, 18.4726341>,
    <2.0010508, 0.0169930, 18.4393764>,
    <2.0011213, -0.0073956, 18.4726341>,
    <2.0011917, -0.0317843, 18.4560052>,
    <2.0011213, -0.0073956, 18.4393764>,
    <2.0010508, 0.0169930, 18.4560052>,
    <2.0011213, -0.0073956, 18.4560052>,
    <2.0009099, 0.0657702, 18.4726341>,
    <2.0009804, 0.0413816, 18.4393764>,
    <2.0009099, 0.0657702, 18.4560052>,
    <2.0009804, 0.0413816, 18.4726341>,
    <2.0009804, 0.0413816, 18.4560052>,
    <2.0010508, 0.0169930, 18.5058918>,
    <2.0009099, 0.0657702, 18.4892630>,
    <2.0009804, 0.0413816, 18.5058918>,
    <2.0010508, 0.0169930, 18.4892630>,
    <2.0009804, 0.0413816, 18.4892630>,
    <2.0011213, -0.0073956, 18.5058918>,
    <2.0011917, -0.0317843, 18.4892630>,
    <2.0011213, -0.0073956, 18.4892630>,
    <2.0012160, 0.0169246, 18.4393764>,
    <2.0013813, 0.0168561, 18.4393764>,
    <2.0012987, 0.0168904, 18.4393764>,
    <2.0014410, -0.0076073, 18.4393764>,
    <2.0012811, -0.0075014, 18.4393764>,
    <2.0013610, -0.0075544, 18.4393764>,
    <2.0010508, 0.0169930, 18.4393764>,
    <2.0011213, -0.0073956, 18.4393764>,
    <2.0011334, 0.0169588, 18.4393764>,
    <2.0012012, -0.0074485, 18.4393764>,
    <2.0009804, 0.0413816, 18.4393764>,
    <2.0011510, 0.0413506, 18.4393764>,
    <2.0010657, 0.0413661, 18.4393764>,
    <2.0013216, 0.0413195, 18.4393764>,
    <2.0012363, 0.0413351, 18.4393764>,
    <2.0014123, 0.0168433, 18.3784821>,
    <2.0015296, -0.0320975, 18.3784821>,
    <2.0014433, 0.0168305, 18.3175878>,
    <2.0014709, -0.0076271, 18.3784821>,
    <2.0015441, -0.0321110, 18.3480349>,
    <2.0015009, -0.0076470, 18.3175878>,
    <2.0014278, 0.0168369, 18.3480349>,
    <2.0014859, -0.0076370, 18.3480349>,
    <2.0012950, 0.0657841, 18.3784821>,
    <2.0013856, 0.0413079, 18.3175878>,
    <2.0013115, 0.0657847, 18.3480349>,
    <2.0013536, 0.0413137, 18.3784821>,
    <2.0013696, 0.0413108, 18.3480349>,
    <2.0013813, 0.0168561, 18.4393764>,
    <2.0012785, 0.0657835, 18.4089292>,
    <2.0013216, 0.0413195, 18.4393764>,
    <2.0013968, 0.0168497, 18.4089292>,
    <2.0013376, 0.0413166, 18.4089292>,
    <2.0014410, -0.0076073, 18.4393764>,
    <2.0015151, -0.0320841, 18.4089292>,
    <2.0014559, -0.0076172, 18.4089292>,
    <2.0020910, 0.0165623, 18.3135798>,
    <2.0027387, 0.0162941, 18.3095719>,
    <2.0024148, 0.0164282, 18.3115759>,
    <2.0027541, -0.0084765, 18.3095719>,
    <2.0021275, -0.0080617, 18.3135798>,
    <2.0024408, -0.0082691, 18.3115759>,
    <2.0014433, 0.0168305, 18.3175878>,
    <2.0015009, -0.0076470, 18.3175878>,
    <2.0017671, 0.0166964, 18.3155838>,
    <2.0018142, -0.0078543, 18.3155838>,
    <2.0013856, 0.0413079, 18.3175878>,
    <2.0020545, 0.0411863, 18.3135798>,
    <2.0017200, 0.0412471, 18.3155838>,
    <2.0027233, 0.0410647, 18.3095719>,
    <2.0023889, 0.0411255, 18.3115759>,
    <2.0027393, 0.0162938, 18.2344341>,
    <2.0027700, -0.0332476, 18.2344341>,
    <2.0027399, 0.0162936, 18.1592964>,
    <2.0027547, -0.0084769, 18.2344341>,
    <2.0027703, -0.0332479, 18.1968653>,
    <2.0027553, -0.0084773, 18.1592964>,
    <2.0027396, 0.0162937, 18.1968653>,
    <2.0027550, -0.0084771, 18.1968653>,
    <2.0027086, 0.0658353, 18.2344341>,
    <2.0027246, 0.0410644, 18.1592964>,
    <2.0027089, 0.0658353, 18.1968653>,
    <2.0027240, 0.0410645, 18.2344341>,
    <2.0027243, 0.0410645, 18.1968653>,
    <2.0027387, 0.0162941, 18.3095719>,
    <2.0027083, 0.0658352, 18.2720030>,
    <2.0027233, 0.0410647, 18.3095719>,
    <2.0027390, 0.0162940, 18.2720030>,
    <2.0027236, 0.0410646, 18.2720030>,
    <2.0027541, -0.0084765, 18.3095719>,
    <2.0027697, -0.0332473, 18.2720030>,
    <2.0027544, -0.0084767, 18.2720030>,
    <2.0028354, 0.0162540, 18.1573801>,
    <2.0029309, 0.0162145, 18.1554639>,
    <2.0028832, 0.0162342, 18.1564220>,
    <2.0029400, -0.0085996, 18.1554639>,
    <2.0028477, -0.0085385, 18.1573801>,
    <2.0028939, -0.0085690, 18.1564220>,
    <2.0027399, 0.0162936, 18.1592964>,
    <2.0027553, -0.0084773, 18.1592964>,
    <2.0027877, 0.0162738, 18.1583383>,
    <2.0028015, -0.0085079, 18.1583383>,
    <2.0027246, 0.0410644, 18.1592964>,
    <2.0028232, 0.0410465, 18.1573801>,
    <2.0027739, 0.0410555, 18.1583383>,
    <2.0029218, 0.0410286, 18.1554639>,
    <2.0028725, 0.0410375, 18.1564220>,
    <2.0031242, 0.0161345, 18.1389725>,
    <2.0031356, -0.0335865, 18.1386133>,
    <2.0032596, 0.0160784, 18.1258340>,
    <2.0031288, -0.0087256, 18.1388528>,
    <2.0032288, -0.0336729, 18.1301880>,
    <2.0032692, -0.0088236, 18.1251156>,
    <2.0032053, 0.0161009, 18.1316249>,
    <2.0032129, -0.0087843, 18.1311460>,
    <2.0031252, 0.0658503, 18.1386133>,
    <2.0032749, 0.0409701, 18.1251156>,
    <2.0032314, 0.0658542, 18.1301880>,
    <2.0031236, 0.0409928, 18.1388528>,
    <2.0032142, 0.0409792, 18.1311460>,
    <2.0029309, 0.0162145, 18.1554639>,
    <2.0030190, 0.0658465, 18.1470386>,
    <2.0029218, 0.0410286, 18.1554639>,
    <2.0030307, 0.0161732, 18.1470386>,
    <2.0030248, 0.0410098, 18.1470386>,
    <2.0029400, -0.0085996, 18.1554639>,
    <2.0030424, -0.0335001, 18.1470386>,
    <2.0030365, -0.0086635, 18.1470386>,
    <2.0032590, 0.0160787, 18.1205987>,
    <2.0032727, 0.0160730, 18.1224380>,
    <2.0032592, -0.0088119, 18.1204790>,
    <2.0032781, -0.0088275, 18.1219591>,
    <2.0032005, 0.0161029, 18.1187163>,
    <2.0032008, -0.0087722, 18.1187163>,
    <2.0032328, 0.0160895, 18.1194779>,
    <2.0032321, -0.0087929, 18.1194779>,
    <2.0032002, 0.0409779, 18.1187163>,
    <2.0032628, 0.0409675, 18.1204790>,
    <2.0032336, 0.0409719, 18.1194779>,
    <2.0032838, 0.0409666, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.2905185, 0.5520584, 0.7815565>,
    <0.1402752, 0.2717584, 0.9520873>,
    <0.1452503, 0.3043949, 0.9414064>,
    <0.2904158, 0.5888277, 0.7542815>,
    <0.4503017, 0.8927509, 0.0149707>,
    <0.4703139, 0.8823914, 0.0137959>,
    <0.4703139, 0.8823914, 0.0137959>,
    <0.4933598, 0.8697367, 0.0124165>,
    <0.2899477, 0.5111445, 0.8091117>,
    <0.2899477, 0.5111445, 0.8091117>,
    <0.1350057, 0.2379995, 0.9618366>,
    <0.0709628, 0.1420534, 0.9873121>,
    <0.0752920, 0.1664715, 0.9831675>,
    <0.1350057, 0.2379995, 0.9618366>,
    <0.0665477, 0.1173160, 0.9908624>,
    <0.0665477, 0.1173160, 0.9908624>,
    <0.0304015, 0.0535943, 0.9980999>,
    <0.0339096, 0.0726304, 0.9967823>,
    <0.0339096, 0.0726304, 0.9967823>,
    <0.0373904, 0.0915607, 0.9950973>,
    <0.0795291, 0.1905307, 0.9784545>,
    <0.1499304, 0.3358470, 0.9299074>,
    <0.0373904, 0.0915607, 0.9950973>,
    <0.0408405, 0.1103649, 0.9930517>,
    <0.0408405, 0.1103649, 0.9930517>,
    <0.0442564, 0.1290236, 0.9906535>,
    <0.0836685, 0.2141944, 0.9732011>,
    <0.0836685, 0.2141944, 0.9732011>,
    <0.1543179, 0.3660700, 0.9177030>,
    <0.2897772, 0.6218040, 0.7275912>,
    <0.1543179, 0.3660700, 0.9177030>,
    <0.2887204, 0.6513470, 0.7017034>,
    <0.2887204, 0.6513470, 0.7017034>,
    <0.4173569, 0.9085862, 0.0168598>,
    <0.4327902, 0.9013530, 0.0159816>,
    <0.4327902, 0.9013530, 0.0159816>,
    <0.4503017, 0.8927509, 0.0149707>,
    <-0.0204816, 0.0000154, -0.9997902>,
    <-0.0204825, 0.0000154, -0.9997902>,
    <-0.0204826, 0.0000151, -0.9997902>,
    <-0.0204816, 0.0000151, -0.9997902>,
    <-0.0204807, 0.0000151, -0.9997902>,
    <-0.0204806, 0.0000154, -0.9997903>,
    <-0.0204806, 0.0000154, -0.9997903>,
    <-0.0204806, 0.0000157, -0.9997903>,
    <-0.0204815, 0.0000157, -0.9997902>,
    <-0.0204815, 0.0000157, -0.9997902>,
    <-0.0204825, 0.0000157, -0.9997902>,
    <-0.0204835, 0.0000154, -0.9997902>,
    <-0.0204835, 0.0000151, -0.9997902>,
    <-0.0204825, 0.0000157, -0.9997902>,
    <-0.0204835, 0.0000157, -0.9997902>,
    <-0.0204835, 0.0000157, -0.9997902>,
    <-0.0204844, 0.0000157, -0.9997902>,
    <-0.0204844, 0.0000154, -0.9997902>,
    <-0.0204844, 0.0000154, -0.9997902>,
    <-0.0204845, 0.0000151, -0.9997902>,
    <-0.0204835, 0.0000148, -0.9997902>,
    <-0.0204826, 0.0000148, -0.9997902>,
    <-0.0204845, 0.0000151, -0.9997902>,
    <-0.0204845, 0.0000148, -0.9997902>,
    <-0.0204845, 0.0000148, -0.9997902>,
    <-0.0204845, 0.0000146, -0.9997902>,
    <-0.0204836, 0.0000146, -0.9997902>,
    <-0.0204836, 0.0000146, -0.9997902>,
    <-0.0204826, 0.0000146, -0.9997902>,
    <-0.0204816, 0.0000148, -0.9997902>,
    <-0.0204826, 0.0000146, -0.9997902>,
    <-0.0204817, 0.0000146, -0.9997902>,
    <-0.0204817, 0.0000146, -0.9997902>,
    <-0.0204808, 0.0000146, -0.9997902>,
    <-0.0204807, 0.0000148, -0.9997902>,
    <-0.0204807, 0.0000148, -0.9997902>,
    <-0.0204807, 0.0000151, -0.9997902>,
    <-0.0662447, -0.4111287, -0.9091671>,
    <-0.1108606, -0.6660332, -0.7376379>,
    <-0.1095162, -0.7112873, -0.6943173>,
    <-0.0684816, -0.4690491, -0.8805130>,
    <-0.0365428, -0.2769570, -0.9601872>,
    <-0.0335113, -0.2224108, -0.9743769>,
    <-0.0335113, -0.2224108, -0.9743769>,
    <-0.0302898, -0.1657078, -0.9857096>,
    <-0.0635669, -0.3477583, -0.9354269>,
    <-0.0635669, -0.3477583, -0.9354269>,
    <-0.1118536, -0.6119224, -0.7829686>,
    <-0.1535213, -0.9048173, -0.3971611>,
    <-0.1463369, -0.9197800, -0.3641294>,
    <-0.1118536, -0.6119224, -0.7829686>,
    <-0.1618285, -0.8853226, -0.4359076>,
    <-0.1618285, -0.8853226, -0.4359076>,
    <-0.1798026, -0.9836545, 0.0097355>,
    <-0.1693426, -0.9855137, 0.0092657>,
    <-0.1693426, -0.9855137, 0.0092657>,
    <-0.1605629, -0.9869857, 0.0088712>,
    <-0.1400938, -0.9314731, -0.3357554>,
    <-0.1079638, -0.7490918, -0.6536095>,
    <-0.1605629, -0.9869857, 0.0088712>,
    <-0.1530904, -0.9881753, 0.0085354>,
    <-0.1530904, -0.9881753, 0.0085354>,
    <-0.1466544, -0.9891534, 0.0082461>,
    <-0.1346375, -0.9407615, -0.3111923>,
    <-0.1346375, -0.9407615, -0.3111923>,
    <-0.1063062, -0.7807166, -0.6157764>,
    <-0.0703159, -0.5214845, -0.8503585>,
    <-0.1063062, -0.7807166, -0.6157764>,
    <-0.0717927, -0.5686019, -0.8194740>,
    <-0.0717927, -0.5686019, -0.8194740>,
    <-0.0419808, -0.3781463, -0.9247935>,
    <-0.0393689, -0.3289623, -0.9435221>,
    <-0.0393689, -0.3289623, -0.9435221>,
    <-0.0365428, -0.2769570, -0.9601872>,
    <-0.4347988, -0.8955530, -0.0945242>,
    <-0.4277094, -0.8832676, -0.1921017>,
    <-0.4474863, -0.8738858, -0.1899461>,
    <-0.4543800, -0.8858841, -0.0935316>,
    <-0.4569573, -0.8894851, 0.0025216>,
    <-0.4376511, -0.8991408, 0.0027153>,
    <-0.4376511, -0.8991408, 0.0027153>,
    <-0.4176624, -0.9085976, 0.0029125>,
    <-0.4145213, -0.9050154, -0.0954944>,
    <-0.4145213, -0.9050154, -0.0954944>,
    <-0.4072389, -0.8924336, -0.1942130>,
    <-0.4165475, -0.8625568, -0.2872001>,
    <-0.4364256, -0.8537413, -0.2840042>,
    <-0.4072389, -0.8924336, -0.1942130>,
    <-0.3959953, -0.8711474, -0.2903272>,
    <-0.3959953, -0.8711474, -0.2903272>,
    <-0.3813068, -0.8421931, -0.3812032>,
    <-0.4018166, -0.8343954, -0.3772636>,
    <-0.4018166, -0.8343954, -0.3772636>,
    <-0.4216870, -0.8263660, -0.3732282>,
    <-0.4556319, -0.8447357, -0.2807512>,
    <-0.4665739, -0.8643246, -0.1877544>,
    <-0.4216870, -0.8263660, -0.3732282>,
    <-0.4409176, -0.8181370, -0.3691118>,
    <-0.4409176, -0.8181370, -0.3691118>,
    <-0.4595111, -0.8097387, -0.3649284>,
    <-0.4741714, -0.8355727, -0.2774523>,
    <-0.4741714, -0.8355727, -0.2774523>,
    <-0.4849793, -0.8546181, -0.1855340>,
    <-0.4732705, -0.8760451, -0.0925204>,
    <-0.4849793, -0.8546181, -0.1855340>,
    <-0.4914783, -0.8660704, -0.0914941>,
    <-0.4914783, -0.8660704, -0.0914941>,
    <-0.4935473, -0.8697163, 0.0021450>,
    <-0.4755866, -0.8796658, 0.0023314>,
    <-0.4755866, -0.8796658, 0.0023314>,
    <-0.4569573, -0.8894851, 0.0025216>,
    <0.9998508, -0.0006848, -0.0172627>,
    <0.9998527, -0.0006848, -0.0171518>,
    <0.9998528, -0.0006593, -0.0171440>,
    <0.9998509, -0.0006593, -0.0172530>,
    <0.9998491, -0.0006593, -0.0173619>,
    <0.9998488, -0.0006848, -0.0173736>,
    <0.9998488, -0.0006848, -0.0173736>,
    <0.9998486, -0.0007113, -0.0173858>,
    <0.9998506, -0.0007113, -0.0172729>,
    <0.9998506, -0.0007113, -0.0172729>,
    <0.9998525, -0.0007113, -0.0171599>,
    <0.9998546, -0.0006848, -0.0170410>,
    <0.9998547, -0.0006593, -0.0170351>,
    <0.9998525, -0.0007113, -0.0171599>,
    <0.9998544, -0.0007113, -0.0170470>,
    <0.9998544, -0.0007113, -0.0170470>,
    <0.9998564, -0.0007113, -0.0169341>,
    <0.9998564, -0.0006848, -0.0169301>,
    <0.9998564, -0.0006848, -0.0169301>,
    <0.9998565, -0.0006593, -0.0169262>,
    <0.9998548, -0.0006347, -0.0170295>,
    <0.9998530, -0.0006347, -0.0171365>,
    <0.9998565, -0.0006593, -0.0169262>,
    <0.9998566, -0.0006347, -0.0169225>,
    <0.9998566, -0.0006347, -0.0169225>,
    <0.9998567, -0.0006109, -0.0169189>,
    <0.9998549, -0.0006109, -0.0170241>,
    <0.9998549, -0.0006109, -0.0170241>,
    <0.9998531, -0.0006109, -0.0171292>,
    <0.9998511, -0.0006347, -0.0172435>,
    <0.9998531, -0.0006109, -0.0171292>,
    <0.9998513, -0.0006109, -0.0172344>,
    <0.9998513, -0.0006109, -0.0172344>,
    <0.9998495, -0.0006109, -0.0173396>,
    <0.9998493, -0.0006347, -0.0173505>,
    <0.9998493, -0.0006347, -0.0173505>,
    <0.9998491, -0.0006593, -0.0173619>,
    <0.1528590, 0.9823322, 0.1079703>,
    <0.1537707, 0.9855089, 0.0716019>,
    <0.1623861, 0.9841359, 0.0714657>,
    <0.1615861, 0.9809612, 0.1077268>,
    <0.1605452, 0.9763635, 0.1447054>,
    <0.1517144, 0.9777221, 0.1450592>,
    <0.1517144, 0.9777221, 0.1450592>,
    <0.1428198, 0.9790099, 0.1454033>,
    <0.1440693, 0.9836338, 0.1082067>,
    <0.1440693, 0.9836338, 0.1082067>,
    <0.1450940, 0.9868141, 0.0717334>,
    <0.1544617, 0.9873400, 0.0360747>,
    <0.1629585, 0.9859744, 0.0360417>,
    <0.1450940, 0.9868141, 0.0717334>,
    <0.1459052, 0.9886395, 0.0361052>,
    <0.1459052, 0.9886395, 0.0361052>,
    <0.1465156, 0.9892073, 0.0014244>,
    <0.1549461, 0.9879218, 0.0014899>,
    <0.1549461, 0.9879218, 0.0014899>,
    <0.1633184, 0.9865722, 0.0015550>,
    <0.1713941, 0.9845444, 0.0360062>,
    <0.1709387, 0.9826966, 0.0713249>,
    <0.1633184, 0.9865722, 0.0015550>,
    <0.1716312, 0.9851599, 0.0016195>,
    <0.1716312, 0.9851599, 0.0016195>,
    <0.1798835, 0.9836865, 0.0016836>,
    <0.1797674, 0.9830514, 0.0359683>,
    <0.1797674, 0.9830514, 0.0359683>,
    <0.1794275, 0.9811928, 0.0711797>,
    <0.1702492, 0.9795224, 0.1074765>,
    <0.1794275, 0.9811928, 0.0711797>,
    <0.1788468, 0.9780173, 0.1072194>,
    <0.1788468, 0.9780173, 0.1072194>,
    <0.1780098, 0.9734398, 0.1439701>,
    <0.1693108, 0.9749355, 0.1443423>,
    <0.1693108, 0.9749355, 0.1443423>,
    <0.1605452, 0.9763635, 0.1447054>,
    <-0.4935128, -0.8696267, 0.0139473>,
    <-0.4935170, -0.8696341, 0.0133223>,
    <-0.4935284, -0.8696271, 0.0133618>,
    <-0.4935243, -0.8696199, 0.0139666>,
    <-0.4935200, -0.8696124, 0.0145714>,
    <-0.4935084, -0.8696189, 0.0145722>,
    <-0.4935084, -0.8696189, 0.0145722>,
    <-0.4934960, -0.8696260, 0.0145731>,
    <-0.4935005, -0.8696340, 0.0139266>,
    <-0.4935005, -0.8696340, 0.0139266>,
    <-0.4935049, -0.8696416, 0.0132801>,
    <-0.4935210, -0.8696412, 0.0126973>,
    <-0.4935323, -0.8696339, 0.0127570>,
    <-0.4935049, -0.8696416, 0.0132801>,
    <-0.4935090, -0.8696489, 0.0126336>,
    <-0.4935090, -0.8696489, 0.0126336>,
    <-0.4935129, -0.8696558, 0.0119871>,
    <-0.4935248, -0.8696479, 0.0120724>,
    <-0.4935248, -0.8696479, 0.0120724>,
    <-0.4935360, -0.8696405, 0.0121521>,
    <-0.4935428, -0.8696271, 0.0128129>,
    <-0.4935390, -0.8696204, 0.0133988>,
    <-0.4935360, -0.8696405, 0.0121521>,
    <-0.4935464, -0.8696335, 0.0122270>,
    <-0.4935464, -0.8696335, 0.0122270>,
    <-0.4935562, -0.8696270, 0.0122972>,
    <-0.4935527, -0.8696207, 0.0128654>,
    <-0.4935527, -0.8696207, 0.0128654>,
    <-0.4935490, -0.8696142, 0.0134336>,
    <-0.4935350, -0.8696135, 0.0139847>,
    <-0.4935490, -0.8696142, 0.0134336>,
    <-0.4935451, -0.8696075, 0.0140018>,
    <-0.4935451, -0.8696075, 0.0140018>,
    <-0.4935411, -0.8696004, 0.0145699>,
    <-0.4935309, -0.8696062, 0.0145706>,
    <-0.4935309, -0.8696062, 0.0145706>,
    <-0.4935200, -0.8696124, 0.0145714>,
    <0.1886155, -0.0001121, -0.9820510>,
    <0.1886387, -0.0001122, -0.9820466>,
    <0.1886398, -0.0001091, -0.9820463>,
    <0.1886169, -0.0001091, -0.9820507>,
    <0.1885939, -0.0001091, -0.9820551>,
    <0.1885923, -0.0001121, -0.9820555>,
    <0.1885923, -0.0001121, -0.9820555>,
    <0.1885906, -0.0001152, -0.9820558>,
    <0.1886141, -0.0001152, -0.9820513>,
    <0.1886141, -0.0001152, -0.9820513>,
    <0.1886376, -0.0001152, -0.9820468>,
    <0.1886619, -0.0001122, -0.9820421>,
    <0.1886627, -0.0001092, -0.9820419>,
    <0.1886376, -0.0001152, -0.9820468>,
    <0.1886611, -0.0001153, -0.9820423>,
    <0.1886611, -0.0001153, -0.9820423>,
    <0.1886845, -0.0001153, -0.9820377>,
    <0.1886851, -0.0001122, -0.9820376>,
    <0.1886851, -0.0001122, -0.9820376>,
    <0.1886856, -0.0001092, -0.9820375>,
    <0.1886635, -0.0001062, -0.9820418>,
    <0.1886408, -0.0001062, -0.9820461>,
    <0.1886856, -0.0001092, -0.9820375>,
    <0.1886862, -0.0001062, -0.9820374>,
    <0.1886862, -0.0001062, -0.9820374>,
    <0.1886867, -0.0001034, -0.9820373>,
    <0.1886643, -0.0001033, -0.9820416>,
    <0.1886643, -0.0001033, -0.9820416>,
    <0.1886419, -0.0001033, -0.9820459>,
    <0.1886182, -0.0001062, -0.9820505>,
    <0.1886419, -0.0001033, -0.9820459>,
    <0.1886195, -0.0001033, -0.9820502>,
    <0.1886195, -0.0001033, -0.9820502>,
    <0.1885971, -0.0001033, -0.9820545>,
    <0.1885955, -0.0001062, -0.9820548>,
    <0.1885955, -0.0001062, -0.9820548>,
    <0.1885939, -0.0001091, -0.9820551>,
    <0.1798765, 0.9836142, 0.0121470>,
    <0.1798770, 0.9836170, 0.0119110>,
    <0.1798827, 0.9836161, 0.0118961>,
    <0.1798822, 0.9836134, 0.0121244>,
    <0.1798817, 0.9836107, 0.0123528>,
    <0.1798760, 0.9836114, 0.0123829>,
    <0.1798760, 0.9836114, 0.0123829>,
    <0.1798699, 0.9836121, 0.0124151>,
    <0.1798705, 0.9836150, 0.0121710>,
    <0.1798705, 0.9836150, 0.0121710>,
    <0.1798710, 0.9836179, 0.0119270>,
    <0.1798775, 0.9836197, 0.0116751>,
    <0.1798831, 0.9836188, 0.0116678>,
    <0.1798710, 0.9836179, 0.0119270>,
    <0.1798715, 0.9836207, 0.0116829>,
    <0.1798715, 0.9836207, 0.0116829>,
    <0.1798720, 0.9836235, 0.0114388>,
    <0.1798780, 0.9836224, 0.0114391>,
    <0.1798780, 0.9836224, 0.0114391>,
    <0.1798836, 0.9836214, 0.0114394>,
    <0.1798884, 0.9836179, 0.0116609>,
    <0.1798879, 0.9836153, 0.0118821>,
    <0.1798836, 0.9836214, 0.0114394>,
    <0.1798889, 0.9836204, 0.0114397>,
    <0.1798889, 0.9836204, 0.0114397>,
    <0.1798938, 0.9836195, 0.0114400>,
    <0.1798933, 0.9836171, 0.0116545>,
    <0.1798933, 0.9836171, 0.0116545>,
    <0.1798929, 0.9836146, 0.0118690>,
    <0.1798875, 0.9836127, 0.0121033>,
    <0.1798929, 0.9836146, 0.0118690>,
    <0.1798924, 0.9836121, 0.0120835>,
    <0.1798924, 0.9836121, 0.0120835>,
    <0.1798920, 0.9836095, 0.0122980>,
    <0.1798870, 0.9836101, 0.0123245>,
    <0.1798870, 0.9836101, 0.0123245>,
    <0.1798817, 0.9836107, 0.0123528>,
    <-0.4932270, -0.8698992, 0.0016126>,
    <-0.4932276, -0.8698942, 0.0032474>,
    <-0.4905562, -0.8713009, 0.0137574>,
    <-0.4905945, -0.8713630, 0.0065962>,
    <-0.4907487, -0.8713011, 0.0000024>,
    <-0.4932312, -0.8698982, 0.0000024>,
    <-0.4932312, -0.8698982, 0.0000024>,
    <-0.4935935, -0.8696927, 0.0000024>,
    <-0.4935935, -0.8696927, 0.0000023>,
    <-0.4935935, -0.8696927, 0.0000023>,
    <-0.4935935, -0.8696927, 0.0000022>,
    <-0.4932312, -0.8698846, 0.0048697>,
    <-0.4906341, -0.8711136, 0.0209607>,
    <-0.4935935, -0.8696927, 0.0000022>,
    <-0.4935935, -0.8696927, 0.0000021>,
    <-0.4935935, -0.8696927, 0.0000021>,
    <-0.4935935, -0.8696927, 0.0000020>,
    <-0.4932299, -0.8698749, 0.0064715>,
    <-0.4932299, -0.8698749, 0.0064715>,
    <-0.4906286, -0.8709211, 0.0279272>,
    <-0.4834834, -0.8737139, 0.0535524>,
    <-0.4830387, -0.8749107, 0.0347105>,
    <-0.4906286, -0.8709211, 0.0279272>,
    <-0.4834444, -0.8724411, 0.0716107>,
    <-0.4834444, -0.8724411, 0.0716107>,
    <-0.4681922, -0.8689935, 0.1601450>,
    <-0.4694776, -0.8747706, 0.1198633>,
    <-0.4690172, -0.8796178, 0.0793433>,
    <-0.4831981, -0.8753646, 0.0160118>,
    <-0.4684035, -0.8825873, 0.0404689>,
    <-0.4732875, -0.8809041, 0.0026299>,
    <-0.4844174, -0.8748370, 0.0000025>,
    <-0.4844174, -0.8748370, 0.0000025>,
    <-0.4907487, -0.8713011, 0.0000024>,
    <0.9990825, -0.0005461, -0.0428231>,
    <0.9990827, -0.0005461, -0.0428194>,
    <0.9831797, -0.0005300, -0.1826399>,
    <0.9831770, -0.0005300, -0.1826548>,
    <0.9831742, -0.0005300, -0.1826698>,
    <0.9990824, -0.0005461, -0.0428267>,
    <0.9990824, -0.0005461, -0.0428267>,
    <0.9999995, -0.0005477, -0.0008604>,
    <0.9999995, -0.0005477, -0.0008602>,
    <0.9999995, -0.0005477, -0.0008602>,
    <0.9999995, -0.0005477, -0.0008601>,
    <0.9990828, -0.0005461, -0.0428157>,
    <0.9831825, -0.0005300, -0.1826250>,
    <0.9999995, -0.0005477, -0.0008601>,
    <0.9999995, -0.0005477, -0.0008600>,
    <0.9999995, -0.0005477, -0.0008600>,
    <0.9999995, -0.0005477, -0.0008599>,
    <0.9990830, -0.0005461, -0.0428121>,
    <0.9990830, -0.0005461, -0.0428121>,
    <0.9831853, -0.0005300, -0.1826101>,
    <0.8941700, -0.0004644, -0.4477273>,
    <0.8941551, -0.0004644, -0.4477571>,
    <0.9831853, -0.0005300, -0.1826101>,
    <0.8941849, -0.0004644, -0.4476975>,
    <0.8941849, -0.0004644, -0.4476975>,
    <0.6281233, -0.0003032, -0.7781137>,
    <0.6280926, -0.0003032, -0.7781385>,
    <0.6280619, -0.0003032, -0.7781633>,
    <0.8941402, -0.0004644, -0.4477869>,
    <0.6280312, -0.0003032, -0.7781881>,
    <0.6280005, -0.0003031, -0.7782129>,
    <0.8941253, -0.0004644, -0.4478166>,
    <0.8941253, -0.0004644, -0.4478166>,
    <0.9831742, -0.0005300, -0.1826698>,
    <0.1797410, 0.9837125, -0.0016805>,
    <0.1797430, 0.9837130, -0.0011033>,
    <0.1785709, 0.9839159, -0.0046738>,
    <0.1785903, 0.9838970, -0.0072269>,
    <0.1786081, 0.9838720, -0.0097525>,
    <0.1797406, 0.9837114, -0.0022621>,
    <0.1797406, 0.9837114, -0.0022621>,
    <0.1799056, 0.9836839, 0.0000020>,
    <0.1799056, 0.9836839, 0.0000020>,
    <0.1799056, 0.9836839, 0.0000020>,
    <0.1799056, 0.9836839, 0.0000020>,
    <0.1797468, 0.9837128, -0.0005410>,
    <0.1786120, 0.9839171, -0.0022176>,
    <0.1799056, 0.9836839, 0.0000020>,
    <0.1799056, 0.9836839, 0.0000019>,
    <0.1799056, 0.9836839, 0.0000019>,
    <0.1799056, 0.9836839, 0.0000019>,
    <0.1797500, 0.9837123, 0.0000019>,
    <0.1797500, 0.9837123, 0.0000019>,
    <0.1786866, 0.9839060, 0.0000019>,
    <0.1754813, 0.9844690, -0.0052155>,
    <0.1753361, 0.9844397, -0.0116538>,
    <0.1786866, 0.9839060, 0.0000019>,
    <0.1760417, 0.9843827, 0.0000019>,
    <0.1760417, 0.9843827, 0.0000019>,
    <0.1719493, 0.9851041, 0.0018113>,
    <0.1694499, 0.9854647, -0.0120892>,
    <0.1696164, 0.9851646, -0.0260942>,
    <0.1755718, 0.9842953, -0.0183637>,
    <0.1703640, 0.9845360, -0.0408044>,
    <0.1708014, 0.9837313, -0.0556743>,
    <0.1757337, 0.9841224, -0.0249169>,
    <0.1757337, 0.9841224, -0.0249169>,
    <0.1786081, 0.9838720, -0.0097525>,
    <-0.4516898, -0.8853808, 0.1098958>,
    <-0.4509098, -0.8785137, 0.1577785>,
    <-0.4385021, -0.8732636, 0.2124300>,
    <-0.4421987, -0.8809854, 0.1683002>,
    <-0.4481903, -0.8921035, 0.0572432>,
    <-0.4560135, -0.8882394, 0.0555203>,
    <-0.4560135, -0.8882394, 0.0555203>,
    <-0.4732875, -0.8809041, 0.0026299>,
    <-0.4483415, -0.8663137, 0.2202057>,
    <-0.4320140, -0.8597113, 0.2725075>,
    <-0.4681922, -0.8689935, 0.1601450>,
    <-0.4416745, -0.8496326, 0.2881806>,
    <-0.4416745, -0.8496326, 0.2881806>,
    <-0.4213719, -0.8382367, 0.3461286>,
    <-0.4314589, -0.8788040, 0.2038304>,
    <-0.4372380, -0.8859469, 0.1546642>,
    <-0.4213719, -0.8382367, 0.3461286>,
    <-0.4247184, -0.8673077, 0.2595990>,
    <-0.4247184, -0.8673077, 0.2595990>,
    <-0.4304872, -0.8946443, 0.1195502>,
    <-0.4323262, -0.8970446, 0.0916794>,
    <-0.4342888, -0.8985334, 0.0634894>,
    <-0.4412498, -0.8902770, 0.1127186>,
    <-0.4357788, -0.8994062, 0.0341353>,
    <-0.4343342, -0.9007433, 0.0039179>,
    <-0.4419903, -0.8951037, 0.0586000>,
    <-0.4419903, -0.8951037, 0.0586000>,
    <-0.4481903, -0.8921035, 0.0572432>,
    <0.3569395, -0.0001533, -0.9341275>,
    <0.3569636, -0.0001533, -0.9341183>,
    <0.2613339, -0.0000968, -0.9652484>,
    <0.2613160, -0.0000968, -0.9652533>,
    <0.2612981, -0.0000968, -0.9652581>,
    <0.3569154, -0.0001532, -0.9341367>,
    <0.3569154, -0.0001532, -0.9341367>,
    <0.6280005, -0.0003031, -0.7782129>,
    <0.3569876, -0.0001533, -0.9341091>,
    <0.2613518, -0.0000969, -0.9652436>,
    <0.6281233, -0.0003032, -0.7781137>,
    <0.3570117, -0.0001533, -0.9340999>,
    <0.3570117, -0.0001533, -0.9340999>,
    <0.2613697, -0.0000969, -0.9652388>,
    <0.3095899, -0.0000981, -0.9508702>,
    <0.3095702, -0.0000981, -0.9508766>,
    <0.2613697, -0.0000969, -0.9652388>,
    <0.3096096, -0.0000981, -0.9508638>,
    <0.3096096, -0.0000981, -0.9508638>,
    <0.5397936, -0.0001488, -0.8417974>,
    <0.5397675, -0.0001488, -0.8418141>,
    <0.5397414, -0.0001488, -0.8418308>,
    <0.3095506, -0.0000981, -0.9508830>,
    <0.5397154, -0.0001488, -0.8418475>,
    <0.5396893, -0.0001488, -0.8418642>,
    <0.3095309, -0.0000981, -0.9508894>,
    <0.3095309, -0.0000981, -0.9508894>,
    <0.2612981, -0.0000968, -0.9652581>,
    <0.1641275, 0.9835956, -0.0748463>,
    <0.1633033, 0.9852626, -0.0508886>,
    <0.1594133, 0.9849136, -0.0673247>,
    <0.1591928, 0.9829450, -0.0920696>,
    <0.1587227, 0.9797268, -0.1222398>,
    <0.1643746, 0.9811649, -0.1014715>,
    <0.1643746, 0.9811649, -0.1014715>,
    <0.1708014, 0.9837313, -0.0556743>,
    <0.1630548, 0.9861497, -0.0303632>,
    <0.1595961, 0.9861817, -0.0444378>,
    <0.1719493, 0.9851041, 0.0018113>,
    <0.1686518, 0.9850482, 0.0351660>,
    <0.1686518, 0.9850482, 0.0351660>,
    <0.1599801, 0.9865454, 0.0336825>,
    <0.1569679, 0.9872087, -0.0279288>,
    <0.1566597, 0.9865185, -0.0473182>,
    <0.1599801, 0.9865454, 0.0336825>,
    <0.1538241, 0.9875594, 0.0326290>,
    <0.1538241, 0.9875594, 0.0326290>,
    <0.1527728, 0.9882591, 0.0020999>,
    <0.1537191, 0.9880791, -0.0083706>,
    <0.1536875, 0.9879398, -0.0188414>,
    <0.1558838, 0.9855271, -0.0666080>,
    <0.1533728, 0.9877434, -0.0289796>,
    <0.1531335, 0.9874344, -0.0390310>,
    <0.1552882, 0.9839324, -0.0881055>,
    <0.1552882, 0.9839324, -0.0881055>,
    <0.1587227, 0.9797268, -0.1222398>,
    <-0.4307522, -0.9024093, 0.0104891>,
    <-0.4306012, -0.9022708, 0.0221350>,
    <-0.4289304, -0.9033124, 0.0067396>,
    <-0.4289496, -0.9033222, 0.0033581>,
    <-0.4289283, -0.9033385, 0.0001944>,
    <-0.4304757, -0.9026021, 0.0001933>,
    <-0.4304757, -0.9026021, 0.0001933>,
    <-0.4343342, -0.9007433, 0.0039179>,
    <-0.4302011, -0.9021181, 0.0333146>,
    <-0.4288794, -0.9033060, 0.0100361>,
    <-0.4304872, -0.8946443, 0.1195502>,
    <-0.4298771, -0.9018188, 0.0439137>,
    <-0.4298771, -0.9018188, 0.0439137>,
    <-0.4288449, -0.9032821, 0.0131708>,
    <-0.4285782, -0.9035047, -0.0002094>,
    <-0.4285802, -0.9035037, -0.0000500>,
    <-0.4288449, -0.9032821, 0.0131708>,
    <-0.4285775, -0.9035049, -0.0003844>,
    <-0.4285775, -0.9035049, -0.0003844>,
    <-0.4287922, -0.9033928, -0.0043306>,
    <-0.4287941, -0.9033966, -0.0031993>,
    <-0.4287941, -0.9033966, -0.0031993>,
    <-0.4287953, -0.9033993, -0.0020681>,
    <-0.4285824, -0.9035027, 0.0000817>,
    <-0.4287953, -0.9033993, -0.0020681>,
    <-0.4287961, -0.9034008, -0.0009368>,
    <-0.4287961, -0.9034008, -0.0009368>,
    <-0.4287962, -0.9034012, 0.0001945>,
    <-0.4285833, -0.9035023, 0.0001946>,
    <-0.4285833, -0.9035023, 0.0001946>,
    <-0.4289283, -0.9033385, 0.0001944>,
    <0.8324089, -0.0002080, -0.5541619>,
    <0.8324262, -0.0002080, -0.5541359>,
    <0.9628647, -0.0002270, -0.2699842>,
    <0.9628598, -0.0002270, -0.2700017>,
    <0.9628549, -0.0002270, -0.2700193>,
    <0.8323916, -0.0002080, -0.5541879>,
    <0.8323916, -0.0002080, -0.5541879>,
    <0.5396893, -0.0001488, -0.8418642>,
    <0.8324435, -0.0002080, -0.5541099>,
    <0.9628696, -0.0002270, -0.2699667>,
    <0.5397936, -0.0001488, -0.8417974>,
    <0.8324608, -0.0002080, -0.5540838>,
    <0.8324608, -0.0002080, -0.5540838>,
    <0.9628745, -0.0002270, -0.2699492>,
    <0.9945504, -0.0002276, -0.1042570>,
    <0.9945495, -0.0002276, -0.1042651>,
    <0.9628745, -0.0002270, -0.2699492>,
    <0.9945512, -0.0002276, -0.1042489>,
    <0.9945512, -0.0002276, -0.1042489>,
    <0.9985910, -0.0002252, -0.0530654>,
    <0.9985908, -0.0002252, -0.0530703>,
    <0.9985908, -0.0002252, -0.0530703>,
    <0.9985905, -0.0002252, -0.0530752>,
    <0.9945487, -0.0002276, -0.1042733>,
    <0.9985905, -0.0002252, -0.0530752>,
    <0.9985902, -0.0002252, -0.0530801>,
    <0.9985902, -0.0002252, -0.0530801>,
    <0.9985900, -0.0002252, -0.0530850>,
    <0.9945478, -0.0002276, -0.1042814>,
    <0.9945478, -0.0002276, -0.1042814>,
    <0.9628549, -0.0002270, -0.2700193>,
    <0.1518804, 0.9883457, -0.0102500>,
    <0.1519275, 0.9883707, -0.0064262>,
    <0.1512521, 0.9884936, -0.0017943>,
    <0.1512552, 0.9884906, -0.0028783>,
    <0.1512534, 0.9884870, -0.0039735>,
    <0.1518353, 0.9883068, -0.0139880>,
    <0.1518353, 0.9883068, -0.0139880>,
    <0.1531335, 0.9874344, -0.0390310>,
    <0.1518725, 0.9883963, -0.0027439>,
    <0.1512393, 0.9884969, -0.0007866>,
    <0.1527728, 0.9882591, 0.0020999>,
    <0.1517346, 0.9884213, 0.0001016>,
    <0.1517346, 0.9884213, 0.0001016>,
    <0.1512258, 0.9884992, 0.0001014>,
    <0.1511230, 0.9885150, 0.0001951>,
    <0.1511243, 0.9885147, 0.0002824>,
    <0.1512258, 0.9884992, 0.0001014>,
    <0.1511226, 0.9885150, 0.0001013>,
    <0.1511226, 0.9885150, 0.0001013>,
    <0.1512185, 0.9885004, 0.0001014>,
    <0.1512185, 0.9885002, 0.0005004>,
    <0.1512185, 0.9885002, 0.0005004>,
    <0.1512184, 0.9885000, 0.0008994>,
    <0.1511257, 0.9885145, 0.0003556>,
    <0.1512184, 0.9885000, 0.0008994>,
    <0.1512183, 0.9884995, 0.0012984>,
    <0.1512183, 0.9884995, 0.0012984>,
    <0.1512183, 0.9884989, 0.0016974>,
    <0.1511262, 0.9885144, 0.0004198>,
    <0.1511262, 0.9885144, 0.0004198>,
    <0.1512534, 0.9884870, -0.0039735>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999971, 0.0023761, 0.0004916>,
    <0.9999970, 0.0023761, 0.0005084>,
    <0.9999970, 0.0023971, 0.0005084>,
    <0.9999970, 0.0023971, 0.0004915>,
    <0.9999970, 0.0023971, 0.0004747>,
    <0.9999971, 0.0023761, 0.0004747>,
    <0.9999971, 0.0023761, 0.0004747>,
    <0.9999971, 0.0023551, 0.0004747>,
    <0.9999971, 0.0023551, 0.0004916>,
    <0.9999971, 0.0023551, 0.0004916>,
    <0.9999971, 0.0023551, 0.0005084>,
    <0.9999970, 0.0023761, 0.0005253>,
    <0.9999970, 0.0023971, 0.0005253>,
    <0.9999971, 0.0023551, 0.0005084>,
    <0.9999971, 0.0023551, 0.0005253>,
    <0.9999971, 0.0023551, 0.0005253>,
    <0.9999971, 0.0023551, 0.0005422>,
    <0.9999970, 0.0023761, 0.0005422>,
    <0.9999970, 0.0023761, 0.0005422>,
    <0.9999970, 0.0023971, 0.0005422>,
    <0.9999969, 0.0024181, 0.0005253>,
    <0.9999969, 0.0024181, 0.0005084>,
    <0.9999970, 0.0023971, 0.0005422>,
    <0.9999969, 0.0024181, 0.0005422>,
    <0.9999969, 0.0024181, 0.0005422>,
    <0.9999969, 0.0024391, 0.0005422>,
    <0.9999969, 0.0024391, 0.0005253>,
    <0.9999969, 0.0024391, 0.0005253>,
    <0.9999969, 0.0024391, 0.0005084>,
    <0.9999970, 0.0024181, 0.0004915>,
    <0.9999969, 0.0024391, 0.0005084>,
    <0.9999969, 0.0024391, 0.0004915>,
    <0.9999969, 0.0024391, 0.0004915>,
    <0.9999969, 0.0024391, 0.0004746>,
    <0.9999970, 0.0024181, 0.0004747>,
    <0.9999970, 0.0024181, 0.0004747>,
    <0.9999970, 0.0023971, 0.0004747>,
    <-0.9880153, -0.0010378, -0.1543523>,
    <-0.9880215, -0.0014650, -0.1543090>,
    <-0.9872063, -0.0014638, -0.1594412>,
    <-0.9872024, -0.0010370, -0.1594691>,
    <-0.9871982, -0.0006128, -0.1594969>,
    <-0.9880090, -0.0006133, -0.1543952>,
    <-0.9880090, -0.0006133, -0.1543952>,
    <-0.9887946, -0.0006137, -0.1492812>,
    <-0.9888030, -0.0010387, -0.1492229>,
    <-0.9888030, -0.0010387, -0.1492229>,
    <-0.9888113, -0.0014661, -0.1491643>,
    <-0.9880276, -0.0018947, -0.1542655>,
    <-0.9872101, -0.0018931, -0.1594131>,
    <-0.9888113, -0.0014661, -0.1491643>,
    <-0.9888195, -0.0018962, -0.1491053>,
    <-0.9888195, -0.0018962, -0.1491053>,
    <-0.9888275, -0.0023288, -0.1490459>,
    <-0.9880335, -0.0023269, -0.1542217>,
    <-0.9880335, -0.0023269, -0.1542217>,
    <-0.9872138, -0.0023250, -0.1593848>,
    <-0.9863673, -0.0018915, -0.1645477>,
    <-0.9863659, -0.0014625, -0.1645605>,
    <-0.9872138, -0.0023250, -0.1593848>,
    <-0.9863685, -0.0023230, -0.1645349>,
    <-0.9863685, -0.0023230, -0.1645349>,
    <-0.9854979, -0.0023209, -0.1696715>,
    <-0.9854993, -0.0018898, -0.1696690>,
    <-0.9854993, -0.0018898, -0.1696690>,
    <-0.9855004, -0.0014612, -0.1696666>,
    <-0.9863643, -0.0010361, -0.1645732>,
    <-0.9855004, -0.0014612, -0.1696666>,
    <-0.9855014, -0.0010352, -0.1696641>,
    <-0.9855014, -0.0010352, -0.1696641>,
    <-0.9855022, -0.0006117, -0.1696616>,
    <-0.9863626, -0.0006122, -0.1645858>,
    <-0.9863626, -0.0006122, -0.1645858>,
    <-0.9871982, -0.0006128, -0.1594969>,
    <0.9999998, 0.0006195, 0.0000080>,
    <0.9999998, 0.0006195, 0.0000082>,
    <0.9999998, 0.0006199, 0.0000082>,
    <0.9999998, 0.0006199, 0.0000080>,
    <0.9999998, 0.0006199, 0.0000077>,
    <0.9999998, 0.0006195, 0.0000077>,
    <0.9999998, 0.0006195, 0.0000077>,
    <0.9999998, 0.0006191, 0.0000077>,
    <0.9999998, 0.0006191, 0.0000080>,
    <0.9999998, 0.0006191, 0.0000080>,
    <0.9999998, 0.0006191, 0.0000082>,
    <0.9999998, 0.0006195, 0.0000085>,
    <0.9999998, 0.0006199, 0.0000085>,
    <0.9999998, 0.0006191, 0.0000082>,
    <0.9999998, 0.0006191, 0.0000085>,
    <0.9999998, 0.0006191, 0.0000085>,
    <0.9999998, 0.0006191, 0.0000088>,
    <0.9999998, 0.0006195, 0.0000088>,
    <0.9999998, 0.0006195, 0.0000088>,
    <0.9999998, 0.0006199, 0.0000088>,
    <0.9999998, 0.0006203, 0.0000085>,
    <0.9999998, 0.0006203, 0.0000082>,
    <0.9999998, 0.0006199, 0.0000088>,
    <0.9999998, 0.0006203, 0.0000088>,
    <0.9999998, 0.0006203, 0.0000088>,
    <0.9999998, 0.0006207, 0.0000088>,
    <0.9999998, 0.0006207, 0.0000085>,
    <0.9999998, 0.0006207, 0.0000085>,
    <0.9999998, 0.0006207, 0.0000082>,
    <0.9999998, 0.0006203, 0.0000080>,
    <0.9999998, 0.0006207, 0.0000082>,
    <0.9999998, 0.0006207, 0.0000080>,
    <0.9999998, 0.0006207, 0.0000080>,
    <0.9999998, 0.0006207, 0.0000077>,
    <0.9999998, 0.0006203, 0.0000077>,
    <0.9999998, 0.0006203, 0.0000077>,
    <0.9999998, 0.0006199, 0.0000077>,
    <-0.9988402, -0.0004293, -0.0481463>,
    <-0.9988403, -0.0004922, -0.0481443>,
    <-0.9987606, -0.0004922, -0.0497705>,
    <-0.9987605, -0.0004292, -0.0497717>,
    <-0.9987605, -0.0003663, -0.0497730>,
    <-0.9988401, -0.0003664, -0.0481483>,
    <-0.9988401, -0.0003664, -0.0481483>,
    <-0.9989171, -0.0003664, -0.0465233>,
    <-0.9989172, -0.0004293, -0.0465205>,
    <-0.9989172, -0.0004293, -0.0465205>,
    <-0.9989173, -0.0004923, -0.0465178>,
    <-0.9988403, -0.0005553, -0.0481423>,
    <-0.9987606, -0.0005552, -0.0497692>,
    <-0.9989173, -0.0004923, -0.0465178>,
    <-0.9989174, -0.0005553, -0.0465151>,
    <-0.9989174, -0.0005553, -0.0465151>,
    <-0.9989175, -0.0006184, -0.0465124>,
    <-0.9988404, -0.0006183, -0.0481403>,
    <-0.9988404, -0.0006183, -0.0481403>,
    <-0.9987606, -0.0006183, -0.0497679>,
    <-0.9986782, -0.0005552, -0.0513956>,
    <-0.9986782, -0.0004922, -0.0513962>,
    <-0.9987606, -0.0006183, -0.0497679>,
    <-0.9986782, -0.0006182, -0.0513950>,
    <-0.9986782, -0.0006182, -0.0513950>,
    <-0.9985932, -0.0006182, -0.0530217>,
    <-0.9985932, -0.0005551, -0.0530216>,
    <-0.9985932, -0.0005551, -0.0530216>,
    <-0.9985933, -0.0004921, -0.0530215>,
    <-0.9986782, -0.0004292, -0.0513968>,
    <-0.9985933, -0.0004921, -0.0530215>,
    <-0.9985933, -0.0004292, -0.0530214>,
    <-0.9985933, -0.0004292, -0.0530214>,
    <-0.9985933, -0.0003663, -0.0530213>,
    <-0.9986782, -0.0003663, -0.0513974>,
    <-0.9986782, -0.0003663, -0.0513974>,
    <-0.9987605, -0.0003663, -0.0497730>,
    <0.9999459, 0.0002063, 0.0103970>,
    <0.9999458, -0.0000193, 0.0104137>,
    <0.9999351, 0.0001043, 0.0113909>,
    <0.9999381, 0.0001631, 0.0111286>,
    <0.9999388, 0.0001835, 0.0110596>,
    <0.9999388, 0.0002729, 0.0110586>,
    <0.9999388, 0.0002729, 0.0110586>,
    <0.9999761, 0.0009066, 0.0068509>,
    <0.9999747, 0.0005212, 0.0070935>,
    <0.9999731, -0.0000995, 0.0073356>,
    <0.9999371, -0.0002314, 0.0112167>,
    <0.9999287, 0.0000535, 0.0119444>,
    <0.9999710, -0.0007475, 0.0075757>,
    <0.9999688, -0.0011235, 0.0078137>,
    <0.9999205, -0.0002636, 0.0126057>,
    <0.9999205, -0.0002636, 0.0126057>,
    <0.9999205, 0.0000450, 0.0126058>,
    <0.9999261, 0.0002293, 0.0121532>,
    <0.9999312, 0.0002354, 0.0117283>,
    <0.9999205, 0.0000450, 0.0126058>,
    <0.9999205, 0.0002280, 0.0126059>,
    <0.9999205, 0.0002280, 0.0126059>,
    <0.9999205, 0.0003668, 0.0126060>,
    <0.9999253, 0.0003668, 0.0122189>,
    <0.9999253, 0.0003668, 0.0122189>,
    <0.9999299, 0.0003668, 0.0118318>,
    <0.9999353, 0.0002425, 0.0113694>,
    <0.9999299, 0.0003668, 0.0118318>,
    <0.9999344, 0.0003668, 0.0114448>,
    <0.9999344, 0.0003668, 0.0114448>,
    <0.9999388, 0.0003668, 0.0110577>,
    <0.9999388, 0.0002453, 0.0110589>,
    <0.9999388, 0.0002453, 0.0110589>,
    <0.9999388, 0.0001835, 0.0110596>,
    <0.9999919, 0.0006078, -0.0039879>,
    <0.9998053, 0.0002831, -0.0197304>,
    <0.9998841, -0.0000725, -0.0152216>,
    <0.9999997, -0.0001076, -0.0008189>,
    <0.9999761, 0.0009066, 0.0068509>,
    <0.9992146, 0.0026973, -0.0395342>,
    <0.9992146, 0.0026973, -0.0395342>,
    <0.9992150, 0.0006565, -0.0396092>,
    <0.9994324, 0.0000311, -0.0336883>,
    <0.9994854, -0.0000301, -0.0320782>,
    <0.9992150, 0.0006565, -0.0396092>,
    <0.9992144, 0.0000611, -0.0396311>,
    <0.9992144, 0.0000611, -0.0396311>,
    <0.9992143, 0.0000123, -0.0396329>,
    <0.9991586, 0.0000123, -0.0410143>,
    <0.9991586, 0.0000123, -0.0410143>,
    <0.9991009, 0.0000123, -0.0423955>,
    <0.9993480, -0.0000942, -0.0361056>,
    <0.9997689, -0.0004450, -0.0214912>,
    <0.9991009, 0.0000123, -0.0423955>,
    <0.9990414, 0.0000123, -0.0437764>,
    <0.9990414, 0.0000123, -0.0437764>,
    <0.9989799, 0.0000123, -0.0451571>,
    <0.9989799, -0.0001301, -0.0451569>,
    <0.9989799, -0.0001301, -0.0451569>,
    <0.9989796, -0.0008726, -0.0451557>,
    <0.9999888, -0.0008603, -0.0046496>,
    <0.9989796, -0.0008726, -0.0451557>,
    <0.9989749, -0.0032222, -0.0451516>,
    <0.9989749, -0.0032222, -0.0451516>,
    <0.9999688, -0.0011235, 0.0078137>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9514758>,
    <0.4351413, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289899, 0.9514081>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9514758>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559068, 0.9657316>,
    <0.6289899, 0.9514081>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4351413, 0.9657316>,
    <0.5000060, 0.9664312>,
    <0.4264239, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379355, 0.9664305>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664312>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559068, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773683, 0.9671308>,
    <0.6379355, 0.9664305>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4264239, 0.9671308>,
    <0.5000061, 0.9783126>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473428, 0.9784058>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9783126>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773683, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473428, 0.9784058>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032666, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458875>,
    <0.4677608, 0.9457732>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9514758>,
    <0.4355157, 0.9458875>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9453187>,
    <0.4677605, 0.9520459>,
    <0.4676667, 0.9588888>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9514758>,
    <0.5000059, 0.9657316>,
    <0.4351413, 0.9657316>,
    <0.4677605, 0.9520459>,
    <0.5000059, 0.9584708>,
    <0.4675719, 0.9657316>,
    <0.4353447, 0.9585650>,
    <0.4031722, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4351413, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4353447, 0.9585650>,
    <0.4025751, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032666, 0.9526160>,
    <0.5322510, 0.9457732>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9514758>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9520459>,
    <0.5000059, 0.9453187>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458716>,
    <0.5967411, 0.9457562>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289899, 0.9514081>,
    <0.5644961, 0.9458716>,
    <0.5967380, 0.9395004>,
    <0.6289859, 0.9452843>,
    <0.5967441, 0.9520120>,
    <0.5967475, 0.9588718>,
    <0.5644983, 0.9526160>,
    <0.6289899, 0.9514081>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967441, 0.9520120>,
    <0.6289944, 0.9583697>,
    <0.5967509, 0.9657316>,
    <0.5645004, 0.9590138>,
    <0.5322532, 0.9588888>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9514758>,
    <0.5645004, 0.9590138>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9584708>,
    <0.5322521, 0.9520459>,
    <0.6423395, 0.9457562>,
    <0.6556982, 0.9526160>,
    <0.6289899, 0.9514081>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423438, 0.9520120>,
    <0.6289859, 0.9452843>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458871>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458871>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691072, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559068, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694234, 0.9657316>,
    <0.6557925, 0.9585434>,
    <0.6423985, 0.9588718>,
    <0.6556982, 0.9526160>,
    <0.6559068, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289899, 0.9514081>,
    <0.6557925, 0.9585434>,
    <0.6424546, 0.9657316>,
    <0.6289944, 0.9583697>,
    <0.6423438, 0.9520120>,
    <0.3998147, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4351413, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4025751, 0.9657316>,
    <0.4331013, 0.9660793>,
    <0.4665476, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.4351413, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664312>,
    <0.4331013, 0.9660793>,
    <0.4675719, 0.9657316>,
    <0.5000060, 0.9661024>,
    <0.4655215, 0.9664312>,
    <0.4643682, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664312>,
    <0.5000061, 0.9671308>,
    <0.4264239, 0.9671308>,
    <0.4655215, 0.9664312>,
    <0.5000060, 0.9667580>,
    <0.4632096, 0.9671308>,
    <0.4287785, 0.9667737>,
    <0.3931631, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4264239, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4287785, 0.9667737>,
    <0.3896051, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660814>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664312>,
    <0.5000060, 0.9661024>,
    <0.5322542, 0.9657316>,
    <0.5668680, 0.9661016>,
    <0.6001031, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379355, 0.9664305>,
    <0.5668680, 0.9661016>,
    <0.5967509, 0.9657316>,
    <0.6337187, 0.9661007>,
    <0.6034553, 0.9664309>,
    <0.6068117, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.6379355, 0.9664305>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034553, 0.9664309>,
    <0.6421270, 0.9667584>,
    <0.6101681, 0.9671308>,
    <0.5710669, 0.9667584>,
    <0.5356086, 0.9667810>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664312>,
    <0.5710669, 0.9667584>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667580>,
    <0.5344905, 0.9664312>,
    <0.6473367, 0.9660812>,
    <0.6665054, 0.9664312>,
    <0.6379355, 0.9664305>,
    <0.6289992, 0.9657316>,
    <0.6559068, 0.9657316>,
    <0.6522205, 0.9664309>,
    <0.6337187, 0.9661007>,
    <0.6424546, 0.9657316>,
    <0.6611297, 0.9660764>,
    <0.6749742, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559068, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6611297, 0.9660764>,
    <0.6694234, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866641, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773683, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926234, 0.9671308>,
    <0.6718561, 0.9667758>,
    <0.6571745, 0.9667808>,
    <0.6665054, 0.9664312>,
    <0.6773683, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379355, 0.9664305>,
    <0.6718561, 0.9667758>,
    <0.6621309, 0.9671308>,
    <0.6421270, 0.9667584>,
    <0.6522205, 0.9664309>,
    <0.3896483, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4264239, 0.9671308>,
    <0.3895222, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3896051, 0.9671308>,
    <0.4263846, 0.9728421>,
    <0.4631967, 0.9725836>,
    <0.4263507, 0.9777601>,
    <0.4264239, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9783126>,
    <0.4263846, 0.9728421>,
    <0.4632096, 0.9671308>,
    <0.5000061, 0.9726033>,
    <0.4631778, 0.9780364>,
    <0.4631249, 0.9832129>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9783126>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631778, 0.9780364>,
    <0.5000061, 0.9834693>,
    <0.4630714, 0.9883895>,
    <0.4262411, 0.9832055>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262411, 0.9832055>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895222, 0.9777601>,
    <0.5367803, 0.9725836>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9783126>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9780364>,
    <0.5000061, 0.9726033>,
    <0.5367268, 0.9671308>,
    <0.5735529, 0.9723694>,
    <0.6103351, 0.9726069>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473428, 0.9784058>,
    <0.5735529, 0.9723694>,
    <0.6101681, 0.9671308>,
    <0.6471135, 0.9727118>,
    <0.6105021, 0.9780830>,
    <0.6106561, 0.9832362>,
    <0.5736614, 0.9777601>,
    <0.6473428, 0.9784058>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105021, 0.9780830>,
    <0.6475487, 0.9835193>,
    <0.6108101, 0.9883895>,
    <0.5737710, 0.9832025>,
    <0.5368873, 0.9832129>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9783126>,
    <0.5737710, 0.9832025>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9834693>,
    <0.5368338, 0.9780364>,
    <0.6623547, 0.9726069>,
    <0.6778190, 0.9777601>,
    <0.6473428, 0.9784058>,
    <0.6468888, 0.9671308>,
    <0.6773683, 0.9671308>,
    <0.6625811, 0.9780830>,
    <0.6471135, 0.9727118>,
    <0.6621309, 0.9671308>,
    <0.6776116, 0.9728682>,
    <0.6928061, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773683, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776116, 0.9728682>,
    <0.6926234, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930704, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930704, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780837, 0.9832067>,
    <0.6628105, 0.9832362>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473428, 0.9784058>,
    <0.6780837, 0.9832067>,
    <0.6630402, 0.9883895>,
    <0.6475487, 0.9835193>,
    <0.6625811, 0.9780830>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.05, -0.876613, -0.147353>
}

#declare TMesh008 = mesh2 {
  vertex_vectors {
    582,
    <2.2046850, 0.3609944, 18.5058918>,
    <2.0021506, 0.3609820, 18.5058918>,
    <2.0021672, 0.2806104, 18.5058918>,
    <2.2046990, 0.2806255, 18.5058918>,
    <2.1034178, 0.3609882, 18.5058918>,
    <2.0021589, 0.3207962, 18.5058918>,
    <2.1034331, 0.2806180, 18.5058918>,
    <2.2046920, 0.3208099, 18.5058918>,
    <2.1034254, 0.3208031, 18.5058918>,
    <2.4072308, 0.2806405, 18.5058918>,
    <2.4072193, 0.3610067, 18.5058918>,
    <2.3059649, 0.2806330, 18.5058918>,
    <2.4072251, 0.3208236, 18.5058918>,
    <2.3059522, 0.3610006, 18.5058918>,
    <2.3059585, 0.3208168, 18.5058918>,
    <2.4072079, 0.4413729, 18.5058918>,
    <2.2046709, 0.4413633, 18.5058918>,
    <2.4072136, 0.4011898, 18.5058918>,
    <2.3059394, 0.4413681, 18.5058918>,
    <2.2046780, 0.4011788, 18.5058918>,
    <2.3059458, 0.4011843, 18.5058918>,
    <2.0021340, 0.4413536, 18.5058918>,
    <2.1034025, 0.4413585, 18.5058918>,
    <2.0021423, 0.4011678, 18.5058918>,
    <2.1034101, 0.4011733, 18.5058918>,
    <2.0664387, 0.2804708, 18.1207908>,
    <2.0044034, 0.2804603, 18.1202395>,
    <2.0044687, 0.2804559, 18.1217627>,
    <2.0559641, 0.2804663, 18.1217627>,
    <2.0354211, 0.2804656, 18.1205151>,
    <2.0044361, 0.2804581, 18.1210011>,
    <2.0302164, 0.2804611, 18.1217627>,
    <2.0612014, 0.2804686, 18.1212767>,
    <2.0328188, 0.2804633, 18.1211389>,
    <2.1074595, 0.2804767, 18.1217627>,
    <2.1284740, 0.2804813, 18.1213420>,
    <2.0817118, 0.2804715, 18.1217627>,
    <2.1179668, 0.2804790, 18.1215524>,
    <2.0974564, 0.2804761, 18.1210664>,
    <2.0895841, 0.2804738, 18.1214145>,
    <2.1494885, 0.2804860, 18.1209214>,
    <2.0769133, 0.2804753, 18.1198188>,
    <2.1389813, 0.2804837, 18.1211317>,
    <2.1132009, 0.2804807, 18.1203701>,
    <2.0716760, 0.2804731, 18.1203048>,
    <2.1053286, 0.2804784, 18.1207182>,
    <2.0043382, 0.2804647, 18.1187163>,
    <2.0406257, 0.2804700, 18.1192675>,
    <2.0043708, 0.2804625, 18.1194779>,
    <2.0380234, 0.2804678, 18.1198913>,
    <2.1284614, 0.3610088, 18.1213420>,
    <2.1074469, 0.3610088, 18.1217627>,
    <2.1284677, 0.3207451, 18.1213420>,
    <2.1074532, 0.3207428, 18.1217627>,
    <2.1179541, 0.3610088, 18.1215524>,
    <2.1179605, 0.3207439, 18.1215524>,
    <2.1074342, 0.4415410, 18.1217627>,
    <2.1284488, 0.4415362, 18.1213420>,
    <2.1074405, 0.4012749, 18.1217627>,
    <2.1179415, 0.4415386, 18.1215524>,
    <2.1284551, 0.4012725, 18.1213420>,
    <2.1179478, 0.4012737, 18.1215524>,
    <2.1494633, 0.4415314, 18.1209214>,
    <2.1494759, 0.3610087, 18.1209214>,
    <2.1389560, 0.4415338, 18.1211317>,
    <2.1494696, 0.4012701, 18.1209214>,
    <2.1389687, 0.3610087, 18.1211317>,
    <2.1389624, 0.4012713, 18.1211317>,
    <2.1494822, 0.3207473, 18.1209214>,
    <2.1389750, 0.3207462, 18.1211317>,
    <2.0664094, 0.4415300, 18.1207908>,
    <2.0559348, 0.4415349, 18.1217627>,
    <2.0974291, 0.4415331, 18.1210664>,
    <2.0816845, 0.4415379, 18.1217627>,
    <2.0611721, 0.4415324, 18.1212767>,
    <2.0895568, 0.4415355, 18.1214145>,
    <2.0044353, 0.4415288, 18.1217627>,
    <2.0043701, 0.4415238, 18.1202395>,
    <2.0301850, 0.4415318, 18.1217627>,
    <2.0044027, 0.4415263, 18.1210011>,
    <2.0353897, 0.4415269, 18.1205151>,
    <2.0327874, 0.4415294, 18.1211389>,
    <2.0043048, 0.4415189, 18.1187163>,
    <2.0768841, 0.4415251, 18.1198188>,
    <2.0043374, 0.4415214, 18.1194779>,
    <2.0405944, 0.4415220, 18.1192675>,
    <2.0716467, 0.4415276, 18.1203048>,
    <2.0379921, 0.4415245, 18.1198913>,
    <2.1131737, 0.4415283, 18.1203701>,
    <2.1053014, 0.4415307, 18.1207182>,
    <2.0766447, 0.2804848, 18.1376413>,
    <2.0042020, 0.2804738, 18.1370901>,
    <2.0404234, 0.2804793, 18.1373657>,
    <2.0042701, 0.2804693, 18.1279032>,
    <2.0767790, 0.2804801, 18.1287301>,
    <2.0405246, 0.2804747, 18.1283166>,
    <2.1490873, 0.2804957, 18.1381926>,
    <2.1492879, 0.2804908, 18.1295570>,
    <2.1128660, 0.2804902, 18.1379170>,
    <2.1130335, 0.2804854, 18.1291435>,
    <2.1486861, 0.2805054, 18.1554639>,
    <2.0763760, 0.2804942, 18.1554639>,
    <2.1488867, 0.2805005, 18.1468283>,
    <2.1125311, 0.2804998, 18.1554639>,
    <2.0765104, 0.2804895, 18.1465526>,
    <2.1126985, 0.2804950, 18.1466904>,
    <2.0040659, 0.2804830, 18.1554639>,
    <2.0402210, 0.2804886, 18.1554639>,
    <2.0041340, 0.2804784, 18.1462770>,
    <2.0403222, 0.2804839, 18.1464148>,
    <2.1490748, 0.3610086, 18.1381926>,
    <2.1490811, 0.3207521, 18.1381926>,
    <2.1492754, 0.3610086, 18.1295570>,
    <2.1492816, 0.3207497, 18.1295570>,
    <2.1490623, 0.4415215, 18.1381926>,
    <2.1492628, 0.4415265, 18.1295570>,
    <2.1490685, 0.4012650, 18.1381926>,
    <2.1492691, 0.4012676, 18.1295570>,
    <2.1486612, 0.4415115, 18.1554639>,
    <2.1486737, 0.3610085, 18.1554639>,
    <2.1488618, 0.4415165, 18.1468283>,
    <2.1486675, 0.4012600, 18.1554639>,
    <2.1488742, 0.3610085, 18.1468283>,
    <2.1488680, 0.4012625, 18.1468283>,
    <2.1486799, 0.3207569, 18.1554639>,
    <2.1488805, 0.3207545, 18.1468283>,
    <2.0766155, 0.4415150, 18.1376413>,
    <2.1128389, 0.4415182, 18.1379170>,
    <2.0767498, 0.4415201, 18.1287301>,
    <2.1130063, 0.4415233, 18.1291435>,
    <2.0041687, 0.4415085, 18.1370901>,
    <2.0042367, 0.4415137, 18.1279032>,
    <2.0403921, 0.4415118, 18.1373657>,
    <2.0404932, 0.4415169, 18.1283166>,
    <2.0040326, 0.4414981, 18.1554639>,
    <2.0763469, 0.4415048, 18.1554639>,
    <2.0041006, 0.4415033, 18.1462770>,
    <2.0401897, 0.4415015, 18.1554639>,
    <2.0764812, 0.4415099, 18.1465526>,
    <2.0402909, 0.4415066, 18.1464148>,
    <2.1125041, 0.4415082, 18.1554639>,
    <2.1126715, 0.4415132, 18.1466904>,
    <2.0812641, 0.2805008, 18.1573801>,
    <2.0039695, 0.2804894, 18.1573801>,
    <2.0426168, 0.2804951, 18.1573801>,
    <2.0040177, 0.2804862, 18.1564220>,
    <2.0788201, 0.2804975, 18.1564220>,
    <2.0414189, 0.2804919, 18.1564220>,
    <2.1585588, 0.2805122, 18.1573801>,
    <2.1536225, 0.2805088, 18.1564220>,
    <2.1199115, 0.2805065, 18.1573801>,
    <2.1162213, 0.2805032, 18.1564220>,
    <2.1684314, 0.2805191, 18.1592964>,
    <2.0861522, 0.2805075, 18.1592964>,
    <2.1634951, 0.2805157, 18.1583383>,
    <2.1272918, 0.2805133, 18.1592964>,
    <2.0837082, 0.2805042, 18.1583383>,
    <2.1236016, 0.2805099, 18.1583383>,
    <2.0038730, 0.2804959, 18.1592964>,
    <2.0450126, 0.2805017, 18.1592964>,
    <2.0039212, 0.2804927, 18.1583383>,
    <2.0438147, 0.2804984, 18.1583383>,
    <2.1585464, 0.3610084, 18.1573801>,
    <2.1585526, 0.3207603, 18.1573801>,
    <2.1536100, 0.3610084, 18.1564220>,
    <2.1536162, 0.3207586, 18.1564220>,
    <2.1585340, 0.4415045, 18.1573801>,
    <2.1535976, 0.4415080, 18.1564220>,
    <2.1585402, 0.4012564, 18.1573801>,
    <2.1536038, 0.4012582, 18.1564220>,
    <2.1684068, 0.4414975, 18.1592964>,
    <2.1684191, 0.3610083, 18.1592964>,
    <2.1634704, 0.4415010, 18.1583383>,
    <2.1684129, 0.4012529, 18.1592964>,
    <2.1634827, 0.3610083, 18.1583383>,
    <2.1634766, 0.4012547, 18.1583383>,
    <2.1684253, 0.3207637, 18.1592964>,
    <2.1634889, 0.3207620, 18.1583383>,
    <2.0812351, 0.4414977, 18.1573801>,
    <2.1198845, 0.4415011, 18.1573801>,
    <2.0787910, 0.4415013, 18.1564220>,
    <2.1161943, 0.4415046, 18.1564220>,
    <2.0039361, 0.4414908, 18.1573801>,
    <2.0039844, 0.4414945, 18.1564220>,
    <2.0425856, 0.4414942, 18.1573801>,
    <2.0413877, 0.4414979, 18.1564220>,
    <2.0038397, 0.4414835, 18.1592964>,
    <2.0861232, 0.4414905, 18.1592964>,
    <2.0038879, 0.4414871, 18.1583383>,
    <2.0449814, 0.4414870, 18.1592964>,
    <2.0836791, 0.4414941, 18.1583383>,
    <2.0437835, 0.4414906, 18.1583383>,
    <2.1272650, 0.4414940, 18.1592964>,
    <2.1235748, 0.4414975, 18.1583383>,
    <2.0877229, 0.2805088, 18.2324892>,
    <2.0038724, 0.2804960, 18.2344341>,
    <2.0457964, 0.2805025, 18.2333227>,
    <2.0038727, 0.2804959, 18.1968653>,
    <2.0861681, 0.2805075, 18.1968653>,
    <2.0450204, 0.2805017, 18.1968653>,
    <2.1715888, 0.2805206, 18.2322113>,
    <2.1684634, 0.2805191, 18.1968653>,
    <2.1296546, 0.2805148, 18.2322113>,
    <2.1273157, 0.2805133, 18.1968653>,
    <2.1994932, 0.2805337, 18.2873438>,
    <2.1015957, 0.2805207, 18.2890109>,
    <2.1809009, 0.2805250, 18.2631118>,
    <2.1505368, 0.2805277, 18.2873438>,
    <2.0923559, 0.2805125, 18.2642232>,
    <2.1366233, 0.2805191, 18.2631118>,
    <2.0038718, 0.2804960, 18.3095719>,
    <2.0526852, 0.2805116, 18.2940122>,
    <2.0038721, 0.2804960, 18.2720030>,
    <2.0481089, 0.2805046, 18.2675574>,
    <2.1715765, 0.3610083, 18.2322113>,
    <2.1715826, 0.3207644, 18.2322113>,
    <2.1684511, 0.3610083, 18.1968653>,
    <2.1684573, 0.3207637, 18.1968653>,
    <2.1715641, 0.4414959, 18.2322113>,
    <2.1684387, 0.4414974, 18.1968653>,
    <2.1715703, 0.4012521, 18.2322113>,
    <2.1684449, 0.4012529, 18.1968653>,
    <2.1994687, 0.4414825, 18.2873438>,
    <2.1994809, 0.3610081, 18.2873438>,
    <2.1808763, 0.4414914, 18.2631118>,
    <2.1994748, 0.4012453, 18.2873438>,
    <2.1808886, 0.3610082, 18.2631118>,
    <2.1808825, 0.4012498, 18.2631118>,
    <2.1994871, 0.3207709, 18.2873438>,
    <2.1808948, 0.3207666, 18.2631118>,
    <2.0876939, 0.4414891, 18.2324892>,
    <2.1296277, 0.4414924, 18.2322113>,
    <2.0861391, 0.4414904, 18.1968653>,
    <2.1272889, 0.4414939, 18.1968653>,
    <2.0038391, 0.4414834, 18.2344341>,
    <2.0038394, 0.4414834, 18.1968653>,
    <2.0457652, 0.4414862, 18.2333227>,
    <2.0449892, 0.4414869, 18.1968653>,
    <2.0038384, 0.4414834, 18.3095719>,
    <2.1015668, 0.4414763, 18.2890109>,
    <2.0038387, 0.4414834, 18.2720030>,
    <2.0526541, 0.4414761, 18.2940122>,
    <2.0923269, 0.4414851, 18.2642232>,
    <2.0480777, 0.4414838, 18.2675574>,
    <2.1505101, 0.4414788, 18.2873438>,
    <2.1365965, 0.4414879, 18.2631118>,
    <2.1354633, 0.2805529, 18.3131904>,
    <2.0032176, 0.2805399, 18.3135798>,
    <2.0693404, 0.2805464, 18.3133573>,
    <2.0035447, 0.2805180, 18.3115759>,
    <2.1169712, 0.2805352, 18.3037960>,
    <2.0602528, 0.2805269, 18.3071303>,
    <2.2677097, 0.2805658, 18.3131347>,
    <2.2304590, 0.2805483, 18.3026846>,
    <2.2015864, 0.2805594, 18.3131347>,
    <2.1737100, 0.2805421, 18.3026846>,
    <2.3367110, 0.2805985, 18.3353648>,
    <2.1697200, 0.2805856, 18.3340315>,
    <2.3051565, 0.2805835, 18.3226946>,
    <2.2532228, 0.2805915, 18.3353648>,
    <2.1540527, 0.2805707, 18.3218058>,
    <2.2296095, 0.2805768, 18.3226946>,
    <2.0025635, 0.2805838, 18.3175878>,
    <2.0861880, 0.2805816, 18.3300317>,
    <2.0028906, 0.2805619, 18.3155838>,
    <2.0784765, 0.2805660, 18.3191392>,
    <2.2676976, 0.3610077, 18.3131347>,
    <2.2677036, 0.3207868, 18.3131347>,
    <2.2304468, 0.3610079, 18.3026846>,
    <2.2304529, 0.3207781, 18.3026846>,
    <2.2676856, 0.4414495, 18.3131347>,
    <2.2304347, 0.4414675, 18.3026846>,
    <2.2676916, 0.4012286, 18.3131347>,
    <2.2304408, 0.4012377, 18.3026846>,
    <2.3366874, 0.4414161, 18.3353648>,
    <2.3366992, 0.3610073, 18.3353648>,
    <2.3051328, 0.4414314, 18.3226946>,
    <2.3366933, 0.4012117, 18.3353648>,
    <2.3051447, 0.3610075, 18.3226946>,
    <2.3051387, 0.4012194, 18.3226946>,
    <2.3367051, 0.3208029, 18.3353648>,
    <2.3051506, 0.3207955, 18.3226946>,
    <2.1354346, 0.4414415, 18.3131904>,
    <2.2015601, 0.4414455, 18.3131347>,
    <2.1169424, 0.4414607, 18.3037960>,
    <2.1736835, 0.4414637, 18.3026846>,
    <2.0031844, 0.4414336, 18.3135798>,
    <2.0035114, 0.4414585, 18.3115759>,
    <2.0693094, 0.4414376, 18.3133573>,
    <2.0602218, 0.4414592, 18.3071303>,
    <2.0025303, 0.4413838, 18.3175878>,
    <2.1696916, 0.4414062, 18.3340315>,
    <2.0028573, 0.4414087, 18.3155838>,
    <2.0861572, 0.4413985, 18.3300317>,
    <2.1540243, 0.4414223, 18.3218058>,
    <2.0784457, 0.4414159, 18.3191392>,
    <2.2531968, 0.4414117, 18.3353648>,
    <2.2295834, 0.4414272, 18.3226946>,
    <2.1847094, 0.2805991, 18.3800376>,
    <2.0025322, 0.2805859, 18.3784821>,
    <2.0936220, 0.2805924, 18.3793709>,
    <2.0025479, 0.2805849, 18.3480349>,
    <2.1794453, 0.2805944, 18.3542569>,
    <2.0910014, 0.2805893, 18.3515903>,
    <2.3668719, 0.2806132, 18.3802598>,
    <2.3562844, 0.2806079, 18.3551457>,
    <2.2757919, 0.2806060, 18.3802598>,
    <2.2678697, 0.2806008, 18.3551457>,
    <2.3730707, 0.2806168, 18.4393764>,
    <2.1877858, 0.2806024, 18.4393764>,
    <2.3714689, 0.2806157, 18.4089292>,
    <2.2804282, 0.2806096, 18.4393764>,
    <2.1869927, 0.2806013, 18.4089292>,
    <2.2792308, 0.2806085, 18.4089292>,
    <2.0025009, 0.2805880, 18.4393764>,
    <2.0951433, 0.2805952, 18.4393764>,
    <2.0025166, 0.2805870, 18.4089292>,
    <2.0947546, 0.2805942, 18.4089292>,
    <2.3668603, 0.3610071, 18.3802598>,
    <2.3668661, 0.3208101, 18.3802598>,
    <2.3562727, 0.3610071, 18.3551457>,
    <2.3562785, 0.3208075, 18.3551457>,
    <2.3668486, 0.4414010, 18.3802598>,
    <2.3562610, 0.4414064, 18.3551457>,
    <2.3668544, 0.4012040, 18.3802598>,
    <2.3562668, 0.4012068, 18.3551457>,
    <2.3730474, 0.4413973, 18.4393764>,
    <2.3730590, 0.3610070, 18.4393764>,
    <2.3714456, 0.4413984, 18.4089292>,
    <2.3730532, 0.4012022, 18.4393764>,
    <2.3714573, 0.3610070, 18.4089292>,
    <2.3714515, 0.4012027, 18.4089292>,
    <2.3730649, 0.3208119, 18.4393764>,
    <2.3714631, 0.3208114, 18.4089292>,
    <2.1846811, 0.4413918, 18.3800376>,
    <2.2757661, 0.4413965, 18.3802598>,
    <2.1794170, 0.4413967, 18.3542569>,
    <2.2678438, 0.4414019, 18.3551457>,
    <2.0024990, 0.4413814, 18.3784821>,
    <2.0025147, 0.4413826, 18.3480349>,
    <2.0935913, 0.4413867, 18.3793709>,
    <2.0909707, 0.4413900, 18.3515903>,
    <2.0024677, 0.4413790, 18.4393764>,
    <2.1877576, 0.4413882, 18.4393764>,
    <2.0024834, 0.4413802, 18.4089292>,
    <2.0951126, 0.4413836, 18.4393764>,
    <2.1869645, 0.4413893, 18.4089292>,
    <2.0947239, 0.4413848, 18.4089292>,
    <2.2804025, 0.4413927, 18.4393764>,
    <2.2792051, 0.4413939, 18.4089292>,
    <2.1962424, 0.2806139, 18.4393764>,
    <2.0023340, 0.2805992, 18.4393764>,
    <2.0992882, 0.2806066, 18.4393764>,
    <2.0024175, 0.2805936, 18.4393764>,
    <2.1920141, 0.2806082, 18.4393764>,
    <2.0972158, 0.2806009, 18.4393764>,
    <2.3901507, 0.2806287, 18.4393764>,
    <2.3816107, 0.2806227, 18.4393764>,
    <2.2931966, 0.2806213, 18.4393764>,
    <2.2868124, 0.2806154, 18.4393764>,
    <2.4072308, 0.2806405, 18.4393764>,
    <2.2046990, 0.2806255, 18.4393764>,
    <2.3986908, 0.2806346, 18.4393764>,
    <2.3059649, 0.2806330, 18.4393764>,
    <2.2004707, 0.2806197, 18.4393764>,
    <2.2995807, 0.2806272, 18.4393764>,
    <2.0021672, 0.2806104, 18.4393764>,
    <2.1034331, 0.2806180, 18.4393764>,
    <2.0022506, 0.2806048, 18.4393764>,
    <2.1013606, 0.2806123, 18.4393764>,
    <2.3901392, 0.3610069, 18.4393764>,
    <2.3901450, 0.3208178, 18.4393764>,
    <2.3815991, 0.3610070, 18.4393764>,
    <2.3816049, 0.3208148, 18.4393764>,
    <2.3901276, 0.4413851, 18.4393764>,
    <2.3815875, 0.4413912, 18.4393764>,
    <2.3901334, 0.4011960, 18.4393764>,
    <2.3815933, 0.4011991, 18.4393764>,
    <2.4072079, 0.4413729, 18.4393764>,
    <2.4072193, 0.3610067, 18.4393764>,
    <2.3986678, 0.4413790, 18.4393764>,
    <2.4072136, 0.4011898, 18.4393764>,
    <2.3986793, 0.3610068, 18.4393764>,
    <2.3986735, 0.4011929, 18.4393764>,
    <2.4072251, 0.3208236, 18.4393764>,
    <2.3986850, 0.3208207, 18.4393764>,
    <2.1962143, 0.4413757, 18.4393764>,
    <2.2931709, 0.4413804, 18.4393764>,
    <2.1919859, 0.4413819, 18.4393764>,
    <2.2867867, 0.4413866, 18.4393764>,
    <2.0023009, 0.4413663, 18.4393764>,
    <2.0023843, 0.4413727, 18.4393764>,
    <2.0992576, 0.4413710, 18.4393764>,
    <2.0971851, 0.4413773, 18.4393764>,
    <2.0021340, 0.4413536, 18.4393764>,
    <2.2046709, 0.4413633, 18.4393764>,
    <2.0022174, 0.4413600, 18.4393764>,
    <2.1034025, 0.4413585, 18.4393764>,
    <2.2004426, 0.4413695, 18.4393764>,
    <2.1013300, 0.4413647, 18.4393764>,
    <2.3059394, 0.4413681, 18.4393764>,
    <2.2995552, 0.4413742, 18.4393764>,
    <2.2046990, 0.2806255, 18.4726341>,
    <2.0021672, 0.2806104, 18.4726341>,
    <2.1034331, 0.2806180, 18.4726341>,
    <2.0021672, 0.2806104, 18.4560052>,
    <2.2046990, 0.2806255, 18.4560052>,
    <2.1034331, 0.2806180, 18.4560052>,
    <2.4072308, 0.2806405, 18.4726341>,
    <2.4072308, 0.2806405, 18.4560052>,
    <2.3059649, 0.2806330, 18.4726341>,
    <2.3059649, 0.2806330, 18.4560052>,
    <2.4072308, 0.2806405, 18.4892630>,
    <2.2046990, 0.2806255, 18.4892630>,
    <2.3059649, 0.2806330, 18.4892630>,
    <2.0021672, 0.2806104, 18.4892630>,
    <2.1034331, 0.2806180, 18.4892630>,
    <2.4072193, 0.3610067, 18.4726341>,
    <2.4072251, 0.3208236, 18.4726341>,
    <2.4072193, 0.3610067, 18.4560052>,
    <2.4072251, 0.3208236, 18.4560052>,
    <2.4072079, 0.4413729, 18.4726341>,
    <2.4072079, 0.4413729, 18.4560052>,
    <2.4072136, 0.4011898, 18.4726341>,
    <2.4072136, 0.4011898, 18.4560052>,
    <2.4072079, 0.4413729, 18.4892630>,
    <2.4072193, 0.3610067, 18.4892630>,
    <2.4072136, 0.4011898, 18.4892630>,
    <2.4072251, 0.3208236, 18.4892630>,
    <2.2046709, 0.4413633, 18.4726341>,
    <2.3059394, 0.4413681, 18.4726341>,
    <2.2046709, 0.4413633, 18.4560052>,
    <2.3059394, 0.4413681, 18.4560052>,
    <2.0021340, 0.4413536, 18.4726341>,
    <2.0021340, 0.4413536, 18.4560052>,
    <2.1034025, 0.4413585, 18.4726341>,
    <2.1034025, 0.4413585, 18.4560052>,
    <2.0021340, 0.4413536, 18.4892630>,
    <2.2046709, 0.4413633, 18.4892630>,
    <2.1034025, 0.4413585, 18.4892630>,
    <2.3059394, 0.4413681, 18.4892630>,
    <2.0021506, 0.3609820, 18.4726341>,
    <2.0021672, 0.2806104, 18.4726341>,
    <2.0021506, 0.3609820, 18.4393764>,
    <2.0021589, 0.3207962, 18.4726341>,
    <2.0021672, 0.2806104, 18.4560052>,
    <2.0021589, 0.3207962, 18.4393764>,
    <2.0021506, 0.3609820, 18.4560052>,
    <2.0021589, 0.3207962, 18.4560052>,
    <2.0021340, 0.4413536, 18.4726341>,
    <2.0021423, 0.4011678, 18.4393764>,
    <2.0021340, 0.4413536, 18.4560052>,
    <2.0021423, 0.4011678, 18.4726341>,
    <2.0021423, 0.4011678, 18.4560052>,
    <2.0021506, 0.3609820, 18.5058918>,
    <2.0021340, 0.4413536, 18.4892630>,
    <2.0021423, 0.4011678, 18.5058918>,
    <2.0021506, 0.3609820, 18.4892630>,
    <2.0021423, 0.4011678, 18.4892630>,
    <2.0021589, 0.3207962, 18.5058918>,
    <2.0021672, 0.2806104, 18.4892630>,
    <2.0021589, 0.3207962, 18.4892630>,
    <2.0023174, 0.3609828, 18.4393764>,
    <2.0024843, 0.3609835, 18.4393764>,
    <2.0024009, 0.3609832, 18.4393764>,
    <2.0024926, 0.3207858, 18.4393764>,
    <2.0023257, 0.3207910, 18.4393764>,
    <2.0024092, 0.3207884, 18.4393764>,
    <2.0021506, 0.3609820, 18.4393764>,
    <2.0021589, 0.3207962, 18.4393764>,
    <2.0022340, 0.3609824, 18.4393764>,
    <2.0022423, 0.3207936, 18.4393764>,
    <2.0021423, 0.4011678, 18.4393764>,
    <2.0023092, 0.4011746, 18.4393764>,
    <2.0022257, 0.4011712, 18.4393764>,
    <2.0024760, 0.4011813, 18.4393764>,
    <2.0023926, 0.4011779, 18.4393764>,
    <2.0025156, 0.3609837, 18.3784821>,
    <2.0025322, 0.2805859, 18.3784821>,
    <2.0025469, 0.3609838, 18.3175878>,
    <2.0025239, 0.3207848, 18.3784821>,
    <2.0025479, 0.2805849, 18.3480349>,
    <2.0025552, 0.3207838, 18.3175878>,
    <2.0025313, 0.3609837, 18.3480349>,
    <2.0025396, 0.3207843, 18.3480349>,
    <2.0024990, 0.4413814, 18.3784821>,
    <2.0025386, 0.4011838, 18.3175878>,
    <2.0025147, 0.4413826, 18.3480349>,
    <2.0025073, 0.4011825, 18.3784821>,
    <2.0025230, 0.4011832, 18.3480349>,
    <2.0024843, 0.3609835, 18.4393764>,
    <2.0024834, 0.4413802, 18.4089292>,
    <2.0024760, 0.4011813, 18.4393764>,
    <2.0025000, 0.3609836, 18.4089292>,
    <2.0024917, 0.4011819, 18.4089292>,
    <2.0024926, 0.3207858, 18.4393764>,
    <2.0025166, 0.2805870, 18.4089292>,
    <2.0025083, 0.3207853, 18.4089292>,
    <2.0032010, 0.3609868, 18.3135798>,
    <2.0038551, 0.3609897, 18.3095719>,
    <2.0035281, 0.3609882, 18.3115759>,
    <2.0038634, 0.3207428, 18.3095719>,
    <2.0032093, 0.3207633, 18.3135798>,
    <2.0035364, 0.3207531, 18.3115759>,
    <2.0025469, 0.3609838, 18.3175878>,
    <2.0025552, 0.3207838, 18.3175878>,
    <2.0028740, 0.3609853, 18.3155838>,
    <2.0028823, 0.3207736, 18.3155838>,
    <2.0025386, 0.4011838, 18.3175878>,
    <2.0031927, 0.4012102, 18.3135798>,
    <2.0028656, 0.4011970, 18.3155838>,
    <2.0038468, 0.4012365, 18.3095719>,
    <2.0035197, 0.4012233, 18.3115759>,
    <2.0038557, 0.3609897, 18.2344341>,
    <2.0038724, 0.2804960, 18.2344341>,
    <2.0038563, 0.3609897, 18.1592964>,
    <2.0038641, 0.3207428, 18.2344341>,
    <2.0038727, 0.2804959, 18.1968653>,
    <2.0038647, 0.3207428, 18.1592964>,
    <2.0038560, 0.3609897, 18.1968653>,
    <2.0038644, 0.3207428, 18.1968653>,
    <2.0038391, 0.4414834, 18.2344341>,
    <2.0038480, 0.4012366, 18.1592964>,
    <2.0038394, 0.4414834, 18.1968653>,
    <2.0038474, 0.4012366, 18.2344341>,
    <2.0038477, 0.4012366, 18.1968653>,
    <2.0038551, 0.3609897, 18.3095719>,
    <2.0038387, 0.4414834, 18.2720030>,
    <2.0038468, 0.4012365, 18.3095719>,
    <2.0038554, 0.3609897, 18.2720030>,
    <2.0038471, 0.4012365, 18.2720030>,
    <2.0038634, 0.3207428, 18.3095719>,
    <2.0038721, 0.2804960, 18.2720030>,
    <2.0038637, 0.3207428, 18.2720030>,
    <2.0039528, 0.3609901, 18.1573801>,
    <2.0040493, 0.3609906, 18.1554639>,
    <2.0040010, 0.3609903, 18.1564220>,
    <2.0040576, 0.3207368, 18.1554639>,
    <2.0039611, 0.3207398, 18.1573801>,
    <2.0040094, 0.3207383, 18.1564220>,
    <2.0038563, 0.3609897, 18.1592964>,
    <2.0038647, 0.3207428, 18.1592964>,
    <2.0039046, 0.3609899, 18.1583383>,
    <2.0039129, 0.3207413, 18.1583383>,
    <2.0038480, 0.4012366, 18.1592964>,
    <2.0039445, 0.4012405, 18.1573801>,
    <2.0038962, 0.4012385, 18.1583383>,
    <2.0040409, 0.4012444, 18.1554639>,
    <2.0039927, 0.4012424, 18.1564220>,
    <2.0042444, 0.3609914, 18.1389725>,
    <2.0042673, 0.2804695, 18.1386133>,
    <2.0043812, 0.3609921, 18.1258340>,
    <2.0042548, 0.3207304, 18.1388528>,
    <2.0043680, 0.2804627, 18.1301880>,
    <2.0044020, 0.3207251, 18.1251156>,
    <2.0043263, 0.3609918, 18.1316249>,
    <2.0043430, 0.3207272, 18.1311460>,
    <2.0042339, 0.4415135, 18.1386133>,
    <2.0043853, 0.4012591, 18.1251156>,
    <2.0043346, 0.4415211, 18.1301880>,
    <2.0042381, 0.4012525, 18.1388528>,
    <2.0043263, 0.4012565, 18.1311460>,
    <2.0040493, 0.3609906, 18.1554639>,
    <2.0041333, 0.4415058, 18.1470386>,
    <2.0040409, 0.4012444, 18.1554639>,
    <2.0041499, 0.3609910, 18.1470386>,
    <2.0041416, 0.4012484, 18.1470386>,
    <2.0040576, 0.3207368, 18.1554639>,
    <2.0041666, 0.2804762, 18.1470386>,
    <2.0041583, 0.3207336, 18.1470386>,
    <2.0043805, 0.3609920, 18.1205987>,
    <2.0043944, 0.3609921, 18.1224380>,
    <2.0043909, 0.3207262, 18.1204790>,
    <2.0044111, 0.3207251, 18.1219591>,
    <2.0043215, 0.3609918, 18.1187163>,
    <2.0043298, 0.3207282, 18.1187163>,
    <2.0043541, 0.3609919, 18.1194779>,
    <2.0043625, 0.3207272, 18.1194779>,
    <2.0043131, 0.4012553, 18.1187163>,
    <2.0043742, 0.4012579, 18.1204790>,
    <2.0043458, 0.4012566, 18.1194779>,
    <2.0043944, 0.4012592, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0001973, 0.9999962, 0.0027423>,
    <-0.0001963, 0.9999968, 0.0025295>,
    <-0.0001923, 0.9999967, 0.0025724>,
    <-0.0001939, 0.9999962, 0.0027564>,
    <-0.0001951, 0.9999958, 0.0028851>,
    <-0.0001980, 0.9999958, 0.0028852>,
    <-0.0001980, 0.9999958, 0.0028852>,
    <-0.0002015, 0.9999958, 0.0028854>,
    <-0.0002015, 0.9999963, 0.0027247>,
    <-0.0002015, 0.9999963, 0.0027247>,
    <-0.0002015, 0.9999969, 0.0024728>,
    <-0.0001946, 0.9999976, 0.0021789>,
    <-0.0001898, 0.9999974, 0.0022878>,
    <-0.0002015, 0.9999969, 0.0024728>,
    <-0.0002015, 0.9999979, 0.0020215>,
    <-0.0002015, 0.9999979, 0.0020215>,
    <-0.0002015, 0.9999995, 0.0009789>,
    <-0.0001912, 0.9999989, 0.0014930>,
    <-0.0001912, 0.9999989, 0.0014930>,
    <-0.0001853, 0.9999984, 0.0017886>,
    <-0.0001862, 0.9999972, 0.0023675>,
    <-0.0001892, 0.9999966, 0.0026061>,
    <-0.0001853, 0.9999984, 0.0017886>,
    <-0.0001815, 0.9999980, 0.0019806>,
    <-0.0001815, 0.9999980, 0.0019806>,
    <-0.0001788, 0.9999977, 0.0021153>,
    <-0.0001835, 0.9999970, 0.0024284>,
    <-0.0001835, 0.9999970, 0.0024284>,
    <-0.0001867, 0.9999965, 0.0026332>,
    <-0.0001912, 0.9999962, 0.0027680>,
    <-0.0001867, 0.9999965, 0.0026332>,
    <-0.0001889, 0.9999961, 0.0027776>,
    <-0.0001889, 0.9999961, 0.0027776>,
    <-0.0001905, 0.9999958, 0.0028849>,
    <-0.0001926, 0.9999958, 0.0028850>,
    <-0.0001926, 0.9999958, 0.0028850>,
    <-0.0001951, 0.9999958, 0.0028851>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <0.0000670, -0.9999644, 0.0084329>,
    <0.0000795, -0.9999828, 0.0058644>,
    <0.0000503, -0.9999846, 0.0055497>,
    <0.0000318, -0.9999708, 0.0076356>,
    <-0.0000007, -0.9999362, 0.0112929>,
    <0.0000426, -0.9999094, 0.0134585>,
    <0.0000426, -0.9999094, 0.0134585>,
    <0.0001180, -0.9998516, 0.0172249>,
    <0.0001180, -0.9999540, 0.0095864>,
    <0.0001180, -0.9999540, 0.0095864>,
    <0.0001180, -0.9999803, 0.0062797>,
    <0.0000871, -0.9999907, 0.0043049>,
    <0.0000623, -0.9999912, 0.0042015>,
    <0.0001180, -0.9999803, 0.0062797>,
    <0.0001180, -0.9999902, 0.0044341>,
    <0.0001180, -0.9999902, 0.0044341>,
    <0.0001180, -0.9999947, 0.0032565>,
    <0.0000922, -0.9999947, 0.0032576>,
    <0.0000922, -0.9999947, 0.0032576>,
    <0.0000707, -0.9999947, 0.0032585>,
    <0.0000420, -0.9999915, 0.0041169>,
    <0.0000274, -0.9999859, 0.0053031>,
    <0.0000707, -0.9999947, 0.0032585>,
    <0.0000525, -0.9999947, 0.0032593>,
    <0.0000525, -0.9999947, 0.0032593>,
    <0.0000370, -0.9999947, 0.0032599>,
    <0.0000251, -0.9999918, 0.0040463>,
    <0.0000251, -0.9999918, 0.0040463>,
    <0.0000090, -0.9999870, 0.0051046>,
    <0.0000059, -0.9999751, 0.0070516>,
    <0.0000090, -0.9999870, 0.0051046>,
    <-0.0000138, -0.9999782, 0.0066053>,
    <-0.0000138, -0.9999782, 0.0066053>,
    <-0.0000487, -0.9999604, 0.0088994>,
    <-0.0000289, -0.9999511, 0.0098864>,
    <-0.0000289, -0.9999511, 0.0098864>,
    <-0.0000007, -0.9999362, 0.0112929>,
    <0.0001428, -0.9999999, 0.0005141>,
    <0.0001426, -0.9999998, 0.0005303>,
    <0.0001467, -0.9999998, 0.0005304>,
    <0.0001468, -0.9999999, 0.0005142>,
    <0.0001469, -0.9999999, 0.0004984>,
    <0.0001430, -0.9999999, 0.0004984>,
    <0.0001430, -0.9999999, 0.0004984>,
    <0.0001391, -0.9999999, 0.0004983>,
    <0.0001388, -0.9999999, 0.0005141>,
    <0.0001388, -0.9999999, 0.0005141>,
    <0.0001386, -0.9999998, 0.0005303>,
    <0.0001425, -0.9999998, 0.0005471>,
    <0.0001466, -0.9999998, 0.0005472>,
    <0.0001386, -0.9999998, 0.0005303>,
    <0.0001383, -0.9999998, 0.0005470>,
    <0.0001383, -0.9999998, 0.0005470>,
    <0.0001381, -0.9999998, 0.0005643>,
    <0.0001423, -0.9999998, 0.0005644>,
    <0.0001423, -0.9999998, 0.0005644>,
    <0.0001464, -0.9999998, 0.0005645>,
    <0.0001507, -0.9999998, 0.0005472>,
    <0.0001508, -0.9999998, 0.0005305>,
    <0.0001464, -0.9999998, 0.0005645>,
    <0.0001506, -0.9999998, 0.0005646>,
    <0.0001506, -0.9999998, 0.0005646>,
    <0.0001548, -0.9999998, 0.0005647>,
    <0.0001548, -0.9999998, 0.0005473>,
    <0.0001548, -0.9999998, 0.0005473>,
    <0.0001548, -0.9999998, 0.0005305>,
    <0.0001508, -0.9999999, 0.0005142>,
    <0.0001548, -0.9999998, 0.0005305>,
    <0.0001548, -0.9999999, 0.0005142>,
    <0.0001548, -0.9999999, 0.0005142>,
    <0.0001548, -0.9999999, 0.0004984>,
    <0.0001509, -0.9999999, 0.0004984>,
    <0.0001509, -0.9999999, 0.0004984>,
    <0.0001469, -0.9999999, 0.0004984>,
    <0.9997304, 0.0001558, 0.0232204>,
    <0.9997304, 0.0001558, 0.0232184>,
    <0.9997304, 0.0001554, 0.0232184>,
    <0.9997304, 0.0001554, 0.0232204>,
    <0.9997303, 0.0001554, 0.0232224>,
    <0.9997303, 0.0001558, 0.0232224>,
    <0.9997303, 0.0001558, 0.0232224>,
    <0.9997303, 0.0001563, 0.0232224>,
    <0.9997304, 0.0001563, 0.0232204>,
    <0.9997304, 0.0001563, 0.0232204>,
    <0.9997304, 0.0001563, 0.0232184>,
    <0.9997305, 0.0001558, 0.0232164>,
    <0.9997305, 0.0001554, 0.0232164>,
    <0.9997304, 0.0001563, 0.0232184>,
    <0.9997305, 0.0001563, 0.0232164>,
    <0.9997305, 0.0001563, 0.0232164>,
    <0.9997305, 0.0001563, 0.0232145>,
    <0.9997305, 0.0001558, 0.0232145>,
    <0.9997305, 0.0001558, 0.0232145>,
    <0.9997305, 0.0001554, 0.0232145>,
    <0.9997305, 0.0001550, 0.0232164>,
    <0.9997304, 0.0001550, 0.0232184>,
    <0.9997305, 0.0001554, 0.0232145>,
    <0.9997305, 0.0001550, 0.0232145>,
    <0.9997305, 0.0001550, 0.0232145>,
    <0.9997305, 0.0001546, 0.0232145>,
    <0.9997305, 0.0001546, 0.0232164>,
    <0.9997305, 0.0001546, 0.0232164>,
    <0.9997304, 0.0001546, 0.0232184>,
    <0.9997304, 0.0001550, 0.0232204>,
    <0.9997304, 0.0001546, 0.0232184>,
    <0.9997304, 0.0001546, 0.0232204>,
    <0.9997304, 0.0001546, 0.0232204>,
    <0.9997303, 0.0001546, 0.0232224>,
    <0.9997303, 0.0001550, 0.0232224>,
    <0.9997303, 0.0001550, 0.0232224>,
    <0.9997303, 0.0001554, 0.0232224>,
    <-0.0000946, 0.9999998, 0.0005706>,
    <-0.0000945, 0.9999998, 0.0005680>,
    <-0.0000939, 0.9999998, 0.0005681>,
    <-0.0000939, 0.9999998, 0.0005706>,
    <-0.0000940, 0.9999998, 0.0005733>,
    <-0.0000946, 0.9999998, 0.0005733>,
    <-0.0000946, 0.9999998, 0.0005733>,
    <-0.0000952, 0.9999998, 0.0005733>,
    <-0.0000952, 0.9999998, 0.0005706>,
    <-0.0000952, 0.9999998, 0.0005706>,
    <-0.0000952, 0.9999998, 0.0005680>,
    <-0.0000945, 0.9999998, 0.0005655>,
    <-0.0000939, 0.9999998, 0.0005656>,
    <-0.0000952, 0.9999998, 0.0005680>,
    <-0.0000951, 0.9999998, 0.0005655>,
    <-0.0000951, 0.9999998, 0.0005655>,
    <-0.0000951, 0.9999998, 0.0005631>,
    <-0.0000945, 0.9999998, 0.0005631>,
    <-0.0000945, 0.9999998, 0.0005631>,
    <-0.0000939, 0.9999998, 0.0005631>,
    <-0.0000933, 0.9999998, 0.0005656>,
    <-0.0000933, 0.9999998, 0.0005681>,
    <-0.0000939, 0.9999998, 0.0005631>,
    <-0.0000933, 0.9999998, 0.0005631>,
    <-0.0000933, 0.9999998, 0.0005631>,
    <-0.0000927, 0.9999998, 0.0005631>,
    <-0.0000927, 0.9999998, 0.0005656>,
    <-0.0000927, 0.9999998, 0.0005656>,
    <-0.0000927, 0.9999998, 0.0005681>,
    <-0.0000933, 0.9999998, 0.0005706>,
    <-0.0000927, 0.9999998, 0.0005681>,
    <-0.0000927, 0.9999998, 0.0005707>,
    <-0.0000927, 0.9999998, 0.0005707>,
    <-0.0000927, 0.9999998, 0.0005733>,
    <-0.0000933, 0.9999998, 0.0005733>,
    <-0.0000933, 0.9999998, 0.0005733>,
    <-0.0000940, 0.9999998, 0.0005733>,
    <0.0001510, -0.9999947, 0.0032413>,
    <0.0001510, -0.9999952, 0.0030960>,
    <0.0001474, -0.9999952, 0.0031052>,
    <0.0001474, -0.9999947, 0.0032458>,
    <0.0001474, -0.9999943, 0.0033864>,
    <0.0001510, -0.9999943, 0.0033866>,
    <0.0001510, -0.9999943, 0.0033866>,
    <0.0001548, -0.9999943, 0.0033868>,
    <0.0001548, -0.9999948, 0.0032365>,
    <0.0001548, -0.9999948, 0.0032365>,
    <0.0001548, -0.9999952, 0.0030862>,
    <0.0001510, -0.9999956, 0.0029508>,
    <0.0001474, -0.9999956, 0.0029647>,
    <0.0001548, -0.9999952, 0.0030862>,
    <0.0001548, -0.9999957, 0.0029360>,
    <0.0001548, -0.9999957, 0.0029360>,
    <0.0001548, -0.9999961, 0.0027857>,
    <0.0001510, -0.9999961, 0.0028055>,
    <0.0001510, -0.9999961, 0.0028055>,
    <0.0001474, -0.9999960, 0.0028241>,
    <0.0001440, -0.9999956, 0.0029777>,
    <0.0001440, -0.9999951, 0.0031138>,
    <0.0001474, -0.9999960, 0.0028241>,
    <0.0001440, -0.9999960, 0.0028415>,
    <0.0001440, -0.9999960, 0.0028415>,
    <0.0001408, -0.9999959, 0.0028578>,
    <0.0001408, -0.9999955, 0.0029899>,
    <0.0001408, -0.9999955, 0.0029899>,
    <0.0001408, -0.9999951, 0.0031219>,
    <0.0001440, -0.9999947, 0.0032500>,
    <0.0001408, -0.9999951, 0.0031219>,
    <0.0001408, -0.9999947, 0.0032540>,
    <0.0001408, -0.9999947, 0.0032540>,
    <0.0001408, -0.9999943, 0.0033861>,
    <0.0001440, -0.9999943, 0.0033862>,
    <0.0001440, -0.9999943, 0.0033862>,
    <0.0001474, -0.9999943, 0.0033864>,
    <0.1905399, 0.0000294, -0.9816795>,
    <0.1905394, 0.0000294, -0.9816795>,
    <0.1905394, 0.0000293, -0.9816795>,
    <0.1905399, 0.0000293, -0.9816795>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000294, -0.9816794>,
    <0.1905403, 0.0000294, -0.9816794>,
    <0.1905403, 0.0000295, -0.9816794>,
    <0.1905399, 0.0000295, -0.9816795>,
    <0.1905399, 0.0000295, -0.9816795>,
    <0.1905394, 0.0000295, -0.9816795>,
    <0.1905390, 0.0000294, -0.9816796>,
    <0.1905390, 0.0000293, -0.9816796>,
    <0.1905394, 0.0000295, -0.9816795>,
    <0.1905390, 0.0000295, -0.9816796>,
    <0.1905390, 0.0000295, -0.9816796>,
    <0.1905385, 0.0000295, -0.9816797>,
    <0.1905385, 0.0000294, -0.9816797>,
    <0.1905385, 0.0000294, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905390, 0.0000293, -0.9816796>,
    <0.1905394, 0.0000293, -0.9816795>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000292, -0.9816797>,
    <0.1905390, 0.0000292, -0.9816796>,
    <0.1905390, 0.0000292, -0.9816796>,
    <0.1905394, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000293, -0.9816795>,
    <0.1905394, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000292, -0.9816795>,
    <0.1905403, 0.0000292, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <-0.0000906, 0.9999917, 0.0040632>,
    <-0.0000906, 0.9999921, 0.0039843>,
    <-0.0000886, 0.9999921, 0.0039793>,
    <-0.0000886, 0.9999918, 0.0040557>,
    <-0.0000886, 0.9999915, 0.0041320>,
    <-0.0000906, 0.9999914, 0.0041421>,
    <-0.0000906, 0.9999914, 0.0041421>,
    <-0.0000927, 0.9999914, 0.0041529>,
    <-0.0000927, 0.9999917, 0.0040712>,
    <-0.0000927, 0.9999917, 0.0040712>,
    <-0.0000927, 0.9999920, 0.0039896>,
    <-0.0000906, 0.9999924, 0.0039053>,
    <-0.0000886, 0.9999924, 0.0039029>,
    <-0.0000927, 0.9999920, 0.0039896>,
    <-0.0000927, 0.9999924, 0.0039079>,
    <-0.0000927, 0.9999924, 0.0039079>,
    <-0.0000927, 0.9999927, 0.0038263>,
    <-0.0000906, 0.9999927, 0.0038264>,
    <-0.0000906, 0.9999927, 0.0038264>,
    <-0.0000886, 0.9999927, 0.0038265>,
    <-0.0000868, 0.9999924, 0.0039006>,
    <-0.0000868, 0.9999921, 0.0039746>,
    <-0.0000886, 0.9999927, 0.0038265>,
    <-0.0000868, 0.9999927, 0.0038266>,
    <-0.0000868, 0.9999927, 0.0038266>,
    <-0.0000851, 0.9999927, 0.0038267>,
    <-0.0000851, 0.9999924, 0.0038984>,
    <-0.0000851, 0.9999924, 0.0038984>,
    <-0.0000851, 0.9999921, 0.0039702>,
    <-0.0000868, 0.9999918, 0.0040486>,
    <-0.0000851, 0.9999921, 0.0039702>,
    <-0.0000851, 0.9999918, 0.0040420>,
    <-0.0000851, 0.9999918, 0.0040420>,
    <-0.0000851, 0.9999915, 0.0041137>,
    <-0.0000868, 0.9999915, 0.0041226>,
    <-0.0000868, 0.9999915, 0.0041226>,
    <-0.0000886, 0.9999915, 0.0041320>,
    <0.0001429, -1.0000000, 0.0000082>,
    <0.0001419, -1.0000000, 0.0000137>,
    <0.0001498, -1.0000000, 0.0000569>,
    <0.0001580, -1.0000000, 0.0000320>,
    <0.0001597, -1.0000000, 0.0000006>,
    <0.0001432, -1.0000000, 0.0000006>,
    <0.0001432, -1.0000000, 0.0000006>,
    <0.0001408, -1.0000000, 0.0000006>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000153>,
    <0.0001410, -1.0000000, 0.0000655>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001405, -1.0000000, 0.0000145>,
    <0.0001405, -1.0000000, 0.0000145>,
    <0.0001380, -1.0000000, 0.0000625>,
    <0.0001413, -1.0000000, 0.0001779>,
    <0.0001691, -1.0000000, 0.0001626>,
    <0.0001380, -1.0000000, 0.0000625>,
    <0.0001318, -1.0000000, 0.0001714>,
    <0.0001318, -1.0000000, 0.0001714>,
    <0.0001216, -0.9999999, 0.0004366>,
    <0.0001376, -0.9999999, 0.0004516>,
    <0.0001860, -0.9999999, 0.0004564>,
    <0.0002044, -1.0000000, 0.0001069>,
    <0.0003013, -0.9999998, 0.0004713>,
    <0.0004041, -0.9999998, 0.0005587>,
    <0.0002114, -1.0000000, 0.0000006>,
    <0.0002114, -1.0000000, 0.0000006>,
    <0.0001597, -1.0000000, 0.0000006>,
    <0.9990638, 0.0001532, -0.0432613>,
    <0.9990638, 0.0001532, -0.0432613>,
    <0.9828283, 0.0001506, -0.1845222>,
    <0.9828284, 0.0001506, -0.1845219>,
    <0.9828284, 0.0001506, -0.1845216>,
    <0.9990638, 0.0001532, -0.0432612>,
    <0.9990638, 0.0001532, -0.0432612>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9990638, 0.0001532, -0.0432614>,
    <0.9828283, 0.0001506, -0.1845225>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9990638, 0.0001532, -0.0432615>,
    <0.9990638, 0.0001532, -0.0432615>,
    <0.9828282, 0.0001506, -0.1845228>,
    <0.8922266, 0.0001364, -0.4515879>,
    <0.8922269, 0.0001364, -0.4515873>,
    <0.9828282, 0.0001506, -0.1845228>,
    <0.8922263, 0.0001364, -0.4515885>,
    <0.8922263, 0.0001364, -0.4515885>,
    <0.6239846, 0.0000949, -0.7814367>,
    <0.6239852, 0.0000949, -0.7814361>,
    <0.6239858, 0.0000949, -0.7814356>,
    <0.8922272, 0.0001364, -0.4515867>,
    <0.6239865, 0.0000949, -0.7814351>,
    <0.6239871, 0.0000949, -0.7814346>,
    <0.8922275, 0.0001364, -0.4515861>,
    <0.8922275, 0.0001364, -0.4515861>,
    <0.9828284, 0.0001506, -0.1845216>,
    <-0.0000844, 1.0000000, 0.0000236>,
    <-0.0000832, 1.0000000, 0.0000197>,
    <-0.0000697, 1.0000000, 0.0000817>,
    <-0.0000799, 1.0000000, 0.0001007>,
    <-0.0000834, 1.0000000, 0.0001064>,
    <-0.0000848, 1.0000000, 0.0000248>,
    <-0.0000848, 1.0000000, 0.0000248>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000821, 1.0000000, 0.0000113>,
    <-0.0000606, 1.0000000, 0.0000444>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000589, 1.0000000, 0.0000006>,
    <0.0000041, 1.0000000, 0.0001407>,
    <-0.0000358, 1.0000000, 0.0002273>,
    <-0.0000589, 1.0000000, 0.0000006>,
    <0.0000100, 1.0000000, 0.0000006>,
    <0.0000100, 1.0000000, 0.0000006>,
    <0.0002453, 0.9999998, 0.0006317>,
    <0.0001370, 0.9999998, 0.0005812>,
    <0.0000045, 0.9999998, 0.0006140>,
    <-0.0000684, 1.0000000, 0.0002687>,
    <-0.0000538, 0.9999998, 0.0006609>,
    <-0.0000741, 0.9999998, 0.0006969>,
    <-0.0000799, 1.0000000, 0.0002847>,
    <-0.0000799, 1.0000000, 0.0002847>,
    <-0.0000834, 1.0000000, 0.0001064>,
    <0.0002903, -0.9999984, 0.0017652>,
    <0.0001720, -0.9999993, 0.0011301>,
    <0.0001022, -0.9999983, 0.0018567>,
    <0.0001108, -0.9999949, 0.0031915>,
    <0.0001476, -0.9999397, 0.0109793>,
    <0.0012656, -0.9999369, 0.0111618>,
    <0.0012656, -0.9999369, 0.0111618>,
    <0.0004041, -0.9999998, 0.0005587>,
    <0.0001236, -0.9999995, 0.0009991>,
    <0.0000986, -0.9999989, 0.0014951>,
    <0.0001216, -0.9999999, 0.0004366>,
    <0.0001091, -0.9999995, 0.0009561>,
    <0.0001091, -0.9999995, 0.0009561>,
    <0.0000977, -0.9999990, 0.0013949>,
    <0.0000782, -0.9999992, 0.0012866>,
    <0.0000399, -0.9999988, 0.0015537>,
    <0.0000977, -0.9999990, 0.0013949>,
    <0.0000891, -0.9999993, 0.0011920>,
    <0.0000891, -0.9999993, 0.0011920>,
    <0.0000833, -0.9999998, 0.0006206>,
    <0.0000734, -0.9999998, 0.0006546>,
    <0.0000424, -0.9999998, 0.0006972>,
    <-0.0000548, -0.9999970, 0.0024352>,
    <-0.0000319, -0.9999997, 0.0007320>,
    <-0.0000815, -0.9999997, 0.0007081>,
    <-0.0005894, -0.9999409, 0.0108590>,
    <-0.0005894, -0.9999409, 0.0108590>,
    <0.0001476, -0.9999397, 0.0109793>,
    <0.3536429, 0.0000533, -0.9353805>,
    <0.3536424, 0.0000533, -0.9353807>,
    <0.2587557, 0.0000386, -0.9659428>,
    <0.2587561, 0.0000386, -0.9659427>,
    <0.2587565, 0.0000386, -0.9659426>,
    <0.3536434, 0.0000533, -0.9353803>,
    <0.3536434, 0.0000533, -0.9353803>,
    <0.6239871, 0.0000949, -0.7814346>,
    <0.3536418, 0.0000533, -0.9353809>,
    <0.2587553, 0.0000386, -0.9659429>,
    <0.6239846, 0.0000949, -0.7814367>,
    <0.3536413, 0.0000533, -0.9353811>,
    <0.3536413, 0.0000533, -0.9353811>,
    <0.2587549, 0.0000386, -0.9659430>,
    <0.3066458, 0.0000453, -0.9518237>,
    <0.3066462, 0.0000453, -0.9518236>,
    <0.2587549, 0.0000386, -0.9659430>,
    <0.3066453, 0.0000453, -0.9518239>,
    <0.3066453, 0.0000453, -0.9518239>,
    <0.5358762, 0.0000785, -0.8442966>,
    <0.5358768, 0.0000785, -0.8442962>,
    <0.5358775, 0.0000785, -0.8442958>,
    <0.3066467, 0.0000453, -0.9518234>,
    <0.5358781, 0.0000785, -0.8442954>,
    <0.5358788, 0.0000785, -0.8442949>,
    <0.3066471, 0.0000453, -0.9518233>,
    <0.3066471, 0.0000453, -0.9518233>,
    <0.2587565, 0.0000386, -0.9659426>,
    <-0.0000481, 0.9999990, 0.0014073>,
    <0.0000111, 0.9999989, 0.0014713>,
    <-0.0000549, 0.9999972, 0.0023605>,
    <-0.0000593, 0.9999979, 0.0020363>,
    <-0.0000606, 0.9999979, 0.0020310>,
    <-0.0000670, 0.9999989, 0.0014538>,
    <-0.0000670, 0.9999989, 0.0014538>,
    <-0.0000741, 0.9999998, 0.0006969>,
    <0.0001476, 0.9999977, 0.0021237>,
    <-0.0000450, 0.9999928, 0.0038031>,
    <0.0002453, 0.9999998, 0.0006317>,
    <0.0012409, 0.9999196, 0.0126229>,
    <0.0012409, 0.9999196, 0.0126229>,
    <-0.0000041, 0.9999229, 0.0124198>,
    <-0.0002242, 0.9999958, 0.0028820>,
    <-0.0001153, 0.9999981, 0.0019448>,
    <-0.0000041, 0.9999229, 0.0124198>,
    <-0.0008233, 0.9999242, 0.0122861>,
    <-0.0008233, 0.9999242, 0.0122861>,
    <-0.0002389, 0.9999997, 0.0008012>,
    <-0.0001858, 0.9999996, 0.0008673>,
    <-0.0001009, 0.9999996, 0.0008664>,
    <-0.0000693, 0.9999985, 0.0017093>,
    <-0.0000645, 0.9999996, 0.0008553>,
    <-0.0000524, 0.9999996, 0.0008537>,
    <-0.0000557, 0.9999986, 0.0016790>,
    <-0.0000557, 0.9999986, 0.0016790>,
    <-0.0000606, 0.9999979, 0.0020310>,
    <0.0000426, -1.0000000, 0.0001869>,
    <0.0000607, -1.0000000, 0.0002648>,
    <0.0000730, -1.0000000, 0.0001115>,
    <0.0000692, -1.0000000, 0.0000775>,
    <0.0000684, -1.0000000, 0.0000345>,
    <0.0000399, -1.0000000, 0.0000345>,
    <0.0000399, -1.0000000, 0.0000345>,
    <-0.0000815, -0.9999997, 0.0007081>,
    <0.0000752, -1.0000000, 0.0002807>,
    <0.0000771, -1.0000000, 0.0001238>,
    <0.0000833, -0.9999998, 0.0006206>,
    <0.0000801, -1.0000000, 0.0002736>,
    <0.0000801, -1.0000000, 0.0002736>,
    <0.0000785, -1.0000000, 0.0001223>,
    <0.0000777, -1.0000000, 0.0000537>,
    <0.0000772, -1.0000000, 0.0000514>,
    <0.0000785, -1.0000000, 0.0001223>,
    <0.0000778, -1.0000000, 0.0000530>,
    <0.0000778, -1.0000000, 0.0000530>,
    <0.0000776, -1.0000000, 0.0000325>,
    <0.0000776, -1.0000000, 0.0000330>,
    <0.0000776, -1.0000000, 0.0000330>,
    <0.0000776, -1.0000000, 0.0000335>,
    <0.0000767, -1.0000000, 0.0000443>,
    <0.0000776, -1.0000000, 0.0000335>,
    <0.0000776, -1.0000000, 0.0000340>,
    <0.0000776, -1.0000000, 0.0000340>,
    <0.0000776, -1.0000000, 0.0000345>,
    <0.0000766, -1.0000000, 0.0000345>,
    <0.0000766, -1.0000000, 0.0000345>,
    <0.0000684, -1.0000000, 0.0000345>,
    <0.8300740, 0.0001209, -0.5576532>,
    <0.8300736, 0.0001209, -0.5576538>,
    <0.9623799, 0.0001397, -0.2717074>,
    <0.9623800, 0.0001397, -0.2717070>,
    <0.9623802, 0.0001397, -0.2717065>,
    <0.8300745, 0.0001209, -0.5576525>,
    <0.8300745, 0.0001209, -0.5576525>,
    <0.5358788, 0.0000785, -0.8442949>,
    <0.8300732, 0.0001209, -0.5576545>,
    <0.9623798, 0.0001397, -0.2717079>,
    <0.5358762, 0.0000785, -0.8442966>,
    <0.8300727, 0.0001209, -0.5576552>,
    <0.8300727, 0.0001209, -0.5576552>,
    <0.9623796, 0.0001397, -0.2717083>,
    <0.9945474, 0.0001442, -0.1042853>,
    <0.9945474, 0.0001442, -0.1042851>,
    <0.9623796, 0.0001397, -0.2717083>,
    <0.9945474, 0.0001442, -0.1042855>,
    <0.9945474, 0.0001442, -0.1042855>,
    <0.9986191, 0.0001446, -0.0525351>,
    <0.9986191, 0.0001446, -0.0525350>,
    <0.9986191, 0.0001446, -0.0525350>,
    <0.9986191, 0.0001446, -0.0525349>,
    <0.9945475, 0.0001442, -0.1042849>,
    <0.9986191, 0.0001446, -0.0525349>,
    <0.9986191, 0.0001446, -0.0525347>,
    <0.9986191, 0.0001446, -0.0525347>,
    <0.9986191, 0.0001446, -0.0525346>,
    <0.9945475, 0.0001442, -0.1042847>,
    <0.9945475, 0.0001442, -0.1042847>,
    <0.9623802, 0.0001397, -0.2717065>,
    <-0.0000564, 0.9999999, 0.0003628>,
    <-0.0000731, 0.9999999, 0.0003290>,
    <-0.0000560, 1.0000000, 0.0001378>,
    <-0.0000513, 1.0000000, 0.0001579>,
    <-0.0000497, 1.0000000, 0.0001622>,
    <-0.0000506, 0.9999999, 0.0003698>,
    <-0.0000506, 0.9999999, 0.0003698>,
    <-0.0000524, 0.9999996, 0.0008537>,
    <-0.0000935, 1.0000000, 0.0002249>,
    <-0.0000603, 1.0000000, 0.0000933>,
    <-0.0002389, 0.9999997, 0.0008012>,
    <-0.0000961, 1.0000000, 0.0000391>,
    <-0.0000961, 1.0000000, 0.0000391>,
    <-0.0000611, 1.0000000, 0.0000391>,
    <-0.0000506, 1.0000000, 0.0000521>,
    <-0.0000501, 1.0000000, 0.0000621>,
    <-0.0000611, 1.0000000, 0.0000391>,
    <-0.0000507, 1.0000000, 0.0000391>,
    <-0.0000507, 1.0000000, 0.0000391>,
    <-0.0000492, 1.0000000, 0.0000391>,
    <-0.0000492, 1.0000000, 0.0000393>,
    <-0.0000492, 1.0000000, 0.0000393>,
    <-0.0000492, 1.0000000, 0.0000396>,
    <-0.0000495, 1.0000000, 0.0000667>,
    <-0.0000492, 1.0000000, 0.0000396>,
    <-0.0000492, 1.0000000, 0.0000399>,
    <-0.0000492, 1.0000000, 0.0000399>,
    <-0.0000492, 1.0000000, 0.0000401>,
    <-0.0000493, 1.0000000, 0.0000679>,
    <-0.0000493, 1.0000000, 0.0000679>,
    <-0.0000497, 1.0000000, 0.0001622>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <-0.9869426, -0.0002042, -0.1610724>,
    <-0.9869426, -0.0002040, -0.1610724>,
    <-0.9869431, -0.0002040, -0.1610691>,
    <-0.9869431, -0.0002042, -0.1610691>,
    <-0.9869431, -0.0002043, -0.1610691>,
    <-0.9869426, -0.0002043, -0.1610724>,
    <-0.9869426, -0.0002043, -0.1610724>,
    <-0.9869420, -0.0002043, -0.1610756>,
    <-0.9869420, -0.0002042, -0.1610756>,
    <-0.9869420, -0.0002042, -0.1610756>,
    <-0.9869420, -0.0002040, -0.1610756>,
    <-0.9869426, -0.0002039, -0.1610724>,
    <-0.9869431, -0.0002039, -0.1610691>,
    <-0.9869420, -0.0002040, -0.1610756>,
    <-0.9869420, -0.0002039, -0.1610756>,
    <-0.9869420, -0.0002039, -0.1610756>,
    <-0.9869420, -0.0002037, -0.1610756>,
    <-0.9869426, -0.0002037, -0.1610724>,
    <-0.9869426, -0.0002037, -0.1610724>,
    <-0.9869431, -0.0002037, -0.1610691>,
    <-0.9869436, -0.0002039, -0.1610659>,
    <-0.9869436, -0.0002040, -0.1610659>,
    <-0.9869431, -0.0002037, -0.1610691>,
    <-0.9869436, -0.0002037, -0.1610659>,
    <-0.9869436, -0.0002037, -0.1610659>,
    <-0.9869442, -0.0002037, -0.1610627>,
    <-0.9869442, -0.0002039, -0.1610627>,
    <-0.9869442, -0.0002039, -0.1610627>,
    <-0.9869442, -0.0002040, -0.1610627>,
    <-0.9869436, -0.0002042, -0.1610659>,
    <-0.9869442, -0.0002040, -0.1610627>,
    <-0.9869442, -0.0002042, -0.1610627>,
    <-0.9869442, -0.0002042, -0.1610627>,
    <-0.9869442, -0.0002043, -0.1610627>,
    <-0.9869436, -0.0002043, -0.1610659>,
    <-0.9869436, -0.0002043, -0.1610659>,
    <-0.9869431, -0.0002043, -0.1610691>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <0.9999404, 0.0003438, 0.0109141>,
    <0.9999447, 0.0002073, 0.0105163>,
    <0.9999338, 0.0002072, 0.0115037>,
    <0.9999321, 0.0002414, 0.0116512>,
    <0.9999286, 0.0002504, 0.0119507>,
    <0.9999285, 0.0003746, 0.0119506>,
    <0.9999285, 0.0003746, 0.0119506>,
    <0.9999722, 0.0008411, 0.0074076>,
    <0.9999724, 0.0006034, 0.0074077>,
    <0.9999725, 0.0002073, 0.0074076>,
    <0.9999404, 0.0000707, 0.0109136>,
    <0.9999321, 0.0001731, 0.0116506>,
    <0.9999725, -0.0001887, 0.0074074>,
    <0.9999725, -0.0004264, 0.0074070>,
    <0.9999286, 0.0000399, 0.0119496>,
    <0.9999286, 0.0000399, 0.0119496>,
    <0.9999286, 0.0001640, 0.0119498>,
    <0.9999294, 0.0002031, 0.0118782>,
    <0.9999298, 0.0002072, 0.0118451>,
    <0.9999286, 0.0001640, 0.0119498>,
    <0.9999286, 0.0002018, 0.0119498>,
    <0.9999286, 0.0002018, 0.0119498>,
    <0.9999286, 0.0002071, 0.0119498>,
    <0.9999286, 0.0002071, 0.0119500>,
    <0.9999286, 0.0002071, 0.0119500>,
    <0.9999286, 0.0002071, 0.0119503>,
    <0.9999294, 0.0002113, 0.0118787>,
    <0.9999286, 0.0002071, 0.0119503>,
    <0.9999286, 0.0002071, 0.0119505>,
    <0.9999286, 0.0002071, 0.0119505>,
    <0.9999286, 0.0002071, 0.0119508>,
    <0.9999286, 0.0002126, 0.0119508>,
    <0.9999286, 0.0002126, 0.0119508>,
    <0.9999286, 0.0002504, 0.0119507>,
    <0.9999903, 0.0006657, -0.0043628>,
    <0.9997832, 0.0004345, -0.0208159>,
    <0.9998818, 0.0002073, -0.0153711>,
    <0.9999996, 0.0002073, -0.0008270>,
    <0.9999722, 0.0008411, 0.0074076>,
    <0.9990811, 0.0020567, -0.0428093>,
    <0.9990811, 0.0020567, -0.0428093>,
    <0.9990829, 0.0006845, -0.0428133>,
    <0.9993788, 0.0002463, -0.0352415>,
    <0.9994752, 0.0002072, -0.0323937>,
    <0.9990829, 0.0006845, -0.0428133>,
    <0.9990830, 0.0002668, -0.0428145>,
    <0.9990830, 0.0002668, -0.0428145>,
    <0.9990830, 0.0002071, -0.0428147>,
    <0.9990830, 0.0002071, -0.0428138>,
    <0.9990830, 0.0002071, -0.0428138>,
    <0.9990831, 0.0002071, -0.0428129>,
    <0.9993789, 0.0001680, -0.0352399>,
    <0.9997834, -0.0000200, -0.0208147>,
    <0.9990831, 0.0002071, -0.0428129>,
    <0.9990831, 0.0002071, -0.0428121>,
    <0.9990831, 0.0002071, -0.0428121>,
    <0.9990832, 0.0002071, -0.0428112>,
    <0.9990832, 0.0001474, -0.0428110>,
    <0.9990832, 0.0001474, -0.0428110>,
    <0.9990832, -0.0002702, -0.0428096>,
    <0.9999905, -0.0002510, -0.0043624>,
    <0.9990832, -0.0002702, -0.0428096>,
    <0.9990821, -0.0016423, -0.0428051>,
    <0.9990821, -0.0016423, -0.0428051>,
    <0.9999725, -0.0004264, 0.0074070>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9514109>,
    <0.4350054, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289899, 0.9514109>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9514109>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559172, 0.9657316>,
    <0.6289899, 0.9514109>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4350054, 0.9657316>,
    <0.5000060, 0.9664305>,
    <0.4264033, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379346, 0.9664305>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664305>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559172, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773692, 0.9671308>,
    <0.6379346, 0.9664305>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4264033, 0.9671308>,
    <0.5000061, 0.9784050>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473428, 0.9784050>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9784050>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773692, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473428, 0.9784050>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032659, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458871>,
    <0.4677608, 0.9457569>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9514109>,
    <0.4355157, 0.9458871>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9452857>,
    <0.4677603, 0.9520134>,
    <0.4676327, 0.9588725>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9514109>,
    <0.5000059, 0.9657316>,
    <0.4350054, 0.9657316>,
    <0.4677603, 0.9520134>,
    <0.5000059, 0.9583740>,
    <0.4675013, 0.9657316>,
    <0.4352839, 0.9585445>,
    <0.4031382, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4350054, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352839, 0.9585445>,
    <0.4023500, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032659, 0.9526160>,
    <0.5322510, 0.9457569>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9514109>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9520135>,
    <0.5000059, 0.9452857>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458711>,
    <0.5967411, 0.9457569>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289899, 0.9514109>,
    <0.5644961, 0.9458711>,
    <0.5967380, 0.9395004>,
    <0.6289859, 0.9452857>,
    <0.5967441, 0.9520135>,
    <0.5967475, 0.9588725>,
    <0.5644983, 0.9526160>,
    <0.6289899, 0.9514109>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967441, 0.9520135>,
    <0.6289944, 0.9583740>,
    <0.5967509, 0.9657316>,
    <0.5645004, 0.9589932>,
    <0.5322532, 0.9588725>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9514109>,
    <0.5645004, 0.9589932>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9583740>,
    <0.5322521, 0.9520135>,
    <0.6423395, 0.9457569>,
    <0.6556982, 0.9526160>,
    <0.6289899, 0.9514109>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423438, 0.9520134>,
    <0.6289859, 0.9452857>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458871>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458871>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691098, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559172, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694404, 0.9657316>,
    <0.6557972, 0.9585445>,
    <0.6424011, 0.9588725>,
    <0.6556982, 0.9526160>,
    <0.6559172, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289899, 0.9514109>,
    <0.6557972, 0.9585445>,
    <0.6424600, 0.9657316>,
    <0.6289944, 0.9583740>,
    <0.6423438, 0.9520134>,
    <0.3997808, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4350054, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4023500, 0.9657316>,
    <0.4330490, 0.9660765>,
    <0.4665136, 0.9660812>,
    <0.4310370, 0.9664312>,
    <0.4350054, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664305>,
    <0.4330490, 0.9660765>,
    <0.4675013, 0.9657316>,
    <0.5000060, 0.9661007>,
    <0.4655215, 0.9664308>,
    <0.4643631, 0.9667808>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664305>,
    <0.5000061, 0.9671308>,
    <0.4264033, 0.9671308>,
    <0.4655215, 0.9664308>,
    <0.5000060, 0.9667582>,
    <0.4631991, 0.9671308>,
    <0.4287555, 0.9667757>,
    <0.3931579, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4264033, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4287555, 0.9667757>,
    <0.3895634, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664305>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664308>,
    <0.5000060, 0.9661007>,
    <0.5322542, 0.9657316>,
    <0.5668649, 0.9661011>,
    <0.6001028, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379346, 0.9664305>,
    <0.5668649, 0.9661011>,
    <0.5967509, 0.9657316>,
    <0.6337189, 0.9661007>,
    <0.6034548, 0.9664308>,
    <0.6068115, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.6379346, 0.9664305>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034548, 0.9664308>,
    <0.6421255, 0.9667582>,
    <0.6101681, 0.9671308>,
    <0.5710683, 0.9667586>,
    <0.5356086, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664305>,
    <0.5710683, 0.9667586>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667582>,
    <0.5344905, 0.9664308>,
    <0.6473391, 0.9660812>,
    <0.6665054, 0.9664312>,
    <0.6379346, 0.9664305>,
    <0.6289992, 0.9657316>,
    <0.6559172, 0.9657316>,
    <0.6522200, 0.9664308>,
    <0.6337189, 0.9661007>,
    <0.6424600, 0.9657316>,
    <0.6611372, 0.9660765>,
    <0.6749768, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559172, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6611372, 0.9660765>,
    <0.6694404, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866644, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773692, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926253, 0.9671308>,
    <0.6718544, 0.9667757>,
    <0.6571745, 0.9667808>,
    <0.6665054, 0.9664312>,
    <0.6773692, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379346, 0.9664305>,
    <0.6718544, 0.9667757>,
    <0.6621313, 0.9671308>,
    <0.6421255, 0.9667582>,
    <0.6522200, 0.9664308>,
    <0.3896432, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4264033, 0.9671308>,
    <0.3895222, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3895634, 0.9671308>,
    <0.4263749, 0.9728674>,
    <0.4631915, 0.9726067>,
    <0.4263507, 0.9777601>,
    <0.4264033, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9784050>,
    <0.4263749, 0.9728674>,
    <0.4631991, 0.9671308>,
    <0.5000061, 0.9727092>,
    <0.4631779, 0.9780826>,
    <0.4631249, 0.9832360>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9784050>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631779, 0.9780826>,
    <0.5000061, 0.9835191>,
    <0.4630714, 0.9883895>,
    <0.4262411, 0.9832068>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262411, 0.9832068>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895222, 0.9777601>,
    <0.5367803, 0.9726067>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9784050>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9780826>,
    <0.5000061, 0.9727092>,
    <0.5367268, 0.9671308>,
    <0.5735533, 0.9723901>,
    <0.6103351, 0.9726067>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473428, 0.9784050>,
    <0.5735533, 0.9723901>,
    <0.6101681, 0.9671308>,
    <0.6471134, 0.9727092>,
    <0.6105021, 0.9780826>,
    <0.6106561, 0.9832360>,
    <0.5736614, 0.9777601>,
    <0.6473428, 0.9784050>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105021, 0.9780826>,
    <0.6475487, 0.9835191>,
    <0.6108101, 0.9883895>,
    <0.5737711, 0.9832046>,
    <0.5368873, 0.9832360>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9784050>,
    <0.5737711, 0.9832046>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9835191>,
    <0.5368338, 0.9780826>,
    <0.6623549, 0.9726067>,
    <0.6778190, 0.9777601>,
    <0.6473428, 0.9784050>,
    <0.6468888, 0.9671308>,
    <0.6773692, 0.9671308>,
    <0.6625811, 0.9780826>,
    <0.6471134, 0.9727092>,
    <0.6621313, 0.9671308>,
    <0.6776119, 0.9728674>,
    <0.6928063, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773692, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776119, 0.9728674>,
    <0.6926253, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930704, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930704, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780837, 0.9832068>,
    <0.6628105, 0.9832360>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473428, 0.9784050>,
    <0.6780837, 0.9832068>,
    <0.6630402, 0.9883895>,
    <0.6475487, 0.9835191>,
    <0.6625811, 0.9780826>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.05, -0.36281, -0.147353>
}

#declare TMesh009 = mesh2 {
  vertex_vectors {
    582,
    <2.2046850, 0.2622270, 18.5058918>,
    <2.0021506, 0.2622153, 18.5058918>,
    <2.0021672, 0.1836464, 18.5058918>,
    <2.2046990, 0.1836606, 18.5058918>,
    <2.1034178, 0.2622212, 18.5058918>,
    <2.0021589, 0.2229309, 18.5058918>,
    <2.1034331, 0.1836535, 18.5058918>,
    <2.2046920, 0.2229438, 18.5058918>,
    <2.1034254, 0.2229373, 18.5058918>,
    <2.4072308, 0.1836748, 18.5058918>,
    <2.4072193, 0.2622387, 18.5058918>,
    <2.3059649, 0.1836677, 18.5058918>,
    <2.4072251, 0.2229568, 18.5058918>,
    <2.3059522, 0.2622329, 18.5058918>,
    <2.3059585, 0.2229503, 18.5058918>,
    <2.4072079, 0.3408027, 18.5058918>,
    <2.2046709, 0.3407934, 18.5058918>,
    <2.4072136, 0.3015207, 18.5058918>,
    <2.3059394, 0.3407980, 18.5058918>,
    <2.2046780, 0.3015102, 18.5058918>,
    <2.3059458, 0.3015155, 18.5058918>,
    <2.0021340, 0.3407842, 18.5058918>,
    <2.1034025, 0.3407888, 18.5058918>,
    <2.0021423, 0.3014997, 18.5058918>,
    <2.1034101, 0.3015050, 18.5058918>,
    <2.0664387, 0.1835149, 18.1207908>,
    <2.0044034, 0.1835050, 18.1202395>,
    <2.0044687, 0.1835009, 18.1217627>,
    <2.0559641, 0.1835106, 18.1217627>,
    <2.0354211, 0.1835099, 18.1205151>,
    <2.0044361, 0.1835029, 18.1210011>,
    <2.0302164, 0.1835058, 18.1217627>,
    <2.0612014, 0.1835128, 18.1212767>,
    <2.0328188, 0.1835079, 18.1211389>,
    <2.1074595, 0.1835204, 18.1217627>,
    <2.1284740, 0.1835248, 18.1213420>,
    <2.0817118, 0.1835155, 18.1217627>,
    <2.1179668, 0.1835226, 18.1215524>,
    <2.0974564, 0.1835198, 18.1210664>,
    <2.0895841, 0.1835177, 18.1214145>,
    <2.1494885, 0.1835292, 18.1209214>,
    <2.0769133, 0.1835192, 18.1198188>,
    <2.1389813, 0.1835270, 18.1211317>,
    <2.1132009, 0.1835242, 18.1203701>,
    <2.0716760, 0.1835170, 18.1203048>,
    <2.1053286, 0.1835220, 18.1207182>,
    <2.0043382, 0.1835091, 18.1187163>,
    <2.0406257, 0.1835141, 18.1192675>,
    <2.0043708, 0.1835071, 18.1194779>,
    <2.0380234, 0.1835120, 18.1198913>,
    <2.1284614, 0.2622422, 18.1213420>,
    <2.1074469, 0.2622423, 18.1217627>,
    <2.1284677, 0.2228835, 18.1213420>,
    <2.1074532, 0.2228813, 18.1217627>,
    <2.1179541, 0.2622422, 18.1215524>,
    <2.1179605, 0.2228824, 18.1215524>,
    <2.1074342, 0.3409641, 18.1217627>,
    <2.1284488, 0.3409595, 18.1213420>,
    <2.1074405, 0.3016032, 18.1217627>,
    <2.1179415, 0.3409618, 18.1215524>,
    <2.1284551, 0.3016009, 18.1213420>,
    <2.1179478, 0.3016020, 18.1215524>,
    <2.1494633, 0.3409550, 18.1209214>,
    <2.1494759, 0.2622421, 18.1209214>,
    <2.1389560, 0.3409573, 18.1211317>,
    <2.1494696, 0.3015985, 18.1209214>,
    <2.1389687, 0.2622421, 18.1211317>,
    <2.1389624, 0.3015997, 18.1211317>,
    <2.1494822, 0.2228856, 18.1209214>,
    <2.1389750, 0.2228846, 18.1211317>,
    <2.0664094, 0.3409536, 18.1207908>,
    <2.0559348, 0.3409583, 18.1217627>,
    <2.0974291, 0.3409566, 18.1210664>,
    <2.0816845, 0.3409612, 18.1217627>,
    <2.0611721, 0.3409559, 18.1212767>,
    <2.0895568, 0.3409589, 18.1214145>,
    <2.0044353, 0.3409524, 18.1217627>,
    <2.0043701, 0.3409477, 18.1202395>,
    <2.0301850, 0.3409554, 18.1217627>,
    <2.0044027, 0.3409501, 18.1210011>,
    <2.0353897, 0.3409506, 18.1205151>,
    <2.0327874, 0.3409530, 18.1211389>,
    <2.0043048, 0.3409429, 18.1187163>,
    <2.0768841, 0.3409489, 18.1198188>,
    <2.0043374, 0.3409453, 18.1194779>,
    <2.0405944, 0.3409459, 18.1192675>,
    <2.0716467, 0.3409513, 18.1203048>,
    <2.0379921, 0.3409483, 18.1198913>,
    <2.1131737, 0.3409520, 18.1203701>,
    <2.1053014, 0.3409543, 18.1207182>,
    <2.0766447, 0.1835280, 18.1376413>,
    <2.0042020, 0.1835177, 18.1370901>,
    <2.0404234, 0.1835229, 18.1373657>,
    <2.0042701, 0.1835134, 18.1279032>,
    <2.0767790, 0.1835236, 18.1287301>,
    <2.0405246, 0.1835185, 18.1283166>,
    <2.1490873, 0.1835383, 18.1381926>,
    <2.1492879, 0.1835337, 18.1295570>,
    <2.1128660, 0.1835332, 18.1379170>,
    <2.1130335, 0.1835287, 18.1291435>,
    <2.1486861, 0.1835474, 18.1554639>,
    <2.0763760, 0.1835369, 18.1554639>,
    <2.1488867, 0.1835429, 18.1468283>,
    <2.1125311, 0.1835422, 18.1554639>,
    <2.0765104, 0.1835325, 18.1465526>,
    <2.1126985, 0.1835377, 18.1466904>,
    <2.0040659, 0.1835263, 18.1554639>,
    <2.0402210, 0.1835316, 18.1554639>,
    <2.0041340, 0.1835220, 18.1462770>,
    <2.0403222, 0.1835272, 18.1464148>,
    <2.1490748, 0.2622419, 18.1381926>,
    <2.1490811, 0.2228901, 18.1381926>,
    <2.1492754, 0.2622420, 18.1295570>,
    <2.1492816, 0.2228879, 18.1295570>,
    <2.1490623, 0.3409454, 18.1381926>,
    <2.1492628, 0.3409502, 18.1295570>,
    <2.1490685, 0.3015936, 18.1381926>,
    <2.1492691, 0.3015961, 18.1295570>,
    <2.1486612, 0.3409359, 18.1554639>,
    <2.1486737, 0.2622417, 18.1554639>,
    <2.1488618, 0.3409406, 18.1468283>,
    <2.1486675, 0.3015888, 18.1554639>,
    <2.1488742, 0.2622418, 18.1468283>,
    <2.1488680, 0.3015912, 18.1468283>,
    <2.1486799, 0.2228945, 18.1554639>,
    <2.1488805, 0.2228923, 18.1468283>,
    <2.0766155, 0.3409392, 18.1376413>,
    <2.1128389, 0.3409423, 18.1379170>,
    <2.0767498, 0.3409441, 18.1287301>,
    <2.1130063, 0.3409471, 18.1291435>,
    <2.0041687, 0.3409329, 18.1370901>,
    <2.0042367, 0.3409379, 18.1279032>,
    <2.0403921, 0.3409361, 18.1373657>,
    <2.0404932, 0.3409410, 18.1283166>,
    <2.0040326, 0.3409230, 18.1554639>,
    <2.0763469, 0.3409294, 18.1554639>,
    <2.0041006, 0.3409280, 18.1462770>,
    <2.0401897, 0.3409262, 18.1554639>,
    <2.0764812, 0.3409343, 18.1465526>,
    <2.0402909, 0.3409311, 18.1464148>,
    <2.1125041, 0.3409327, 18.1554639>,
    <2.1126715, 0.3409375, 18.1466904>,
    <2.0812641, 0.1835432, 18.1573801>,
    <2.0039695, 0.1835324, 18.1573801>,
    <2.0426168, 0.1835378, 18.1573801>,
    <2.0040177, 0.1835294, 18.1564220>,
    <2.0788201, 0.1835400, 18.1564220>,
    <2.0414189, 0.1835347, 18.1564220>,
    <2.1585588, 0.1835539, 18.1573801>,
    <2.1536225, 0.1835507, 18.1564220>,
    <2.1199115, 0.1835485, 18.1573801>,
    <2.1162213, 0.1835454, 18.1564220>,
    <2.1684314, 0.1835604, 18.1592964>,
    <2.0861522, 0.1835495, 18.1592964>,
    <2.1634951, 0.1835571, 18.1583383>,
    <2.1272918, 0.1835549, 18.1592964>,
    <2.0837082, 0.1835463, 18.1583383>,
    <2.1236016, 0.1835517, 18.1583383>,
    <2.0038730, 0.1835385, 18.1592964>,
    <2.0450126, 0.1835440, 18.1592964>,
    <2.0039212, 0.1835355, 18.1583383>,
    <2.0438147, 0.1835409, 18.1583383>,
    <2.1585464, 0.2622415, 18.1573801>,
    <2.1585526, 0.2228977, 18.1573801>,
    <2.1536100, 0.2622416, 18.1564220>,
    <2.1536162, 0.2228961, 18.1564220>,
    <2.1585340, 0.3409291, 18.1573801>,
    <2.1535976, 0.3409325, 18.1564220>,
    <2.1585402, 0.3015853, 18.1573801>,
    <2.1536038, 0.3015870, 18.1564220>,
    <2.1684068, 0.3409223, 18.1592964>,
    <2.1684191, 0.2622414, 18.1592964>,
    <2.1634704, 0.3409257, 18.1583383>,
    <2.1684129, 0.3015818, 18.1592964>,
    <2.1634827, 0.2622414, 18.1583383>,
    <2.1634766, 0.3015836, 18.1583383>,
    <2.1684253, 0.2229009, 18.1592964>,
    <2.1634889, 0.2228993, 18.1583383>,
    <2.0812351, 0.3409225, 18.1573801>,
    <2.1198845, 0.3409258, 18.1573801>,
    <2.0787910, 0.3409260, 18.1564220>,
    <2.1161943, 0.3409292, 18.1564220>,
    <2.0039361, 0.3409159, 18.1573801>,
    <2.0039844, 0.3409195, 18.1564220>,
    <2.0425856, 0.3409192, 18.1573801>,
    <2.0413877, 0.3409227, 18.1564220>,
    <2.0038397, 0.3409089, 18.1592964>,
    <2.0861232, 0.3409156, 18.1592964>,
    <2.0038879, 0.3409124, 18.1583383>,
    <2.0449814, 0.3409123, 18.1592964>,
    <2.0836791, 0.3409191, 18.1583383>,
    <2.0437835, 0.3409157, 18.1583383>,
    <2.1272650, 0.3409190, 18.1592964>,
    <2.1235748, 0.3409224, 18.1583383>,
    <2.0877229, 0.1835507, 18.2324892>,
    <2.0038724, 0.1835386, 18.2344341>,
    <2.0457964, 0.1835447, 18.2333227>,
    <2.0038727, 0.1835386, 18.1968653>,
    <2.0861681, 0.1835495, 18.1968653>,
    <2.0450204, 0.1835440, 18.1968653>,
    <2.1715888, 0.1835618, 18.2322113>,
    <2.1684634, 0.1835604, 18.1968653>,
    <2.1296546, 0.1835563, 18.2322113>,
    <2.1273157, 0.1835549, 18.1968653>,
    <2.1994932, 0.1835742, 18.2873438>,
    <2.1015957, 0.1835619, 18.2890109>,
    <2.1809009, 0.1835659, 18.2631118>,
    <2.1505368, 0.1835685, 18.2873438>,
    <2.0923559, 0.1835542, 18.2642232>,
    <2.1366233, 0.1835604, 18.2631118>,
    <2.0038718, 0.1835386, 18.3095719>,
    <2.0526852, 0.1835533, 18.2940122>,
    <2.0038721, 0.1835386, 18.2720030>,
    <2.0481089, 0.1835467, 18.2675574>,
    <2.1715765, 0.2622413, 18.2322113>,
    <2.1715826, 0.2229016, 18.2322113>,
    <2.1684511, 0.2622414, 18.1968653>,
    <2.1684573, 0.2229009, 18.1968653>,
    <2.1715641, 0.3409209, 18.2322113>,
    <2.1684387, 0.3409223, 18.1968653>,
    <2.1715703, 0.3015811, 18.2322113>,
    <2.1684449, 0.3015818, 18.1968653>,
    <2.1994687, 0.3409079, 18.2873438>,
    <2.1994809, 0.2622410, 18.2873438>,
    <2.1808763, 0.3409165, 18.2631118>,
    <2.1994748, 0.3015745, 18.2873438>,
    <2.1808886, 0.2622412, 18.2631118>,
    <2.1808825, 0.3015789, 18.2631118>,
    <2.1994871, 0.2229076, 18.2873438>,
    <2.1808948, 0.2229036, 18.2631118>,
    <2.0876939, 0.3409143, 18.2324892>,
    <2.1296277, 0.3409175, 18.2322113>,
    <2.0861391, 0.3409156, 18.1968653>,
    <2.1272889, 0.3409190, 18.1968653>,
    <2.0038391, 0.3409088, 18.2344341>,
    <2.0038394, 0.3409089, 18.1968653>,
    <2.0457652, 0.3409115, 18.2333227>,
    <2.0449892, 0.3409122, 18.1968653>,
    <2.0038384, 0.3409088, 18.3095719>,
    <2.1015668, 0.3409020, 18.2890109>,
    <2.0038387, 0.3409088, 18.2720030>,
    <2.0526541, 0.3409019, 18.2940122>,
    <2.0923269, 0.3409104, 18.2642232>,
    <2.0480777, 0.3409093, 18.2675574>,
    <2.1505101, 0.3409044, 18.2873438>,
    <2.1365965, 0.3409131, 18.2631118>,
    <2.1354633, 0.1835922, 18.3131904>,
    <2.0032176, 0.1835800, 18.3135798>,
    <2.0693404, 0.1835861, 18.3133573>,
    <2.0035447, 0.1835593, 18.3115759>,
    <2.1169712, 0.1835755, 18.3037960>,
    <2.0602528, 0.1835677, 18.3071303>,
    <2.2677097, 0.1836044, 18.3131347>,
    <2.2304590, 0.1835879, 18.3026846>,
    <2.2015864, 0.1835983, 18.3131347>,
    <2.1737100, 0.1835820, 18.3026846>,
    <2.3367110, 0.1836352, 18.3353648>,
    <2.1697200, 0.1836230, 18.3340315>,
    <2.3051565, 0.1836211, 18.3226946>,
    <2.2532228, 0.1836286, 18.3353648>,
    <2.1540527, 0.1836090, 18.3218058>,
    <2.2296095, 0.1836147, 18.3226946>,
    <2.0025635, 0.1836214, 18.3175878>,
    <2.0861880, 0.1836193, 18.3300317>,
    <2.0028906, 0.1836007, 18.3155838>,
    <2.0784765, 0.1836045, 18.3191392>,
    <2.2676976, 0.2622403, 18.3131347>,
    <2.2677036, 0.2229224, 18.3131347>,
    <2.2304468, 0.2622407, 18.3026846>,
    <2.2304529, 0.2229143, 18.3026846>,
    <2.2676856, 0.3408763, 18.3131347>,
    <2.2304347, 0.3408936, 18.3026846>,
    <2.2676916, 0.3015583, 18.3131347>,
    <2.2304408, 0.3015672, 18.3026846>,
    <2.3366874, 0.3408441, 18.3353648>,
    <2.3366992, 0.2622396, 18.3353648>,
    <2.3051328, 0.3408589, 18.3226946>,
    <2.3366933, 0.3015419, 18.3353648>,
    <2.3051447, 0.2622400, 18.3226946>,
    <2.3051387, 0.3015494, 18.3226946>,
    <2.3367051, 0.2229374, 18.3353648>,
    <2.3051506, 0.2229305, 18.3226946>,
    <2.1354346, 0.3408686, 18.3131904>,
    <2.2015601, 0.3408724, 18.3131347>,
    <2.1169424, 0.3408870, 18.3037960>,
    <2.1736835, 0.3408899, 18.3026846>,
    <2.0031844, 0.3408610, 18.3135798>,
    <2.0035114, 0.3408849, 18.3115759>,
    <2.0693094, 0.3408648, 18.3133573>,
    <2.0602218, 0.3408856, 18.3071303>,
    <2.0025303, 0.3408131, 18.3175878>,
    <2.1696916, 0.3408347, 18.3340315>,
    <2.0028573, 0.3408371, 18.3155838>,
    <2.0861572, 0.3408273, 18.3300317>,
    <2.1540243, 0.3408501, 18.3218058>,
    <2.0784457, 0.3408439, 18.3191392>,
    <2.2531968, 0.3408399, 18.3353648>,
    <2.2295834, 0.3408548, 18.3226946>,
    <2.1847094, 0.1836357, 18.3800376>,
    <2.0025322, 0.1836233, 18.3784821>,
    <2.0936220, 0.1836295, 18.3793709>,
    <2.0025479, 0.1836224, 18.3480349>,
    <2.1794453, 0.1836314, 18.3542569>,
    <2.0910014, 0.1836265, 18.3515903>,
    <2.3668719, 0.1836490, 18.3802598>,
    <2.3562844, 0.1836440, 18.3551457>,
    <2.2757919, 0.1836423, 18.3802598>,
    <2.2678697, 0.1836374, 18.3551457>,
    <2.3730707, 0.1836524, 18.4393764>,
    <2.1877858, 0.1836389, 18.4393764>,
    <2.3714689, 0.1836514, 18.4089292>,
    <2.2804282, 0.1836456, 18.4393764>,
    <2.1869927, 0.1836378, 18.4089292>,
    <2.2792308, 0.1836446, 18.4089292>,
    <2.0025009, 0.1836253, 18.4393764>,
    <2.0951433, 0.1836321, 18.4393764>,
    <2.0025166, 0.1836243, 18.4089292>,
    <2.0947546, 0.1836311, 18.4089292>,
    <2.3668603, 0.2622393, 18.3802598>,
    <2.3668661, 0.2229442, 18.3802598>,
    <2.3562727, 0.2622394, 18.3551457>,
    <2.3562785, 0.2229417, 18.3551457>,
    <2.3668486, 0.3408296, 18.3802598>,
    <2.3562610, 0.3408348, 18.3551457>,
    <2.3668544, 0.3015345, 18.3802598>,
    <2.3562668, 0.3015371, 18.3551457>,
    <2.3730474, 0.3408261, 18.4393764>,
    <2.3730590, 0.2622392, 18.4393764>,
    <2.3714456, 0.3408272, 18.4089292>,
    <2.3730532, 0.3015327, 18.4393764>,
    <2.3714573, 0.2622393, 18.4089292>,
    <2.3714515, 0.3015332, 18.4089292>,
    <2.3730649, 0.2229458, 18.4393764>,
    <2.3714631, 0.2229453, 18.4089292>,
    <2.1846811, 0.3408208, 18.3800376>,
    <2.2757661, 0.3408253, 18.3802598>,
    <2.1794170, 0.3408256, 18.3542569>,
    <2.2678438, 0.3408306, 18.3551457>,
    <2.0024990, 0.3408109, 18.3784821>,
    <2.0025147, 0.3408120, 18.3480349>,
    <2.0935913, 0.3408159, 18.3793709>,
    <2.0909707, 0.3408191, 18.3515903>,
    <2.0024677, 0.3408086, 18.4393764>,
    <2.1877576, 0.3408173, 18.4393764>,
    <2.0024834, 0.3408097, 18.4089292>,
    <2.0951126, 0.3408129, 18.4393764>,
    <2.1869645, 0.3408184, 18.4089292>,
    <2.0947239, 0.3408141, 18.4089292>,
    <2.2804025, 0.3408217, 18.4393764>,
    <2.2792051, 0.3408228, 18.4089292>,
    <2.1962424, 0.1836497, 18.4393764>,
    <2.0023340, 0.1836359, 18.4393764>,
    <2.0992882, 0.1836428, 18.4393764>,
    <2.0024175, 0.1836306, 18.4393764>,
    <2.1920141, 0.1836443, 18.4393764>,
    <2.0972158, 0.1836375, 18.4393764>,
    <2.3901507, 0.1836636, 18.4393764>,
    <2.3816107, 0.1836580, 18.4393764>,
    <2.2931966, 0.1836567, 18.4393764>,
    <2.2868124, 0.1836512, 18.4393764>,
    <2.4072308, 0.1836748, 18.4393764>,
    <2.2046990, 0.1836606, 18.4393764>,
    <2.3986908, 0.1836692, 18.4393764>,
    <2.3059649, 0.1836677, 18.4393764>,
    <2.2004707, 0.1836552, 18.4393764>,
    <2.2995807, 0.1836622, 18.4393764>,
    <2.0021672, 0.1836464, 18.4393764>,
    <2.1034331, 0.1836535, 18.4393764>,
    <2.0022506, 0.1836412, 18.4393764>,
    <2.1013606, 0.1836482, 18.4393764>,
    <2.3901392, 0.2622390, 18.4393764>,
    <2.3901450, 0.2229513, 18.4393764>,
    <2.3815991, 0.2622391, 18.4393764>,
    <2.3816049, 0.2229486, 18.4393764>,
    <2.3901276, 0.3408144, 18.4393764>,
    <2.3815875, 0.3408202, 18.4393764>,
    <2.3901334, 0.3015267, 18.4393764>,
    <2.3815933, 0.3015297, 18.4393764>,
    <2.4072079, 0.3408027, 18.4393764>,
    <2.4072193, 0.2622387, 18.4393764>,
    <2.3986678, 0.3408085, 18.4393764>,
    <2.4072136, 0.3015207, 18.4393764>,
    <2.3986793, 0.2622389, 18.4393764>,
    <2.3986735, 0.3015237, 18.4393764>,
    <2.4072251, 0.2229568, 18.4393764>,
    <2.3986850, 0.2229540, 18.4393764>,
    <2.1962143, 0.3408054, 18.4393764>,
    <2.2931709, 0.3408099, 18.4393764>,
    <2.1919859, 0.3408113, 18.4393764>,
    <2.2867867, 0.3408158, 18.4393764>,
    <2.0023009, 0.3407964, 18.4393764>,
    <2.0023843, 0.3408025, 18.4393764>,
    <2.0992576, 0.3408009, 18.4393764>,
    <2.0971851, 0.3408069, 18.4393764>,
    <2.0021340, 0.3407842, 18.4393764>,
    <2.2046709, 0.3407934, 18.4393764>,
    <2.0022174, 0.3407903, 18.4393764>,
    <2.1034025, 0.3407888, 18.4393764>,
    <2.2004426, 0.3407994, 18.4393764>,
    <2.1013300, 0.3407948, 18.4393764>,
    <2.3059394, 0.3407980, 18.4393764>,
    <2.2995552, 0.3408040, 18.4393764>,
    <2.2046990, 0.1836606, 18.4726341>,
    <2.0021672, 0.1836464, 18.4726341>,
    <2.1034331, 0.1836535, 18.4726341>,
    <2.0021672, 0.1836464, 18.4560052>,
    <2.2046990, 0.1836606, 18.4560052>,
    <2.1034331, 0.1836535, 18.4560052>,
    <2.4072308, 0.1836748, 18.4726341>,
    <2.4072308, 0.1836748, 18.4560052>,
    <2.3059649, 0.1836677, 18.4726341>,
    <2.3059649, 0.1836677, 18.4560052>,
    <2.4072308, 0.1836748, 18.4892630>,
    <2.2046990, 0.1836606, 18.4892630>,
    <2.3059649, 0.1836677, 18.4892630>,
    <2.0021672, 0.1836464, 18.4892630>,
    <2.1034331, 0.1836535, 18.4892630>,
    <2.4072193, 0.2622387, 18.4726341>,
    <2.4072251, 0.2229568, 18.4726341>,
    <2.4072193, 0.2622387, 18.4560052>,
    <2.4072251, 0.2229568, 18.4560052>,
    <2.4072079, 0.3408027, 18.4726341>,
    <2.4072079, 0.3408027, 18.4560052>,
    <2.4072136, 0.3015207, 18.4726341>,
    <2.4072136, 0.3015207, 18.4560052>,
    <2.4072079, 0.3408027, 18.4892630>,
    <2.4072193, 0.2622387, 18.4892630>,
    <2.4072136, 0.3015207, 18.4892630>,
    <2.4072251, 0.2229568, 18.4892630>,
    <2.2046709, 0.3407934, 18.4726341>,
    <2.3059394, 0.3407980, 18.4726341>,
    <2.2046709, 0.3407934, 18.4560052>,
    <2.3059394, 0.3407980, 18.4560052>,
    <2.0021340, 0.3407842, 18.4726341>,
    <2.0021340, 0.3407842, 18.4560052>,
    <2.1034025, 0.3407888, 18.4726341>,
    <2.1034025, 0.3407888, 18.4560052>,
    <2.0021340, 0.3407842, 18.4892630>,
    <2.2046709, 0.3407934, 18.4892630>,
    <2.1034025, 0.3407888, 18.4892630>,
    <2.3059394, 0.3407980, 18.4892630>,
    <2.0021506, 0.2622153, 18.4726341>,
    <2.0021672, 0.1836464, 18.4726341>,
    <2.0021506, 0.2622153, 18.4393764>,
    <2.0021589, 0.2229309, 18.4726341>,
    <2.0021672, 0.1836464, 18.4560052>,
    <2.0021589, 0.2229309, 18.4393764>,
    <2.0021506, 0.2622153, 18.4560052>,
    <2.0021589, 0.2229309, 18.4560052>,
    <2.0021340, 0.3407842, 18.4726341>,
    <2.0021423, 0.3014997, 18.4393764>,
    <2.0021340, 0.3407842, 18.4560052>,
    <2.0021423, 0.3014997, 18.4726341>,
    <2.0021423, 0.3014997, 18.4560052>,
    <2.0021506, 0.2622153, 18.5058918>,
    <2.0021340, 0.3407842, 18.4892630>,
    <2.0021423, 0.3014997, 18.5058918>,
    <2.0021506, 0.2622153, 18.4892630>,
    <2.0021423, 0.3014997, 18.4892630>,
    <2.0021589, 0.2229309, 18.5058918>,
    <2.0021672, 0.1836464, 18.4892630>,
    <2.0021589, 0.2229309, 18.4892630>,
    <2.0023174, 0.2622161, 18.4393764>,
    <2.0024843, 0.2622169, 18.4393764>,
    <2.0024009, 0.2622165, 18.4393764>,
    <2.0024926, 0.2229211, 18.4393764>,
    <2.0023257, 0.2229260, 18.4393764>,
    <2.0024092, 0.2229236, 18.4393764>,
    <2.0021506, 0.2622153, 18.4393764>,
    <2.0021589, 0.2229309, 18.4393764>,
    <2.0022340, 0.2622157, 18.4393764>,
    <2.0022423, 0.2229284, 18.4393764>,
    <2.0021423, 0.3014997, 18.4393764>,
    <2.0023092, 0.3015062, 18.4393764>,
    <2.0022257, 0.3015030, 18.4393764>,
    <2.0024760, 0.3015128, 18.4393764>,
    <2.0023926, 0.3015095, 18.4393764>,
    <2.0025156, 0.2622171, 18.3784821>,
    <2.0025322, 0.1836233, 18.3784821>,
    <2.0025469, 0.2622173, 18.3175878>,
    <2.0025239, 0.2229202, 18.3784821>,
    <2.0025479, 0.1836224, 18.3480349>,
    <2.0025552, 0.2229193, 18.3175878>,
    <2.0025313, 0.2622172, 18.3480349>,
    <2.0025396, 0.2229198, 18.3480349>,
    <2.0024990, 0.3408109, 18.3784821>,
    <2.0025386, 0.3015152, 18.3175878>,
    <2.0025147, 0.3408120, 18.3480349>,
    <2.0025073, 0.3015140, 18.3784821>,
    <2.0025230, 0.3015146, 18.3480349>,
    <2.0024843, 0.2622169, 18.4393764>,
    <2.0024834, 0.3408097, 18.4089292>,
    <2.0024760, 0.3015128, 18.4393764>,
    <2.0025000, 0.2622170, 18.4089292>,
    <2.0024917, 0.3015134, 18.4089292>,
    <2.0024926, 0.2229211, 18.4393764>,
    <2.0025166, 0.1836243, 18.4089292>,
    <2.0025083, 0.2229207, 18.4089292>,
    <2.0032010, 0.2622205, 18.3135798>,
    <2.0038551, 0.2622237, 18.3095719>,
    <2.0035281, 0.2622221, 18.3115759>,
    <2.0038634, 0.2228812, 18.3095719>,
    <2.0032093, 0.2229002, 18.3135798>,
    <2.0035364, 0.2228907, 18.3115759>,
    <2.0025469, 0.2622173, 18.3175878>,
    <2.0025552, 0.2229193, 18.3175878>,
    <2.0028740, 0.2622189, 18.3155838>,
    <2.0028823, 0.2229098, 18.3155838>,
    <2.0025386, 0.3015152, 18.3175878>,
    <2.0031927, 0.3015407, 18.3135798>,
    <2.0028656, 0.3015280, 18.3155838>,
    <2.0038468, 0.3015663, 18.3095719>,
    <2.0035197, 0.3015535, 18.3115759>,
    <2.0038557, 0.2622237, 18.2344341>,
    <2.0038724, 0.1835386, 18.2344341>,
    <2.0038563, 0.2622237, 18.1592964>,
    <2.0038641, 0.2228811, 18.2344341>,
    <2.0038727, 0.1835386, 18.1968653>,
    <2.0038647, 0.2228811, 18.1592964>,
    <2.0038560, 0.2622237, 18.1968653>,
    <2.0038644, 0.2228811, 18.1968653>,
    <2.0038391, 0.3409088, 18.2344341>,
    <2.0038480, 0.3015663, 18.1592964>,
    <2.0038394, 0.3409089, 18.1968653>,
    <2.0038474, 0.3015663, 18.2344341>,
    <2.0038477, 0.3015663, 18.1968653>,
    <2.0038551, 0.2622237, 18.3095719>,
    <2.0038387, 0.3409088, 18.2720030>,
    <2.0038468, 0.3015663, 18.3095719>,
    <2.0038554, 0.2622237, 18.2720030>,
    <2.0038471, 0.3015663, 18.2720030>,
    <2.0038634, 0.2228812, 18.3095719>,
    <2.0038721, 0.1835386, 18.2720030>,
    <2.0038637, 0.2228812, 18.2720030>,
    <2.0039528, 0.2622242, 18.1573801>,
    <2.0040493, 0.2622247, 18.1554639>,
    <2.0040010, 0.2622244, 18.1564220>,
    <2.0040576, 0.2228755, 18.1554639>,
    <2.0039611, 0.2228783, 18.1573801>,
    <2.0040094, 0.2228769, 18.1564220>,
    <2.0038563, 0.2622237, 18.1592964>,
    <2.0038647, 0.2228811, 18.1592964>,
    <2.0039046, 0.2622240, 18.1583383>,
    <2.0039129, 0.2228797, 18.1583383>,
    <2.0038480, 0.3015663, 18.1592964>,
    <2.0039445, 0.3015701, 18.1573801>,
    <2.0038962, 0.3015682, 18.1583383>,
    <2.0040409, 0.3015738, 18.1554639>,
    <2.0039927, 0.3015719, 18.1564220>,
    <2.0042444, 0.2622256, 18.1389725>,
    <2.0042673, 0.1835136, 18.1386133>,
    <2.0043812, 0.2622263, 18.1258340>,
    <2.0042548, 0.2228696, 18.1388528>,
    <2.0043680, 0.1835072, 18.1301880>,
    <2.0044020, 0.2228646, 18.1251156>,
    <2.0043263, 0.2622260, 18.1316249>,
    <2.0043430, 0.2228666, 18.1311460>,
    <2.0042339, 0.3409377, 18.1386133>,
    <2.0043853, 0.3015881, 18.1251156>,
    <2.0043346, 0.3409451, 18.1301880>,
    <2.0042381, 0.3015817, 18.1388528>,
    <2.0043263, 0.3015855, 18.1311460>,
    <2.0040493, 0.2622247, 18.1554639>,
    <2.0041333, 0.3409304, 18.1470386>,
    <2.0040409, 0.3015738, 18.1554639>,
    <2.0041499, 0.2622252, 18.1470386>,
    <2.0041416, 0.3015778, 18.1470386>,
    <2.0040576, 0.2228755, 18.1554639>,
    <2.0041666, 0.1835200, 18.1470386>,
    <2.0041583, 0.2228726, 18.1470386>,
    <2.0043805, 0.2622263, 18.1205987>,
    <2.0043944, 0.2622264, 18.1224380>,
    <2.0043909, 0.2228656, 18.1204790>,
    <2.0044111, 0.2228646, 18.1219591>,
    <2.0043215, 0.2622260, 18.1187163>,
    <2.0043298, 0.2228676, 18.1187163>,
    <2.0043541, 0.2622262, 18.1194779>,
    <2.0043625, 0.2228666, 18.1194779>,
    <2.0043131, 0.3015845, 18.1187163>,
    <2.0043742, 0.3015870, 18.1204790>,
    <2.0043458, 0.3015857, 18.1194779>,
    <2.0043944, 0.3015882, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0001859, 0.9999966, 0.0025837>,
    <-0.0001849, 0.9999971, 0.0023832>,
    <-0.0001812, 0.9999970, 0.0024237>,
    <-0.0001827, 0.9999966, 0.0025970>,
    <-0.0001838, 0.9999963, 0.0027183>,
    <-0.0001866, 0.9999963, 0.0027184>,
    <-0.0001866, 0.9999963, 0.0027184>,
    <-0.0001899, 0.9999963, 0.0027186>,
    <-0.0001899, 0.9999967, 0.0025671>,
    <-0.0001899, 0.9999967, 0.0025671>,
    <-0.0001899, 0.9999973, 0.0023298>,
    <-0.0001833, 0.9999979, 0.0020530>,
    <-0.0001788, 0.9999977, 0.0021555>,
    <-0.0001899, 0.9999973, 0.0023298>,
    <-0.0001899, 0.9999982, 0.0019046>,
    <-0.0001899, 0.9999982, 0.0019046>,
    <-0.0001899, 0.9999996, 0.0009223>,
    <-0.0001802, 0.9999990, 0.0014067>,
    <-0.0001802, 0.9999990, 0.0014067>,
    <-0.0001746, 0.9999986, 0.0016852>,
    <-0.0001755, 0.9999975, 0.0022306>,
    <-0.0001782, 0.9999970, 0.0024554>,
    <-0.0001746, 0.9999986, 0.0016852>,
    <-0.0001710, 0.9999982, 0.0018661>,
    <-0.0001710, 0.9999982, 0.0018661>,
    <-0.0001685, 0.9999980, 0.0019930>,
    <-0.0001729, 0.9999974, 0.0022880>,
    <-0.0001729, 0.9999974, 0.0022880>,
    <-0.0001759, 0.9999969, 0.0024809>,
    <-0.0001801, 0.9999966, 0.0026079>,
    <-0.0001759, 0.9999969, 0.0024809>,
    <-0.0001779, 0.9999966, 0.0026170>,
    <-0.0001779, 0.9999966, 0.0026170>,
    <-0.0001795, 0.9999963, 0.0027181>,
    <-0.0001815, 0.9999963, 0.0027182>,
    <-0.0001815, 0.9999963, 0.0027182>,
    <-0.0001838, 0.9999963, 0.0027183>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <0.0000644, -0.9999672, 0.0081018>,
    <0.0000764, -0.9999841, 0.0056341>,
    <0.0000483, -0.9999858, 0.0053318>,
    <0.0000305, -0.9999731, 0.0073358>,
    <-0.0000007, -0.9999411, 0.0108495>,
    <0.0000409, -0.9999164, 0.0129301>,
    <0.0000409, -0.9999164, 0.0129301>,
    <0.0001134, -0.9998631, 0.0165488>,
    <0.0001134, -0.9999576, 0.0092100>,
    <0.0001134, -0.9999576, 0.0092100>,
    <0.0001134, -0.9999818, 0.0060332>,
    <0.0000836, -0.9999914, 0.0041359>,
    <0.0000598, -0.9999919, 0.0040365>,
    <0.0001134, -0.9999818, 0.0060332>,
    <0.0001134, -0.9999909, 0.0042600>,
    <0.0001134, -0.9999909, 0.0042600>,
    <0.0001134, -0.9999951, 0.0031286>,
    <0.0000885, -0.9999951, 0.0031297>,
    <0.0000885, -0.9999951, 0.0031297>,
    <0.0000679, -0.9999951, 0.0031306>,
    <0.0000403, -0.9999922, 0.0039552>,
    <0.0000263, -0.9999870, 0.0050949>,
    <0.0000679, -0.9999951, 0.0031306>,
    <0.0000505, -0.9999951, 0.0031313>,
    <0.0000505, -0.9999951, 0.0031313>,
    <0.0000356, -0.9999951, 0.0031319>,
    <0.0000241, -0.9999924, 0.0038874>,
    <0.0000241, -0.9999924, 0.0038874>,
    <0.0000086, -0.9999880, 0.0049041>,
    <0.0000057, -0.9999771, 0.0067747>,
    <0.0000086, -0.9999880, 0.0049041>,
    <-0.0000133, -0.9999799, 0.0063460>,
    <-0.0000133, -0.9999799, 0.0063460>,
    <-0.0000467, -0.9999634, 0.0085500>,
    <-0.0000278, -0.9999549, 0.0094982>,
    <-0.0000278, -0.9999549, 0.0094982>,
    <-0.0000007, -0.9999411, 0.0108495>,
    <0.0001346, -0.9999999, 0.0004844>,
    <0.0001344, -0.9999999, 0.0004997>,
    <0.0001382, -0.9999999, 0.0004997>,
    <0.0001383, -0.9999999, 0.0004844>,
    <0.0001385, -0.9999999, 0.0004696>,
    <0.0001347, -0.9999999, 0.0004695>,
    <0.0001347, -0.9999999, 0.0004695>,
    <0.0001310, -0.9999999, 0.0004695>,
    <0.0001308, -0.9999999, 0.0004843>,
    <0.0001308, -0.9999999, 0.0004843>,
    <0.0001306, -0.9999999, 0.0004996>,
    <0.0001342, -0.9999999, 0.0005155>,
    <0.0001381, -0.9999999, 0.0005155>,
    <0.0001306, -0.9999999, 0.0004996>,
    <0.0001303, -0.9999999, 0.0005154>,
    <0.0001303, -0.9999999, 0.0005154>,
    <0.0001301, -0.9999999, 0.0005316>,
    <0.0001340, -0.9999998, 0.0005317>,
    <0.0001340, -0.9999998, 0.0005317>,
    <0.0001380, -0.9999998, 0.0005318>,
    <0.0001420, -0.9999999, 0.0005156>,
    <0.0001420, -0.9999999, 0.0004998>,
    <0.0001380, -0.9999998, 0.0005318>,
    <0.0001419, -0.9999998, 0.0005319>,
    <0.0001419, -0.9999998, 0.0005319>,
    <0.0001459, -0.9999998, 0.0005320>,
    <0.0001459, -0.9999999, 0.0005157>,
    <0.0001459, -0.9999999, 0.0005157>,
    <0.0001459, -0.9999999, 0.0004999>,
    <0.0001421, -0.9999999, 0.0004845>,
    <0.0001459, -0.9999999, 0.0004999>,
    <0.0001459, -0.9999999, 0.0004845>,
    <0.0001459, -0.9999999, 0.0004845>,
    <0.0001459, -0.9999999, 0.0004696>,
    <0.0001422, -0.9999999, 0.0004696>,
    <0.0001422, -0.9999999, 0.0004696>,
    <0.0001385, -0.9999999, 0.0004696>,
    <0.9997304, 0.0001594, 0.0232204>,
    <0.9997304, 0.0001594, 0.0232184>,
    <0.9997304, 0.0001590, 0.0232184>,
    <0.9997304, 0.0001590, 0.0232204>,
    <0.9997303, 0.0001590, 0.0232224>,
    <0.9997303, 0.0001594, 0.0232224>,
    <0.9997303, 0.0001594, 0.0232224>,
    <0.9997303, 0.0001599, 0.0232224>,
    <0.9997304, 0.0001599, 0.0232204>,
    <0.9997304, 0.0001599, 0.0232204>,
    <0.9997304, 0.0001599, 0.0232184>,
    <0.9997304, 0.0001594, 0.0232164>,
    <0.9997304, 0.0001590, 0.0232164>,
    <0.9997304, 0.0001599, 0.0232184>,
    <0.9997304, 0.0001599, 0.0232164>,
    <0.9997304, 0.0001599, 0.0232164>,
    <0.9997305, 0.0001599, 0.0232145>,
    <0.9997305, 0.0001594, 0.0232145>,
    <0.9997305, 0.0001594, 0.0232145>,
    <0.9997305, 0.0001590, 0.0232145>,
    <0.9997304, 0.0001586, 0.0232164>,
    <0.9997304, 0.0001586, 0.0232184>,
    <0.9997305, 0.0001590, 0.0232145>,
    <0.9997305, 0.0001586, 0.0232145>,
    <0.9997305, 0.0001586, 0.0232145>,
    <0.9997305, 0.0001581, 0.0232144>,
    <0.9997304, 0.0001581, 0.0232164>,
    <0.9997304, 0.0001581, 0.0232164>,
    <0.9997304, 0.0001581, 0.0232184>,
    <0.9997304, 0.0001586, 0.0232204>,
    <0.9997304, 0.0001581, 0.0232184>,
    <0.9997304, 0.0001581, 0.0232204>,
    <0.9997304, 0.0001581, 0.0232204>,
    <0.9997303, 0.0001581, 0.0232224>,
    <0.9997303, 0.0001586, 0.0232224>,
    <0.9997303, 0.0001586, 0.0232224>,
    <0.9997303, 0.0001590, 0.0232224>,
    <-0.0000909, 0.9999998, 0.0005482>,
    <-0.0000908, 0.9999998, 0.0005457>,
    <-0.0000902, 0.9999998, 0.0005457>,
    <-0.0000902, 0.9999998, 0.0005482>,
    <-0.0000903, 0.9999998, 0.0005508>,
    <-0.0000909, 0.9999998, 0.0005508>,
    <-0.0000909, 0.9999998, 0.0005508>,
    <-0.0000915, 0.9999998, 0.0005508>,
    <-0.0000915, 0.9999998, 0.0005482>,
    <-0.0000915, 0.9999998, 0.0005482>,
    <-0.0000914, 0.9999998, 0.0005457>,
    <-0.0000908, 0.9999998, 0.0005433>,
    <-0.0000902, 0.9999998, 0.0005433>,
    <-0.0000914, 0.9999998, 0.0005457>,
    <-0.0000914, 0.9999998, 0.0005433>,
    <-0.0000914, 0.9999998, 0.0005433>,
    <-0.0000914, 0.9999998, 0.0005410>,
    <-0.0000908, 0.9999998, 0.0005410>,
    <-0.0000908, 0.9999998, 0.0005410>,
    <-0.0000902, 0.9999998, 0.0005410>,
    <-0.0000896, 0.9999998, 0.0005434>,
    <-0.0000896, 0.9999998, 0.0005458>,
    <-0.0000902, 0.9999998, 0.0005410>,
    <-0.0000896, 0.9999998, 0.0005410>,
    <-0.0000896, 0.9999998, 0.0005410>,
    <-0.0000890, 0.9999998, 0.0005410>,
    <-0.0000890, 0.9999998, 0.0005434>,
    <-0.0000890, 0.9999998, 0.0005434>,
    <-0.0000890, 0.9999998, 0.0005458>,
    <-0.0000896, 0.9999998, 0.0005482>,
    <-0.0000890, 0.9999998, 0.0005458>,
    <-0.0000890, 0.9999998, 0.0005482>,
    <-0.0000890, 0.9999998, 0.0005482>,
    <-0.0000890, 0.9999998, 0.0005508>,
    <-0.0000896, 0.9999998, 0.0005508>,
    <-0.0000896, 0.9999998, 0.0005508>,
    <-0.0000903, 0.9999998, 0.0005508>,
    <0.0001423, -0.9999953, 0.0030539>,
    <0.0001423, -0.9999957, 0.0029170>,
    <0.0001389, -0.9999957, 0.0029257>,
    <0.0001389, -0.9999953, 0.0030582>,
    <0.0001389, -0.9999949, 0.0031906>,
    <0.0001423, -0.9999949, 0.0031908>,
    <0.0001423, -0.9999949, 0.0031908>,
    <0.0001459, -0.9999949, 0.0031910>,
    <0.0001459, -0.9999953, 0.0030494>,
    <0.0001459, -0.9999953, 0.0030494>,
    <0.0001459, -0.9999958, 0.0029078>,
    <0.0001423, -0.9999961, 0.0027802>,
    <0.0001389, -0.9999961, 0.0027933>,
    <0.0001459, -0.9999958, 0.0029078>,
    <0.0001459, -0.9999962, 0.0027662>,
    <0.0001459, -0.9999962, 0.0027662>,
    <0.0001459, -0.9999965, 0.0026246>,
    <0.0001423, -0.9999965, 0.0026433>,
    <0.0001423, -0.9999965, 0.0026433>,
    <0.0001389, -0.9999965, 0.0026608>,
    <0.0001357, -0.9999961, 0.0028055>,
    <0.0001357, -0.9999957, 0.0029338>,
    <0.0001389, -0.9999965, 0.0026608>,
    <0.0001357, -0.9999964, 0.0026772>,
    <0.0001357, -0.9999964, 0.0026772>,
    <0.0001327, -0.9999964, 0.0026926>,
    <0.0001327, -0.9999960, 0.0028170>,
    <0.0001327, -0.9999960, 0.0028170>,
    <0.0001327, -0.9999957, 0.0029414>,
    <0.0001357, -0.9999953, 0.0030621>,
    <0.0001327, -0.9999957, 0.0029414>,
    <0.0001327, -0.9999953, 0.0030659>,
    <0.0001327, -0.9999953, 0.0030659>,
    <0.0001327, -0.9999949, 0.0031903>,
    <0.0001357, -0.9999949, 0.0031905>,
    <0.0001357, -0.9999949, 0.0031905>,
    <0.0001389, -0.9999949, 0.0031906>,
    <0.1905399, 0.0000301, -0.9816795>,
    <0.1905394, 0.0000301, -0.9816795>,
    <0.1905394, 0.0000300, -0.9816795>,
    <0.1905399, 0.0000300, -0.9816795>,
    <0.1905403, 0.0000300, -0.9816794>,
    <0.1905403, 0.0000301, -0.9816794>,
    <0.1905403, 0.0000301, -0.9816794>,
    <0.1905403, 0.0000301, -0.9816794>,
    <0.1905399, 0.0000301, -0.9816795>,
    <0.1905399, 0.0000301, -0.9816795>,
    <0.1905394, 0.0000301, -0.9816795>,
    <0.1905390, 0.0000301, -0.9816796>,
    <0.1905390, 0.0000300, -0.9816796>,
    <0.1905394, 0.0000301, -0.9816795>,
    <0.1905390, 0.0000301, -0.9816796>,
    <0.1905390, 0.0000301, -0.9816796>,
    <0.1905385, 0.0000301, -0.9816797>,
    <0.1905385, 0.0000301, -0.9816797>,
    <0.1905385, 0.0000301, -0.9816797>,
    <0.1905385, 0.0000300, -0.9816797>,
    <0.1905390, 0.0000300, -0.9816796>,
    <0.1905394, 0.0000300, -0.9816795>,
    <0.1905385, 0.0000300, -0.9816797>,
    <0.1905385, 0.0000300, -0.9816797>,
    <0.1905385, 0.0000300, -0.9816797>,
    <0.1905385, 0.0000299, -0.9816797>,
    <0.1905390, 0.0000299, -0.9816796>,
    <0.1905390, 0.0000299, -0.9816796>,
    <0.1905394, 0.0000299, -0.9816795>,
    <0.1905399, 0.0000300, -0.9816795>,
    <0.1905394, 0.0000299, -0.9816795>,
    <0.1905399, 0.0000299, -0.9816795>,
    <0.1905399, 0.0000299, -0.9816795>,
    <0.1905403, 0.0000299, -0.9816794>,
    <0.1905403, 0.0000300, -0.9816794>,
    <0.1905403, 0.0000300, -0.9816794>,
    <0.1905403, 0.0000300, -0.9816794>,
    <-0.0000870, 0.9999924, 0.0039037>,
    <-0.0000870, 0.9999927, 0.0038278>,
    <-0.0000851, 0.9999927, 0.0038230>,
    <-0.0000851, 0.9999924, 0.0038964>,
    <-0.0000851, 0.9999921, 0.0039698>,
    <-0.0000870, 0.9999921, 0.0039795>,
    <-0.0000870, 0.9999921, 0.0039795>,
    <-0.0000890, 0.9999920, 0.0039898>,
    <-0.0000890, 0.9999923, 0.0039114>,
    <-0.0000890, 0.9999923, 0.0039114>,
    <-0.0000890, 0.9999927, 0.0038329>,
    <-0.0000870, 0.9999930, 0.0037520>,
    <-0.0000851, 0.9999930, 0.0037496>,
    <-0.0000890, 0.9999927, 0.0038329>,
    <-0.0000890, 0.9999929, 0.0037545>,
    <-0.0000890, 0.9999929, 0.0037545>,
    <-0.0000890, 0.9999932, 0.0036761>,
    <-0.0000870, 0.9999932, 0.0036762>,
    <-0.0000870, 0.9999932, 0.0036762>,
    <-0.0000851, 0.9999932, 0.0036762>,
    <-0.0000834, 0.9999930, 0.0037474>,
    <-0.0000834, 0.9999927, 0.0038185>,
    <-0.0000851, 0.9999932, 0.0036762>,
    <-0.0000834, 0.9999932, 0.0036763>,
    <-0.0000834, 0.9999932, 0.0036763>,
    <-0.0000817, 0.9999932, 0.0036764>,
    <-0.0000817, 0.9999930, 0.0037454>,
    <-0.0000817, 0.9999930, 0.0037454>,
    <-0.0000817, 0.9999927, 0.0038143>,
    <-0.0000834, 0.9999924, 0.0038896>,
    <-0.0000817, 0.9999927, 0.0038143>,
    <-0.0000817, 0.9999925, 0.0038832>,
    <-0.0000817, 0.9999925, 0.0038832>,
    <-0.0000817, 0.9999922, 0.0039522>,
    <-0.0000834, 0.9999922, 0.0039607>,
    <-0.0000834, 0.9999922, 0.0039607>,
    <-0.0000851, 0.9999921, 0.0039698>,
    <0.0001347, -1.0000000, 0.0000077>,
    <0.0001337, -1.0000000, 0.0000129>,
    <0.0001412, -1.0000000, 0.0000536>,
    <0.0001488, -1.0000000, 0.0000301>,
    <0.0001505, -1.0000000, 0.0000005>,
    <0.0001350, -1.0000000, 0.0000005>,
    <0.0001350, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000144>,
    <0.0001328, -1.0000000, 0.0000617>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000004>,
    <0.0001323, -1.0000000, 0.0000136>,
    <0.0001323, -1.0000000, 0.0000136>,
    <0.0001300, -1.0000000, 0.0000589>,
    <0.0001331, -1.0000000, 0.0001676>,
    <0.0001593, -1.0000000, 0.0001532>,
    <0.0001300, -1.0000000, 0.0000589>,
    <0.0001242, -1.0000000, 0.0001615>,
    <0.0001242, -1.0000000, 0.0001615>,
    <0.0001146, -0.9999999, 0.0004114>,
    <0.0001297, -0.9999999, 0.0004255>,
    <0.0001752, -0.9999999, 0.0004301>,
    <0.0001926, -1.0000000, 0.0001007>,
    <0.0002839, -0.9999999, 0.0004440>,
    <0.0003808, -0.9999998, 0.0005264>,
    <0.0001992, -1.0000000, 0.0000005>,
    <0.0001992, -1.0000000, 0.0000005>,
    <0.0001505, -1.0000000, 0.0000005>,
    <0.9990638, 0.0001568, -0.0432613>,
    <0.9990638, 0.0001568, -0.0432613>,
    <0.9828283, 0.0001541, -0.1845222>,
    <0.9828284, 0.0001541, -0.1845219>,
    <0.9828284, 0.0001541, -0.1845216>,
    <0.9990638, 0.0001568, -0.0432612>,
    <0.9990638, 0.0001568, -0.0432612>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9990638, 0.0001568, -0.0432614>,
    <0.9828283, 0.0001541, -0.1845225>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9990638, 0.0001568, -0.0432615>,
    <0.9990638, 0.0001568, -0.0432615>,
    <0.9828282, 0.0001541, -0.1845228>,
    <0.8922266, 0.0001395, -0.4515879>,
    <0.8922269, 0.0001395, -0.4515873>,
    <0.9828282, 0.0001541, -0.1845228>,
    <0.8922263, 0.0001395, -0.4515885>,
    <0.8922263, 0.0001395, -0.4515885>,
    <0.6239846, 0.0000970, -0.7814367>,
    <0.6239852, 0.0000970, -0.7814361>,
    <0.6239858, 0.0000970, -0.7814356>,
    <0.8922272, 0.0001395, -0.4515867>,
    <0.6239865, 0.0000970, -0.7814351>,
    <0.6239871, 0.0000971, -0.7814346>,
    <0.8922275, 0.0001395, -0.4515861>,
    <0.8922275, 0.0001395, -0.4515861>,
    <0.9828284, 0.0001541, -0.1845216>,
    <-0.0000811, 1.0000000, 0.0000227>,
    <-0.0000800, 1.0000000, 0.0000189>,
    <-0.0000670, 1.0000000, 0.0000785>,
    <-0.0000768, 1.0000000, 0.0000967>,
    <-0.0000802, 1.0000000, 0.0001022>,
    <-0.0000815, 1.0000000, 0.0000238>,
    <-0.0000815, 1.0000000, 0.0000238>,
    <-0.0000817, 1.0000000, 0.0000007>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000788, 1.0000000, 0.0000109>,
    <-0.0000582, 1.0000000, 0.0000427>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000785, 1.0000000, 0.0000006>,
    <-0.0000785, 1.0000000, 0.0000006>,
    <-0.0000566, 1.0000000, 0.0000006>,
    <0.0000039, 1.0000000, 0.0001352>,
    <-0.0000344, 1.0000000, 0.0002184>,
    <-0.0000566, 1.0000000, 0.0000006>,
    <0.0000096, 1.0000000, 0.0000006>,
    <0.0000096, 1.0000000, 0.0000006>,
    <0.0002356, 0.9999998, 0.0006068>,
    <0.0001316, 0.9999998, 0.0005584>,
    <0.0000043, 0.9999998, 0.0005899>,
    <-0.0000657, 1.0000000, 0.0002581>,
    <-0.0000517, 0.9999998, 0.0006349>,
    <-0.0000712, 0.9999998, 0.0006696>,
    <-0.0000768, 1.0000000, 0.0002735>,
    <-0.0000768, 1.0000000, 0.0002735>,
    <-0.0000802, 1.0000000, 0.0001022>,
    <0.0002735, -0.9999986, 0.0016632>,
    <0.0001620, -0.9999994, 0.0010648>,
    <0.0000963, -0.9999985, 0.0017494>,
    <0.0001044, -0.9999955, 0.0030069>,
    <0.0001391, -0.9999465, 0.0103446>,
    <0.0011924, -0.9999440, 0.0105165>,
    <0.0011924, -0.9999440, 0.0105165>,
    <0.0003808, -0.9999998, 0.0005264>,
    <0.0001164, -0.9999996, 0.0009414>,
    <0.0000929, -0.9999990, 0.0014086>,
    <0.0001146, -0.9999999, 0.0004114>,
    <0.0001027, -0.9999996, 0.0009008>,
    <0.0001027, -0.9999996, 0.0009008>,
    <0.0000920, -0.9999991, 0.0013143>,
    <0.0000737, -0.9999993, 0.0012122>,
    <0.0000376, -0.9999989, 0.0014639>,
    <0.0000920, -0.9999991, 0.0013143>,
    <0.0000839, -0.9999994, 0.0011231>,
    <0.0000839, -0.9999994, 0.0011231>,
    <0.0000785, -0.9999998, 0.0005847>,
    <0.0000691, -0.9999998, 0.0006168>,
    <0.0000399, -0.9999998, 0.0006569>,
    <-0.0000516, -0.9999974, 0.0022944>,
    <-0.0000300, -0.9999998, 0.0006897>,
    <-0.0000768, -0.9999998, 0.0006671>,
    <-0.0005554, -0.9999475, 0.0102313>,
    <-0.0005554, -0.9999475, 0.0102313>,
    <0.0001391, -0.9999465, 0.0103446>,
    <0.3536429, 0.0000546, -0.9353805>,
    <0.3536424, 0.0000546, -0.9353807>,
    <0.2587557, 0.0000395, -0.9659428>,
    <0.2587561, 0.0000395, -0.9659427>,
    <0.2587565, 0.0000395, -0.9659426>,
    <0.3536434, 0.0000546, -0.9353803>,
    <0.3536434, 0.0000546, -0.9353803>,
    <0.6239871, 0.0000971, -0.7814346>,
    <0.3536418, 0.0000546, -0.9353809>,
    <0.2587553, 0.0000395, -0.9659429>,
    <0.6239846, 0.0000970, -0.7814367>,
    <0.3536413, 0.0000546, -0.9353811>,
    <0.3536413, 0.0000546, -0.9353811>,
    <0.2587549, 0.0000395, -0.9659430>,
    <0.3066458, 0.0000464, -0.9518237>,
    <0.3066462, 0.0000464, -0.9518236>,
    <0.2587549, 0.0000395, -0.9659430>,
    <0.3066453, 0.0000464, -0.9518239>,
    <0.3066453, 0.0000464, -0.9518239>,
    <0.5358762, 0.0000803, -0.8442966>,
    <0.5358768, 0.0000803, -0.8442962>,
    <0.5358775, 0.0000803, -0.8442958>,
    <0.3066467, 0.0000464, -0.9518234>,
    <0.5358781, 0.0000803, -0.8442954>,
    <0.5358788, 0.0000803, -0.8442949>,
    <0.3066472, 0.0000464, -0.9518233>,
    <0.3066472, 0.0000464, -0.9518233>,
    <0.2587565, 0.0000395, -0.9659426>,
    <-0.0000462, 0.9999991, 0.0013520>,
    <0.0000106, 0.9999990, 0.0014135>,
    <-0.0000528, 0.9999974, 0.0022678>,
    <-0.0000570, 0.9999981, 0.0019563>,
    <-0.0000582, 0.9999981, 0.0019512>,
    <-0.0000644, 0.9999990, 0.0013967>,
    <-0.0000644, 0.9999990, 0.0013967>,
    <-0.0000712, 0.9999998, 0.0006696>,
    <0.0001418, 0.9999979, 0.0020403>,
    <-0.0000432, 0.9999933, 0.0036538>,
    <0.0002356, 0.9999998, 0.0006068>,
    <0.0011921, 0.9999258, 0.0121273>,
    <0.0011921, 0.9999258, 0.0121273>,
    <-0.0000040, 0.9999288, 0.0119322>,
    <-0.0002154, 0.9999961, 0.0027688>,
    <-0.0001107, 0.9999982, 0.0018684>,
    <-0.0000040, 0.9999288, 0.0119322>,
    <-0.0007910, 0.9999300, 0.0118038>,
    <-0.0007910, 0.9999300, 0.0118038>,
    <-0.0002295, 0.9999997, 0.0007698>,
    <-0.0001785, 0.9999996, 0.0008333>,
    <-0.0000970, 0.9999996, 0.0008324>,
    <-0.0000666, 0.9999986, 0.0016422>,
    <-0.0000619, 0.9999997, 0.0008217>,
    <-0.0000504, 0.9999997, 0.0008202>,
    <-0.0000535, 0.9999987, 0.0016131>,
    <-0.0000535, 0.9999987, 0.0016131>,
    <-0.0000582, 0.9999981, 0.0019512>,
    <0.0000402, -1.0000000, 0.0001761>,
    <0.0000572, -1.0000000, 0.0002495>,
    <0.0000687, -1.0000000, 0.0001050>,
    <0.0000652, -1.0000000, 0.0000730>,
    <0.0000645, -1.0000000, 0.0000325>,
    <0.0000376, -1.0000000, 0.0000325>,
    <0.0000376, -1.0000000, 0.0000325>,
    <-0.0000768, -0.9999998, 0.0006671>,
    <0.0000708, -1.0000000, 0.0002645>,
    <0.0000726, -1.0000000, 0.0001166>,
    <0.0000785, -0.9999998, 0.0005847>,
    <0.0000755, -1.0000000, 0.0002578>,
    <0.0000755, -1.0000000, 0.0002578>,
    <0.0000740, -1.0000000, 0.0001152>,
    <0.0000732, -1.0000000, 0.0000506>,
    <0.0000727, -1.0000000, 0.0000485>,
    <0.0000740, -1.0000000, 0.0001152>,
    <0.0000733, -1.0000000, 0.0000499>,
    <0.0000733, -1.0000000, 0.0000499>,
    <0.0000731, -1.0000000, 0.0000306>,
    <0.0000731, -1.0000000, 0.0000311>,
    <0.0000731, -1.0000000, 0.0000311>,
    <0.0000731, -1.0000000, 0.0000316>,
    <0.0000723, -1.0000000, 0.0000418>,
    <0.0000731, -1.0000000, 0.0000316>,
    <0.0000731, -1.0000000, 0.0000321>,
    <0.0000731, -1.0000000, 0.0000321>,
    <0.0000731, -1.0000000, 0.0000325>,
    <0.0000722, -1.0000000, 0.0000325>,
    <0.0000722, -1.0000000, 0.0000325>,
    <0.0000645, -1.0000000, 0.0000325>,
    <0.8300740, 0.0001237, -0.5576532>,
    <0.8300736, 0.0001237, -0.5576538>,
    <0.9623799, 0.0001429, -0.2717074>,
    <0.9623800, 0.0001429, -0.2717070>,
    <0.9623802, 0.0001429, -0.2717065>,
    <0.8300745, 0.0001237, -0.5576525>,
    <0.8300745, 0.0001237, -0.5576525>,
    <0.5358788, 0.0000803, -0.8442949>,
    <0.8300732, 0.0001237, -0.5576545>,
    <0.9623798, 0.0001429, -0.2717079>,
    <0.5358762, 0.0000803, -0.8442966>,
    <0.8300727, 0.0001237, -0.5576552>,
    <0.8300727, 0.0001237, -0.5576552>,
    <0.9623796, 0.0001429, -0.2717083>,
    <0.9945474, 0.0001475, -0.1042853>,
    <0.9945474, 0.0001475, -0.1042851>,
    <0.9623796, 0.0001429, -0.2717083>,
    <0.9945474, 0.0001475, -0.1042855>,
    <0.9945474, 0.0001475, -0.1042855>,
    <0.9986191, 0.0001479, -0.0525351>,
    <0.9986191, 0.0001479, -0.0525350>,
    <0.9986191, 0.0001479, -0.0525350>,
    <0.9986191, 0.0001479, -0.0525349>,
    <0.9945475, 0.0001475, -0.1042849>,
    <0.9986191, 0.0001479, -0.0525349>,
    <0.9986191, 0.0001479, -0.0525347>,
    <0.9986191, 0.0001479, -0.0525347>,
    <0.9986191, 0.0001479, -0.0525346>,
    <0.9945475, 0.0001475, -0.1042847>,
    <0.9945475, 0.0001475, -0.1042847>,
    <0.9623802, 0.0001429, -0.2717065>,
    <-0.0000542, 0.9999999, 0.0003485>,
    <-0.0000702, 0.9999999, 0.0003161>,
    <-0.0000538, 1.0000000, 0.0001324>,
    <-0.0000493, 1.0000000, 0.0001517>,
    <-0.0000478, 1.0000000, 0.0001559>,
    <-0.0000486, 0.9999999, 0.0003553>,
    <-0.0000486, 0.9999999, 0.0003553>,
    <-0.0000504, 0.9999997, 0.0008202>,
    <-0.0000898, 1.0000000, 0.0002161>,
    <-0.0000579, 1.0000000, 0.0000896>,
    <-0.0002295, 0.9999997, 0.0007698>,
    <-0.0000923, 1.0000000, 0.0000375>,
    <-0.0000923, 1.0000000, 0.0000375>,
    <-0.0000587, 1.0000000, 0.0000376>,
    <-0.0000486, 1.0000000, 0.0000501>,
    <-0.0000481, 1.0000000, 0.0000597>,
    <-0.0000587, 1.0000000, 0.0000376>,
    <-0.0000487, 1.0000000, 0.0000376>,
    <-0.0000487, 1.0000000, 0.0000376>,
    <-0.0000473, 1.0000000, 0.0000376>,
    <-0.0000473, 1.0000000, 0.0000378>,
    <-0.0000473, 1.0000000, 0.0000378>,
    <-0.0000473, 1.0000000, 0.0000381>,
    <-0.0000476, 1.0000000, 0.0000641>,
    <-0.0000473, 1.0000000, 0.0000381>,
    <-0.0000473, 1.0000000, 0.0000383>,
    <-0.0000473, 1.0000000, 0.0000383>,
    <-0.0000473, 1.0000000, 0.0000385>,
    <-0.0000474, 1.0000000, 0.0000652>,
    <-0.0000474, 1.0000000, 0.0000652>,
    <-0.0000478, 1.0000000, 0.0001559>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <-0.9869426, -0.0002089, -0.1610724>,
    <-0.9869426, -0.0002087, -0.1610724>,
    <-0.9869431, -0.0002087, -0.1610692>,
    <-0.9869431, -0.0002089, -0.1610692>,
    <-0.9869431, -0.0002090, -0.1610692>,
    <-0.9869426, -0.0002090, -0.1610724>,
    <-0.9869426, -0.0002090, -0.1610724>,
    <-0.9869420, -0.0002090, -0.1610757>,
    <-0.9869420, -0.0002089, -0.1610757>,
    <-0.9869420, -0.0002089, -0.1610757>,
    <-0.9869420, -0.0002087, -0.1610757>,
    <-0.9869426, -0.0002085, -0.1610724>,
    <-0.9869431, -0.0002085, -0.1610692>,
    <-0.9869420, -0.0002087, -0.1610757>,
    <-0.9869420, -0.0002085, -0.1610757>,
    <-0.9869420, -0.0002085, -0.1610757>,
    <-0.9869420, -0.0002084, -0.1610757>,
    <-0.9869426, -0.0002084, -0.1610724>,
    <-0.9869426, -0.0002084, -0.1610724>,
    <-0.9869431, -0.0002084, -0.1610692>,
    <-0.9869436, -0.0002085, -0.1610659>,
    <-0.9869436, -0.0002087, -0.1610659>,
    <-0.9869431, -0.0002084, -0.1610692>,
    <-0.9869436, -0.0002084, -0.1610659>,
    <-0.9869436, -0.0002084, -0.1610659>,
    <-0.9869442, -0.0002084, -0.1610626>,
    <-0.9869442, -0.0002085, -0.1610626>,
    <-0.9869442, -0.0002085, -0.1610626>,
    <-0.9869442, -0.0002087, -0.1610626>,
    <-0.9869436, -0.0002089, -0.1610659>,
    <-0.9869442, -0.0002087, -0.1610626>,
    <-0.9869442, -0.0002089, -0.1610627>,
    <-0.9869442, -0.0002089, -0.1610627>,
    <-0.9869442, -0.0002090, -0.1610627>,
    <-0.9869436, -0.0002090, -0.1610659>,
    <-0.9869436, -0.0002090, -0.1610659>,
    <-0.9869431, -0.0002090, -0.1610692>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <-0.9987356, -0.0002116, -0.0502712>,
    <-0.9987356, -0.0002116, -0.0502712>,
    <-0.9987356, -0.0002116, -0.0502702>,
    <-0.9987356, -0.0002116, -0.0502702>,
    <-0.9987356, -0.0002116, -0.0502702>,
    <-0.9987356, -0.0002116, -0.0502712>,
    <-0.9987356, -0.0002116, -0.0502712>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987356, -0.0002116, -0.0502712>,
    <-0.9987356, -0.0002116, -0.0502702>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002115, -0.0502722>,
    <-0.9987356, -0.0002115, -0.0502712>,
    <-0.9987356, -0.0002115, -0.0502712>,
    <-0.9987356, -0.0002115, -0.0502702>,
    <-0.9987357, -0.0002116, -0.0502691>,
    <-0.9987357, -0.0002116, -0.0502691>,
    <-0.9987356, -0.0002115, -0.0502702>,
    <-0.9987357, -0.0002115, -0.0502691>,
    <-0.9987357, -0.0002115, -0.0502691>,
    <-0.9987357, -0.0002115, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502691>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502691>,
    <-0.9987357, -0.0002116, -0.0502691>,
    <-0.9987356, -0.0002116, -0.0502702>,
    <0.9999404, 0.0003518, 0.0109141>,
    <0.9999447, 0.0002121, 0.0105163>,
    <0.9999338, 0.0002120, 0.0115037>,
    <0.9999321, 0.0002470, 0.0116512>,
    <0.9999286, 0.0002562, 0.0119508>,
    <0.9999285, 0.0003833, 0.0119507>,
    <0.9999285, 0.0003833, 0.0119507>,
    <0.9999722, 0.0008604, 0.0074076>,
    <0.9999724, 0.0006173, 0.0074077>,
    <0.9999725, 0.0002121, 0.0074076>,
    <0.9999404, 0.0000724, 0.0109136>,
    <0.9999321, 0.0001770, 0.0116506>,
    <0.9999725, -0.0001931, 0.0074074>,
    <0.9999725, -0.0004362, 0.0074070>,
    <0.9999286, 0.0000408, 0.0119496>,
    <0.9999286, 0.0000408, 0.0119496>,
    <0.9999286, 0.0001678, 0.0119498>,
    <0.9999294, 0.0002078, 0.0118782>,
    <0.9999298, 0.0002119, 0.0118451>,
    <0.9999286, 0.0001678, 0.0119498>,
    <0.9999286, 0.0002064, 0.0119498>,
    <0.9999286, 0.0002064, 0.0119498>,
    <0.9999286, 0.0002119, 0.0119498>,
    <0.9999286, 0.0002119, 0.0119500>,
    <0.9999286, 0.0002119, 0.0119500>,
    <0.9999286, 0.0002119, 0.0119503>,
    <0.9999294, 0.0002161, 0.0118787>,
    <0.9999286, 0.0002119, 0.0119503>,
    <0.9999286, 0.0002119, 0.0119505>,
    <0.9999286, 0.0002119, 0.0119505>,
    <0.9999286, 0.0002119, 0.0119508>,
    <0.9999286, 0.0002175, 0.0119508>,
    <0.9999286, 0.0002175, 0.0119508>,
    <0.9999286, 0.0002562, 0.0119508>,
    <0.9999903, 0.0006810, -0.0043628>,
    <0.9997832, 0.0004445, -0.0208159>,
    <0.9998818, 0.0002121, -0.0153711>,
    <0.9999996, 0.0002121, -0.0008270>,
    <0.9999722, 0.0008604, 0.0074076>,
    <0.9990810, 0.0021041, -0.0428095>,
    <0.9990810, 0.0021041, -0.0428095>,
    <0.9990828, 0.0007002, -0.0428134>,
    <0.9993788, 0.0002520, -0.0352415>,
    <0.9994752, 0.0002120, -0.0323937>,
    <0.9990828, 0.0007002, -0.0428134>,
    <0.9990830, 0.0002729, -0.0428145>,
    <0.9990830, 0.0002729, -0.0428145>,
    <0.9990830, 0.0002119, -0.0428147>,
    <0.9990830, 0.0002119, -0.0428138>,
    <0.9990830, 0.0002119, -0.0428138>,
    <0.9990831, 0.0002119, -0.0428129>,
    <0.9993789, 0.0001719, -0.0352399>,
    <0.9997834, -0.0000204, -0.0208147>,
    <0.9990831, 0.0002119, -0.0428129>,
    <0.9990831, 0.0002119, -0.0428120>,
    <0.9990831, 0.0002119, -0.0428120>,
    <0.9990832, 0.0002119, -0.0428112>,
    <0.9990832, 0.0001508, -0.0428110>,
    <0.9990832, 0.0001508, -0.0428110>,
    <0.9990832, -0.0002764, -0.0428096>,
    <0.9999905, -0.0002568, -0.0043624>,
    <0.9990832, -0.0002764, -0.0428096>,
    <0.9990820, -0.0016801, -0.0428052>,
    <0.9990820, -0.0016801, -0.0428052>,
    <0.9999725, -0.0004362, 0.0074070>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9514109>,
    <0.4350054, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289899, 0.9514109>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9514109>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559172, 0.9657316>,
    <0.6289899, 0.9514109>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4350054, 0.9657316>,
    <0.5000060, 0.9664305>,
    <0.4264033, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379346, 0.9664305>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664305>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559172, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773692, 0.9671308>,
    <0.6379346, 0.9664305>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4264033, 0.9671308>,
    <0.5000061, 0.9784050>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473428, 0.9784050>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9784050>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773692, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473428, 0.9784050>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032659, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458871>,
    <0.4677608, 0.9457569>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9514109>,
    <0.4355157, 0.9458871>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9452857>,
    <0.4677603, 0.9520134>,
    <0.4676327, 0.9588725>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9514109>,
    <0.5000059, 0.9657316>,
    <0.4350054, 0.9657316>,
    <0.4677603, 0.9520134>,
    <0.5000059, 0.9583740>,
    <0.4675013, 0.9657316>,
    <0.4352839, 0.9585445>,
    <0.4031382, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4350054, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352839, 0.9585445>,
    <0.4023500, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032659, 0.9526160>,
    <0.5322510, 0.9457569>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9514109>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9520135>,
    <0.5000059, 0.9452857>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458711>,
    <0.5967411, 0.9457569>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289899, 0.9514109>,
    <0.5644961, 0.9458711>,
    <0.5967380, 0.9395004>,
    <0.6289859, 0.9452857>,
    <0.5967441, 0.9520135>,
    <0.5967475, 0.9588725>,
    <0.5644983, 0.9526160>,
    <0.6289899, 0.9514109>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967441, 0.9520135>,
    <0.6289944, 0.9583740>,
    <0.5967509, 0.9657316>,
    <0.5645004, 0.9589932>,
    <0.5322532, 0.9588725>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9514109>,
    <0.5645004, 0.9589932>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9583740>,
    <0.5322521, 0.9520135>,
    <0.6423395, 0.9457569>,
    <0.6556982, 0.9526160>,
    <0.6289899, 0.9514109>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423438, 0.9520134>,
    <0.6289859, 0.9452857>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458871>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458871>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691098, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559172, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694404, 0.9657316>,
    <0.6557972, 0.9585445>,
    <0.6424011, 0.9588725>,
    <0.6556982, 0.9526160>,
    <0.6559172, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289899, 0.9514109>,
    <0.6557972, 0.9585445>,
    <0.6424600, 0.9657316>,
    <0.6289944, 0.9583740>,
    <0.6423438, 0.9520134>,
    <0.3997808, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4350054, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4023500, 0.9657316>,
    <0.4330490, 0.9660765>,
    <0.4665136, 0.9660812>,
    <0.4310370, 0.9664312>,
    <0.4350054, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664305>,
    <0.4330490, 0.9660765>,
    <0.4675013, 0.9657316>,
    <0.5000060, 0.9661007>,
    <0.4655215, 0.9664308>,
    <0.4643631, 0.9667808>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664305>,
    <0.5000061, 0.9671308>,
    <0.4264033, 0.9671308>,
    <0.4655215, 0.9664308>,
    <0.5000060, 0.9667582>,
    <0.4631991, 0.9671308>,
    <0.4287555, 0.9667757>,
    <0.3931579, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4264033, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4287555, 0.9667757>,
    <0.3895634, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664305>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664308>,
    <0.5000060, 0.9661007>,
    <0.5322542, 0.9657316>,
    <0.5668649, 0.9661011>,
    <0.6001028, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379346, 0.9664305>,
    <0.5668649, 0.9661011>,
    <0.5967509, 0.9657316>,
    <0.6337189, 0.9661007>,
    <0.6034548, 0.9664308>,
    <0.6068115, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.6379346, 0.9664305>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034548, 0.9664308>,
    <0.6421255, 0.9667582>,
    <0.6101681, 0.9671308>,
    <0.5710683, 0.9667586>,
    <0.5356086, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664305>,
    <0.5710683, 0.9667586>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667582>,
    <0.5344905, 0.9664308>,
    <0.6473391, 0.9660812>,
    <0.6665054, 0.9664312>,
    <0.6379346, 0.9664305>,
    <0.6289992, 0.9657316>,
    <0.6559172, 0.9657316>,
    <0.6522200, 0.9664308>,
    <0.6337189, 0.9661007>,
    <0.6424600, 0.9657316>,
    <0.6611372, 0.9660765>,
    <0.6749768, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559172, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6611372, 0.9660765>,
    <0.6694404, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866644, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773692, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926253, 0.9671308>,
    <0.6718544, 0.9667757>,
    <0.6571745, 0.9667808>,
    <0.6665054, 0.9664312>,
    <0.6773692, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379346, 0.9664305>,
    <0.6718544, 0.9667757>,
    <0.6621313, 0.9671308>,
    <0.6421255, 0.9667582>,
    <0.6522200, 0.9664308>,
    <0.3896432, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4264033, 0.9671308>,
    <0.3895222, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3895634, 0.9671308>,
    <0.4263749, 0.9728674>,
    <0.4631915, 0.9726067>,
    <0.4263507, 0.9777601>,
    <0.4264033, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9784050>,
    <0.4263749, 0.9728674>,
    <0.4631991, 0.9671308>,
    <0.5000061, 0.9727092>,
    <0.4631779, 0.9780826>,
    <0.4631249, 0.9832360>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9784050>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631779, 0.9780826>,
    <0.5000061, 0.9835191>,
    <0.4630714, 0.9883895>,
    <0.4262411, 0.9832068>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262411, 0.9832068>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895222, 0.9777601>,
    <0.5367803, 0.9726067>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9784050>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9780826>,
    <0.5000061, 0.9727092>,
    <0.5367268, 0.9671308>,
    <0.5735533, 0.9723901>,
    <0.6103351, 0.9726067>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473428, 0.9784050>,
    <0.5735533, 0.9723901>,
    <0.6101681, 0.9671308>,
    <0.6471134, 0.9727092>,
    <0.6105021, 0.9780826>,
    <0.6106561, 0.9832360>,
    <0.5736614, 0.9777601>,
    <0.6473428, 0.9784050>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105021, 0.9780826>,
    <0.6475487, 0.9835191>,
    <0.6108101, 0.9883895>,
    <0.5737711, 0.9832046>,
    <0.5368873, 0.9832360>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9784050>,
    <0.5737711, 0.9832046>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9835191>,
    <0.5368338, 0.9780826>,
    <0.6623549, 0.9726067>,
    <0.6778190, 0.9777601>,
    <0.6473428, 0.9784050>,
    <0.6468888, 0.9671308>,
    <0.6773692, 0.9671308>,
    <0.6625811, 0.9780826>,
    <0.6471134, 0.9727092>,
    <0.6621313, 0.9671308>,
    <0.6776119, 0.9728674>,
    <0.6928063, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773692, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776119, 0.9728674>,
    <0.6926253, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930704, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930704, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780837, 0.9832068>,
    <0.6628105, 0.9832360>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473428, 0.9784050>,
    <0.6780837, 0.9832068>,
    <0.6630402, 0.9883895>,
    <0.6475487, 0.9835191>,
    <0.6625811, 0.9780826>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.05, 0.196529, -0.147353>
}

#declare TMesh010 = mesh2 {
  vertex_vectors {
    582,
    <2.2066458, 0.1989400, 18.5058918>,
    <1.9978099, 0.1409798, 18.5058918>,
    <1.9974799, 0.0831028, 18.5058918>,
    <2.2063266, 0.1212845, 18.5058918>,
    <2.1022278, 0.1699599, 18.5058918>,
    <1.9976449, 0.1120413, 18.5058918>,
    <2.1019033, 0.1021936, 18.5058918>,
    <2.2064862, 0.1601122, 18.5058918>,
    <2.1020655, 0.1360768, 18.5058918>,
    <2.4151733, 0.1594662, 18.5058918>,
    <2.4154818, 0.2569002, 18.5058918>,
    <2.3107499, 0.1403753, 18.5058918>,
    <2.4153275, 0.2081832, 18.5058918>,
    <2.3110638, 0.2279201, 18.5058918>,
    <2.3109069, 0.1841477, 18.5058918>,
    <2.4157903, 0.3543342, 18.5058918>,
    <2.2069650, 0.2765955, 18.5058918>,
    <2.4156360, 0.3056172, 18.5058918>,
    <2.3113777, 0.3154649, 18.5058918>,
    <2.2068054, 0.2377677, 18.5058918>,
    <2.3112207, 0.2716925, 18.5058918>,
    <1.9981398, 0.1988568, 18.5058918>,
    <2.1025524, 0.2377261, 18.5058918>,
    <1.9979748, 0.1699183, 18.5058918>,
    <2.1023901, 0.2038430, 18.5058918>,
    <2.0647758, 0.0954626, 18.1207908>,
    <1.9999089, 0.0831535, 18.1202395>,
    <1.9999798, 0.0831550, 18.1217627>,
    <2.0534502, 0.0947089, 18.1217627>,
    <2.0323423, 0.0893081, 18.1205151>,
    <1.9999443, 0.0831542, 18.1210011>,
    <2.0267150, 0.0889319, 18.1217627>,
    <2.0591130, 0.0950858, 18.1212767>,
    <2.0295287, 0.0891200, 18.1211389>,
    <2.1069206, 0.1062628, 18.1217627>,
    <2.1296427, 0.1077718, 18.1213420>,
    <2.0801854, 0.1004859, 18.1217627>,
    <2.1182817, 0.1070173, 18.1215524>,
    <2.0972092, 0.1016172, 18.1210664>,
    <2.0886973, 0.1010515, 18.1214145>,
    <2.1523647, 0.1092807, 18.1209214>,
    <2.0761013, 0.0962164, 18.1198188>,
    <2.1410037, 0.1085263, 18.1211317>,
    <2.1142330, 0.1027486, 18.1203701>,
    <2.0704386, 0.0958395, 18.1203048>,
    <2.1057211, 0.1021829, 18.1207182>,
    <1.9998380, 0.0831520, 18.1187163>,
    <2.0379697, 0.0896842, 18.1192675>,
    <1.9998734, 0.0831528, 18.1194779>,
    <2.0351560, 0.0894961, 18.1198913>,
    <2.1298375, 0.1792179, 18.1213420>,
    <2.1071071, 0.1769503, 18.1217627>,
    <2.1297401, 0.1434948, 18.1213420>,
    <2.1070139, 0.1416066, 18.1217627>,
    <2.1184723, 0.1780841, 18.1215524>,
    <2.1183770, 0.1425507, 18.1215524>,
    <2.1072935, 0.2476378, 18.1217627>,
    <2.1300324, 0.2506639, 18.1213420>,
    <2.1072003, 0.2122941, 18.1217627>,
    <2.1186629, 0.2491509, 18.1215524>,
    <2.1299349, 0.2149409, 18.1213420>,
    <2.1185676, 0.2136175, 18.1215524>,
    <2.1527712, 0.2536901, 18.1209214>,
    <2.1525679, 0.1814854, 18.1209214>,
    <2.1414018, 0.2521770, 18.1211317>,
    <2.1526696, 0.2175877, 18.1209214>,
    <2.1412027, 0.1803516, 18.1211317>,
    <2.1413023, 0.2162643, 18.1211317>,
    <2.1524663, 0.1453831, 18.1209214>,
    <2.1411032, 0.1444389, 18.1211317>,
    <2.0651703, 0.2256229, 18.1207908>,
    <2.0538325, 0.2241350, 18.1217627>,
    <2.0976013, 0.2381434, 18.1210664>,
    <2.0805630, 0.2358864, 18.1217627>,
    <2.0595014, 0.2248790, 18.1212767>,
    <2.0890821, 0.2370149, 18.1214145>,
    <2.0003715, 0.2006323, 18.1217627>,
    <2.0003082, 0.2005819, 18.1202395>,
    <2.0271020, 0.2123837, 18.1217627>,
    <2.0003398, 0.2006071, 18.1210011>,
    <2.0327392, 0.2131024, 18.1205151>,
    <2.0299206, 0.2127430, 18.1211389>,
    <2.0002449, 0.2005316, 18.1187163>,
    <2.0765080, 0.2271108, 18.1198188>,
    <2.0002765, 0.2005567, 18.1194779>,
    <2.0383765, 0.2138212, 18.1192675>,
    <2.0708391, 0.2263669, 18.1203048>,
    <2.0355578, 0.2134618, 18.1198913>,
    <2.1146396, 0.2404004, 18.1203701>,
    <2.1061205, 0.2392719, 18.1207182>,
    <2.0762105, 0.0977881, 18.1376413>,
    <1.9996901, 0.0831489, 18.1370901>,
    <2.0379503, 0.0904685, 18.1373657>,
    <1.9997641, 0.0831505, 18.1279032>,
    <2.0761559, 0.0970022, 18.1287301>,
    <2.0379600, 0.0900764, 18.1283166>,
    <2.1527308, 0.1124273, 18.1381926>,
    <2.1525477, 0.1108540, 18.1295570>,
    <2.1144706, 0.1051077, 18.1379170>,
    <2.1143518, 0.1039281, 18.1291435>,
    <2.1530969, 0.1155738, 18.1554639>,
    <2.0763196, 0.0993598, 18.1554639>,
    <2.1529138, 0.1140005, 18.1468283>,
    <2.1147082, 0.1074668, 18.1554639>,
    <2.0762650, 0.0985740, 18.1465526>,
    <2.1145894, 0.1062872, 18.1466904>,
    <1.9995423, 0.0831458, 18.1554639>,
    <2.0379309, 0.0912528, 18.1554639>,
    <1.9996162, 0.0831474, 18.1462770>,
    <2.0379406, 0.0908607, 18.1464148>,
    <2.1529349, 0.1862137, 18.1381926>,
    <2.1528328, 0.1493205, 18.1381926>,
    <2.1527514, 0.1838496, 18.1295570>,
    <2.1526496, 0.1473518, 18.1295570>,
    <2.1531391, 0.2600002, 18.1381926>,
    <2.1529551, 0.2568451, 18.1295570>,
    <2.1530370, 0.2231070, 18.1381926>,
    <2.1528533, 0.2203474, 18.1295570>,
    <2.1535069, 0.2663104, 18.1554639>,
    <2.1533019, 0.1909421, 18.1554639>,
    <2.1533230, 0.2631553, 18.1468283>,
    <2.1534044, 0.2286263, 18.1554639>,
    <2.1531184, 0.1885779, 18.1468283>,
    <2.1532207, 0.2258666, 18.1468283>,
    <2.1531994, 0.1532579, 18.1554639>,
    <2.1530161, 0.1512892, 18.1468283>,
    <2.0766260, 0.2302134, 18.1376413>,
    <2.1148825, 0.2451068, 18.1379170>,
    <2.0765670, 0.2286621, 18.1287301>,
    <2.1147611, 0.2427536, 18.1291435>,
    <2.0001129, 0.2004266, 18.1370901>,
    <2.0001789, 0.2004791, 18.1279032>,
    <2.0383694, 0.2153200, 18.1373657>,
    <2.0383729, 0.2145706, 18.1283166>,
    <1.9999809, 0.2003215, 18.1554639>,
    <2.0767439, 0.2333160, 18.1554639>,
    <2.0000469, 0.2003740, 18.1462770>,
    <2.0383624, 0.2168188, 18.1554639>,
    <2.0766849, 0.2317647, 18.1465526>,
    <2.0383659, 0.2160694, 18.1464148>,
    <2.1151254, 0.2498132, 18.1554639>,
    <2.1150040, 0.2474600, 18.1466904>,
    <2.0805454, 0.1004736, 18.1573801>,
    <1.9994375, 0.0831437, 18.1573801>,
    <2.0399915, 0.0918086, 18.1573801>,
    <1.9994899, 0.0831447, 18.1564220>,
    <2.0784325, 0.0999167, 18.1564220>,
    <2.0389612, 0.0915307, 18.1564220>,
    <2.1616533, 0.1178035, 18.1573801>,
    <2.1573751, 0.1166886, 18.1564220>,
    <2.1210993, 0.1091385, 18.1573801>,
    <2.1179038, 0.1083027, 18.1564220>,
    <2.1702097, 0.1200332, 18.1592964>,
    <2.0847712, 0.1015873, 18.1592964>,
    <2.1659315, 0.1189184, 18.1583383>,
    <2.1274904, 0.1108103, 18.1592964>,
    <2.0826583, 0.1010305, 18.1583383>,
    <2.1242949, 0.1099744, 18.1583383>,
    <1.9993328, 0.0831415, 18.1592964>,
    <2.0420520, 0.0923644, 18.1592964>,
    <1.9993851, 0.0831426, 18.1583383>,
    <2.0410217, 0.0920865, 18.1583383>,
    <2.1618619, 0.1942928, 18.1573801>,
    <2.1617576, 0.1560481, 18.1573801>,
    <2.1575819, 0.1926174, 18.1564220>,
    <2.1574785, 0.1546530, 18.1564220>,
    <2.1620705, 0.2707820, 18.1573801>,
    <2.1577887, 0.2685462, 18.1564220>,
    <2.1619662, 0.2325374, 18.1573801>,
    <2.1576853, 0.2305818, 18.1564220>,
    <2.1706340, 0.2752536, 18.1592964>,
    <2.1704218, 0.1976434, 18.1592964>,
    <2.1663522, 0.2730178, 18.1583383>,
    <2.1705279, 0.2364485, 18.1592964>,
    <2.1661419, 0.1959681, 18.1583383>,
    <2.1662470, 0.2344929, 18.1583383>,
    <2.1703157, 0.1588383, 18.1592964>,
    <2.1660367, 0.1574432, 18.1583383>,
    <2.0809789, 0.2355146, 18.1573801>,
    <2.1215247, 0.2531483, 18.1573801>,
    <2.0788614, 0.2344153, 18.1564220>,
    <2.1183251, 0.2514807, 18.1564220>,
    <1.9998874, 0.2002471, 18.1573801>,
    <1.9999341, 0.2002843, 18.1564220>,
    <2.0404331, 0.2178809, 18.1573801>,
    <2.0393978, 0.2173498, 18.1564220>,
    <1.9997938, 0.2001727, 18.1592964>,
    <2.0852139, 0.2377132, 18.1592964>,
    <1.9998406, 0.2002099, 18.1583383>,
    <2.0425039, 0.2189429, 18.1592964>,
    <2.0830964, 0.2366139, 18.1583383>,
    <2.0414685, 0.2184119, 18.1583383>,
    <2.1279240, 0.2564834, 18.1592964>,
    <2.1247243, 0.2548158, 18.1583383>,
    <2.0863785, 0.1018304, 18.2324892>,
    <1.9993321, 0.0831415, 18.2344341>,
    <2.0428539, 0.0924859, 18.2333227>,
    <1.9993324, 0.0831415, 18.1968653>,
    <2.0847876, 0.1015910, 18.1968653>,
    <2.0420600, 0.0923662, 18.1968653>,
    <2.1734415, 0.1205197, 18.2322113>,
    <2.1702429, 0.1200404, 18.1968653>,
    <2.1299086, 0.1111751, 18.2322113>,
    <2.1275152, 0.1108157, 18.1968653>,
    <2.2019970, 0.1247829, 18.2873438>,
    <2.1005699, 0.1039602, 18.2890109>,
    <2.1829711, 0.1219432, 18.2631118>,
    <2.1512752, 0.1143714, 18.2873438>,
    <2.0911181, 0.1025416, 18.2642232>,
    <2.1370391, 0.1122423, 18.2631118>,
    <1.9993314, 0.0831414, 18.3095719>,
    <2.0498980, 0.0935497, 18.2940122>,
    <1.9993317, 0.0831414, 18.2720030>,
    <2.0452194, 0.0928414, 18.2675574>,
    <2.1736549, 0.1983745, 18.2322113>,
    <2.1735482, 0.1594471, 18.2322113>,
    <2.1704550, 0.1976543, 18.1968653>,
    <2.1703490, 0.1588474, 18.1968653>,
    <2.1738684, 0.2762293, 18.2322113>,
    <2.1706672, 0.2752681, 18.1968653>,
    <2.1737617, 0.2373019, 18.2322113>,
    <2.1705611, 0.2364612, 18.1968653>,
    <2.2024462, 0.2847788, 18.2873438>,
    <2.2022216, 0.2047809, 18.2873438>,
    <2.1834054, 0.2790840, 18.2631118>,
    <2.2023339, 0.2447799, 18.2873438>,
    <2.1831882, 0.2005136, 18.2631118>,
    <2.1832968, 0.2397988, 18.2631118>,
    <2.2021093, 0.1647819, 18.2873438>,
    <2.1830797, 0.1612284, 18.2631118>,
    <2.0868234, 0.2381949, 18.2324892>,
    <2.1303447, 0.2572111, 18.2322113>,
    <2.0852304, 0.2377203, 18.1968653>,
    <2.1279488, 0.2564942, 18.1968653>,
    <1.9997932, 0.2001722, 18.2344341>,
    <1.9997935, 0.2001725, 18.1968653>,
    <2.0433071, 0.2191826, 18.2333227>,
    <2.0425120, 0.2189464, 18.1968653>,
    <1.9997926, 0.2001718, 18.3095719>,
    <2.1010353, 0.2424083, 18.2890109>,
    <1.9997929, 0.2001720, 18.2720030>,
    <2.0503669, 0.2212526, 18.2940122>,
    <2.0915695, 0.2396044, 18.2642232>,
    <2.0456762, 0.2198842, 18.2675574>,
    <2.1517333, 0.2635877, 18.2873438>,
    <2.1374825, 0.2593402, 18.2631118>,
    <2.1352127, 0.1091659, 18.3131904>,
    <1.9986209, 0.0831266, 18.3135798>,
    <2.0669167, 0.0961463, 18.3133573>,
    <1.9989762, 0.0831340, 18.3115759>,
    <2.1162972, 0.1063218, 18.3037960>,
    <2.0576311, 0.0947278, 18.3071303>,
    <2.2718053, 0.1352053, 18.3131347>,
    <2.2336848, 0.1295109, 18.3026846>,
    <2.2035089, 0.1221856, 18.3131347>,
    <2.1749854, 0.1179163, 18.3026846>,
    <2.3424283, 0.1458049, 18.3353648>,
    <2.1702592, 0.1144602, 18.3340315>,
    <2.3101295, 0.1409440, 18.3226946>,
    <2.2563517, 0.1301327, 18.3353648>,
    <2.1542293, 0.1120322, 18.3218058>,
    <2.2321847, 0.1264882, 18.3226946>,
    <1.9979104, 0.0831118, 18.3175878>,
    <2.0841350, 0.0987870, 18.3300317>,
    <1.9982657, 0.0831192, 18.3155838>,
    <2.0762528, 0.0975758, 18.3191392>,
    <2.2720572, 0.2204428, 18.3131347>,
    <2.2719312, 0.1778241, 18.3131347>,
    <2.2339217, 0.2118858, 18.3026846>,
    <2.2338033, 0.1706984, 18.3026846>,
    <2.2723090, 0.3056804, 18.3131347>,
    <2.2341587, 0.2942607, 18.3026846>,
    <2.2721831, 0.2630616, 18.3131347>,
    <2.2340402, 0.2530732, 18.3026846>,
    <2.3429872, 0.3269374, 18.3353648>,
    <2.3427077, 0.2363712, 18.3353648>,
    <2.3106631, 0.3171889, 18.3226946>,
    <2.3428475, 0.2816543, 18.3353648>,
    <2.3103963, 0.2290665, 18.3226946>,
    <2.3105297, 0.2731277, 18.3226946>,
    <2.3425680, 0.1910880, 18.3353648>,
    <2.3102629, 0.1850052, 18.3226946>,
    <2.1357333, 0.2526735, 18.3131904>,
    <2.2040211, 0.2791769, 18.3131347>,
    <2.1167874, 0.2470664, 18.3037960>,
    <2.1754681, 0.2706596, 18.3026846>,
    <1.9991584, 0.1996671, 18.3135798>,
    <1.9994755, 0.1999195, 18.3115759>,
    <2.0674458, 0.2261703, 18.3133573>,
    <2.0581265, 0.2234890, 18.3071303>,
    <1.9985241, 0.1991625, 18.3175878>,
    <2.1708358, 0.2631138, 18.3340315>,
    <1.9988412, 0.1994148, 18.3155838>,
    <2.0847248, 0.2311738, 18.3300317>,
    <2.1547805, 0.2583244, 18.3218058>,
    <2.0768156, 0.2288734, 18.3191392>,
    <2.2569186, 0.2950312, 18.3353648>,
    <2.2327265, 0.2877604, 18.3226946>,
    <2.1856092, 0.1168446, 18.3800376>,
    <1.9978764, 0.0831111, 18.3784821>,
    <2.0917441, 0.0999778, 18.3793709>,
    <1.9978934, 0.0831114, 18.3480349>,
    <2.1802147, 0.1159895, 18.3542569>,
    <2.0890594, 0.0995506, 18.3515903>,
    <2.3733261, 0.1505777, 18.3802598>,
    <2.3624726, 0.1488662, 18.3551457>,
    <2.2794690, 0.1337112, 18.3802598>,
    <2.2713490, 0.1324280, 18.3551457>,
    <2.3797149, 0.1517512, 18.4393764>,
    <2.1887787, 0.1174308, 18.4393764>,
    <2.3780523, 0.1513894, 18.4089292>,
    <2.2842468, 0.1345910, 18.4393764>,
    <2.1879559, 0.1172501, 18.4089292>,
    <2.2830041, 0.1343197, 18.4089292>,
    <1.9978424, 0.0831103, 18.4393764>,
    <2.0933106, 0.1002706, 18.4393764>,
    <1.9978594, 0.0831107, 18.4089292>,
    <2.0929077, 0.1001804, 18.4089292>,
    <2.3736176, 0.2435434, 18.3802598>,
    <2.3734719, 0.1970605, 18.3802598>,
    <2.3627599, 0.2409714, 18.3551457>,
    <2.3626163, 0.1949188, 18.3551457>,
    <2.3739092, 0.3365090, 18.3802598>,
    <2.3630472, 0.3330766, 18.3551457>,
    <2.3737634, 0.2900262, 18.3802598>,
    <2.3629036, 0.2870240, 18.3551457>,
    <2.3803031, 0.3388622, 18.4393764>,
    <2.3800090, 0.2453067, 18.4393764>,
    <2.3786391, 0.3381367, 18.4089292>,
    <2.3801561, 0.2920844, 18.4393764>,
    <2.3783457, 0.2447631, 18.4089292>,
    <2.3784924, 0.2914499, 18.4089292>,
    <2.3798620, 0.1985289, 18.4393764>,
    <2.3781990, 0.1980762, 18.4089292>,
    <2.1862085, 0.2678293, 18.3800376>,
    <2.2800600, 0.3021701, 18.3802598>,
    <2.1808064, 0.2661361, 18.3542569>,
    <2.2719315, 0.2996101, 18.3551457>,
    <1.9984938, 0.1991384, 18.3784821>,
    <1.9985089, 0.1991505, 18.3480349>,
    <2.0923523, 0.2334848, 18.3793709>,
    <2.0896624, 0.2326470, 18.3515903>,
    <1.9984634, 0.1991142, 18.4393764>,
    <2.1893833, 0.2689882, 18.4393764>,
    <1.9984786, 0.1991263, 18.4089292>,
    <2.0939233, 0.2340512, 18.4393764>,
    <2.1885589, 0.2686315, 18.4089292>,
    <2.0935187, 0.2338789, 18.4089292>,
    <2.2848432, 0.3039252, 18.4393764>,
    <2.2835990, 0.3033841, 18.4089292>,
    <2.1975526, 0.1193576, 18.4393764>,
    <1.9976612, 0.0831066, 18.4393764>,
    <2.0976069, 0.1012321, 18.4393764>,
    <1.9977518, 0.0831085, 18.4393764>,
    <2.1931657, 0.1183942, 18.4393764>,
    <2.0954587, 0.1007513, 18.4393764>,
    <2.3974441, 0.1556087, 18.4393764>,
    <2.3885795, 0.1536799, 18.4393764>,
    <2.2974984, 0.1374831, 18.4393764>,
    <2.2908726, 0.1360370, 18.4393764>,
    <2.4151733, 0.1594662, 18.4393764>,
    <2.2063266, 0.1212845, 18.4393764>,
    <2.4063087, 0.1575374, 18.4393764>,
    <2.3107499, 0.1403753, 18.4393764>,
    <2.2019396, 0.1203210, 18.4393764>,
    <2.3041241, 0.1389292, 18.4393764>,
    <1.9974799, 0.0831028, 18.4393764>,
    <2.1019033, 0.1021936, 18.4393764>,
    <1.9975705, 0.0831047, 18.4393764>,
    <2.0997551, 0.1017129, 18.4393764>,
    <2.3977454, 0.2511034, 18.4393764>,
    <2.3975948, 0.2033560, 18.4393764>,
    <2.3888772, 0.2482051, 18.4393764>,
    <2.3887284, 0.2009425, 18.4393764>,
    <2.3980467, 0.3465982, 18.4393764>,
    <2.3891749, 0.3427302, 18.4393764>,
    <2.3978960, 0.2988508, 18.4393764>,
    <2.3890261, 0.2954676, 18.4393764>,
    <2.4157903, 0.3543342, 18.4393764>,
    <2.4154818, 0.2569002, 18.4393764>,
    <2.4069185, 0.3504662, 18.4393764>,
    <2.4156360, 0.3056172, 18.4393764>,
    <2.4066136, 0.2540018, 18.4393764>,
    <2.4067660, 0.3022340, 18.4393764>,
    <2.4153275, 0.2081832, 18.4393764>,
    <2.4064611, 0.2057696, 18.4393764>,
    <2.1981741, 0.2727919, 18.4393764>,
    <2.2981104, 0.3096950, 18.4393764>,
    <2.1937787, 0.2708900, 18.4393764>,
    <2.2914768, 0.3068101, 18.4393764>,
    <1.9983016, 0.1989855, 18.4393764>,
    <1.9983825, 0.1990499, 18.4393764>,
    <2.0982379, 0.2358887, 18.4393764>,
    <2.0960806, 0.2349700, 18.4393764>,
    <1.9981398, 0.1988568, 18.4393764>,
    <2.2069650, 0.2765955, 18.4393764>,
    <1.9982207, 0.1989211, 18.4393764>,
    <2.1025524, 0.2377261, 18.4393764>,
    <2.2025696, 0.2746937, 18.4393764>,
    <2.1003951, 0.2368074, 18.4393764>,
    <2.3113777, 0.3154649, 18.4393764>,
    <2.3047440, 0.3125800, 18.4393764>,
    <2.2063266, 0.1212845, 18.4726341>,
    <1.9974799, 0.0831028, 18.4726341>,
    <2.1019033, 0.1021936, 18.4726341>,
    <1.9974799, 0.0831028, 18.4560052>,
    <2.2063266, 0.1212845, 18.4560052>,
    <2.1019033, 0.1021936, 18.4560052>,
    <2.4151733, 0.1594662, 18.4726341>,
    <2.4151733, 0.1594662, 18.4560052>,
    <2.3107499, 0.1403753, 18.4726341>,
    <2.3107499, 0.1403753, 18.4560052>,
    <2.4151733, 0.1594662, 18.4892630>,
    <2.2063266, 0.1212845, 18.4892630>,
    <2.3107499, 0.1403753, 18.4892630>,
    <1.9974799, 0.0831028, 18.4892630>,
    <2.1019033, 0.1021936, 18.4892630>,
    <2.4154818, 0.2569002, 18.4726341>,
    <2.4153275, 0.2081832, 18.4726341>,
    <2.4154818, 0.2569002, 18.4560052>,
    <2.4153275, 0.2081832, 18.4560052>,
    <2.4157903, 0.3543342, 18.4726341>,
    <2.4157903, 0.3543342, 18.4560052>,
    <2.4156360, 0.3056172, 18.4726341>,
    <2.4156360, 0.3056172, 18.4560052>,
    <2.4157903, 0.3543342, 18.4892630>,
    <2.4154818, 0.2569002, 18.4892630>,
    <2.4156360, 0.3056172, 18.4892630>,
    <2.4153275, 0.2081832, 18.4892630>,
    <2.2069650, 0.2765955, 18.4726341>,
    <2.3113777, 0.3154649, 18.4726341>,
    <2.2069650, 0.2765955, 18.4560052>,
    <2.3113777, 0.3154649, 18.4560052>,
    <1.9981398, 0.1988568, 18.4726341>,
    <1.9981398, 0.1988568, 18.4560052>,
    <2.1025524, 0.2377261, 18.4726341>,
    <2.1025524, 0.2377261, 18.4560052>,
    <1.9981398, 0.1988568, 18.4892630>,
    <2.2069650, 0.2765955, 18.4892630>,
    <2.1025524, 0.2377261, 18.4892630>,
    <2.3113777, 0.3154649, 18.4892630>,
    <1.9978099, 0.1409798, 18.4726341>,
    <1.9974799, 0.0831028, 18.4726341>,
    <1.9978099, 0.1409798, 18.4393764>,
    <1.9976449, 0.1120413, 18.4726341>,
    <1.9974799, 0.0831028, 18.4560052>,
    <1.9976449, 0.1120413, 18.4393764>,
    <1.9978099, 0.1409798, 18.4560052>,
    <1.9976449, 0.1120413, 18.4560052>,
    <1.9981398, 0.1988568, 18.4726341>,
    <1.9979748, 0.1699183, 18.4393764>,
    <1.9981398, 0.1988568, 18.4560052>,
    <1.9979748, 0.1699183, 18.4726341>,
    <1.9979748, 0.1699183, 18.4560052>,
    <1.9978099, 0.1409798, 18.5058918>,
    <1.9981398, 0.1988568, 18.4892630>,
    <1.9979748, 0.1699183, 18.5058918>,
    <1.9978099, 0.1409798, 18.4892630>,
    <1.9979748, 0.1699183, 18.4892630>,
    <1.9976449, 0.1120413, 18.5058918>,
    <1.9974799, 0.0831028, 18.4892630>,
    <1.9976449, 0.1120413, 18.4892630>,
    <1.9979814, 0.1410460, 18.4393764>,
    <1.9981529, 0.1411123, 18.4393764>,
    <1.9980671, 0.1410792, 18.4393764>,
    <1.9979977, 0.1121113, 18.4393764>,
    <1.9978213, 0.1120763, 18.4393764>,
    <1.9979095, 0.1120938, 18.4393764>,
    <1.9978099, 0.1409798, 18.4393764>,
    <1.9976449, 0.1120413, 18.4393764>,
    <1.9978956, 0.1410129, 18.4393764>,
    <1.9977331, 0.1120588, 18.4393764>,
    <1.9979748, 0.1699183, 18.4393764>,
    <1.9981415, 0.1700158, 18.4393764>,
    <1.9980582, 0.1699670, 18.4393764>,
    <1.9983082, 0.1701133, 18.4393764>,
    <1.9982248, 0.1700645, 18.4393764>,
    <1.9981851, 0.1411247, 18.3784821>,
    <1.9978764, 0.0831111, 18.3784821>,
    <1.9982173, 0.1411371, 18.3175878>,
    <1.9980308, 0.1121179, 18.3784821>,
    <1.9978934, 0.0831114, 18.3480349>,
    <1.9980638, 0.1121245, 18.3175878>,
    <1.9982012, 0.1411309, 18.3480349>,
    <1.9980473, 0.1121212, 18.3480349>,
    <1.9984938, 0.1991384, 18.3784821>,
    <1.9983707, 0.1701498, 18.3175878>,
    <1.9985089, 0.1991505, 18.3480349>,
    <1.9983394, 0.1701316, 18.3784821>,
    <1.9983550, 0.1701407, 18.3480349>,
    <1.9981529, 0.1411123, 18.4393764>,
    <1.9984786, 0.1991263, 18.4089292>,
    <1.9983082, 0.1701133, 18.4393764>,
    <1.9981690, 0.1411185, 18.4089292>,
    <1.9983238, 0.1701224, 18.4089292>,
    <1.9979977, 0.1121113, 18.4393764>,
    <1.9978594, 0.0831107, 18.4089292>,
    <1.9980142, 0.1121146, 18.4089292>,
    <1.9988896, 0.1413969, 18.3135798>,
    <1.9995620, 0.1416566, 18.3095719>,
    <1.9992258, 0.1415267, 18.3115759>,
    <1.9994467, 0.1123990, 18.3095719>,
    <1.9987553, 0.1122617, 18.3135798>,
    <1.9991010, 0.1123304, 18.3115759>,
    <1.9982173, 0.1411371, 18.3175878>,
    <1.9980638, 0.1121245, 18.3175878>,
    <1.9985534, 0.1412670, 18.3155838>,
    <1.9984096, 0.1121931, 18.3155838>,
    <1.9983707, 0.1701498, 18.3175878>,
    <1.9990240, 0.1705320, 18.3135798>,
    <1.9986973, 0.1703409, 18.3155838>,
    <1.9996773, 0.1709142, 18.3095719>,
    <1.9993507, 0.1707231, 18.3115759>,
    <1.9995627, 0.1416568, 18.2344341>,
    <1.9993321, 0.0831415, 18.2344341>,
    <1.9995633, 0.1416571, 18.1592964>,
    <1.9994474, 0.1123991, 18.2344341>,
    <1.9993324, 0.0831415, 18.1968653>,
    <1.9994480, 0.1123993, 18.1592964>,
    <1.9995630, 0.1416570, 18.1968653>,
    <1.9994477, 0.1123992, 18.1968653>,
    <1.9997932, 0.2001722, 18.2344341>,
    <1.9996786, 0.1709149, 18.1592964>,
    <1.9997935, 0.2001725, 18.1968653>,
    <1.9996779, 0.1709145, 18.2344341>,
    <1.9996783, 0.1709147, 18.1968653>,
    <1.9995620, 0.1416566, 18.3095719>,
    <1.9997929, 0.2001720, 18.2720030>,
    <1.9996773, 0.1709142, 18.3095719>,
    <1.9995623, 0.1416567, 18.2720030>,
    <1.9996776, 0.1709144, 18.2720030>,
    <1.9994467, 0.1123990, 18.3095719>,
    <1.9993317, 0.0831414, 18.2720030>,
    <1.9994470, 0.1123991, 18.2720030>,
    <1.9996624, 0.1416954, 18.1573801>,
    <1.9997616, 0.1417337, 18.1554639>,
    <1.9997120, 0.1417145, 18.1564220>,
    <1.9996519, 0.1124398, 18.1554639>,
    <1.9995500, 0.1124195, 18.1573801>,
    <1.9996010, 0.1124296, 18.1564220>,
    <1.9995633, 0.1416571, 18.1592964>,
    <1.9994480, 0.1123993, 18.1592964>,
    <1.9996129, 0.1416762, 18.1583383>,
    <1.9994990, 0.1124094, 18.1583383>,
    <1.9996786, 0.1709149, 18.1592964>,
    <1.9997749, 0.1709713, 18.1573801>,
    <1.9997267, 0.1709431, 18.1583383>,
    <1.9998712, 0.1710276, 18.1554639>,
    <1.9998231, 0.1709994, 18.1564220>,
    <1.9999622, 0.1418112, 18.1389725>,
    <1.9997610, 0.0831504, 18.1386133>,
    <2.0001028, 0.1418655, 18.1258340>,
    <1.9998605, 0.1124804, 18.1388528>,
    <1.9998704, 0.0831527, 18.1301880>,
    <2.0000168, 0.1125074, 18.1251156>,
    <2.0000464, 0.1418437, 18.1316249>,
    <1.9999541, 0.1124965, 18.1311460>,
    <2.0001762, 0.2004769, 18.1386133>,
    <2.0002145, 0.1712335, 18.1251156>,
    <2.0002738, 0.2005546, 18.1301880>,
    <2.0000681, 0.1711436, 18.1388528>,
    <2.0001558, 0.1711975, 18.1311460>,
    <1.9997616, 0.1417337, 18.1554639>,
    <2.0000785, 0.2003992, 18.1470386>,
    <1.9998712, 0.1710276, 18.1554639>,
    <1.9998651, 0.1417737, 18.1470386>,
    <1.9999718, 0.1710865, 18.1470386>,
    <1.9996519, 0.1124398, 18.1554639>,
    <1.9996517, 0.0831481, 18.1470386>,
    <1.9997584, 0.1124609, 18.1470386>,
    <2.0001021, 0.1418652, 18.1205987>,
    <2.0001164, 0.1418707, 18.1224380>,
    <2.0000044, 0.1125089, 18.1204790>,
    <2.0000261, 0.1125108, 18.1219591>,
    <2.0000414, 0.1418418, 18.1187163>,
    <1.9999397, 0.1124969, 18.1187163>,
    <2.0000750, 0.1418547, 18.1194779>,
    <1.9999742, 0.1125037, 18.1194779>,
    <2.0001431, 0.1711867, 18.1187163>,
    <2.0002041, 0.1712232, 18.1204790>,
    <2.0001757, 0.1712057, 18.1194779>,
    <2.0002238, 0.1712373, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.1684286, 0.8468919, -0.5043866>,
    <-0.1077075, 0.5532059, -0.8260523>,
    <-0.1079631, 0.6042998, -0.7894085>,
    <-0.1612495, 0.8705741, -0.4648648>,
    <-0.1864910, 0.9824263, 0.0077258>,
    <-0.1977042, 0.9802270, 0.0082499>,
    <-0.1977042, 0.9802270, 0.0082499>,
    <-0.2111980, 0.9774030, 0.0088807>,
    <-0.1764384, 0.8165392, -0.5496664>,
    <-0.1764384, 0.8165392, -0.5496664>,
    <-0.1069419, 0.4949163, -0.8623348>,
    <-0.0598753, 0.3187753, -0.9459372>,
    <-0.0625607, 0.3711753, -0.9264529>,
    <-0.1069419, 0.4949163, -0.8623348>,
    <-0.0568859, 0.2632621, -0.9630457>,
    <-0.0568859, 0.2632621, -0.9630457>,
    <-0.0265166, 0.1227160, -0.9920875>,
    <-0.0294498, 0.1688017, -0.9852100>,
    <-0.0294498, 0.1688017, -0.9852100>,
    <-0.0322743, 0.2138059, -0.9763429>,
    <-0.0649473, 0.4202370, -0.9050871>,
    <-0.1078241, 0.6488264, -0.7532584>,
    <-0.0322743, 0.2138059, -0.9763429>,
    <-0.0349771, 0.2574871, -0.9656485>,
    <-0.0349771, 0.2574871, -0.9656485>,
    <-0.0375482, 0.2996421, -0.9533125>,
    <-0.0670475, 0.4658527, -0.8823185>,
    <-0.0670475, 0.4658527, -0.8823185>,
    <-0.1073893, 0.6874979, -0.7182020>,
    <-0.1548422, 0.8892971, -0.4303192>,
    <-0.1073893, 0.6874979, -0.7182020>,
    <-0.1491274, 0.9042920, -0.4000214>,
    <-0.1491274, 0.9042920, -0.4000214>,
    <-0.1689393, 0.9856023, 0.0069058>,
    <-0.1770288, 0.9841787, 0.0072837>,
    <-0.1770288, 0.9841787, 0.0072837>,
    <-0.1864910, 0.9824263, 0.0077258>,
    <-0.0185111, 0.0000497, -0.9998287>,
    <-0.0185085, 0.0000496, -0.9998287>,
    <-0.0185086, 0.0000505, -0.9998287>,
    <-0.0185112, 0.0000505, -0.9998287>,
    <-0.0185138, 0.0000505, -0.9998286>,
    <-0.0185137, 0.0000497, -0.9998286>,
    <-0.0185137, 0.0000497, -0.9998286>,
    <-0.0185136, 0.0000488, -0.9998286>,
    <-0.0185110, 0.0000488, -0.9998287>,
    <-0.0185110, 0.0000488, -0.9998287>,
    <-0.0185084, 0.0000488, -0.9998287>,
    <-0.0185059, 0.0000496, -0.9998287>,
    <-0.0185060, 0.0000505, -0.9998287>,
    <-0.0185084, 0.0000488, -0.9998287>,
    <-0.0185058, 0.0000488, -0.9998288>,
    <-0.0185058, 0.0000488, -0.9998288>,
    <-0.0185032, 0.0000488, -0.9998288>,
    <-0.0185033, 0.0000496, -0.9998288>,
    <-0.0185033, 0.0000496, -0.9998288>,
    <-0.0185034, 0.0000505, -0.9998288>,
    <-0.0185061, 0.0000513, -0.9998287>,
    <-0.0185087, 0.0000513, -0.9998287>,
    <-0.0185034, 0.0000505, -0.9998288>,
    <-0.0185035, 0.0000513, -0.9998288>,
    <-0.0185035, 0.0000513, -0.9998288>,
    <-0.0185036, 0.0000521, -0.9998288>,
    <-0.0185062, 0.0000521, -0.9998287>,
    <-0.0185062, 0.0000521, -0.9998287>,
    <-0.0185087, 0.0000521, -0.9998287>,
    <-0.0185112, 0.0000513, -0.9998287>,
    <-0.0185087, 0.0000521, -0.9998287>,
    <-0.0185113, 0.0000521, -0.9998286>,
    <-0.0185113, 0.0000521, -0.9998286>,
    <-0.0185139, 0.0000521, -0.9998286>,
    <-0.0185138, 0.0000513, -0.9998286>,
    <-0.0185138, 0.0000513, -0.9998286>,
    <-0.0185138, 0.0000505, -0.9998286>,
    <0.0616346, -0.1614169, 0.9849598>,
    <0.1210969, -0.3058919, 0.9443334>,
    <0.1249312, -0.3440880, 0.9305889>,
    <0.0652855, -0.1906681, 0.9794812>,
    <0.0325008, -0.1060639, 0.9938280>,
    <0.0295033, -0.0832248, 0.9960940>,
    <0.0295033, -0.0832248, 0.9960940>,
    <0.0264739, -0.0602193, 0.9978340>,
    <0.0578833, -0.1316653, 0.9896028>,
    <0.0578833, -0.1316653, 0.9896028>,
    <0.1169336, -0.2659851, 0.9568586>,
    <0.2448025, -0.6052957, 0.7574225>,
    <0.2426456, -0.6444722, 0.7251060>,
    <0.1169336, -0.2659851, 0.9568586>,
    <0.2464396, -0.5605686, 0.7905886>,
    <0.2464396, -0.5605686, 0.7905886>,
    <0.4024137, -0.9153578, 0.0135396>,
    <0.3794621, -0.9250887, 0.0148150>,
    <0.3794621, -0.9250887, 0.0148150>,
    <0.3599943, -0.9328194, 0.0158795>,
    <0.2401329, -0.6787374, 0.6940114>,
    <0.1284426, -0.3804923, 0.9158210>,
    <0.3599943, -0.9328194, 0.0158795>,
    <0.3432955, -0.9390775, 0.0167803>,
    <0.3432955, -0.9390775, 0.0167803>,
    <0.3288282, -0.9442266, 0.0175517>,
    <0.2373930, -0.7087048, 0.6643659>,
    <0.2373930, -0.7087048, 0.6643659>,
    <0.1316414, -0.4150581, 0.9002207>,
    <0.0688293, -0.2193535, 0.9732146>,
    <0.1316414, -0.4150581, 0.9002207>,
    <0.0722602, -0.2474147, 0.9662114>,
    <0.0722602, -0.2474147, 0.9662114>,
    <0.0383831, -0.1511062, 0.9877721>,
    <0.0354622, -0.1287021, 0.9910490>,
    <0.0354622, -0.1287021, 0.9910490>,
    <0.0325008, -0.1060639, 0.9938280>,
    <0.1778039, -0.9831349, 0.0427960>,
    <0.1768694, -0.9805235, 0.0853866>,
    <0.1866284, -0.9787319, 0.0851688>,
    <0.1874346, -0.9813473, 0.0427289>,
    <0.1878936, -0.9821885, 0.0013469>,
    <0.1784024, -0.9839568, 0.0012702>,
    <0.1784024, -0.9839568, 0.0012702>,
    <0.1688295, -0.9856445, 0.0011929>,
    <0.1680892, -0.9848396, 0.0428595>,
    <0.1680892, -0.9848396, 0.0428595>,
    <0.1670243, -0.9822301, 0.0855973>,
    <0.1755784, -0.9759979, 0.1288420>,
    <0.1854532, -0.9742191, 0.1284691>,
    <0.1670243, -0.9822301, 0.0855973>,
    <0.1656161, -0.9776899, 0.1292044>,
    <0.1656161, -0.9776899, 0.1292044>,
    <0.1638506, -0.9711174, 0.1734475>,
    <0.1739152, -0.9694576, 0.1729318>,
    <0.1739152, -0.9694576, 0.1729318>,
    <0.1838913, -0.9677095, 0.1724019>,
    <0.1952387, -0.9723558, 0.1280861>,
    <0.1962998, -0.9768576, 0.0849443>,
    <0.1838913, -0.9677095, 0.1724019>,
    <0.1937770, -0.9658754, 0.1718582>,
    <0.1937770, -0.9658754, 0.1718582>,
    <0.2035704, -0.9639580, 0.1713013>,
    <0.2049331, -0.9704107, 0.1276933>,
    <0.2049331, -0.9704107, 0.1276933>,
    <0.2058819, -0.9749032, 0.0847133>,
    <0.1969795, -0.9794791, 0.0426581>,
    <0.2058819, -0.9749032, 0.0847133>,
    <0.2064372, -0.9775328, 0.0425839>,
    <0.2064372, -0.9775328, 0.0425839>,
    <0.2066244, -0.9784192, 0.0014982>,
    <0.1973014, -0.9803418, 0.0014229>,
    <0.1973014, -0.9803418, 0.0014229>,
    <0.1878936, -0.9821885, 0.0013469>,
    <0.9997843, -0.0027901, -0.0205813>,
    <0.9997864, -0.0027901, -0.0204793>,
    <0.9997863, -0.0027662, -0.0204858>,
    <0.9997842, -0.0027662, -0.0205868>,
    <0.9997822, -0.0027662, -0.0206877>,
    <0.9997822, -0.0027901, -0.0206834>,
    <0.9997822, -0.0027901, -0.0206834>,
    <0.9997822, -0.0028145, -0.0206789>,
    <0.9997843, -0.0028145, -0.0205758>,
    <0.9997843, -0.0028145, -0.0205758>,
    <0.9997865, -0.0028145, -0.0204726>,
    <0.9997885, -0.0027901, -0.0203772>,
    <0.9997884, -0.0027662, -0.0203849>,
    <0.9997865, -0.0028145, -0.0204726>,
    <0.9997886, -0.0028145, -0.0203694>,
    <0.9997886, -0.0028145, -0.0203694>,
    <0.9997907, -0.0028145, -0.0202662>,
    <0.9997905, -0.0027901, -0.0202752>,
    <0.9997905, -0.0027901, -0.0202752>,
    <0.9997904, -0.0027662, -0.0202839>,
    <0.9997883, -0.0027428, -0.0203923>,
    <0.9997863, -0.0027428, -0.0204922>,
    <0.9997904, -0.0027662, -0.0202839>,
    <0.9997903, -0.0027428, -0.0202924>,
    <0.9997903, -0.0027428, -0.0202924>,
    <0.9997902, -0.0027199, -0.0203008>,
    <0.9997882, -0.0027199, -0.0203996>,
    <0.9997882, -0.0027199, -0.0203996>,
    <0.9997862, -0.0027199, -0.0204985>,
    <0.9997842, -0.0027428, -0.0205921>,
    <0.9997862, -0.0027199, -0.0204985>,
    <0.9997842, -0.0027199, -0.0205973>,
    <0.9997842, -0.0027199, -0.0205973>,
    <0.9997821, -0.0027199, -0.0206962>,
    <0.9997821, -0.0027428, -0.0206920>,
    <0.9997821, -0.0027428, -0.0206920>,
    <0.9997822, -0.0027662, -0.0206877>,
    <-0.3337440, 0.9116280, -0.2398945>,
    <-0.3402139, 0.9267933, -0.1590869>,
    <-0.3572435, 0.9205692, -0.1578907>,
    <-0.3508626, 0.9056622, -0.2380574>,
    <-0.3422134, 0.8848880, -0.3160114>,
    <-0.3250866, 0.8904667, -0.3184144>,
    <-0.3250866, 0.8904667, -0.3184144>,
    <-0.3075786, 0.8958327, -0.3207478>,
    <-0.3162318, 0.9173812, -0.2416800>,
    <-0.3162318, 0.9173812, -0.2416800>,
    <-0.3227854, 0.9328075, -0.1602492>,
    <-0.3443545, 0.9356258, -0.0776170>,
    <-0.3612199, 0.9292879, -0.0770987>,
    <-0.3227854, 0.9328075, -0.1602492>,
    <-0.3270923, 0.9417580, -0.0781181>,
    <-0.3270923, 0.9417580, -0.0781181>,
    <-0.3291428, 0.9442753, 0.0030322>,
    <-0.3461644, 0.9381695, 0.0028750>,
    <-0.3461644, 0.9381695, 0.0028750>,
    <-0.3627978, 0.9318639, 0.0027195>,
    <-0.3776847, 0.9227633, -0.0765647>,
    <-0.3738703, 0.9141539, -0.1566639>,
    <-0.3627978, 0.9318639, 0.0027195>,
    <-0.3790398, 0.9253768, 0.0025657>,
    <-0.3790398, 0.9253768, 0.0025657>,
    <-0.3948886, 0.9187258, 0.0024139>,
    <-0.3937471, 0.9160702, -0.0760167>,
    <-0.3937471, 0.9160702, -0.0760167>,
    <-0.3900919, 0.9075661, -0.1554097>,
    <-0.3675831, 0.8995024, -0.2361738>,
    <-0.3900919, 0.9075661, -0.1554097>,
    <-0.3839026, 0.8931665, -0.2342485>,
    <-0.3839026, 0.8931665, -0.2342485>,
    <-0.3753042, 0.8731619, -0.3110224>,
    <-0.3589538, 0.8791140, -0.3135453>,
    <-0.3589538, 0.8791140, -0.3135453>,
    <-0.3422134, 0.8848880, -0.3160114>,
    <0.2074430, -0.9763972, 0.0601332>,
    <0.2065677, -0.9722773, 0.1095750>,
    <0.2077495, -0.9723134, 0.1069898>,
    <0.2085866, -0.9762314, 0.0588554>,
    <0.2089377, -0.9778746, 0.0103071>,
    <0.2078081, -0.9781160, 0.0102451>,
    <0.2078081, -0.9781160, 0.0102451>,
    <0.2066139, -0.9783696, 0.0101795>,
    <0.2062337, -0.9765692, 0.0614834>,
    <0.2062337, -0.9765692, 0.0614834>,
    <0.2053175, -0.9722306, 0.1123049>,
    <0.2052014, -0.9658466, 0.1582172>,
    <0.2064437, -0.9662021, 0.1543840>,
    <0.2053175, -0.9722306, 0.1123049>,
    <0.2038864, -0.9654542, 0.1622606>,
    <0.2038864, -0.9654542, 0.1622606>,
    <0.2019727, -0.9563922, 0.2109999>,
    <0.2033733, -0.9572421, 0.2057347>,
    <0.2033733, -0.9572421, 0.2057347>,
    <0.2046957, -0.9580212, 0.2007364>,
    <0.2076191, -0.9665248, 0.1507453>,
    <0.2088684, -0.9723404, 0.1045381>,
    <0.2046957, -0.9580212, 0.2007364>,
    <0.2059461, -0.9587366, 0.1959856>,
    <0.2059461, -0.9587366, 0.1959856>,
    <0.2071302, -0.9593948, 0.1914646>,
    <0.2087328, -0.9668181, 0.1472867>,
    <0.2087328, -0.9668181, 0.1472867>,
    <0.2099292, -0.9723594, 0.1022098>,
    <0.2096699, -0.9760716, 0.0576442>,
    <0.2099292, -0.9723594, 0.1022098>,
    <0.2106974, -0.9759175, 0.0564947>,
    <0.2106974, -0.9759175, 0.0564947>,
    <0.2110229, -0.9774256, 0.0104216>,
    <0.2100078, -0.9776448, 0.0103659>,
    <0.2100078, -0.9776448, 0.0103659>,
    <0.2089377, -0.9778746, 0.0103071>,
    <0.2186828, -0.0005957, -0.9757958>,
    <0.2186765, -0.0005957, -0.9757972>,
    <0.2186768, -0.0005964, -0.9757972>,
    <0.2186830, -0.0005964, -0.9757958>,
    <0.2186892, -0.0005964, -0.9757944>,
    <0.2186891, -0.0005957, -0.9757944>,
    <0.2186891, -0.0005957, -0.9757944>,
    <0.2186889, -0.0005949, -0.9757945>,
    <0.2186825, -0.0005949, -0.9757959>,
    <0.2186825, -0.0005949, -0.9757959>,
    <0.2186762, -0.0005949, -0.9757973>,
    <0.2186702, -0.0005956, -0.9757986>,
    <0.2186705, -0.0005964, -0.9757986>,
    <0.2186762, -0.0005949, -0.9757973>,
    <0.2186699, -0.0005949, -0.9757987>,
    <0.2186699, -0.0005949, -0.9757987>,
    <0.2186635, -0.0005949, -0.9758001>,
    <0.2186639, -0.0005956, -0.9758001>,
    <0.2186639, -0.0005956, -0.9758001>,
    <0.2186643, -0.0005964, -0.9758000>,
    <0.2186708, -0.0005971, -0.9757985>,
    <0.2186770, -0.0005971, -0.9757971>,
    <0.2186643, -0.0005964, -0.9758000>,
    <0.2186646, -0.0005971, -0.9757999>,
    <0.2186646, -0.0005971, -0.9757999>,
    <0.2186650, -0.0005978, -0.9757998>,
    <0.2186711, -0.0005978, -0.9757984>,
    <0.2186711, -0.0005978, -0.9757984>,
    <0.2186773, -0.0005978, -0.9757971>,
    <0.2186832, -0.0005971, -0.9757957>,
    <0.2186773, -0.0005978, -0.9757971>,
    <0.2186834, -0.0005979, -0.9757957>,
    <0.2186834, -0.0005979, -0.9757957>,
    <0.2186896, -0.0005979, -0.9757943>,
    <0.2186894, -0.0005972, -0.9757943>,
    <0.2186894, -0.0005972, -0.9757943>,
    <0.2186892, -0.0005964, -0.9757944>,
    <-0.3830005, 0.8856831, -0.2624425>,
    <-0.3909121, 0.9039786, -0.1732349>,
    <-0.3931354, 0.9039491, -0.1682874>,
    <-0.3855972, 0.8866162, -0.2553949>,
    <-0.3755358, 0.8634816, -0.3367081>,
    <-0.3724847, 0.8613655, -0.3454050>,
    <-0.3724847, 0.8613655, -0.3454050>,
    <-0.3692422, 0.8590585, -0.3545119>,
    <-0.3802397, 0.8846446, -0.2698548>,
    <-0.3802397, 0.8846446, -0.2698548>,
    <-0.3885509, 0.9039810, -0.1784560>,
    <-0.3956551, 0.9149466, -0.0795597>,
    <-0.3976376, 0.9143009, -0.0770595>,
    <-0.3885509, 0.9039810, -0.1784560>,
    <-0.3935533, 0.9156191, -0.0822037>,
    <-0.3935533, 0.9156191, -0.0822037>,
    <-0.3948366, 0.9186050, 0.0163994>,
    <-0.3968607, 0.9177347, 0.0162668>,
    <-0.3968607, 0.9177347, 0.0162668>,
    <-0.3987715, 0.9169083, 0.0161414>,
    <-0.3995105, 0.9136807, -0.0746919>,
    <-0.3952322, 0.9038965, -0.1635930>,
    <-0.3987715, 0.9169083, 0.0161414>,
    <-0.4005781, 0.9161225, 0.0160228>,
    <-0.4005781, 0.9161225, 0.0160228>,
    <-0.4022889, 0.9153745, 0.0159102>,
    <-0.4012826, 0.9130848, -0.0724465>,
    <-0.4012826, 0.9130848, -0.0724465>,
    <-0.3972129, 0.9038244, -0.1591330>,
    <-0.3880434, 0.8874555, -0.2486867>,
    <-0.3972129, 0.9038244, -0.1591330>,
    <-0.3903511, 0.8882112, -0.2422951>,
    <-0.3903511, 0.8882112, -0.2422951>,
    <-0.3811230, 0.8672133, -0.3204472>,
    <-0.3784106, 0.8654254, -0.3283965>,
    <-0.3784106, 0.8654254, -0.3283965>,
    <-0.3755358, 0.8634816, -0.3367081>,
    <0.2108429, -0.9775197, -0.0006803>,
    <0.2108394, -0.9775197, -0.0013841>,
    <0.2094328, -0.9778055, -0.0058606>,
    <0.2094744, -0.9778102, -0.0027863>,
    <0.2095618, -0.9777954, 0.0000017>,
    <0.2108464, -0.9775192, 0.0000017>,
    <0.2108464, -0.9775192, 0.0000017>,
    <0.2110344, -0.9774786, 0.0000017>,
    <0.2110344, -0.9774786, 0.0000017>,
    <0.2110344, -0.9774786, 0.0000017>,
    <0.2110344, -0.9774786, 0.0000016>,
    <0.2108380, -0.9775188, -0.0021019>,
    <0.2094632, -0.9777748, -0.0090369>,
    <0.2110344, -0.9774786, 0.0000016>,
    <0.2110344, -0.9774786, 0.0000015>,
    <0.2110344, -0.9774786, 0.0000015>,
    <0.2110344, -0.9774786, 0.0000015>,
    <0.2108377, -0.9775170, -0.0028226>,
    <0.2108377, -0.9775170, -0.0028226>,
    <0.2094851, -0.9777361, -0.0121662>,
    <0.2058488, -0.9783142, -0.0229696>,
    <0.2055507, -0.9785371, -0.0146328>,
    <0.2094851, -0.9777361, -0.0121662>,
    <0.2060360, -0.9780505, -0.0310863>,
    <0.2060360, -0.9780505, -0.0310863>,
    <0.2000348, -0.9773242, -0.0694511>,
    <0.1995736, -0.9785513, -0.0510666>,
    <0.1986859, -0.9795125, -0.0328512>,
    <0.2056936, -0.9785943, -0.0065870>,
    <0.1983980, -0.9799988, -0.0155113>,
    <0.2012800, -0.9795324, 0.0016249>,
    <0.2063560, -0.9784770, 0.0000017>,
    <0.2063560, -0.9784770, 0.0000017>,
    <0.2095618, -0.9777954, 0.0000017>,
    <0.9990161, -0.0027325, -0.0442658>,
    <0.9990159, -0.0027325, -0.0442698>,
    <0.9820424, -0.0026947, -0.1886412>,
    <0.9820456, -0.0026948, -0.1886245>,
    <0.9820488, -0.0026948, -0.1886077>,
    <0.9990162, -0.0027325, -0.0442617>,
    <0.9990162, -0.0027325, -0.0442617>,
    <0.9999959, -0.0027339, -0.0008831>,
    <0.9999959, -0.0027339, -0.0008831>,
    <0.9999959, -0.0027339, -0.0008831>,
    <0.9999959, -0.0027339, -0.0008832>,
    <0.9990157, -0.0027325, -0.0442739>,
    <0.9820392, -0.0026947, -0.1886580>,
    <0.9999959, -0.0027339, -0.0008832>,
    <0.9999959, -0.0027339, -0.0008832>,
    <0.9999959, -0.0027339, -0.0008832>,
    <0.9999959, -0.0027339, -0.0008833>,
    <0.9990155, -0.0027325, -0.0442779>,
    <0.9990155, -0.0027325, -0.0442779>,
    <0.9820359, -0.0026947, -0.1886748>,
    <0.8879866, -0.0024576, -0.4598627>,
    <0.8880038, -0.0024576, -0.4598296>,
    <0.9820359, -0.0026947, -0.1886748>,
    <0.8879695, -0.0024575, -0.4598959>,
    <0.8879695, -0.0024575, -0.4598959>,
    <0.6152103, -0.0017301, -0.7883612>,
    <0.6152446, -0.0017302, -0.7883344>,
    <0.6152789, -0.0017303, -0.7883076>,
    <0.8880209, -0.0024577, -0.4597965>,
    <0.6153132, -0.0017304, -0.7882808>,
    <0.6153475, -0.0017305, -0.7882540>,
    <0.8880381, -0.0024577, -0.4597633>,
    <0.8880381, -0.0024577, -0.4597633>,
    <0.9820488, -0.0026948, -0.1886077>,
    <-0.4020058, 0.9156275, 0.0042032>,
    <-0.4020007, 0.9156351, 0.0028064>,
    <-0.3995352, 0.9166409, 0.0118794>,
    <-0.3996341, 0.9164965, 0.0180793>,
    <-0.3996583, 0.9163482, 0.0240650>,
    <-0.4020063, 0.9156199, 0.0055800>,
    <-0.4020063, 0.9156199, 0.0055800>,
    <-0.4023398, 0.9154904, 0.0000028>,
    <-0.4023398, 0.9154904, 0.0000028>,
    <-0.4023398, 0.9154904, 0.0000028>,
    <-0.4023398, 0.9154904, 0.0000027>,
    <-0.4019986, 0.9156392, 0.0013951>,
    <-0.3995527, 0.9166925, 0.0057003>,
    <-0.4023398, 0.9154904, 0.0000027>,
    <-0.4023398, 0.9154904, 0.0000027>,
    <-0.4023398, 0.9154904, 0.0000027>,
    <-0.4023398, 0.9154904, 0.0000026>,
    <-0.4020020, 0.9156388, 0.0000026>,
    <-0.4020020, 0.9156388, 0.0000026>,
    <-0.3996905, 0.9166501, 0.0000027>,
    <-0.3927089, 0.9195587, 0.0138413>,
    <-0.3926638, 0.9191946, 0.0299390>,
    <-0.3996905, 0.9166501, 0.0000027>,
    <-0.3938059, 0.9191936, 0.0000027>,
    <-0.3938059, 0.9191936, 0.0000027>,
    <-0.3834384, 0.9235622, 0.0028183>,
    <-0.3791870, 0.9246552, 0.0350699>,
    <-0.3801872, 0.9223809, 0.0683465>,
    <-0.3932241, 0.9182844, 0.0461365>,
    <-0.3812502, 0.9186964, 0.1031757>,
    <-0.3809364, 0.9142548, 0.1379336>,
    <-0.3933713, 0.9173102, 0.0616531>,
    <-0.3933713, 0.9173102, 0.0616531>,
    <-0.3996583, 0.9163482, 0.0240650>,
    <0.1907384, -0.9808428, -0.0395770>,
    <0.1910733, -0.9794694, -0.0642712>,
    <0.1864041, -0.9787582, -0.0853577>,
    <0.1867309, -0.9806645, -0.0585557>,
    <0.1873093, -0.9818558, 0.0295705>,
    <0.1964879, -0.9800096, 0.0312044>,
    <0.1964879, -0.9800096, 0.0312044>,
    <0.2012800, -0.9795324, 0.0016249>,
    <0.1919501, -0.9769196, -0.0937195>,
    <0.1859531, -0.9757523, -0.1154508>,
    <0.2000348, -0.9773242, -0.0694511>,
    <0.1920202, -0.9732095, -0.1264573>,
    <0.1920202, -0.9732095, -0.1264573>,
    <0.1850793, -0.9708410, -0.1523593>,
    <0.1822454, -0.9796722, -0.0838389>,
    <0.1833149, -0.9812028, -0.0603052>,
    <0.1850793, -0.9708410, -0.1523593>,
    <0.1813655, -0.9772185, -0.1102298>,
    <0.1813655, -0.9772185, -0.1102298>,
    <0.1791184, -0.9826049, -0.0490326>,
    <0.1794466, -0.9830856, -0.0366277>,
    <0.1798777, -0.9833933, -0.0241185>,
    <0.1838503, -0.9822467, -0.0372895>,
    <0.1800076, -0.9836016, -0.0111839>,
    <0.1789369, -0.9838589, 0.0018169>,
    <0.1807410, -0.9831206, 0.0284014>,
    <0.1807410, -0.9831206, 0.0284014>,
    <0.1873093, -0.9818558, 0.0295705>,
    <0.3466621, -0.0009980, -0.9379895>,
    <0.3466355, -0.0009979, -0.9379994>,
    <0.2532907, -0.0007484, -0.9673899>,
    <0.2533106, -0.0007484, -0.9673847>,
    <0.2533306, -0.0007485, -0.9673795>,
    <0.3466887, -0.0009981, -0.9379797>,
    <0.3466887, -0.0009981, -0.9379797>,
    <0.6153475, -0.0017305, -0.7882540>,
    <0.3466089, -0.0009978, -0.9380092>,
    <0.2532707, -0.0007483, -0.9673952>,
    <0.6152103, -0.0017301, -0.7883612>,
    <0.3465823, -0.0009978, -0.9380190>,
    <0.3465823, -0.0009978, -0.9380190>,
    <0.2532508, -0.0007483, -0.9674004>,
    <0.3003049, -0.0009087, -0.9538428>,
    <0.3003270, -0.0009087, -0.9538359>,
    <0.2532508, -0.0007483, -0.9674004>,
    <0.3002827, -0.0009086, -0.9538498>,
    <0.3002827, -0.0009086, -0.9538498>,
    <0.5269785, -0.0016240, -0.8498771>,
    <0.5270082, -0.0016241, -0.8498586>,
    <0.5270380, -0.0016242, -0.8498401>,
    <0.3003492, -0.0009088, -0.9538289>,
    <0.5270678, -0.0016243, -0.8498217>,
    <0.5270976, -0.0016244, -0.8498032>,
    <0.3003714, -0.0009089, -0.9538219>,
    <0.3003714, -0.0009089, -0.9538219>,
    <0.2533306, -0.0007485, -0.9673795>,
    <-0.3644957, 0.9116250, 0.1899545>,
    <-0.3650837, 0.9209867, 0.1360048>,
    <-0.3553259, 0.9165361, 0.1835894>,
    <-0.3515308, 0.9060567, 0.2355574>,
    <-0.3450915, 0.8891350, 0.3005843>,
    <-0.3609454, 0.8985940, 0.2494941>,
    <-0.3609454, 0.8985940, 0.2494941>,
    <-0.3809364, 0.9142548, 0.1379336>,
    <-0.3647568, 0.9261892, 0.0955300>,
    <-0.3574124, 0.9223265, 0.1468680>,
    <-0.3834384, 0.9235622, 0.0028183>,
    <-0.3670087, 0.9283570, 0.0588043>,
    <-0.3670087, 0.9283570, 0.0588043>,
    <-0.3609411, 0.9306530, 0.0600536>,
    <-0.3556925, 0.9294082, 0.0984036>,
    <-0.3528085, 0.9261473, 0.1333315>,
    <-0.3609411, 0.9306530, 0.0600536>,
    <-0.3560457, 0.9324717, 0.0610572>,
    <-0.3560457, 0.9324717, 0.0610572>,
    <-0.3487579, 0.9372040, 0.0040641>,
    <-0.3500704, 0.9362520, 0.0297126>,
    <-0.3488669, 0.9355817, 0.0545785>,
    <-0.3488131, 0.9206557, 0.1752785>,
    <-0.3473850, 0.9344334, 0.0784718>,
    <-0.3461344, 0.9326070, 0.1021527>,
    <-0.3445281, 0.9117769, 0.2235249>,
    <-0.3445281, 0.9117769, 0.2235249>,
    <-0.3450915, 0.8891350, 0.3005843>,
    <0.1777342, -0.9840719, -0.0036114>,
    <0.1777791, -0.9840357, -0.0082655>,
    <0.1769622, -0.9842148, -0.0023606>,
    <0.1769510, -0.9842191, -0.0010672>,
    <0.1769357, -0.9842224, 0.0000873>,
    <0.1775731, -0.9841076, 0.0000877>,
    <0.1775731, -0.9841076, 0.0000877>,
    <0.1789369, -0.9838589, 0.0018169>,
    <0.1777045, -0.9839977, -0.0130262>,
    <0.1769613, -0.9842108, -0.0037247>,
    <0.1791184, -0.9826049, -0.0490326>,
    <0.1776412, -0.9839370, -0.0176542>,
    <0.1776412, -0.9839370, -0.0176542>,
    <0.1769573, -0.9842054, -0.0050871>,
    <0.1768047, -0.9842459, 0.0003568>,
    <0.1768035, -0.9842461, 0.0002767>,
    <0.1769573, -0.9842054, -0.0050871>,
    <0.1768051, -0.9842458, 0.0004289>,
    <0.1768051, -0.9842458, 0.0004289>,
    <0.1769124, -0.9842245, 0.0020333>,
    <0.1769125, -0.9842254, 0.0015468>,
    <0.1769125, -0.9842254, 0.0015468>,
    <0.1769126, -0.9842260, 0.0010603>,
    <0.1768024, -0.9842463, 0.0001846>,
    <0.1769126, -0.9842260, 0.0010603>,
    <0.1769127, -0.9842264, 0.0005738>,
    <0.1769127, -0.9842264, 0.0005738>,
    <0.1769127, -0.9842265, 0.0000873>,
    <0.1768022, -0.9842464, 0.0000872>,
    <0.1768022, -0.9842464, 0.0000872>,
    <0.1769357, -0.9842224, 0.0000873>,
    <0.8238686, -0.0025675, -0.5667750>,
    <0.8238488, -0.0025674, -0.5668038>,
    <0.9605359, -0.0030105, -0.2781398>,
    <0.9605410, -0.0030105, -0.2781220>,
    <0.9605462, -0.0030106, -0.2781043>,
    <0.8238884, -0.0025675, -0.5667462>,
    <0.8238884, -0.0025675, -0.5667462>,
    <0.5270976, -0.0016244, -0.8498032>,
    <0.8238290, -0.0025673, -0.5668326>,
    <0.9605307, -0.0030105, -0.2781575>,
    <0.5269785, -0.0016240, -0.8498771>,
    <0.8238091, -0.0025673, -0.5668614>,
    <0.8238091, -0.0025673, -0.5668614>,
    <0.9605256, -0.0030105, -0.2781753>,
    <0.9942108, -0.0031232, -0.1074017>,
    <0.9942114, -0.0031232, -0.1073960>,
    <0.9605256, -0.0030105, -0.2781753>,
    <0.9942102, -0.0031232, -0.1074075>,
    <0.9942102, -0.0031232, -0.1074075>,
    <0.9985091, -0.0031387, -0.0544946>,
    <0.9985092, -0.0031387, -0.0544929>,
    <0.9985092, -0.0031387, -0.0544929>,
    <0.9985093, -0.0031387, -0.0544912>,
    <0.9942120, -0.0031232, -0.1073902>,
    <0.9985093, -0.0031387, -0.0544912>,
    <0.9985094, -0.0031387, -0.0544895>,
    <0.9985094, -0.0031387, -0.0544895>,
    <0.9985095, -0.0031387, -0.0544878>,
    <0.9942127, -0.0031232, -0.1073844>,
    <0.9942127, -0.0031232, -0.1073844>,
    <0.9605462, -0.0030106, -0.2781043>,
    <-0.3450172, 0.9381628, 0.0285264>,
    <-0.3453448, 0.9382828, 0.0190352>,
    <-0.3438220, 0.9390167, 0.0058383>,
    <-0.3437766, 0.9390116, 0.0086501>,
    <-0.3437494, 0.9389933, 0.0113102>,
    <-0.3447793, 0.9379343, 0.0375038>,
    <-0.3447793, 0.9379343, 0.0375038>,
    <-0.3461344, 0.9326070, 0.1021527>,
    <-0.3454708, 0.9383855, 0.0090844>,
    <-0.3438404, 0.9390235, 0.0029319>,
    <-0.3487579, 0.9372040, 0.0040641>,
    <-0.3452210, 0.9385214, 0.0002001>,
    <-0.3452210, 0.9385214, 0.0002001>,
    <-0.3438214, 0.9390350, 0.0002010>,
    <-0.3435051, 0.9391508, 0.0001251>,
    <-0.3435027, 0.9391517, 0.0000305>,
    <-0.3438214, 0.9390350, 0.0002010>,
    <-0.3435059, 0.9391505, 0.0002012>,
    <-0.3435059, 0.9391505, 0.0002012>,
    <-0.3436911, 0.9390827, 0.0002011>,
    <-0.3436910, 0.9390825, -0.0007474>,
    <-0.3436910, 0.9390825, -0.0007474>,
    <-0.3436906, 0.9390814, -0.0016958>,
    <-0.3435005, 0.9391525, -0.0000928>,
    <-0.3436906, 0.9390814, -0.0016958>,
    <-0.3436899, 0.9390795, -0.0026442>,
    <-0.3436899, 0.9390795, -0.0026442>,
    <-0.3436889, 0.9390767, -0.0035927>,
    <-0.3434997, 0.9391527, -0.0002323>,
    <-0.3434997, 0.9391527, -0.0002323>,
    <-0.3437494, 0.9389933, 0.0113102>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.9999858, -0.0053042, 0.0005427>,
    <0.9999858, -0.0053042, 0.0005272>,
    <0.9999857, -0.0053205, 0.0005272>,
    <0.9999857, -0.0053205, 0.0005427>,
    <0.9999857, -0.0053205, 0.0005582>,
    <0.9999858, -0.0053042, 0.0005582>,
    <0.9999858, -0.0053042, 0.0005582>,
    <0.9999859, -0.0052880, 0.0005582>,
    <0.9999859, -0.0052880, 0.0005427>,
    <0.9999859, -0.0052880, 0.0005427>,
    <0.9999859, -0.0052880, 0.0005272>,
    <0.9999858, -0.0053042, 0.0005117>,
    <0.9999857, -0.0053205, 0.0005117>,
    <0.9999859, -0.0052880, 0.0005272>,
    <0.9999859, -0.0052880, 0.0005117>,
    <0.9999859, -0.0052880, 0.0005117>,
    <0.9999859, -0.0052880, 0.0004963>,
    <0.9999858, -0.0053042, 0.0004963>,
    <0.9999858, -0.0053042, 0.0004963>,
    <0.9999857, -0.0053205, 0.0004963>,
    <0.9999856, -0.0053367, 0.0005117>,
    <0.9999856, -0.0053367, 0.0005272>,
    <0.9999857, -0.0053205, 0.0004963>,
    <0.9999856, -0.0053367, 0.0004962>,
    <0.9999856, -0.0053367, 0.0004962>,
    <0.9999855, -0.0053530, 0.0004962>,
    <0.9999855, -0.0053530, 0.0005117>,
    <0.9999855, -0.0053530, 0.0005117>,
    <0.9999855, -0.0053530, 0.0005272>,
    <0.9999856, -0.0053367, 0.0005427>,
    <0.9999855, -0.0053530, 0.0005272>,
    <0.9999855, -0.0053530, 0.0005427>,
    <0.9999855, -0.0053530, 0.0005427>,
    <0.9999855, -0.0053530, 0.0005582>,
    <0.9999856, -0.0053367, 0.0005582>,
    <0.9999856, -0.0053367, 0.0005582>,
    <0.9999857, -0.0053205, 0.0005582>,
    <-0.9854586, 0.0042136, -0.1698632>,
    <-0.9854591, 0.0045447, -0.1698520>,
    <-0.9862561, 0.0045484, -0.1651611>,
    <-0.9862541, 0.0042170, -0.1651822>,
    <-0.9862519, 0.0038870, -0.1652032>,
    <-0.9854581, 0.0038838, -0.1698744>,
    <-0.9854581, 0.0038838, -0.1698744>,
    <-0.9846435, 0.0038806, -0.1745342>,
    <-0.9846424, 0.0042101, -0.1745327>,
    <-0.9846424, 0.0042101, -0.1745327>,
    <-0.9846412, 0.0045409, -0.1745313>,
    <-0.9854595, 0.0048772, -0.1698406>,
    <-0.9862581, 0.0048812, -0.1651398>,
    <-0.9846412, 0.0045409, -0.1745313>,
    <-0.9846398, 0.0048732, -0.1745298>,
    <-0.9846398, 0.0048732, -0.1745298>,
    <-0.9846384, 0.0052068, -0.1745284>,
    <-0.9854597, 0.0052112, -0.1698292>,
    <-0.9854597, 0.0052112, -0.1698292>,
    <-0.9862599, 0.0052154, -0.1651185>,
    <-0.9870355, 0.0048850, -0.1604278>,
    <-0.9870320, 0.0045520, -0.1604590>,
    <-0.9862599, 0.0052154, -0.1651185>,
    <-0.9870389, 0.0052195, -0.1603964>,
    <-0.9870389, 0.0052195, -0.1603964>,
    <-0.9877964, 0.0052235, -0.1556633>,
    <-0.9877915, 0.0048888, -0.1557047>,
    <-0.9877915, 0.0048888, -0.1557047>,
    <-0.9877866, 0.0045554, -0.1557459>,
    <-0.9870284, 0.0042203, -0.1604900>,
    <-0.9877866, 0.0045554, -0.1557459>,
    <-0.9877817, 0.0042235, -0.1557869>,
    <-0.9877817, 0.0042235, -0.1557869>,
    <-0.9877766, 0.0038930, -0.1558277>,
    <-0.9870248, 0.0038900, -0.1605209>,
    <-0.9870248, 0.0038900, -0.1605209>,
    <-0.9862519, 0.0038870, -0.1652032>,
    <0.9999922, -0.0039402, 0.0000088>,
    <0.9999922, -0.0039402, 0.0000085>,
    <0.9999922, -0.0039405, 0.0000085>,
    <0.9999922, -0.0039405, 0.0000088>,
    <0.9999922, -0.0039405, 0.0000090>,
    <0.9999922, -0.0039402, 0.0000090>,
    <0.9999922, -0.0039402, 0.0000090>,
    <0.9999922, -0.0039398, 0.0000090>,
    <0.9999922, -0.0039398, 0.0000088>,
    <0.9999922, -0.0039398, 0.0000088>,
    <0.9999922, -0.0039398, 0.0000085>,
    <0.9999922, -0.0039402, 0.0000083>,
    <0.9999922, -0.0039405, 0.0000083>,
    <0.9999922, -0.0039398, 0.0000085>,
    <0.9999922, -0.0039398, 0.0000083>,
    <0.9999922, -0.0039398, 0.0000083>,
    <0.9999922, -0.0039398, 0.0000080>,
    <0.9999922, -0.0039402, 0.0000080>,
    <0.9999922, -0.0039402, 0.0000080>,
    <0.9999922, -0.0039405, 0.0000080>,
    <0.9999922, -0.0039408, 0.0000083>,
    <0.9999922, -0.0039408, 0.0000085>,
    <0.9999922, -0.0039405, 0.0000080>,
    <0.9999922, -0.0039408, 0.0000080>,
    <0.9999922, -0.0039408, 0.0000080>,
    <0.9999922, -0.0039411, 0.0000080>,
    <0.9999922, -0.0039411, 0.0000083>,
    <0.9999922, -0.0039411, 0.0000083>,
    <0.9999922, -0.0039411, 0.0000085>,
    <0.9999922, -0.0039408, 0.0000088>,
    <0.9999922, -0.0039411, 0.0000085>,
    <0.9999922, -0.0039411, 0.0000088>,
    <0.9999922, -0.0039411, 0.0000088>,
    <0.9999922, -0.0039411, 0.0000090>,
    <0.9999922, -0.0039408, 0.0000090>,
    <0.9999922, -0.0039408, 0.0000090>,
    <0.9999922, -0.0039405, 0.0000090>,
    <-0.9985825, 0.0037869, -0.0530916>,
    <-0.9985823, 0.0038360, -0.0530911>,
    <-0.9986607, 0.0038363, -0.0515947>,
    <-0.9986609, 0.0037872, -0.0515957>,
    <-0.9986610, 0.0037381, -0.0515966>,
    <-0.9985826, 0.0037379, -0.0530922>,
    <-0.9985826, 0.0037379, -0.0530922>,
    <-0.9985020, 0.0037375, -0.0545873>,
    <-0.9985018, 0.0037866, -0.0545872>,
    <-0.9985018, 0.0037866, -0.0545872>,
    <-0.9985016, 0.0038357, -0.0545872>,
    <-0.9985821, 0.0038851, -0.0530906>,
    <-0.9986606, 0.0038854, -0.0515937>,
    <-0.9985016, 0.0038357, -0.0545872>,
    <-0.9985015, 0.0038848, -0.0545871>,
    <-0.9985015, 0.0038848, -0.0545871>,
    <-0.9985013, 0.0039340, -0.0545870>,
    <-0.9985820, 0.0039343, -0.0530900>,
    <-0.9985820, 0.0039343, -0.0530900>,
    <-0.9986605, 0.0039346, -0.0515927>,
    <-0.9987368, 0.0038857, -0.0500964>,
    <-0.9987369, 0.0038366, -0.0500979>,
    <-0.9986605, 0.0039346, -0.0515927>,
    <-0.9987367, 0.0039349, -0.0500950>,
    <-0.9987367, 0.0039349, -0.0500950>,
    <-0.9988107, 0.0039352, -0.0485970>,
    <-0.9988108, 0.0038860, -0.0485989>,
    <-0.9988108, 0.0038860, -0.0485989>,
    <-0.9988109, 0.0038369, -0.0486008>,
    <-0.9987371, 0.0037875, -0.0500993>,
    <-0.9988109, 0.0038369, -0.0486008>,
    <-0.9988110, 0.0037878, -0.0486027>,
    <-0.9988110, 0.0037878, -0.0486027>,
    <-0.9988111, 0.0037387, -0.0486046>,
    <-0.9987372, 0.0037384, -0.0501008>,
    <-0.9987372, 0.0037384, -0.0501008>,
    <-0.9986610, 0.0037381, -0.0515966>,
    <0.9999276, -0.0032544, 0.0115811>,
    <0.9999358, -0.0034415, 0.0107958>,
    <0.9999240, -0.0035381, 0.0118089>,
    <0.9999178, -0.0034929, 0.0123358>,
    <0.9999097, -0.0034849, 0.0129794>,
    <0.9999106, -0.0032244, 0.0129795>,
    <0.9999106, -0.0032244, 0.0129795>,
    <0.9999646, -0.0024797, 0.0080458>,
    <0.9999654, -0.0028107, 0.0078261>,
    <0.9999654, -0.0033789, 0.0076047>,
    <0.9999348, -0.0036391, 0.0108258>,
    <0.9999265, -0.0035893, 0.0115841>,
    <0.9999650, -0.0039259, 0.0073818>,
    <0.9999653, -0.0042642, 0.0071586>,
    <0.9999264, -0.0036959, 0.0115539>,
    <0.9999264, -0.0036959, 0.0115539>,
    <0.9999267, -0.0036067, 0.0115547>,
    <0.9999233, -0.0036465, 0.0118321>,
    <0.9999195, -0.0036404, 0.0121589>,
    <0.9999267, -0.0036067, 0.0115547>,
    <0.9999266, -0.0036490, 0.0115543>,
    <0.9999266, -0.0036490, 0.0115543>,
    <0.9999263, -0.0037429, 0.0115535>,
    <0.9999221, -0.0037429, 0.0119099>,
    <0.9999221, -0.0037429, 0.0119099>,
    <0.9999178, -0.0037428, 0.0122664>,
    <0.9999146, -0.0036349, 0.0125541>,
    <0.9999178, -0.0037428, 0.0122664>,
    <0.9999133, -0.0037428, 0.0126229>,
    <0.9999133, -0.0037428, 0.0126229>,
    <0.9999088, -0.0037428, 0.0129793>,
    <0.9999092, -0.0036337, 0.0129794>,
    <0.9999092, -0.0036337, 0.0129794>,
    <0.9999097, -0.0034849, 0.0129794>,
    <0.9999849, -0.0027128, -0.0047826>,
    <0.9997493, -0.0030727, -0.0221785>,
    <0.9998697, -0.0033997, -0.0157798>,
    <0.9999940, -0.0033727, -0.0008490>,
    <0.9999646, -0.0024797, 0.0080458>,
    <0.9989183, -0.0006460, -0.0464959>,
    <0.9989183, -0.0006460, -0.0464959>,
    <0.9989149, -0.0026967, -0.0464937>,
    <0.9992988, -0.0033746, -0.0372896>,
    <0.9994410, -0.0034314, -0.0332538>,
    <0.9989149, -0.0026967, -0.0464937>,
    <0.9989130, -0.0033421, -0.0464930>,
    <0.9989130, -0.0033421, -0.0464930>,
    <0.9989126, -0.0034626, -0.0464929>,
    <0.9989710, -0.0034628, -0.0452206>,
    <0.9989710, -0.0034628, -0.0452206>,
    <0.9990278, -0.0034630, -0.0439482>,
    <0.9993791, -0.0034851, -0.0350620>,
    <0.9997818, -0.0037128, -0.0205559>,
    <0.9990278, -0.0034630, -0.0439482>,
    <0.9990830, -0.0034632, -0.0426755>,
    <0.9990830, -0.0034632, -0.0426755>,
    <0.9991365, -0.0034634, -0.0414027>,
    <0.9991364, -0.0035109, -0.0414011>,
    <0.9991364, -0.0035109, -0.0414011>,
    <0.9991352, -0.0040414, -0.0413835>,
    <0.9999833, -0.0040033, -0.0041727>,
    <0.9991352, -0.0040414, -0.0413835>,
    <0.9991287, -0.0058511, -0.0413234>,
    <0.9991287, -0.0058511, -0.0413234>,
    <0.9999653, -0.0042642, 0.0071586>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9514469>,
    <0.4350651, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289899, 0.9514833>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9514469>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6558680, 0.9657316>,
    <0.6289899, 0.9514833>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4350651, 0.9657316>,
    <0.5000060, 0.9664308>,
    <0.4264138, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379435, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664308>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6558680, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773611, 0.9671308>,
    <0.6379435, 0.9664312>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4264138, 0.9671308>,
    <0.5000061, 0.9783560>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473388, 0.9783062>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9783560>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773611, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473388, 0.9783062>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032661, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458873>,
    <0.4677608, 0.9457659>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9514469>,
    <0.4355157, 0.9458873>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9453040>,
    <0.4677604, 0.9520314>,
    <0.4676476, 0.9588815>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9514469>,
    <0.5000059, 0.9657316>,
    <0.4350651, 0.9657316>,
    <0.4677604, 0.9520314>,
    <0.5000059, 0.9584281>,
    <0.4675322, 0.9657316>,
    <0.4353104, 0.9585559>,
    <0.4031531, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4350651, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4353104, 0.9585559>,
    <0.4024494, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032661, 0.9526160>,
    <0.5322510, 0.9457659>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9514469>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9520314>,
    <0.5000059, 0.9453040>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458724>,
    <0.5967411, 0.9457750>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289899, 0.9514833>,
    <0.5644961, 0.9458724>,
    <0.5967380, 0.9395004>,
    <0.6289859, 0.9453225>,
    <0.5967441, 0.9520496>,
    <0.5967475, 0.9588906>,
    <0.5644983, 0.9526160>,
    <0.6289899, 0.9514833>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967441, 0.9520496>,
    <0.6289945, 0.9584819>,
    <0.5967509, 0.9657316>,
    <0.5645004, 0.9590395>,
    <0.5322532, 0.9588815>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9514469>,
    <0.5645004, 0.9590395>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9584281>,
    <0.5322521, 0.9520314>,
    <0.6423395, 0.9457750>,
    <0.6556982, 0.9526160>,
    <0.6289899, 0.9514833>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423437, 0.9520496>,
    <0.6289859, 0.9453225>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458875>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458875>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690524, 0.9526160>,
    <0.6690975, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6558680, 0.9657316>,
    <0.6690524, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6693589, 0.9657316>,
    <0.6557753, 0.9585675>,
    <0.6423888, 0.9588906>,
    <0.6556982, 0.9526160>,
    <0.6558680, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289899, 0.9514833>,
    <0.6557753, 0.9585675>,
    <0.6424344, 0.9657316>,
    <0.6289945, 0.9584819>,
    <0.6423437, 0.9520496>,
    <0.3997957, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4350651, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4024494, 0.9657316>,
    <0.4330699, 0.9660781>,
    <0.4665285, 0.9660813>,
    <0.4310370, 0.9664312>,
    <0.4350651, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664308>,
    <0.4330699, 0.9660781>,
    <0.4675322, 0.9657316>,
    <0.5000060, 0.9661017>,
    <0.4655215, 0.9664310>,
    <0.4643657, 0.9667809>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664308>,
    <0.5000061, 0.9671308>,
    <0.4264138, 0.9671308>,
    <0.4655215, 0.9664310>,
    <0.5000060, 0.9667580>,
    <0.4632045, 0.9671308>,
    <0.4287683, 0.9667745>,
    <0.3931605, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4264138, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4287683, 0.9667745>,
    <0.3895841, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660813>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664308>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664310>,
    <0.5000060, 0.9661017>,
    <0.5322542, 0.9657316>,
    <0.5668714, 0.9661021>,
    <0.6001051, 0.9660814>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379435, 0.9664312>,
    <0.5668714, 0.9661021>,
    <0.5967509, 0.9657316>,
    <0.6337414, 0.9661025>,
    <0.6034593, 0.9664312>,
    <0.6068137, 0.9667810>,
    <0.5689750, 0.9664312>,
    <0.6379435, 0.9664312>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034593, 0.9664312>,
    <0.6421204, 0.9667579>,
    <0.6101681, 0.9671308>,
    <0.5710646, 0.9667581>,
    <0.5356086, 0.9667809>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664308>,
    <0.5710646, 0.9667581>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667580>,
    <0.5344905, 0.9664310>,
    <0.6473290, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6379435, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6558680, 0.9657316>,
    <0.6522245, 0.9664312>,
    <0.6337414, 0.9661025>,
    <0.6424344, 0.9657316>,
    <0.6611598, 0.9660796>,
    <0.6749645, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6558680, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6611598, 0.9660796>,
    <0.6693589, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866623, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773611, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926092, 0.9671308>,
    <0.6718162, 0.9667735>,
    <0.6571747, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6773611, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379435, 0.9664312>,
    <0.6718162, 0.9667735>,
    <0.6621272, 0.9671308>,
    <0.6421204, 0.9667579>,
    <0.6522245, 0.9664312>,
    <0.3896458, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4264138, 0.9671308>,
    <0.3895222, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3895841, 0.9671308>,
    <0.4263799, 0.9728535>,
    <0.4631942, 0.9725944>,
    <0.4263507, 0.9777601>,
    <0.4264138, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9783560>,
    <0.4263799, 0.9728535>,
    <0.4632045, 0.9671308>,
    <0.5000061, 0.9726513>,
    <0.4631779, 0.9780581>,
    <0.4631249, 0.9832238>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9783560>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631779, 0.9780581>,
    <0.5000061, 0.9834929>,
    <0.4630714, 0.9883895>,
    <0.4262411, 0.9832062>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262411, 0.9832062>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895222, 0.9777601>,
    <0.5367803, 0.9725944>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9783560>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9780581>,
    <0.5000061, 0.9726513>,
    <0.5367268, 0.9671308>,
    <0.5735524, 0.9723450>,
    <0.6103341, 0.9725820>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473388, 0.9783062>,
    <0.5735524, 0.9723450>,
    <0.6101681, 0.9671308>,
    <0.6471088, 0.9725940>,
    <0.6105001, 0.9780332>,
    <0.6106551, 0.9832113>,
    <0.5736614, 0.9777601>,
    <0.6473388, 0.9783062>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105001, 0.9780332>,
    <0.6475465, 0.9834662>,
    <0.6108101, 0.9883895>,
    <0.5737710, 0.9832010>,
    <0.5368873, 0.9832238>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9783560>,
    <0.5737710, 0.9832010>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9834929>,
    <0.5368338, 0.9780581>,
    <0.6623519, 0.9725820>,
    <0.6778190, 0.9777601>,
    <0.6473388, 0.9783062>,
    <0.6468888, 0.9671308>,
    <0.6773611, 0.9671308>,
    <0.6625791, 0.9780332>,
    <0.6471088, 0.9725940>,
    <0.6621272, 0.9671308>,
    <0.6776070, 0.9728395>,
    <0.6928043, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773611, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776070, 0.9728395>,
    <0.6926092, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930704, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930704, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780836, 0.9832055>,
    <0.6628095, 0.9832113>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473388, 0.9783062>,
    <0.6780836, 0.9832055>,
    <0.6630402, 0.9883895>,
    <0.6475465, 0.9834662>,
    <0.6625791, 0.9780332>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.046223, 0.731795, -0.147353>
}

#declare TMesh011 = mesh2 {
  vertex_vectors {
    582,
    <2.2037408, 0.3609944, 18.5058918>,
    <2.0021506, 0.3609820, 18.5058918>,
    <2.0021672, 0.2806104, 18.5058918>,
    <2.2037549, 0.2806255, 18.5058918>,
    <2.1029457, 0.3609882, 18.5058918>,
    <2.0021589, 0.3207962, 18.5058918>,
    <2.1029610, 0.2806180, 18.5058918>,
    <2.2037479, 0.3208099, 18.5058918>,
    <2.1029534, 0.3208031, 18.5058918>,
    <2.4053426, 0.2806405, 18.5058918>,
    <2.4053311, 0.3610067, 18.5058918>,
    <2.3045487, 0.2806330, 18.5058918>,
    <2.4053368, 0.3208236, 18.5058918>,
    <2.3045360, 0.3610006, 18.5058918>,
    <2.3045424, 0.3208168, 18.5058918>,
    <2.4053196, 0.4413729, 18.5058918>,
    <2.2037268, 0.4413633, 18.5058918>,
    <2.4053254, 0.4011898, 18.5058918>,
    <2.3045232, 0.4413681, 18.5058918>,
    <2.2037338, 0.4011788, 18.5058918>,
    <2.3045296, 0.4011843, 18.5058918>,
    <2.0021340, 0.4413536, 18.5058918>,
    <2.1029304, 0.4413585, 18.5058918>,
    <2.0021423, 0.4011678, 18.5058918>,
    <2.1029381, 0.4011733, 18.5058918>,
    <2.0661631, 0.2804708, 18.1207908>,
    <2.0044034, 0.2804603, 18.1202395>,
    <2.0044687, 0.2804559, 18.1217627>,
    <2.0559641, 0.2804663, 18.1217627>,
    <2.0352833, 0.2804656, 18.1205151>,
    <2.0044361, 0.2804581, 18.1210011>,
    <2.0302164, 0.2804611, 18.1217627>,
    <2.0610636, 0.2804686, 18.1212767>,
    <2.0327498, 0.2804633, 18.1211389>,
    <2.1074595, 0.2804767, 18.1217627>,
    <2.1279227, 0.2804813, 18.1213420>,
    <2.0817118, 0.2804715, 18.1217627>,
    <2.1176911, 0.2804790, 18.1215524>,
    <2.0970429, 0.2804761, 18.1210664>,
    <2.0893774, 0.2804738, 18.1214145>,
    <2.1483859, 0.2804860, 18.1209214>,
    <2.0763621, 0.2804753, 18.1198188>,
    <2.1381543, 0.2804837, 18.1211317>,
    <2.1123740, 0.2804807, 18.1203701>,
    <2.0712626, 0.2804731, 18.1203048>,
    <2.1047085, 0.2804784, 18.1207182>,
    <2.0043382, 0.2804647, 18.1187163>,
    <2.0403501, 0.2804700, 18.1192675>,
    <2.0043708, 0.2804625, 18.1194779>,
    <2.0378167, 0.2804678, 18.1198913>,
    <2.1279101, 0.3610088, 18.1213420>,
    <2.1074469, 0.3610088, 18.1217627>,
    <2.1279164, 0.3207451, 18.1213420>,
    <2.1074532, 0.3207428, 18.1217627>,
    <2.1176785, 0.3610088, 18.1215524>,
    <2.1176848, 0.3207439, 18.1215524>,
    <2.1074342, 0.4415410, 18.1217627>,
    <2.1278975, 0.4415362, 18.1213420>,
    <2.1074405, 0.4012749, 18.1217627>,
    <2.1176659, 0.4415386, 18.1215524>,
    <2.1279038, 0.4012725, 18.1213420>,
    <2.1176722, 0.4012737, 18.1215524>,
    <2.1483608, 0.4415314, 18.1209214>,
    <2.1483734, 0.3610087, 18.1209214>,
    <2.1381291, 0.4415338, 18.1211317>,
    <2.1483671, 0.4012701, 18.1209214>,
    <2.1381417, 0.3610087, 18.1211317>,
    <2.1381354, 0.4012713, 18.1211317>,
    <2.1483797, 0.3207473, 18.1209214>,
    <2.1381480, 0.3207462, 18.1211317>,
    <2.0661338, 0.4415300, 18.1207908>,
    <2.0559348, 0.4415349, 18.1217627>,
    <2.0970156, 0.4415331, 18.1210664>,
    <2.0816845, 0.4415379, 18.1217627>,
    <2.0610343, 0.4415324, 18.1212767>,
    <2.0893501, 0.4415355, 18.1214145>,
    <2.0044353, 0.4415288, 18.1217627>,
    <2.0043701, 0.4415238, 18.1202395>,
    <2.0301850, 0.4415318, 18.1217627>,
    <2.0044027, 0.4415263, 18.1210011>,
    <2.0352519, 0.4415269, 18.1205151>,
    <2.0327185, 0.4415294, 18.1211389>,
    <2.0043048, 0.4415189, 18.1187163>,
    <2.0763328, 0.4415251, 18.1198188>,
    <2.0043374, 0.4415214, 18.1194779>,
    <2.0403188, 0.4415220, 18.1192675>,
    <2.0712333, 0.4415276, 18.1203048>,
    <2.0377853, 0.4415245, 18.1198913>,
    <2.1123468, 0.4415283, 18.1203701>,
    <2.1046812, 0.4415307, 18.1207182>,
    <2.0763690, 0.2804848, 18.1376413>,
    <2.0042020, 0.2804738, 18.1370901>,
    <2.0402855, 0.2804793, 18.1373657>,
    <2.0042701, 0.2804693, 18.1279032>,
    <2.0763655, 0.2804801, 18.1287301>,
    <2.0403178, 0.2804747, 18.1283166>,
    <2.1485360, 0.2804957, 18.1381926>,
    <2.1484610, 0.2804908, 18.1295570>,
    <2.1124525, 0.2804902, 18.1379170>,
    <2.1124133, 0.2804854, 18.1291435>,
    <2.1486861, 0.2805054, 18.1554639>,
    <2.0763760, 0.2804942, 18.1554639>,
    <2.1486111, 0.2805005, 18.1468283>,
    <2.1125311, 0.2804998, 18.1554639>,
    <2.0763725, 0.2804895, 18.1465526>,
    <2.1124918, 0.2804950, 18.1466904>,
    <2.0040659, 0.2804830, 18.1554639>,
    <2.0402210, 0.2804886, 18.1554639>,
    <2.0041340, 0.2804784, 18.1462770>,
    <2.0402533, 0.2804839, 18.1464148>,
    <2.1485235, 0.3610086, 18.1381926>,
    <2.1485298, 0.3207521, 18.1381926>,
    <2.1484484, 0.3610086, 18.1295570>,
    <2.1484547, 0.3207497, 18.1295570>,
    <2.1485110, 0.4415215, 18.1381926>,
    <2.1484359, 0.4415265, 18.1295570>,
    <2.1485173, 0.4012650, 18.1381926>,
    <2.1484422, 0.4012676, 18.1295570>,
    <2.1486612, 0.4415115, 18.1554639>,
    <2.1486737, 0.3610085, 18.1554639>,
    <2.1485861, 0.4415165, 18.1468283>,
    <2.1486675, 0.4012600, 18.1554639>,
    <2.1485986, 0.3610085, 18.1468283>,
    <2.1485924, 0.4012625, 18.1468283>,
    <2.1486799, 0.3207569, 18.1554639>,
    <2.1486048, 0.3207545, 18.1468283>,
    <2.0763398, 0.4415150, 18.1376413>,
    <2.1124254, 0.4415182, 18.1379170>,
    <2.0763363, 0.4415201, 18.1287301>,
    <2.1123861, 0.4415233, 18.1291435>,
    <2.0041687, 0.4415085, 18.1370901>,
    <2.0042367, 0.4415137, 18.1279032>,
    <2.0402543, 0.4415118, 18.1373657>,
    <2.0402865, 0.4415169, 18.1283166>,
    <2.0040326, 0.4414981, 18.1554639>,
    <2.0763469, 0.4415048, 18.1554639>,
    <2.0041006, 0.4415033, 18.1462770>,
    <2.0401897, 0.4415015, 18.1554639>,
    <2.0763434, 0.4415099, 18.1465526>,
    <2.0402220, 0.4415066, 18.1464148>,
    <2.1125041, 0.4415082, 18.1554639>,
    <2.1124647, 0.4415132, 18.1466904>,
    <2.0812641, 0.2805008, 18.1573801>,
    <2.0039695, 0.2804894, 18.1573801>,
    <2.0426168, 0.2804951, 18.1573801>,
    <2.0040177, 0.2804862, 18.1564220>,
    <2.0788201, 0.2804975, 18.1564220>,
    <2.0414189, 0.2804919, 18.1564220>,
    <2.1585588, 0.2805122, 18.1573801>,
    <2.1536225, 0.2805088, 18.1564220>,
    <2.1199115, 0.2805065, 18.1573801>,
    <2.1162213, 0.2805032, 18.1564220>,
    <2.1684314, 0.2805191, 18.1592964>,
    <2.0861522, 0.2805075, 18.1592964>,
    <2.1634951, 0.2805157, 18.1583383>,
    <2.1272918, 0.2805133, 18.1592964>,
    <2.0837082, 0.2805042, 18.1583383>,
    <2.1236016, 0.2805099, 18.1583383>,
    <2.0038730, 0.2804959, 18.1592964>,
    <2.0450126, 0.2805017, 18.1592964>,
    <2.0039212, 0.2804927, 18.1583383>,
    <2.0438147, 0.2804984, 18.1583383>,
    <2.1585464, 0.3610084, 18.1573801>,
    <2.1585526, 0.3207603, 18.1573801>,
    <2.1536100, 0.3610084, 18.1564220>,
    <2.1536162, 0.3207586, 18.1564220>,
    <2.1585340, 0.4415045, 18.1573801>,
    <2.1535976, 0.4415080, 18.1564220>,
    <2.1585402, 0.4012564, 18.1573801>,
    <2.1536038, 0.4012582, 18.1564220>,
    <2.1684068, 0.4414975, 18.1592964>,
    <2.1684191, 0.3610083, 18.1592964>,
    <2.1634704, 0.4415010, 18.1583383>,
    <2.1684129, 0.4012529, 18.1592964>,
    <2.1634827, 0.3610083, 18.1583383>,
    <2.1634766, 0.4012547, 18.1583383>,
    <2.1684253, 0.3207637, 18.1592964>,
    <2.1634889, 0.3207620, 18.1583383>,
    <2.0812351, 0.4414977, 18.1573801>,
    <2.1198845, 0.4415011, 18.1573801>,
    <2.0787910, 0.4415013, 18.1564220>,
    <2.1161943, 0.4415046, 18.1564220>,
    <2.0039361, 0.4414908, 18.1573801>,
    <2.0039844, 0.4414945, 18.1564220>,
    <2.0425856, 0.4414942, 18.1573801>,
    <2.0413877, 0.4414979, 18.1564220>,
    <2.0038397, 0.4414835, 18.1592964>,
    <2.0861232, 0.4414905, 18.1592964>,
    <2.0038879, 0.4414871, 18.1583383>,
    <2.0449814, 0.4414870, 18.1592964>,
    <2.0836791, 0.4414941, 18.1583383>,
    <2.0437835, 0.4414906, 18.1583383>,
    <2.1272650, 0.4414940, 18.1592964>,
    <2.1235748, 0.4414975, 18.1583383>,
    <2.0877082, 0.2805088, 18.2324892>,
    <2.0038724, 0.2804960, 18.2344341>,
    <2.0457890, 0.2805025, 18.2333227>,
    <2.0038727, 0.2804959, 18.1968653>,
    <2.0861681, 0.2805075, 18.1968653>,
    <2.0450204, 0.2805017, 18.1968653>,
    <2.1715593, 0.2805206, 18.2322113>,
    <2.1684634, 0.2805191, 18.1968653>,
    <2.1296325, 0.2805148, 18.2322113>,
    <2.1273157, 0.2805133, 18.1968653>,
    <2.1991981, 0.2805337, 18.2873438>,
    <2.1014482, 0.2805207, 18.2890109>,
    <2.1807829, 0.2805250, 18.2631118>,
    <2.1503155, 0.2805277, 18.2873438>,
    <2.0922969, 0.2805125, 18.2642232>,
    <2.1365348, 0.2805191, 18.2631118>,
    <2.0038718, 0.2804960, 18.3095719>,
    <2.0526115, 0.2805116, 18.2940122>,
    <2.0038721, 0.2804960, 18.2720030>,
    <2.0480794, 0.2805046, 18.2675574>,
    <2.1715469, 0.3610083, 18.2322113>,
    <2.1715531, 0.3207644, 18.2322113>,
    <2.1684511, 0.3610083, 18.1968653>,
    <2.1684573, 0.3207637, 18.1968653>,
    <2.1715346, 0.4414959, 18.2322113>,
    <2.1684387, 0.4414974, 18.1968653>,
    <2.1715408, 0.4012521, 18.2322113>,
    <2.1684449, 0.4012529, 18.1968653>,
    <2.1991737, 0.4414825, 18.2873438>,
    <2.1991859, 0.3610081, 18.2873438>,
    <2.1807583, 0.4414914, 18.2631118>,
    <2.1991798, 0.4012453, 18.2873438>,
    <2.1807706, 0.3610082, 18.2631118>,
    <2.1807644, 0.4012498, 18.2631118>,
    <2.1991920, 0.3207709, 18.2873438>,
    <2.1807767, 0.3207666, 18.2631118>,
    <2.0876792, 0.4414891, 18.2324892>,
    <2.1296056, 0.4414924, 18.2322113>,
    <2.0861391, 0.4414904, 18.1968653>,
    <2.1272889, 0.4414939, 18.1968653>,
    <2.0038391, 0.4414834, 18.2344341>,
    <2.0038394, 0.4414834, 18.1968653>,
    <2.0457578, 0.4414862, 18.2333227>,
    <2.0449892, 0.4414869, 18.1968653>,
    <2.0038384, 0.4414834, 18.3095719>,
    <2.1014193, 0.4414763, 18.2890109>,
    <2.0038387, 0.4414834, 18.2720030>,
    <2.0525804, 0.4414761, 18.2940122>,
    <2.0922679, 0.4414851, 18.2642232>,
    <2.0480482, 0.4414838, 18.2675574>,
    <2.1502888, 0.4414788, 18.2873438>,
    <2.1365080, 0.4414879, 18.2631118>,
    <2.1349912, 0.2805529, 18.3131904>,
    <2.0032176, 0.2805399, 18.3135798>,
    <2.0691044, 0.2805464, 18.3133573>,
    <2.0035447, 0.2805180, 18.3115759>,
    <2.1166762, 0.2805352, 18.3037960>,
    <2.0601053, 0.2805269, 18.3071303>,
    <2.2667655, 0.2805658, 18.3131347>,
    <2.2298689, 0.2805483, 18.3026846>,
    <2.2008783, 0.2805594, 18.3131347>,
    <2.1732674, 0.2805421, 18.3026846>,
    <2.3351178, 0.2805985, 18.3353648>,
    <2.1689234, 0.2805856, 18.3340315>,
    <2.3038584, 0.2805835, 18.3226946>,
    <2.2520279, 0.2805915, 18.3353648>,
    <2.1534037, 0.2805707, 18.3218058>,
    <2.2286359, 0.2805768, 18.3226946>,
    <2.0025635, 0.2805838, 18.3175878>,
    <2.0857897, 0.2805816, 18.3300317>,
    <2.0028906, 0.2805619, 18.3155838>,
    <2.0781520, 0.2805660, 18.3191392>,
    <2.2667535, 0.3610077, 18.3131347>,
    <2.2667595, 0.3207868, 18.3131347>,
    <2.2298568, 0.3610079, 18.3026846>,
    <2.2298628, 0.3207781, 18.3026846>,
    <2.2667415, 0.4414495, 18.3131347>,
    <2.2298446, 0.4414675, 18.3026846>,
    <2.2667475, 0.4012286, 18.3131347>,
    <2.2298507, 0.4012377, 18.3026846>,
    <2.3350943, 0.4414161, 18.3353648>,
    <2.3351060, 0.3610073, 18.3353648>,
    <2.3038346, 0.4414314, 18.3226946>,
    <2.3351001, 0.4012117, 18.3353648>,
    <2.3038465, 0.3610075, 18.3226946>,
    <2.3038406, 0.4012194, 18.3226946>,
    <2.3351119, 0.3208029, 18.3353648>,
    <2.3038524, 0.3207955, 18.3226946>,
    <2.1349626, 0.4414415, 18.3131904>,
    <2.2008520, 0.4414455, 18.3131347>,
    <2.1166474, 0.4414607, 18.3037960>,
    <2.1732409, 0.4414637, 18.3026846>,
    <2.0031844, 0.4414336, 18.3135798>,
    <2.0035114, 0.4414585, 18.3115759>,
    <2.0690734, 0.4414376, 18.3133573>,
    <2.0600743, 0.4414592, 18.3071303>,
    <2.0025303, 0.4413838, 18.3175878>,
    <2.1688950, 0.4414062, 18.3340315>,
    <2.0028573, 0.4414087, 18.3155838>,
    <2.0857589, 0.4413985, 18.3300317>,
    <2.1533752, 0.4414223, 18.3218058>,
    <2.0781211, 0.4414159, 18.3191392>,
    <2.2520019, 0.4414117, 18.3353648>,
    <2.2286098, 0.4414272, 18.3226946>,
    <2.1837800, 0.2805991, 18.3800376>,
    <2.0025322, 0.2805859, 18.3784821>,
    <2.0931573, 0.2805924, 18.3793709>,
    <2.0025479, 0.2805849, 18.3480349>,
    <2.1785602, 0.2805944, 18.3542569>,
    <2.0905589, 0.2805893, 18.3515903>,
    <2.3650132, 0.2806132, 18.3802598>,
    <2.3545142, 0.2806079, 18.3551457>,
    <2.2743978, 0.2806060, 18.3802598>,
    <2.2665420, 0.2806008, 18.3551457>,
    <2.3711824, 0.2806168, 18.4393764>,
    <2.1868417, 0.2806024, 18.4393764>,
    <2.3695807, 0.2806157, 18.4089292>,
    <2.2790121, 0.2806096, 18.4393764>,
    <2.1860486, 0.2806013, 18.4089292>,
    <2.2778147, 0.2806085, 18.4089292>,
    <2.0025009, 0.2805880, 18.4393764>,
    <2.0946713, 0.2805952, 18.4393764>,
    <2.0025166, 0.2805870, 18.4089292>,
    <2.0942826, 0.2805942, 18.4089292>,
    <2.3650015, 0.3610071, 18.3802598>,
    <2.3650074, 0.3208101, 18.3802598>,
    <2.3545024, 0.3610071, 18.3551457>,
    <2.3545083, 0.3208075, 18.3551457>,
    <2.3649899, 0.4414010, 18.3802598>,
    <2.3544907, 0.4414064, 18.3551457>,
    <2.3649957, 0.4012040, 18.3802598>,
    <2.3544966, 0.4012068, 18.3551457>,
    <2.3711592, 0.4413973, 18.4393764>,
    <2.3711708, 0.3610070, 18.4393764>,
    <2.3695574, 0.4413984, 18.4089292>,
    <2.3711650, 0.4012022, 18.4393764>,
    <2.3695691, 0.3610070, 18.4089292>,
    <2.3695632, 0.4012027, 18.4089292>,
    <2.3711766, 0.3208119, 18.4393764>,
    <2.3695749, 0.3208114, 18.4089292>,
    <2.1837517, 0.4413918, 18.3800376>,
    <2.2743720, 0.4413965, 18.3802598>,
    <2.1785319, 0.4413967, 18.3542569>,
    <2.2665162, 0.4414019, 18.3551457>,
    <2.0024990, 0.4413814, 18.3784821>,
    <2.0025147, 0.4413826, 18.3480349>,
    <2.0931266, 0.4413867, 18.3793709>,
    <2.0905281, 0.4413900, 18.3515903>,
    <2.0024677, 0.4413790, 18.4393764>,
    <2.1868134, 0.4413882, 18.4393764>,
    <2.0024834, 0.4413802, 18.4089292>,
    <2.0946406, 0.4413836, 18.4393764>,
    <2.1860204, 0.4413893, 18.4089292>,
    <2.0942519, 0.4413848, 18.4089292>,
    <2.2789863, 0.4413927, 18.4393764>,
    <2.2777889, 0.4413939, 18.4089292>,
    <2.1952983, 0.2806139, 18.4393764>,
    <2.0023340, 0.2805992, 18.4393764>,
    <2.0988161, 0.2806066, 18.4393764>,
    <2.0024175, 0.2805936, 18.4393764>,
    <2.1910700, 0.2806082, 18.4393764>,
    <2.0967437, 0.2806009, 18.4393764>,
    <2.3882625, 0.2806287, 18.4393764>,
    <2.3797225, 0.2806227, 18.4393764>,
    <2.2917804, 0.2806213, 18.4393764>,
    <2.2853962, 0.2806154, 18.4393764>,
    <2.4053426, 0.2806405, 18.4393764>,
    <2.2037549, 0.2806255, 18.4393764>,
    <2.3968025, 0.2806346, 18.4393764>,
    <2.3045487, 0.2806330, 18.4393764>,
    <2.1995266, 0.2806197, 18.4393764>,
    <2.2981646, 0.2806272, 18.4393764>,
    <2.0021672, 0.2806104, 18.4393764>,
    <2.1029610, 0.2806180, 18.4393764>,
    <2.0022506, 0.2806048, 18.4393764>,
    <2.1008886, 0.2806123, 18.4393764>,
    <2.3882510, 0.3610069, 18.4393764>,
    <2.3882567, 0.3208178, 18.4393764>,
    <2.3797109, 0.3610070, 18.4393764>,
    <2.3797167, 0.3208148, 18.4393764>,
    <2.3882394, 0.4413851, 18.4393764>,
    <2.3796993, 0.4413912, 18.4393764>,
    <2.3882452, 0.4011960, 18.4393764>,
    <2.3797051, 0.4011991, 18.4393764>,
    <2.4053196, 0.4413729, 18.4393764>,
    <2.4053311, 0.3610067, 18.4393764>,
    <2.3967795, 0.4413790, 18.4393764>,
    <2.4053254, 0.4011898, 18.4393764>,
    <2.3967910, 0.3610068, 18.4393764>,
    <2.3967853, 0.4011929, 18.4393764>,
    <2.4053368, 0.3208236, 18.4393764>,
    <2.3967968, 0.3208207, 18.4393764>,
    <2.1952701, 0.4413757, 18.4393764>,
    <2.2917548, 0.4413804, 18.4393764>,
    <2.1910418, 0.4413819, 18.4393764>,
    <2.2853705, 0.4413866, 18.4393764>,
    <2.0023009, 0.4413663, 18.4393764>,
    <2.0023843, 0.4413727, 18.4393764>,
    <2.0987855, 0.4413710, 18.4393764>,
    <2.0967130, 0.4413773, 18.4393764>,
    <2.0021340, 0.4413536, 18.4393764>,
    <2.2037268, 0.4413633, 18.4393764>,
    <2.0022174, 0.4413600, 18.4393764>,
    <2.1029304, 0.4413585, 18.4393764>,
    <2.1994985, 0.4413695, 18.4393764>,
    <2.1008580, 0.4413647, 18.4393764>,
    <2.3045232, 0.4413681, 18.4393764>,
    <2.2981390, 0.4413742, 18.4393764>,
    <2.2037549, 0.2806255, 18.4726341>,
    <2.0021672, 0.2806104, 18.4726341>,
    <2.1029610, 0.2806180, 18.4726341>,
    <2.0021672, 0.2806104, 18.4560052>,
    <2.2037549, 0.2806255, 18.4560052>,
    <2.1029610, 0.2806180, 18.4560052>,
    <2.4053426, 0.2806405, 18.4726341>,
    <2.4053426, 0.2806405, 18.4560052>,
    <2.3045487, 0.2806330, 18.4726341>,
    <2.3045487, 0.2806330, 18.4560052>,
    <2.4053426, 0.2806405, 18.4892630>,
    <2.2037549, 0.2806255, 18.4892630>,
    <2.3045487, 0.2806330, 18.4892630>,
    <2.0021672, 0.2806104, 18.4892630>,
    <2.1029610, 0.2806180, 18.4892630>,
    <2.4053311, 0.3610067, 18.4726341>,
    <2.4053368, 0.3208236, 18.4726341>,
    <2.4053311, 0.3610067, 18.4560052>,
    <2.4053368, 0.3208236, 18.4560052>,
    <2.4053196, 0.4413729, 18.4726341>,
    <2.4053196, 0.4413729, 18.4560052>,
    <2.4053254, 0.4011898, 18.4726341>,
    <2.4053254, 0.4011898, 18.4560052>,
    <2.4053196, 0.4413729, 18.4892630>,
    <2.4053311, 0.3610067, 18.4892630>,
    <2.4053254, 0.4011898, 18.4892630>,
    <2.4053368, 0.3208236, 18.4892630>,
    <2.2037268, 0.4413633, 18.4726341>,
    <2.3045232, 0.4413681, 18.4726341>,
    <2.2037268, 0.4413633, 18.4560052>,
    <2.3045232, 0.4413681, 18.4560052>,
    <2.0021340, 0.4413536, 18.4726341>,
    <2.0021340, 0.4413536, 18.4560052>,
    <2.1029304, 0.4413585, 18.4726341>,
    <2.1029304, 0.4413585, 18.4560052>,
    <2.0021340, 0.4413536, 18.4892630>,
    <2.2037268, 0.4413633, 18.4892630>,
    <2.1029304, 0.4413585, 18.4892630>,
    <2.3045232, 0.4413681, 18.4892630>,
    <2.0021506, 0.3609820, 18.4726341>,
    <2.0021672, 0.2806104, 18.4726341>,
    <2.0021506, 0.3609820, 18.4393764>,
    <2.0021589, 0.3207962, 18.4726341>,
    <2.0021672, 0.2806104, 18.4560052>,
    <2.0021589, 0.3207962, 18.4393764>,
    <2.0021506, 0.3609820, 18.4560052>,
    <2.0021589, 0.3207962, 18.4560052>,
    <2.0021340, 0.4413536, 18.4726341>,
    <2.0021423, 0.4011678, 18.4393764>,
    <2.0021340, 0.4413536, 18.4560052>,
    <2.0021423, 0.4011678, 18.4726341>,
    <2.0021423, 0.4011678, 18.4560052>,
    <2.0021506, 0.3609820, 18.5058918>,
    <2.0021340, 0.4413536, 18.4892630>,
    <2.0021423, 0.4011678, 18.5058918>,
    <2.0021506, 0.3609820, 18.4892630>,
    <2.0021423, 0.4011678, 18.4892630>,
    <2.0021589, 0.3207962, 18.5058918>,
    <2.0021672, 0.2806104, 18.4892630>,
    <2.0021589, 0.3207962, 18.4892630>,
    <2.0023174, 0.3609828, 18.4393764>,
    <2.0024843, 0.3609835, 18.4393764>,
    <2.0024009, 0.3609832, 18.4393764>,
    <2.0024926, 0.3207858, 18.4393764>,
    <2.0023257, 0.3207910, 18.4393764>,
    <2.0024092, 0.3207884, 18.4393764>,
    <2.0021506, 0.3609820, 18.4393764>,
    <2.0021589, 0.3207962, 18.4393764>,
    <2.0022340, 0.3609824, 18.4393764>,
    <2.0022423, 0.3207936, 18.4393764>,
    <2.0021423, 0.4011678, 18.4393764>,
    <2.0023092, 0.4011746, 18.4393764>,
    <2.0022257, 0.4011712, 18.4393764>,
    <2.0024760, 0.4011813, 18.4393764>,
    <2.0023926, 0.4011779, 18.4393764>,
    <2.0025156, 0.3609837, 18.3784821>,
    <2.0025322, 0.2805859, 18.3784821>,
    <2.0025469, 0.3609838, 18.3175878>,
    <2.0025239, 0.3207848, 18.3784821>,
    <2.0025479, 0.2805849, 18.3480349>,
    <2.0025552, 0.3207838, 18.3175878>,
    <2.0025313, 0.3609837, 18.3480349>,
    <2.0025396, 0.3207843, 18.3480349>,
    <2.0024990, 0.4413814, 18.3784821>,
    <2.0025386, 0.4011838, 18.3175878>,
    <2.0025147, 0.4413826, 18.3480349>,
    <2.0025073, 0.4011825, 18.3784821>,
    <2.0025230, 0.4011832, 18.3480349>,
    <2.0024843, 0.3609835, 18.4393764>,
    <2.0024834, 0.4413802, 18.4089292>,
    <2.0024760, 0.4011813, 18.4393764>,
    <2.0025000, 0.3609836, 18.4089292>,
    <2.0024917, 0.4011819, 18.4089292>,
    <2.0024926, 0.3207858, 18.4393764>,
    <2.0025166, 0.2805870, 18.4089292>,
    <2.0025083, 0.3207853, 18.4089292>,
    <2.0032010, 0.3609868, 18.3135798>,
    <2.0038551, 0.3609897, 18.3095719>,
    <2.0035281, 0.3609882, 18.3115759>,
    <2.0038634, 0.3207428, 18.3095719>,
    <2.0032093, 0.3207633, 18.3135798>,
    <2.0035364, 0.3207531, 18.3115759>,
    <2.0025469, 0.3609838, 18.3175878>,
    <2.0025552, 0.3207838, 18.3175878>,
    <2.0028740, 0.3609853, 18.3155838>,
    <2.0028823, 0.3207736, 18.3155838>,
    <2.0025386, 0.4011838, 18.3175878>,
    <2.0031927, 0.4012102, 18.3135798>,
    <2.0028656, 0.4011970, 18.3155838>,
    <2.0038468, 0.4012365, 18.3095719>,
    <2.0035197, 0.4012233, 18.3115759>,
    <2.0038557, 0.3609897, 18.2344341>,
    <2.0038724, 0.2804960, 18.2344341>,
    <2.0038563, 0.3609897, 18.1592964>,
    <2.0038641, 0.3207428, 18.2344341>,
    <2.0038727, 0.2804959, 18.1968653>,
    <2.0038647, 0.3207428, 18.1592964>,
    <2.0038560, 0.3609897, 18.1968653>,
    <2.0038644, 0.3207428, 18.1968653>,
    <2.0038391, 0.4414834, 18.2344341>,
    <2.0038480, 0.4012366, 18.1592964>,
    <2.0038394, 0.4414834, 18.1968653>,
    <2.0038474, 0.4012366, 18.2344341>,
    <2.0038477, 0.4012366, 18.1968653>,
    <2.0038551, 0.3609897, 18.3095719>,
    <2.0038387, 0.4414834, 18.2720030>,
    <2.0038468, 0.4012365, 18.3095719>,
    <2.0038554, 0.3609897, 18.2720030>,
    <2.0038471, 0.4012365, 18.2720030>,
    <2.0038634, 0.3207428, 18.3095719>,
    <2.0038721, 0.2804960, 18.2720030>,
    <2.0038637, 0.3207428, 18.2720030>,
    <2.0039528, 0.3609901, 18.1573801>,
    <2.0040493, 0.3609906, 18.1554639>,
    <2.0040010, 0.3609903, 18.1564220>,
    <2.0040576, 0.3207368, 18.1554639>,
    <2.0039611, 0.3207398, 18.1573801>,
    <2.0040094, 0.3207383, 18.1564220>,
    <2.0038563, 0.3609897, 18.1592964>,
    <2.0038647, 0.3207428, 18.1592964>,
    <2.0039046, 0.3609899, 18.1583383>,
    <2.0039129, 0.3207413, 18.1583383>,
    <2.0038480, 0.4012366, 18.1592964>,
    <2.0039445, 0.4012405, 18.1573801>,
    <2.0038962, 0.4012385, 18.1583383>,
    <2.0040409, 0.4012444, 18.1554639>,
    <2.0039927, 0.4012424, 18.1564220>,
    <2.0042444, 0.3609914, 18.1389725>,
    <2.0042673, 0.2804695, 18.1386133>,
    <2.0043812, 0.3609921, 18.1258340>,
    <2.0042548, 0.3207304, 18.1388528>,
    <2.0043680, 0.2804627, 18.1301880>,
    <2.0044020, 0.3207251, 18.1251156>,
    <2.0043263, 0.3609918, 18.1316249>,
    <2.0043430, 0.3207272, 18.1311460>,
    <2.0042339, 0.4415135, 18.1386133>,
    <2.0043853, 0.4012591, 18.1251156>,
    <2.0043346, 0.4415211, 18.1301880>,
    <2.0042381, 0.4012525, 18.1388528>,
    <2.0043263, 0.4012565, 18.1311460>,
    <2.0040493, 0.3609906, 18.1554639>,
    <2.0041333, 0.4415058, 18.1470386>,
    <2.0040409, 0.4012444, 18.1554639>,
    <2.0041499, 0.3609910, 18.1470386>,
    <2.0041416, 0.4012484, 18.1470386>,
    <2.0040576, 0.3207368, 18.1554639>,
    <2.0041666, 0.2804762, 18.1470386>,
    <2.0041583, 0.3207336, 18.1470386>,
    <2.0043805, 0.3609920, 18.1205987>,
    <2.0043944, 0.3609921, 18.1224380>,
    <2.0043909, 0.3207262, 18.1204790>,
    <2.0044111, 0.3207251, 18.1219591>,
    <2.0043215, 0.3609918, 18.1187163>,
    <2.0043298, 0.3207282, 18.1187163>,
    <2.0043541, 0.3609919, 18.1194779>,
    <2.0043625, 0.3207272, 18.1194779>,
    <2.0043131, 0.4012553, 18.1187163>,
    <2.0043742, 0.4012579, 18.1204790>,
    <2.0043458, 0.4012566, 18.1194779>,
    <2.0043944, 0.4012592, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0001979, 0.9999962, 0.0027618>,
    <-0.0001970, 0.9999967, 0.0025777>,
    <-0.0001935, 0.9999966, 0.0026141>,
    <-0.0001949, 0.9999961, 0.0027737>,
    <-0.0001959, 0.9999958, 0.0028851>,
    <-0.0001985, 0.9999958, 0.0028852>,
    <-0.0001985, 0.9999958, 0.0028852>,
    <-0.0002015, 0.9999958, 0.0028854>,
    <-0.0002015, 0.9999962, 0.0027469>,
    <-0.0002015, 0.9999962, 0.0027469>,
    <-0.0002015, 0.9999968, 0.0025299>,
    <-0.0001955, 0.9999974, 0.0022739>,
    <-0.0001913, 0.9999972, 0.0023663>,
    <-0.0002015, 0.9999968, 0.0025299>,
    <-0.0002015, 0.9999977, 0.0021412>,
    <-0.0002015, 0.9999977, 0.0021412>,
    <-0.0002015, 0.9999992, 0.0012430>,
    <-0.0001926, 0.9999986, 0.0016774>,
    <-0.0001926, 0.9999986, 0.0016774>,
    <-0.0001874, 0.9999981, 0.0019299>,
    <-0.0001882, 0.9999970, 0.0024345>,
    <-0.0001908, 0.9999965, 0.0026427>,
    <-0.0001874, 0.9999981, 0.0019299>,
    <-0.0001840, 0.9999978, 0.0020951>,
    <-0.0001840, 0.9999978, 0.0020951>,
    <-0.0001816, 0.9999975, 0.0022114>,
    <-0.0001858, 0.9999969, 0.0024868>,
    <-0.0001858, 0.9999969, 0.0024868>,
    <-0.0001886, 0.9999964, 0.0026659>,
    <-0.0001925, 0.9999961, 0.0027835>,
    <-0.0001886, 0.9999964, 0.0026659>,
    <-0.0001905, 0.9999961, 0.0027917>,
    <-0.0001905, 0.9999961, 0.0027917>,
    <-0.0001919, 0.9999958, 0.0028850>,
    <-0.0001938, 0.9999958, 0.0028850>,
    <-0.0001938, 0.9999958, 0.0028850>,
    <-0.0001959, 0.9999958, 0.0028851>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <0.0000673, -0.9999647, 0.0084002>,
    <0.0000798, -0.9999829, 0.0058449>,
    <0.0000506, -0.9999847, 0.0055388>,
    <0.0000320, -0.9999709, 0.0076225>,
    <-0.0000008, -0.9999362, 0.0112934>,
    <0.0000429, -0.9999100, 0.0134174>,
    <0.0000429, -0.9999100, 0.0134174>,
    <0.0001180, -0.9998543, 0.0170703>,
    <0.0001180, -0.9999547, 0.0095163>,
    <0.0001180, -0.9999547, 0.0095163>,
    <0.0001180, -0.9999805, 0.0062463>,
    <0.0000873, -0.9999908, 0.0042964>,
    <0.0000626, -0.9999912, 0.0041960>,
    <0.0001180, -0.9999805, 0.0062463>,
    <0.0001180, -0.9999902, 0.0044211>,
    <0.0001180, -0.9999902, 0.0044211>,
    <0.0001180, -0.9999947, 0.0032565>,
    <0.0000924, -0.9999947, 0.0032576>,
    <0.0000924, -0.9999947, 0.0032576>,
    <0.0000710, -0.9999947, 0.0032585>,
    <0.0000423, -0.9999915, 0.0041134>,
    <0.0000276, -0.9999860, 0.0052978>,
    <0.0000710, -0.9999947, 0.0032585>,
    <0.0000528, -0.9999947, 0.0032593>,
    <0.0000528, -0.9999947, 0.0032593>,
    <0.0000373, -0.9999947, 0.0032599>,
    <0.0000253, -0.9999918, 0.0040444>,
    <0.0000253, -0.9999918, 0.0040444>,
    <0.0000091, -0.9999870, 0.0051030>,
    <0.0000060, -0.9999752, 0.0070495>,
    <0.0000091, -0.9999870, 0.0051030>,
    <-0.0000140, -0.9999782, 0.0066097>,
    <-0.0000140, -0.9999782, 0.0066097>,
    <-0.0000494, -0.9999602, 0.0089256>,
    <-0.0000293, -0.9999509, 0.0099046>,
    <-0.0000293, -0.9999509, 0.0099046>,
    <-0.0000008, -0.9999362, 0.0112934>,
    <0.0001437, -0.9999999, 0.0005130>,
    <0.0001435, -0.9999999, 0.0005281>,
    <0.0001473, -0.9999998, 0.0005281>,
    <0.0001474, -0.9999999, 0.0005130>,
    <0.0001475, -0.9999999, 0.0004984>,
    <0.0001438, -0.9999999, 0.0004984>,
    <0.0001438, -0.9999999, 0.0004984>,
    <0.0001401, -0.9999999, 0.0004983>,
    <0.0001399, -0.9999999, 0.0005130>,
    <0.0001399, -0.9999999, 0.0005130>,
    <0.0001397, -0.9999999, 0.0005281>,
    <0.0001433, -0.9999998, 0.0005437>,
    <0.0001472, -0.9999998, 0.0005437>,
    <0.0001397, -0.9999999, 0.0005281>,
    <0.0001395, -0.9999998, 0.0005437>,
    <0.0001395, -0.9999998, 0.0005437>,
    <0.0001392, -0.9999998, 0.0005598>,
    <0.0001431, -0.9999998, 0.0005598>,
    <0.0001431, -0.9999998, 0.0005598>,
    <0.0001470, -0.9999998, 0.0005598>,
    <0.0001510, -0.9999998, 0.0005437>,
    <0.0001511, -0.9999998, 0.0005281>,
    <0.0001470, -0.9999998, 0.0005598>,
    <0.0001509, -0.9999998, 0.0005597>,
    <0.0001509, -0.9999998, 0.0005597>,
    <0.0001548, -0.9999998, 0.0005597>,
    <0.0001548, -0.9999998, 0.0005437>,
    <0.0001548, -0.9999998, 0.0005437>,
    <0.0001548, -0.9999998, 0.0005281>,
    <0.0001511, -0.9999999, 0.0005131>,
    <0.0001548, -0.9999998, 0.0005281>,
    <0.0001548, -0.9999999, 0.0005131>,
    <0.0001548, -0.9999999, 0.0005131>,
    <0.0001548, -0.9999999, 0.0004984>,
    <0.0001512, -0.9999999, 0.0004984>,
    <0.0001512, -0.9999999, 0.0004984>,
    <0.0001475, -0.9999999, 0.0004984>,
    <0.9999622, 0.0001559, -0.0086918>,
    <0.9999622, 0.0001559, -0.0086938>,
    <0.9999622, 0.0001555, -0.0086938>,
    <0.9999622, 0.0001555, -0.0086918>,
    <0.9999622, 0.0001555, -0.0086898>,
    <0.9999622, 0.0001559, -0.0086898>,
    <0.9999622, 0.0001559, -0.0086898>,
    <0.9999622, 0.0001563, -0.0086898>,
    <0.9999622, 0.0001563, -0.0086918>,
    <0.9999622, 0.0001563, -0.0086918>,
    <0.9999622, 0.0001563, -0.0086938>,
    <0.9999622, 0.0001559, -0.0086958>,
    <0.9999622, 0.0001555, -0.0086958>,
    <0.9999622, 0.0001563, -0.0086938>,
    <0.9999622, 0.0001563, -0.0086958>,
    <0.9999622, 0.0001563, -0.0086958>,
    <0.9999622, 0.0001563, -0.0086977>,
    <0.9999622, 0.0001559, -0.0086977>,
    <0.9999622, 0.0001559, -0.0086977>,
    <0.9999622, 0.0001555, -0.0086977>,
    <0.9999622, 0.0001550, -0.0086958>,
    <0.9999622, 0.0001550, -0.0086938>,
    <0.9999622, 0.0001555, -0.0086977>,
    <0.9999622, 0.0001550, -0.0086977>,
    <0.9999622, 0.0001550, -0.0086977>,
    <0.9999622, 0.0001546, -0.0086977>,
    <0.9999622, 0.0001546, -0.0086958>,
    <0.9999622, 0.0001546, -0.0086958>,
    <0.9999622, 0.0001546, -0.0086938>,
    <0.9999622, 0.0001550, -0.0086918>,
    <0.9999622, 0.0001546, -0.0086938>,
    <0.9999622, 0.0001546, -0.0086918>,
    <0.9999622, 0.0001546, -0.0086918>,
    <0.9999622, 0.0001546, -0.0086898>,
    <0.9999622, 0.0001550, -0.0086898>,
    <0.9999622, 0.0001550, -0.0086898>,
    <0.9999622, 0.0001555, -0.0086898>,
    <-0.0000951, 0.9999998, 0.0005728>,
    <-0.0000951, 0.9999998, 0.0005695>,
    <-0.0000943, 0.9999998, 0.0005695>,
    <-0.0000943, 0.9999998, 0.0005728>,
    <-0.0000943, 0.9999998, 0.0005763>,
    <-0.0000952, 0.9999998, 0.0005763>,
    <-0.0000952, 0.9999998, 0.0005763>,
    <-0.0000960, 0.9999998, 0.0005763>,
    <-0.0000960, 0.9999998, 0.0005729>,
    <-0.0000960, 0.9999998, 0.0005729>,
    <-0.0000959, 0.9999998, 0.0005695>,
    <-0.0000951, 0.9999998, 0.0005663>,
    <-0.0000943, 0.9999998, 0.0005663>,
    <-0.0000959, 0.9999998, 0.0005695>,
    <-0.0000959, 0.9999998, 0.0005663>,
    <-0.0000959, 0.9999998, 0.0005663>,
    <-0.0000958, 0.9999998, 0.0005631>,
    <-0.0000950, 0.9999998, 0.0005631>,
    <-0.0000950, 0.9999998, 0.0005631>,
    <-0.0000942, 0.9999998, 0.0005631>,
    <-0.0000935, 0.9999998, 0.0005663>,
    <-0.0000935, 0.9999998, 0.0005695>,
    <-0.0000942, 0.9999998, 0.0005631>,
    <-0.0000935, 0.9999998, 0.0005631>,
    <-0.0000935, 0.9999998, 0.0005631>,
    <-0.0000927, 0.9999998, 0.0005631>,
    <-0.0000927, 0.9999998, 0.0005663>,
    <-0.0000927, 0.9999998, 0.0005663>,
    <-0.0000927, 0.9999998, 0.0005695>,
    <-0.0000935, 0.9999998, 0.0005728>,
    <-0.0000927, 0.9999998, 0.0005695>,
    <-0.0000927, 0.9999998, 0.0005728>,
    <-0.0000927, 0.9999998, 0.0005728>,
    <-0.0000927, 0.9999998, 0.0005763>,
    <-0.0000935, 0.9999998, 0.0005763>,
    <-0.0000935, 0.9999998, 0.0005763>,
    <-0.0000943, 0.9999998, 0.0005763>,
    <0.0001510, -0.9999947, 0.0032413>,
    <0.0001510, -0.9999952, 0.0030960>,
    <0.0001474, -0.9999952, 0.0031052>,
    <0.0001474, -0.9999947, 0.0032458>,
    <0.0001474, -0.9999943, 0.0033864>,
    <0.0001510, -0.9999943, 0.0033866>,
    <0.0001510, -0.9999943, 0.0033866>,
    <0.0001548, -0.9999943, 0.0033868>,
    <0.0001548, -0.9999948, 0.0032365>,
    <0.0001548, -0.9999948, 0.0032365>,
    <0.0001548, -0.9999952, 0.0030862>,
    <0.0001510, -0.9999956, 0.0029508>,
    <0.0001474, -0.9999956, 0.0029647>,
    <0.0001548, -0.9999952, 0.0030862>,
    <0.0001548, -0.9999957, 0.0029360>,
    <0.0001548, -0.9999957, 0.0029360>,
    <0.0001548, -0.9999961, 0.0027857>,
    <0.0001510, -0.9999961, 0.0028055>,
    <0.0001510, -0.9999961, 0.0028055>,
    <0.0001474, -0.9999960, 0.0028241>,
    <0.0001440, -0.9999956, 0.0029777>,
    <0.0001440, -0.9999951, 0.0031138>,
    <0.0001474, -0.9999960, 0.0028241>,
    <0.0001440, -0.9999960, 0.0028415>,
    <0.0001440, -0.9999960, 0.0028415>,
    <0.0001408, -0.9999959, 0.0028578>,
    <0.0001408, -0.9999955, 0.0029899>,
    <0.0001408, -0.9999955, 0.0029899>,
    <0.0001408, -0.9999951, 0.0031219>,
    <0.0001440, -0.9999947, 0.0032500>,
    <0.0001408, -0.9999951, 0.0031219>,
    <0.0001408, -0.9999947, 0.0032540>,
    <0.0001408, -0.9999947, 0.0032540>,
    <0.0001408, -0.9999943, 0.0033861>,
    <0.0001440, -0.9999943, 0.0033862>,
    <0.0001440, -0.9999943, 0.0033862>,
    <0.0001474, -0.9999943, 0.0033864>,
    <0.1905399, 0.0000294, -0.9816795>,
    <0.1905394, 0.0000294, -0.9816795>,
    <0.1905394, 0.0000293, -0.9816795>,
    <0.1905399, 0.0000293, -0.9816795>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000294, -0.9816794>,
    <0.1905403, 0.0000294, -0.9816794>,
    <0.1905403, 0.0000295, -0.9816794>,
    <0.1905399, 0.0000295, -0.9816795>,
    <0.1905399, 0.0000295, -0.9816795>,
    <0.1905394, 0.0000295, -0.9816795>,
    <0.1905390, 0.0000294, -0.9816796>,
    <0.1905390, 0.0000293, -0.9816796>,
    <0.1905394, 0.0000295, -0.9816795>,
    <0.1905390, 0.0000295, -0.9816796>,
    <0.1905390, 0.0000295, -0.9816796>,
    <0.1905385, 0.0000295, -0.9816797>,
    <0.1905385, 0.0000294, -0.9816797>,
    <0.1905385, 0.0000294, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905390, 0.0000293, -0.9816796>,
    <0.1905394, 0.0000293, -0.9816795>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000292, -0.9816797>,
    <0.1905390, 0.0000292, -0.9816796>,
    <0.1905390, 0.0000292, -0.9816796>,
    <0.1905394, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000293, -0.9816795>,
    <0.1905394, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000292, -0.9816795>,
    <0.1905403, 0.0000292, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <-0.0000906, 0.9999917, 0.0040632>,
    <-0.0000906, 0.9999921, 0.0039843>,
    <-0.0000886, 0.9999921, 0.0039793>,
    <-0.0000886, 0.9999918, 0.0040557>,
    <-0.0000886, 0.9999915, 0.0041320>,
    <-0.0000906, 0.9999914, 0.0041421>,
    <-0.0000906, 0.9999914, 0.0041421>,
    <-0.0000927, 0.9999914, 0.0041529>,
    <-0.0000927, 0.9999917, 0.0040712>,
    <-0.0000927, 0.9999917, 0.0040712>,
    <-0.0000927, 0.9999920, 0.0039896>,
    <-0.0000906, 0.9999924, 0.0039053>,
    <-0.0000886, 0.9999924, 0.0039029>,
    <-0.0000927, 0.9999920, 0.0039896>,
    <-0.0000927, 0.9999924, 0.0039079>,
    <-0.0000927, 0.9999924, 0.0039079>,
    <-0.0000927, 0.9999927, 0.0038263>,
    <-0.0000906, 0.9999927, 0.0038264>,
    <-0.0000906, 0.9999927, 0.0038264>,
    <-0.0000886, 0.9999927, 0.0038265>,
    <-0.0000868, 0.9999924, 0.0039006>,
    <-0.0000868, 0.9999921, 0.0039746>,
    <-0.0000886, 0.9999927, 0.0038265>,
    <-0.0000868, 0.9999927, 0.0038266>,
    <-0.0000868, 0.9999927, 0.0038266>,
    <-0.0000851, 0.9999927, 0.0038267>,
    <-0.0000851, 0.9999924, 0.0038984>,
    <-0.0000851, 0.9999924, 0.0038984>,
    <-0.0000851, 0.9999921, 0.0039702>,
    <-0.0000868, 0.9999918, 0.0040486>,
    <-0.0000851, 0.9999921, 0.0039702>,
    <-0.0000851, 0.9999918, 0.0040420>,
    <-0.0000851, 0.9999918, 0.0040420>,
    <-0.0000851, 0.9999915, 0.0041137>,
    <-0.0000868, 0.9999915, 0.0041226>,
    <-0.0000868, 0.9999915, 0.0041226>,
    <-0.0000886, 0.9999915, 0.0041320>,
    <0.0001429, -1.0000000, 0.0000082>,
    <0.0001419, -1.0000000, 0.0000137>,
    <0.0001499, -1.0000000, 0.0000570>,
    <0.0001580, -1.0000000, 0.0000320>,
    <0.0001598, -1.0000000, 0.0000006>,
    <0.0001432, -1.0000000, 0.0000006>,
    <0.0001432, -1.0000000, 0.0000006>,
    <0.0001408, -1.0000000, 0.0000006>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000153>,
    <0.0001410, -1.0000000, 0.0000657>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001405, -1.0000000, 0.0000145>,
    <0.0001405, -1.0000000, 0.0000145>,
    <0.0001380, -1.0000000, 0.0000628>,
    <0.0001414, -1.0000000, 0.0001783>,
    <0.0001692, -1.0000000, 0.0001630>,
    <0.0001380, -1.0000000, 0.0000628>,
    <0.0001319, -1.0000000, 0.0001720>,
    <0.0001319, -1.0000000, 0.0001720>,
    <0.0001218, -0.9999999, 0.0004379>,
    <0.0001379, -0.9999999, 0.0004526>,
    <0.0001863, -0.9999999, 0.0004573>,
    <0.0002046, -1.0000000, 0.0001071>,
    <0.0003019, -0.9999998, 0.0004720>,
    <0.0004048, -0.9999998, 0.0005587>,
    <0.0002116, -1.0000000, 0.0000006>,
    <0.0002116, -1.0000000, 0.0000006>,
    <0.0001598, -1.0000000, 0.0000006>,
    <0.9990812, 0.0001532, -0.0428577>,
    <0.9990812, 0.0001532, -0.0428578>,
    <0.9831445, 0.0001507, -0.1828302>,
    <0.9831446, 0.0001507, -0.1828299>,
    <0.9831446, 0.0001507, -0.1828296>,
    <0.9990812, 0.0001532, -0.0428577>,
    <0.9990812, 0.0001532, -0.0428577>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9990812, 0.0001532, -0.0428579>,
    <0.9831444, 0.0001507, -0.1828304>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9990812, 0.0001532, -0.0428580>,
    <0.9990812, 0.0001532, -0.0428580>,
    <0.9831444, 0.0001507, -0.1828307>,
    <0.8939548, 0.0001366, -0.4481571>,
    <0.8939551, 0.0001366, -0.4481565>,
    <0.9831444, 0.0001507, -0.1828307>,
    <0.8939545, 0.0001366, -0.4481577>,
    <0.8939545, 0.0001366, -0.4481577>,
    <0.6276284, 0.0000954, -0.7785131>,
    <0.6276290, 0.0000954, -0.7785125>,
    <0.6276297, 0.0000954, -0.7785120>,
    <0.8939554, 0.0001366, -0.4481559>,
    <0.6276303, 0.0000954, -0.7785115>,
    <0.6276310, 0.0000954, -0.7785110>,
    <0.8939557, 0.0001366, -0.4481553>,
    <0.8939557, 0.0001366, -0.4481553>,
    <0.9831446, 0.0001507, -0.1828296>,
    <-0.0000844, 1.0000000, 0.0000236>,
    <-0.0000832, 1.0000000, 0.0000196>,
    <-0.0000698, 1.0000000, 0.0000816>,
    <-0.0000800, 1.0000000, 0.0001006>,
    <-0.0000835, 1.0000000, 0.0001062>,
    <-0.0000848, 1.0000000, 0.0000247>,
    <-0.0000848, 1.0000000, 0.0000247>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000821, 1.0000000, 0.0000113>,
    <-0.0000606, 1.0000000, 0.0000444>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000589, 1.0000000, 0.0000006>,
    <0.0000041, 1.0000000, 0.0001407>,
    <-0.0000358, 1.0000000, 0.0002272>,
    <-0.0000589, 1.0000000, 0.0000006>,
    <0.0000100, 1.0000000, 0.0000006>,
    <0.0000100, 1.0000000, 0.0000006>,
    <0.0002457, 0.9999998, 0.0006317>,
    <0.0001373, 0.9999998, 0.0005815>,
    <0.0000045, 0.9999998, 0.0006141>,
    <-0.0000685, 1.0000000, 0.0002685>,
    <-0.0000539, 0.9999998, 0.0006605>,
    <-0.0000743, 0.9999998, 0.0006962>,
    <-0.0000800, 1.0000000, 0.0002844>,
    <-0.0000800, 1.0000000, 0.0002844>,
    <-0.0000835, 1.0000000, 0.0001062>,
    <0.0002912, -0.9999984, 0.0017670>,
    <0.0001725, -0.9999993, 0.0011318>,
    <0.0001026, -0.9999983, 0.0018581>,
    <0.0001112, -0.9999949, 0.0031925>,
    <0.0001481, -0.9999397, 0.0109794>,
    <0.0012690, -0.9999369, 0.0111623>,
    <0.0012690, -0.9999369, 0.0111623>,
    <0.0004048, -0.9999998, 0.0005587>,
    <0.0001239, -0.9999995, 0.0010008>,
    <0.0000990, -0.9999989, 0.0014968>,
    <0.0001218, -0.9999999, 0.0004379>,
    <0.0001093, -0.9999995, 0.0009581>,
    <0.0001093, -0.9999995, 0.0009581>,
    <0.0000980, -0.9999990, 0.0013971>,
    <0.0000785, -0.9999992, 0.0012876>,
    <0.0000401, -0.9999988, 0.0015540>,
    <0.0000980, -0.9999990, 0.0013971>,
    <0.0000894, -0.9999993, 0.0011934>,
    <0.0000894, -0.9999993, 0.0011934>,
    <0.0000837, -0.9999998, 0.0006212>,
    <0.0000737, -0.9999998, 0.0006550>,
    <0.0000426, -0.9999998, 0.0006974>,
    <-0.0000550, -0.9999970, 0.0024349>,
    <-0.0000320, -0.9999997, 0.0007319>,
    <-0.0000818, -0.9999997, 0.0007081>,
    <-0.0005919, -0.9999409, 0.0108586>,
    <-0.0005919, -0.9999409, 0.0108586>,
    <0.0001481, -0.9999397, 0.0109794>,
    <0.3566099, 0.0000538, -0.9342534>,
    <0.3566093, 0.0000538, -0.9342536>,
    <0.2610639, 0.0000390, -0.9653215>,
    <0.2610644, 0.0000390, -0.9653214>,
    <0.2610648, 0.0000390, -0.9653213>,
    <0.3566104, 0.0000538, -0.9342532>,
    <0.3566104, 0.0000538, -0.9342532>,
    <0.6276310, 0.0000954, -0.7785110>,
    <0.3566088, 0.0000538, -0.9342538>,
    <0.2610635, 0.0000390, -0.9653216>,
    <0.6276284, 0.0000954, -0.7785131>,
    <0.3566083, 0.0000538, -0.9342540>,
    <0.3566083, 0.0000538, -0.9342540>,
    <0.2610631, 0.0000390, -0.9653217>,
    <0.3092803, 0.0000457, -0.9509709>,
    <0.3092808, 0.0000457, -0.9509708>,
    <0.2610631, 0.0000390, -0.9653217>,
    <0.3092799, 0.0000457, -0.9509711>,
    <0.3092799, 0.0000457, -0.9509711>,
    <0.5394217, 0.0000790, -0.8420358>,
    <0.5394223, 0.0000790, -0.8420354>,
    <0.5394230, 0.0000790, -0.8420350>,
    <0.3092813, 0.0000457, -0.9509706>,
    <0.5394236, 0.0000790, -0.8420345>,
    <0.5394243, 0.0000790, -0.8420341>,
    <0.3092817, 0.0000457, -0.9509705>,
    <0.3092817, 0.0000457, -0.9509705>,
    <0.2610648, 0.0000390, -0.9653213>,
    <-0.0000482, 0.9999990, 0.0014066>,
    <0.0000111, 0.9999989, 0.0014714>,
    <-0.0000551, 0.9999972, 0.0023598>,
    <-0.0000596, 0.9999979, 0.0020352>,
    <-0.0000608, 0.9999979, 0.0020296>,
    <-0.0000672, 0.9999989, 0.0014526>,
    <-0.0000672, 0.9999989, 0.0014526>,
    <-0.0000743, 0.9999998, 0.0006962>,
    <0.0001481, 0.9999977, 0.0021246>,
    <-0.0000452, 0.9999928, 0.0038027>,
    <0.0002457, 0.9999998, 0.0006317>,
    <0.0012442, 0.9999195, 0.0126234>,
    <0.0012442, 0.9999195, 0.0126234>,
    <-0.0000041, 0.9999229, 0.0124198>,
    <-0.0002251, 0.9999958, 0.0028806>,
    <-0.0001157, 0.9999981, 0.0019437>,
    <-0.0000041, 0.9999229, 0.0124198>,
    <-0.0008268, 0.9999242, 0.0122855>,
    <-0.0008268, 0.9999242, 0.0122855>,
    <-0.0002400, 0.9999997, 0.0008012>,
    <-0.0001867, 0.9999996, 0.0008670>,
    <-0.0001014, 0.9999996, 0.0008661>,
    <-0.0000696, 0.9999985, 0.0017084>,
    <-0.0000648, 0.9999996, 0.0008550>,
    <-0.0000527, 0.9999996, 0.0008534>,
    <-0.0000559, 0.9999986, 0.0016781>,
    <-0.0000559, 0.9999986, 0.0016781>,
    <-0.0000608, 0.9999979, 0.0020296>,
    <0.0000429, -1.0000000, 0.0001869>,
    <0.0000610, -1.0000000, 0.0002649>,
    <0.0000733, -1.0000000, 0.0001115>,
    <0.0000696, -1.0000000, 0.0000775>,
    <0.0000688, -1.0000000, 0.0000345>,
    <0.0000401, -1.0000000, 0.0000345>,
    <0.0000401, -1.0000000, 0.0000345>,
    <-0.0000818, -0.9999997, 0.0007081>,
    <0.0000755, -1.0000000, 0.0002809>,
    <0.0000775, -1.0000000, 0.0001238>,
    <0.0000837, -0.9999998, 0.0006212>,
    <0.0000805, -1.0000000, 0.0002738>,
    <0.0000805, -1.0000000, 0.0002738>,
    <0.0000789, -1.0000000, 0.0001224>,
    <0.0000781, -1.0000000, 0.0000537>,
    <0.0000776, -1.0000000, 0.0000514>,
    <0.0000789, -1.0000000, 0.0001224>,
    <0.0000782, -1.0000000, 0.0000530>,
    <0.0000782, -1.0000000, 0.0000530>,
    <0.0000780, -1.0000000, 0.0000325>,
    <0.0000780, -1.0000000, 0.0000330>,
    <0.0000780, -1.0000000, 0.0000330>,
    <0.0000780, -1.0000000, 0.0000335>,
    <0.0000771, -1.0000000, 0.0000443>,
    <0.0000780, -1.0000000, 0.0000335>,
    <0.0000780, -1.0000000, 0.0000340>,
    <0.0000780, -1.0000000, 0.0000340>,
    <0.0000780, -1.0000000, 0.0000345>,
    <0.0000770, -1.0000000, 0.0000345>,
    <0.0000770, -1.0000000, 0.0000345>,
    <0.0000688, -1.0000000, 0.0000345>,
    <0.8323459, 0.0001212, -0.5542565>,
    <0.8323455, 0.0001212, -0.5542572>,
    <0.9629304, 0.0001398, -0.2697499>,
    <0.9629305, 0.0001398, -0.2697495>,
    <0.9629307, 0.0001398, -0.2697490>,
    <0.8323463, 0.0001212, -0.5542558>,
    <0.8323463, 0.0001212, -0.5542558>,
    <0.5394243, 0.0000790, -0.8420341>,
    <0.8323450, 0.0001212, -0.5542578>,
    <0.9629303, 0.0001398, -0.2697504>,
    <0.5394217, 0.0000790, -0.8420358>,
    <0.8323446, 0.0001212, -0.5542585>,
    <0.8323446, 0.0001212, -0.5542585>,
    <0.9629301, 0.0001398, -0.2697508>,
    <0.9945988, 0.0001442, -0.1037943>,
    <0.9945988, 0.0001442, -0.1037941>,
    <0.9629301, 0.0001398, -0.2697508>,
    <0.9945988, 0.0001442, -0.1037945>,
    <0.9945988, 0.0001442, -0.1037945>,
    <0.9986191, 0.0001446, -0.0525351>,
    <0.9986191, 0.0001446, -0.0525350>,
    <0.9986191, 0.0001446, -0.0525350>,
    <0.9986191, 0.0001446, -0.0525349>,
    <0.9945988, 0.0001442, -0.1037939>,
    <0.9986191, 0.0001446, -0.0525349>,
    <0.9986191, 0.0001446, -0.0525347>,
    <0.9986191, 0.0001446, -0.0525347>,
    <0.9986191, 0.0001446, -0.0525346>,
    <0.9945988, 0.0001442, -0.1037937>,
    <0.9945988, 0.0001442, -0.1037937>,
    <0.9629307, 0.0001398, -0.2697490>,
    <-0.0000567, 0.9999999, 0.0003627>,
    <-0.0000734, 0.9999999, 0.0003289>,
    <-0.0000563, 1.0000000, 0.0001378>,
    <-0.0000516, 1.0000000, 0.0001578>,
    <-0.0000500, 1.0000000, 0.0001622>,
    <-0.0000509, 0.9999999, 0.0003697>,
    <-0.0000509, 0.9999999, 0.0003697>,
    <-0.0000527, 0.9999996, 0.0008534>,
    <-0.0000940, 1.0000000, 0.0002249>,
    <-0.0000606, 1.0000000, 0.0000933>,
    <-0.0002400, 0.9999997, 0.0008012>,
    <-0.0000965, 1.0000000, 0.0000391>,
    <-0.0000965, 1.0000000, 0.0000391>,
    <-0.0000614, 1.0000000, 0.0000391>,
    <-0.0000508, 1.0000000, 0.0000521>,
    <-0.0000503, 1.0000000, 0.0000621>,
    <-0.0000614, 1.0000000, 0.0000391>,
    <-0.0000510, 1.0000000, 0.0000391>,
    <-0.0000510, 1.0000000, 0.0000391>,
    <-0.0000495, 1.0000000, 0.0000391>,
    <-0.0000495, 1.0000000, 0.0000394>,
    <-0.0000495, 1.0000000, 0.0000394>,
    <-0.0000495, 1.0000000, 0.0000396>,
    <-0.0000498, 1.0000000, 0.0000667>,
    <-0.0000495, 1.0000000, 0.0000396>,
    <-0.0000495, 1.0000000, 0.0000399>,
    <-0.0000495, 1.0000000, 0.0000399>,
    <-0.0000495, 1.0000000, 0.0000401>,
    <-0.0000496, 1.0000000, 0.0000679>,
    <-0.0000496, 1.0000000, 0.0000679>,
    <-0.0000500, 1.0000000, 0.0001622>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <-0.9869426, -0.0002042, -0.1610724>,
    <-0.9869426, -0.0002040, -0.1610724>,
    <-0.9869431, -0.0002040, -0.1610691>,
    <-0.9869431, -0.0002042, -0.1610691>,
    <-0.9869431, -0.0002043, -0.1610691>,
    <-0.9869426, -0.0002043, -0.1610724>,
    <-0.9869426, -0.0002043, -0.1610724>,
    <-0.9869420, -0.0002043, -0.1610756>,
    <-0.9869420, -0.0002042, -0.1610756>,
    <-0.9869420, -0.0002042, -0.1610756>,
    <-0.9869420, -0.0002040, -0.1610756>,
    <-0.9869426, -0.0002039, -0.1610724>,
    <-0.9869431, -0.0002039, -0.1610691>,
    <-0.9869420, -0.0002040, -0.1610756>,
    <-0.9869420, -0.0002039, -0.1610756>,
    <-0.9869420, -0.0002039, -0.1610756>,
    <-0.9869420, -0.0002037, -0.1610756>,
    <-0.9869426, -0.0002037, -0.1610724>,
    <-0.9869426, -0.0002037, -0.1610724>,
    <-0.9869431, -0.0002037, -0.1610691>,
    <-0.9869436, -0.0002039, -0.1610659>,
    <-0.9869436, -0.0002040, -0.1610659>,
    <-0.9869431, -0.0002037, -0.1610691>,
    <-0.9869436, -0.0002037, -0.1610659>,
    <-0.9869436, -0.0002037, -0.1610659>,
    <-0.9869442, -0.0002037, -0.1610627>,
    <-0.9869442, -0.0002039, -0.1610627>,
    <-0.9869442, -0.0002039, -0.1610627>,
    <-0.9869442, -0.0002040, -0.1610627>,
    <-0.9869436, -0.0002042, -0.1610659>,
    <-0.9869442, -0.0002040, -0.1610627>,
    <-0.9869442, -0.0002042, -0.1610627>,
    <-0.9869442, -0.0002042, -0.1610627>,
    <-0.9869442, -0.0002043, -0.1610627>,
    <-0.9869436, -0.0002043, -0.1610659>,
    <-0.9869436, -0.0002043, -0.1610659>,
    <-0.9869431, -0.0002043, -0.1610691>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <0.9999404, 0.0003438, 0.0109141>,
    <0.9999447, 0.0002073, 0.0105163>,
    <0.9999338, 0.0002072, 0.0115037>,
    <0.9999321, 0.0002414, 0.0116512>,
    <0.9999286, 0.0002504, 0.0119507>,
    <0.9999285, 0.0003746, 0.0119506>,
    <0.9999285, 0.0003746, 0.0119506>,
    <0.9999722, 0.0008411, 0.0074076>,
    <0.9999724, 0.0006034, 0.0074077>,
    <0.9999725, 0.0002073, 0.0074076>,
    <0.9999404, 0.0000707, 0.0109136>,
    <0.9999321, 0.0001731, 0.0116506>,
    <0.9999725, -0.0001887, 0.0074074>,
    <0.9999725, -0.0004264, 0.0074070>,
    <0.9999286, 0.0000399, 0.0119496>,
    <0.9999286, 0.0000399, 0.0119496>,
    <0.9999286, 0.0001640, 0.0119498>,
    <0.9999294, 0.0002031, 0.0118782>,
    <0.9999298, 0.0002072, 0.0118451>,
    <0.9999286, 0.0001640, 0.0119498>,
    <0.9999286, 0.0002018, 0.0119498>,
    <0.9999286, 0.0002018, 0.0119498>,
    <0.9999286, 0.0002071, 0.0119498>,
    <0.9999286, 0.0002071, 0.0119500>,
    <0.9999286, 0.0002071, 0.0119500>,
    <0.9999286, 0.0002071, 0.0119503>,
    <0.9999294, 0.0002113, 0.0118787>,
    <0.9999286, 0.0002071, 0.0119503>,
    <0.9999286, 0.0002071, 0.0119505>,
    <0.9999286, 0.0002071, 0.0119505>,
    <0.9999286, 0.0002071, 0.0119508>,
    <0.9999286, 0.0002126, 0.0119508>,
    <0.9999286, 0.0002126, 0.0119508>,
    <0.9999286, 0.0002504, 0.0119507>,
    <0.9999903, 0.0006657, -0.0043628>,
    <0.9997832, 0.0004345, -0.0208159>,
    <0.9998818, 0.0002073, -0.0153711>,
    <0.9999996, 0.0002073, -0.0008270>,
    <0.9999722, 0.0008411, 0.0074076>,
    <0.9990811, 0.0020567, -0.0428093>,
    <0.9990811, 0.0020567, -0.0428093>,
    <0.9990829, 0.0006845, -0.0428133>,
    <0.9993788, 0.0002463, -0.0352415>,
    <0.9994752, 0.0002072, -0.0323937>,
    <0.9990829, 0.0006845, -0.0428133>,
    <0.9990830, 0.0002668, -0.0428145>,
    <0.9990830, 0.0002668, -0.0428145>,
    <0.9990830, 0.0002071, -0.0428147>,
    <0.9990830, 0.0002071, -0.0428138>,
    <0.9990830, 0.0002071, -0.0428138>,
    <0.9990831, 0.0002071, -0.0428129>,
    <0.9993789, 0.0001680, -0.0352399>,
    <0.9997834, -0.0000200, -0.0208147>,
    <0.9990831, 0.0002071, -0.0428129>,
    <0.9990831, 0.0002071, -0.0428121>,
    <0.9990831, 0.0002071, -0.0428121>,
    <0.9990832, 0.0002071, -0.0428112>,
    <0.9990832, 0.0001474, -0.0428110>,
    <0.9990832, 0.0001474, -0.0428110>,
    <0.9990832, -0.0002702, -0.0428096>,
    <0.9999905, -0.0002510, -0.0043624>,
    <0.9990832, -0.0002702, -0.0428096>,
    <0.9990821, -0.0016423, -0.0428051>,
    <0.9990821, -0.0016423, -0.0428051>,
    <0.9999725, -0.0004264, 0.0074070>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9514012>,
    <0.4350041, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289898, 0.9514012>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9514012>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559177, 0.9657316>,
    <0.6289898, 0.9514012>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4350041, 0.9657316>,
    <0.5000060, 0.9664304>,
    <0.4264019, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379340, 0.9664304>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664304>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559177, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773698, 0.9671308>,
    <0.6379340, 0.9664304>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4264019, 0.9671308>,
    <0.5000061, 0.9784166>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473432, 0.9784166>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9784166>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773698, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473432, 0.9784166>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032659, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458870>,
    <0.4677608, 0.9457545>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9514012>,
    <0.4355157, 0.9458870>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9452808>,
    <0.4677603, 0.9520086>,
    <0.4676324, 0.9588701>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9514012>,
    <0.5000059, 0.9657316>,
    <0.4350041, 0.9657316>,
    <0.4677603, 0.9520086>,
    <0.5000059, 0.9583592>,
    <0.4675006, 0.9657316>,
    <0.4352834, 0.9585413>,
    <0.4031379, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4350041, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352834, 0.9585413>,
    <0.4023474, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032659, 0.9526160>,
    <0.5322510, 0.9457545>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9514012>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9520086>,
    <0.5000059, 0.9452808>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458708>,
    <0.5967411, 0.9457545>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289898, 0.9514012>,
    <0.5644961, 0.9458708>,
    <0.5967380, 0.9395004>,
    <0.6289859, 0.9452808>,
    <0.5967441, 0.9520086>,
    <0.5967475, 0.9588701>,
    <0.5644983, 0.9526160>,
    <0.6289898, 0.9514012>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967441, 0.9520086>,
    <0.6289944, 0.9583592>,
    <0.5967509, 0.9657316>,
    <0.5645003, 0.9589842>,
    <0.5322532, 0.9588701>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9514012>,
    <0.5645003, 0.9589842>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9583592>,
    <0.5322521, 0.9520086>,
    <0.6423395, 0.9457545>,
    <0.6556982, 0.9526160>,
    <0.6289898, 0.9514012>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423438, 0.9520086>,
    <0.6289859, 0.9452808>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458870>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458870>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691099, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559177, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694415, 0.9657316>,
    <0.6557974, 0.9585413>,
    <0.6424012, 0.9588701>,
    <0.6556982, 0.9526160>,
    <0.6559177, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289898, 0.9514012>,
    <0.6557974, 0.9585413>,
    <0.6424603, 0.9657316>,
    <0.6289944, 0.9583592>,
    <0.6423438, 0.9520086>,
    <0.3997804, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4350041, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4023474, 0.9657316>,
    <0.4330510, 0.9660760>,
    <0.4665132, 0.9660812>,
    <0.4310370, 0.9664312>,
    <0.4350041, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664304>,
    <0.4330510, 0.9660760>,
    <0.4675006, 0.9657316>,
    <0.5000060, 0.9661005>,
    <0.4655215, 0.9664308>,
    <0.4643627, 0.9667808>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664304>,
    <0.5000061, 0.9671308>,
    <0.4264019, 0.9671308>,
    <0.4655215, 0.9664308>,
    <0.5000060, 0.9667584>,
    <0.4631984, 0.9671308>,
    <0.4287525, 0.9667760>,
    <0.3931576, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4264019, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4287525, 0.9667760>,
    <0.3895609, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664304>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664308>,
    <0.5000060, 0.9661005>,
    <0.5322542, 0.9657316>,
    <0.5668636, 0.9661009>,
    <0.6001027, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379340, 0.9664304>,
    <0.5668636, 0.9661009>,
    <0.5967509, 0.9657316>,
    <0.6337159, 0.9661005>,
    <0.6034545, 0.9664308>,
    <0.6068113, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.6379340, 0.9664304>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034545, 0.9664308>,
    <0.6421270, 0.9667584>,
    <0.6101681, 0.9671308>,
    <0.5710692, 0.9667588>,
    <0.5356086, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664304>,
    <0.5710692, 0.9667588>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667584>,
    <0.5344905, 0.9664308>,
    <0.6473391, 0.9660812>,
    <0.6665054, 0.9664312>,
    <0.6379340, 0.9664304>,
    <0.6289992, 0.9657316>,
    <0.6559177, 0.9657316>,
    <0.6522197, 0.9664308>,
    <0.6337159, 0.9661005>,
    <0.6424603, 0.9657316>,
    <0.6611304, 0.9660760>,
    <0.6749770, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559177, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6611304, 0.9660760>,
    <0.6694415, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866645, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773698, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926264, 0.9671308>,
    <0.6718601, 0.9667760>,
    <0.6571745, 0.9667808>,
    <0.6665054, 0.9664312>,
    <0.6773698, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379340, 0.9664304>,
    <0.6718601, 0.9667760>,
    <0.6621316, 0.9671308>,
    <0.6421270, 0.9667584>,
    <0.6522197, 0.9664308>,
    <0.3896428, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4264019, 0.9671308>,
    <0.3895222, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3895609, 0.9671308>,
    <0.4263743, 0.9728710>,
    <0.4631912, 0.9726096>,
    <0.4263507, 0.9777601>,
    <0.4264019, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9784166>,
    <0.4263743, 0.9728710>,
    <0.4631984, 0.9671308>,
    <0.5000061, 0.9727240>,
    <0.4631779, 0.9780884>,
    <0.4631249, 0.9832389>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9784166>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631779, 0.9780884>,
    <0.5000061, 0.9835252>,
    <0.4630714, 0.9883895>,
    <0.4262411, 0.9832069>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262411, 0.9832069>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895222, 0.9777601>,
    <0.5367803, 0.9726096>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9784166>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9780884>,
    <0.5000061, 0.9727240>,
    <0.5367268, 0.9671308>,
    <0.5735535, 0.9723987>,
    <0.6103352, 0.9726096>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473432, 0.9784166>,
    <0.5735535, 0.9723987>,
    <0.6101681, 0.9671308>,
    <0.6471140, 0.9727240>,
    <0.6105023, 0.9780884>,
    <0.6106562, 0.9832389>,
    <0.5736614, 0.9777601>,
    <0.6473432, 0.9784166>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105023, 0.9780884>,
    <0.6475489, 0.9835252>,
    <0.6108101, 0.9883895>,
    <0.5737711, 0.9832050>,
    <0.5368873, 0.9832389>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9784166>,
    <0.5737711, 0.9832050>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9835252>,
    <0.5368338, 0.9780884>,
    <0.6623552, 0.9726096>,
    <0.6778190, 0.9777601>,
    <0.6473432, 0.9784166>,
    <0.6468888, 0.9671308>,
    <0.6773698, 0.9671308>,
    <0.6625813, 0.9780884>,
    <0.6471140, 0.9727240>,
    <0.6621316, 0.9671308>,
    <0.6776124, 0.9728710>,
    <0.6928064, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773698, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776124, 0.9728710>,
    <0.6926264, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930704, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930704, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780837, 0.9832069>,
    <0.6628106, 0.9832389>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473432, 0.9784166>,
    <0.6780837, 0.9832069>,
    <0.6630402, 0.9883895>,
    <0.6475489, 0.9835252>,
    <0.6625813, 0.9780884>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.05, -0.822255, -0.147353>
}

#declare Cube006 = object {
  box { // Cube006
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.0, -0.5, 0.5>
    material {
      Tchainette
    }
    scale <0.3, 0.46, 0.07>
    translate  <2.312629, 0.0, 18.358506>
  }
}
#declare Cube007 = object {
  box { // Cube007
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.0, -0.5, 0.5>
    material {
      Tchainette
    }
    scale <0.3, 0.629605, 0.05>
    translate  <2.304506, -0.46392, 18.358506>
  }
}
#declare Cube010 = object {
  box { // Cube010
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    material {
      Tchainette
    }
    scale <0.3, 0.46, 0.3>
    translate  <2.309153, 0.0, 18.41>
  }
}
#declare Cube011 = object {
  object { // Cube011 -> Cube010
    Cube010
    translate  0.467323*y
  }
}
#declare Elment_chainette1 = union {
  box { // Cube003
    <-1, -1, -1>, <1, 1, 1>
    translate  -1.0*x
    scale <-0.25, 0.1, 0.155036>
    rotate 45.0*z
    translate  <0.910312, -2.307264, 8.131053>
  }
  box { // Cube004
    <-1, -1, -1>, <1, 1, 1>
    translate  -1.0*x
    scale <-0.18, 0.1, 0.155036>
    rotate 45.0*z
    translate  <0.910312, -2.307237, 8.449714>
  }
  box { // Cube001
    <-1, -1, -1>, <1, 1, 1>
    translate  -1.0*x
    scale <0.25, 0.1, 0.155036>
    translate  <0.987818, -2.275221, 8.131053>
  }
  box { // Cube002
    <-1, -1, -1>, <1, 1, 1>
    translate  -1.0*x
    scale <0.18, 0.1, 0.155036>
    translate  <0.987783, -2.27519, 8.449714>
  }
  translate  -7.976505*z
  scale <1.0, 1.0, 0.944799>
  translate  7.987424*z
}
#declare Elment_chainette24 = object {
  object { // Elment_chainette24 -> Elment_chainette1
    Elment_chainette1
    translate  <-0.086749, -0.251315, 10.73053>
  }
}
#declare Cube012 = object {
  box { // Cube012
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.0, -0.5, 0.5>
    material {
      Tchainette
    }
    scale <0.3, 0.388847, 0.3>
    translate  <2.304506, -0.702674, 18.41>
  }
}
#declare HgtFld007 = object { 
  height_field {
    jpeg "BriquesNB.jpg"
    water_level 0.0
  }
  rotate    <-90, 0, 0> // Turn onto XY plane. Now points along -Z
  scale     <  2, 2,-2> // Scale to Cube size. Now points along +Z
  translate < -1,-1,-1> // Center around origin
  translate  1.0*y
  material {
    Mat_hf_pierres
    rotate -90.0*x
  }
  scale <0.8, 1.212713, 0.025>
  rotate <90.0, 0.0, 90.0>
  translate  <2.424391, 0.0, 18.728163>
}
#declare Cube015 = object {
  box { // Cube015
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    material {
      Tchainette
    }
    scale <0.25, 0.46, 0.25>
    rotate -35.0*y
    translate  <2.416864, 0.0, 21.080437>
  }
}
#declare TMesh012 = mesh2 {
    vertex_vectors {
      8,
      <-0.9985696, -0.5961068, -0.9993175>,
      <-1.0000000, 1.0000000, -1.0000000>,
      <1.0000000, 1.0000000, -1.0000000>,
      <1.0079331, -0.9961198, -1.0038707>,
      <-1.0031228, -0.3160146, 1.0038707>,
      <-1.0000000, 1.0000000, 1.0000000>,
      <1.0000000, 1.0000000, 1.0000000>,
      <1.0033799, -0.7160277, 0.9993175>
    }
    normal_vectors {
      6,
      <0.0028542, 0.0029344, 0.9999916>,
      <-0.1934142, -0.9717251, 0.1354301>,
      <0.0000000, -0.0004276, -0.9999999>,
      <0.0000000, 1.0000000, 0.0000000>,
      <-0.9999938, 0.0023653, -0.0026037>,
      <0.9999981, 0.0019696, 0.0000000>
    }
    uv_vectors {
      14,
      <0.2500000, 0.6666667>,
      <0.5000000, 0.6666667>,
      <0.5000000, 0.3333333>,
      <0.2500000, 0.3333333>,
      <0.2500000, 1.0000000>,
      <0.5000000, 1.0000000>,
      <0.2500000, 0.0000000>,
      <0.5000000, 0.0000000>,
      <0.0000000, 0.6666667>,
      <0.0000000, 0.3333333>,
      <0.7500000, 0.6666667>,
      <0.7500000, 0.3333333>,
      <1.0000000, 0.6666667>,
      <1.0000000, 0.3333333>
    }
    texture_list {
      1,
      texture { T_Pierre }
    }
    face_indices {
      12,   // 0 triangles and 6 quads
      <5, 4, 7>, 0,
      <5, 7, 6>, 0,
      <4, 0, 3>, 0,
      <4, 3, 7>, 0,
      <0, 1, 2>, 0,
      <0, 2, 3>, 0,
      <1, 5, 6>, 0,
      <1, 6, 2>, 0,
      <0, 4, 5>, 0,
      <0, 5, 1>, 0,
      <2, 6, 7>, 0,
      <2, 7, 3>, 0
    }
    normal_indices {
      12,   // from 0 triangles and 6 quads
      <0, 0, 0>,
      <0, 0, 0>,
      <1, 1, 1>,
      <1, 1, 1>,
      <2, 2, 2>,
      <2, 2, 2>,
      <3, 3, 3>,
      <3, 3, 3>,
      <4, 4, 4>,
      <4, 4, 4>,
      <5, 5, 5>,
      <5, 5, 5>
    }
    uv_indices {
      12,   // from 0 triangles and 6 quads
      <0, 3, 2>,
      <0, 2, 1>      <3, 6, 7>,
      <3, 7, 2>      <13, 12, 10>,
      <13, 10, 11>      <4, 0, 1>,
      <4, 1, 5>      <9, 3, 0>,
      <9, 0, 8>      <10, 1, 2>,
      <10, 2, 11>
    }
    scale 0.5
    translate  <0.0, -0.5, 0.5>
    scale <0.25, 0.418032, 0.25>
    rotate -35.0*y
    translate  <2.416864, -0.701048, 21.080437>
}

#declare TMesh007 = mesh2 {
  vertex_vectors {
    582,
    <2.2035487, -0.0476156, 18.5058918>,
    <2.0010508, 0.0169930, 18.5058918>,
    <2.0011917, -0.0317843, 18.5058918>,
    <2.2036094, -0.1294874, 18.5058918>,
    <2.1022998, -0.0153113, 18.5058918>,
    <2.0011213, -0.0073956, 18.5058918>,
    <2.1024005, -0.0806358, 18.5058918>,
    <2.2035790, -0.0885515, 18.5058918>,
    <2.1023502, -0.0479736, 18.5058918>,
    <2.4060270, -0.2271905, 18.5058918>,
    <2.4060466, -0.1122243, 18.5058918>,
    <2.3048182, -0.1783389, 18.5058918>,
    <2.4060368, -0.1697074, 18.5058918>,
    <2.3047976, -0.0799199, 18.5058918>,
    <2.3048079, -0.1291294, 18.5058918>,
    <2.4060661, 0.0027419, 18.5058918>,
    <2.2034880, 0.0342561, 18.5058918>,
    <2.4060563, -0.0547412, 18.5058918>,
    <2.3047771, 0.0184990, 18.5058918>,
    <2.2035184, -0.0066798, 18.5058918>,
    <2.3047874, -0.0307105, 18.5058918>,
    <2.0009099, 0.0657702, 18.5058918>,
    <2.1021990, 0.0500132, 18.5058918>,
    <2.0009804, 0.0413816, 18.5058918>,
    <2.1022494, 0.0173509, 18.5058918>,
    <2.0655560, -0.0651338, 18.1207908>,
    <2.0032615, -0.0337033, 18.1202395>,
    <2.0033220, -0.0337594, 18.1217627>,
    <2.0553199, -0.0632553, 18.1217627>,
    <2.0344088, -0.0494186, 18.1205151>,
    <2.0032917, -0.0337313, 18.1210011>,
    <2.0293209, -0.0485073, 18.1217627>,
    <2.0604380, -0.0641945, 18.1212767>,
    <2.0318649, -0.0489629, 18.1211389>,
    <2.1073179, -0.0927512, 18.1217627>,
    <2.1278504, -0.0965642, 18.1213420>,
    <2.0813189, -0.0780033, 18.1217627>,
    <2.1175842, -0.0946577, 18.1215524>,
    <2.0967032, -0.0808490, 18.1210664>,
    <2.0890111, -0.0794261, 18.1214145>,
    <2.1483830, -0.1003772, 18.1209214>,
    <2.0757921, -0.0670122, 18.1198188>,
    <2.1381167, -0.0984707, 18.1211317>,
    <2.1120875, -0.0836947, 18.1203701>,
    <2.0706740, -0.0660730, 18.1203048>,
    <2.1043954, -0.0822719, 18.1207182>,
    <2.0032011, -0.0336473, 18.1187163>,
    <2.0394966, -0.0503298, 18.1192675>,
    <2.0032313, -0.0336753, 18.1194779>,
    <2.0369527, -0.0498742, 18.1198913>,
    <2.1279029, -0.0254914, 18.1213420>,
    <2.1073713, -0.0229597, 18.1217627>,
    <2.1278767, -0.0610278, 18.1213420>,
    <2.1073446, -0.0578555, 18.1217627>,
    <2.1176371, -0.0242255, 18.1215524>,
    <2.1176106, -0.0594416, 18.1215524>,
    <2.1074247, 0.0468319, 18.1217627>,
    <2.1279553, 0.0455814, 18.1213420>,
    <2.1073980, 0.0119361, 18.1217627>,
    <2.1176900, 0.0462066, 18.1215524>,
    <2.1279291, 0.0100450, 18.1213420>,
    <2.1176635, 0.0109906, 18.1215524>,
    <2.1484859, 0.0443309, 18.1209214>,
    <2.1484345, -0.0280231, 18.1209214>,
    <2.1382206, 0.0449562, 18.1211317>,
    <2.1484602, 0.0081539, 18.1209214>,
    <2.1381687, -0.0267573, 18.1211317>,
    <2.1381946, 0.0090995, 18.1211317>,
    <2.1484087, -0.0642001, 18.1209214>,
    <2.1381427, -0.0626140, 18.1211317>,
    <2.0656120, 0.0557185, 18.1207908>,
    <2.0553811, 0.0563449, 18.1217627>,
    <2.0967837, 0.0506499, 18.1210664>,
    <2.0814029, 0.0515884, 18.1217627>,
    <2.0604966, 0.0560317, 18.1212767>,
    <2.0890933, 0.0511192, 18.1214145>,
    <2.0033376, 0.0658580, 18.1217627>,
    <2.0032688, 0.0658555, 18.1202395>,
    <2.0293594, 0.0611015, 18.1217627>,
    <2.0033032, 0.0658568, 18.1210011>,
    <2.0344404, 0.0607870, 18.1205151>,
    <2.0318999, 0.0609442, 18.1211389>,
    <2.0031999, 0.0658530, 18.1187163>,
    <2.0758429, 0.0550920, 18.1198188>,
    <2.0032343, 0.0658543, 18.1194779>,
    <2.0395214, 0.0604725, 18.1192675>,
    <2.0707275, 0.0554052, 18.1203048>,
    <2.0369809, 0.0606297, 18.1198913>,
    <2.1121644, 0.0497115, 18.1203701>,
    <2.1044740, 0.0501807, 18.1207182>,
    <2.0758764, -0.0709293, 18.1376413>,
    <2.0030751, -0.0335305, 18.1370901>,
    <2.0394758, -0.0522299, 18.1373657>,
    <2.0031381, -0.0335889, 18.1279032>,
    <2.0758342, -0.0689708, 18.1287301>,
    <2.0394862, -0.0512798, 18.1283166>,
    <2.1486776, -0.1083281, 18.1381926>,
    <2.1485303, -0.1043526, 18.1295570>,
    <2.1122770, -0.0896287, 18.1379170>,
    <2.1121823, -0.0866617, 18.1291435>,
    <2.1489723, -0.1162790, 18.1554639>,
    <2.0759607, -0.0748464, 18.1554639>,
    <2.1488250, -0.1123036, 18.1468283>,
    <2.1124665, -0.0955627, 18.1554639>,
    <2.0759186, -0.0728878, 18.1465526>,
    <2.1123718, -0.0925957, 18.1466904>,
    <2.0029492, -0.0334137, 18.1554639>,
    <2.0394549, -0.0541300, 18.1554639>,
    <2.0030121, -0.0334721, 18.1462770>,
    <2.0394654, -0.0531800, 18.1464148>,
    <2.1487271, -0.0333024, 18.1381926>,
    <2.1487024, -0.0708152, 18.1381926>,
    <2.1485808, -0.0306627, 18.1295570>,
    <2.1485556, -0.0675077, 18.1295570>,
    <2.1487766, 0.0417234, 18.1381926>,
    <2.1486313, 0.0430272, 18.1295570>,
    <2.1487519, 0.0042105, 18.1381926>,
    <2.1486060, 0.0061822, 18.1295570>,
    <2.1490672, 0.0391158, 18.1554639>,
    <2.1490198, -0.0385816, 18.1554639>,
    <2.1489219, 0.0404196, 18.1468283>,
    <2.1490435, 0.0002671, 18.1554639>,
    <2.1488734, -0.0359420, 18.1468283>,
    <2.1488977, 0.0022388, 18.1468283>,
    <2.1489960, -0.0774303, 18.1554639>,
    <2.1488492, -0.0741228, 18.1468283>,
    <2.0759165, 0.0537856, 18.1376413>,
    <2.1123465, 0.0477545, 18.1379170>,
    <2.0758797, 0.0544388, 18.1287301>,
    <2.1122555, 0.0487330, 18.1291435>,
    <2.0030563, 0.0658478, 18.1370901>,
    <2.0031281, 0.0658504, 18.1279032>,
    <2.0394864, 0.0598167, 18.1373657>,
    <2.0395039, 0.0601446, 18.1283166>,
    <2.0029127, 0.0658426, 18.1554639>,
    <2.0759900, 0.0524792, 18.1554639>,
    <2.0029845, 0.0658452, 18.1462770>,
    <2.0394514, 0.0591609, 18.1554639>,
    <2.0759532, 0.0531324, 18.1465526>,
    <2.0394689, 0.0594888, 18.1464148>,
    <2.1125286, 0.0457975, 18.1554639>,
    <2.1124376, 0.0467760, 18.1466904>,
    <2.0809036, -0.0776221, 18.1573801>,
    <2.0028599, -0.0333309, 18.1573801>,
    <2.0418818, -0.0554765, 18.1573801>,
    <2.0029045, -0.0333723, 18.1564220>,
    <2.0784322, -0.0762342, 18.1564220>,
    <2.0406684, -0.0548033, 18.1564220>,
    <2.1589474, -0.1219133, 18.1573801>,
    <2.1539599, -0.1190962, 18.1564220>,
    <2.1199255, -0.0997677, 18.1573801>,
    <2.1161960, -0.0976652, 18.1564220>,
    <2.1689225, -0.1275476, 18.1592964>,
    <2.0858466, -0.0803979, 18.1592964>,
    <2.1639350, -0.1247304, 18.1583383>,
    <2.1273846, -0.1039727, 18.1592964>,
    <2.0833751, -0.0790100, 18.1583383>,
    <2.1236550, -0.1018702, 18.1583383>,
    <2.0027706, -0.0332481, 18.1592964>,
    <2.0443086, -0.0568230, 18.1592964>,
    <2.0028152, -0.0332895, 18.1583383>,
    <2.0430952, -0.0561498, 18.1583383>,
    <2.1589935, -0.0423226, 18.1573801>,
    <2.1589704, -0.0821180, 18.1573801>,
    <2.1540066, -0.0404521, 18.1564220>,
    <2.1539832, -0.0797741, 18.1564220>,
    <2.1590395, 0.0372681, 18.1573801>,
    <2.1540534, 0.0381920, 18.1564220>,
    <2.1590165, -0.0025273, 18.1573801>,
    <2.1540300, -0.0011301, 18.1564220>,
    <2.1690118, 0.0354203, 18.1592964>,
    <2.1689672, -0.0460636, 18.1592964>,
    <2.1640257, 0.0363442, 18.1583383>,
    <2.1689895, -0.0053217, 18.1592964>,
    <2.1639803, -0.0441931, 18.1583383>,
    <2.1640030, -0.0039245, 18.1583383>,
    <2.1689449, -0.0868056, 18.1592964>,
    <2.1639576, -0.0844618, 18.1583383>,
    <2.0809253, 0.0515535, 18.1573801>,
    <2.1199824, 0.0444108, 18.1573801>,
    <2.0784576, 0.0520164, 18.1564220>,
    <2.1162555, 0.0451042, 18.1564220>,
    <2.0028110, 0.0658390, 18.1573801>,
    <2.0028619, 0.0658408, 18.1564220>,
    <2.0418681, 0.0586962, 18.1573801>,
    <2.0406598, 0.0589286, 18.1564220>,
    <2.0027093, 0.0658353, 18.1592964>,
    <2.0858605, 0.0506278, 18.1592964>,
    <2.0027601, 0.0658371, 18.1583383>,
    <2.0442849, 0.0582315, 18.1592964>,
    <2.0833929, 0.0510906, 18.1583383>,
    <2.0430765, 0.0584639, 18.1583383>,
    <2.1274362, 0.0430240, 18.1592964>,
    <2.1237093, 0.0437174, 18.1583383>,
    <2.0874016, -0.0810057, 18.2324892>,
    <2.0027700, -0.0332476, 18.2344341>,
    <2.0450846, -0.0571256, 18.2333227>,
    <2.0027703, -0.0332479, 18.1968653>,
    <2.0858626, -0.0804069, 18.1968653>,
    <2.0443164, -0.0568274, 18.1968653>,
    <2.1720474, -0.1287770, 18.2322113>,
    <2.1689548, -0.1275658, 18.1968653>,
    <2.1297234, -0.1048903, 18.2322113>,
    <2.1274087, -0.1039863, 18.1968653>,
    <2.1996546, -0.1395496, 18.2873438>,
    <2.1011317, -0.0863238, 18.2890109>,
    <2.1812606, -0.1323739, 18.2631118>,
    <2.1503860, -0.1129301, 18.2873438>,
    <2.0919868, -0.0827843, 18.2642232>,
    <2.1366190, -0.1075747, 18.2631118>,
    <2.0027694, -0.0332471, 18.3095719>,
    <2.0519057, -0.0597438, 18.2940122>,
    <2.0027697, -0.0332473, 18.2720030>,
    <2.0473735, -0.0580115, 18.2675574>,
    <2.1720918, -0.0468799, 18.2322113>,
    <2.1720696, -0.0878285, 18.2322113>,
    <2.1689995, -0.0460758, 18.1968653>,
    <2.1689772, -0.0868208, 18.1968653>,
    <2.1721361, 0.0350171, 18.2322113>,
    <2.1690441, 0.0354143, 18.1968653>,
    <2.1721139, -0.0059314, 18.2322113>,
    <2.1690218, -0.0053307, 18.1968653>,
    <2.1997378, 0.0314842, 18.2873438>,
    <2.1996962, -0.0540327, 18.2873438>,
    <2.1813474, 0.0338375, 18.2631118>,
    <2.1997170, -0.0112743, 18.2873438>,
    <2.1813040, -0.0492682, 18.2631118>,
    <2.1813257, -0.0077154, 18.2631118>,
    <2.1996754, -0.0967911, 18.2873438>,
    <2.1812823, -0.0908211, 18.2631118>,
    <2.0874143, 0.0504259, 18.2324892>,
    <2.1297738, 0.0427214, 18.2322113>,
    <2.0858765, 0.0506248, 18.1968653>,
    <2.1274603, 0.0430195, 18.1968653>,
    <2.0027086, 0.0658353, 18.2344341>,
    <2.0027089, 0.0658353, 18.1968653>,
    <2.0450601, 0.0581305, 18.2333227>,
    <2.0442927, 0.0582300, 18.1968653>,
    <2.0027079, 0.0658352, 18.3095719>,
    <2.1011313, 0.0486564, 18.2890109>,
    <2.0027083, 0.0658352, 18.2720030>,
    <2.0518685, 0.0572440, 18.2940122>,
    <2.0919955, 0.0498352, 18.2642232>,
    <2.0473465, 0.0578350, 18.2675574>,
    <2.1504265, 0.0400700, 18.2873438>,
    <2.1366661, 0.0418361, 18.2631118>,
    <2.1346539, -0.0992855, 18.3131904>,
    <2.0021640, -0.0326857, 18.3135798>,
    <2.0684089, -0.0659855, 18.3133573>,
    <2.0024667, -0.0329664, 18.3115759>,
    <2.1163499, -0.0922053, 18.3037960>,
    <2.0594036, -0.0625815, 18.3071303>,
    <2.2671445, -0.1658858, 18.3131347>,
    <2.2302897, -0.1514968, 18.3026846>,
    <2.2008992, -0.1325856, 18.3131347>,
    <2.1733151, -0.1218467, 18.3026846>,
    <2.3354274, -0.1926700, 18.3353648>,
    <2.1685696, -0.1124682, 18.3340315>,
    <2.3041976, -0.1803868, 18.3226946>,
    <2.2520053, -0.1525753, 18.3353648>,
    <2.1530564, -0.1064210, 18.3218058>,
    <2.2286315, -0.1434081, 18.3226946>,
    <2.0015586, -0.0321244, 18.3175878>,
    <2.0851068, -0.0723359, 18.3300317>,
    <2.0018613, -0.0324051, 18.3155838>,
    <2.0774634, -0.0694172, 18.3191392>,
    <2.2671795, -0.0715194, 18.3131347>,
    <2.2671620, -0.1187026, 18.3131347>,
    <2.2303283, -0.0619654, 18.3026846>,
    <2.2303090, -0.1067311, 18.3026846>,
    <2.2672145, 0.0228471, 18.3131347>,
    <2.2303669, 0.0275660, 18.3026846>,
    <2.2671970, -0.0243361, 18.3131347>,
    <2.2303476, -0.0171997, 18.3026846>,
    <2.3354839, 0.0140631, 18.3353648>,
    <2.3354557, -0.0893034, 18.3353648>,
    <2.3042602, 0.0180914, 18.3226946>,
    <2.3354698, -0.0376202, 18.3353648>,
    <2.3042289, -0.0811477, 18.3226946>,
    <2.3042446, -0.0315281, 18.3226946>,
    <2.3354416, -0.1409867, 18.3353648>,
    <2.3042132, -0.1307673, 18.3226946>,
    <2.1346158, 0.0443287, 18.3131904>,
    <2.2009151, 0.0335879, 18.3131347>,
    <2.1163326, 0.0466932, 18.3037960>,
    <2.1733444, 0.0371294, 18.3026846>,
    <2.0020180, 0.0658103, 18.3135798>,
    <2.0023629, 0.0658228, 18.3115759>,
    <2.0683168, 0.0550695, 18.3133573>,
    <2.0593424, 0.0562578, 18.3071303>,
    <2.0013280, 0.0657853, 18.3175878>,
    <2.1684932, 0.0399274, 18.3340315>,
    <2.0016730, 0.0657978, 18.3155838>,
    <2.0849593, 0.0528581, 18.3300317>,
    <2.1529974, 0.0419457, 18.3218058>,
    <2.0773403, 0.0538720, 18.3191392>,
    <2.2519963, 0.0269955, 18.3353648>,
    <2.2286339, 0.0300188, 18.3226946>,
    <2.1834288, -0.1184202, 18.3800376>,
    <2.0015296, -0.0320975, 18.3784821>,
    <2.0924803, -0.0752599, 18.3793709>,
    <2.0015441, -0.0321110, 18.3480349>,
    <2.1782054, -0.1162833, 18.3542569>,
    <2.0898793, -0.0742013, 18.3515903>,
    <2.3653145, -0.2047304, 18.3802598>,
    <2.3548127, -0.2004055, 18.3551457>,
    <2.2743728, -0.1615763, 18.3802598>,
    <2.2665136, -0.1583486, 18.3551457>,
    <2.3715124, -0.2076955, 18.4393764>,
    <2.1865065, -0.1198831, 18.4393764>,
    <2.3698941, -0.2067814, 18.4089292>,
    <2.2790095, -0.1637893, 18.4393764>,
    <2.1857046, -0.1194327, 18.4089292>,
    <2.2777993, -0.1631070, 18.4089292>,
    <2.0015006, -0.0320707, 18.4393764>,
    <2.0940036, -0.0759769, 18.4393764>,
    <2.0015151, -0.0320841, 18.4089292>,
    <2.0936098, -0.0757584, 18.4089292>,
    <2.3653397, -0.0973113, 18.3802598>,
    <2.3653271, -0.1510208, 18.3802598>,
    <2.3548390, -0.0944397, 18.3551457>,
    <2.3548259, -0.1474226, 18.3551457>,
    <2.3653649, 0.0101078, 18.3802598>,
    <2.3548653, 0.0115262, 18.3551457>,
    <2.3653523, -0.0436017, 18.3802598>,
    <2.3548521, -0.0414567, 18.3551457>,
    <2.3715613, 0.0091354, 18.4393764>,
    <2.3715369, -0.0992800, 18.4393764>,
    <2.3699434, 0.0094352, 18.4089292>,
    <2.3715491, -0.0450723, 18.4393764>,
    <2.3699187, -0.0986731, 18.4089292>,
    <2.3699311, -0.0446189, 18.4089292>,
    <2.3715246, -0.1534878, 18.4393764>,
    <2.3699064, -0.1527272, 18.4089292>,
    <2.1833376, 0.0379463, 18.3800376>,
    <2.2743526, 0.0240271, 18.3802598>,
    <2.1781192, 0.0386566, 18.3542569>,
    <2.2664974, 0.0250916, 18.3551457>,
    <2.0012950, 0.0657841, 18.3784821>,
    <2.0013115, 0.0657847, 18.3480349>,
    <2.0923176, 0.0518653, 18.3793709>,
    <2.0897205, 0.0522208, 18.3515903>,
    <2.0012619, 0.0657829, 18.4393764>,
    <2.1864116, 0.0374592, 18.4393764>,
    <2.0012785, 0.0657835, 18.4089292>,
    <2.0938368, 0.0516211, 18.4393764>,
    <2.1856109, 0.0376094, 18.4089292>,
    <2.0934447, 0.0516965, 18.4089292>,
    <2.2789865, 0.0232973, 18.4393764>,
    <2.2777772, 0.0235223, 18.4089292>,
    <2.1950579, -0.1246852, 18.4393764>,
    <2.0013462, -0.0319275, 18.4393764>,
    <2.0982021, -0.0783063, 18.4393764>,
    <2.0014234, -0.0319991, 18.4393764>,
    <2.1907822, -0.1222841, 18.4393764>,
    <2.0961028, -0.0771416, 18.4393764>,
    <2.3887697, -0.2174430, 18.4393764>,
    <2.3801411, -0.2125692, 18.4393764>,
    <2.2919138, -0.1710641, 18.4393764>,
    <2.2854617, -0.1674267, 18.4393764>,
    <2.4060270, -0.2271905, 18.4393764>,
    <2.2036094, -0.1294874, 18.4393764>,
    <2.3973984, -0.2223167, 18.4393764>,
    <2.3048182, -0.1783389, 18.4393764>,
    <2.1993337, -0.1270863, 18.4393764>,
    <2.2983660, -0.1747015, 18.4393764>,
    <2.0011917, -0.0317843, 18.4393764>,
    <2.1024005, -0.0806358, 18.4393764>,
    <2.0012689, -0.0318559, 18.4393764>,
    <2.1003013, -0.0794711, 18.4393764>,
    <2.3887917, -0.1057521, 18.4393764>,
    <2.3887807, -0.1615976, 18.4393764>,
    <2.3801643, -0.1025161, 18.4393764>,
    <2.3801527, -0.1575427, 18.4393764>,
    <2.3888137, 0.0059387, 18.4393764>,
    <2.3801875, 0.0075370, 18.4393764>,
    <2.3888027, -0.0499067, 18.4393764>,
    <2.3801759, -0.0474895, 18.4393764>,
    <2.4060661, 0.0027419, 18.4393764>,
    <2.4060466, -0.1122243, 18.4393764>,
    <2.3974399, 0.0043403, 18.4393764>,
    <2.4060563, -0.0547412, 18.4393764>,
    <2.3974192, -0.1089882, 18.4393764>,
    <2.3974295, -0.0523239, 18.4393764>,
    <2.4060368, -0.1697074, 18.4393764>,
    <2.3974088, -0.1656525, 18.4393764>,
    <2.1949498, 0.0358576, 18.4393764>,
    <2.2918818, 0.0208982, 18.4393764>,
    <2.1906807, 0.0366584, 18.4393764>,
    <2.2854341, 0.0220977, 18.4393764>,
    <2.0010859, 0.0657766, 18.4393764>,
    <2.0011739, 0.0657798, 18.4393764>,
    <2.0980179, 0.0508171, 18.4393764>,
    <2.0959273, 0.0512191, 18.4393764>,
    <2.0009099, 0.0657702, 18.4393764>,
    <2.2034880, 0.0342561, 18.4393764>,
    <2.0009979, 0.0657734, 18.4393764>,
    <2.1021990, 0.0500132, 18.4393764>,
    <2.1992189, 0.0350569, 18.4393764>,
    <2.1001084, 0.0504151, 18.4393764>,
    <2.3047771, 0.0184990, 18.4393764>,
    <2.2983294, 0.0196986, 18.4393764>,
    <2.2036094, -0.1294874, 18.4726341>,
    <2.0011917, -0.0317843, 18.4726341>,
    <2.1024005, -0.0806358, 18.4726341>,
    <2.0011917, -0.0317843, 18.4560052>,
    <2.2036094, -0.1294874, 18.4560052>,
    <2.1024005, -0.0806358, 18.4560052>,
    <2.4060270, -0.2271905, 18.4726341>,
    <2.4060270, -0.2271905, 18.4560052>,
    <2.3048182, -0.1783389, 18.4726341>,
    <2.3048182, -0.1783389, 18.4560052>,
    <2.4060270, -0.2271905, 18.4892630>,
    <2.2036094, -0.1294874, 18.4892630>,
    <2.3048182, -0.1783389, 18.4892630>,
    <2.0011917, -0.0317843, 18.4892630>,
    <2.1024005, -0.0806358, 18.4892630>,
    <2.4060466, -0.1122243, 18.4726341>,
    <2.4060368, -0.1697074, 18.4726341>,
    <2.4060466, -0.1122243, 18.4560052>,
    <2.4060368, -0.1697074, 18.4560052>,
    <2.4060661, 0.0027419, 18.4726341>,
    <2.4060661, 0.0027419, 18.4560052>,
    <2.4060563, -0.0547412, 18.4726341>,
    <2.4060563, -0.0547412, 18.4560052>,
    <2.4060661, 0.0027419, 18.4892630>,
    <2.4060466, -0.1122243, 18.4892630>,
    <2.4060563, -0.0547412, 18.4892630>,
    <2.4060368, -0.1697074, 18.4892630>,
    <2.2034880, 0.0342561, 18.4726341>,
    <2.3047771, 0.0184990, 18.4726341>,
    <2.2034880, 0.0342561, 18.4560052>,
    <2.3047771, 0.0184990, 18.4560052>,
    <2.0009099, 0.0657702, 18.4726341>,
    <2.0009099, 0.0657702, 18.4560052>,
    <2.1021990, 0.0500132, 18.4726341>,
    <2.1021990, 0.0500132, 18.4560052>,
    <2.0009099, 0.0657702, 18.4892630>,
    <2.2034880, 0.0342561, 18.4892630>,
    <2.1021990, 0.0500132, 18.4892630>,
    <2.3047771, 0.0184990, 18.4892630>,
    <2.0010508, 0.0169930, 18.4726341>,
    <2.0011917, -0.0317843, 18.4726341>,
    <2.0010508, 0.0169930, 18.4393764>,
    <2.0011213, -0.0073956, 18.4726341>,
    <2.0011917, -0.0317843, 18.4560052>,
    <2.0011213, -0.0073956, 18.4393764>,
    <2.0010508, 0.0169930, 18.4560052>,
    <2.0011213, -0.0073956, 18.4560052>,
    <2.0009099, 0.0657702, 18.4726341>,
    <2.0009804, 0.0413816, 18.4393764>,
    <2.0009099, 0.0657702, 18.4560052>,
    <2.0009804, 0.0413816, 18.4726341>,
    <2.0009804, 0.0413816, 18.4560052>,
    <2.0010508, 0.0169930, 18.5058918>,
    <2.0009099, 0.0657702, 18.4892630>,
    <2.0009804, 0.0413816, 18.5058918>,
    <2.0010508, 0.0169930, 18.4892630>,
    <2.0009804, 0.0413816, 18.4892630>,
    <2.0011213, -0.0073956, 18.5058918>,
    <2.0011917, -0.0317843, 18.4892630>,
    <2.0011213, -0.0073956, 18.4892630>,
    <2.0012160, 0.0169246, 18.4393764>,
    <2.0013813, 0.0168561, 18.4393764>,
    <2.0012987, 0.0168904, 18.4393764>,
    <2.0014410, -0.0076073, 18.4393764>,
    <2.0012811, -0.0075014, 18.4393764>,
    <2.0013610, -0.0075544, 18.4393764>,
    <2.0010508, 0.0169930, 18.4393764>,
    <2.0011213, -0.0073956, 18.4393764>,
    <2.0011334, 0.0169588, 18.4393764>,
    <2.0012012, -0.0074485, 18.4393764>,
    <2.0009804, 0.0413816, 18.4393764>,
    <2.0011510, 0.0413506, 18.4393764>,
    <2.0010657, 0.0413661, 18.4393764>,
    <2.0013216, 0.0413195, 18.4393764>,
    <2.0012363, 0.0413351, 18.4393764>,
    <2.0014123, 0.0168433, 18.3784821>,
    <2.0015296, -0.0320975, 18.3784821>,
    <2.0014433, 0.0168305, 18.3175878>,
    <2.0014709, -0.0076271, 18.3784821>,
    <2.0015441, -0.0321110, 18.3480349>,
    <2.0015009, -0.0076470, 18.3175878>,
    <2.0014278, 0.0168369, 18.3480349>,
    <2.0014859, -0.0076370, 18.3480349>,
    <2.0012950, 0.0657841, 18.3784821>,
    <2.0013856, 0.0413079, 18.3175878>,
    <2.0013115, 0.0657847, 18.3480349>,
    <2.0013536, 0.0413137, 18.3784821>,
    <2.0013696, 0.0413108, 18.3480349>,
    <2.0013813, 0.0168561, 18.4393764>,
    <2.0012785, 0.0657835, 18.4089292>,
    <2.0013216, 0.0413195, 18.4393764>,
    <2.0013968, 0.0168497, 18.4089292>,
    <2.0013376, 0.0413166, 18.4089292>,
    <2.0014410, -0.0076073, 18.4393764>,
    <2.0015151, -0.0320841, 18.4089292>,
    <2.0014559, -0.0076172, 18.4089292>,
    <2.0020910, 0.0165623, 18.3135798>,
    <2.0027387, 0.0162941, 18.3095719>,
    <2.0024148, 0.0164282, 18.3115759>,
    <2.0027541, -0.0084765, 18.3095719>,
    <2.0021275, -0.0080617, 18.3135798>,
    <2.0024408, -0.0082691, 18.3115759>,
    <2.0014433, 0.0168305, 18.3175878>,
    <2.0015009, -0.0076470, 18.3175878>,
    <2.0017671, 0.0166964, 18.3155838>,
    <2.0018142, -0.0078543, 18.3155838>,
    <2.0013856, 0.0413079, 18.3175878>,
    <2.0020545, 0.0411863, 18.3135798>,
    <2.0017200, 0.0412471, 18.3155838>,
    <2.0027233, 0.0410647, 18.3095719>,
    <2.0023889, 0.0411255, 18.3115759>,
    <2.0027393, 0.0162938, 18.2344341>,
    <2.0027700, -0.0332476, 18.2344341>,
    <2.0027399, 0.0162936, 18.1592964>,
    <2.0027547, -0.0084769, 18.2344341>,
    <2.0027703, -0.0332479, 18.1968653>,
    <2.0027553, -0.0084773, 18.1592964>,
    <2.0027396, 0.0162937, 18.1968653>,
    <2.0027550, -0.0084771, 18.1968653>,
    <2.0027086, 0.0658353, 18.2344341>,
    <2.0027246, 0.0410644, 18.1592964>,
    <2.0027089, 0.0658353, 18.1968653>,
    <2.0027240, 0.0410645, 18.2344341>,
    <2.0027243, 0.0410645, 18.1968653>,
    <2.0027387, 0.0162941, 18.3095719>,
    <2.0027083, 0.0658352, 18.2720030>,
    <2.0027233, 0.0410647, 18.3095719>,
    <2.0027390, 0.0162940, 18.2720030>,
    <2.0027236, 0.0410646, 18.2720030>,
    <2.0027541, -0.0084765, 18.3095719>,
    <2.0027697, -0.0332473, 18.2720030>,
    <2.0027544, -0.0084767, 18.2720030>,
    <2.0028354, 0.0162540, 18.1573801>,
    <2.0029309, 0.0162145, 18.1554639>,
    <2.0028832, 0.0162342, 18.1564220>,
    <2.0029400, -0.0085996, 18.1554639>,
    <2.0028477, -0.0085385, 18.1573801>,
    <2.0028939, -0.0085690, 18.1564220>,
    <2.0027399, 0.0162936, 18.1592964>,
    <2.0027553, -0.0084773, 18.1592964>,
    <2.0027877, 0.0162738, 18.1583383>,
    <2.0028015, -0.0085079, 18.1583383>,
    <2.0027246, 0.0410644, 18.1592964>,
    <2.0028232, 0.0410465, 18.1573801>,
    <2.0027739, 0.0410555, 18.1583383>,
    <2.0029218, 0.0410286, 18.1554639>,
    <2.0028725, 0.0410375, 18.1564220>,
    <2.0031242, 0.0161345, 18.1389725>,
    <2.0031356, -0.0335865, 18.1386133>,
    <2.0032596, 0.0160784, 18.1258340>,
    <2.0031288, -0.0087256, 18.1388528>,
    <2.0032288, -0.0336729, 18.1301880>,
    <2.0032692, -0.0088236, 18.1251156>,
    <2.0032053, 0.0161009, 18.1316249>,
    <2.0032129, -0.0087843, 18.1311460>,
    <2.0031252, 0.0658503, 18.1386133>,
    <2.0032749, 0.0409701, 18.1251156>,
    <2.0032314, 0.0658542, 18.1301880>,
    <2.0031236, 0.0409928, 18.1388528>,
    <2.0032142, 0.0409792, 18.1311460>,
    <2.0029309, 0.0162145, 18.1554639>,
    <2.0030190, 0.0658465, 18.1470386>,
    <2.0029218, 0.0410286, 18.1554639>,
    <2.0030307, 0.0161732, 18.1470386>,
    <2.0030248, 0.0410098, 18.1470386>,
    <2.0029400, -0.0085996, 18.1554639>,
    <2.0030424, -0.0335001, 18.1470386>,
    <2.0030365, -0.0086635, 18.1470386>,
    <2.0032590, 0.0160787, 18.1205987>,
    <2.0032727, 0.0160730, 18.1224380>,
    <2.0032592, -0.0088119, 18.1204790>,
    <2.0032781, -0.0088275, 18.1219591>,
    <2.0032005, 0.0161029, 18.1187163>,
    <2.0032008, -0.0087722, 18.1187163>,
    <2.0032328, 0.0160895, 18.1194779>,
    <2.0032321, -0.0087929, 18.1194779>,
    <2.0032002, 0.0409779, 18.1187163>,
    <2.0032628, 0.0409675, 18.1204790>,
    <2.0032336, 0.0409719, 18.1194779>,
    <2.0032838, 0.0409666, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.2905185, 0.5520584, 0.7815565>,
    <0.1402752, 0.2717584, 0.9520873>,
    <0.1452503, 0.3043949, 0.9414064>,
    <0.2904158, 0.5888277, 0.7542815>,
    <0.4503017, 0.8927509, 0.0149707>,
    <0.4703139, 0.8823914, 0.0137959>,
    <0.4703139, 0.8823914, 0.0137959>,
    <0.4933598, 0.8697367, 0.0124165>,
    <0.2899477, 0.5111445, 0.8091117>,
    <0.2899477, 0.5111445, 0.8091117>,
    <0.1350057, 0.2379995, 0.9618366>,
    <0.0709628, 0.1420534, 0.9873121>,
    <0.0752920, 0.1664715, 0.9831675>,
    <0.1350057, 0.2379995, 0.9618366>,
    <0.0665477, 0.1173160, 0.9908624>,
    <0.0665477, 0.1173160, 0.9908624>,
    <0.0304015, 0.0535943, 0.9980999>,
    <0.0339096, 0.0726304, 0.9967823>,
    <0.0339096, 0.0726304, 0.9967823>,
    <0.0373904, 0.0915607, 0.9950973>,
    <0.0795291, 0.1905307, 0.9784545>,
    <0.1499304, 0.3358470, 0.9299074>,
    <0.0373904, 0.0915607, 0.9950973>,
    <0.0408405, 0.1103649, 0.9930517>,
    <0.0408405, 0.1103649, 0.9930517>,
    <0.0442564, 0.1290236, 0.9906535>,
    <0.0836685, 0.2141944, 0.9732011>,
    <0.0836685, 0.2141944, 0.9732011>,
    <0.1543179, 0.3660700, 0.9177030>,
    <0.2897772, 0.6218040, 0.7275912>,
    <0.1543179, 0.3660700, 0.9177030>,
    <0.2887204, 0.6513470, 0.7017034>,
    <0.2887204, 0.6513470, 0.7017034>,
    <0.4173569, 0.9085862, 0.0168598>,
    <0.4327902, 0.9013530, 0.0159816>,
    <0.4327902, 0.9013530, 0.0159816>,
    <0.4503017, 0.8927509, 0.0149707>,
    <-0.0204816, 0.0000154, -0.9997902>,
    <-0.0204825, 0.0000154, -0.9997902>,
    <-0.0204826, 0.0000151, -0.9997902>,
    <-0.0204816, 0.0000151, -0.9997902>,
    <-0.0204807, 0.0000151, -0.9997902>,
    <-0.0204806, 0.0000154, -0.9997903>,
    <-0.0204806, 0.0000154, -0.9997903>,
    <-0.0204806, 0.0000157, -0.9997903>,
    <-0.0204815, 0.0000157, -0.9997902>,
    <-0.0204815, 0.0000157, -0.9997902>,
    <-0.0204825, 0.0000157, -0.9997902>,
    <-0.0204835, 0.0000154, -0.9997902>,
    <-0.0204835, 0.0000151, -0.9997902>,
    <-0.0204825, 0.0000157, -0.9997902>,
    <-0.0204835, 0.0000157, -0.9997902>,
    <-0.0204835, 0.0000157, -0.9997902>,
    <-0.0204844, 0.0000157, -0.9997902>,
    <-0.0204844, 0.0000154, -0.9997902>,
    <-0.0204844, 0.0000154, -0.9997902>,
    <-0.0204845, 0.0000151, -0.9997902>,
    <-0.0204835, 0.0000148, -0.9997902>,
    <-0.0204826, 0.0000148, -0.9997902>,
    <-0.0204845, 0.0000151, -0.9997902>,
    <-0.0204845, 0.0000148, -0.9997902>,
    <-0.0204845, 0.0000148, -0.9997902>,
    <-0.0204845, 0.0000146, -0.9997902>,
    <-0.0204836, 0.0000146, -0.9997902>,
    <-0.0204836, 0.0000146, -0.9997902>,
    <-0.0204826, 0.0000146, -0.9997902>,
    <-0.0204816, 0.0000148, -0.9997902>,
    <-0.0204826, 0.0000146, -0.9997902>,
    <-0.0204817, 0.0000146, -0.9997902>,
    <-0.0204817, 0.0000146, -0.9997902>,
    <-0.0204808, 0.0000146, -0.9997902>,
    <-0.0204807, 0.0000148, -0.9997902>,
    <-0.0204807, 0.0000148, -0.9997902>,
    <-0.0204807, 0.0000151, -0.9997902>,
    <-0.0662447, -0.4111287, -0.9091671>,
    <-0.1108606, -0.6660332, -0.7376379>,
    <-0.1095162, -0.7112873, -0.6943173>,
    <-0.0684816, -0.4690491, -0.8805130>,
    <-0.0365428, -0.2769570, -0.9601872>,
    <-0.0335113, -0.2224108, -0.9743769>,
    <-0.0335113, -0.2224108, -0.9743769>,
    <-0.0302898, -0.1657078, -0.9857096>,
    <-0.0635669, -0.3477583, -0.9354269>,
    <-0.0635669, -0.3477583, -0.9354269>,
    <-0.1118536, -0.6119224, -0.7829686>,
    <-0.1535213, -0.9048173, -0.3971611>,
    <-0.1463369, -0.9197800, -0.3641294>,
    <-0.1118536, -0.6119224, -0.7829686>,
    <-0.1618285, -0.8853226, -0.4359076>,
    <-0.1618285, -0.8853226, -0.4359076>,
    <-0.1798026, -0.9836545, 0.0097355>,
    <-0.1693426, -0.9855137, 0.0092657>,
    <-0.1693426, -0.9855137, 0.0092657>,
    <-0.1605629, -0.9869857, 0.0088712>,
    <-0.1400938, -0.9314731, -0.3357554>,
    <-0.1079638, -0.7490918, -0.6536095>,
    <-0.1605629, -0.9869857, 0.0088712>,
    <-0.1530904, -0.9881753, 0.0085354>,
    <-0.1530904, -0.9881753, 0.0085354>,
    <-0.1466544, -0.9891534, 0.0082461>,
    <-0.1346375, -0.9407615, -0.3111923>,
    <-0.1346375, -0.9407615, -0.3111923>,
    <-0.1063062, -0.7807166, -0.6157764>,
    <-0.0703159, -0.5214845, -0.8503585>,
    <-0.1063062, -0.7807166, -0.6157764>,
    <-0.0717927, -0.5686019, -0.8194740>,
    <-0.0717927, -0.5686019, -0.8194740>,
    <-0.0419808, -0.3781463, -0.9247935>,
    <-0.0393689, -0.3289623, -0.9435221>,
    <-0.0393689, -0.3289623, -0.9435221>,
    <-0.0365428, -0.2769570, -0.9601872>,
    <-0.4347988, -0.8955530, -0.0945242>,
    <-0.4277094, -0.8832676, -0.1921017>,
    <-0.4474863, -0.8738858, -0.1899461>,
    <-0.4543800, -0.8858841, -0.0935316>,
    <-0.4569573, -0.8894851, 0.0025216>,
    <-0.4376511, -0.8991408, 0.0027153>,
    <-0.4376511, -0.8991408, 0.0027153>,
    <-0.4176624, -0.9085976, 0.0029125>,
    <-0.4145213, -0.9050154, -0.0954944>,
    <-0.4145213, -0.9050154, -0.0954944>,
    <-0.4072389, -0.8924336, -0.1942130>,
    <-0.4165475, -0.8625568, -0.2872001>,
    <-0.4364256, -0.8537413, -0.2840042>,
    <-0.4072389, -0.8924336, -0.1942130>,
    <-0.3959953, -0.8711474, -0.2903272>,
    <-0.3959953, -0.8711474, -0.2903272>,
    <-0.3813068, -0.8421931, -0.3812032>,
    <-0.4018166, -0.8343954, -0.3772636>,
    <-0.4018166, -0.8343954, -0.3772636>,
    <-0.4216870, -0.8263660, -0.3732282>,
    <-0.4556319, -0.8447357, -0.2807512>,
    <-0.4665739, -0.8643246, -0.1877544>,
    <-0.4216870, -0.8263660, -0.3732282>,
    <-0.4409176, -0.8181370, -0.3691118>,
    <-0.4409176, -0.8181370, -0.3691118>,
    <-0.4595111, -0.8097387, -0.3649284>,
    <-0.4741714, -0.8355727, -0.2774523>,
    <-0.4741714, -0.8355727, -0.2774523>,
    <-0.4849793, -0.8546181, -0.1855340>,
    <-0.4732705, -0.8760451, -0.0925204>,
    <-0.4849793, -0.8546181, -0.1855340>,
    <-0.4914783, -0.8660704, -0.0914941>,
    <-0.4914783, -0.8660704, -0.0914941>,
    <-0.4935473, -0.8697163, 0.0021450>,
    <-0.4755866, -0.8796658, 0.0023314>,
    <-0.4755866, -0.8796658, 0.0023314>,
    <-0.4569573, -0.8894851, 0.0025216>,
    <0.9998508, -0.0006848, -0.0172627>,
    <0.9998527, -0.0006848, -0.0171518>,
    <0.9998528, -0.0006593, -0.0171440>,
    <0.9998509, -0.0006593, -0.0172530>,
    <0.9998491, -0.0006593, -0.0173619>,
    <0.9998488, -0.0006848, -0.0173736>,
    <0.9998488, -0.0006848, -0.0173736>,
    <0.9998486, -0.0007113, -0.0173858>,
    <0.9998506, -0.0007113, -0.0172729>,
    <0.9998506, -0.0007113, -0.0172729>,
    <0.9998525, -0.0007113, -0.0171599>,
    <0.9998546, -0.0006848, -0.0170410>,
    <0.9998547, -0.0006593, -0.0170351>,
    <0.9998525, -0.0007113, -0.0171599>,
    <0.9998544, -0.0007113, -0.0170470>,
    <0.9998544, -0.0007113, -0.0170470>,
    <0.9998564, -0.0007113, -0.0169341>,
    <0.9998564, -0.0006848, -0.0169301>,
    <0.9998564, -0.0006848, -0.0169301>,
    <0.9998565, -0.0006593, -0.0169262>,
    <0.9998548, -0.0006347, -0.0170295>,
    <0.9998530, -0.0006347, -0.0171365>,
    <0.9998565, -0.0006593, -0.0169262>,
    <0.9998566, -0.0006347, -0.0169225>,
    <0.9998566, -0.0006347, -0.0169225>,
    <0.9998567, -0.0006109, -0.0169189>,
    <0.9998549, -0.0006109, -0.0170241>,
    <0.9998549, -0.0006109, -0.0170241>,
    <0.9998531, -0.0006109, -0.0171292>,
    <0.9998511, -0.0006347, -0.0172435>,
    <0.9998531, -0.0006109, -0.0171292>,
    <0.9998513, -0.0006109, -0.0172344>,
    <0.9998513, -0.0006109, -0.0172344>,
    <0.9998495, -0.0006109, -0.0173396>,
    <0.9998493, -0.0006347, -0.0173505>,
    <0.9998493, -0.0006347, -0.0173505>,
    <0.9998491, -0.0006593, -0.0173619>,
    <0.1528590, 0.9823322, 0.1079703>,
    <0.1537707, 0.9855089, 0.0716019>,
    <0.1623861, 0.9841359, 0.0714657>,
    <0.1615861, 0.9809612, 0.1077268>,
    <0.1605452, 0.9763635, 0.1447054>,
    <0.1517144, 0.9777221, 0.1450592>,
    <0.1517144, 0.9777221, 0.1450592>,
    <0.1428198, 0.9790099, 0.1454033>,
    <0.1440693, 0.9836338, 0.1082067>,
    <0.1440693, 0.9836338, 0.1082067>,
    <0.1450940, 0.9868141, 0.0717334>,
    <0.1544617, 0.9873400, 0.0360747>,
    <0.1629585, 0.9859744, 0.0360417>,
    <0.1450940, 0.9868141, 0.0717334>,
    <0.1459052, 0.9886395, 0.0361052>,
    <0.1459052, 0.9886395, 0.0361052>,
    <0.1465156, 0.9892073, 0.0014244>,
    <0.1549461, 0.9879218, 0.0014899>,
    <0.1549461, 0.9879218, 0.0014899>,
    <0.1633184, 0.9865722, 0.0015550>,
    <0.1713941, 0.9845444, 0.0360062>,
    <0.1709387, 0.9826966, 0.0713249>,
    <0.1633184, 0.9865722, 0.0015550>,
    <0.1716312, 0.9851599, 0.0016195>,
    <0.1716312, 0.9851599, 0.0016195>,
    <0.1798835, 0.9836865, 0.0016836>,
    <0.1797674, 0.9830514, 0.0359683>,
    <0.1797674, 0.9830514, 0.0359683>,
    <0.1794275, 0.9811928, 0.0711797>,
    <0.1702492, 0.9795224, 0.1074765>,
    <0.1794275, 0.9811928, 0.0711797>,
    <0.1788468, 0.9780173, 0.1072194>,
    <0.1788468, 0.9780173, 0.1072194>,
    <0.1780098, 0.9734398, 0.1439701>,
    <0.1693108, 0.9749355, 0.1443423>,
    <0.1693108, 0.9749355, 0.1443423>,
    <0.1605452, 0.9763635, 0.1447054>,
    <-0.4935128, -0.8696267, 0.0139473>,
    <-0.4935170, -0.8696341, 0.0133223>,
    <-0.4935284, -0.8696271, 0.0133618>,
    <-0.4935243, -0.8696199, 0.0139666>,
    <-0.4935200, -0.8696124, 0.0145714>,
    <-0.4935084, -0.8696189, 0.0145722>,
    <-0.4935084, -0.8696189, 0.0145722>,
    <-0.4934960, -0.8696260, 0.0145731>,
    <-0.4935005, -0.8696340, 0.0139266>,
    <-0.4935005, -0.8696340, 0.0139266>,
    <-0.4935049, -0.8696416, 0.0132801>,
    <-0.4935210, -0.8696412, 0.0126973>,
    <-0.4935323, -0.8696339, 0.0127570>,
    <-0.4935049, -0.8696416, 0.0132801>,
    <-0.4935090, -0.8696489, 0.0126336>,
    <-0.4935090, -0.8696489, 0.0126336>,
    <-0.4935129, -0.8696558, 0.0119871>,
    <-0.4935248, -0.8696479, 0.0120724>,
    <-0.4935248, -0.8696479, 0.0120724>,
    <-0.4935360, -0.8696405, 0.0121521>,
    <-0.4935428, -0.8696271, 0.0128129>,
    <-0.4935390, -0.8696204, 0.0133988>,
    <-0.4935360, -0.8696405, 0.0121521>,
    <-0.4935464, -0.8696335, 0.0122270>,
    <-0.4935464, -0.8696335, 0.0122270>,
    <-0.4935562, -0.8696270, 0.0122972>,
    <-0.4935527, -0.8696207, 0.0128654>,
    <-0.4935527, -0.8696207, 0.0128654>,
    <-0.4935490, -0.8696142, 0.0134336>,
    <-0.4935350, -0.8696135, 0.0139847>,
    <-0.4935490, -0.8696142, 0.0134336>,
    <-0.4935451, -0.8696075, 0.0140018>,
    <-0.4935451, -0.8696075, 0.0140018>,
    <-0.4935411, -0.8696004, 0.0145699>,
    <-0.4935309, -0.8696062, 0.0145706>,
    <-0.4935309, -0.8696062, 0.0145706>,
    <-0.4935200, -0.8696124, 0.0145714>,
    <0.1886155, -0.0001121, -0.9820510>,
    <0.1886387, -0.0001122, -0.9820466>,
    <0.1886398, -0.0001091, -0.9820463>,
    <0.1886169, -0.0001091, -0.9820507>,
    <0.1885939, -0.0001091, -0.9820551>,
    <0.1885923, -0.0001121, -0.9820555>,
    <0.1885923, -0.0001121, -0.9820555>,
    <0.1885906, -0.0001152, -0.9820558>,
    <0.1886141, -0.0001152, -0.9820513>,
    <0.1886141, -0.0001152, -0.9820513>,
    <0.1886376, -0.0001152, -0.9820468>,
    <0.1886619, -0.0001122, -0.9820421>,
    <0.1886627, -0.0001092, -0.9820419>,
    <0.1886376, -0.0001152, -0.9820468>,
    <0.1886611, -0.0001153, -0.9820423>,
    <0.1886611, -0.0001153, -0.9820423>,
    <0.1886845, -0.0001153, -0.9820377>,
    <0.1886851, -0.0001122, -0.9820376>,
    <0.1886851, -0.0001122, -0.9820376>,
    <0.1886856, -0.0001092, -0.9820375>,
    <0.1886635, -0.0001062, -0.9820418>,
    <0.1886408, -0.0001062, -0.9820461>,
    <0.1886856, -0.0001092, -0.9820375>,
    <0.1886862, -0.0001062, -0.9820374>,
    <0.1886862, -0.0001062, -0.9820374>,
    <0.1886867, -0.0001034, -0.9820373>,
    <0.1886643, -0.0001033, -0.9820416>,
    <0.1886643, -0.0001033, -0.9820416>,
    <0.1886419, -0.0001033, -0.9820459>,
    <0.1886182, -0.0001062, -0.9820505>,
    <0.1886419, -0.0001033, -0.9820459>,
    <0.1886195, -0.0001033, -0.9820502>,
    <0.1886195, -0.0001033, -0.9820502>,
    <0.1885971, -0.0001033, -0.9820545>,
    <0.1885955, -0.0001062, -0.9820548>,
    <0.1885955, -0.0001062, -0.9820548>,
    <0.1885939, -0.0001091, -0.9820551>,
    <0.1798765, 0.9836142, 0.0121470>,
    <0.1798770, 0.9836170, 0.0119110>,
    <0.1798827, 0.9836161, 0.0118961>,
    <0.1798822, 0.9836134, 0.0121244>,
    <0.1798817, 0.9836107, 0.0123528>,
    <0.1798760, 0.9836114, 0.0123829>,
    <0.1798760, 0.9836114, 0.0123829>,
    <0.1798699, 0.9836121, 0.0124151>,
    <0.1798705, 0.9836150, 0.0121710>,
    <0.1798705, 0.9836150, 0.0121710>,
    <0.1798710, 0.9836179, 0.0119270>,
    <0.1798775, 0.9836197, 0.0116751>,
    <0.1798831, 0.9836188, 0.0116678>,
    <0.1798710, 0.9836179, 0.0119270>,
    <0.1798715, 0.9836207, 0.0116829>,
    <0.1798715, 0.9836207, 0.0116829>,
    <0.1798720, 0.9836235, 0.0114388>,
    <0.1798780, 0.9836224, 0.0114391>,
    <0.1798780, 0.9836224, 0.0114391>,
    <0.1798836, 0.9836214, 0.0114394>,
    <0.1798884, 0.9836179, 0.0116609>,
    <0.1798879, 0.9836153, 0.0118821>,
    <0.1798836, 0.9836214, 0.0114394>,
    <0.1798889, 0.9836204, 0.0114397>,
    <0.1798889, 0.9836204, 0.0114397>,
    <0.1798938, 0.9836195, 0.0114400>,
    <0.1798933, 0.9836171, 0.0116545>,
    <0.1798933, 0.9836171, 0.0116545>,
    <0.1798929, 0.9836146, 0.0118690>,
    <0.1798875, 0.9836127, 0.0121033>,
    <0.1798929, 0.9836146, 0.0118690>,
    <0.1798924, 0.9836121, 0.0120835>,
    <0.1798924, 0.9836121, 0.0120835>,
    <0.1798920, 0.9836095, 0.0122980>,
    <0.1798870, 0.9836101, 0.0123245>,
    <0.1798870, 0.9836101, 0.0123245>,
    <0.1798817, 0.9836107, 0.0123528>,
    <-0.4932270, -0.8698992, 0.0016126>,
    <-0.4932276, -0.8698942, 0.0032474>,
    <-0.4905562, -0.8713009, 0.0137574>,
    <-0.4905945, -0.8713630, 0.0065962>,
    <-0.4907487, -0.8713011, 0.0000024>,
    <-0.4932312, -0.8698982, 0.0000024>,
    <-0.4932312, -0.8698982, 0.0000024>,
    <-0.4935935, -0.8696927, 0.0000024>,
    <-0.4935935, -0.8696927, 0.0000023>,
    <-0.4935935, -0.8696927, 0.0000023>,
    <-0.4935935, -0.8696927, 0.0000022>,
    <-0.4932312, -0.8698846, 0.0048697>,
    <-0.4906341, -0.8711136, 0.0209607>,
    <-0.4935935, -0.8696927, 0.0000022>,
    <-0.4935935, -0.8696927, 0.0000021>,
    <-0.4935935, -0.8696927, 0.0000021>,
    <-0.4935935, -0.8696927, 0.0000020>,
    <-0.4932299, -0.8698749, 0.0064715>,
    <-0.4932299, -0.8698749, 0.0064715>,
    <-0.4906286, -0.8709211, 0.0279272>,
    <-0.4834834, -0.8737139, 0.0535524>,
    <-0.4830387, -0.8749107, 0.0347105>,
    <-0.4906286, -0.8709211, 0.0279272>,
    <-0.4834444, -0.8724411, 0.0716107>,
    <-0.4834444, -0.8724411, 0.0716107>,
    <-0.4681922, -0.8689935, 0.1601450>,
    <-0.4694776, -0.8747706, 0.1198633>,
    <-0.4690172, -0.8796178, 0.0793433>,
    <-0.4831981, -0.8753646, 0.0160118>,
    <-0.4684035, -0.8825873, 0.0404689>,
    <-0.4732875, -0.8809041, 0.0026299>,
    <-0.4844174, -0.8748370, 0.0000025>,
    <-0.4844174, -0.8748370, 0.0000025>,
    <-0.4907487, -0.8713011, 0.0000024>,
    <0.9990825, -0.0005461, -0.0428231>,
    <0.9990827, -0.0005461, -0.0428194>,
    <0.9831797, -0.0005300, -0.1826399>,
    <0.9831770, -0.0005300, -0.1826548>,
    <0.9831742, -0.0005300, -0.1826698>,
    <0.9990824, -0.0005461, -0.0428267>,
    <0.9990824, -0.0005461, -0.0428267>,
    <0.9999995, -0.0005477, -0.0008604>,
    <0.9999995, -0.0005477, -0.0008602>,
    <0.9999995, -0.0005477, -0.0008602>,
    <0.9999995, -0.0005477, -0.0008601>,
    <0.9990828, -0.0005461, -0.0428157>,
    <0.9831825, -0.0005300, -0.1826250>,
    <0.9999995, -0.0005477, -0.0008601>,
    <0.9999995, -0.0005477, -0.0008600>,
    <0.9999995, -0.0005477, -0.0008600>,
    <0.9999995, -0.0005477, -0.0008599>,
    <0.9990830, -0.0005461, -0.0428121>,
    <0.9990830, -0.0005461, -0.0428121>,
    <0.9831853, -0.0005300, -0.1826101>,
    <0.8941700, -0.0004644, -0.4477273>,
    <0.8941551, -0.0004644, -0.4477571>,
    <0.9831853, -0.0005300, -0.1826101>,
    <0.8941849, -0.0004644, -0.4476975>,
    <0.8941849, -0.0004644, -0.4476975>,
    <0.6281233, -0.0003032, -0.7781137>,
    <0.6280926, -0.0003032, -0.7781385>,
    <0.6280619, -0.0003032, -0.7781633>,
    <0.8941402, -0.0004644, -0.4477869>,
    <0.6280312, -0.0003032, -0.7781881>,
    <0.6280005, -0.0003031, -0.7782129>,
    <0.8941253, -0.0004644, -0.4478166>,
    <0.8941253, -0.0004644, -0.4478166>,
    <0.9831742, -0.0005300, -0.1826698>,
    <0.1797410, 0.9837125, -0.0016805>,
    <0.1797430, 0.9837130, -0.0011033>,
    <0.1785709, 0.9839159, -0.0046738>,
    <0.1785903, 0.9838970, -0.0072269>,
    <0.1786081, 0.9838720, -0.0097525>,
    <0.1797406, 0.9837114, -0.0022621>,
    <0.1797406, 0.9837114, -0.0022621>,
    <0.1799056, 0.9836839, 0.0000020>,
    <0.1799056, 0.9836839, 0.0000020>,
    <0.1799056, 0.9836839, 0.0000020>,
    <0.1799056, 0.9836839, 0.0000020>,
    <0.1797468, 0.9837128, -0.0005410>,
    <0.1786120, 0.9839171, -0.0022176>,
    <0.1799056, 0.9836839, 0.0000020>,
    <0.1799056, 0.9836839, 0.0000019>,
    <0.1799056, 0.9836839, 0.0000019>,
    <0.1799056, 0.9836839, 0.0000019>,
    <0.1797500, 0.9837123, 0.0000019>,
    <0.1797500, 0.9837123, 0.0000019>,
    <0.1786866, 0.9839060, 0.0000019>,
    <0.1754813, 0.9844690, -0.0052155>,
    <0.1753361, 0.9844397, -0.0116538>,
    <0.1786866, 0.9839060, 0.0000019>,
    <0.1760417, 0.9843827, 0.0000019>,
    <0.1760417, 0.9843827, 0.0000019>,
    <0.1719493, 0.9851041, 0.0018113>,
    <0.1694499, 0.9854647, -0.0120892>,
    <0.1696164, 0.9851646, -0.0260942>,
    <0.1755718, 0.9842953, -0.0183637>,
    <0.1703640, 0.9845360, -0.0408044>,
    <0.1708014, 0.9837313, -0.0556743>,
    <0.1757337, 0.9841224, -0.0249169>,
    <0.1757337, 0.9841224, -0.0249169>,
    <0.1786081, 0.9838720, -0.0097525>,
    <-0.4516898, -0.8853808, 0.1098958>,
    <-0.4509098, -0.8785137, 0.1577785>,
    <-0.4385021, -0.8732636, 0.2124300>,
    <-0.4421987, -0.8809854, 0.1683002>,
    <-0.4481903, -0.8921035, 0.0572432>,
    <-0.4560135, -0.8882394, 0.0555203>,
    <-0.4560135, -0.8882394, 0.0555203>,
    <-0.4732875, -0.8809041, 0.0026299>,
    <-0.4483415, -0.8663137, 0.2202057>,
    <-0.4320140, -0.8597113, 0.2725075>,
    <-0.4681922, -0.8689935, 0.1601450>,
    <-0.4416745, -0.8496326, 0.2881806>,
    <-0.4416745, -0.8496326, 0.2881806>,
    <-0.4213719, -0.8382367, 0.3461286>,
    <-0.4314589, -0.8788040, 0.2038304>,
    <-0.4372380, -0.8859469, 0.1546642>,
    <-0.4213719, -0.8382367, 0.3461286>,
    <-0.4247184, -0.8673077, 0.2595990>,
    <-0.4247184, -0.8673077, 0.2595990>,
    <-0.4304872, -0.8946443, 0.1195502>,
    <-0.4323262, -0.8970446, 0.0916794>,
    <-0.4342888, -0.8985334, 0.0634894>,
    <-0.4412498, -0.8902770, 0.1127186>,
    <-0.4357788, -0.8994062, 0.0341353>,
    <-0.4343342, -0.9007433, 0.0039179>,
    <-0.4419903, -0.8951037, 0.0586000>,
    <-0.4419903, -0.8951037, 0.0586000>,
    <-0.4481903, -0.8921035, 0.0572432>,
    <0.3569395, -0.0001533, -0.9341275>,
    <0.3569636, -0.0001533, -0.9341183>,
    <0.2613339, -0.0000968, -0.9652484>,
    <0.2613160, -0.0000968, -0.9652533>,
    <0.2612981, -0.0000968, -0.9652581>,
    <0.3569154, -0.0001532, -0.9341367>,
    <0.3569154, -0.0001532, -0.9341367>,
    <0.6280005, -0.0003031, -0.7782129>,
    <0.3569876, -0.0001533, -0.9341091>,
    <0.2613518, -0.0000969, -0.9652436>,
    <0.6281233, -0.0003032, -0.7781137>,
    <0.3570117, -0.0001533, -0.9340999>,
    <0.3570117, -0.0001533, -0.9340999>,
    <0.2613697, -0.0000969, -0.9652388>,
    <0.3095899, -0.0000981, -0.9508702>,
    <0.3095702, -0.0000981, -0.9508766>,
    <0.2613697, -0.0000969, -0.9652388>,
    <0.3096096, -0.0000981, -0.9508638>,
    <0.3096096, -0.0000981, -0.9508638>,
    <0.5397936, -0.0001488, -0.8417974>,
    <0.5397675, -0.0001488, -0.8418141>,
    <0.5397414, -0.0001488, -0.8418308>,
    <0.3095506, -0.0000981, -0.9508830>,
    <0.5397154, -0.0001488, -0.8418475>,
    <0.5396893, -0.0001488, -0.8418642>,
    <0.3095309, -0.0000981, -0.9508894>,
    <0.3095309, -0.0000981, -0.9508894>,
    <0.2612981, -0.0000968, -0.9652581>,
    <0.1641275, 0.9835956, -0.0748463>,
    <0.1633033, 0.9852626, -0.0508886>,
    <0.1594133, 0.9849136, -0.0673247>,
    <0.1591928, 0.9829450, -0.0920696>,
    <0.1587227, 0.9797268, -0.1222398>,
    <0.1643746, 0.9811649, -0.1014715>,
    <0.1643746, 0.9811649, -0.1014715>,
    <0.1708014, 0.9837313, -0.0556743>,
    <0.1630548, 0.9861497, -0.0303632>,
    <0.1595961, 0.9861817, -0.0444378>,
    <0.1719493, 0.9851041, 0.0018113>,
    <0.1686518, 0.9850482, 0.0351660>,
    <0.1686518, 0.9850482, 0.0351660>,
    <0.1599801, 0.9865454, 0.0336825>,
    <0.1569679, 0.9872087, -0.0279288>,
    <0.1566597, 0.9865185, -0.0473182>,
    <0.1599801, 0.9865454, 0.0336825>,
    <0.1538241, 0.9875594, 0.0326290>,
    <0.1538241, 0.9875594, 0.0326290>,
    <0.1527728, 0.9882591, 0.0020999>,
    <0.1537191, 0.9880791, -0.0083706>,
    <0.1536875, 0.9879398, -0.0188414>,
    <0.1558838, 0.9855271, -0.0666080>,
    <0.1533728, 0.9877434, -0.0289796>,
    <0.1531335, 0.9874344, -0.0390310>,
    <0.1552882, 0.9839324, -0.0881055>,
    <0.1552882, 0.9839324, -0.0881055>,
    <0.1587227, 0.9797268, -0.1222398>,
    <-0.4307522, -0.9024093, 0.0104891>,
    <-0.4306012, -0.9022708, 0.0221350>,
    <-0.4289304, -0.9033124, 0.0067396>,
    <-0.4289496, -0.9033222, 0.0033581>,
    <-0.4289283, -0.9033385, 0.0001944>,
    <-0.4304757, -0.9026021, 0.0001933>,
    <-0.4304757, -0.9026021, 0.0001933>,
    <-0.4343342, -0.9007433, 0.0039179>,
    <-0.4302011, -0.9021181, 0.0333146>,
    <-0.4288794, -0.9033060, 0.0100361>,
    <-0.4304872, -0.8946443, 0.1195502>,
    <-0.4298771, -0.9018188, 0.0439137>,
    <-0.4298771, -0.9018188, 0.0439137>,
    <-0.4288449, -0.9032821, 0.0131708>,
    <-0.4285782, -0.9035047, -0.0002094>,
    <-0.4285802, -0.9035037, -0.0000500>,
    <-0.4288449, -0.9032821, 0.0131708>,
    <-0.4285775, -0.9035049, -0.0003844>,
    <-0.4285775, -0.9035049, -0.0003844>,
    <-0.4287922, -0.9033928, -0.0043306>,
    <-0.4287941, -0.9033966, -0.0031993>,
    <-0.4287941, -0.9033966, -0.0031993>,
    <-0.4287953, -0.9033993, -0.0020681>,
    <-0.4285824, -0.9035027, 0.0000817>,
    <-0.4287953, -0.9033993, -0.0020681>,
    <-0.4287961, -0.9034008, -0.0009368>,
    <-0.4287961, -0.9034008, -0.0009368>,
    <-0.4287962, -0.9034012, 0.0001945>,
    <-0.4285833, -0.9035023, 0.0001946>,
    <-0.4285833, -0.9035023, 0.0001946>,
    <-0.4289283, -0.9033385, 0.0001944>,
    <0.8324089, -0.0002080, -0.5541619>,
    <0.8324262, -0.0002080, -0.5541359>,
    <0.9628647, -0.0002270, -0.2699842>,
    <0.9628598, -0.0002270, -0.2700017>,
    <0.9628549, -0.0002270, -0.2700193>,
    <0.8323916, -0.0002080, -0.5541879>,
    <0.8323916, -0.0002080, -0.5541879>,
    <0.5396893, -0.0001488, -0.8418642>,
    <0.8324435, -0.0002080, -0.5541099>,
    <0.9628696, -0.0002270, -0.2699667>,
    <0.5397936, -0.0001488, -0.8417974>,
    <0.8324608, -0.0002080, -0.5540838>,
    <0.8324608, -0.0002080, -0.5540838>,
    <0.9628745, -0.0002270, -0.2699492>,
    <0.9945504, -0.0002276, -0.1042570>,
    <0.9945495, -0.0002276, -0.1042651>,
    <0.9628745, -0.0002270, -0.2699492>,
    <0.9945512, -0.0002276, -0.1042489>,
    <0.9945512, -0.0002276, -0.1042489>,
    <0.9985910, -0.0002252, -0.0530654>,
    <0.9985908, -0.0002252, -0.0530703>,
    <0.9985908, -0.0002252, -0.0530703>,
    <0.9985905, -0.0002252, -0.0530752>,
    <0.9945487, -0.0002276, -0.1042733>,
    <0.9985905, -0.0002252, -0.0530752>,
    <0.9985902, -0.0002252, -0.0530801>,
    <0.9985902, -0.0002252, -0.0530801>,
    <0.9985900, -0.0002252, -0.0530850>,
    <0.9945478, -0.0002276, -0.1042814>,
    <0.9945478, -0.0002276, -0.1042814>,
    <0.9628549, -0.0002270, -0.2700193>,
    <0.1518804, 0.9883457, -0.0102500>,
    <0.1519275, 0.9883707, -0.0064262>,
    <0.1512521, 0.9884936, -0.0017943>,
    <0.1512552, 0.9884906, -0.0028783>,
    <0.1512534, 0.9884870, -0.0039735>,
    <0.1518353, 0.9883068, -0.0139880>,
    <0.1518353, 0.9883068, -0.0139880>,
    <0.1531335, 0.9874344, -0.0390310>,
    <0.1518725, 0.9883963, -0.0027439>,
    <0.1512393, 0.9884969, -0.0007866>,
    <0.1527728, 0.9882591, 0.0020999>,
    <0.1517346, 0.9884213, 0.0001016>,
    <0.1517346, 0.9884213, 0.0001016>,
    <0.1512258, 0.9884992, 0.0001014>,
    <0.1511230, 0.9885150, 0.0001951>,
    <0.1511243, 0.9885147, 0.0002824>,
    <0.1512258, 0.9884992, 0.0001014>,
    <0.1511226, 0.9885150, 0.0001013>,
    <0.1511226, 0.9885150, 0.0001013>,
    <0.1512185, 0.9885004, 0.0001014>,
    <0.1512185, 0.9885002, 0.0005004>,
    <0.1512185, 0.9885002, 0.0005004>,
    <0.1512184, 0.9885000, 0.0008994>,
    <0.1511257, 0.9885145, 0.0003556>,
    <0.1512184, 0.9885000, 0.0008994>,
    <0.1512183, 0.9884995, 0.0012984>,
    <0.1512183, 0.9884995, 0.0012984>,
    <0.1512183, 0.9884989, 0.0016974>,
    <0.1511262, 0.9885144, 0.0004198>,
    <0.1511262, 0.9885144, 0.0004198>,
    <0.1512534, 0.9884870, -0.0039735>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, -0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <-0.4346922, -0.9005791, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, -0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <1.0000000, -0.0001700, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, -0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.1537165, 0.9881150, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, -0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.9999958, 0.0028888, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999971, 0.0023761, 0.0004916>,
    <0.9999970, 0.0023761, 0.0005084>,
    <0.9999970, 0.0023971, 0.0005084>,
    <0.9999970, 0.0023971, 0.0004915>,
    <0.9999970, 0.0023971, 0.0004747>,
    <0.9999971, 0.0023761, 0.0004747>,
    <0.9999971, 0.0023761, 0.0004747>,
    <0.9999971, 0.0023551, 0.0004747>,
    <0.9999971, 0.0023551, 0.0004916>,
    <0.9999971, 0.0023551, 0.0004916>,
    <0.9999971, 0.0023551, 0.0005084>,
    <0.9999970, 0.0023761, 0.0005253>,
    <0.9999970, 0.0023971, 0.0005253>,
    <0.9999971, 0.0023551, 0.0005084>,
    <0.9999971, 0.0023551, 0.0005253>,
    <0.9999971, 0.0023551, 0.0005253>,
    <0.9999971, 0.0023551, 0.0005422>,
    <0.9999970, 0.0023761, 0.0005422>,
    <0.9999970, 0.0023761, 0.0005422>,
    <0.9999970, 0.0023971, 0.0005422>,
    <0.9999969, 0.0024181, 0.0005253>,
    <0.9999969, 0.0024181, 0.0005084>,
    <0.9999970, 0.0023971, 0.0005422>,
    <0.9999969, 0.0024181, 0.0005422>,
    <0.9999969, 0.0024181, 0.0005422>,
    <0.9999969, 0.0024391, 0.0005422>,
    <0.9999969, 0.0024391, 0.0005253>,
    <0.9999969, 0.0024391, 0.0005253>,
    <0.9999969, 0.0024391, 0.0005084>,
    <0.9999970, 0.0024181, 0.0004915>,
    <0.9999969, 0.0024391, 0.0005084>,
    <0.9999969, 0.0024391, 0.0004915>,
    <0.9999969, 0.0024391, 0.0004915>,
    <0.9999969, 0.0024391, 0.0004746>,
    <0.9999970, 0.0024181, 0.0004747>,
    <0.9999970, 0.0024181, 0.0004747>,
    <0.9999970, 0.0023971, 0.0004747>,
    <-0.9880153, -0.0010378, -0.1543523>,
    <-0.9880215, -0.0014650, -0.1543090>,
    <-0.9872063, -0.0014638, -0.1594412>,
    <-0.9872024, -0.0010370, -0.1594691>,
    <-0.9871982, -0.0006128, -0.1594969>,
    <-0.9880090, -0.0006133, -0.1543952>,
    <-0.9880090, -0.0006133, -0.1543952>,
    <-0.9887946, -0.0006137, -0.1492812>,
    <-0.9888030, -0.0010387, -0.1492229>,
    <-0.9888030, -0.0010387, -0.1492229>,
    <-0.9888113, -0.0014661, -0.1491643>,
    <-0.9880276, -0.0018947, -0.1542655>,
    <-0.9872101, -0.0018931, -0.1594131>,
    <-0.9888113, -0.0014661, -0.1491643>,
    <-0.9888195, -0.0018962, -0.1491053>,
    <-0.9888195, -0.0018962, -0.1491053>,
    <-0.9888275, -0.0023288, -0.1490459>,
    <-0.9880335, -0.0023269, -0.1542217>,
    <-0.9880335, -0.0023269, -0.1542217>,
    <-0.9872138, -0.0023250, -0.1593848>,
    <-0.9863673, -0.0018915, -0.1645477>,
    <-0.9863659, -0.0014625, -0.1645605>,
    <-0.9872138, -0.0023250, -0.1593848>,
    <-0.9863685, -0.0023230, -0.1645349>,
    <-0.9863685, -0.0023230, -0.1645349>,
    <-0.9854979, -0.0023209, -0.1696715>,
    <-0.9854993, -0.0018898, -0.1696690>,
    <-0.9854993, -0.0018898, -0.1696690>,
    <-0.9855004, -0.0014612, -0.1696666>,
    <-0.9863643, -0.0010361, -0.1645732>,
    <-0.9855004, -0.0014612, -0.1696666>,
    <-0.9855014, -0.0010352, -0.1696641>,
    <-0.9855014, -0.0010352, -0.1696641>,
    <-0.9855022, -0.0006117, -0.1696616>,
    <-0.9863626, -0.0006122, -0.1645858>,
    <-0.9863626, -0.0006122, -0.1645858>,
    <-0.9871982, -0.0006128, -0.1594969>,
    <0.9999998, 0.0006195, 0.0000080>,
    <0.9999998, 0.0006195, 0.0000082>,
    <0.9999998, 0.0006199, 0.0000082>,
    <0.9999998, 0.0006199, 0.0000080>,
    <0.9999998, 0.0006199, 0.0000077>,
    <0.9999998, 0.0006195, 0.0000077>,
    <0.9999998, 0.0006195, 0.0000077>,
    <0.9999998, 0.0006191, 0.0000077>,
    <0.9999998, 0.0006191, 0.0000080>,
    <0.9999998, 0.0006191, 0.0000080>,
    <0.9999998, 0.0006191, 0.0000082>,
    <0.9999998, 0.0006195, 0.0000085>,
    <0.9999998, 0.0006199, 0.0000085>,
    <0.9999998, 0.0006191, 0.0000082>,
    <0.9999998, 0.0006191, 0.0000085>,
    <0.9999998, 0.0006191, 0.0000085>,
    <0.9999998, 0.0006191, 0.0000088>,
    <0.9999998, 0.0006195, 0.0000088>,
    <0.9999998, 0.0006195, 0.0000088>,
    <0.9999998, 0.0006199, 0.0000088>,
    <0.9999998, 0.0006203, 0.0000085>,
    <0.9999998, 0.0006203, 0.0000082>,
    <0.9999998, 0.0006199, 0.0000088>,
    <0.9999998, 0.0006203, 0.0000088>,
    <0.9999998, 0.0006203, 0.0000088>,
    <0.9999998, 0.0006207, 0.0000088>,
    <0.9999998, 0.0006207, 0.0000085>,
    <0.9999998, 0.0006207, 0.0000085>,
    <0.9999998, 0.0006207, 0.0000082>,
    <0.9999998, 0.0006203, 0.0000080>,
    <0.9999998, 0.0006207, 0.0000082>,
    <0.9999998, 0.0006207, 0.0000080>,
    <0.9999998, 0.0006207, 0.0000080>,
    <0.9999998, 0.0006207, 0.0000077>,
    <0.9999998, 0.0006203, 0.0000077>,
    <0.9999998, 0.0006203, 0.0000077>,
    <0.9999998, 0.0006199, 0.0000077>,
    <-0.9988402, -0.0004293, -0.0481463>,
    <-0.9988403, -0.0004922, -0.0481443>,
    <-0.9987606, -0.0004922, -0.0497705>,
    <-0.9987605, -0.0004292, -0.0497717>,
    <-0.9987605, -0.0003663, -0.0497730>,
    <-0.9988401, -0.0003664, -0.0481483>,
    <-0.9988401, -0.0003664, -0.0481483>,
    <-0.9989171, -0.0003664, -0.0465233>,
    <-0.9989172, -0.0004293, -0.0465205>,
    <-0.9989172, -0.0004293, -0.0465205>,
    <-0.9989173, -0.0004923, -0.0465178>,
    <-0.9988403, -0.0005553, -0.0481423>,
    <-0.9987606, -0.0005552, -0.0497692>,
    <-0.9989173, -0.0004923, -0.0465178>,
    <-0.9989174, -0.0005553, -0.0465151>,
    <-0.9989174, -0.0005553, -0.0465151>,
    <-0.9989175, -0.0006184, -0.0465124>,
    <-0.9988404, -0.0006183, -0.0481403>,
    <-0.9988404, -0.0006183, -0.0481403>,
    <-0.9987606, -0.0006183, -0.0497679>,
    <-0.9986782, -0.0005552, -0.0513956>,
    <-0.9986782, -0.0004922, -0.0513962>,
    <-0.9987606, -0.0006183, -0.0497679>,
    <-0.9986782, -0.0006182, -0.0513950>,
    <-0.9986782, -0.0006182, -0.0513950>,
    <-0.9985932, -0.0006182, -0.0530217>,
    <-0.9985932, -0.0005551, -0.0530216>,
    <-0.9985932, -0.0005551, -0.0530216>,
    <-0.9985933, -0.0004921, -0.0530215>,
    <-0.9986782, -0.0004292, -0.0513968>,
    <-0.9985933, -0.0004921, -0.0530215>,
    <-0.9985933, -0.0004292, -0.0530214>,
    <-0.9985933, -0.0004292, -0.0530214>,
    <-0.9985933, -0.0003663, -0.0530213>,
    <-0.9986782, -0.0003663, -0.0513974>,
    <-0.9986782, -0.0003663, -0.0513974>,
    <-0.9987605, -0.0003663, -0.0497730>,
    <0.9999459, 0.0002063, 0.0103970>,
    <0.9999458, -0.0000193, 0.0104137>,
    <0.9999351, 0.0001043, 0.0113909>,
    <0.9999381, 0.0001631, 0.0111286>,
    <0.9999388, 0.0001835, 0.0110596>,
    <0.9999388, 0.0002729, 0.0110586>,
    <0.9999388, 0.0002729, 0.0110586>,
    <0.9999761, 0.0009066, 0.0068509>,
    <0.9999747, 0.0005212, 0.0070935>,
    <0.9999731, -0.0000995, 0.0073356>,
    <0.9999371, -0.0002314, 0.0112167>,
    <0.9999287, 0.0000535, 0.0119444>,
    <0.9999710, -0.0007475, 0.0075757>,
    <0.9999688, -0.0011235, 0.0078137>,
    <0.9999205, -0.0002636, 0.0126057>,
    <0.9999205, -0.0002636, 0.0126057>,
    <0.9999205, 0.0000450, 0.0126058>,
    <0.9999261, 0.0002293, 0.0121532>,
    <0.9999312, 0.0002354, 0.0117283>,
    <0.9999205, 0.0000450, 0.0126058>,
    <0.9999205, 0.0002280, 0.0126059>,
    <0.9999205, 0.0002280, 0.0126059>,
    <0.9999205, 0.0003668, 0.0126060>,
    <0.9999253, 0.0003668, 0.0122189>,
    <0.9999253, 0.0003668, 0.0122189>,
    <0.9999299, 0.0003668, 0.0118318>,
    <0.9999353, 0.0002425, 0.0113694>,
    <0.9999299, 0.0003668, 0.0118318>,
    <0.9999344, 0.0003668, 0.0114448>,
    <0.9999344, 0.0003668, 0.0114448>,
    <0.9999388, 0.0003668, 0.0110577>,
    <0.9999388, 0.0002453, 0.0110589>,
    <0.9999388, 0.0002453, 0.0110589>,
    <0.9999388, 0.0001835, 0.0110596>,
    <0.9999919, 0.0006078, -0.0039879>,
    <0.9998053, 0.0002831, -0.0197304>,
    <0.9998841, -0.0000725, -0.0152216>,
    <0.9999997, -0.0001076, -0.0008189>,
    <0.9999761, 0.0009066, 0.0068509>,
    <0.9992146, 0.0026973, -0.0395342>,
    <0.9992146, 0.0026973, -0.0395342>,
    <0.9992150, 0.0006565, -0.0396092>,
    <0.9994324, 0.0000311, -0.0336883>,
    <0.9994854, -0.0000301, -0.0320782>,
    <0.9992150, 0.0006565, -0.0396092>,
    <0.9992144, 0.0000611, -0.0396311>,
    <0.9992144, 0.0000611, -0.0396311>,
    <0.9992143, 0.0000123, -0.0396329>,
    <0.9991586, 0.0000123, -0.0410143>,
    <0.9991586, 0.0000123, -0.0410143>,
    <0.9991009, 0.0000123, -0.0423955>,
    <0.9993480, -0.0000942, -0.0361056>,
    <0.9997689, -0.0004450, -0.0214912>,
    <0.9991009, 0.0000123, -0.0423955>,
    <0.9990414, 0.0000123, -0.0437764>,
    <0.9990414, 0.0000123, -0.0437764>,
    <0.9989799, 0.0000123, -0.0451571>,
    <0.9989799, -0.0001301, -0.0451569>,
    <0.9989799, -0.0001301, -0.0451569>,
    <0.9989796, -0.0008726, -0.0451557>,
    <0.9999888, -0.0008603, -0.0046496>,
    <0.9989796, -0.0008726, -0.0451557>,
    <0.9989749, -0.0032222, -0.0451516>,
    <0.9989749, -0.0032222, -0.0451516>,
    <0.9999688, -0.0011235, 0.0078137>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9514758>,
    <0.4351413, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289899, 0.9514081>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9514758>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559068, 0.9657316>,
    <0.6289899, 0.9514081>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4351413, 0.9657316>,
    <0.5000060, 0.9664312>,
    <0.4264239, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379355, 0.9664305>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664312>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559068, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773683, 0.9671308>,
    <0.6379355, 0.9664305>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4264239, 0.9671308>,
    <0.5000061, 0.9783126>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473428, 0.9784058>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9783126>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773683, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473428, 0.9784058>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032666, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458875>,
    <0.4677608, 0.9457732>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9514758>,
    <0.4355157, 0.9458875>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9453187>,
    <0.4677605, 0.9520459>,
    <0.4676667, 0.9588888>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9514758>,
    <0.5000059, 0.9657316>,
    <0.4351413, 0.9657316>,
    <0.4677605, 0.9520459>,
    <0.5000059, 0.9584708>,
    <0.4675719, 0.9657316>,
    <0.4353447, 0.9585650>,
    <0.4031722, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4351413, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4353447, 0.9585650>,
    <0.4025751, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032666, 0.9526160>,
    <0.5322510, 0.9457732>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9514758>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9520459>,
    <0.5000059, 0.9453187>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458716>,
    <0.5967411, 0.9457562>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289899, 0.9514081>,
    <0.5644961, 0.9458716>,
    <0.5967380, 0.9395004>,
    <0.6289859, 0.9452843>,
    <0.5967441, 0.9520120>,
    <0.5967475, 0.9588718>,
    <0.5644983, 0.9526160>,
    <0.6289899, 0.9514081>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967441, 0.9520120>,
    <0.6289944, 0.9583697>,
    <0.5967509, 0.9657316>,
    <0.5645004, 0.9590138>,
    <0.5322532, 0.9588888>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9514758>,
    <0.5645004, 0.9590138>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9584708>,
    <0.5322521, 0.9520459>,
    <0.6423395, 0.9457562>,
    <0.6556982, 0.9526160>,
    <0.6289899, 0.9514081>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423438, 0.9520120>,
    <0.6289859, 0.9452843>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458871>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458871>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691072, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559068, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694234, 0.9657316>,
    <0.6557925, 0.9585434>,
    <0.6423985, 0.9588718>,
    <0.6556982, 0.9526160>,
    <0.6559068, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289899, 0.9514081>,
    <0.6557925, 0.9585434>,
    <0.6424546, 0.9657316>,
    <0.6289944, 0.9583697>,
    <0.6423438, 0.9520120>,
    <0.3998147, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4351413, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4025751, 0.9657316>,
    <0.4331013, 0.9660793>,
    <0.4665476, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.4351413, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664312>,
    <0.4331013, 0.9660793>,
    <0.4675719, 0.9657316>,
    <0.5000060, 0.9661024>,
    <0.4655215, 0.9664312>,
    <0.4643682, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664312>,
    <0.5000061, 0.9671308>,
    <0.4264239, 0.9671308>,
    <0.4655215, 0.9664312>,
    <0.5000060, 0.9667580>,
    <0.4632096, 0.9671308>,
    <0.4287785, 0.9667737>,
    <0.3931631, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4264239, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4287785, 0.9667737>,
    <0.3896051, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660814>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664312>,
    <0.5000060, 0.9661024>,
    <0.5322542, 0.9657316>,
    <0.5668680, 0.9661016>,
    <0.6001031, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379355, 0.9664305>,
    <0.5668680, 0.9661016>,
    <0.5967509, 0.9657316>,
    <0.6337187, 0.9661007>,
    <0.6034553, 0.9664309>,
    <0.6068117, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.6379355, 0.9664305>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034553, 0.9664309>,
    <0.6421270, 0.9667584>,
    <0.6101681, 0.9671308>,
    <0.5710669, 0.9667584>,
    <0.5356086, 0.9667810>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664312>,
    <0.5710669, 0.9667584>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667580>,
    <0.5344905, 0.9664312>,
    <0.6473367, 0.9660812>,
    <0.6665054, 0.9664312>,
    <0.6379355, 0.9664305>,
    <0.6289992, 0.9657316>,
    <0.6559068, 0.9657316>,
    <0.6522205, 0.9664309>,
    <0.6337187, 0.9661007>,
    <0.6424546, 0.9657316>,
    <0.6611297, 0.9660764>,
    <0.6749742, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559068, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6611297, 0.9660764>,
    <0.6694234, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866641, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773683, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926234, 0.9671308>,
    <0.6718561, 0.9667758>,
    <0.6571745, 0.9667808>,
    <0.6665054, 0.9664312>,
    <0.6773683, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379355, 0.9664305>,
    <0.6718561, 0.9667758>,
    <0.6621309, 0.9671308>,
    <0.6421270, 0.9667584>,
    <0.6522205, 0.9664309>,
    <0.3896483, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4264239, 0.9671308>,
    <0.3895222, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3896051, 0.9671308>,
    <0.4263846, 0.9728421>,
    <0.4631967, 0.9725836>,
    <0.4263507, 0.9777601>,
    <0.4264239, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9783126>,
    <0.4263846, 0.9728421>,
    <0.4632096, 0.9671308>,
    <0.5000061, 0.9726033>,
    <0.4631778, 0.9780364>,
    <0.4631249, 0.9832129>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9783126>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631778, 0.9780364>,
    <0.5000061, 0.9834693>,
    <0.4630714, 0.9883895>,
    <0.4262411, 0.9832055>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262411, 0.9832055>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895222, 0.9777601>,
    <0.5367803, 0.9725836>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9783126>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9780364>,
    <0.5000061, 0.9726033>,
    <0.5367268, 0.9671308>,
    <0.5735529, 0.9723694>,
    <0.6103351, 0.9726069>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473428, 0.9784058>,
    <0.5735529, 0.9723694>,
    <0.6101681, 0.9671308>,
    <0.6471135, 0.9727118>,
    <0.6105021, 0.9780830>,
    <0.6106561, 0.9832362>,
    <0.5736614, 0.9777601>,
    <0.6473428, 0.9784058>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105021, 0.9780830>,
    <0.6475487, 0.9835193>,
    <0.6108101, 0.9883895>,
    <0.5737710, 0.9832025>,
    <0.5368873, 0.9832129>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9783126>,
    <0.5737710, 0.9832025>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9834693>,
    <0.5368338, 0.9780364>,
    <0.6623547, 0.9726069>,
    <0.6778190, 0.9777601>,
    <0.6473428, 0.9784058>,
    <0.6468888, 0.9671308>,
    <0.6773683, 0.9671308>,
    <0.6625811, 0.9780830>,
    <0.6471135, 0.9727118>,
    <0.6621309, 0.9671308>,
    <0.6776116, 0.9728682>,
    <0.6928061, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773683, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776116, 0.9728682>,
    <0.6926234, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930704, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930704, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780837, 0.9832067>,
    <0.6628105, 0.9832362>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473428, 0.9784058>,
    <0.6780837, 0.9832067>,
    <0.6630402, 0.9883895>,
    <0.6475487, 0.9835193>,
    <0.6625811, 0.9780830>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.05, -0.876613, -0.147353>
}

#declare TMesh008 = mesh2 {
  vertex_vectors {
    582,
    <2.2046850, 0.3609944, 18.5058918>,
    <2.0021506, 0.3609820, 18.5058918>,
    <2.0021672, 0.2806104, 18.5058918>,
    <2.2046990, 0.2806255, 18.5058918>,
    <2.1034178, 0.3609882, 18.5058918>,
    <2.0021589, 0.3207962, 18.5058918>,
    <2.1034331, 0.2806180, 18.5058918>,
    <2.2046920, 0.3208099, 18.5058918>,
    <2.1034254, 0.3208031, 18.5058918>,
    <2.4072308, 0.2806405, 18.5058918>,
    <2.4072193, 0.3610067, 18.5058918>,
    <2.3059649, 0.2806330, 18.5058918>,
    <2.4072251, 0.3208236, 18.5058918>,
    <2.3059522, 0.3610006, 18.5058918>,
    <2.3059585, 0.3208168, 18.5058918>,
    <2.4072079, 0.4413729, 18.5058918>,
    <2.2046709, 0.4413633, 18.5058918>,
    <2.4072136, 0.4011898, 18.5058918>,
    <2.3059394, 0.4413681, 18.5058918>,
    <2.2046780, 0.4011788, 18.5058918>,
    <2.3059458, 0.4011843, 18.5058918>,
    <2.0021340, 0.4413536, 18.5058918>,
    <2.1034025, 0.4413585, 18.5058918>,
    <2.0021423, 0.4011678, 18.5058918>,
    <2.1034101, 0.4011733, 18.5058918>,
    <2.0664387, 0.2804708, 18.1207908>,
    <2.0044034, 0.2804603, 18.1202395>,
    <2.0044687, 0.2804559, 18.1217627>,
    <2.0559641, 0.2804663, 18.1217627>,
    <2.0354211, 0.2804656, 18.1205151>,
    <2.0044361, 0.2804581, 18.1210011>,
    <2.0302164, 0.2804611, 18.1217627>,
    <2.0612014, 0.2804686, 18.1212767>,
    <2.0328188, 0.2804633, 18.1211389>,
    <2.1074595, 0.2804767, 18.1217627>,
    <2.1284740, 0.2804813, 18.1213420>,
    <2.0817118, 0.2804715, 18.1217627>,
    <2.1179668, 0.2804790, 18.1215524>,
    <2.0974564, 0.2804761, 18.1210664>,
    <2.0895841, 0.2804738, 18.1214145>,
    <2.1494885, 0.2804860, 18.1209214>,
    <2.0769133, 0.2804753, 18.1198188>,
    <2.1389813, 0.2804837, 18.1211317>,
    <2.1132009, 0.2804807, 18.1203701>,
    <2.0716760, 0.2804731, 18.1203048>,
    <2.1053286, 0.2804784, 18.1207182>,
    <2.0043382, 0.2804647, 18.1187163>,
    <2.0406257, 0.2804700, 18.1192675>,
    <2.0043708, 0.2804625, 18.1194779>,
    <2.0380234, 0.2804678, 18.1198913>,
    <2.1284614, 0.3610088, 18.1213420>,
    <2.1074469, 0.3610088, 18.1217627>,
    <2.1284677, 0.3207451, 18.1213420>,
    <2.1074532, 0.3207428, 18.1217627>,
    <2.1179541, 0.3610088, 18.1215524>,
    <2.1179605, 0.3207439, 18.1215524>,
    <2.1074342, 0.4415410, 18.1217627>,
    <2.1284488, 0.4415362, 18.1213420>,
    <2.1074405, 0.4012749, 18.1217627>,
    <2.1179415, 0.4415386, 18.1215524>,
    <2.1284551, 0.4012725, 18.1213420>,
    <2.1179478, 0.4012737, 18.1215524>,
    <2.1494633, 0.4415314, 18.1209214>,
    <2.1494759, 0.3610087, 18.1209214>,
    <2.1389560, 0.4415338, 18.1211317>,
    <2.1494696, 0.4012701, 18.1209214>,
    <2.1389687, 0.3610087, 18.1211317>,
    <2.1389624, 0.4012713, 18.1211317>,
    <2.1494822, 0.3207473, 18.1209214>,
    <2.1389750, 0.3207462, 18.1211317>,
    <2.0664094, 0.4415300, 18.1207908>,
    <2.0559348, 0.4415349, 18.1217627>,
    <2.0974291, 0.4415331, 18.1210664>,
    <2.0816845, 0.4415379, 18.1217627>,
    <2.0611721, 0.4415324, 18.1212767>,
    <2.0895568, 0.4415355, 18.1214145>,
    <2.0044353, 0.4415288, 18.1217627>,
    <2.0043701, 0.4415238, 18.1202395>,
    <2.0301850, 0.4415318, 18.1217627>,
    <2.0044027, 0.4415263, 18.1210011>,
    <2.0353897, 0.4415269, 18.1205151>,
    <2.0327874, 0.4415294, 18.1211389>,
    <2.0043048, 0.4415189, 18.1187163>,
    <2.0768841, 0.4415251, 18.1198188>,
    <2.0043374, 0.4415214, 18.1194779>,
    <2.0405944, 0.4415220, 18.1192675>,
    <2.0716467, 0.4415276, 18.1203048>,
    <2.0379921, 0.4415245, 18.1198913>,
    <2.1131737, 0.4415283, 18.1203701>,
    <2.1053014, 0.4415307, 18.1207182>,
    <2.0766447, 0.2804848, 18.1376413>,
    <2.0042020, 0.2804738, 18.1370901>,
    <2.0404234, 0.2804793, 18.1373657>,
    <2.0042701, 0.2804693, 18.1279032>,
    <2.0767790, 0.2804801, 18.1287301>,
    <2.0405246, 0.2804747, 18.1283166>,
    <2.1490873, 0.2804957, 18.1381926>,
    <2.1492879, 0.2804908, 18.1295570>,
    <2.1128660, 0.2804902, 18.1379170>,
    <2.1130335, 0.2804854, 18.1291435>,
    <2.1486861, 0.2805054, 18.1554639>,
    <2.0763760, 0.2804942, 18.1554639>,
    <2.1488867, 0.2805005, 18.1468283>,
    <2.1125311, 0.2804998, 18.1554639>,
    <2.0765104, 0.2804895, 18.1465526>,
    <2.1126985, 0.2804950, 18.1466904>,
    <2.0040659, 0.2804830, 18.1554639>,
    <2.0402210, 0.2804886, 18.1554639>,
    <2.0041340, 0.2804784, 18.1462770>,
    <2.0403222, 0.2804839, 18.1464148>,
    <2.1490748, 0.3610086, 18.1381926>,
    <2.1490811, 0.3207521, 18.1381926>,
    <2.1492754, 0.3610086, 18.1295570>,
    <2.1492816, 0.3207497, 18.1295570>,
    <2.1490623, 0.4415215, 18.1381926>,
    <2.1492628, 0.4415265, 18.1295570>,
    <2.1490685, 0.4012650, 18.1381926>,
    <2.1492691, 0.4012676, 18.1295570>,
    <2.1486612, 0.4415115, 18.1554639>,
    <2.1486737, 0.3610085, 18.1554639>,
    <2.1488618, 0.4415165, 18.1468283>,
    <2.1486675, 0.4012600, 18.1554639>,
    <2.1488742, 0.3610085, 18.1468283>,
    <2.1488680, 0.4012625, 18.1468283>,
    <2.1486799, 0.3207569, 18.1554639>,
    <2.1488805, 0.3207545, 18.1468283>,
    <2.0766155, 0.4415150, 18.1376413>,
    <2.1128389, 0.4415182, 18.1379170>,
    <2.0767498, 0.4415201, 18.1287301>,
    <2.1130063, 0.4415233, 18.1291435>,
    <2.0041687, 0.4415085, 18.1370901>,
    <2.0042367, 0.4415137, 18.1279032>,
    <2.0403921, 0.4415118, 18.1373657>,
    <2.0404932, 0.4415169, 18.1283166>,
    <2.0040326, 0.4414981, 18.1554639>,
    <2.0763469, 0.4415048, 18.1554639>,
    <2.0041006, 0.4415033, 18.1462770>,
    <2.0401897, 0.4415015, 18.1554639>,
    <2.0764812, 0.4415099, 18.1465526>,
    <2.0402909, 0.4415066, 18.1464148>,
    <2.1125041, 0.4415082, 18.1554639>,
    <2.1126715, 0.4415132, 18.1466904>,
    <2.0812641, 0.2805008, 18.1573801>,
    <2.0039695, 0.2804894, 18.1573801>,
    <2.0426168, 0.2804951, 18.1573801>,
    <2.0040177, 0.2804862, 18.1564220>,
    <2.0788201, 0.2804975, 18.1564220>,
    <2.0414189, 0.2804919, 18.1564220>,
    <2.1585588, 0.2805122, 18.1573801>,
    <2.1536225, 0.2805088, 18.1564220>,
    <2.1199115, 0.2805065, 18.1573801>,
    <2.1162213, 0.2805032, 18.1564220>,
    <2.1684314, 0.2805191, 18.1592964>,
    <2.0861522, 0.2805075, 18.1592964>,
    <2.1634951, 0.2805157, 18.1583383>,
    <2.1272918, 0.2805133, 18.1592964>,
    <2.0837082, 0.2805042, 18.1583383>,
    <2.1236016, 0.2805099, 18.1583383>,
    <2.0038730, 0.2804959, 18.1592964>,
    <2.0450126, 0.2805017, 18.1592964>,
    <2.0039212, 0.2804927, 18.1583383>,
    <2.0438147, 0.2804984, 18.1583383>,
    <2.1585464, 0.3610084, 18.1573801>,
    <2.1585526, 0.3207603, 18.1573801>,
    <2.1536100, 0.3610084, 18.1564220>,
    <2.1536162, 0.3207586, 18.1564220>,
    <2.1585340, 0.4415045, 18.1573801>,
    <2.1535976, 0.4415080, 18.1564220>,
    <2.1585402, 0.4012564, 18.1573801>,
    <2.1536038, 0.4012582, 18.1564220>,
    <2.1684068, 0.4414975, 18.1592964>,
    <2.1684191, 0.3610083, 18.1592964>,
    <2.1634704, 0.4415010, 18.1583383>,
    <2.1684129, 0.4012529, 18.1592964>,
    <2.1634827, 0.3610083, 18.1583383>,
    <2.1634766, 0.4012547, 18.1583383>,
    <2.1684253, 0.3207637, 18.1592964>,
    <2.1634889, 0.3207620, 18.1583383>,
    <2.0812351, 0.4414977, 18.1573801>,
    <2.1198845, 0.4415011, 18.1573801>,
    <2.0787910, 0.4415013, 18.1564220>,
    <2.1161943, 0.4415046, 18.1564220>,
    <2.0039361, 0.4414908, 18.1573801>,
    <2.0039844, 0.4414945, 18.1564220>,
    <2.0425856, 0.4414942, 18.1573801>,
    <2.0413877, 0.4414979, 18.1564220>,
    <2.0038397, 0.4414835, 18.1592964>,
    <2.0861232, 0.4414905, 18.1592964>,
    <2.0038879, 0.4414871, 18.1583383>,
    <2.0449814, 0.4414870, 18.1592964>,
    <2.0836791, 0.4414941, 18.1583383>,
    <2.0437835, 0.4414906, 18.1583383>,
    <2.1272650, 0.4414940, 18.1592964>,
    <2.1235748, 0.4414975, 18.1583383>,
    <2.0877229, 0.2805088, 18.2324892>,
    <2.0038724, 0.2804960, 18.2344341>,
    <2.0457964, 0.2805025, 18.2333227>,
    <2.0038727, 0.2804959, 18.1968653>,
    <2.0861681, 0.2805075, 18.1968653>,
    <2.0450204, 0.2805017, 18.1968653>,
    <2.1715888, 0.2805206, 18.2322113>,
    <2.1684634, 0.2805191, 18.1968653>,
    <2.1296546, 0.2805148, 18.2322113>,
    <2.1273157, 0.2805133, 18.1968653>,
    <2.1994932, 0.2805337, 18.2873438>,
    <2.1015957, 0.2805207, 18.2890109>,
    <2.1809009, 0.2805250, 18.2631118>,
    <2.1505368, 0.2805277, 18.2873438>,
    <2.0923559, 0.2805125, 18.2642232>,
    <2.1366233, 0.2805191, 18.2631118>,
    <2.0038718, 0.2804960, 18.3095719>,
    <2.0526852, 0.2805116, 18.2940122>,
    <2.0038721, 0.2804960, 18.2720030>,
    <2.0481089, 0.2805046, 18.2675574>,
    <2.1715765, 0.3610083, 18.2322113>,
    <2.1715826, 0.3207644, 18.2322113>,
    <2.1684511, 0.3610083, 18.1968653>,
    <2.1684573, 0.3207637, 18.1968653>,
    <2.1715641, 0.4414959, 18.2322113>,
    <2.1684387, 0.4414974, 18.1968653>,
    <2.1715703, 0.4012521, 18.2322113>,
    <2.1684449, 0.4012529, 18.1968653>,
    <2.1994687, 0.4414825, 18.2873438>,
    <2.1994809, 0.3610081, 18.2873438>,
    <2.1808763, 0.4414914, 18.2631118>,
    <2.1994748, 0.4012453, 18.2873438>,
    <2.1808886, 0.3610082, 18.2631118>,
    <2.1808825, 0.4012498, 18.2631118>,
    <2.1994871, 0.3207709, 18.2873438>,
    <2.1808948, 0.3207666, 18.2631118>,
    <2.0876939, 0.4414891, 18.2324892>,
    <2.1296277, 0.4414924, 18.2322113>,
    <2.0861391, 0.4414904, 18.1968653>,
    <2.1272889, 0.4414939, 18.1968653>,
    <2.0038391, 0.4414834, 18.2344341>,
    <2.0038394, 0.4414834, 18.1968653>,
    <2.0457652, 0.4414862, 18.2333227>,
    <2.0449892, 0.4414869, 18.1968653>,
    <2.0038384, 0.4414834, 18.3095719>,
    <2.1015668, 0.4414763, 18.2890109>,
    <2.0038387, 0.4414834, 18.2720030>,
    <2.0526541, 0.4414761, 18.2940122>,
    <2.0923269, 0.4414851, 18.2642232>,
    <2.0480777, 0.4414838, 18.2675574>,
    <2.1505101, 0.4414788, 18.2873438>,
    <2.1365965, 0.4414879, 18.2631118>,
    <2.1354633, 0.2805529, 18.3131904>,
    <2.0032176, 0.2805399, 18.3135798>,
    <2.0693404, 0.2805464, 18.3133573>,
    <2.0035447, 0.2805180, 18.3115759>,
    <2.1169712, 0.2805352, 18.3037960>,
    <2.0602528, 0.2805269, 18.3071303>,
    <2.2677097, 0.2805658, 18.3131347>,
    <2.2304590, 0.2805483, 18.3026846>,
    <2.2015864, 0.2805594, 18.3131347>,
    <2.1737100, 0.2805421, 18.3026846>,
    <2.3367110, 0.2805985, 18.3353648>,
    <2.1697200, 0.2805856, 18.3340315>,
    <2.3051565, 0.2805835, 18.3226946>,
    <2.2532228, 0.2805915, 18.3353648>,
    <2.1540527, 0.2805707, 18.3218058>,
    <2.2296095, 0.2805768, 18.3226946>,
    <2.0025635, 0.2805838, 18.3175878>,
    <2.0861880, 0.2805816, 18.3300317>,
    <2.0028906, 0.2805619, 18.3155838>,
    <2.0784765, 0.2805660, 18.3191392>,
    <2.2676976, 0.3610077, 18.3131347>,
    <2.2677036, 0.3207868, 18.3131347>,
    <2.2304468, 0.3610079, 18.3026846>,
    <2.2304529, 0.3207781, 18.3026846>,
    <2.2676856, 0.4414495, 18.3131347>,
    <2.2304347, 0.4414675, 18.3026846>,
    <2.2676916, 0.4012286, 18.3131347>,
    <2.2304408, 0.4012377, 18.3026846>,
    <2.3366874, 0.4414161, 18.3353648>,
    <2.3366992, 0.3610073, 18.3353648>,
    <2.3051328, 0.4414314, 18.3226946>,
    <2.3366933, 0.4012117, 18.3353648>,
    <2.3051447, 0.3610075, 18.3226946>,
    <2.3051387, 0.4012194, 18.3226946>,
    <2.3367051, 0.3208029, 18.3353648>,
    <2.3051506, 0.3207955, 18.3226946>,
    <2.1354346, 0.4414415, 18.3131904>,
    <2.2015601, 0.4414455, 18.3131347>,
    <2.1169424, 0.4414607, 18.3037960>,
    <2.1736835, 0.4414637, 18.3026846>,
    <2.0031844, 0.4414336, 18.3135798>,
    <2.0035114, 0.4414585, 18.3115759>,
    <2.0693094, 0.4414376, 18.3133573>,
    <2.0602218, 0.4414592, 18.3071303>,
    <2.0025303, 0.4413838, 18.3175878>,
    <2.1696916, 0.4414062, 18.3340315>,
    <2.0028573, 0.4414087, 18.3155838>,
    <2.0861572, 0.4413985, 18.3300317>,
    <2.1540243, 0.4414223, 18.3218058>,
    <2.0784457, 0.4414159, 18.3191392>,
    <2.2531968, 0.4414117, 18.3353648>,
    <2.2295834, 0.4414272, 18.3226946>,
    <2.1847094, 0.2805991, 18.3800376>,
    <2.0025322, 0.2805859, 18.3784821>,
    <2.0936220, 0.2805924, 18.3793709>,
    <2.0025479, 0.2805849, 18.3480349>,
    <2.1794453, 0.2805944, 18.3542569>,
    <2.0910014, 0.2805893, 18.3515903>,
    <2.3668719, 0.2806132, 18.3802598>,
    <2.3562844, 0.2806079, 18.3551457>,
    <2.2757919, 0.2806060, 18.3802598>,
    <2.2678697, 0.2806008, 18.3551457>,
    <2.3730707, 0.2806168, 18.4393764>,
    <2.1877858, 0.2806024, 18.4393764>,
    <2.3714689, 0.2806157, 18.4089292>,
    <2.2804282, 0.2806096, 18.4393764>,
    <2.1869927, 0.2806013, 18.4089292>,
    <2.2792308, 0.2806085, 18.4089292>,
    <2.0025009, 0.2805880, 18.4393764>,
    <2.0951433, 0.2805952, 18.4393764>,
    <2.0025166, 0.2805870, 18.4089292>,
    <2.0947546, 0.2805942, 18.4089292>,
    <2.3668603, 0.3610071, 18.3802598>,
    <2.3668661, 0.3208101, 18.3802598>,
    <2.3562727, 0.3610071, 18.3551457>,
    <2.3562785, 0.3208075, 18.3551457>,
    <2.3668486, 0.4414010, 18.3802598>,
    <2.3562610, 0.4414064, 18.3551457>,
    <2.3668544, 0.4012040, 18.3802598>,
    <2.3562668, 0.4012068, 18.3551457>,
    <2.3730474, 0.4413973, 18.4393764>,
    <2.3730590, 0.3610070, 18.4393764>,
    <2.3714456, 0.4413984, 18.4089292>,
    <2.3730532, 0.4012022, 18.4393764>,
    <2.3714573, 0.3610070, 18.4089292>,
    <2.3714515, 0.4012027, 18.4089292>,
    <2.3730649, 0.3208119, 18.4393764>,
    <2.3714631, 0.3208114, 18.4089292>,
    <2.1846811, 0.4413918, 18.3800376>,
    <2.2757661, 0.4413965, 18.3802598>,
    <2.1794170, 0.4413967, 18.3542569>,
    <2.2678438, 0.4414019, 18.3551457>,
    <2.0024990, 0.4413814, 18.3784821>,
    <2.0025147, 0.4413826, 18.3480349>,
    <2.0935913, 0.4413867, 18.3793709>,
    <2.0909707, 0.4413900, 18.3515903>,
    <2.0024677, 0.4413790, 18.4393764>,
    <2.1877576, 0.4413882, 18.4393764>,
    <2.0024834, 0.4413802, 18.4089292>,
    <2.0951126, 0.4413836, 18.4393764>,
    <2.1869645, 0.4413893, 18.4089292>,
    <2.0947239, 0.4413848, 18.4089292>,
    <2.2804025, 0.4413927, 18.4393764>,
    <2.2792051, 0.4413939, 18.4089292>,
    <2.1962424, 0.2806139, 18.4393764>,
    <2.0023340, 0.2805992, 18.4393764>,
    <2.0992882, 0.2806066, 18.4393764>,
    <2.0024175, 0.2805936, 18.4393764>,
    <2.1920141, 0.2806082, 18.4393764>,
    <2.0972158, 0.2806009, 18.4393764>,
    <2.3901507, 0.2806287, 18.4393764>,
    <2.3816107, 0.2806227, 18.4393764>,
    <2.2931966, 0.2806213, 18.4393764>,
    <2.2868124, 0.2806154, 18.4393764>,
    <2.4072308, 0.2806405, 18.4393764>,
    <2.2046990, 0.2806255, 18.4393764>,
    <2.3986908, 0.2806346, 18.4393764>,
    <2.3059649, 0.2806330, 18.4393764>,
    <2.2004707, 0.2806197, 18.4393764>,
    <2.2995807, 0.2806272, 18.4393764>,
    <2.0021672, 0.2806104, 18.4393764>,
    <2.1034331, 0.2806180, 18.4393764>,
    <2.0022506, 0.2806048, 18.4393764>,
    <2.1013606, 0.2806123, 18.4393764>,
    <2.3901392, 0.3610069, 18.4393764>,
    <2.3901450, 0.3208178, 18.4393764>,
    <2.3815991, 0.3610070, 18.4393764>,
    <2.3816049, 0.3208148, 18.4393764>,
    <2.3901276, 0.4413851, 18.4393764>,
    <2.3815875, 0.4413912, 18.4393764>,
    <2.3901334, 0.4011960, 18.4393764>,
    <2.3815933, 0.4011991, 18.4393764>,
    <2.4072079, 0.4413729, 18.4393764>,
    <2.4072193, 0.3610067, 18.4393764>,
    <2.3986678, 0.4413790, 18.4393764>,
    <2.4072136, 0.4011898, 18.4393764>,
    <2.3986793, 0.3610068, 18.4393764>,
    <2.3986735, 0.4011929, 18.4393764>,
    <2.4072251, 0.3208236, 18.4393764>,
    <2.3986850, 0.3208207, 18.4393764>,
    <2.1962143, 0.4413757, 18.4393764>,
    <2.2931709, 0.4413804, 18.4393764>,
    <2.1919859, 0.4413819, 18.4393764>,
    <2.2867867, 0.4413866, 18.4393764>,
    <2.0023009, 0.4413663, 18.4393764>,
    <2.0023843, 0.4413727, 18.4393764>,
    <2.0992576, 0.4413710, 18.4393764>,
    <2.0971851, 0.4413773, 18.4393764>,
    <2.0021340, 0.4413536, 18.4393764>,
    <2.2046709, 0.4413633, 18.4393764>,
    <2.0022174, 0.4413600, 18.4393764>,
    <2.1034025, 0.4413585, 18.4393764>,
    <2.2004426, 0.4413695, 18.4393764>,
    <2.1013300, 0.4413647, 18.4393764>,
    <2.3059394, 0.4413681, 18.4393764>,
    <2.2995552, 0.4413742, 18.4393764>,
    <2.2046990, 0.2806255, 18.4726341>,
    <2.0021672, 0.2806104, 18.4726341>,
    <2.1034331, 0.2806180, 18.4726341>,
    <2.0021672, 0.2806104, 18.4560052>,
    <2.2046990, 0.2806255, 18.4560052>,
    <2.1034331, 0.2806180, 18.4560052>,
    <2.4072308, 0.2806405, 18.4726341>,
    <2.4072308, 0.2806405, 18.4560052>,
    <2.3059649, 0.2806330, 18.4726341>,
    <2.3059649, 0.2806330, 18.4560052>,
    <2.4072308, 0.2806405, 18.4892630>,
    <2.2046990, 0.2806255, 18.4892630>,
    <2.3059649, 0.2806330, 18.4892630>,
    <2.0021672, 0.2806104, 18.4892630>,
    <2.1034331, 0.2806180, 18.4892630>,
    <2.4072193, 0.3610067, 18.4726341>,
    <2.4072251, 0.3208236, 18.4726341>,
    <2.4072193, 0.3610067, 18.4560052>,
    <2.4072251, 0.3208236, 18.4560052>,
    <2.4072079, 0.4413729, 18.4726341>,
    <2.4072079, 0.4413729, 18.4560052>,
    <2.4072136, 0.4011898, 18.4726341>,
    <2.4072136, 0.4011898, 18.4560052>,
    <2.4072079, 0.4413729, 18.4892630>,
    <2.4072193, 0.3610067, 18.4892630>,
    <2.4072136, 0.4011898, 18.4892630>,
    <2.4072251, 0.3208236, 18.4892630>,
    <2.2046709, 0.4413633, 18.4726341>,
    <2.3059394, 0.4413681, 18.4726341>,
    <2.2046709, 0.4413633, 18.4560052>,
    <2.3059394, 0.4413681, 18.4560052>,
    <2.0021340, 0.4413536, 18.4726341>,
    <2.0021340, 0.4413536, 18.4560052>,
    <2.1034025, 0.4413585, 18.4726341>,
    <2.1034025, 0.4413585, 18.4560052>,
    <2.0021340, 0.4413536, 18.4892630>,
    <2.2046709, 0.4413633, 18.4892630>,
    <2.1034025, 0.4413585, 18.4892630>,
    <2.3059394, 0.4413681, 18.4892630>,
    <2.0021506, 0.3609820, 18.4726341>,
    <2.0021672, 0.2806104, 18.4726341>,
    <2.0021506, 0.3609820, 18.4393764>,
    <2.0021589, 0.3207962, 18.4726341>,
    <2.0021672, 0.2806104, 18.4560052>,
    <2.0021589, 0.3207962, 18.4393764>,
    <2.0021506, 0.3609820, 18.4560052>,
    <2.0021589, 0.3207962, 18.4560052>,
    <2.0021340, 0.4413536, 18.4726341>,
    <2.0021423, 0.4011678, 18.4393764>,
    <2.0021340, 0.4413536, 18.4560052>,
    <2.0021423, 0.4011678, 18.4726341>,
    <2.0021423, 0.4011678, 18.4560052>,
    <2.0021506, 0.3609820, 18.5058918>,
    <2.0021340, 0.4413536, 18.4892630>,
    <2.0021423, 0.4011678, 18.5058918>,
    <2.0021506, 0.3609820, 18.4892630>,
    <2.0021423, 0.4011678, 18.4892630>,
    <2.0021589, 0.3207962, 18.5058918>,
    <2.0021672, 0.2806104, 18.4892630>,
    <2.0021589, 0.3207962, 18.4892630>,
    <2.0023174, 0.3609828, 18.4393764>,
    <2.0024843, 0.3609835, 18.4393764>,
    <2.0024009, 0.3609832, 18.4393764>,
    <2.0024926, 0.3207858, 18.4393764>,
    <2.0023257, 0.3207910, 18.4393764>,
    <2.0024092, 0.3207884, 18.4393764>,
    <2.0021506, 0.3609820, 18.4393764>,
    <2.0021589, 0.3207962, 18.4393764>,
    <2.0022340, 0.3609824, 18.4393764>,
    <2.0022423, 0.3207936, 18.4393764>,
    <2.0021423, 0.4011678, 18.4393764>,
    <2.0023092, 0.4011746, 18.4393764>,
    <2.0022257, 0.4011712, 18.4393764>,
    <2.0024760, 0.4011813, 18.4393764>,
    <2.0023926, 0.4011779, 18.4393764>,
    <2.0025156, 0.3609837, 18.3784821>,
    <2.0025322, 0.2805859, 18.3784821>,
    <2.0025469, 0.3609838, 18.3175878>,
    <2.0025239, 0.3207848, 18.3784821>,
    <2.0025479, 0.2805849, 18.3480349>,
    <2.0025552, 0.3207838, 18.3175878>,
    <2.0025313, 0.3609837, 18.3480349>,
    <2.0025396, 0.3207843, 18.3480349>,
    <2.0024990, 0.4413814, 18.3784821>,
    <2.0025386, 0.4011838, 18.3175878>,
    <2.0025147, 0.4413826, 18.3480349>,
    <2.0025073, 0.4011825, 18.3784821>,
    <2.0025230, 0.4011832, 18.3480349>,
    <2.0024843, 0.3609835, 18.4393764>,
    <2.0024834, 0.4413802, 18.4089292>,
    <2.0024760, 0.4011813, 18.4393764>,
    <2.0025000, 0.3609836, 18.4089292>,
    <2.0024917, 0.4011819, 18.4089292>,
    <2.0024926, 0.3207858, 18.4393764>,
    <2.0025166, 0.2805870, 18.4089292>,
    <2.0025083, 0.3207853, 18.4089292>,
    <2.0032010, 0.3609868, 18.3135798>,
    <2.0038551, 0.3609897, 18.3095719>,
    <2.0035281, 0.3609882, 18.3115759>,
    <2.0038634, 0.3207428, 18.3095719>,
    <2.0032093, 0.3207633, 18.3135798>,
    <2.0035364, 0.3207531, 18.3115759>,
    <2.0025469, 0.3609838, 18.3175878>,
    <2.0025552, 0.3207838, 18.3175878>,
    <2.0028740, 0.3609853, 18.3155838>,
    <2.0028823, 0.3207736, 18.3155838>,
    <2.0025386, 0.4011838, 18.3175878>,
    <2.0031927, 0.4012102, 18.3135798>,
    <2.0028656, 0.4011970, 18.3155838>,
    <2.0038468, 0.4012365, 18.3095719>,
    <2.0035197, 0.4012233, 18.3115759>,
    <2.0038557, 0.3609897, 18.2344341>,
    <2.0038724, 0.2804960, 18.2344341>,
    <2.0038563, 0.3609897, 18.1592964>,
    <2.0038641, 0.3207428, 18.2344341>,
    <2.0038727, 0.2804959, 18.1968653>,
    <2.0038647, 0.3207428, 18.1592964>,
    <2.0038560, 0.3609897, 18.1968653>,
    <2.0038644, 0.3207428, 18.1968653>,
    <2.0038391, 0.4414834, 18.2344341>,
    <2.0038480, 0.4012366, 18.1592964>,
    <2.0038394, 0.4414834, 18.1968653>,
    <2.0038474, 0.4012366, 18.2344341>,
    <2.0038477, 0.4012366, 18.1968653>,
    <2.0038551, 0.3609897, 18.3095719>,
    <2.0038387, 0.4414834, 18.2720030>,
    <2.0038468, 0.4012365, 18.3095719>,
    <2.0038554, 0.3609897, 18.2720030>,
    <2.0038471, 0.4012365, 18.2720030>,
    <2.0038634, 0.3207428, 18.3095719>,
    <2.0038721, 0.2804960, 18.2720030>,
    <2.0038637, 0.3207428, 18.2720030>,
    <2.0039528, 0.3609901, 18.1573801>,
    <2.0040493, 0.3609906, 18.1554639>,
    <2.0040010, 0.3609903, 18.1564220>,
    <2.0040576, 0.3207368, 18.1554639>,
    <2.0039611, 0.3207398, 18.1573801>,
    <2.0040094, 0.3207383, 18.1564220>,
    <2.0038563, 0.3609897, 18.1592964>,
    <2.0038647, 0.3207428, 18.1592964>,
    <2.0039046, 0.3609899, 18.1583383>,
    <2.0039129, 0.3207413, 18.1583383>,
    <2.0038480, 0.4012366, 18.1592964>,
    <2.0039445, 0.4012405, 18.1573801>,
    <2.0038962, 0.4012385, 18.1583383>,
    <2.0040409, 0.4012444, 18.1554639>,
    <2.0039927, 0.4012424, 18.1564220>,
    <2.0042444, 0.3609914, 18.1389725>,
    <2.0042673, 0.2804695, 18.1386133>,
    <2.0043812, 0.3609921, 18.1258340>,
    <2.0042548, 0.3207304, 18.1388528>,
    <2.0043680, 0.2804627, 18.1301880>,
    <2.0044020, 0.3207251, 18.1251156>,
    <2.0043263, 0.3609918, 18.1316249>,
    <2.0043430, 0.3207272, 18.1311460>,
    <2.0042339, 0.4415135, 18.1386133>,
    <2.0043853, 0.4012591, 18.1251156>,
    <2.0043346, 0.4415211, 18.1301880>,
    <2.0042381, 0.4012525, 18.1388528>,
    <2.0043263, 0.4012565, 18.1311460>,
    <2.0040493, 0.3609906, 18.1554639>,
    <2.0041333, 0.4415058, 18.1470386>,
    <2.0040409, 0.4012444, 18.1554639>,
    <2.0041499, 0.3609910, 18.1470386>,
    <2.0041416, 0.4012484, 18.1470386>,
    <2.0040576, 0.3207368, 18.1554639>,
    <2.0041666, 0.2804762, 18.1470386>,
    <2.0041583, 0.3207336, 18.1470386>,
    <2.0043805, 0.3609920, 18.1205987>,
    <2.0043944, 0.3609921, 18.1224380>,
    <2.0043909, 0.3207262, 18.1204790>,
    <2.0044111, 0.3207251, 18.1219591>,
    <2.0043215, 0.3609918, 18.1187163>,
    <2.0043298, 0.3207282, 18.1187163>,
    <2.0043541, 0.3609919, 18.1194779>,
    <2.0043625, 0.3207272, 18.1194779>,
    <2.0043131, 0.4012553, 18.1187163>,
    <2.0043742, 0.4012579, 18.1204790>,
    <2.0043458, 0.4012566, 18.1194779>,
    <2.0043944, 0.4012592, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0001973, 0.9999962, 0.0027423>,
    <-0.0001963, 0.9999968, 0.0025295>,
    <-0.0001923, 0.9999967, 0.0025724>,
    <-0.0001939, 0.9999962, 0.0027564>,
    <-0.0001951, 0.9999958, 0.0028851>,
    <-0.0001980, 0.9999958, 0.0028852>,
    <-0.0001980, 0.9999958, 0.0028852>,
    <-0.0002015, 0.9999958, 0.0028854>,
    <-0.0002015, 0.9999963, 0.0027247>,
    <-0.0002015, 0.9999963, 0.0027247>,
    <-0.0002015, 0.9999969, 0.0024728>,
    <-0.0001946, 0.9999976, 0.0021789>,
    <-0.0001898, 0.9999974, 0.0022878>,
    <-0.0002015, 0.9999969, 0.0024728>,
    <-0.0002015, 0.9999979, 0.0020215>,
    <-0.0002015, 0.9999979, 0.0020215>,
    <-0.0002015, 0.9999995, 0.0009789>,
    <-0.0001912, 0.9999989, 0.0014930>,
    <-0.0001912, 0.9999989, 0.0014930>,
    <-0.0001853, 0.9999984, 0.0017886>,
    <-0.0001862, 0.9999972, 0.0023675>,
    <-0.0001892, 0.9999966, 0.0026061>,
    <-0.0001853, 0.9999984, 0.0017886>,
    <-0.0001815, 0.9999980, 0.0019806>,
    <-0.0001815, 0.9999980, 0.0019806>,
    <-0.0001788, 0.9999977, 0.0021153>,
    <-0.0001835, 0.9999970, 0.0024284>,
    <-0.0001835, 0.9999970, 0.0024284>,
    <-0.0001867, 0.9999965, 0.0026332>,
    <-0.0001912, 0.9999962, 0.0027680>,
    <-0.0001867, 0.9999965, 0.0026332>,
    <-0.0001889, 0.9999961, 0.0027776>,
    <-0.0001889, 0.9999961, 0.0027776>,
    <-0.0001905, 0.9999958, 0.0028849>,
    <-0.0001926, 0.9999958, 0.0028850>,
    <-0.0001926, 0.9999958, 0.0028850>,
    <-0.0001951, 0.9999958, 0.0028851>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200138, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <-0.0200139, -0.0000031, -0.9997997>,
    <0.0000670, -0.9999644, 0.0084329>,
    <0.0000795, -0.9999828, 0.0058644>,
    <0.0000503, -0.9999846, 0.0055497>,
    <0.0000318, -0.9999708, 0.0076356>,
    <-0.0000007, -0.9999362, 0.0112929>,
    <0.0000426, -0.9999094, 0.0134585>,
    <0.0000426, -0.9999094, 0.0134585>,
    <0.0001180, -0.9998516, 0.0172249>,
    <0.0001180, -0.9999540, 0.0095864>,
    <0.0001180, -0.9999540, 0.0095864>,
    <0.0001180, -0.9999803, 0.0062797>,
    <0.0000871, -0.9999907, 0.0043049>,
    <0.0000623, -0.9999912, 0.0042015>,
    <0.0001180, -0.9999803, 0.0062797>,
    <0.0001180, -0.9999902, 0.0044341>,
    <0.0001180, -0.9999902, 0.0044341>,
    <0.0001180, -0.9999947, 0.0032565>,
    <0.0000922, -0.9999947, 0.0032576>,
    <0.0000922, -0.9999947, 0.0032576>,
    <0.0000707, -0.9999947, 0.0032585>,
    <0.0000420, -0.9999915, 0.0041169>,
    <0.0000274, -0.9999859, 0.0053031>,
    <0.0000707, -0.9999947, 0.0032585>,
    <0.0000525, -0.9999947, 0.0032593>,
    <0.0000525, -0.9999947, 0.0032593>,
    <0.0000370, -0.9999947, 0.0032599>,
    <0.0000251, -0.9999918, 0.0040463>,
    <0.0000251, -0.9999918, 0.0040463>,
    <0.0000090, -0.9999870, 0.0051046>,
    <0.0000059, -0.9999751, 0.0070516>,
    <0.0000090, -0.9999870, 0.0051046>,
    <-0.0000138, -0.9999782, 0.0066053>,
    <-0.0000138, -0.9999782, 0.0066053>,
    <-0.0000487, -0.9999604, 0.0088994>,
    <-0.0000289, -0.9999511, 0.0098864>,
    <-0.0000289, -0.9999511, 0.0098864>,
    <-0.0000007, -0.9999362, 0.0112929>,
    <0.0001428, -0.9999999, 0.0005141>,
    <0.0001426, -0.9999998, 0.0005303>,
    <0.0001467, -0.9999998, 0.0005304>,
    <0.0001468, -0.9999999, 0.0005142>,
    <0.0001469, -0.9999999, 0.0004984>,
    <0.0001430, -0.9999999, 0.0004984>,
    <0.0001430, -0.9999999, 0.0004984>,
    <0.0001391, -0.9999999, 0.0004983>,
    <0.0001388, -0.9999999, 0.0005141>,
    <0.0001388, -0.9999999, 0.0005141>,
    <0.0001386, -0.9999998, 0.0005303>,
    <0.0001425, -0.9999998, 0.0005471>,
    <0.0001466, -0.9999998, 0.0005472>,
    <0.0001386, -0.9999998, 0.0005303>,
    <0.0001383, -0.9999998, 0.0005470>,
    <0.0001383, -0.9999998, 0.0005470>,
    <0.0001381, -0.9999998, 0.0005643>,
    <0.0001423, -0.9999998, 0.0005644>,
    <0.0001423, -0.9999998, 0.0005644>,
    <0.0001464, -0.9999998, 0.0005645>,
    <0.0001507, -0.9999998, 0.0005472>,
    <0.0001508, -0.9999998, 0.0005305>,
    <0.0001464, -0.9999998, 0.0005645>,
    <0.0001506, -0.9999998, 0.0005646>,
    <0.0001506, -0.9999998, 0.0005646>,
    <0.0001548, -0.9999998, 0.0005647>,
    <0.0001548, -0.9999998, 0.0005473>,
    <0.0001548, -0.9999998, 0.0005473>,
    <0.0001548, -0.9999998, 0.0005305>,
    <0.0001508, -0.9999999, 0.0005142>,
    <0.0001548, -0.9999998, 0.0005305>,
    <0.0001548, -0.9999999, 0.0005142>,
    <0.0001548, -0.9999999, 0.0005142>,
    <0.0001548, -0.9999999, 0.0004984>,
    <0.0001509, -0.9999999, 0.0004984>,
    <0.0001509, -0.9999999, 0.0004984>,
    <0.0001469, -0.9999999, 0.0004984>,
    <0.9997304, 0.0001558, 0.0232204>,
    <0.9997304, 0.0001558, 0.0232184>,
    <0.9997304, 0.0001554, 0.0232184>,
    <0.9997304, 0.0001554, 0.0232204>,
    <0.9997303, 0.0001554, 0.0232224>,
    <0.9997303, 0.0001558, 0.0232224>,
    <0.9997303, 0.0001558, 0.0232224>,
    <0.9997303, 0.0001563, 0.0232224>,
    <0.9997304, 0.0001563, 0.0232204>,
    <0.9997304, 0.0001563, 0.0232204>,
    <0.9997304, 0.0001563, 0.0232184>,
    <0.9997305, 0.0001558, 0.0232164>,
    <0.9997305, 0.0001554, 0.0232164>,
    <0.9997304, 0.0001563, 0.0232184>,
    <0.9997305, 0.0001563, 0.0232164>,
    <0.9997305, 0.0001563, 0.0232164>,
    <0.9997305, 0.0001563, 0.0232145>,
    <0.9997305, 0.0001558, 0.0232145>,
    <0.9997305, 0.0001558, 0.0232145>,
    <0.9997305, 0.0001554, 0.0232145>,
    <0.9997305, 0.0001550, 0.0232164>,
    <0.9997304, 0.0001550, 0.0232184>,
    <0.9997305, 0.0001554, 0.0232145>,
    <0.9997305, 0.0001550, 0.0232145>,
    <0.9997305, 0.0001550, 0.0232145>,
    <0.9997305, 0.0001546, 0.0232145>,
    <0.9997305, 0.0001546, 0.0232164>,
    <0.9997305, 0.0001546, 0.0232164>,
    <0.9997304, 0.0001546, 0.0232184>,
    <0.9997304, 0.0001550, 0.0232204>,
    <0.9997304, 0.0001546, 0.0232184>,
    <0.9997304, 0.0001546, 0.0232204>,
    <0.9997304, 0.0001546, 0.0232204>,
    <0.9997303, 0.0001546, 0.0232224>,
    <0.9997303, 0.0001550, 0.0232224>,
    <0.9997303, 0.0001550, 0.0232224>,
    <0.9997303, 0.0001554, 0.0232224>,
    <-0.0000946, 0.9999998, 0.0005706>,
    <-0.0000945, 0.9999998, 0.0005680>,
    <-0.0000939, 0.9999998, 0.0005681>,
    <-0.0000939, 0.9999998, 0.0005706>,
    <-0.0000940, 0.9999998, 0.0005733>,
    <-0.0000946, 0.9999998, 0.0005733>,
    <-0.0000946, 0.9999998, 0.0005733>,
    <-0.0000952, 0.9999998, 0.0005733>,
    <-0.0000952, 0.9999998, 0.0005706>,
    <-0.0000952, 0.9999998, 0.0005706>,
    <-0.0000952, 0.9999998, 0.0005680>,
    <-0.0000945, 0.9999998, 0.0005655>,
    <-0.0000939, 0.9999998, 0.0005656>,
    <-0.0000952, 0.9999998, 0.0005680>,
    <-0.0000951, 0.9999998, 0.0005655>,
    <-0.0000951, 0.9999998, 0.0005655>,
    <-0.0000951, 0.9999998, 0.0005631>,
    <-0.0000945, 0.9999998, 0.0005631>,
    <-0.0000945, 0.9999998, 0.0005631>,
    <-0.0000939, 0.9999998, 0.0005631>,
    <-0.0000933, 0.9999998, 0.0005656>,
    <-0.0000933, 0.9999998, 0.0005681>,
    <-0.0000939, 0.9999998, 0.0005631>,
    <-0.0000933, 0.9999998, 0.0005631>,
    <-0.0000933, 0.9999998, 0.0005631>,
    <-0.0000927, 0.9999998, 0.0005631>,
    <-0.0000927, 0.9999998, 0.0005656>,
    <-0.0000927, 0.9999998, 0.0005656>,
    <-0.0000927, 0.9999998, 0.0005681>,
    <-0.0000933, 0.9999998, 0.0005706>,
    <-0.0000927, 0.9999998, 0.0005681>,
    <-0.0000927, 0.9999998, 0.0005707>,
    <-0.0000927, 0.9999998, 0.0005707>,
    <-0.0000927, 0.9999998, 0.0005733>,
    <-0.0000933, 0.9999998, 0.0005733>,
    <-0.0000933, 0.9999998, 0.0005733>,
    <-0.0000940, 0.9999998, 0.0005733>,
    <0.0001510, -0.9999947, 0.0032413>,
    <0.0001510, -0.9999952, 0.0030960>,
    <0.0001474, -0.9999952, 0.0031052>,
    <0.0001474, -0.9999947, 0.0032458>,
    <0.0001474, -0.9999943, 0.0033864>,
    <0.0001510, -0.9999943, 0.0033866>,
    <0.0001510, -0.9999943, 0.0033866>,
    <0.0001548, -0.9999943, 0.0033868>,
    <0.0001548, -0.9999948, 0.0032365>,
    <0.0001548, -0.9999948, 0.0032365>,
    <0.0001548, -0.9999952, 0.0030862>,
    <0.0001510, -0.9999956, 0.0029508>,
    <0.0001474, -0.9999956, 0.0029647>,
    <0.0001548, -0.9999952, 0.0030862>,
    <0.0001548, -0.9999957, 0.0029360>,
    <0.0001548, -0.9999957, 0.0029360>,
    <0.0001548, -0.9999961, 0.0027857>,
    <0.0001510, -0.9999961, 0.0028055>,
    <0.0001510, -0.9999961, 0.0028055>,
    <0.0001474, -0.9999960, 0.0028241>,
    <0.0001440, -0.9999956, 0.0029777>,
    <0.0001440, -0.9999951, 0.0031138>,
    <0.0001474, -0.9999960, 0.0028241>,
    <0.0001440, -0.9999960, 0.0028415>,
    <0.0001440, -0.9999960, 0.0028415>,
    <0.0001408, -0.9999959, 0.0028578>,
    <0.0001408, -0.9999955, 0.0029899>,
    <0.0001408, -0.9999955, 0.0029899>,
    <0.0001408, -0.9999951, 0.0031219>,
    <0.0001440, -0.9999947, 0.0032500>,
    <0.0001408, -0.9999951, 0.0031219>,
    <0.0001408, -0.9999947, 0.0032540>,
    <0.0001408, -0.9999947, 0.0032540>,
    <0.0001408, -0.9999943, 0.0033861>,
    <0.0001440, -0.9999943, 0.0033862>,
    <0.0001440, -0.9999943, 0.0033862>,
    <0.0001474, -0.9999943, 0.0033864>,
    <0.1905399, 0.0000294, -0.9816795>,
    <0.1905394, 0.0000294, -0.9816795>,
    <0.1905394, 0.0000293, -0.9816795>,
    <0.1905399, 0.0000293, -0.9816795>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000294, -0.9816794>,
    <0.1905403, 0.0000294, -0.9816794>,
    <0.1905403, 0.0000295, -0.9816794>,
    <0.1905399, 0.0000295, -0.9816795>,
    <0.1905399, 0.0000295, -0.9816795>,
    <0.1905394, 0.0000295, -0.9816795>,
    <0.1905390, 0.0000294, -0.9816796>,
    <0.1905390, 0.0000293, -0.9816796>,
    <0.1905394, 0.0000295, -0.9816795>,
    <0.1905390, 0.0000295, -0.9816796>,
    <0.1905390, 0.0000295, -0.9816796>,
    <0.1905385, 0.0000295, -0.9816797>,
    <0.1905385, 0.0000294, -0.9816797>,
    <0.1905385, 0.0000294, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905390, 0.0000293, -0.9816796>,
    <0.1905394, 0.0000293, -0.9816795>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000292, -0.9816797>,
    <0.1905390, 0.0000292, -0.9816796>,
    <0.1905390, 0.0000292, -0.9816796>,
    <0.1905394, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000293, -0.9816795>,
    <0.1905394, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000292, -0.9816795>,
    <0.1905403, 0.0000292, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <-0.0000906, 0.9999917, 0.0040632>,
    <-0.0000906, 0.9999921, 0.0039843>,
    <-0.0000886, 0.9999921, 0.0039793>,
    <-0.0000886, 0.9999918, 0.0040557>,
    <-0.0000886, 0.9999915, 0.0041320>,
    <-0.0000906, 0.9999914, 0.0041421>,
    <-0.0000906, 0.9999914, 0.0041421>,
    <-0.0000927, 0.9999914, 0.0041529>,
    <-0.0000927, 0.9999917, 0.0040712>,
    <-0.0000927, 0.9999917, 0.0040712>,
    <-0.0000927, 0.9999920, 0.0039896>,
    <-0.0000906, 0.9999924, 0.0039053>,
    <-0.0000886, 0.9999924, 0.0039029>,
    <-0.0000927, 0.9999920, 0.0039896>,
    <-0.0000927, 0.9999924, 0.0039079>,
    <-0.0000927, 0.9999924, 0.0039079>,
    <-0.0000927, 0.9999927, 0.0038263>,
    <-0.0000906, 0.9999927, 0.0038264>,
    <-0.0000906, 0.9999927, 0.0038264>,
    <-0.0000886, 0.9999927, 0.0038265>,
    <-0.0000868, 0.9999924, 0.0039006>,
    <-0.0000868, 0.9999921, 0.0039746>,
    <-0.0000886, 0.9999927, 0.0038265>,
    <-0.0000868, 0.9999927, 0.0038266>,
    <-0.0000868, 0.9999927, 0.0038266>,
    <-0.0000851, 0.9999927, 0.0038267>,
    <-0.0000851, 0.9999924, 0.0038984>,
    <-0.0000851, 0.9999924, 0.0038984>,
    <-0.0000851, 0.9999921, 0.0039702>,
    <-0.0000868, 0.9999918, 0.0040486>,
    <-0.0000851, 0.9999921, 0.0039702>,
    <-0.0000851, 0.9999918, 0.0040420>,
    <-0.0000851, 0.9999918, 0.0040420>,
    <-0.0000851, 0.9999915, 0.0041137>,
    <-0.0000868, 0.9999915, 0.0041226>,
    <-0.0000868, 0.9999915, 0.0041226>,
    <-0.0000886, 0.9999915, 0.0041320>,
    <0.0001429, -1.0000000, 0.0000082>,
    <0.0001419, -1.0000000, 0.0000137>,
    <0.0001498, -1.0000000, 0.0000569>,
    <0.0001580, -1.0000000, 0.0000320>,
    <0.0001597, -1.0000000, 0.0000006>,
    <0.0001432, -1.0000000, 0.0000006>,
    <0.0001432, -1.0000000, 0.0000006>,
    <0.0001408, -1.0000000, 0.0000006>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000153>,
    <0.0001410, -1.0000000, 0.0000655>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001405, -1.0000000, 0.0000145>,
    <0.0001405, -1.0000000, 0.0000145>,
    <0.0001380, -1.0000000, 0.0000625>,
    <0.0001413, -1.0000000, 0.0001779>,
    <0.0001691, -1.0000000, 0.0001626>,
    <0.0001380, -1.0000000, 0.0000625>,
    <0.0001318, -1.0000000, 0.0001714>,
    <0.0001318, -1.0000000, 0.0001714>,
    <0.0001216, -0.9999999, 0.0004366>,
    <0.0001376, -0.9999999, 0.0004516>,
    <0.0001860, -0.9999999, 0.0004564>,
    <0.0002044, -1.0000000, 0.0001069>,
    <0.0003013, -0.9999998, 0.0004713>,
    <0.0004041, -0.9999998, 0.0005587>,
    <0.0002114, -1.0000000, 0.0000006>,
    <0.0002114, -1.0000000, 0.0000006>,
    <0.0001597, -1.0000000, 0.0000006>,
    <0.9990638, 0.0001532, -0.0432613>,
    <0.9990638, 0.0001532, -0.0432613>,
    <0.9828283, 0.0001506, -0.1845222>,
    <0.9828284, 0.0001506, -0.1845219>,
    <0.9828284, 0.0001506, -0.1845216>,
    <0.9990638, 0.0001532, -0.0432612>,
    <0.9990638, 0.0001532, -0.0432612>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9990638, 0.0001532, -0.0432614>,
    <0.9828283, 0.0001506, -0.1845225>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9990638, 0.0001532, -0.0432615>,
    <0.9990638, 0.0001532, -0.0432615>,
    <0.9828282, 0.0001506, -0.1845228>,
    <0.8922266, 0.0001364, -0.4515879>,
    <0.8922269, 0.0001364, -0.4515873>,
    <0.9828282, 0.0001506, -0.1845228>,
    <0.8922263, 0.0001364, -0.4515885>,
    <0.8922263, 0.0001364, -0.4515885>,
    <0.6239846, 0.0000949, -0.7814367>,
    <0.6239852, 0.0000949, -0.7814361>,
    <0.6239858, 0.0000949, -0.7814356>,
    <0.8922272, 0.0001364, -0.4515867>,
    <0.6239865, 0.0000949, -0.7814351>,
    <0.6239871, 0.0000949, -0.7814346>,
    <0.8922275, 0.0001364, -0.4515861>,
    <0.8922275, 0.0001364, -0.4515861>,
    <0.9828284, 0.0001506, -0.1845216>,
    <-0.0000844, 1.0000000, 0.0000236>,
    <-0.0000832, 1.0000000, 0.0000197>,
    <-0.0000697, 1.0000000, 0.0000817>,
    <-0.0000799, 1.0000000, 0.0001007>,
    <-0.0000834, 1.0000000, 0.0001064>,
    <-0.0000848, 1.0000000, 0.0000248>,
    <-0.0000848, 1.0000000, 0.0000248>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000821, 1.0000000, 0.0000113>,
    <-0.0000606, 1.0000000, 0.0000444>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000589, 1.0000000, 0.0000006>,
    <0.0000041, 1.0000000, 0.0001407>,
    <-0.0000358, 1.0000000, 0.0002273>,
    <-0.0000589, 1.0000000, 0.0000006>,
    <0.0000100, 1.0000000, 0.0000006>,
    <0.0000100, 1.0000000, 0.0000006>,
    <0.0002453, 0.9999998, 0.0006317>,
    <0.0001370, 0.9999998, 0.0005812>,
    <0.0000045, 0.9999998, 0.0006140>,
    <-0.0000684, 1.0000000, 0.0002687>,
    <-0.0000538, 0.9999998, 0.0006609>,
    <-0.0000741, 0.9999998, 0.0006969>,
    <-0.0000799, 1.0000000, 0.0002847>,
    <-0.0000799, 1.0000000, 0.0002847>,
    <-0.0000834, 1.0000000, 0.0001064>,
    <0.0002903, -0.9999984, 0.0017652>,
    <0.0001720, -0.9999993, 0.0011301>,
    <0.0001022, -0.9999983, 0.0018567>,
    <0.0001108, -0.9999949, 0.0031915>,
    <0.0001476, -0.9999397, 0.0109793>,
    <0.0012656, -0.9999369, 0.0111618>,
    <0.0012656, -0.9999369, 0.0111618>,
    <0.0004041, -0.9999998, 0.0005587>,
    <0.0001236, -0.9999995, 0.0009991>,
    <0.0000986, -0.9999989, 0.0014951>,
    <0.0001216, -0.9999999, 0.0004366>,
    <0.0001091, -0.9999995, 0.0009561>,
    <0.0001091, -0.9999995, 0.0009561>,
    <0.0000977, -0.9999990, 0.0013949>,
    <0.0000782, -0.9999992, 0.0012866>,
    <0.0000399, -0.9999988, 0.0015537>,
    <0.0000977, -0.9999990, 0.0013949>,
    <0.0000891, -0.9999993, 0.0011920>,
    <0.0000891, -0.9999993, 0.0011920>,
    <0.0000833, -0.9999998, 0.0006206>,
    <0.0000734, -0.9999998, 0.0006546>,
    <0.0000424, -0.9999998, 0.0006972>,
    <-0.0000548, -0.9999970, 0.0024352>,
    <-0.0000319, -0.9999997, 0.0007320>,
    <-0.0000815, -0.9999997, 0.0007081>,
    <-0.0005894, -0.9999409, 0.0108590>,
    <-0.0005894, -0.9999409, 0.0108590>,
    <0.0001476, -0.9999397, 0.0109793>,
    <0.3536429, 0.0000533, -0.9353805>,
    <0.3536424, 0.0000533, -0.9353807>,
    <0.2587557, 0.0000386, -0.9659428>,
    <0.2587561, 0.0000386, -0.9659427>,
    <0.2587565, 0.0000386, -0.9659426>,
    <0.3536434, 0.0000533, -0.9353803>,
    <0.3536434, 0.0000533, -0.9353803>,
    <0.6239871, 0.0000949, -0.7814346>,
    <0.3536418, 0.0000533, -0.9353809>,
    <0.2587553, 0.0000386, -0.9659429>,
    <0.6239846, 0.0000949, -0.7814367>,
    <0.3536413, 0.0000533, -0.9353811>,
    <0.3536413, 0.0000533, -0.9353811>,
    <0.2587549, 0.0000386, -0.9659430>,
    <0.3066458, 0.0000453, -0.9518237>,
    <0.3066462, 0.0000453, -0.9518236>,
    <0.2587549, 0.0000386, -0.9659430>,
    <0.3066453, 0.0000453, -0.9518239>,
    <0.3066453, 0.0000453, -0.9518239>,
    <0.5358762, 0.0000785, -0.8442966>,
    <0.5358768, 0.0000785, -0.8442962>,
    <0.5358775, 0.0000785, -0.8442958>,
    <0.3066467, 0.0000453, -0.9518234>,
    <0.5358781, 0.0000785, -0.8442954>,
    <0.5358788, 0.0000785, -0.8442949>,
    <0.3066471, 0.0000453, -0.9518233>,
    <0.3066471, 0.0000453, -0.9518233>,
    <0.2587565, 0.0000386, -0.9659426>,
    <-0.0000481, 0.9999990, 0.0014073>,
    <0.0000111, 0.9999989, 0.0014713>,
    <-0.0000549, 0.9999972, 0.0023605>,
    <-0.0000593, 0.9999979, 0.0020363>,
    <-0.0000606, 0.9999979, 0.0020310>,
    <-0.0000670, 0.9999989, 0.0014538>,
    <-0.0000670, 0.9999989, 0.0014538>,
    <-0.0000741, 0.9999998, 0.0006969>,
    <0.0001476, 0.9999977, 0.0021237>,
    <-0.0000450, 0.9999928, 0.0038031>,
    <0.0002453, 0.9999998, 0.0006317>,
    <0.0012409, 0.9999196, 0.0126229>,
    <0.0012409, 0.9999196, 0.0126229>,
    <-0.0000041, 0.9999229, 0.0124198>,
    <-0.0002242, 0.9999958, 0.0028820>,
    <-0.0001153, 0.9999981, 0.0019448>,
    <-0.0000041, 0.9999229, 0.0124198>,
    <-0.0008233, 0.9999242, 0.0122861>,
    <-0.0008233, 0.9999242, 0.0122861>,
    <-0.0002389, 0.9999997, 0.0008012>,
    <-0.0001858, 0.9999996, 0.0008673>,
    <-0.0001009, 0.9999996, 0.0008664>,
    <-0.0000693, 0.9999985, 0.0017093>,
    <-0.0000645, 0.9999996, 0.0008553>,
    <-0.0000524, 0.9999996, 0.0008537>,
    <-0.0000557, 0.9999986, 0.0016790>,
    <-0.0000557, 0.9999986, 0.0016790>,
    <-0.0000606, 0.9999979, 0.0020310>,
    <0.0000426, -1.0000000, 0.0001869>,
    <0.0000607, -1.0000000, 0.0002648>,
    <0.0000730, -1.0000000, 0.0001115>,
    <0.0000692, -1.0000000, 0.0000775>,
    <0.0000684, -1.0000000, 0.0000345>,
    <0.0000399, -1.0000000, 0.0000345>,
    <0.0000399, -1.0000000, 0.0000345>,
    <-0.0000815, -0.9999997, 0.0007081>,
    <0.0000752, -1.0000000, 0.0002807>,
    <0.0000771, -1.0000000, 0.0001238>,
    <0.0000833, -0.9999998, 0.0006206>,
    <0.0000801, -1.0000000, 0.0002736>,
    <0.0000801, -1.0000000, 0.0002736>,
    <0.0000785, -1.0000000, 0.0001223>,
    <0.0000777, -1.0000000, 0.0000537>,
    <0.0000772, -1.0000000, 0.0000514>,
    <0.0000785, -1.0000000, 0.0001223>,
    <0.0000778, -1.0000000, 0.0000530>,
    <0.0000778, -1.0000000, 0.0000530>,
    <0.0000776, -1.0000000, 0.0000325>,
    <0.0000776, -1.0000000, 0.0000330>,
    <0.0000776, -1.0000000, 0.0000330>,
    <0.0000776, -1.0000000, 0.0000335>,
    <0.0000767, -1.0000000, 0.0000443>,
    <0.0000776, -1.0000000, 0.0000335>,
    <0.0000776, -1.0000000, 0.0000340>,
    <0.0000776, -1.0000000, 0.0000340>,
    <0.0000776, -1.0000000, 0.0000345>,
    <0.0000766, -1.0000000, 0.0000345>,
    <0.0000766, -1.0000000, 0.0000345>,
    <0.0000684, -1.0000000, 0.0000345>,
    <0.8300740, 0.0001209, -0.5576532>,
    <0.8300736, 0.0001209, -0.5576538>,
    <0.9623799, 0.0001397, -0.2717074>,
    <0.9623800, 0.0001397, -0.2717070>,
    <0.9623802, 0.0001397, -0.2717065>,
    <0.8300745, 0.0001209, -0.5576525>,
    <0.8300745, 0.0001209, -0.5576525>,
    <0.5358788, 0.0000785, -0.8442949>,
    <0.8300732, 0.0001209, -0.5576545>,
    <0.9623798, 0.0001397, -0.2717079>,
    <0.5358762, 0.0000785, -0.8442966>,
    <0.8300727, 0.0001209, -0.5576552>,
    <0.8300727, 0.0001209, -0.5576552>,
    <0.9623796, 0.0001397, -0.2717083>,
    <0.9945474, 0.0001442, -0.1042853>,
    <0.9945474, 0.0001442, -0.1042851>,
    <0.9623796, 0.0001397, -0.2717083>,
    <0.9945474, 0.0001442, -0.1042855>,
    <0.9945474, 0.0001442, -0.1042855>,
    <0.9986191, 0.0001446, -0.0525351>,
    <0.9986191, 0.0001446, -0.0525350>,
    <0.9986191, 0.0001446, -0.0525350>,
    <0.9986191, 0.0001446, -0.0525349>,
    <0.9945475, 0.0001442, -0.1042849>,
    <0.9986191, 0.0001446, -0.0525349>,
    <0.9986191, 0.0001446, -0.0525347>,
    <0.9986191, 0.0001446, -0.0525347>,
    <0.9986191, 0.0001446, -0.0525346>,
    <0.9945475, 0.0001442, -0.1042847>,
    <0.9945475, 0.0001442, -0.1042847>,
    <0.9623802, 0.0001397, -0.2717065>,
    <-0.0000564, 0.9999999, 0.0003628>,
    <-0.0000731, 0.9999999, 0.0003290>,
    <-0.0000560, 1.0000000, 0.0001378>,
    <-0.0000513, 1.0000000, 0.0001579>,
    <-0.0000497, 1.0000000, 0.0001622>,
    <-0.0000506, 0.9999999, 0.0003698>,
    <-0.0000506, 0.9999999, 0.0003698>,
    <-0.0000524, 0.9999996, 0.0008537>,
    <-0.0000935, 1.0000000, 0.0002249>,
    <-0.0000603, 1.0000000, 0.0000933>,
    <-0.0002389, 0.9999997, 0.0008012>,
    <-0.0000961, 1.0000000, 0.0000391>,
    <-0.0000961, 1.0000000, 0.0000391>,
    <-0.0000611, 1.0000000, 0.0000391>,
    <-0.0000506, 1.0000000, 0.0000521>,
    <-0.0000501, 1.0000000, 0.0000621>,
    <-0.0000611, 1.0000000, 0.0000391>,
    <-0.0000507, 1.0000000, 0.0000391>,
    <-0.0000507, 1.0000000, 0.0000391>,
    <-0.0000492, 1.0000000, 0.0000391>,
    <-0.0000492, 1.0000000, 0.0000393>,
    <-0.0000492, 1.0000000, 0.0000393>,
    <-0.0000492, 1.0000000, 0.0000396>,
    <-0.0000495, 1.0000000, 0.0000667>,
    <-0.0000492, 1.0000000, 0.0000396>,
    <-0.0000492, 1.0000000, 0.0000399>,
    <-0.0000492, 1.0000000, 0.0000399>,
    <-0.0000492, 1.0000000, 0.0000401>,
    <-0.0000493, 1.0000000, 0.0000679>,
    <-0.0000493, 1.0000000, 0.0000679>,
    <-0.0000497, 1.0000000, 0.0001622>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, -0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <0.0000743, -1.0000000, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, -0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <-0.0000476, 1.0000000, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <-0.9869426, -0.0002042, -0.1610724>,
    <-0.9869426, -0.0002040, -0.1610724>,
    <-0.9869431, -0.0002040, -0.1610691>,
    <-0.9869431, -0.0002042, -0.1610691>,
    <-0.9869431, -0.0002043, -0.1610691>,
    <-0.9869426, -0.0002043, -0.1610724>,
    <-0.9869426, -0.0002043, -0.1610724>,
    <-0.9869420, -0.0002043, -0.1610756>,
    <-0.9869420, -0.0002042, -0.1610756>,
    <-0.9869420, -0.0002042, -0.1610756>,
    <-0.9869420, -0.0002040, -0.1610756>,
    <-0.9869426, -0.0002039, -0.1610724>,
    <-0.9869431, -0.0002039, -0.1610691>,
    <-0.9869420, -0.0002040, -0.1610756>,
    <-0.9869420, -0.0002039, -0.1610756>,
    <-0.9869420, -0.0002039, -0.1610756>,
    <-0.9869420, -0.0002037, -0.1610756>,
    <-0.9869426, -0.0002037, -0.1610724>,
    <-0.9869426, -0.0002037, -0.1610724>,
    <-0.9869431, -0.0002037, -0.1610691>,
    <-0.9869436, -0.0002039, -0.1610659>,
    <-0.9869436, -0.0002040, -0.1610659>,
    <-0.9869431, -0.0002037, -0.1610691>,
    <-0.9869436, -0.0002037, -0.1610659>,
    <-0.9869436, -0.0002037, -0.1610659>,
    <-0.9869442, -0.0002037, -0.1610627>,
    <-0.9869442, -0.0002039, -0.1610627>,
    <-0.9869442, -0.0002039, -0.1610627>,
    <-0.9869442, -0.0002040, -0.1610627>,
    <-0.9869436, -0.0002042, -0.1610659>,
    <-0.9869442, -0.0002040, -0.1610627>,
    <-0.9869442, -0.0002042, -0.1610627>,
    <-0.9869442, -0.0002042, -0.1610627>,
    <-0.9869442, -0.0002043, -0.1610627>,
    <-0.9869436, -0.0002043, -0.1610659>,
    <-0.9869436, -0.0002043, -0.1610659>,
    <-0.9869431, -0.0002043, -0.1610691>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <0.9999404, 0.0003438, 0.0109141>,
    <0.9999447, 0.0002073, 0.0105163>,
    <0.9999338, 0.0002072, 0.0115037>,
    <0.9999321, 0.0002414, 0.0116512>,
    <0.9999286, 0.0002504, 0.0119507>,
    <0.9999285, 0.0003746, 0.0119506>,
    <0.9999285, 0.0003746, 0.0119506>,
    <0.9999722, 0.0008411, 0.0074076>,
    <0.9999724, 0.0006034, 0.0074077>,
    <0.9999725, 0.0002073, 0.0074076>,
    <0.9999404, 0.0000707, 0.0109136>,
    <0.9999321, 0.0001731, 0.0116506>,
    <0.9999725, -0.0001887, 0.0074074>,
    <0.9999725, -0.0004264, 0.0074070>,
    <0.9999286, 0.0000399, 0.0119496>,
    <0.9999286, 0.0000399, 0.0119496>,
    <0.9999286, 0.0001640, 0.0119498>,
    <0.9999294, 0.0002031, 0.0118782>,
    <0.9999298, 0.0002072, 0.0118451>,
    <0.9999286, 0.0001640, 0.0119498>,
    <0.9999286, 0.0002018, 0.0119498>,
    <0.9999286, 0.0002018, 0.0119498>,
    <0.9999286, 0.0002071, 0.0119498>,
    <0.9999286, 0.0002071, 0.0119500>,
    <0.9999286, 0.0002071, 0.0119500>,
    <0.9999286, 0.0002071, 0.0119503>,
    <0.9999294, 0.0002113, 0.0118787>,
    <0.9999286, 0.0002071, 0.0119503>,
    <0.9999286, 0.0002071, 0.0119505>,
    <0.9999286, 0.0002071, 0.0119505>,
    <0.9999286, 0.0002071, 0.0119508>,
    <0.9999286, 0.0002126, 0.0119508>,
    <0.9999286, 0.0002126, 0.0119508>,
    <0.9999286, 0.0002504, 0.0119507>,
    <0.9999903, 0.0006657, -0.0043628>,
    <0.9997832, 0.0004345, -0.0208159>,
    <0.9998818, 0.0002073, -0.0153711>,
    <0.9999996, 0.0002073, -0.0008270>,
    <0.9999722, 0.0008411, 0.0074076>,
    <0.9990811, 0.0020567, -0.0428093>,
    <0.9990811, 0.0020567, -0.0428093>,
    <0.9990829, 0.0006845, -0.0428133>,
    <0.9993788, 0.0002463, -0.0352415>,
    <0.9994752, 0.0002072, -0.0323937>,
    <0.9990829, 0.0006845, -0.0428133>,
    <0.9990830, 0.0002668, -0.0428145>,
    <0.9990830, 0.0002668, -0.0428145>,
    <0.9990830, 0.0002071, -0.0428147>,
    <0.9990830, 0.0002071, -0.0428138>,
    <0.9990830, 0.0002071, -0.0428138>,
    <0.9990831, 0.0002071, -0.0428129>,
    <0.9993789, 0.0001680, -0.0352399>,
    <0.9997834, -0.0000200, -0.0208147>,
    <0.9990831, 0.0002071, -0.0428129>,
    <0.9990831, 0.0002071, -0.0428121>,
    <0.9990831, 0.0002071, -0.0428121>,
    <0.9990832, 0.0002071, -0.0428112>,
    <0.9990832, 0.0001474, -0.0428110>,
    <0.9990832, 0.0001474, -0.0428110>,
    <0.9990832, -0.0002702, -0.0428096>,
    <0.9999905, -0.0002510, -0.0043624>,
    <0.9990832, -0.0002702, -0.0428096>,
    <0.9990821, -0.0016423, -0.0428051>,
    <0.9990821, -0.0016423, -0.0428051>,
    <0.9999725, -0.0004264, 0.0074070>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9514109>,
    <0.4350054, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289899, 0.9514109>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9514109>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559172, 0.9657316>,
    <0.6289899, 0.9514109>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4350054, 0.9657316>,
    <0.5000060, 0.9664305>,
    <0.4264033, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379346, 0.9664305>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664305>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559172, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773692, 0.9671308>,
    <0.6379346, 0.9664305>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4264033, 0.9671308>,
    <0.5000061, 0.9784050>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473428, 0.9784050>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9784050>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773692, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473428, 0.9784050>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032659, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458871>,
    <0.4677608, 0.9457569>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9514109>,
    <0.4355157, 0.9458871>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9452857>,
    <0.4677603, 0.9520134>,
    <0.4676327, 0.9588725>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9514109>,
    <0.5000059, 0.9657316>,
    <0.4350054, 0.9657316>,
    <0.4677603, 0.9520134>,
    <0.5000059, 0.9583740>,
    <0.4675013, 0.9657316>,
    <0.4352839, 0.9585445>,
    <0.4031382, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4350054, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352839, 0.9585445>,
    <0.4023500, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032659, 0.9526160>,
    <0.5322510, 0.9457569>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9514109>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9520135>,
    <0.5000059, 0.9452857>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458711>,
    <0.5967411, 0.9457569>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289899, 0.9514109>,
    <0.5644961, 0.9458711>,
    <0.5967380, 0.9395004>,
    <0.6289859, 0.9452857>,
    <0.5967441, 0.9520135>,
    <0.5967475, 0.9588725>,
    <0.5644983, 0.9526160>,
    <0.6289899, 0.9514109>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967441, 0.9520135>,
    <0.6289944, 0.9583740>,
    <0.5967509, 0.9657316>,
    <0.5645004, 0.9589932>,
    <0.5322532, 0.9588725>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9514109>,
    <0.5645004, 0.9589932>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9583740>,
    <0.5322521, 0.9520135>,
    <0.6423395, 0.9457569>,
    <0.6556982, 0.9526160>,
    <0.6289899, 0.9514109>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423438, 0.9520134>,
    <0.6289859, 0.9452857>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458871>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458871>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691098, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559172, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694404, 0.9657316>,
    <0.6557972, 0.9585445>,
    <0.6424011, 0.9588725>,
    <0.6556982, 0.9526160>,
    <0.6559172, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289899, 0.9514109>,
    <0.6557972, 0.9585445>,
    <0.6424600, 0.9657316>,
    <0.6289944, 0.9583740>,
    <0.6423438, 0.9520134>,
    <0.3997808, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4350054, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4023500, 0.9657316>,
    <0.4330490, 0.9660765>,
    <0.4665136, 0.9660812>,
    <0.4310370, 0.9664312>,
    <0.4350054, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664305>,
    <0.4330490, 0.9660765>,
    <0.4675013, 0.9657316>,
    <0.5000060, 0.9661007>,
    <0.4655215, 0.9664308>,
    <0.4643631, 0.9667808>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664305>,
    <0.5000061, 0.9671308>,
    <0.4264033, 0.9671308>,
    <0.4655215, 0.9664308>,
    <0.5000060, 0.9667582>,
    <0.4631991, 0.9671308>,
    <0.4287555, 0.9667757>,
    <0.3931579, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4264033, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4287555, 0.9667757>,
    <0.3895634, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664305>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664308>,
    <0.5000060, 0.9661007>,
    <0.5322542, 0.9657316>,
    <0.5668649, 0.9661011>,
    <0.6001028, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379346, 0.9664305>,
    <0.5668649, 0.9661011>,
    <0.5967509, 0.9657316>,
    <0.6337189, 0.9661007>,
    <0.6034548, 0.9664308>,
    <0.6068115, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.6379346, 0.9664305>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034548, 0.9664308>,
    <0.6421255, 0.9667582>,
    <0.6101681, 0.9671308>,
    <0.5710683, 0.9667586>,
    <0.5356086, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664305>,
    <0.5710683, 0.9667586>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667582>,
    <0.5344905, 0.9664308>,
    <0.6473391, 0.9660812>,
    <0.6665054, 0.9664312>,
    <0.6379346, 0.9664305>,
    <0.6289992, 0.9657316>,
    <0.6559172, 0.9657316>,
    <0.6522200, 0.9664308>,
    <0.6337189, 0.9661007>,
    <0.6424600, 0.9657316>,
    <0.6611372, 0.9660765>,
    <0.6749768, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559172, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6611372, 0.9660765>,
    <0.6694404, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866644, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773692, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926253, 0.9671308>,
    <0.6718544, 0.9667757>,
    <0.6571745, 0.9667808>,
    <0.6665054, 0.9664312>,
    <0.6773692, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379346, 0.9664305>,
    <0.6718544, 0.9667757>,
    <0.6621313, 0.9671308>,
    <0.6421255, 0.9667582>,
    <0.6522200, 0.9664308>,
    <0.3896432, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4264033, 0.9671308>,
    <0.3895222, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3895634, 0.9671308>,
    <0.4263749, 0.9728674>,
    <0.4631915, 0.9726067>,
    <0.4263507, 0.9777601>,
    <0.4264033, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9784050>,
    <0.4263749, 0.9728674>,
    <0.4631991, 0.9671308>,
    <0.5000061, 0.9727092>,
    <0.4631779, 0.9780826>,
    <0.4631249, 0.9832360>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9784050>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631779, 0.9780826>,
    <0.5000061, 0.9835191>,
    <0.4630714, 0.9883895>,
    <0.4262411, 0.9832068>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262411, 0.9832068>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895222, 0.9777601>,
    <0.5367803, 0.9726067>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9784050>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9780826>,
    <0.5000061, 0.9727092>,
    <0.5367268, 0.9671308>,
    <0.5735533, 0.9723901>,
    <0.6103351, 0.9726067>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473428, 0.9784050>,
    <0.5735533, 0.9723901>,
    <0.6101681, 0.9671308>,
    <0.6471134, 0.9727092>,
    <0.6105021, 0.9780826>,
    <0.6106561, 0.9832360>,
    <0.5736614, 0.9777601>,
    <0.6473428, 0.9784050>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105021, 0.9780826>,
    <0.6475487, 0.9835191>,
    <0.6108101, 0.9883895>,
    <0.5737711, 0.9832046>,
    <0.5368873, 0.9832360>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9784050>,
    <0.5737711, 0.9832046>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9835191>,
    <0.5368338, 0.9780826>,
    <0.6623549, 0.9726067>,
    <0.6778190, 0.9777601>,
    <0.6473428, 0.9784050>,
    <0.6468888, 0.9671308>,
    <0.6773692, 0.9671308>,
    <0.6625811, 0.9780826>,
    <0.6471134, 0.9727092>,
    <0.6621313, 0.9671308>,
    <0.6776119, 0.9728674>,
    <0.6928063, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773692, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776119, 0.9728674>,
    <0.6926253, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930704, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930704, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780837, 0.9832068>,
    <0.6628105, 0.9832360>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473428, 0.9784050>,
    <0.6780837, 0.9832068>,
    <0.6630402, 0.9883895>,
    <0.6475487, 0.9835191>,
    <0.6625811, 0.9780826>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.05, -0.36281, -0.147353>
}

#declare TMesh009 = mesh2 {
  vertex_vectors {
    582,
    <2.2046850, 0.2622270, 18.5058918>,
    <2.0021506, 0.2622153, 18.5058918>,
    <2.0021672, 0.1836464, 18.5058918>,
    <2.2046990, 0.1836606, 18.5058918>,
    <2.1034178, 0.2622212, 18.5058918>,
    <2.0021589, 0.2229309, 18.5058918>,
    <2.1034331, 0.1836535, 18.5058918>,
    <2.2046920, 0.2229438, 18.5058918>,
    <2.1034254, 0.2229373, 18.5058918>,
    <2.4072308, 0.1836748, 18.5058918>,
    <2.4072193, 0.2622387, 18.5058918>,
    <2.3059649, 0.1836677, 18.5058918>,
    <2.4072251, 0.2229568, 18.5058918>,
    <2.3059522, 0.2622329, 18.5058918>,
    <2.3059585, 0.2229503, 18.5058918>,
    <2.4072079, 0.3408027, 18.5058918>,
    <2.2046709, 0.3407934, 18.5058918>,
    <2.4072136, 0.3015207, 18.5058918>,
    <2.3059394, 0.3407980, 18.5058918>,
    <2.2046780, 0.3015102, 18.5058918>,
    <2.3059458, 0.3015155, 18.5058918>,
    <2.0021340, 0.3407842, 18.5058918>,
    <2.1034025, 0.3407888, 18.5058918>,
    <2.0021423, 0.3014997, 18.5058918>,
    <2.1034101, 0.3015050, 18.5058918>,
    <2.0664387, 0.1835149, 18.1207908>,
    <2.0044034, 0.1835050, 18.1202395>,
    <2.0044687, 0.1835009, 18.1217627>,
    <2.0559641, 0.1835106, 18.1217627>,
    <2.0354211, 0.1835099, 18.1205151>,
    <2.0044361, 0.1835029, 18.1210011>,
    <2.0302164, 0.1835058, 18.1217627>,
    <2.0612014, 0.1835128, 18.1212767>,
    <2.0328188, 0.1835079, 18.1211389>,
    <2.1074595, 0.1835204, 18.1217627>,
    <2.1284740, 0.1835248, 18.1213420>,
    <2.0817118, 0.1835155, 18.1217627>,
    <2.1179668, 0.1835226, 18.1215524>,
    <2.0974564, 0.1835198, 18.1210664>,
    <2.0895841, 0.1835177, 18.1214145>,
    <2.1494885, 0.1835292, 18.1209214>,
    <2.0769133, 0.1835192, 18.1198188>,
    <2.1389813, 0.1835270, 18.1211317>,
    <2.1132009, 0.1835242, 18.1203701>,
    <2.0716760, 0.1835170, 18.1203048>,
    <2.1053286, 0.1835220, 18.1207182>,
    <2.0043382, 0.1835091, 18.1187163>,
    <2.0406257, 0.1835141, 18.1192675>,
    <2.0043708, 0.1835071, 18.1194779>,
    <2.0380234, 0.1835120, 18.1198913>,
    <2.1284614, 0.2622422, 18.1213420>,
    <2.1074469, 0.2622423, 18.1217627>,
    <2.1284677, 0.2228835, 18.1213420>,
    <2.1074532, 0.2228813, 18.1217627>,
    <2.1179541, 0.2622422, 18.1215524>,
    <2.1179605, 0.2228824, 18.1215524>,
    <2.1074342, 0.3409641, 18.1217627>,
    <2.1284488, 0.3409595, 18.1213420>,
    <2.1074405, 0.3016032, 18.1217627>,
    <2.1179415, 0.3409618, 18.1215524>,
    <2.1284551, 0.3016009, 18.1213420>,
    <2.1179478, 0.3016020, 18.1215524>,
    <2.1494633, 0.3409550, 18.1209214>,
    <2.1494759, 0.2622421, 18.1209214>,
    <2.1389560, 0.3409573, 18.1211317>,
    <2.1494696, 0.3015985, 18.1209214>,
    <2.1389687, 0.2622421, 18.1211317>,
    <2.1389624, 0.3015997, 18.1211317>,
    <2.1494822, 0.2228856, 18.1209214>,
    <2.1389750, 0.2228846, 18.1211317>,
    <2.0664094, 0.3409536, 18.1207908>,
    <2.0559348, 0.3409583, 18.1217627>,
    <2.0974291, 0.3409566, 18.1210664>,
    <2.0816845, 0.3409612, 18.1217627>,
    <2.0611721, 0.3409559, 18.1212767>,
    <2.0895568, 0.3409589, 18.1214145>,
    <2.0044353, 0.3409524, 18.1217627>,
    <2.0043701, 0.3409477, 18.1202395>,
    <2.0301850, 0.3409554, 18.1217627>,
    <2.0044027, 0.3409501, 18.1210011>,
    <2.0353897, 0.3409506, 18.1205151>,
    <2.0327874, 0.3409530, 18.1211389>,
    <2.0043048, 0.3409429, 18.1187163>,
    <2.0768841, 0.3409489, 18.1198188>,
    <2.0043374, 0.3409453, 18.1194779>,
    <2.0405944, 0.3409459, 18.1192675>,
    <2.0716467, 0.3409513, 18.1203048>,
    <2.0379921, 0.3409483, 18.1198913>,
    <2.1131737, 0.3409520, 18.1203701>,
    <2.1053014, 0.3409543, 18.1207182>,
    <2.0766447, 0.1835280, 18.1376413>,
    <2.0042020, 0.1835177, 18.1370901>,
    <2.0404234, 0.1835229, 18.1373657>,
    <2.0042701, 0.1835134, 18.1279032>,
    <2.0767790, 0.1835236, 18.1287301>,
    <2.0405246, 0.1835185, 18.1283166>,
    <2.1490873, 0.1835383, 18.1381926>,
    <2.1492879, 0.1835337, 18.1295570>,
    <2.1128660, 0.1835332, 18.1379170>,
    <2.1130335, 0.1835287, 18.1291435>,
    <2.1486861, 0.1835474, 18.1554639>,
    <2.0763760, 0.1835369, 18.1554639>,
    <2.1488867, 0.1835429, 18.1468283>,
    <2.1125311, 0.1835422, 18.1554639>,
    <2.0765104, 0.1835325, 18.1465526>,
    <2.1126985, 0.1835377, 18.1466904>,
    <2.0040659, 0.1835263, 18.1554639>,
    <2.0402210, 0.1835316, 18.1554639>,
    <2.0041340, 0.1835220, 18.1462770>,
    <2.0403222, 0.1835272, 18.1464148>,
    <2.1490748, 0.2622419, 18.1381926>,
    <2.1490811, 0.2228901, 18.1381926>,
    <2.1492754, 0.2622420, 18.1295570>,
    <2.1492816, 0.2228879, 18.1295570>,
    <2.1490623, 0.3409454, 18.1381926>,
    <2.1492628, 0.3409502, 18.1295570>,
    <2.1490685, 0.3015936, 18.1381926>,
    <2.1492691, 0.3015961, 18.1295570>,
    <2.1486612, 0.3409359, 18.1554639>,
    <2.1486737, 0.2622417, 18.1554639>,
    <2.1488618, 0.3409406, 18.1468283>,
    <2.1486675, 0.3015888, 18.1554639>,
    <2.1488742, 0.2622418, 18.1468283>,
    <2.1488680, 0.3015912, 18.1468283>,
    <2.1486799, 0.2228945, 18.1554639>,
    <2.1488805, 0.2228923, 18.1468283>,
    <2.0766155, 0.3409392, 18.1376413>,
    <2.1128389, 0.3409423, 18.1379170>,
    <2.0767498, 0.3409441, 18.1287301>,
    <2.1130063, 0.3409471, 18.1291435>,
    <2.0041687, 0.3409329, 18.1370901>,
    <2.0042367, 0.3409379, 18.1279032>,
    <2.0403921, 0.3409361, 18.1373657>,
    <2.0404932, 0.3409410, 18.1283166>,
    <2.0040326, 0.3409230, 18.1554639>,
    <2.0763469, 0.3409294, 18.1554639>,
    <2.0041006, 0.3409280, 18.1462770>,
    <2.0401897, 0.3409262, 18.1554639>,
    <2.0764812, 0.3409343, 18.1465526>,
    <2.0402909, 0.3409311, 18.1464148>,
    <2.1125041, 0.3409327, 18.1554639>,
    <2.1126715, 0.3409375, 18.1466904>,
    <2.0812641, 0.1835432, 18.1573801>,
    <2.0039695, 0.1835324, 18.1573801>,
    <2.0426168, 0.1835378, 18.1573801>,
    <2.0040177, 0.1835294, 18.1564220>,
    <2.0788201, 0.1835400, 18.1564220>,
    <2.0414189, 0.1835347, 18.1564220>,
    <2.1585588, 0.1835539, 18.1573801>,
    <2.1536225, 0.1835507, 18.1564220>,
    <2.1199115, 0.1835485, 18.1573801>,
    <2.1162213, 0.1835454, 18.1564220>,
    <2.1684314, 0.1835604, 18.1592964>,
    <2.0861522, 0.1835495, 18.1592964>,
    <2.1634951, 0.1835571, 18.1583383>,
    <2.1272918, 0.1835549, 18.1592964>,
    <2.0837082, 0.1835463, 18.1583383>,
    <2.1236016, 0.1835517, 18.1583383>,
    <2.0038730, 0.1835385, 18.1592964>,
    <2.0450126, 0.1835440, 18.1592964>,
    <2.0039212, 0.1835355, 18.1583383>,
    <2.0438147, 0.1835409, 18.1583383>,
    <2.1585464, 0.2622415, 18.1573801>,
    <2.1585526, 0.2228977, 18.1573801>,
    <2.1536100, 0.2622416, 18.1564220>,
    <2.1536162, 0.2228961, 18.1564220>,
    <2.1585340, 0.3409291, 18.1573801>,
    <2.1535976, 0.3409325, 18.1564220>,
    <2.1585402, 0.3015853, 18.1573801>,
    <2.1536038, 0.3015870, 18.1564220>,
    <2.1684068, 0.3409223, 18.1592964>,
    <2.1684191, 0.2622414, 18.1592964>,
    <2.1634704, 0.3409257, 18.1583383>,
    <2.1684129, 0.3015818, 18.1592964>,
    <2.1634827, 0.2622414, 18.1583383>,
    <2.1634766, 0.3015836, 18.1583383>,
    <2.1684253, 0.2229009, 18.1592964>,
    <2.1634889, 0.2228993, 18.1583383>,
    <2.0812351, 0.3409225, 18.1573801>,
    <2.1198845, 0.3409258, 18.1573801>,
    <2.0787910, 0.3409260, 18.1564220>,
    <2.1161943, 0.3409292, 18.1564220>,
    <2.0039361, 0.3409159, 18.1573801>,
    <2.0039844, 0.3409195, 18.1564220>,
    <2.0425856, 0.3409192, 18.1573801>,
    <2.0413877, 0.3409227, 18.1564220>,
    <2.0038397, 0.3409089, 18.1592964>,
    <2.0861232, 0.3409156, 18.1592964>,
    <2.0038879, 0.3409124, 18.1583383>,
    <2.0449814, 0.3409123, 18.1592964>,
    <2.0836791, 0.3409191, 18.1583383>,
    <2.0437835, 0.3409157, 18.1583383>,
    <2.1272650, 0.3409190, 18.1592964>,
    <2.1235748, 0.3409224, 18.1583383>,
    <2.0877229, 0.1835507, 18.2324892>,
    <2.0038724, 0.1835386, 18.2344341>,
    <2.0457964, 0.1835447, 18.2333227>,
    <2.0038727, 0.1835386, 18.1968653>,
    <2.0861681, 0.1835495, 18.1968653>,
    <2.0450204, 0.1835440, 18.1968653>,
    <2.1715888, 0.1835618, 18.2322113>,
    <2.1684634, 0.1835604, 18.1968653>,
    <2.1296546, 0.1835563, 18.2322113>,
    <2.1273157, 0.1835549, 18.1968653>,
    <2.1994932, 0.1835742, 18.2873438>,
    <2.1015957, 0.1835619, 18.2890109>,
    <2.1809009, 0.1835659, 18.2631118>,
    <2.1505368, 0.1835685, 18.2873438>,
    <2.0923559, 0.1835542, 18.2642232>,
    <2.1366233, 0.1835604, 18.2631118>,
    <2.0038718, 0.1835386, 18.3095719>,
    <2.0526852, 0.1835533, 18.2940122>,
    <2.0038721, 0.1835386, 18.2720030>,
    <2.0481089, 0.1835467, 18.2675574>,
    <2.1715765, 0.2622413, 18.2322113>,
    <2.1715826, 0.2229016, 18.2322113>,
    <2.1684511, 0.2622414, 18.1968653>,
    <2.1684573, 0.2229009, 18.1968653>,
    <2.1715641, 0.3409209, 18.2322113>,
    <2.1684387, 0.3409223, 18.1968653>,
    <2.1715703, 0.3015811, 18.2322113>,
    <2.1684449, 0.3015818, 18.1968653>,
    <2.1994687, 0.3409079, 18.2873438>,
    <2.1994809, 0.2622410, 18.2873438>,
    <2.1808763, 0.3409165, 18.2631118>,
    <2.1994748, 0.3015745, 18.2873438>,
    <2.1808886, 0.2622412, 18.2631118>,
    <2.1808825, 0.3015789, 18.2631118>,
    <2.1994871, 0.2229076, 18.2873438>,
    <2.1808948, 0.2229036, 18.2631118>,
    <2.0876939, 0.3409143, 18.2324892>,
    <2.1296277, 0.3409175, 18.2322113>,
    <2.0861391, 0.3409156, 18.1968653>,
    <2.1272889, 0.3409190, 18.1968653>,
    <2.0038391, 0.3409088, 18.2344341>,
    <2.0038394, 0.3409089, 18.1968653>,
    <2.0457652, 0.3409115, 18.2333227>,
    <2.0449892, 0.3409122, 18.1968653>,
    <2.0038384, 0.3409088, 18.3095719>,
    <2.1015668, 0.3409020, 18.2890109>,
    <2.0038387, 0.3409088, 18.2720030>,
    <2.0526541, 0.3409019, 18.2940122>,
    <2.0923269, 0.3409104, 18.2642232>,
    <2.0480777, 0.3409093, 18.2675574>,
    <2.1505101, 0.3409044, 18.2873438>,
    <2.1365965, 0.3409131, 18.2631118>,
    <2.1354633, 0.1835922, 18.3131904>,
    <2.0032176, 0.1835800, 18.3135798>,
    <2.0693404, 0.1835861, 18.3133573>,
    <2.0035447, 0.1835593, 18.3115759>,
    <2.1169712, 0.1835755, 18.3037960>,
    <2.0602528, 0.1835677, 18.3071303>,
    <2.2677097, 0.1836044, 18.3131347>,
    <2.2304590, 0.1835879, 18.3026846>,
    <2.2015864, 0.1835983, 18.3131347>,
    <2.1737100, 0.1835820, 18.3026846>,
    <2.3367110, 0.1836352, 18.3353648>,
    <2.1697200, 0.1836230, 18.3340315>,
    <2.3051565, 0.1836211, 18.3226946>,
    <2.2532228, 0.1836286, 18.3353648>,
    <2.1540527, 0.1836090, 18.3218058>,
    <2.2296095, 0.1836147, 18.3226946>,
    <2.0025635, 0.1836214, 18.3175878>,
    <2.0861880, 0.1836193, 18.3300317>,
    <2.0028906, 0.1836007, 18.3155838>,
    <2.0784765, 0.1836045, 18.3191392>,
    <2.2676976, 0.2622403, 18.3131347>,
    <2.2677036, 0.2229224, 18.3131347>,
    <2.2304468, 0.2622407, 18.3026846>,
    <2.2304529, 0.2229143, 18.3026846>,
    <2.2676856, 0.3408763, 18.3131347>,
    <2.2304347, 0.3408936, 18.3026846>,
    <2.2676916, 0.3015583, 18.3131347>,
    <2.2304408, 0.3015672, 18.3026846>,
    <2.3366874, 0.3408441, 18.3353648>,
    <2.3366992, 0.2622396, 18.3353648>,
    <2.3051328, 0.3408589, 18.3226946>,
    <2.3366933, 0.3015419, 18.3353648>,
    <2.3051447, 0.2622400, 18.3226946>,
    <2.3051387, 0.3015494, 18.3226946>,
    <2.3367051, 0.2229374, 18.3353648>,
    <2.3051506, 0.2229305, 18.3226946>,
    <2.1354346, 0.3408686, 18.3131904>,
    <2.2015601, 0.3408724, 18.3131347>,
    <2.1169424, 0.3408870, 18.3037960>,
    <2.1736835, 0.3408899, 18.3026846>,
    <2.0031844, 0.3408610, 18.3135798>,
    <2.0035114, 0.3408849, 18.3115759>,
    <2.0693094, 0.3408648, 18.3133573>,
    <2.0602218, 0.3408856, 18.3071303>,
    <2.0025303, 0.3408131, 18.3175878>,
    <2.1696916, 0.3408347, 18.3340315>,
    <2.0028573, 0.3408371, 18.3155838>,
    <2.0861572, 0.3408273, 18.3300317>,
    <2.1540243, 0.3408501, 18.3218058>,
    <2.0784457, 0.3408439, 18.3191392>,
    <2.2531968, 0.3408399, 18.3353648>,
    <2.2295834, 0.3408548, 18.3226946>,
    <2.1847094, 0.1836357, 18.3800376>,
    <2.0025322, 0.1836233, 18.3784821>,
    <2.0936220, 0.1836295, 18.3793709>,
    <2.0025479, 0.1836224, 18.3480349>,
    <2.1794453, 0.1836314, 18.3542569>,
    <2.0910014, 0.1836265, 18.3515903>,
    <2.3668719, 0.1836490, 18.3802598>,
    <2.3562844, 0.1836440, 18.3551457>,
    <2.2757919, 0.1836423, 18.3802598>,
    <2.2678697, 0.1836374, 18.3551457>,
    <2.3730707, 0.1836524, 18.4393764>,
    <2.1877858, 0.1836389, 18.4393764>,
    <2.3714689, 0.1836514, 18.4089292>,
    <2.2804282, 0.1836456, 18.4393764>,
    <2.1869927, 0.1836378, 18.4089292>,
    <2.2792308, 0.1836446, 18.4089292>,
    <2.0025009, 0.1836253, 18.4393764>,
    <2.0951433, 0.1836321, 18.4393764>,
    <2.0025166, 0.1836243, 18.4089292>,
    <2.0947546, 0.1836311, 18.4089292>,
    <2.3668603, 0.2622393, 18.3802598>,
    <2.3668661, 0.2229442, 18.3802598>,
    <2.3562727, 0.2622394, 18.3551457>,
    <2.3562785, 0.2229417, 18.3551457>,
    <2.3668486, 0.3408296, 18.3802598>,
    <2.3562610, 0.3408348, 18.3551457>,
    <2.3668544, 0.3015345, 18.3802598>,
    <2.3562668, 0.3015371, 18.3551457>,
    <2.3730474, 0.3408261, 18.4393764>,
    <2.3730590, 0.2622392, 18.4393764>,
    <2.3714456, 0.3408272, 18.4089292>,
    <2.3730532, 0.3015327, 18.4393764>,
    <2.3714573, 0.2622393, 18.4089292>,
    <2.3714515, 0.3015332, 18.4089292>,
    <2.3730649, 0.2229458, 18.4393764>,
    <2.3714631, 0.2229453, 18.4089292>,
    <2.1846811, 0.3408208, 18.3800376>,
    <2.2757661, 0.3408253, 18.3802598>,
    <2.1794170, 0.3408256, 18.3542569>,
    <2.2678438, 0.3408306, 18.3551457>,
    <2.0024990, 0.3408109, 18.3784821>,
    <2.0025147, 0.3408120, 18.3480349>,
    <2.0935913, 0.3408159, 18.3793709>,
    <2.0909707, 0.3408191, 18.3515903>,
    <2.0024677, 0.3408086, 18.4393764>,
    <2.1877576, 0.3408173, 18.4393764>,
    <2.0024834, 0.3408097, 18.4089292>,
    <2.0951126, 0.3408129, 18.4393764>,
    <2.1869645, 0.3408184, 18.4089292>,
    <2.0947239, 0.3408141, 18.4089292>,
    <2.2804025, 0.3408217, 18.4393764>,
    <2.2792051, 0.3408228, 18.4089292>,
    <2.1962424, 0.1836497, 18.4393764>,
    <2.0023340, 0.1836359, 18.4393764>,
    <2.0992882, 0.1836428, 18.4393764>,
    <2.0024175, 0.1836306, 18.4393764>,
    <2.1920141, 0.1836443, 18.4393764>,
    <2.0972158, 0.1836375, 18.4393764>,
    <2.3901507, 0.1836636, 18.4393764>,
    <2.3816107, 0.1836580, 18.4393764>,
    <2.2931966, 0.1836567, 18.4393764>,
    <2.2868124, 0.1836512, 18.4393764>,
    <2.4072308, 0.1836748, 18.4393764>,
    <2.2046990, 0.1836606, 18.4393764>,
    <2.3986908, 0.1836692, 18.4393764>,
    <2.3059649, 0.1836677, 18.4393764>,
    <2.2004707, 0.1836552, 18.4393764>,
    <2.2995807, 0.1836622, 18.4393764>,
    <2.0021672, 0.1836464, 18.4393764>,
    <2.1034331, 0.1836535, 18.4393764>,
    <2.0022506, 0.1836412, 18.4393764>,
    <2.1013606, 0.1836482, 18.4393764>,
    <2.3901392, 0.2622390, 18.4393764>,
    <2.3901450, 0.2229513, 18.4393764>,
    <2.3815991, 0.2622391, 18.4393764>,
    <2.3816049, 0.2229486, 18.4393764>,
    <2.3901276, 0.3408144, 18.4393764>,
    <2.3815875, 0.3408202, 18.4393764>,
    <2.3901334, 0.3015267, 18.4393764>,
    <2.3815933, 0.3015297, 18.4393764>,
    <2.4072079, 0.3408027, 18.4393764>,
    <2.4072193, 0.2622387, 18.4393764>,
    <2.3986678, 0.3408085, 18.4393764>,
    <2.4072136, 0.3015207, 18.4393764>,
    <2.3986793, 0.2622389, 18.4393764>,
    <2.3986735, 0.3015237, 18.4393764>,
    <2.4072251, 0.2229568, 18.4393764>,
    <2.3986850, 0.2229540, 18.4393764>,
    <2.1962143, 0.3408054, 18.4393764>,
    <2.2931709, 0.3408099, 18.4393764>,
    <2.1919859, 0.3408113, 18.4393764>,
    <2.2867867, 0.3408158, 18.4393764>,
    <2.0023009, 0.3407964, 18.4393764>,
    <2.0023843, 0.3408025, 18.4393764>,
    <2.0992576, 0.3408009, 18.4393764>,
    <2.0971851, 0.3408069, 18.4393764>,
    <2.0021340, 0.3407842, 18.4393764>,
    <2.2046709, 0.3407934, 18.4393764>,
    <2.0022174, 0.3407903, 18.4393764>,
    <2.1034025, 0.3407888, 18.4393764>,
    <2.2004426, 0.3407994, 18.4393764>,
    <2.1013300, 0.3407948, 18.4393764>,
    <2.3059394, 0.3407980, 18.4393764>,
    <2.2995552, 0.3408040, 18.4393764>,
    <2.2046990, 0.1836606, 18.4726341>,
    <2.0021672, 0.1836464, 18.4726341>,
    <2.1034331, 0.1836535, 18.4726341>,
    <2.0021672, 0.1836464, 18.4560052>,
    <2.2046990, 0.1836606, 18.4560052>,
    <2.1034331, 0.1836535, 18.4560052>,
    <2.4072308, 0.1836748, 18.4726341>,
    <2.4072308, 0.1836748, 18.4560052>,
    <2.3059649, 0.1836677, 18.4726341>,
    <2.3059649, 0.1836677, 18.4560052>,
    <2.4072308, 0.1836748, 18.4892630>,
    <2.2046990, 0.1836606, 18.4892630>,
    <2.3059649, 0.1836677, 18.4892630>,
    <2.0021672, 0.1836464, 18.4892630>,
    <2.1034331, 0.1836535, 18.4892630>,
    <2.4072193, 0.2622387, 18.4726341>,
    <2.4072251, 0.2229568, 18.4726341>,
    <2.4072193, 0.2622387, 18.4560052>,
    <2.4072251, 0.2229568, 18.4560052>,
    <2.4072079, 0.3408027, 18.4726341>,
    <2.4072079, 0.3408027, 18.4560052>,
    <2.4072136, 0.3015207, 18.4726341>,
    <2.4072136, 0.3015207, 18.4560052>,
    <2.4072079, 0.3408027, 18.4892630>,
    <2.4072193, 0.2622387, 18.4892630>,
    <2.4072136, 0.3015207, 18.4892630>,
    <2.4072251, 0.2229568, 18.4892630>,
    <2.2046709, 0.3407934, 18.4726341>,
    <2.3059394, 0.3407980, 18.4726341>,
    <2.2046709, 0.3407934, 18.4560052>,
    <2.3059394, 0.3407980, 18.4560052>,
    <2.0021340, 0.3407842, 18.4726341>,
    <2.0021340, 0.3407842, 18.4560052>,
    <2.1034025, 0.3407888, 18.4726341>,
    <2.1034025, 0.3407888, 18.4560052>,
    <2.0021340, 0.3407842, 18.4892630>,
    <2.2046709, 0.3407934, 18.4892630>,
    <2.1034025, 0.3407888, 18.4892630>,
    <2.3059394, 0.3407980, 18.4892630>,
    <2.0021506, 0.2622153, 18.4726341>,
    <2.0021672, 0.1836464, 18.4726341>,
    <2.0021506, 0.2622153, 18.4393764>,
    <2.0021589, 0.2229309, 18.4726341>,
    <2.0021672, 0.1836464, 18.4560052>,
    <2.0021589, 0.2229309, 18.4393764>,
    <2.0021506, 0.2622153, 18.4560052>,
    <2.0021589, 0.2229309, 18.4560052>,
    <2.0021340, 0.3407842, 18.4726341>,
    <2.0021423, 0.3014997, 18.4393764>,
    <2.0021340, 0.3407842, 18.4560052>,
    <2.0021423, 0.3014997, 18.4726341>,
    <2.0021423, 0.3014997, 18.4560052>,
    <2.0021506, 0.2622153, 18.5058918>,
    <2.0021340, 0.3407842, 18.4892630>,
    <2.0021423, 0.3014997, 18.5058918>,
    <2.0021506, 0.2622153, 18.4892630>,
    <2.0021423, 0.3014997, 18.4892630>,
    <2.0021589, 0.2229309, 18.5058918>,
    <2.0021672, 0.1836464, 18.4892630>,
    <2.0021589, 0.2229309, 18.4892630>,
    <2.0023174, 0.2622161, 18.4393764>,
    <2.0024843, 0.2622169, 18.4393764>,
    <2.0024009, 0.2622165, 18.4393764>,
    <2.0024926, 0.2229211, 18.4393764>,
    <2.0023257, 0.2229260, 18.4393764>,
    <2.0024092, 0.2229236, 18.4393764>,
    <2.0021506, 0.2622153, 18.4393764>,
    <2.0021589, 0.2229309, 18.4393764>,
    <2.0022340, 0.2622157, 18.4393764>,
    <2.0022423, 0.2229284, 18.4393764>,
    <2.0021423, 0.3014997, 18.4393764>,
    <2.0023092, 0.3015062, 18.4393764>,
    <2.0022257, 0.3015030, 18.4393764>,
    <2.0024760, 0.3015128, 18.4393764>,
    <2.0023926, 0.3015095, 18.4393764>,
    <2.0025156, 0.2622171, 18.3784821>,
    <2.0025322, 0.1836233, 18.3784821>,
    <2.0025469, 0.2622173, 18.3175878>,
    <2.0025239, 0.2229202, 18.3784821>,
    <2.0025479, 0.1836224, 18.3480349>,
    <2.0025552, 0.2229193, 18.3175878>,
    <2.0025313, 0.2622172, 18.3480349>,
    <2.0025396, 0.2229198, 18.3480349>,
    <2.0024990, 0.3408109, 18.3784821>,
    <2.0025386, 0.3015152, 18.3175878>,
    <2.0025147, 0.3408120, 18.3480349>,
    <2.0025073, 0.3015140, 18.3784821>,
    <2.0025230, 0.3015146, 18.3480349>,
    <2.0024843, 0.2622169, 18.4393764>,
    <2.0024834, 0.3408097, 18.4089292>,
    <2.0024760, 0.3015128, 18.4393764>,
    <2.0025000, 0.2622170, 18.4089292>,
    <2.0024917, 0.3015134, 18.4089292>,
    <2.0024926, 0.2229211, 18.4393764>,
    <2.0025166, 0.1836243, 18.4089292>,
    <2.0025083, 0.2229207, 18.4089292>,
    <2.0032010, 0.2622205, 18.3135798>,
    <2.0038551, 0.2622237, 18.3095719>,
    <2.0035281, 0.2622221, 18.3115759>,
    <2.0038634, 0.2228812, 18.3095719>,
    <2.0032093, 0.2229002, 18.3135798>,
    <2.0035364, 0.2228907, 18.3115759>,
    <2.0025469, 0.2622173, 18.3175878>,
    <2.0025552, 0.2229193, 18.3175878>,
    <2.0028740, 0.2622189, 18.3155838>,
    <2.0028823, 0.2229098, 18.3155838>,
    <2.0025386, 0.3015152, 18.3175878>,
    <2.0031927, 0.3015407, 18.3135798>,
    <2.0028656, 0.3015280, 18.3155838>,
    <2.0038468, 0.3015663, 18.3095719>,
    <2.0035197, 0.3015535, 18.3115759>,
    <2.0038557, 0.2622237, 18.2344341>,
    <2.0038724, 0.1835386, 18.2344341>,
    <2.0038563, 0.2622237, 18.1592964>,
    <2.0038641, 0.2228811, 18.2344341>,
    <2.0038727, 0.1835386, 18.1968653>,
    <2.0038647, 0.2228811, 18.1592964>,
    <2.0038560, 0.2622237, 18.1968653>,
    <2.0038644, 0.2228811, 18.1968653>,
    <2.0038391, 0.3409088, 18.2344341>,
    <2.0038480, 0.3015663, 18.1592964>,
    <2.0038394, 0.3409089, 18.1968653>,
    <2.0038474, 0.3015663, 18.2344341>,
    <2.0038477, 0.3015663, 18.1968653>,
    <2.0038551, 0.2622237, 18.3095719>,
    <2.0038387, 0.3409088, 18.2720030>,
    <2.0038468, 0.3015663, 18.3095719>,
    <2.0038554, 0.2622237, 18.2720030>,
    <2.0038471, 0.3015663, 18.2720030>,
    <2.0038634, 0.2228812, 18.3095719>,
    <2.0038721, 0.1835386, 18.2720030>,
    <2.0038637, 0.2228812, 18.2720030>,
    <2.0039528, 0.2622242, 18.1573801>,
    <2.0040493, 0.2622247, 18.1554639>,
    <2.0040010, 0.2622244, 18.1564220>,
    <2.0040576, 0.2228755, 18.1554639>,
    <2.0039611, 0.2228783, 18.1573801>,
    <2.0040094, 0.2228769, 18.1564220>,
    <2.0038563, 0.2622237, 18.1592964>,
    <2.0038647, 0.2228811, 18.1592964>,
    <2.0039046, 0.2622240, 18.1583383>,
    <2.0039129, 0.2228797, 18.1583383>,
    <2.0038480, 0.3015663, 18.1592964>,
    <2.0039445, 0.3015701, 18.1573801>,
    <2.0038962, 0.3015682, 18.1583383>,
    <2.0040409, 0.3015738, 18.1554639>,
    <2.0039927, 0.3015719, 18.1564220>,
    <2.0042444, 0.2622256, 18.1389725>,
    <2.0042673, 0.1835136, 18.1386133>,
    <2.0043812, 0.2622263, 18.1258340>,
    <2.0042548, 0.2228696, 18.1388528>,
    <2.0043680, 0.1835072, 18.1301880>,
    <2.0044020, 0.2228646, 18.1251156>,
    <2.0043263, 0.2622260, 18.1316249>,
    <2.0043430, 0.2228666, 18.1311460>,
    <2.0042339, 0.3409377, 18.1386133>,
    <2.0043853, 0.3015881, 18.1251156>,
    <2.0043346, 0.3409451, 18.1301880>,
    <2.0042381, 0.3015817, 18.1388528>,
    <2.0043263, 0.3015855, 18.1311460>,
    <2.0040493, 0.2622247, 18.1554639>,
    <2.0041333, 0.3409304, 18.1470386>,
    <2.0040409, 0.3015738, 18.1554639>,
    <2.0041499, 0.2622252, 18.1470386>,
    <2.0041416, 0.3015778, 18.1470386>,
    <2.0040576, 0.2228755, 18.1554639>,
    <2.0041666, 0.1835200, 18.1470386>,
    <2.0041583, 0.2228726, 18.1470386>,
    <2.0043805, 0.2622263, 18.1205987>,
    <2.0043944, 0.2622264, 18.1224380>,
    <2.0043909, 0.2228656, 18.1204790>,
    <2.0044111, 0.2228646, 18.1219591>,
    <2.0043215, 0.2622260, 18.1187163>,
    <2.0043298, 0.2228676, 18.1187163>,
    <2.0043541, 0.2622262, 18.1194779>,
    <2.0043625, 0.2228666, 18.1194779>,
    <2.0043131, 0.3015845, 18.1187163>,
    <2.0043742, 0.3015870, 18.1204790>,
    <2.0043458, 0.3015857, 18.1194779>,
    <2.0043944, 0.3015882, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0001859, 0.9999966, 0.0025837>,
    <-0.0001849, 0.9999971, 0.0023832>,
    <-0.0001812, 0.9999970, 0.0024237>,
    <-0.0001827, 0.9999966, 0.0025970>,
    <-0.0001838, 0.9999963, 0.0027183>,
    <-0.0001866, 0.9999963, 0.0027184>,
    <-0.0001866, 0.9999963, 0.0027184>,
    <-0.0001899, 0.9999963, 0.0027186>,
    <-0.0001899, 0.9999967, 0.0025671>,
    <-0.0001899, 0.9999967, 0.0025671>,
    <-0.0001899, 0.9999973, 0.0023298>,
    <-0.0001833, 0.9999979, 0.0020530>,
    <-0.0001788, 0.9999977, 0.0021555>,
    <-0.0001899, 0.9999973, 0.0023298>,
    <-0.0001899, 0.9999982, 0.0019046>,
    <-0.0001899, 0.9999982, 0.0019046>,
    <-0.0001899, 0.9999996, 0.0009223>,
    <-0.0001802, 0.9999990, 0.0014067>,
    <-0.0001802, 0.9999990, 0.0014067>,
    <-0.0001746, 0.9999986, 0.0016852>,
    <-0.0001755, 0.9999975, 0.0022306>,
    <-0.0001782, 0.9999970, 0.0024554>,
    <-0.0001746, 0.9999986, 0.0016852>,
    <-0.0001710, 0.9999982, 0.0018661>,
    <-0.0001710, 0.9999982, 0.0018661>,
    <-0.0001685, 0.9999980, 0.0019930>,
    <-0.0001729, 0.9999974, 0.0022880>,
    <-0.0001729, 0.9999974, 0.0022880>,
    <-0.0001759, 0.9999969, 0.0024809>,
    <-0.0001801, 0.9999966, 0.0026079>,
    <-0.0001759, 0.9999969, 0.0024809>,
    <-0.0001779, 0.9999966, 0.0026170>,
    <-0.0001779, 0.9999966, 0.0026170>,
    <-0.0001795, 0.9999963, 0.0027181>,
    <-0.0001815, 0.9999963, 0.0027182>,
    <-0.0001815, 0.9999963, 0.0027182>,
    <-0.0001838, 0.9999963, 0.0027183>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200138, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <-0.0200139, -0.0000032, -0.9997997>,
    <0.0000644, -0.9999672, 0.0081018>,
    <0.0000764, -0.9999841, 0.0056341>,
    <0.0000483, -0.9999858, 0.0053318>,
    <0.0000305, -0.9999731, 0.0073358>,
    <-0.0000007, -0.9999411, 0.0108495>,
    <0.0000409, -0.9999164, 0.0129301>,
    <0.0000409, -0.9999164, 0.0129301>,
    <0.0001134, -0.9998631, 0.0165488>,
    <0.0001134, -0.9999576, 0.0092100>,
    <0.0001134, -0.9999576, 0.0092100>,
    <0.0001134, -0.9999818, 0.0060332>,
    <0.0000836, -0.9999914, 0.0041359>,
    <0.0000598, -0.9999919, 0.0040365>,
    <0.0001134, -0.9999818, 0.0060332>,
    <0.0001134, -0.9999909, 0.0042600>,
    <0.0001134, -0.9999909, 0.0042600>,
    <0.0001134, -0.9999951, 0.0031286>,
    <0.0000885, -0.9999951, 0.0031297>,
    <0.0000885, -0.9999951, 0.0031297>,
    <0.0000679, -0.9999951, 0.0031306>,
    <0.0000403, -0.9999922, 0.0039552>,
    <0.0000263, -0.9999870, 0.0050949>,
    <0.0000679, -0.9999951, 0.0031306>,
    <0.0000505, -0.9999951, 0.0031313>,
    <0.0000505, -0.9999951, 0.0031313>,
    <0.0000356, -0.9999951, 0.0031319>,
    <0.0000241, -0.9999924, 0.0038874>,
    <0.0000241, -0.9999924, 0.0038874>,
    <0.0000086, -0.9999880, 0.0049041>,
    <0.0000057, -0.9999771, 0.0067747>,
    <0.0000086, -0.9999880, 0.0049041>,
    <-0.0000133, -0.9999799, 0.0063460>,
    <-0.0000133, -0.9999799, 0.0063460>,
    <-0.0000467, -0.9999634, 0.0085500>,
    <-0.0000278, -0.9999549, 0.0094982>,
    <-0.0000278, -0.9999549, 0.0094982>,
    <-0.0000007, -0.9999411, 0.0108495>,
    <0.0001346, -0.9999999, 0.0004844>,
    <0.0001344, -0.9999999, 0.0004997>,
    <0.0001382, -0.9999999, 0.0004997>,
    <0.0001383, -0.9999999, 0.0004844>,
    <0.0001385, -0.9999999, 0.0004696>,
    <0.0001347, -0.9999999, 0.0004695>,
    <0.0001347, -0.9999999, 0.0004695>,
    <0.0001310, -0.9999999, 0.0004695>,
    <0.0001308, -0.9999999, 0.0004843>,
    <0.0001308, -0.9999999, 0.0004843>,
    <0.0001306, -0.9999999, 0.0004996>,
    <0.0001342, -0.9999999, 0.0005155>,
    <0.0001381, -0.9999999, 0.0005155>,
    <0.0001306, -0.9999999, 0.0004996>,
    <0.0001303, -0.9999999, 0.0005154>,
    <0.0001303, -0.9999999, 0.0005154>,
    <0.0001301, -0.9999999, 0.0005316>,
    <0.0001340, -0.9999998, 0.0005317>,
    <0.0001340, -0.9999998, 0.0005317>,
    <0.0001380, -0.9999998, 0.0005318>,
    <0.0001420, -0.9999999, 0.0005156>,
    <0.0001420, -0.9999999, 0.0004998>,
    <0.0001380, -0.9999998, 0.0005318>,
    <0.0001419, -0.9999998, 0.0005319>,
    <0.0001419, -0.9999998, 0.0005319>,
    <0.0001459, -0.9999998, 0.0005320>,
    <0.0001459, -0.9999999, 0.0005157>,
    <0.0001459, -0.9999999, 0.0005157>,
    <0.0001459, -0.9999999, 0.0004999>,
    <0.0001421, -0.9999999, 0.0004845>,
    <0.0001459, -0.9999999, 0.0004999>,
    <0.0001459, -0.9999999, 0.0004845>,
    <0.0001459, -0.9999999, 0.0004845>,
    <0.0001459, -0.9999999, 0.0004696>,
    <0.0001422, -0.9999999, 0.0004696>,
    <0.0001422, -0.9999999, 0.0004696>,
    <0.0001385, -0.9999999, 0.0004696>,
    <0.9997304, 0.0001594, 0.0232204>,
    <0.9997304, 0.0001594, 0.0232184>,
    <0.9997304, 0.0001590, 0.0232184>,
    <0.9997304, 0.0001590, 0.0232204>,
    <0.9997303, 0.0001590, 0.0232224>,
    <0.9997303, 0.0001594, 0.0232224>,
    <0.9997303, 0.0001594, 0.0232224>,
    <0.9997303, 0.0001599, 0.0232224>,
    <0.9997304, 0.0001599, 0.0232204>,
    <0.9997304, 0.0001599, 0.0232204>,
    <0.9997304, 0.0001599, 0.0232184>,
    <0.9997304, 0.0001594, 0.0232164>,
    <0.9997304, 0.0001590, 0.0232164>,
    <0.9997304, 0.0001599, 0.0232184>,
    <0.9997304, 0.0001599, 0.0232164>,
    <0.9997304, 0.0001599, 0.0232164>,
    <0.9997305, 0.0001599, 0.0232145>,
    <0.9997305, 0.0001594, 0.0232145>,
    <0.9997305, 0.0001594, 0.0232145>,
    <0.9997305, 0.0001590, 0.0232145>,
    <0.9997304, 0.0001586, 0.0232164>,
    <0.9997304, 0.0001586, 0.0232184>,
    <0.9997305, 0.0001590, 0.0232145>,
    <0.9997305, 0.0001586, 0.0232145>,
    <0.9997305, 0.0001586, 0.0232145>,
    <0.9997305, 0.0001581, 0.0232144>,
    <0.9997304, 0.0001581, 0.0232164>,
    <0.9997304, 0.0001581, 0.0232164>,
    <0.9997304, 0.0001581, 0.0232184>,
    <0.9997304, 0.0001586, 0.0232204>,
    <0.9997304, 0.0001581, 0.0232184>,
    <0.9997304, 0.0001581, 0.0232204>,
    <0.9997304, 0.0001581, 0.0232204>,
    <0.9997303, 0.0001581, 0.0232224>,
    <0.9997303, 0.0001586, 0.0232224>,
    <0.9997303, 0.0001586, 0.0232224>,
    <0.9997303, 0.0001590, 0.0232224>,
    <-0.0000909, 0.9999998, 0.0005482>,
    <-0.0000908, 0.9999998, 0.0005457>,
    <-0.0000902, 0.9999998, 0.0005457>,
    <-0.0000902, 0.9999998, 0.0005482>,
    <-0.0000903, 0.9999998, 0.0005508>,
    <-0.0000909, 0.9999998, 0.0005508>,
    <-0.0000909, 0.9999998, 0.0005508>,
    <-0.0000915, 0.9999998, 0.0005508>,
    <-0.0000915, 0.9999998, 0.0005482>,
    <-0.0000915, 0.9999998, 0.0005482>,
    <-0.0000914, 0.9999998, 0.0005457>,
    <-0.0000908, 0.9999998, 0.0005433>,
    <-0.0000902, 0.9999998, 0.0005433>,
    <-0.0000914, 0.9999998, 0.0005457>,
    <-0.0000914, 0.9999998, 0.0005433>,
    <-0.0000914, 0.9999998, 0.0005433>,
    <-0.0000914, 0.9999998, 0.0005410>,
    <-0.0000908, 0.9999998, 0.0005410>,
    <-0.0000908, 0.9999998, 0.0005410>,
    <-0.0000902, 0.9999998, 0.0005410>,
    <-0.0000896, 0.9999998, 0.0005434>,
    <-0.0000896, 0.9999998, 0.0005458>,
    <-0.0000902, 0.9999998, 0.0005410>,
    <-0.0000896, 0.9999998, 0.0005410>,
    <-0.0000896, 0.9999998, 0.0005410>,
    <-0.0000890, 0.9999998, 0.0005410>,
    <-0.0000890, 0.9999998, 0.0005434>,
    <-0.0000890, 0.9999998, 0.0005434>,
    <-0.0000890, 0.9999998, 0.0005458>,
    <-0.0000896, 0.9999998, 0.0005482>,
    <-0.0000890, 0.9999998, 0.0005458>,
    <-0.0000890, 0.9999998, 0.0005482>,
    <-0.0000890, 0.9999998, 0.0005482>,
    <-0.0000890, 0.9999998, 0.0005508>,
    <-0.0000896, 0.9999998, 0.0005508>,
    <-0.0000896, 0.9999998, 0.0005508>,
    <-0.0000903, 0.9999998, 0.0005508>,
    <0.0001423, -0.9999953, 0.0030539>,
    <0.0001423, -0.9999957, 0.0029170>,
    <0.0001389, -0.9999957, 0.0029257>,
    <0.0001389, -0.9999953, 0.0030582>,
    <0.0001389, -0.9999949, 0.0031906>,
    <0.0001423, -0.9999949, 0.0031908>,
    <0.0001423, -0.9999949, 0.0031908>,
    <0.0001459, -0.9999949, 0.0031910>,
    <0.0001459, -0.9999953, 0.0030494>,
    <0.0001459, -0.9999953, 0.0030494>,
    <0.0001459, -0.9999958, 0.0029078>,
    <0.0001423, -0.9999961, 0.0027802>,
    <0.0001389, -0.9999961, 0.0027933>,
    <0.0001459, -0.9999958, 0.0029078>,
    <0.0001459, -0.9999962, 0.0027662>,
    <0.0001459, -0.9999962, 0.0027662>,
    <0.0001459, -0.9999965, 0.0026246>,
    <0.0001423, -0.9999965, 0.0026433>,
    <0.0001423, -0.9999965, 0.0026433>,
    <0.0001389, -0.9999965, 0.0026608>,
    <0.0001357, -0.9999961, 0.0028055>,
    <0.0001357, -0.9999957, 0.0029338>,
    <0.0001389, -0.9999965, 0.0026608>,
    <0.0001357, -0.9999964, 0.0026772>,
    <0.0001357, -0.9999964, 0.0026772>,
    <0.0001327, -0.9999964, 0.0026926>,
    <0.0001327, -0.9999960, 0.0028170>,
    <0.0001327, -0.9999960, 0.0028170>,
    <0.0001327, -0.9999957, 0.0029414>,
    <0.0001357, -0.9999953, 0.0030621>,
    <0.0001327, -0.9999957, 0.0029414>,
    <0.0001327, -0.9999953, 0.0030659>,
    <0.0001327, -0.9999953, 0.0030659>,
    <0.0001327, -0.9999949, 0.0031903>,
    <0.0001357, -0.9999949, 0.0031905>,
    <0.0001357, -0.9999949, 0.0031905>,
    <0.0001389, -0.9999949, 0.0031906>,
    <0.1905399, 0.0000301, -0.9816795>,
    <0.1905394, 0.0000301, -0.9816795>,
    <0.1905394, 0.0000300, -0.9816795>,
    <0.1905399, 0.0000300, -0.9816795>,
    <0.1905403, 0.0000300, -0.9816794>,
    <0.1905403, 0.0000301, -0.9816794>,
    <0.1905403, 0.0000301, -0.9816794>,
    <0.1905403, 0.0000301, -0.9816794>,
    <0.1905399, 0.0000301, -0.9816795>,
    <0.1905399, 0.0000301, -0.9816795>,
    <0.1905394, 0.0000301, -0.9816795>,
    <0.1905390, 0.0000301, -0.9816796>,
    <0.1905390, 0.0000300, -0.9816796>,
    <0.1905394, 0.0000301, -0.9816795>,
    <0.1905390, 0.0000301, -0.9816796>,
    <0.1905390, 0.0000301, -0.9816796>,
    <0.1905385, 0.0000301, -0.9816797>,
    <0.1905385, 0.0000301, -0.9816797>,
    <0.1905385, 0.0000301, -0.9816797>,
    <0.1905385, 0.0000300, -0.9816797>,
    <0.1905390, 0.0000300, -0.9816796>,
    <0.1905394, 0.0000300, -0.9816795>,
    <0.1905385, 0.0000300, -0.9816797>,
    <0.1905385, 0.0000300, -0.9816797>,
    <0.1905385, 0.0000300, -0.9816797>,
    <0.1905385, 0.0000299, -0.9816797>,
    <0.1905390, 0.0000299, -0.9816796>,
    <0.1905390, 0.0000299, -0.9816796>,
    <0.1905394, 0.0000299, -0.9816795>,
    <0.1905399, 0.0000300, -0.9816795>,
    <0.1905394, 0.0000299, -0.9816795>,
    <0.1905399, 0.0000299, -0.9816795>,
    <0.1905399, 0.0000299, -0.9816795>,
    <0.1905403, 0.0000299, -0.9816794>,
    <0.1905403, 0.0000300, -0.9816794>,
    <0.1905403, 0.0000300, -0.9816794>,
    <0.1905403, 0.0000300, -0.9816794>,
    <-0.0000870, 0.9999924, 0.0039037>,
    <-0.0000870, 0.9999927, 0.0038278>,
    <-0.0000851, 0.9999927, 0.0038230>,
    <-0.0000851, 0.9999924, 0.0038964>,
    <-0.0000851, 0.9999921, 0.0039698>,
    <-0.0000870, 0.9999921, 0.0039795>,
    <-0.0000870, 0.9999921, 0.0039795>,
    <-0.0000890, 0.9999920, 0.0039898>,
    <-0.0000890, 0.9999923, 0.0039114>,
    <-0.0000890, 0.9999923, 0.0039114>,
    <-0.0000890, 0.9999927, 0.0038329>,
    <-0.0000870, 0.9999930, 0.0037520>,
    <-0.0000851, 0.9999930, 0.0037496>,
    <-0.0000890, 0.9999927, 0.0038329>,
    <-0.0000890, 0.9999929, 0.0037545>,
    <-0.0000890, 0.9999929, 0.0037545>,
    <-0.0000890, 0.9999932, 0.0036761>,
    <-0.0000870, 0.9999932, 0.0036762>,
    <-0.0000870, 0.9999932, 0.0036762>,
    <-0.0000851, 0.9999932, 0.0036762>,
    <-0.0000834, 0.9999930, 0.0037474>,
    <-0.0000834, 0.9999927, 0.0038185>,
    <-0.0000851, 0.9999932, 0.0036762>,
    <-0.0000834, 0.9999932, 0.0036763>,
    <-0.0000834, 0.9999932, 0.0036763>,
    <-0.0000817, 0.9999932, 0.0036764>,
    <-0.0000817, 0.9999930, 0.0037454>,
    <-0.0000817, 0.9999930, 0.0037454>,
    <-0.0000817, 0.9999927, 0.0038143>,
    <-0.0000834, 0.9999924, 0.0038896>,
    <-0.0000817, 0.9999927, 0.0038143>,
    <-0.0000817, 0.9999925, 0.0038832>,
    <-0.0000817, 0.9999925, 0.0038832>,
    <-0.0000817, 0.9999922, 0.0039522>,
    <-0.0000834, 0.9999922, 0.0039607>,
    <-0.0000834, 0.9999922, 0.0039607>,
    <-0.0000851, 0.9999921, 0.0039698>,
    <0.0001347, -1.0000000, 0.0000077>,
    <0.0001337, -1.0000000, 0.0000129>,
    <0.0001412, -1.0000000, 0.0000536>,
    <0.0001488, -1.0000000, 0.0000301>,
    <0.0001505, -1.0000000, 0.0000005>,
    <0.0001350, -1.0000000, 0.0000005>,
    <0.0001350, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000144>,
    <0.0001328, -1.0000000, 0.0000617>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000005>,
    <0.0001327, -1.0000000, 0.0000004>,
    <0.0001323, -1.0000000, 0.0000136>,
    <0.0001323, -1.0000000, 0.0000136>,
    <0.0001300, -1.0000000, 0.0000589>,
    <0.0001331, -1.0000000, 0.0001676>,
    <0.0001593, -1.0000000, 0.0001532>,
    <0.0001300, -1.0000000, 0.0000589>,
    <0.0001242, -1.0000000, 0.0001615>,
    <0.0001242, -1.0000000, 0.0001615>,
    <0.0001146, -0.9999999, 0.0004114>,
    <0.0001297, -0.9999999, 0.0004255>,
    <0.0001752, -0.9999999, 0.0004301>,
    <0.0001926, -1.0000000, 0.0001007>,
    <0.0002839, -0.9999999, 0.0004440>,
    <0.0003808, -0.9999998, 0.0005264>,
    <0.0001992, -1.0000000, 0.0000005>,
    <0.0001992, -1.0000000, 0.0000005>,
    <0.0001505, -1.0000000, 0.0000005>,
    <0.9990638, 0.0001568, -0.0432613>,
    <0.9990638, 0.0001568, -0.0432613>,
    <0.9828283, 0.0001541, -0.1845222>,
    <0.9828284, 0.0001541, -0.1845219>,
    <0.9828284, 0.0001541, -0.1845216>,
    <0.9990638, 0.0001568, -0.0432612>,
    <0.9990638, 0.0001568, -0.0432612>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9990638, 0.0001568, -0.0432614>,
    <0.9828283, 0.0001541, -0.1845225>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9999996, 0.0001569, -0.0008513>,
    <0.9990638, 0.0001568, -0.0432615>,
    <0.9990638, 0.0001568, -0.0432615>,
    <0.9828282, 0.0001541, -0.1845228>,
    <0.8922266, 0.0001395, -0.4515879>,
    <0.8922269, 0.0001395, -0.4515873>,
    <0.9828282, 0.0001541, -0.1845228>,
    <0.8922263, 0.0001395, -0.4515885>,
    <0.8922263, 0.0001395, -0.4515885>,
    <0.6239846, 0.0000970, -0.7814367>,
    <0.6239852, 0.0000970, -0.7814361>,
    <0.6239858, 0.0000970, -0.7814356>,
    <0.8922272, 0.0001395, -0.4515867>,
    <0.6239865, 0.0000970, -0.7814351>,
    <0.6239871, 0.0000971, -0.7814346>,
    <0.8922275, 0.0001395, -0.4515861>,
    <0.8922275, 0.0001395, -0.4515861>,
    <0.9828284, 0.0001541, -0.1845216>,
    <-0.0000811, 1.0000000, 0.0000227>,
    <-0.0000800, 1.0000000, 0.0000189>,
    <-0.0000670, 1.0000000, 0.0000785>,
    <-0.0000768, 1.0000000, 0.0000967>,
    <-0.0000802, 1.0000000, 0.0001022>,
    <-0.0000815, 1.0000000, 0.0000238>,
    <-0.0000815, 1.0000000, 0.0000238>,
    <-0.0000817, 1.0000000, 0.0000007>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000788, 1.0000000, 0.0000109>,
    <-0.0000582, 1.0000000, 0.0000427>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000785, 1.0000000, 0.0000006>,
    <-0.0000785, 1.0000000, 0.0000006>,
    <-0.0000566, 1.0000000, 0.0000006>,
    <0.0000039, 1.0000000, 0.0001352>,
    <-0.0000344, 1.0000000, 0.0002184>,
    <-0.0000566, 1.0000000, 0.0000006>,
    <0.0000096, 1.0000000, 0.0000006>,
    <0.0000096, 1.0000000, 0.0000006>,
    <0.0002356, 0.9999998, 0.0006068>,
    <0.0001316, 0.9999998, 0.0005584>,
    <0.0000043, 0.9999998, 0.0005899>,
    <-0.0000657, 1.0000000, 0.0002581>,
    <-0.0000517, 0.9999998, 0.0006349>,
    <-0.0000712, 0.9999998, 0.0006696>,
    <-0.0000768, 1.0000000, 0.0002735>,
    <-0.0000768, 1.0000000, 0.0002735>,
    <-0.0000802, 1.0000000, 0.0001022>,
    <0.0002735, -0.9999986, 0.0016632>,
    <0.0001620, -0.9999994, 0.0010648>,
    <0.0000963, -0.9999985, 0.0017494>,
    <0.0001044, -0.9999955, 0.0030069>,
    <0.0001391, -0.9999465, 0.0103446>,
    <0.0011924, -0.9999440, 0.0105165>,
    <0.0011924, -0.9999440, 0.0105165>,
    <0.0003808, -0.9999998, 0.0005264>,
    <0.0001164, -0.9999996, 0.0009414>,
    <0.0000929, -0.9999990, 0.0014086>,
    <0.0001146, -0.9999999, 0.0004114>,
    <0.0001027, -0.9999996, 0.0009008>,
    <0.0001027, -0.9999996, 0.0009008>,
    <0.0000920, -0.9999991, 0.0013143>,
    <0.0000737, -0.9999993, 0.0012122>,
    <0.0000376, -0.9999989, 0.0014639>,
    <0.0000920, -0.9999991, 0.0013143>,
    <0.0000839, -0.9999994, 0.0011231>,
    <0.0000839, -0.9999994, 0.0011231>,
    <0.0000785, -0.9999998, 0.0005847>,
    <0.0000691, -0.9999998, 0.0006168>,
    <0.0000399, -0.9999998, 0.0006569>,
    <-0.0000516, -0.9999974, 0.0022944>,
    <-0.0000300, -0.9999998, 0.0006897>,
    <-0.0000768, -0.9999998, 0.0006671>,
    <-0.0005554, -0.9999475, 0.0102313>,
    <-0.0005554, -0.9999475, 0.0102313>,
    <0.0001391, -0.9999465, 0.0103446>,
    <0.3536429, 0.0000546, -0.9353805>,
    <0.3536424, 0.0000546, -0.9353807>,
    <0.2587557, 0.0000395, -0.9659428>,
    <0.2587561, 0.0000395, -0.9659427>,
    <0.2587565, 0.0000395, -0.9659426>,
    <0.3536434, 0.0000546, -0.9353803>,
    <0.3536434, 0.0000546, -0.9353803>,
    <0.6239871, 0.0000971, -0.7814346>,
    <0.3536418, 0.0000546, -0.9353809>,
    <0.2587553, 0.0000395, -0.9659429>,
    <0.6239846, 0.0000970, -0.7814367>,
    <0.3536413, 0.0000546, -0.9353811>,
    <0.3536413, 0.0000546, -0.9353811>,
    <0.2587549, 0.0000395, -0.9659430>,
    <0.3066458, 0.0000464, -0.9518237>,
    <0.3066462, 0.0000464, -0.9518236>,
    <0.2587549, 0.0000395, -0.9659430>,
    <0.3066453, 0.0000464, -0.9518239>,
    <0.3066453, 0.0000464, -0.9518239>,
    <0.5358762, 0.0000803, -0.8442966>,
    <0.5358768, 0.0000803, -0.8442962>,
    <0.5358775, 0.0000803, -0.8442958>,
    <0.3066467, 0.0000464, -0.9518234>,
    <0.5358781, 0.0000803, -0.8442954>,
    <0.5358788, 0.0000803, -0.8442949>,
    <0.3066472, 0.0000464, -0.9518233>,
    <0.3066472, 0.0000464, -0.9518233>,
    <0.2587565, 0.0000395, -0.9659426>,
    <-0.0000462, 0.9999991, 0.0013520>,
    <0.0000106, 0.9999990, 0.0014135>,
    <-0.0000528, 0.9999974, 0.0022678>,
    <-0.0000570, 0.9999981, 0.0019563>,
    <-0.0000582, 0.9999981, 0.0019512>,
    <-0.0000644, 0.9999990, 0.0013967>,
    <-0.0000644, 0.9999990, 0.0013967>,
    <-0.0000712, 0.9999998, 0.0006696>,
    <0.0001418, 0.9999979, 0.0020403>,
    <-0.0000432, 0.9999933, 0.0036538>,
    <0.0002356, 0.9999998, 0.0006068>,
    <0.0011921, 0.9999258, 0.0121273>,
    <0.0011921, 0.9999258, 0.0121273>,
    <-0.0000040, 0.9999288, 0.0119322>,
    <-0.0002154, 0.9999961, 0.0027688>,
    <-0.0001107, 0.9999982, 0.0018684>,
    <-0.0000040, 0.9999288, 0.0119322>,
    <-0.0007910, 0.9999300, 0.0118038>,
    <-0.0007910, 0.9999300, 0.0118038>,
    <-0.0002295, 0.9999997, 0.0007698>,
    <-0.0001785, 0.9999996, 0.0008333>,
    <-0.0000970, 0.9999996, 0.0008324>,
    <-0.0000666, 0.9999986, 0.0016422>,
    <-0.0000619, 0.9999997, 0.0008217>,
    <-0.0000504, 0.9999997, 0.0008202>,
    <-0.0000535, 0.9999987, 0.0016131>,
    <-0.0000535, 0.9999987, 0.0016131>,
    <-0.0000582, 0.9999981, 0.0019512>,
    <0.0000402, -1.0000000, 0.0001761>,
    <0.0000572, -1.0000000, 0.0002495>,
    <0.0000687, -1.0000000, 0.0001050>,
    <0.0000652, -1.0000000, 0.0000730>,
    <0.0000645, -1.0000000, 0.0000325>,
    <0.0000376, -1.0000000, 0.0000325>,
    <0.0000376, -1.0000000, 0.0000325>,
    <-0.0000768, -0.9999998, 0.0006671>,
    <0.0000708, -1.0000000, 0.0002645>,
    <0.0000726, -1.0000000, 0.0001166>,
    <0.0000785, -0.9999998, 0.0005847>,
    <0.0000755, -1.0000000, 0.0002578>,
    <0.0000755, -1.0000000, 0.0002578>,
    <0.0000740, -1.0000000, 0.0001152>,
    <0.0000732, -1.0000000, 0.0000506>,
    <0.0000727, -1.0000000, 0.0000485>,
    <0.0000740, -1.0000000, 0.0001152>,
    <0.0000733, -1.0000000, 0.0000499>,
    <0.0000733, -1.0000000, 0.0000499>,
    <0.0000731, -1.0000000, 0.0000306>,
    <0.0000731, -1.0000000, 0.0000311>,
    <0.0000731, -1.0000000, 0.0000311>,
    <0.0000731, -1.0000000, 0.0000316>,
    <0.0000723, -1.0000000, 0.0000418>,
    <0.0000731, -1.0000000, 0.0000316>,
    <0.0000731, -1.0000000, 0.0000321>,
    <0.0000731, -1.0000000, 0.0000321>,
    <0.0000731, -1.0000000, 0.0000325>,
    <0.0000722, -1.0000000, 0.0000325>,
    <0.0000722, -1.0000000, 0.0000325>,
    <0.0000645, -1.0000000, 0.0000325>,
    <0.8300740, 0.0001237, -0.5576532>,
    <0.8300736, 0.0001237, -0.5576538>,
    <0.9623799, 0.0001429, -0.2717074>,
    <0.9623800, 0.0001429, -0.2717070>,
    <0.9623802, 0.0001429, -0.2717065>,
    <0.8300745, 0.0001237, -0.5576525>,
    <0.8300745, 0.0001237, -0.5576525>,
    <0.5358788, 0.0000803, -0.8442949>,
    <0.8300732, 0.0001237, -0.5576545>,
    <0.9623798, 0.0001429, -0.2717079>,
    <0.5358762, 0.0000803, -0.8442966>,
    <0.8300727, 0.0001237, -0.5576552>,
    <0.8300727, 0.0001237, -0.5576552>,
    <0.9623796, 0.0001429, -0.2717083>,
    <0.9945474, 0.0001475, -0.1042853>,
    <0.9945474, 0.0001475, -0.1042851>,
    <0.9623796, 0.0001429, -0.2717083>,
    <0.9945474, 0.0001475, -0.1042855>,
    <0.9945474, 0.0001475, -0.1042855>,
    <0.9986191, 0.0001479, -0.0525351>,
    <0.9986191, 0.0001479, -0.0525350>,
    <0.9986191, 0.0001479, -0.0525350>,
    <0.9986191, 0.0001479, -0.0525349>,
    <0.9945475, 0.0001475, -0.1042849>,
    <0.9986191, 0.0001479, -0.0525349>,
    <0.9986191, 0.0001479, -0.0525347>,
    <0.9986191, 0.0001479, -0.0525347>,
    <0.9986191, 0.0001479, -0.0525346>,
    <0.9945475, 0.0001475, -0.1042847>,
    <0.9945475, 0.0001475, -0.1042847>,
    <0.9623802, 0.0001429, -0.2717065>,
    <-0.0000542, 0.9999999, 0.0003485>,
    <-0.0000702, 0.9999999, 0.0003161>,
    <-0.0000538, 1.0000000, 0.0001324>,
    <-0.0000493, 1.0000000, 0.0001517>,
    <-0.0000478, 1.0000000, 0.0001559>,
    <-0.0000486, 0.9999999, 0.0003553>,
    <-0.0000486, 0.9999999, 0.0003553>,
    <-0.0000504, 0.9999997, 0.0008202>,
    <-0.0000898, 1.0000000, 0.0002161>,
    <-0.0000579, 1.0000000, 0.0000896>,
    <-0.0002295, 0.9999997, 0.0007698>,
    <-0.0000923, 1.0000000, 0.0000375>,
    <-0.0000923, 1.0000000, 0.0000375>,
    <-0.0000587, 1.0000000, 0.0000376>,
    <-0.0000486, 1.0000000, 0.0000501>,
    <-0.0000481, 1.0000000, 0.0000597>,
    <-0.0000587, 1.0000000, 0.0000376>,
    <-0.0000487, 1.0000000, 0.0000376>,
    <-0.0000487, 1.0000000, 0.0000376>,
    <-0.0000473, 1.0000000, 0.0000376>,
    <-0.0000473, 1.0000000, 0.0000378>,
    <-0.0000473, 1.0000000, 0.0000378>,
    <-0.0000473, 1.0000000, 0.0000381>,
    <-0.0000476, 1.0000000, 0.0000641>,
    <-0.0000473, 1.0000000, 0.0000381>,
    <-0.0000473, 1.0000000, 0.0000383>,
    <-0.0000473, 1.0000000, 0.0000383>,
    <-0.0000473, 1.0000000, 0.0000385>,
    <-0.0000474, 1.0000000, 0.0000652>,
    <-0.0000474, 1.0000000, 0.0000652>,
    <-0.0000478, 1.0000000, 0.0001559>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, -0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <0.0000700, -1.0000000, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, -0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <1.0000000, 0.0001460, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, -0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <-0.0000457, 1.0000000, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, -0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <1.0000000, 0.0002109, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005139>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <0.9999998, 0.0002111, 0.0005140>,
    <-0.9869426, -0.0002089, -0.1610724>,
    <-0.9869426, -0.0002087, -0.1610724>,
    <-0.9869431, -0.0002087, -0.1610692>,
    <-0.9869431, -0.0002089, -0.1610692>,
    <-0.9869431, -0.0002090, -0.1610692>,
    <-0.9869426, -0.0002090, -0.1610724>,
    <-0.9869426, -0.0002090, -0.1610724>,
    <-0.9869420, -0.0002090, -0.1610757>,
    <-0.9869420, -0.0002089, -0.1610757>,
    <-0.9869420, -0.0002089, -0.1610757>,
    <-0.9869420, -0.0002087, -0.1610757>,
    <-0.9869426, -0.0002085, -0.1610724>,
    <-0.9869431, -0.0002085, -0.1610692>,
    <-0.9869420, -0.0002087, -0.1610757>,
    <-0.9869420, -0.0002085, -0.1610757>,
    <-0.9869420, -0.0002085, -0.1610757>,
    <-0.9869420, -0.0002084, -0.1610757>,
    <-0.9869426, -0.0002084, -0.1610724>,
    <-0.9869426, -0.0002084, -0.1610724>,
    <-0.9869431, -0.0002084, -0.1610692>,
    <-0.9869436, -0.0002085, -0.1610659>,
    <-0.9869436, -0.0002087, -0.1610659>,
    <-0.9869431, -0.0002084, -0.1610692>,
    <-0.9869436, -0.0002084, -0.1610659>,
    <-0.9869436, -0.0002084, -0.1610659>,
    <-0.9869442, -0.0002084, -0.1610626>,
    <-0.9869442, -0.0002085, -0.1610626>,
    <-0.9869442, -0.0002085, -0.1610626>,
    <-0.9869442, -0.0002087, -0.1610626>,
    <-0.9869436, -0.0002089, -0.1610659>,
    <-0.9869442, -0.0002087, -0.1610626>,
    <-0.9869442, -0.0002089, -0.1610627>,
    <-0.9869442, -0.0002089, -0.1610627>,
    <-0.9869442, -0.0002090, -0.1610627>,
    <-0.9869436, -0.0002090, -0.1610659>,
    <-0.9869436, -0.0002090, -0.1610659>,
    <-0.9869431, -0.0002090, -0.1610692>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <1.0000000, 0.0002118, 0.0000083>,
    <-0.9987356, -0.0002116, -0.0502712>,
    <-0.9987356, -0.0002116, -0.0502712>,
    <-0.9987356, -0.0002116, -0.0502702>,
    <-0.9987356, -0.0002116, -0.0502702>,
    <-0.9987356, -0.0002116, -0.0502702>,
    <-0.9987356, -0.0002116, -0.0502712>,
    <-0.9987356, -0.0002116, -0.0502712>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987356, -0.0002116, -0.0502712>,
    <-0.9987356, -0.0002116, -0.0502702>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002116, -0.0502722>,
    <-0.9987355, -0.0002115, -0.0502722>,
    <-0.9987356, -0.0002115, -0.0502712>,
    <-0.9987356, -0.0002115, -0.0502712>,
    <-0.9987356, -0.0002115, -0.0502702>,
    <-0.9987357, -0.0002116, -0.0502691>,
    <-0.9987357, -0.0002116, -0.0502691>,
    <-0.9987356, -0.0002115, -0.0502702>,
    <-0.9987357, -0.0002115, -0.0502691>,
    <-0.9987357, -0.0002115, -0.0502691>,
    <-0.9987357, -0.0002115, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502691>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502681>,
    <-0.9987357, -0.0002116, -0.0502691>,
    <-0.9987357, -0.0002116, -0.0502691>,
    <-0.9987356, -0.0002116, -0.0502702>,
    <0.9999404, 0.0003518, 0.0109141>,
    <0.9999447, 0.0002121, 0.0105163>,
    <0.9999338, 0.0002120, 0.0115037>,
    <0.9999321, 0.0002470, 0.0116512>,
    <0.9999286, 0.0002562, 0.0119508>,
    <0.9999285, 0.0003833, 0.0119507>,
    <0.9999285, 0.0003833, 0.0119507>,
    <0.9999722, 0.0008604, 0.0074076>,
    <0.9999724, 0.0006173, 0.0074077>,
    <0.9999725, 0.0002121, 0.0074076>,
    <0.9999404, 0.0000724, 0.0109136>,
    <0.9999321, 0.0001770, 0.0116506>,
    <0.9999725, -0.0001931, 0.0074074>,
    <0.9999725, -0.0004362, 0.0074070>,
    <0.9999286, 0.0000408, 0.0119496>,
    <0.9999286, 0.0000408, 0.0119496>,
    <0.9999286, 0.0001678, 0.0119498>,
    <0.9999294, 0.0002078, 0.0118782>,
    <0.9999298, 0.0002119, 0.0118451>,
    <0.9999286, 0.0001678, 0.0119498>,
    <0.9999286, 0.0002064, 0.0119498>,
    <0.9999286, 0.0002064, 0.0119498>,
    <0.9999286, 0.0002119, 0.0119498>,
    <0.9999286, 0.0002119, 0.0119500>,
    <0.9999286, 0.0002119, 0.0119500>,
    <0.9999286, 0.0002119, 0.0119503>,
    <0.9999294, 0.0002161, 0.0118787>,
    <0.9999286, 0.0002119, 0.0119503>,
    <0.9999286, 0.0002119, 0.0119505>,
    <0.9999286, 0.0002119, 0.0119505>,
    <0.9999286, 0.0002119, 0.0119508>,
    <0.9999286, 0.0002175, 0.0119508>,
    <0.9999286, 0.0002175, 0.0119508>,
    <0.9999286, 0.0002562, 0.0119508>,
    <0.9999903, 0.0006810, -0.0043628>,
    <0.9997832, 0.0004445, -0.0208159>,
    <0.9998818, 0.0002121, -0.0153711>,
    <0.9999996, 0.0002121, -0.0008270>,
    <0.9999722, 0.0008604, 0.0074076>,
    <0.9990810, 0.0021041, -0.0428095>,
    <0.9990810, 0.0021041, -0.0428095>,
    <0.9990828, 0.0007002, -0.0428134>,
    <0.9993788, 0.0002520, -0.0352415>,
    <0.9994752, 0.0002120, -0.0323937>,
    <0.9990828, 0.0007002, -0.0428134>,
    <0.9990830, 0.0002729, -0.0428145>,
    <0.9990830, 0.0002729, -0.0428145>,
    <0.9990830, 0.0002119, -0.0428147>,
    <0.9990830, 0.0002119, -0.0428138>,
    <0.9990830, 0.0002119, -0.0428138>,
    <0.9990831, 0.0002119, -0.0428129>,
    <0.9993789, 0.0001719, -0.0352399>,
    <0.9997834, -0.0000204, -0.0208147>,
    <0.9990831, 0.0002119, -0.0428129>,
    <0.9990831, 0.0002119, -0.0428120>,
    <0.9990831, 0.0002119, -0.0428120>,
    <0.9990832, 0.0002119, -0.0428112>,
    <0.9990832, 0.0001508, -0.0428110>,
    <0.9990832, 0.0001508, -0.0428110>,
    <0.9990832, -0.0002764, -0.0428096>,
    <0.9999905, -0.0002568, -0.0043624>,
    <0.9990832, -0.0002764, -0.0428096>,
    <0.9990820, -0.0016801, -0.0428052>,
    <0.9990820, -0.0016801, -0.0428052>,
    <0.9999725, -0.0004362, 0.0074070>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9514109>,
    <0.4350054, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289899, 0.9514109>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9514109>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559172, 0.9657316>,
    <0.6289899, 0.9514109>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4350054, 0.9657316>,
    <0.5000060, 0.9664305>,
    <0.4264033, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379346, 0.9664305>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664305>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559172, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773692, 0.9671308>,
    <0.6379346, 0.9664305>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4264033, 0.9671308>,
    <0.5000061, 0.9784050>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473428, 0.9784050>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9784050>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773692, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473428, 0.9784050>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032659, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458871>,
    <0.4677608, 0.9457569>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9514109>,
    <0.4355157, 0.9458871>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9452857>,
    <0.4677603, 0.9520134>,
    <0.4676327, 0.9588725>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9514109>,
    <0.5000059, 0.9657316>,
    <0.4350054, 0.9657316>,
    <0.4677603, 0.9520134>,
    <0.5000059, 0.9583740>,
    <0.4675013, 0.9657316>,
    <0.4352839, 0.9585445>,
    <0.4031382, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4350054, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352839, 0.9585445>,
    <0.4023500, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032659, 0.9526160>,
    <0.5322510, 0.9457569>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9514109>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9520135>,
    <0.5000059, 0.9452857>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458711>,
    <0.5967411, 0.9457569>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289899, 0.9514109>,
    <0.5644961, 0.9458711>,
    <0.5967380, 0.9395004>,
    <0.6289859, 0.9452857>,
    <0.5967441, 0.9520135>,
    <0.5967475, 0.9588725>,
    <0.5644983, 0.9526160>,
    <0.6289899, 0.9514109>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967441, 0.9520135>,
    <0.6289944, 0.9583740>,
    <0.5967509, 0.9657316>,
    <0.5645004, 0.9589932>,
    <0.5322532, 0.9588725>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9514109>,
    <0.5645004, 0.9589932>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9583740>,
    <0.5322521, 0.9520135>,
    <0.6423395, 0.9457569>,
    <0.6556982, 0.9526160>,
    <0.6289899, 0.9514109>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423438, 0.9520134>,
    <0.6289859, 0.9452857>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458871>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458871>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691098, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559172, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694404, 0.9657316>,
    <0.6557972, 0.9585445>,
    <0.6424011, 0.9588725>,
    <0.6556982, 0.9526160>,
    <0.6559172, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289899, 0.9514109>,
    <0.6557972, 0.9585445>,
    <0.6424600, 0.9657316>,
    <0.6289944, 0.9583740>,
    <0.6423438, 0.9520134>,
    <0.3997808, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4350054, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4023500, 0.9657316>,
    <0.4330490, 0.9660765>,
    <0.4665136, 0.9660812>,
    <0.4310370, 0.9664312>,
    <0.4350054, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664305>,
    <0.4330490, 0.9660765>,
    <0.4675013, 0.9657316>,
    <0.5000060, 0.9661007>,
    <0.4655215, 0.9664308>,
    <0.4643631, 0.9667808>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664305>,
    <0.5000061, 0.9671308>,
    <0.4264033, 0.9671308>,
    <0.4655215, 0.9664308>,
    <0.5000060, 0.9667582>,
    <0.4631991, 0.9671308>,
    <0.4287555, 0.9667757>,
    <0.3931579, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4264033, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4287555, 0.9667757>,
    <0.3895634, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664305>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664308>,
    <0.5000060, 0.9661007>,
    <0.5322542, 0.9657316>,
    <0.5668649, 0.9661011>,
    <0.6001028, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379346, 0.9664305>,
    <0.5668649, 0.9661011>,
    <0.5967509, 0.9657316>,
    <0.6337189, 0.9661007>,
    <0.6034548, 0.9664308>,
    <0.6068115, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.6379346, 0.9664305>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034548, 0.9664308>,
    <0.6421255, 0.9667582>,
    <0.6101681, 0.9671308>,
    <0.5710683, 0.9667586>,
    <0.5356086, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664305>,
    <0.5710683, 0.9667586>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667582>,
    <0.5344905, 0.9664308>,
    <0.6473391, 0.9660812>,
    <0.6665054, 0.9664312>,
    <0.6379346, 0.9664305>,
    <0.6289992, 0.9657316>,
    <0.6559172, 0.9657316>,
    <0.6522200, 0.9664308>,
    <0.6337189, 0.9661007>,
    <0.6424600, 0.9657316>,
    <0.6611372, 0.9660765>,
    <0.6749768, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559172, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6611372, 0.9660765>,
    <0.6694404, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866644, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773692, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926253, 0.9671308>,
    <0.6718544, 0.9667757>,
    <0.6571745, 0.9667808>,
    <0.6665054, 0.9664312>,
    <0.6773692, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379346, 0.9664305>,
    <0.6718544, 0.9667757>,
    <0.6621313, 0.9671308>,
    <0.6421255, 0.9667582>,
    <0.6522200, 0.9664308>,
    <0.3896432, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4264033, 0.9671308>,
    <0.3895222, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3895634, 0.9671308>,
    <0.4263749, 0.9728674>,
    <0.4631915, 0.9726067>,
    <0.4263507, 0.9777601>,
    <0.4264033, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9784050>,
    <0.4263749, 0.9728674>,
    <0.4631991, 0.9671308>,
    <0.5000061, 0.9727092>,
    <0.4631779, 0.9780826>,
    <0.4631249, 0.9832360>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9784050>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631779, 0.9780826>,
    <0.5000061, 0.9835191>,
    <0.4630714, 0.9883895>,
    <0.4262411, 0.9832068>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262411, 0.9832068>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895222, 0.9777601>,
    <0.5367803, 0.9726067>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9784050>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9780826>,
    <0.5000061, 0.9727092>,
    <0.5367268, 0.9671308>,
    <0.5735533, 0.9723901>,
    <0.6103351, 0.9726067>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473428, 0.9784050>,
    <0.5735533, 0.9723901>,
    <0.6101681, 0.9671308>,
    <0.6471134, 0.9727092>,
    <0.6105021, 0.9780826>,
    <0.6106561, 0.9832360>,
    <0.5736614, 0.9777601>,
    <0.6473428, 0.9784050>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105021, 0.9780826>,
    <0.6475487, 0.9835191>,
    <0.6108101, 0.9883895>,
    <0.5737711, 0.9832046>,
    <0.5368873, 0.9832360>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9784050>,
    <0.5737711, 0.9832046>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9835191>,
    <0.5368338, 0.9780826>,
    <0.6623549, 0.9726067>,
    <0.6778190, 0.9777601>,
    <0.6473428, 0.9784050>,
    <0.6468888, 0.9671308>,
    <0.6773692, 0.9671308>,
    <0.6625811, 0.9780826>,
    <0.6471134, 0.9727092>,
    <0.6621313, 0.9671308>,
    <0.6776119, 0.9728674>,
    <0.6928063, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773692, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776119, 0.9728674>,
    <0.6926253, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930704, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930704, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780837, 0.9832068>,
    <0.6628105, 0.9832360>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473428, 0.9784050>,
    <0.6780837, 0.9832068>,
    <0.6630402, 0.9883895>,
    <0.6475487, 0.9835191>,
    <0.6625811, 0.9780826>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.05, 0.196529, -0.147353>
}

#declare TMesh010 = mesh2 {
  vertex_vectors {
    582,
    <2.2066458, 0.1989400, 18.5058918>,
    <1.9978099, 0.1409798, 18.5058918>,
    <1.9974799, 0.0831028, 18.5058918>,
    <2.2063266, 0.1212845, 18.5058918>,
    <2.1022278, 0.1699599, 18.5058918>,
    <1.9976449, 0.1120413, 18.5058918>,
    <2.1019033, 0.1021936, 18.5058918>,
    <2.2064862, 0.1601122, 18.5058918>,
    <2.1020655, 0.1360768, 18.5058918>,
    <2.4151733, 0.1594662, 18.5058918>,
    <2.4154818, 0.2569002, 18.5058918>,
    <2.3107499, 0.1403753, 18.5058918>,
    <2.4153275, 0.2081832, 18.5058918>,
    <2.3110638, 0.2279201, 18.5058918>,
    <2.3109069, 0.1841477, 18.5058918>,
    <2.4157903, 0.3543342, 18.5058918>,
    <2.2069650, 0.2765955, 18.5058918>,
    <2.4156360, 0.3056172, 18.5058918>,
    <2.3113777, 0.3154649, 18.5058918>,
    <2.2068054, 0.2377677, 18.5058918>,
    <2.3112207, 0.2716925, 18.5058918>,
    <1.9981398, 0.1988568, 18.5058918>,
    <2.1025524, 0.2377261, 18.5058918>,
    <1.9979748, 0.1699183, 18.5058918>,
    <2.1023901, 0.2038430, 18.5058918>,
    <2.0647758, 0.0954626, 18.1207908>,
    <1.9999089, 0.0831535, 18.1202395>,
    <1.9999798, 0.0831550, 18.1217627>,
    <2.0534502, 0.0947089, 18.1217627>,
    <2.0323423, 0.0893081, 18.1205151>,
    <1.9999443, 0.0831542, 18.1210011>,
    <2.0267150, 0.0889319, 18.1217627>,
    <2.0591130, 0.0950858, 18.1212767>,
    <2.0295287, 0.0891200, 18.1211389>,
    <2.1069206, 0.1062628, 18.1217627>,
    <2.1296427, 0.1077718, 18.1213420>,
    <2.0801854, 0.1004859, 18.1217627>,
    <2.1182817, 0.1070173, 18.1215524>,
    <2.0972092, 0.1016172, 18.1210664>,
    <2.0886973, 0.1010515, 18.1214145>,
    <2.1523647, 0.1092807, 18.1209214>,
    <2.0761013, 0.0962164, 18.1198188>,
    <2.1410037, 0.1085263, 18.1211317>,
    <2.1142330, 0.1027486, 18.1203701>,
    <2.0704386, 0.0958395, 18.1203048>,
    <2.1057211, 0.1021829, 18.1207182>,
    <1.9998380, 0.0831520, 18.1187163>,
    <2.0379697, 0.0896842, 18.1192675>,
    <1.9998734, 0.0831528, 18.1194779>,
    <2.0351560, 0.0894961, 18.1198913>,
    <2.1298375, 0.1792179, 18.1213420>,
    <2.1071071, 0.1769503, 18.1217627>,
    <2.1297401, 0.1434948, 18.1213420>,
    <2.1070139, 0.1416066, 18.1217627>,
    <2.1184723, 0.1780841, 18.1215524>,
    <2.1183770, 0.1425507, 18.1215524>,
    <2.1072935, 0.2476378, 18.1217627>,
    <2.1300324, 0.2506639, 18.1213420>,
    <2.1072003, 0.2122941, 18.1217627>,
    <2.1186629, 0.2491509, 18.1215524>,
    <2.1299349, 0.2149409, 18.1213420>,
    <2.1185676, 0.2136175, 18.1215524>,
    <2.1527712, 0.2536901, 18.1209214>,
    <2.1525679, 0.1814854, 18.1209214>,
    <2.1414018, 0.2521770, 18.1211317>,
    <2.1526696, 0.2175877, 18.1209214>,
    <2.1412027, 0.1803516, 18.1211317>,
    <2.1413023, 0.2162643, 18.1211317>,
    <2.1524663, 0.1453831, 18.1209214>,
    <2.1411032, 0.1444389, 18.1211317>,
    <2.0651703, 0.2256229, 18.1207908>,
    <2.0538325, 0.2241350, 18.1217627>,
    <2.0976013, 0.2381434, 18.1210664>,
    <2.0805630, 0.2358864, 18.1217627>,
    <2.0595014, 0.2248790, 18.1212767>,
    <2.0890821, 0.2370149, 18.1214145>,
    <2.0003715, 0.2006323, 18.1217627>,
    <2.0003082, 0.2005819, 18.1202395>,
    <2.0271020, 0.2123837, 18.1217627>,
    <2.0003398, 0.2006071, 18.1210011>,
    <2.0327392, 0.2131024, 18.1205151>,
    <2.0299206, 0.2127430, 18.1211389>,
    <2.0002449, 0.2005316, 18.1187163>,
    <2.0765080, 0.2271108, 18.1198188>,
    <2.0002765, 0.2005567, 18.1194779>,
    <2.0383765, 0.2138212, 18.1192675>,
    <2.0708391, 0.2263669, 18.1203048>,
    <2.0355578, 0.2134618, 18.1198913>,
    <2.1146396, 0.2404004, 18.1203701>,
    <2.1061205, 0.2392719, 18.1207182>,
    <2.0762105, 0.0977881, 18.1376413>,
    <1.9996901, 0.0831489, 18.1370901>,
    <2.0379503, 0.0904685, 18.1373657>,
    <1.9997641, 0.0831505, 18.1279032>,
    <2.0761559, 0.0970022, 18.1287301>,
    <2.0379600, 0.0900764, 18.1283166>,
    <2.1527308, 0.1124273, 18.1381926>,
    <2.1525477, 0.1108540, 18.1295570>,
    <2.1144706, 0.1051077, 18.1379170>,
    <2.1143518, 0.1039281, 18.1291435>,
    <2.1530969, 0.1155738, 18.1554639>,
    <2.0763196, 0.0993598, 18.1554639>,
    <2.1529138, 0.1140005, 18.1468283>,
    <2.1147082, 0.1074668, 18.1554639>,
    <2.0762650, 0.0985740, 18.1465526>,
    <2.1145894, 0.1062872, 18.1466904>,
    <1.9995423, 0.0831458, 18.1554639>,
    <2.0379309, 0.0912528, 18.1554639>,
    <1.9996162, 0.0831474, 18.1462770>,
    <2.0379406, 0.0908607, 18.1464148>,
    <2.1529349, 0.1862137, 18.1381926>,
    <2.1528328, 0.1493205, 18.1381926>,
    <2.1527514, 0.1838496, 18.1295570>,
    <2.1526496, 0.1473518, 18.1295570>,
    <2.1531391, 0.2600002, 18.1381926>,
    <2.1529551, 0.2568451, 18.1295570>,
    <2.1530370, 0.2231070, 18.1381926>,
    <2.1528533, 0.2203474, 18.1295570>,
    <2.1535069, 0.2663104, 18.1554639>,
    <2.1533019, 0.1909421, 18.1554639>,
    <2.1533230, 0.2631553, 18.1468283>,
    <2.1534044, 0.2286263, 18.1554639>,
    <2.1531184, 0.1885779, 18.1468283>,
    <2.1532207, 0.2258666, 18.1468283>,
    <2.1531994, 0.1532579, 18.1554639>,
    <2.1530161, 0.1512892, 18.1468283>,
    <2.0766260, 0.2302134, 18.1376413>,
    <2.1148825, 0.2451068, 18.1379170>,
    <2.0765670, 0.2286621, 18.1287301>,
    <2.1147611, 0.2427536, 18.1291435>,
    <2.0001129, 0.2004266, 18.1370901>,
    <2.0001789, 0.2004791, 18.1279032>,
    <2.0383694, 0.2153200, 18.1373657>,
    <2.0383729, 0.2145706, 18.1283166>,
    <1.9999809, 0.2003215, 18.1554639>,
    <2.0767439, 0.2333160, 18.1554639>,
    <2.0000469, 0.2003740, 18.1462770>,
    <2.0383624, 0.2168188, 18.1554639>,
    <2.0766849, 0.2317647, 18.1465526>,
    <2.0383659, 0.2160694, 18.1464148>,
    <2.1151254, 0.2498132, 18.1554639>,
    <2.1150040, 0.2474600, 18.1466904>,
    <2.0805454, 0.1004736, 18.1573801>,
    <1.9994375, 0.0831437, 18.1573801>,
    <2.0399915, 0.0918086, 18.1573801>,
    <1.9994899, 0.0831447, 18.1564220>,
    <2.0784325, 0.0999167, 18.1564220>,
    <2.0389612, 0.0915307, 18.1564220>,
    <2.1616533, 0.1178035, 18.1573801>,
    <2.1573751, 0.1166886, 18.1564220>,
    <2.1210993, 0.1091385, 18.1573801>,
    <2.1179038, 0.1083027, 18.1564220>,
    <2.1702097, 0.1200332, 18.1592964>,
    <2.0847712, 0.1015873, 18.1592964>,
    <2.1659315, 0.1189184, 18.1583383>,
    <2.1274904, 0.1108103, 18.1592964>,
    <2.0826583, 0.1010305, 18.1583383>,
    <2.1242949, 0.1099744, 18.1583383>,
    <1.9993328, 0.0831415, 18.1592964>,
    <2.0420520, 0.0923644, 18.1592964>,
    <1.9993851, 0.0831426, 18.1583383>,
    <2.0410217, 0.0920865, 18.1583383>,
    <2.1618619, 0.1942928, 18.1573801>,
    <2.1617576, 0.1560481, 18.1573801>,
    <2.1575819, 0.1926174, 18.1564220>,
    <2.1574785, 0.1546530, 18.1564220>,
    <2.1620705, 0.2707820, 18.1573801>,
    <2.1577887, 0.2685462, 18.1564220>,
    <2.1619662, 0.2325374, 18.1573801>,
    <2.1576853, 0.2305818, 18.1564220>,
    <2.1706340, 0.2752536, 18.1592964>,
    <2.1704218, 0.1976434, 18.1592964>,
    <2.1663522, 0.2730178, 18.1583383>,
    <2.1705279, 0.2364485, 18.1592964>,
    <2.1661419, 0.1959681, 18.1583383>,
    <2.1662470, 0.2344929, 18.1583383>,
    <2.1703157, 0.1588383, 18.1592964>,
    <2.1660367, 0.1574432, 18.1583383>,
    <2.0809789, 0.2355146, 18.1573801>,
    <2.1215247, 0.2531483, 18.1573801>,
    <2.0788614, 0.2344153, 18.1564220>,
    <2.1183251, 0.2514807, 18.1564220>,
    <1.9998874, 0.2002471, 18.1573801>,
    <1.9999341, 0.2002843, 18.1564220>,
    <2.0404331, 0.2178809, 18.1573801>,
    <2.0393978, 0.2173498, 18.1564220>,
    <1.9997938, 0.2001727, 18.1592964>,
    <2.0852139, 0.2377132, 18.1592964>,
    <1.9998406, 0.2002099, 18.1583383>,
    <2.0425039, 0.2189429, 18.1592964>,
    <2.0830964, 0.2366139, 18.1583383>,
    <2.0414685, 0.2184119, 18.1583383>,
    <2.1279240, 0.2564834, 18.1592964>,
    <2.1247243, 0.2548158, 18.1583383>,
    <2.0863785, 0.1018304, 18.2324892>,
    <1.9993321, 0.0831415, 18.2344341>,
    <2.0428539, 0.0924859, 18.2333227>,
    <1.9993324, 0.0831415, 18.1968653>,
    <2.0847876, 0.1015910, 18.1968653>,
    <2.0420600, 0.0923662, 18.1968653>,
    <2.1734415, 0.1205197, 18.2322113>,
    <2.1702429, 0.1200404, 18.1968653>,
    <2.1299086, 0.1111751, 18.2322113>,
    <2.1275152, 0.1108157, 18.1968653>,
    <2.2019970, 0.1247829, 18.2873438>,
    <2.1005699, 0.1039602, 18.2890109>,
    <2.1829711, 0.1219432, 18.2631118>,
    <2.1512752, 0.1143714, 18.2873438>,
    <2.0911181, 0.1025416, 18.2642232>,
    <2.1370391, 0.1122423, 18.2631118>,
    <1.9993314, 0.0831414, 18.3095719>,
    <2.0498980, 0.0935497, 18.2940122>,
    <1.9993317, 0.0831414, 18.2720030>,
    <2.0452194, 0.0928414, 18.2675574>,
    <2.1736549, 0.1983745, 18.2322113>,
    <2.1735482, 0.1594471, 18.2322113>,
    <2.1704550, 0.1976543, 18.1968653>,
    <2.1703490, 0.1588474, 18.1968653>,
    <2.1738684, 0.2762293, 18.2322113>,
    <2.1706672, 0.2752681, 18.1968653>,
    <2.1737617, 0.2373019, 18.2322113>,
    <2.1705611, 0.2364612, 18.1968653>,
    <2.2024462, 0.2847788, 18.2873438>,
    <2.2022216, 0.2047809, 18.2873438>,
    <2.1834054, 0.2790840, 18.2631118>,
    <2.2023339, 0.2447799, 18.2873438>,
    <2.1831882, 0.2005136, 18.2631118>,
    <2.1832968, 0.2397988, 18.2631118>,
    <2.2021093, 0.1647819, 18.2873438>,
    <2.1830797, 0.1612284, 18.2631118>,
    <2.0868234, 0.2381949, 18.2324892>,
    <2.1303447, 0.2572111, 18.2322113>,
    <2.0852304, 0.2377203, 18.1968653>,
    <2.1279488, 0.2564942, 18.1968653>,
    <1.9997932, 0.2001722, 18.2344341>,
    <1.9997935, 0.2001725, 18.1968653>,
    <2.0433071, 0.2191826, 18.2333227>,
    <2.0425120, 0.2189464, 18.1968653>,
    <1.9997926, 0.2001718, 18.3095719>,
    <2.1010353, 0.2424083, 18.2890109>,
    <1.9997929, 0.2001720, 18.2720030>,
    <2.0503669, 0.2212526, 18.2940122>,
    <2.0915695, 0.2396044, 18.2642232>,
    <2.0456762, 0.2198842, 18.2675574>,
    <2.1517333, 0.2635877, 18.2873438>,
    <2.1374825, 0.2593402, 18.2631118>,
    <2.1352127, 0.1091659, 18.3131904>,
    <1.9986209, 0.0831266, 18.3135798>,
    <2.0669167, 0.0961463, 18.3133573>,
    <1.9989762, 0.0831340, 18.3115759>,
    <2.1162972, 0.1063218, 18.3037960>,
    <2.0576311, 0.0947278, 18.3071303>,
    <2.2718053, 0.1352053, 18.3131347>,
    <2.2336848, 0.1295109, 18.3026846>,
    <2.2035089, 0.1221856, 18.3131347>,
    <2.1749854, 0.1179163, 18.3026846>,
    <2.3424283, 0.1458049, 18.3353648>,
    <2.1702592, 0.1144602, 18.3340315>,
    <2.3101295, 0.1409440, 18.3226946>,
    <2.2563517, 0.1301327, 18.3353648>,
    <2.1542293, 0.1120322, 18.3218058>,
    <2.2321847, 0.1264882, 18.3226946>,
    <1.9979104, 0.0831118, 18.3175878>,
    <2.0841350, 0.0987870, 18.3300317>,
    <1.9982657, 0.0831192, 18.3155838>,
    <2.0762528, 0.0975758, 18.3191392>,
    <2.2720572, 0.2204428, 18.3131347>,
    <2.2719312, 0.1778241, 18.3131347>,
    <2.2339217, 0.2118858, 18.3026846>,
    <2.2338033, 0.1706984, 18.3026846>,
    <2.2723090, 0.3056804, 18.3131347>,
    <2.2341587, 0.2942607, 18.3026846>,
    <2.2721831, 0.2630616, 18.3131347>,
    <2.2340402, 0.2530732, 18.3026846>,
    <2.3429872, 0.3269374, 18.3353648>,
    <2.3427077, 0.2363712, 18.3353648>,
    <2.3106631, 0.3171889, 18.3226946>,
    <2.3428475, 0.2816543, 18.3353648>,
    <2.3103963, 0.2290665, 18.3226946>,
    <2.3105297, 0.2731277, 18.3226946>,
    <2.3425680, 0.1910880, 18.3353648>,
    <2.3102629, 0.1850052, 18.3226946>,
    <2.1357333, 0.2526735, 18.3131904>,
    <2.2040211, 0.2791769, 18.3131347>,
    <2.1167874, 0.2470664, 18.3037960>,
    <2.1754681, 0.2706596, 18.3026846>,
    <1.9991584, 0.1996671, 18.3135798>,
    <1.9994755, 0.1999195, 18.3115759>,
    <2.0674458, 0.2261703, 18.3133573>,
    <2.0581265, 0.2234890, 18.3071303>,
    <1.9985241, 0.1991625, 18.3175878>,
    <2.1708358, 0.2631138, 18.3340315>,
    <1.9988412, 0.1994148, 18.3155838>,
    <2.0847248, 0.2311738, 18.3300317>,
    <2.1547805, 0.2583244, 18.3218058>,
    <2.0768156, 0.2288734, 18.3191392>,
    <2.2569186, 0.2950312, 18.3353648>,
    <2.2327265, 0.2877604, 18.3226946>,
    <2.1856092, 0.1168446, 18.3800376>,
    <1.9978764, 0.0831111, 18.3784821>,
    <2.0917441, 0.0999778, 18.3793709>,
    <1.9978934, 0.0831114, 18.3480349>,
    <2.1802147, 0.1159895, 18.3542569>,
    <2.0890594, 0.0995506, 18.3515903>,
    <2.3733261, 0.1505777, 18.3802598>,
    <2.3624726, 0.1488662, 18.3551457>,
    <2.2794690, 0.1337112, 18.3802598>,
    <2.2713490, 0.1324280, 18.3551457>,
    <2.3797149, 0.1517512, 18.4393764>,
    <2.1887787, 0.1174308, 18.4393764>,
    <2.3780523, 0.1513894, 18.4089292>,
    <2.2842468, 0.1345910, 18.4393764>,
    <2.1879559, 0.1172501, 18.4089292>,
    <2.2830041, 0.1343197, 18.4089292>,
    <1.9978424, 0.0831103, 18.4393764>,
    <2.0933106, 0.1002706, 18.4393764>,
    <1.9978594, 0.0831107, 18.4089292>,
    <2.0929077, 0.1001804, 18.4089292>,
    <2.3736176, 0.2435434, 18.3802598>,
    <2.3734719, 0.1970605, 18.3802598>,
    <2.3627599, 0.2409714, 18.3551457>,
    <2.3626163, 0.1949188, 18.3551457>,
    <2.3739092, 0.3365090, 18.3802598>,
    <2.3630472, 0.3330766, 18.3551457>,
    <2.3737634, 0.2900262, 18.3802598>,
    <2.3629036, 0.2870240, 18.3551457>,
    <2.3803031, 0.3388622, 18.4393764>,
    <2.3800090, 0.2453067, 18.4393764>,
    <2.3786391, 0.3381367, 18.4089292>,
    <2.3801561, 0.2920844, 18.4393764>,
    <2.3783457, 0.2447631, 18.4089292>,
    <2.3784924, 0.2914499, 18.4089292>,
    <2.3798620, 0.1985289, 18.4393764>,
    <2.3781990, 0.1980762, 18.4089292>,
    <2.1862085, 0.2678293, 18.3800376>,
    <2.2800600, 0.3021701, 18.3802598>,
    <2.1808064, 0.2661361, 18.3542569>,
    <2.2719315, 0.2996101, 18.3551457>,
    <1.9984938, 0.1991384, 18.3784821>,
    <1.9985089, 0.1991505, 18.3480349>,
    <2.0923523, 0.2334848, 18.3793709>,
    <2.0896624, 0.2326470, 18.3515903>,
    <1.9984634, 0.1991142, 18.4393764>,
    <2.1893833, 0.2689882, 18.4393764>,
    <1.9984786, 0.1991263, 18.4089292>,
    <2.0939233, 0.2340512, 18.4393764>,
    <2.1885589, 0.2686315, 18.4089292>,
    <2.0935187, 0.2338789, 18.4089292>,
    <2.2848432, 0.3039252, 18.4393764>,
    <2.2835990, 0.3033841, 18.4089292>,
    <2.1975526, 0.1193576, 18.4393764>,
    <1.9976612, 0.0831066, 18.4393764>,
    <2.0976069, 0.1012321, 18.4393764>,
    <1.9977518, 0.0831085, 18.4393764>,
    <2.1931657, 0.1183942, 18.4393764>,
    <2.0954587, 0.1007513, 18.4393764>,
    <2.3974441, 0.1556087, 18.4393764>,
    <2.3885795, 0.1536799, 18.4393764>,
    <2.2974984, 0.1374831, 18.4393764>,
    <2.2908726, 0.1360370, 18.4393764>,
    <2.4151733, 0.1594662, 18.4393764>,
    <2.2063266, 0.1212845, 18.4393764>,
    <2.4063087, 0.1575374, 18.4393764>,
    <2.3107499, 0.1403753, 18.4393764>,
    <2.2019396, 0.1203210, 18.4393764>,
    <2.3041241, 0.1389292, 18.4393764>,
    <1.9974799, 0.0831028, 18.4393764>,
    <2.1019033, 0.1021936, 18.4393764>,
    <1.9975705, 0.0831047, 18.4393764>,
    <2.0997551, 0.1017129, 18.4393764>,
    <2.3977454, 0.2511034, 18.4393764>,
    <2.3975948, 0.2033560, 18.4393764>,
    <2.3888772, 0.2482051, 18.4393764>,
    <2.3887284, 0.2009425, 18.4393764>,
    <2.3980467, 0.3465982, 18.4393764>,
    <2.3891749, 0.3427302, 18.4393764>,
    <2.3978960, 0.2988508, 18.4393764>,
    <2.3890261, 0.2954676, 18.4393764>,
    <2.4157903, 0.3543342, 18.4393764>,
    <2.4154818, 0.2569002, 18.4393764>,
    <2.4069185, 0.3504662, 18.4393764>,
    <2.4156360, 0.3056172, 18.4393764>,
    <2.4066136, 0.2540018, 18.4393764>,
    <2.4067660, 0.3022340, 18.4393764>,
    <2.4153275, 0.2081832, 18.4393764>,
    <2.4064611, 0.2057696, 18.4393764>,
    <2.1981741, 0.2727919, 18.4393764>,
    <2.2981104, 0.3096950, 18.4393764>,
    <2.1937787, 0.2708900, 18.4393764>,
    <2.2914768, 0.3068101, 18.4393764>,
    <1.9983016, 0.1989855, 18.4393764>,
    <1.9983825, 0.1990499, 18.4393764>,
    <2.0982379, 0.2358887, 18.4393764>,
    <2.0960806, 0.2349700, 18.4393764>,
    <1.9981398, 0.1988568, 18.4393764>,
    <2.2069650, 0.2765955, 18.4393764>,
    <1.9982207, 0.1989211, 18.4393764>,
    <2.1025524, 0.2377261, 18.4393764>,
    <2.2025696, 0.2746937, 18.4393764>,
    <2.1003951, 0.2368074, 18.4393764>,
    <2.3113777, 0.3154649, 18.4393764>,
    <2.3047440, 0.3125800, 18.4393764>,
    <2.2063266, 0.1212845, 18.4726341>,
    <1.9974799, 0.0831028, 18.4726341>,
    <2.1019033, 0.1021936, 18.4726341>,
    <1.9974799, 0.0831028, 18.4560052>,
    <2.2063266, 0.1212845, 18.4560052>,
    <2.1019033, 0.1021936, 18.4560052>,
    <2.4151733, 0.1594662, 18.4726341>,
    <2.4151733, 0.1594662, 18.4560052>,
    <2.3107499, 0.1403753, 18.4726341>,
    <2.3107499, 0.1403753, 18.4560052>,
    <2.4151733, 0.1594662, 18.4892630>,
    <2.2063266, 0.1212845, 18.4892630>,
    <2.3107499, 0.1403753, 18.4892630>,
    <1.9974799, 0.0831028, 18.4892630>,
    <2.1019033, 0.1021936, 18.4892630>,
    <2.4154818, 0.2569002, 18.4726341>,
    <2.4153275, 0.2081832, 18.4726341>,
    <2.4154818, 0.2569002, 18.4560052>,
    <2.4153275, 0.2081832, 18.4560052>,
    <2.4157903, 0.3543342, 18.4726341>,
    <2.4157903, 0.3543342, 18.4560052>,
    <2.4156360, 0.3056172, 18.4726341>,
    <2.4156360, 0.3056172, 18.4560052>,
    <2.4157903, 0.3543342, 18.4892630>,
    <2.4154818, 0.2569002, 18.4892630>,
    <2.4156360, 0.3056172, 18.4892630>,
    <2.4153275, 0.2081832, 18.4892630>,
    <2.2069650, 0.2765955, 18.4726341>,
    <2.3113777, 0.3154649, 18.4726341>,
    <2.2069650, 0.2765955, 18.4560052>,
    <2.3113777, 0.3154649, 18.4560052>,
    <1.9981398, 0.1988568, 18.4726341>,
    <1.9981398, 0.1988568, 18.4560052>,
    <2.1025524, 0.2377261, 18.4726341>,
    <2.1025524, 0.2377261, 18.4560052>,
    <1.9981398, 0.1988568, 18.4892630>,
    <2.2069650, 0.2765955, 18.4892630>,
    <2.1025524, 0.2377261, 18.4892630>,
    <2.3113777, 0.3154649, 18.4892630>,
    <1.9978099, 0.1409798, 18.4726341>,
    <1.9974799, 0.0831028, 18.4726341>,
    <1.9978099, 0.1409798, 18.4393764>,
    <1.9976449, 0.1120413, 18.4726341>,
    <1.9974799, 0.0831028, 18.4560052>,
    <1.9976449, 0.1120413, 18.4393764>,
    <1.9978099, 0.1409798, 18.4560052>,
    <1.9976449, 0.1120413, 18.4560052>,
    <1.9981398, 0.1988568, 18.4726341>,
    <1.9979748, 0.1699183, 18.4393764>,
    <1.9981398, 0.1988568, 18.4560052>,
    <1.9979748, 0.1699183, 18.4726341>,
    <1.9979748, 0.1699183, 18.4560052>,
    <1.9978099, 0.1409798, 18.5058918>,
    <1.9981398, 0.1988568, 18.4892630>,
    <1.9979748, 0.1699183, 18.5058918>,
    <1.9978099, 0.1409798, 18.4892630>,
    <1.9979748, 0.1699183, 18.4892630>,
    <1.9976449, 0.1120413, 18.5058918>,
    <1.9974799, 0.0831028, 18.4892630>,
    <1.9976449, 0.1120413, 18.4892630>,
    <1.9979814, 0.1410460, 18.4393764>,
    <1.9981529, 0.1411123, 18.4393764>,
    <1.9980671, 0.1410792, 18.4393764>,
    <1.9979977, 0.1121113, 18.4393764>,
    <1.9978213, 0.1120763, 18.4393764>,
    <1.9979095, 0.1120938, 18.4393764>,
    <1.9978099, 0.1409798, 18.4393764>,
    <1.9976449, 0.1120413, 18.4393764>,
    <1.9978956, 0.1410129, 18.4393764>,
    <1.9977331, 0.1120588, 18.4393764>,
    <1.9979748, 0.1699183, 18.4393764>,
    <1.9981415, 0.1700158, 18.4393764>,
    <1.9980582, 0.1699670, 18.4393764>,
    <1.9983082, 0.1701133, 18.4393764>,
    <1.9982248, 0.1700645, 18.4393764>,
    <1.9981851, 0.1411247, 18.3784821>,
    <1.9978764, 0.0831111, 18.3784821>,
    <1.9982173, 0.1411371, 18.3175878>,
    <1.9980308, 0.1121179, 18.3784821>,
    <1.9978934, 0.0831114, 18.3480349>,
    <1.9980638, 0.1121245, 18.3175878>,
    <1.9982012, 0.1411309, 18.3480349>,
    <1.9980473, 0.1121212, 18.3480349>,
    <1.9984938, 0.1991384, 18.3784821>,
    <1.9983707, 0.1701498, 18.3175878>,
    <1.9985089, 0.1991505, 18.3480349>,
    <1.9983394, 0.1701316, 18.3784821>,
    <1.9983550, 0.1701407, 18.3480349>,
    <1.9981529, 0.1411123, 18.4393764>,
    <1.9984786, 0.1991263, 18.4089292>,
    <1.9983082, 0.1701133, 18.4393764>,
    <1.9981690, 0.1411185, 18.4089292>,
    <1.9983238, 0.1701224, 18.4089292>,
    <1.9979977, 0.1121113, 18.4393764>,
    <1.9978594, 0.0831107, 18.4089292>,
    <1.9980142, 0.1121146, 18.4089292>,
    <1.9988896, 0.1413969, 18.3135798>,
    <1.9995620, 0.1416566, 18.3095719>,
    <1.9992258, 0.1415267, 18.3115759>,
    <1.9994467, 0.1123990, 18.3095719>,
    <1.9987553, 0.1122617, 18.3135798>,
    <1.9991010, 0.1123304, 18.3115759>,
    <1.9982173, 0.1411371, 18.3175878>,
    <1.9980638, 0.1121245, 18.3175878>,
    <1.9985534, 0.1412670, 18.3155838>,
    <1.9984096, 0.1121931, 18.3155838>,
    <1.9983707, 0.1701498, 18.3175878>,
    <1.9990240, 0.1705320, 18.3135798>,
    <1.9986973, 0.1703409, 18.3155838>,
    <1.9996773, 0.1709142, 18.3095719>,
    <1.9993507, 0.1707231, 18.3115759>,
    <1.9995627, 0.1416568, 18.2344341>,
    <1.9993321, 0.0831415, 18.2344341>,
    <1.9995633, 0.1416571, 18.1592964>,
    <1.9994474, 0.1123991, 18.2344341>,
    <1.9993324, 0.0831415, 18.1968653>,
    <1.9994480, 0.1123993, 18.1592964>,
    <1.9995630, 0.1416570, 18.1968653>,
    <1.9994477, 0.1123992, 18.1968653>,
    <1.9997932, 0.2001722, 18.2344341>,
    <1.9996786, 0.1709149, 18.1592964>,
    <1.9997935, 0.2001725, 18.1968653>,
    <1.9996779, 0.1709145, 18.2344341>,
    <1.9996783, 0.1709147, 18.1968653>,
    <1.9995620, 0.1416566, 18.3095719>,
    <1.9997929, 0.2001720, 18.2720030>,
    <1.9996773, 0.1709142, 18.3095719>,
    <1.9995623, 0.1416567, 18.2720030>,
    <1.9996776, 0.1709144, 18.2720030>,
    <1.9994467, 0.1123990, 18.3095719>,
    <1.9993317, 0.0831414, 18.2720030>,
    <1.9994470, 0.1123991, 18.2720030>,
    <1.9996624, 0.1416954, 18.1573801>,
    <1.9997616, 0.1417337, 18.1554639>,
    <1.9997120, 0.1417145, 18.1564220>,
    <1.9996519, 0.1124398, 18.1554639>,
    <1.9995500, 0.1124195, 18.1573801>,
    <1.9996010, 0.1124296, 18.1564220>,
    <1.9995633, 0.1416571, 18.1592964>,
    <1.9994480, 0.1123993, 18.1592964>,
    <1.9996129, 0.1416762, 18.1583383>,
    <1.9994990, 0.1124094, 18.1583383>,
    <1.9996786, 0.1709149, 18.1592964>,
    <1.9997749, 0.1709713, 18.1573801>,
    <1.9997267, 0.1709431, 18.1583383>,
    <1.9998712, 0.1710276, 18.1554639>,
    <1.9998231, 0.1709994, 18.1564220>,
    <1.9999622, 0.1418112, 18.1389725>,
    <1.9997610, 0.0831504, 18.1386133>,
    <2.0001028, 0.1418655, 18.1258340>,
    <1.9998605, 0.1124804, 18.1388528>,
    <1.9998704, 0.0831527, 18.1301880>,
    <2.0000168, 0.1125074, 18.1251156>,
    <2.0000464, 0.1418437, 18.1316249>,
    <1.9999541, 0.1124965, 18.1311460>,
    <2.0001762, 0.2004769, 18.1386133>,
    <2.0002145, 0.1712335, 18.1251156>,
    <2.0002738, 0.2005546, 18.1301880>,
    <2.0000681, 0.1711436, 18.1388528>,
    <2.0001558, 0.1711975, 18.1311460>,
    <1.9997616, 0.1417337, 18.1554639>,
    <2.0000785, 0.2003992, 18.1470386>,
    <1.9998712, 0.1710276, 18.1554639>,
    <1.9998651, 0.1417737, 18.1470386>,
    <1.9999718, 0.1710865, 18.1470386>,
    <1.9996519, 0.1124398, 18.1554639>,
    <1.9996517, 0.0831481, 18.1470386>,
    <1.9997584, 0.1124609, 18.1470386>,
    <2.0001021, 0.1418652, 18.1205987>,
    <2.0001164, 0.1418707, 18.1224380>,
    <2.0000044, 0.1125089, 18.1204790>,
    <2.0000261, 0.1125108, 18.1219591>,
    <2.0000414, 0.1418418, 18.1187163>,
    <1.9999397, 0.1124969, 18.1187163>,
    <2.0000750, 0.1418547, 18.1194779>,
    <1.9999742, 0.1125037, 18.1194779>,
    <2.0001431, 0.1711867, 18.1187163>,
    <2.0002041, 0.1712232, 18.1204790>,
    <2.0001757, 0.1712057, 18.1194779>,
    <2.0002238, 0.1712373, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.1684286, 0.8468919, -0.5043866>,
    <-0.1077075, 0.5532059, -0.8260523>,
    <-0.1079631, 0.6042998, -0.7894085>,
    <-0.1612495, 0.8705741, -0.4648648>,
    <-0.1864910, 0.9824263, 0.0077258>,
    <-0.1977042, 0.9802270, 0.0082499>,
    <-0.1977042, 0.9802270, 0.0082499>,
    <-0.2111980, 0.9774030, 0.0088807>,
    <-0.1764384, 0.8165392, -0.5496664>,
    <-0.1764384, 0.8165392, -0.5496664>,
    <-0.1069419, 0.4949163, -0.8623348>,
    <-0.0598753, 0.3187753, -0.9459372>,
    <-0.0625607, 0.3711753, -0.9264529>,
    <-0.1069419, 0.4949163, -0.8623348>,
    <-0.0568859, 0.2632621, -0.9630457>,
    <-0.0568859, 0.2632621, -0.9630457>,
    <-0.0265166, 0.1227160, -0.9920875>,
    <-0.0294498, 0.1688017, -0.9852100>,
    <-0.0294498, 0.1688017, -0.9852100>,
    <-0.0322743, 0.2138059, -0.9763429>,
    <-0.0649473, 0.4202370, -0.9050871>,
    <-0.1078241, 0.6488264, -0.7532584>,
    <-0.0322743, 0.2138059, -0.9763429>,
    <-0.0349771, 0.2574871, -0.9656485>,
    <-0.0349771, 0.2574871, -0.9656485>,
    <-0.0375482, 0.2996421, -0.9533125>,
    <-0.0670475, 0.4658527, -0.8823185>,
    <-0.0670475, 0.4658527, -0.8823185>,
    <-0.1073893, 0.6874979, -0.7182020>,
    <-0.1548422, 0.8892971, -0.4303192>,
    <-0.1073893, 0.6874979, -0.7182020>,
    <-0.1491274, 0.9042920, -0.4000214>,
    <-0.1491274, 0.9042920, -0.4000214>,
    <-0.1689393, 0.9856023, 0.0069058>,
    <-0.1770288, 0.9841787, 0.0072837>,
    <-0.1770288, 0.9841787, 0.0072837>,
    <-0.1864910, 0.9824263, 0.0077258>,
    <-0.0185111, 0.0000497, -0.9998287>,
    <-0.0185085, 0.0000496, -0.9998287>,
    <-0.0185086, 0.0000505, -0.9998287>,
    <-0.0185112, 0.0000505, -0.9998287>,
    <-0.0185138, 0.0000505, -0.9998286>,
    <-0.0185137, 0.0000497, -0.9998286>,
    <-0.0185137, 0.0000497, -0.9998286>,
    <-0.0185136, 0.0000488, -0.9998286>,
    <-0.0185110, 0.0000488, -0.9998287>,
    <-0.0185110, 0.0000488, -0.9998287>,
    <-0.0185084, 0.0000488, -0.9998287>,
    <-0.0185059, 0.0000496, -0.9998287>,
    <-0.0185060, 0.0000505, -0.9998287>,
    <-0.0185084, 0.0000488, -0.9998287>,
    <-0.0185058, 0.0000488, -0.9998288>,
    <-0.0185058, 0.0000488, -0.9998288>,
    <-0.0185032, 0.0000488, -0.9998288>,
    <-0.0185033, 0.0000496, -0.9998288>,
    <-0.0185033, 0.0000496, -0.9998288>,
    <-0.0185034, 0.0000505, -0.9998288>,
    <-0.0185061, 0.0000513, -0.9998287>,
    <-0.0185087, 0.0000513, -0.9998287>,
    <-0.0185034, 0.0000505, -0.9998288>,
    <-0.0185035, 0.0000513, -0.9998288>,
    <-0.0185035, 0.0000513, -0.9998288>,
    <-0.0185036, 0.0000521, -0.9998288>,
    <-0.0185062, 0.0000521, -0.9998287>,
    <-0.0185062, 0.0000521, -0.9998287>,
    <-0.0185087, 0.0000521, -0.9998287>,
    <-0.0185112, 0.0000513, -0.9998287>,
    <-0.0185087, 0.0000521, -0.9998287>,
    <-0.0185113, 0.0000521, -0.9998286>,
    <-0.0185113, 0.0000521, -0.9998286>,
    <-0.0185139, 0.0000521, -0.9998286>,
    <-0.0185138, 0.0000513, -0.9998286>,
    <-0.0185138, 0.0000513, -0.9998286>,
    <-0.0185138, 0.0000505, -0.9998286>,
    <0.0616346, -0.1614169, 0.9849598>,
    <0.1210969, -0.3058919, 0.9443334>,
    <0.1249312, -0.3440880, 0.9305889>,
    <0.0652855, -0.1906681, 0.9794812>,
    <0.0325008, -0.1060639, 0.9938280>,
    <0.0295033, -0.0832248, 0.9960940>,
    <0.0295033, -0.0832248, 0.9960940>,
    <0.0264739, -0.0602193, 0.9978340>,
    <0.0578833, -0.1316653, 0.9896028>,
    <0.0578833, -0.1316653, 0.9896028>,
    <0.1169336, -0.2659851, 0.9568586>,
    <0.2448025, -0.6052957, 0.7574225>,
    <0.2426456, -0.6444722, 0.7251060>,
    <0.1169336, -0.2659851, 0.9568586>,
    <0.2464396, -0.5605686, 0.7905886>,
    <0.2464396, -0.5605686, 0.7905886>,
    <0.4024137, -0.9153578, 0.0135396>,
    <0.3794621, -0.9250887, 0.0148150>,
    <0.3794621, -0.9250887, 0.0148150>,
    <0.3599943, -0.9328194, 0.0158795>,
    <0.2401329, -0.6787374, 0.6940114>,
    <0.1284426, -0.3804923, 0.9158210>,
    <0.3599943, -0.9328194, 0.0158795>,
    <0.3432955, -0.9390775, 0.0167803>,
    <0.3432955, -0.9390775, 0.0167803>,
    <0.3288282, -0.9442266, 0.0175517>,
    <0.2373930, -0.7087048, 0.6643659>,
    <0.2373930, -0.7087048, 0.6643659>,
    <0.1316414, -0.4150581, 0.9002207>,
    <0.0688293, -0.2193535, 0.9732146>,
    <0.1316414, -0.4150581, 0.9002207>,
    <0.0722602, -0.2474147, 0.9662114>,
    <0.0722602, -0.2474147, 0.9662114>,
    <0.0383831, -0.1511062, 0.9877721>,
    <0.0354622, -0.1287021, 0.9910490>,
    <0.0354622, -0.1287021, 0.9910490>,
    <0.0325008, -0.1060639, 0.9938280>,
    <0.1778039, -0.9831349, 0.0427960>,
    <0.1768694, -0.9805235, 0.0853866>,
    <0.1866284, -0.9787319, 0.0851688>,
    <0.1874346, -0.9813473, 0.0427289>,
    <0.1878936, -0.9821885, 0.0013469>,
    <0.1784024, -0.9839568, 0.0012702>,
    <0.1784024, -0.9839568, 0.0012702>,
    <0.1688295, -0.9856445, 0.0011929>,
    <0.1680892, -0.9848396, 0.0428595>,
    <0.1680892, -0.9848396, 0.0428595>,
    <0.1670243, -0.9822301, 0.0855973>,
    <0.1755784, -0.9759979, 0.1288420>,
    <0.1854532, -0.9742191, 0.1284691>,
    <0.1670243, -0.9822301, 0.0855973>,
    <0.1656161, -0.9776899, 0.1292044>,
    <0.1656161, -0.9776899, 0.1292044>,
    <0.1638506, -0.9711174, 0.1734475>,
    <0.1739152, -0.9694576, 0.1729318>,
    <0.1739152, -0.9694576, 0.1729318>,
    <0.1838913, -0.9677095, 0.1724019>,
    <0.1952387, -0.9723558, 0.1280861>,
    <0.1962998, -0.9768576, 0.0849443>,
    <0.1838913, -0.9677095, 0.1724019>,
    <0.1937770, -0.9658754, 0.1718582>,
    <0.1937770, -0.9658754, 0.1718582>,
    <0.2035704, -0.9639580, 0.1713013>,
    <0.2049331, -0.9704107, 0.1276933>,
    <0.2049331, -0.9704107, 0.1276933>,
    <0.2058819, -0.9749032, 0.0847133>,
    <0.1969795, -0.9794791, 0.0426581>,
    <0.2058819, -0.9749032, 0.0847133>,
    <0.2064372, -0.9775328, 0.0425839>,
    <0.2064372, -0.9775328, 0.0425839>,
    <0.2066244, -0.9784192, 0.0014982>,
    <0.1973014, -0.9803418, 0.0014229>,
    <0.1973014, -0.9803418, 0.0014229>,
    <0.1878936, -0.9821885, 0.0013469>,
    <0.9997843, -0.0027901, -0.0205813>,
    <0.9997864, -0.0027901, -0.0204793>,
    <0.9997863, -0.0027662, -0.0204858>,
    <0.9997842, -0.0027662, -0.0205868>,
    <0.9997822, -0.0027662, -0.0206877>,
    <0.9997822, -0.0027901, -0.0206834>,
    <0.9997822, -0.0027901, -0.0206834>,
    <0.9997822, -0.0028145, -0.0206789>,
    <0.9997843, -0.0028145, -0.0205758>,
    <0.9997843, -0.0028145, -0.0205758>,
    <0.9997865, -0.0028145, -0.0204726>,
    <0.9997885, -0.0027901, -0.0203772>,
    <0.9997884, -0.0027662, -0.0203849>,
    <0.9997865, -0.0028145, -0.0204726>,
    <0.9997886, -0.0028145, -0.0203694>,
    <0.9997886, -0.0028145, -0.0203694>,
    <0.9997907, -0.0028145, -0.0202662>,
    <0.9997905, -0.0027901, -0.0202752>,
    <0.9997905, -0.0027901, -0.0202752>,
    <0.9997904, -0.0027662, -0.0202839>,
    <0.9997883, -0.0027428, -0.0203923>,
    <0.9997863, -0.0027428, -0.0204922>,
    <0.9997904, -0.0027662, -0.0202839>,
    <0.9997903, -0.0027428, -0.0202924>,
    <0.9997903, -0.0027428, -0.0202924>,
    <0.9997902, -0.0027199, -0.0203008>,
    <0.9997882, -0.0027199, -0.0203996>,
    <0.9997882, -0.0027199, -0.0203996>,
    <0.9997862, -0.0027199, -0.0204985>,
    <0.9997842, -0.0027428, -0.0205921>,
    <0.9997862, -0.0027199, -0.0204985>,
    <0.9997842, -0.0027199, -0.0205973>,
    <0.9997842, -0.0027199, -0.0205973>,
    <0.9997821, -0.0027199, -0.0206962>,
    <0.9997821, -0.0027428, -0.0206920>,
    <0.9997821, -0.0027428, -0.0206920>,
    <0.9997822, -0.0027662, -0.0206877>,
    <-0.3337440, 0.9116280, -0.2398945>,
    <-0.3402139, 0.9267933, -0.1590869>,
    <-0.3572435, 0.9205692, -0.1578907>,
    <-0.3508626, 0.9056622, -0.2380574>,
    <-0.3422134, 0.8848880, -0.3160114>,
    <-0.3250866, 0.8904667, -0.3184144>,
    <-0.3250866, 0.8904667, -0.3184144>,
    <-0.3075786, 0.8958327, -0.3207478>,
    <-0.3162318, 0.9173812, -0.2416800>,
    <-0.3162318, 0.9173812, -0.2416800>,
    <-0.3227854, 0.9328075, -0.1602492>,
    <-0.3443545, 0.9356258, -0.0776170>,
    <-0.3612199, 0.9292879, -0.0770987>,
    <-0.3227854, 0.9328075, -0.1602492>,
    <-0.3270923, 0.9417580, -0.0781181>,
    <-0.3270923, 0.9417580, -0.0781181>,
    <-0.3291428, 0.9442753, 0.0030322>,
    <-0.3461644, 0.9381695, 0.0028750>,
    <-0.3461644, 0.9381695, 0.0028750>,
    <-0.3627978, 0.9318639, 0.0027195>,
    <-0.3776847, 0.9227633, -0.0765647>,
    <-0.3738703, 0.9141539, -0.1566639>,
    <-0.3627978, 0.9318639, 0.0027195>,
    <-0.3790398, 0.9253768, 0.0025657>,
    <-0.3790398, 0.9253768, 0.0025657>,
    <-0.3948886, 0.9187258, 0.0024139>,
    <-0.3937471, 0.9160702, -0.0760167>,
    <-0.3937471, 0.9160702, -0.0760167>,
    <-0.3900919, 0.9075661, -0.1554097>,
    <-0.3675831, 0.8995024, -0.2361738>,
    <-0.3900919, 0.9075661, -0.1554097>,
    <-0.3839026, 0.8931665, -0.2342485>,
    <-0.3839026, 0.8931665, -0.2342485>,
    <-0.3753042, 0.8731619, -0.3110224>,
    <-0.3589538, 0.8791140, -0.3135453>,
    <-0.3589538, 0.8791140, -0.3135453>,
    <-0.3422134, 0.8848880, -0.3160114>,
    <0.2074430, -0.9763972, 0.0601332>,
    <0.2065677, -0.9722773, 0.1095750>,
    <0.2077495, -0.9723134, 0.1069898>,
    <0.2085866, -0.9762314, 0.0588554>,
    <0.2089377, -0.9778746, 0.0103071>,
    <0.2078081, -0.9781160, 0.0102451>,
    <0.2078081, -0.9781160, 0.0102451>,
    <0.2066139, -0.9783696, 0.0101795>,
    <0.2062337, -0.9765692, 0.0614834>,
    <0.2062337, -0.9765692, 0.0614834>,
    <0.2053175, -0.9722306, 0.1123049>,
    <0.2052014, -0.9658466, 0.1582172>,
    <0.2064437, -0.9662021, 0.1543840>,
    <0.2053175, -0.9722306, 0.1123049>,
    <0.2038864, -0.9654542, 0.1622606>,
    <0.2038864, -0.9654542, 0.1622606>,
    <0.2019727, -0.9563922, 0.2109999>,
    <0.2033733, -0.9572421, 0.2057347>,
    <0.2033733, -0.9572421, 0.2057347>,
    <0.2046957, -0.9580212, 0.2007364>,
    <0.2076191, -0.9665248, 0.1507453>,
    <0.2088684, -0.9723404, 0.1045381>,
    <0.2046957, -0.9580212, 0.2007364>,
    <0.2059461, -0.9587366, 0.1959856>,
    <0.2059461, -0.9587366, 0.1959856>,
    <0.2071302, -0.9593948, 0.1914646>,
    <0.2087328, -0.9668181, 0.1472867>,
    <0.2087328, -0.9668181, 0.1472867>,
    <0.2099292, -0.9723594, 0.1022098>,
    <0.2096699, -0.9760716, 0.0576442>,
    <0.2099292, -0.9723594, 0.1022098>,
    <0.2106974, -0.9759175, 0.0564947>,
    <0.2106974, -0.9759175, 0.0564947>,
    <0.2110229, -0.9774256, 0.0104216>,
    <0.2100078, -0.9776448, 0.0103659>,
    <0.2100078, -0.9776448, 0.0103659>,
    <0.2089377, -0.9778746, 0.0103071>,
    <0.2186828, -0.0005957, -0.9757958>,
    <0.2186765, -0.0005957, -0.9757972>,
    <0.2186768, -0.0005964, -0.9757972>,
    <0.2186830, -0.0005964, -0.9757958>,
    <0.2186892, -0.0005964, -0.9757944>,
    <0.2186891, -0.0005957, -0.9757944>,
    <0.2186891, -0.0005957, -0.9757944>,
    <0.2186889, -0.0005949, -0.9757945>,
    <0.2186825, -0.0005949, -0.9757959>,
    <0.2186825, -0.0005949, -0.9757959>,
    <0.2186762, -0.0005949, -0.9757973>,
    <0.2186702, -0.0005956, -0.9757986>,
    <0.2186705, -0.0005964, -0.9757986>,
    <0.2186762, -0.0005949, -0.9757973>,
    <0.2186699, -0.0005949, -0.9757987>,
    <0.2186699, -0.0005949, -0.9757987>,
    <0.2186635, -0.0005949, -0.9758001>,
    <0.2186639, -0.0005956, -0.9758001>,
    <0.2186639, -0.0005956, -0.9758001>,
    <0.2186643, -0.0005964, -0.9758000>,
    <0.2186708, -0.0005971, -0.9757985>,
    <0.2186770, -0.0005971, -0.9757971>,
    <0.2186643, -0.0005964, -0.9758000>,
    <0.2186646, -0.0005971, -0.9757999>,
    <0.2186646, -0.0005971, -0.9757999>,
    <0.2186650, -0.0005978, -0.9757998>,
    <0.2186711, -0.0005978, -0.9757984>,
    <0.2186711, -0.0005978, -0.9757984>,
    <0.2186773, -0.0005978, -0.9757971>,
    <0.2186832, -0.0005971, -0.9757957>,
    <0.2186773, -0.0005978, -0.9757971>,
    <0.2186834, -0.0005979, -0.9757957>,
    <0.2186834, -0.0005979, -0.9757957>,
    <0.2186896, -0.0005979, -0.9757943>,
    <0.2186894, -0.0005972, -0.9757943>,
    <0.2186894, -0.0005972, -0.9757943>,
    <0.2186892, -0.0005964, -0.9757944>,
    <-0.3830005, 0.8856831, -0.2624425>,
    <-0.3909121, 0.9039786, -0.1732349>,
    <-0.3931354, 0.9039491, -0.1682874>,
    <-0.3855972, 0.8866162, -0.2553949>,
    <-0.3755358, 0.8634816, -0.3367081>,
    <-0.3724847, 0.8613655, -0.3454050>,
    <-0.3724847, 0.8613655, -0.3454050>,
    <-0.3692422, 0.8590585, -0.3545119>,
    <-0.3802397, 0.8846446, -0.2698548>,
    <-0.3802397, 0.8846446, -0.2698548>,
    <-0.3885509, 0.9039810, -0.1784560>,
    <-0.3956551, 0.9149466, -0.0795597>,
    <-0.3976376, 0.9143009, -0.0770595>,
    <-0.3885509, 0.9039810, -0.1784560>,
    <-0.3935533, 0.9156191, -0.0822037>,
    <-0.3935533, 0.9156191, -0.0822037>,
    <-0.3948366, 0.9186050, 0.0163994>,
    <-0.3968607, 0.9177347, 0.0162668>,
    <-0.3968607, 0.9177347, 0.0162668>,
    <-0.3987715, 0.9169083, 0.0161414>,
    <-0.3995105, 0.9136807, -0.0746919>,
    <-0.3952322, 0.9038965, -0.1635930>,
    <-0.3987715, 0.9169083, 0.0161414>,
    <-0.4005781, 0.9161225, 0.0160228>,
    <-0.4005781, 0.9161225, 0.0160228>,
    <-0.4022889, 0.9153745, 0.0159102>,
    <-0.4012826, 0.9130848, -0.0724465>,
    <-0.4012826, 0.9130848, -0.0724465>,
    <-0.3972129, 0.9038244, -0.1591330>,
    <-0.3880434, 0.8874555, -0.2486867>,
    <-0.3972129, 0.9038244, -0.1591330>,
    <-0.3903511, 0.8882112, -0.2422951>,
    <-0.3903511, 0.8882112, -0.2422951>,
    <-0.3811230, 0.8672133, -0.3204472>,
    <-0.3784106, 0.8654254, -0.3283965>,
    <-0.3784106, 0.8654254, -0.3283965>,
    <-0.3755358, 0.8634816, -0.3367081>,
    <0.2108429, -0.9775197, -0.0006803>,
    <0.2108394, -0.9775197, -0.0013841>,
    <0.2094328, -0.9778055, -0.0058606>,
    <0.2094744, -0.9778102, -0.0027863>,
    <0.2095618, -0.9777954, 0.0000017>,
    <0.2108464, -0.9775192, 0.0000017>,
    <0.2108464, -0.9775192, 0.0000017>,
    <0.2110344, -0.9774786, 0.0000017>,
    <0.2110344, -0.9774786, 0.0000017>,
    <0.2110344, -0.9774786, 0.0000017>,
    <0.2110344, -0.9774786, 0.0000016>,
    <0.2108380, -0.9775188, -0.0021019>,
    <0.2094632, -0.9777748, -0.0090369>,
    <0.2110344, -0.9774786, 0.0000016>,
    <0.2110344, -0.9774786, 0.0000015>,
    <0.2110344, -0.9774786, 0.0000015>,
    <0.2110344, -0.9774786, 0.0000015>,
    <0.2108377, -0.9775170, -0.0028226>,
    <0.2108377, -0.9775170, -0.0028226>,
    <0.2094851, -0.9777361, -0.0121662>,
    <0.2058488, -0.9783142, -0.0229696>,
    <0.2055507, -0.9785371, -0.0146328>,
    <0.2094851, -0.9777361, -0.0121662>,
    <0.2060360, -0.9780505, -0.0310863>,
    <0.2060360, -0.9780505, -0.0310863>,
    <0.2000348, -0.9773242, -0.0694511>,
    <0.1995736, -0.9785513, -0.0510666>,
    <0.1986859, -0.9795125, -0.0328512>,
    <0.2056936, -0.9785943, -0.0065870>,
    <0.1983980, -0.9799988, -0.0155113>,
    <0.2012800, -0.9795324, 0.0016249>,
    <0.2063560, -0.9784770, 0.0000017>,
    <0.2063560, -0.9784770, 0.0000017>,
    <0.2095618, -0.9777954, 0.0000017>,
    <0.9990161, -0.0027325, -0.0442658>,
    <0.9990159, -0.0027325, -0.0442698>,
    <0.9820424, -0.0026947, -0.1886412>,
    <0.9820456, -0.0026948, -0.1886245>,
    <0.9820488, -0.0026948, -0.1886077>,
    <0.9990162, -0.0027325, -0.0442617>,
    <0.9990162, -0.0027325, -0.0442617>,
    <0.9999959, -0.0027339, -0.0008831>,
    <0.9999959, -0.0027339, -0.0008831>,
    <0.9999959, -0.0027339, -0.0008831>,
    <0.9999959, -0.0027339, -0.0008832>,
    <0.9990157, -0.0027325, -0.0442739>,
    <0.9820392, -0.0026947, -0.1886580>,
    <0.9999959, -0.0027339, -0.0008832>,
    <0.9999959, -0.0027339, -0.0008832>,
    <0.9999959, -0.0027339, -0.0008832>,
    <0.9999959, -0.0027339, -0.0008833>,
    <0.9990155, -0.0027325, -0.0442779>,
    <0.9990155, -0.0027325, -0.0442779>,
    <0.9820359, -0.0026947, -0.1886748>,
    <0.8879866, -0.0024576, -0.4598627>,
    <0.8880038, -0.0024576, -0.4598296>,
    <0.9820359, -0.0026947, -0.1886748>,
    <0.8879695, -0.0024575, -0.4598959>,
    <0.8879695, -0.0024575, -0.4598959>,
    <0.6152103, -0.0017301, -0.7883612>,
    <0.6152446, -0.0017302, -0.7883344>,
    <0.6152789, -0.0017303, -0.7883076>,
    <0.8880209, -0.0024577, -0.4597965>,
    <0.6153132, -0.0017304, -0.7882808>,
    <0.6153475, -0.0017305, -0.7882540>,
    <0.8880381, -0.0024577, -0.4597633>,
    <0.8880381, -0.0024577, -0.4597633>,
    <0.9820488, -0.0026948, -0.1886077>,
    <-0.4020058, 0.9156275, 0.0042032>,
    <-0.4020007, 0.9156351, 0.0028064>,
    <-0.3995352, 0.9166409, 0.0118794>,
    <-0.3996341, 0.9164965, 0.0180793>,
    <-0.3996583, 0.9163482, 0.0240650>,
    <-0.4020063, 0.9156199, 0.0055800>,
    <-0.4020063, 0.9156199, 0.0055800>,
    <-0.4023398, 0.9154904, 0.0000028>,
    <-0.4023398, 0.9154904, 0.0000028>,
    <-0.4023398, 0.9154904, 0.0000028>,
    <-0.4023398, 0.9154904, 0.0000027>,
    <-0.4019986, 0.9156392, 0.0013951>,
    <-0.3995527, 0.9166925, 0.0057003>,
    <-0.4023398, 0.9154904, 0.0000027>,
    <-0.4023398, 0.9154904, 0.0000027>,
    <-0.4023398, 0.9154904, 0.0000027>,
    <-0.4023398, 0.9154904, 0.0000026>,
    <-0.4020020, 0.9156388, 0.0000026>,
    <-0.4020020, 0.9156388, 0.0000026>,
    <-0.3996905, 0.9166501, 0.0000027>,
    <-0.3927089, 0.9195587, 0.0138413>,
    <-0.3926638, 0.9191946, 0.0299390>,
    <-0.3996905, 0.9166501, 0.0000027>,
    <-0.3938059, 0.9191936, 0.0000027>,
    <-0.3938059, 0.9191936, 0.0000027>,
    <-0.3834384, 0.9235622, 0.0028183>,
    <-0.3791870, 0.9246552, 0.0350699>,
    <-0.3801872, 0.9223809, 0.0683465>,
    <-0.3932241, 0.9182844, 0.0461365>,
    <-0.3812502, 0.9186964, 0.1031757>,
    <-0.3809364, 0.9142548, 0.1379336>,
    <-0.3933713, 0.9173102, 0.0616531>,
    <-0.3933713, 0.9173102, 0.0616531>,
    <-0.3996583, 0.9163482, 0.0240650>,
    <0.1907384, -0.9808428, -0.0395770>,
    <0.1910733, -0.9794694, -0.0642712>,
    <0.1864041, -0.9787582, -0.0853577>,
    <0.1867309, -0.9806645, -0.0585557>,
    <0.1873093, -0.9818558, 0.0295705>,
    <0.1964879, -0.9800096, 0.0312044>,
    <0.1964879, -0.9800096, 0.0312044>,
    <0.2012800, -0.9795324, 0.0016249>,
    <0.1919501, -0.9769196, -0.0937195>,
    <0.1859531, -0.9757523, -0.1154508>,
    <0.2000348, -0.9773242, -0.0694511>,
    <0.1920202, -0.9732095, -0.1264573>,
    <0.1920202, -0.9732095, -0.1264573>,
    <0.1850793, -0.9708410, -0.1523593>,
    <0.1822454, -0.9796722, -0.0838389>,
    <0.1833149, -0.9812028, -0.0603052>,
    <0.1850793, -0.9708410, -0.1523593>,
    <0.1813655, -0.9772185, -0.1102298>,
    <0.1813655, -0.9772185, -0.1102298>,
    <0.1791184, -0.9826049, -0.0490326>,
    <0.1794466, -0.9830856, -0.0366277>,
    <0.1798777, -0.9833933, -0.0241185>,
    <0.1838503, -0.9822467, -0.0372895>,
    <0.1800076, -0.9836016, -0.0111839>,
    <0.1789369, -0.9838589, 0.0018169>,
    <0.1807410, -0.9831206, 0.0284014>,
    <0.1807410, -0.9831206, 0.0284014>,
    <0.1873093, -0.9818558, 0.0295705>,
    <0.3466621, -0.0009980, -0.9379895>,
    <0.3466355, -0.0009979, -0.9379994>,
    <0.2532907, -0.0007484, -0.9673899>,
    <0.2533106, -0.0007484, -0.9673847>,
    <0.2533306, -0.0007485, -0.9673795>,
    <0.3466887, -0.0009981, -0.9379797>,
    <0.3466887, -0.0009981, -0.9379797>,
    <0.6153475, -0.0017305, -0.7882540>,
    <0.3466089, -0.0009978, -0.9380092>,
    <0.2532707, -0.0007483, -0.9673952>,
    <0.6152103, -0.0017301, -0.7883612>,
    <0.3465823, -0.0009978, -0.9380190>,
    <0.3465823, -0.0009978, -0.9380190>,
    <0.2532508, -0.0007483, -0.9674004>,
    <0.3003049, -0.0009087, -0.9538428>,
    <0.3003270, -0.0009087, -0.9538359>,
    <0.2532508, -0.0007483, -0.9674004>,
    <0.3002827, -0.0009086, -0.9538498>,
    <0.3002827, -0.0009086, -0.9538498>,
    <0.5269785, -0.0016240, -0.8498771>,
    <0.5270082, -0.0016241, -0.8498586>,
    <0.5270380, -0.0016242, -0.8498401>,
    <0.3003492, -0.0009088, -0.9538289>,
    <0.5270678, -0.0016243, -0.8498217>,
    <0.5270976, -0.0016244, -0.8498032>,
    <0.3003714, -0.0009089, -0.9538219>,
    <0.3003714, -0.0009089, -0.9538219>,
    <0.2533306, -0.0007485, -0.9673795>,
    <-0.3644957, 0.9116250, 0.1899545>,
    <-0.3650837, 0.9209867, 0.1360048>,
    <-0.3553259, 0.9165361, 0.1835894>,
    <-0.3515308, 0.9060567, 0.2355574>,
    <-0.3450915, 0.8891350, 0.3005843>,
    <-0.3609454, 0.8985940, 0.2494941>,
    <-0.3609454, 0.8985940, 0.2494941>,
    <-0.3809364, 0.9142548, 0.1379336>,
    <-0.3647568, 0.9261892, 0.0955300>,
    <-0.3574124, 0.9223265, 0.1468680>,
    <-0.3834384, 0.9235622, 0.0028183>,
    <-0.3670087, 0.9283570, 0.0588043>,
    <-0.3670087, 0.9283570, 0.0588043>,
    <-0.3609411, 0.9306530, 0.0600536>,
    <-0.3556925, 0.9294082, 0.0984036>,
    <-0.3528085, 0.9261473, 0.1333315>,
    <-0.3609411, 0.9306530, 0.0600536>,
    <-0.3560457, 0.9324717, 0.0610572>,
    <-0.3560457, 0.9324717, 0.0610572>,
    <-0.3487579, 0.9372040, 0.0040641>,
    <-0.3500704, 0.9362520, 0.0297126>,
    <-0.3488669, 0.9355817, 0.0545785>,
    <-0.3488131, 0.9206557, 0.1752785>,
    <-0.3473850, 0.9344334, 0.0784718>,
    <-0.3461344, 0.9326070, 0.1021527>,
    <-0.3445281, 0.9117769, 0.2235249>,
    <-0.3445281, 0.9117769, 0.2235249>,
    <-0.3450915, 0.8891350, 0.3005843>,
    <0.1777342, -0.9840719, -0.0036114>,
    <0.1777791, -0.9840357, -0.0082655>,
    <0.1769622, -0.9842148, -0.0023606>,
    <0.1769510, -0.9842191, -0.0010672>,
    <0.1769357, -0.9842224, 0.0000873>,
    <0.1775731, -0.9841076, 0.0000877>,
    <0.1775731, -0.9841076, 0.0000877>,
    <0.1789369, -0.9838589, 0.0018169>,
    <0.1777045, -0.9839977, -0.0130262>,
    <0.1769613, -0.9842108, -0.0037247>,
    <0.1791184, -0.9826049, -0.0490326>,
    <0.1776412, -0.9839370, -0.0176542>,
    <0.1776412, -0.9839370, -0.0176542>,
    <0.1769573, -0.9842054, -0.0050871>,
    <0.1768047, -0.9842459, 0.0003568>,
    <0.1768035, -0.9842461, 0.0002767>,
    <0.1769573, -0.9842054, -0.0050871>,
    <0.1768051, -0.9842458, 0.0004289>,
    <0.1768051, -0.9842458, 0.0004289>,
    <0.1769124, -0.9842245, 0.0020333>,
    <0.1769125, -0.9842254, 0.0015468>,
    <0.1769125, -0.9842254, 0.0015468>,
    <0.1769126, -0.9842260, 0.0010603>,
    <0.1768024, -0.9842463, 0.0001846>,
    <0.1769126, -0.9842260, 0.0010603>,
    <0.1769127, -0.9842264, 0.0005738>,
    <0.1769127, -0.9842264, 0.0005738>,
    <0.1769127, -0.9842265, 0.0000873>,
    <0.1768022, -0.9842464, 0.0000872>,
    <0.1768022, -0.9842464, 0.0000872>,
    <0.1769357, -0.9842224, 0.0000873>,
    <0.8238686, -0.0025675, -0.5667750>,
    <0.8238488, -0.0025674, -0.5668038>,
    <0.9605359, -0.0030105, -0.2781398>,
    <0.9605410, -0.0030105, -0.2781220>,
    <0.9605462, -0.0030106, -0.2781043>,
    <0.8238884, -0.0025675, -0.5667462>,
    <0.8238884, -0.0025675, -0.5667462>,
    <0.5270976, -0.0016244, -0.8498032>,
    <0.8238290, -0.0025673, -0.5668326>,
    <0.9605307, -0.0030105, -0.2781575>,
    <0.5269785, -0.0016240, -0.8498771>,
    <0.8238091, -0.0025673, -0.5668614>,
    <0.8238091, -0.0025673, -0.5668614>,
    <0.9605256, -0.0030105, -0.2781753>,
    <0.9942108, -0.0031232, -0.1074017>,
    <0.9942114, -0.0031232, -0.1073960>,
    <0.9605256, -0.0030105, -0.2781753>,
    <0.9942102, -0.0031232, -0.1074075>,
    <0.9942102, -0.0031232, -0.1074075>,
    <0.9985091, -0.0031387, -0.0544946>,
    <0.9985092, -0.0031387, -0.0544929>,
    <0.9985092, -0.0031387, -0.0544929>,
    <0.9985093, -0.0031387, -0.0544912>,
    <0.9942120, -0.0031232, -0.1073902>,
    <0.9985093, -0.0031387, -0.0544912>,
    <0.9985094, -0.0031387, -0.0544895>,
    <0.9985094, -0.0031387, -0.0544895>,
    <0.9985095, -0.0031387, -0.0544878>,
    <0.9942127, -0.0031232, -0.1073844>,
    <0.9942127, -0.0031232, -0.1073844>,
    <0.9605462, -0.0030106, -0.2781043>,
    <-0.3450172, 0.9381628, 0.0285264>,
    <-0.3453448, 0.9382828, 0.0190352>,
    <-0.3438220, 0.9390167, 0.0058383>,
    <-0.3437766, 0.9390116, 0.0086501>,
    <-0.3437494, 0.9389933, 0.0113102>,
    <-0.3447793, 0.9379343, 0.0375038>,
    <-0.3447793, 0.9379343, 0.0375038>,
    <-0.3461344, 0.9326070, 0.1021527>,
    <-0.3454708, 0.9383855, 0.0090844>,
    <-0.3438404, 0.9390235, 0.0029319>,
    <-0.3487579, 0.9372040, 0.0040641>,
    <-0.3452210, 0.9385214, 0.0002001>,
    <-0.3452210, 0.9385214, 0.0002001>,
    <-0.3438214, 0.9390350, 0.0002010>,
    <-0.3435051, 0.9391508, 0.0001251>,
    <-0.3435027, 0.9391517, 0.0000305>,
    <-0.3438214, 0.9390350, 0.0002010>,
    <-0.3435059, 0.9391505, 0.0002012>,
    <-0.3435059, 0.9391505, 0.0002012>,
    <-0.3436911, 0.9390827, 0.0002011>,
    <-0.3436910, 0.9390825, -0.0007474>,
    <-0.3436910, 0.9390825, -0.0007474>,
    <-0.3436906, 0.9390814, -0.0016958>,
    <-0.3435005, 0.9391525, -0.0000928>,
    <-0.3436906, 0.9390814, -0.0016958>,
    <-0.3436899, 0.9390795, -0.0026442>,
    <-0.3436899, 0.9390795, -0.0026442>,
    <-0.3436889, 0.9390767, -0.0035927>,
    <-0.3434997, 0.9391527, -0.0002323>,
    <-0.3434997, 0.9391527, -0.0002323>,
    <-0.3437494, 0.9389933, 0.0113102>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, -0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.1798408, -0.9836957, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, -0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <0.9999950, -0.0031663, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, -0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <-0.3488768, 0.9371686, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, -0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.9999838, -0.0057005, 0.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.9999858, -0.0053042, 0.0005427>,
    <0.9999858, -0.0053042, 0.0005272>,
    <0.9999857, -0.0053205, 0.0005272>,
    <0.9999857, -0.0053205, 0.0005427>,
    <0.9999857, -0.0053205, 0.0005582>,
    <0.9999858, -0.0053042, 0.0005582>,
    <0.9999858, -0.0053042, 0.0005582>,
    <0.9999859, -0.0052880, 0.0005582>,
    <0.9999859, -0.0052880, 0.0005427>,
    <0.9999859, -0.0052880, 0.0005427>,
    <0.9999859, -0.0052880, 0.0005272>,
    <0.9999858, -0.0053042, 0.0005117>,
    <0.9999857, -0.0053205, 0.0005117>,
    <0.9999859, -0.0052880, 0.0005272>,
    <0.9999859, -0.0052880, 0.0005117>,
    <0.9999859, -0.0052880, 0.0005117>,
    <0.9999859, -0.0052880, 0.0004963>,
    <0.9999858, -0.0053042, 0.0004963>,
    <0.9999858, -0.0053042, 0.0004963>,
    <0.9999857, -0.0053205, 0.0004963>,
    <0.9999856, -0.0053367, 0.0005117>,
    <0.9999856, -0.0053367, 0.0005272>,
    <0.9999857, -0.0053205, 0.0004963>,
    <0.9999856, -0.0053367, 0.0004962>,
    <0.9999856, -0.0053367, 0.0004962>,
    <0.9999855, -0.0053530, 0.0004962>,
    <0.9999855, -0.0053530, 0.0005117>,
    <0.9999855, -0.0053530, 0.0005117>,
    <0.9999855, -0.0053530, 0.0005272>,
    <0.9999856, -0.0053367, 0.0005427>,
    <0.9999855, -0.0053530, 0.0005272>,
    <0.9999855, -0.0053530, 0.0005427>,
    <0.9999855, -0.0053530, 0.0005427>,
    <0.9999855, -0.0053530, 0.0005582>,
    <0.9999856, -0.0053367, 0.0005582>,
    <0.9999856, -0.0053367, 0.0005582>,
    <0.9999857, -0.0053205, 0.0005582>,
    <-0.9854586, 0.0042136, -0.1698632>,
    <-0.9854591, 0.0045447, -0.1698520>,
    <-0.9862561, 0.0045484, -0.1651611>,
    <-0.9862541, 0.0042170, -0.1651822>,
    <-0.9862519, 0.0038870, -0.1652032>,
    <-0.9854581, 0.0038838, -0.1698744>,
    <-0.9854581, 0.0038838, -0.1698744>,
    <-0.9846435, 0.0038806, -0.1745342>,
    <-0.9846424, 0.0042101, -0.1745327>,
    <-0.9846424, 0.0042101, -0.1745327>,
    <-0.9846412, 0.0045409, -0.1745313>,
    <-0.9854595, 0.0048772, -0.1698406>,
    <-0.9862581, 0.0048812, -0.1651398>,
    <-0.9846412, 0.0045409, -0.1745313>,
    <-0.9846398, 0.0048732, -0.1745298>,
    <-0.9846398, 0.0048732, -0.1745298>,
    <-0.9846384, 0.0052068, -0.1745284>,
    <-0.9854597, 0.0052112, -0.1698292>,
    <-0.9854597, 0.0052112, -0.1698292>,
    <-0.9862599, 0.0052154, -0.1651185>,
    <-0.9870355, 0.0048850, -0.1604278>,
    <-0.9870320, 0.0045520, -0.1604590>,
    <-0.9862599, 0.0052154, -0.1651185>,
    <-0.9870389, 0.0052195, -0.1603964>,
    <-0.9870389, 0.0052195, -0.1603964>,
    <-0.9877964, 0.0052235, -0.1556633>,
    <-0.9877915, 0.0048888, -0.1557047>,
    <-0.9877915, 0.0048888, -0.1557047>,
    <-0.9877866, 0.0045554, -0.1557459>,
    <-0.9870284, 0.0042203, -0.1604900>,
    <-0.9877866, 0.0045554, -0.1557459>,
    <-0.9877817, 0.0042235, -0.1557869>,
    <-0.9877817, 0.0042235, -0.1557869>,
    <-0.9877766, 0.0038930, -0.1558277>,
    <-0.9870248, 0.0038900, -0.1605209>,
    <-0.9870248, 0.0038900, -0.1605209>,
    <-0.9862519, 0.0038870, -0.1652032>,
    <0.9999922, -0.0039402, 0.0000088>,
    <0.9999922, -0.0039402, 0.0000085>,
    <0.9999922, -0.0039405, 0.0000085>,
    <0.9999922, -0.0039405, 0.0000088>,
    <0.9999922, -0.0039405, 0.0000090>,
    <0.9999922, -0.0039402, 0.0000090>,
    <0.9999922, -0.0039402, 0.0000090>,
    <0.9999922, -0.0039398, 0.0000090>,
    <0.9999922, -0.0039398, 0.0000088>,
    <0.9999922, -0.0039398, 0.0000088>,
    <0.9999922, -0.0039398, 0.0000085>,
    <0.9999922, -0.0039402, 0.0000083>,
    <0.9999922, -0.0039405, 0.0000083>,
    <0.9999922, -0.0039398, 0.0000085>,
    <0.9999922, -0.0039398, 0.0000083>,
    <0.9999922, -0.0039398, 0.0000083>,
    <0.9999922, -0.0039398, 0.0000080>,
    <0.9999922, -0.0039402, 0.0000080>,
    <0.9999922, -0.0039402, 0.0000080>,
    <0.9999922, -0.0039405, 0.0000080>,
    <0.9999922, -0.0039408, 0.0000083>,
    <0.9999922, -0.0039408, 0.0000085>,
    <0.9999922, -0.0039405, 0.0000080>,
    <0.9999922, -0.0039408, 0.0000080>,
    <0.9999922, -0.0039408, 0.0000080>,
    <0.9999922, -0.0039411, 0.0000080>,
    <0.9999922, -0.0039411, 0.0000083>,
    <0.9999922, -0.0039411, 0.0000083>,
    <0.9999922, -0.0039411, 0.0000085>,
    <0.9999922, -0.0039408, 0.0000088>,
    <0.9999922, -0.0039411, 0.0000085>,
    <0.9999922, -0.0039411, 0.0000088>,
    <0.9999922, -0.0039411, 0.0000088>,
    <0.9999922, -0.0039411, 0.0000090>,
    <0.9999922, -0.0039408, 0.0000090>,
    <0.9999922, -0.0039408, 0.0000090>,
    <0.9999922, -0.0039405, 0.0000090>,
    <-0.9985825, 0.0037869, -0.0530916>,
    <-0.9985823, 0.0038360, -0.0530911>,
    <-0.9986607, 0.0038363, -0.0515947>,
    <-0.9986609, 0.0037872, -0.0515957>,
    <-0.9986610, 0.0037381, -0.0515966>,
    <-0.9985826, 0.0037379, -0.0530922>,
    <-0.9985826, 0.0037379, -0.0530922>,
    <-0.9985020, 0.0037375, -0.0545873>,
    <-0.9985018, 0.0037866, -0.0545872>,
    <-0.9985018, 0.0037866, -0.0545872>,
    <-0.9985016, 0.0038357, -0.0545872>,
    <-0.9985821, 0.0038851, -0.0530906>,
    <-0.9986606, 0.0038854, -0.0515937>,
    <-0.9985016, 0.0038357, -0.0545872>,
    <-0.9985015, 0.0038848, -0.0545871>,
    <-0.9985015, 0.0038848, -0.0545871>,
    <-0.9985013, 0.0039340, -0.0545870>,
    <-0.9985820, 0.0039343, -0.0530900>,
    <-0.9985820, 0.0039343, -0.0530900>,
    <-0.9986605, 0.0039346, -0.0515927>,
    <-0.9987368, 0.0038857, -0.0500964>,
    <-0.9987369, 0.0038366, -0.0500979>,
    <-0.9986605, 0.0039346, -0.0515927>,
    <-0.9987367, 0.0039349, -0.0500950>,
    <-0.9987367, 0.0039349, -0.0500950>,
    <-0.9988107, 0.0039352, -0.0485970>,
    <-0.9988108, 0.0038860, -0.0485989>,
    <-0.9988108, 0.0038860, -0.0485989>,
    <-0.9988109, 0.0038369, -0.0486008>,
    <-0.9987371, 0.0037875, -0.0500993>,
    <-0.9988109, 0.0038369, -0.0486008>,
    <-0.9988110, 0.0037878, -0.0486027>,
    <-0.9988110, 0.0037878, -0.0486027>,
    <-0.9988111, 0.0037387, -0.0486046>,
    <-0.9987372, 0.0037384, -0.0501008>,
    <-0.9987372, 0.0037384, -0.0501008>,
    <-0.9986610, 0.0037381, -0.0515966>,
    <0.9999276, -0.0032544, 0.0115811>,
    <0.9999358, -0.0034415, 0.0107958>,
    <0.9999240, -0.0035381, 0.0118089>,
    <0.9999178, -0.0034929, 0.0123358>,
    <0.9999097, -0.0034849, 0.0129794>,
    <0.9999106, -0.0032244, 0.0129795>,
    <0.9999106, -0.0032244, 0.0129795>,
    <0.9999646, -0.0024797, 0.0080458>,
    <0.9999654, -0.0028107, 0.0078261>,
    <0.9999654, -0.0033789, 0.0076047>,
    <0.9999348, -0.0036391, 0.0108258>,
    <0.9999265, -0.0035893, 0.0115841>,
    <0.9999650, -0.0039259, 0.0073818>,
    <0.9999653, -0.0042642, 0.0071586>,
    <0.9999264, -0.0036959, 0.0115539>,
    <0.9999264, -0.0036959, 0.0115539>,
    <0.9999267, -0.0036067, 0.0115547>,
    <0.9999233, -0.0036465, 0.0118321>,
    <0.9999195, -0.0036404, 0.0121589>,
    <0.9999267, -0.0036067, 0.0115547>,
    <0.9999266, -0.0036490, 0.0115543>,
    <0.9999266, -0.0036490, 0.0115543>,
    <0.9999263, -0.0037429, 0.0115535>,
    <0.9999221, -0.0037429, 0.0119099>,
    <0.9999221, -0.0037429, 0.0119099>,
    <0.9999178, -0.0037428, 0.0122664>,
    <0.9999146, -0.0036349, 0.0125541>,
    <0.9999178, -0.0037428, 0.0122664>,
    <0.9999133, -0.0037428, 0.0126229>,
    <0.9999133, -0.0037428, 0.0126229>,
    <0.9999088, -0.0037428, 0.0129793>,
    <0.9999092, -0.0036337, 0.0129794>,
    <0.9999092, -0.0036337, 0.0129794>,
    <0.9999097, -0.0034849, 0.0129794>,
    <0.9999849, -0.0027128, -0.0047826>,
    <0.9997493, -0.0030727, -0.0221785>,
    <0.9998697, -0.0033997, -0.0157798>,
    <0.9999940, -0.0033727, -0.0008490>,
    <0.9999646, -0.0024797, 0.0080458>,
    <0.9989183, -0.0006460, -0.0464959>,
    <0.9989183, -0.0006460, -0.0464959>,
    <0.9989149, -0.0026967, -0.0464937>,
    <0.9992988, -0.0033746, -0.0372896>,
    <0.9994410, -0.0034314, -0.0332538>,
    <0.9989149, -0.0026967, -0.0464937>,
    <0.9989130, -0.0033421, -0.0464930>,
    <0.9989130, -0.0033421, -0.0464930>,
    <0.9989126, -0.0034626, -0.0464929>,
    <0.9989710, -0.0034628, -0.0452206>,
    <0.9989710, -0.0034628, -0.0452206>,
    <0.9990278, -0.0034630, -0.0439482>,
    <0.9993791, -0.0034851, -0.0350620>,
    <0.9997818, -0.0037128, -0.0205559>,
    <0.9990278, -0.0034630, -0.0439482>,
    <0.9990830, -0.0034632, -0.0426755>,
    <0.9990830, -0.0034632, -0.0426755>,
    <0.9991365, -0.0034634, -0.0414027>,
    <0.9991364, -0.0035109, -0.0414011>,
    <0.9991364, -0.0035109, -0.0414011>,
    <0.9991352, -0.0040414, -0.0413835>,
    <0.9999833, -0.0040033, -0.0041727>,
    <0.9991352, -0.0040414, -0.0413835>,
    <0.9991287, -0.0058511, -0.0413234>,
    <0.9991287, -0.0058511, -0.0413234>,
    <0.9999653, -0.0042642, 0.0071586>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9514469>,
    <0.4350651, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289899, 0.9514833>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9514469>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6558680, 0.9657316>,
    <0.6289899, 0.9514833>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4350651, 0.9657316>,
    <0.5000060, 0.9664308>,
    <0.4264138, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379435, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664308>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6558680, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773611, 0.9671308>,
    <0.6379435, 0.9664312>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4264138, 0.9671308>,
    <0.5000061, 0.9783560>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473388, 0.9783062>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9783560>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773611, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473388, 0.9783062>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032661, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458873>,
    <0.4677608, 0.9457659>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9514469>,
    <0.4355157, 0.9458873>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9453040>,
    <0.4677604, 0.9520314>,
    <0.4676476, 0.9588815>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9514469>,
    <0.5000059, 0.9657316>,
    <0.4350651, 0.9657316>,
    <0.4677604, 0.9520314>,
    <0.5000059, 0.9584281>,
    <0.4675322, 0.9657316>,
    <0.4353104, 0.9585559>,
    <0.4031531, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4350651, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4353104, 0.9585559>,
    <0.4024494, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032661, 0.9526160>,
    <0.5322510, 0.9457659>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9514469>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9520314>,
    <0.5000059, 0.9453040>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458724>,
    <0.5967411, 0.9457750>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289899, 0.9514833>,
    <0.5644961, 0.9458724>,
    <0.5967380, 0.9395004>,
    <0.6289859, 0.9453225>,
    <0.5967441, 0.9520496>,
    <0.5967475, 0.9588906>,
    <0.5644983, 0.9526160>,
    <0.6289899, 0.9514833>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967441, 0.9520496>,
    <0.6289945, 0.9584819>,
    <0.5967509, 0.9657316>,
    <0.5645004, 0.9590395>,
    <0.5322532, 0.9588815>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9514469>,
    <0.5645004, 0.9590395>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9584281>,
    <0.5322521, 0.9520314>,
    <0.6423395, 0.9457750>,
    <0.6556982, 0.9526160>,
    <0.6289899, 0.9514833>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423437, 0.9520496>,
    <0.6289859, 0.9453225>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458875>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458875>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690524, 0.9526160>,
    <0.6690975, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6558680, 0.9657316>,
    <0.6690524, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6693589, 0.9657316>,
    <0.6557753, 0.9585675>,
    <0.6423888, 0.9588906>,
    <0.6556982, 0.9526160>,
    <0.6558680, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289899, 0.9514833>,
    <0.6557753, 0.9585675>,
    <0.6424344, 0.9657316>,
    <0.6289945, 0.9584819>,
    <0.6423437, 0.9520496>,
    <0.3997957, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4350651, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4024494, 0.9657316>,
    <0.4330699, 0.9660781>,
    <0.4665285, 0.9660813>,
    <0.4310370, 0.9664312>,
    <0.4350651, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664308>,
    <0.4330699, 0.9660781>,
    <0.4675322, 0.9657316>,
    <0.5000060, 0.9661017>,
    <0.4655215, 0.9664310>,
    <0.4643657, 0.9667809>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664308>,
    <0.5000061, 0.9671308>,
    <0.4264138, 0.9671308>,
    <0.4655215, 0.9664310>,
    <0.5000060, 0.9667580>,
    <0.4632045, 0.9671308>,
    <0.4287683, 0.9667745>,
    <0.3931605, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4264138, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4287683, 0.9667745>,
    <0.3895841, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660813>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664308>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664310>,
    <0.5000060, 0.9661017>,
    <0.5322542, 0.9657316>,
    <0.5668714, 0.9661021>,
    <0.6001051, 0.9660814>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379435, 0.9664312>,
    <0.5668714, 0.9661021>,
    <0.5967509, 0.9657316>,
    <0.6337414, 0.9661025>,
    <0.6034593, 0.9664312>,
    <0.6068137, 0.9667810>,
    <0.5689750, 0.9664312>,
    <0.6379435, 0.9664312>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034593, 0.9664312>,
    <0.6421204, 0.9667579>,
    <0.6101681, 0.9671308>,
    <0.5710646, 0.9667581>,
    <0.5356086, 0.9667809>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664308>,
    <0.5710646, 0.9667581>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667580>,
    <0.5344905, 0.9664310>,
    <0.6473290, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6379435, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6558680, 0.9657316>,
    <0.6522245, 0.9664312>,
    <0.6337414, 0.9661025>,
    <0.6424344, 0.9657316>,
    <0.6611598, 0.9660796>,
    <0.6749645, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6558680, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6611598, 0.9660796>,
    <0.6693589, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866623, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773611, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926092, 0.9671308>,
    <0.6718162, 0.9667735>,
    <0.6571747, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6773611, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379435, 0.9664312>,
    <0.6718162, 0.9667735>,
    <0.6621272, 0.9671308>,
    <0.6421204, 0.9667579>,
    <0.6522245, 0.9664312>,
    <0.3896458, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4264138, 0.9671308>,
    <0.3895222, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3895841, 0.9671308>,
    <0.4263799, 0.9728535>,
    <0.4631942, 0.9725944>,
    <0.4263507, 0.9777601>,
    <0.4264138, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9783560>,
    <0.4263799, 0.9728535>,
    <0.4632045, 0.9671308>,
    <0.5000061, 0.9726513>,
    <0.4631779, 0.9780581>,
    <0.4631249, 0.9832238>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9783560>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631779, 0.9780581>,
    <0.5000061, 0.9834929>,
    <0.4630714, 0.9883895>,
    <0.4262411, 0.9832062>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262411, 0.9832062>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895222, 0.9777601>,
    <0.5367803, 0.9725944>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9783560>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9780581>,
    <0.5000061, 0.9726513>,
    <0.5367268, 0.9671308>,
    <0.5735524, 0.9723450>,
    <0.6103341, 0.9725820>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473388, 0.9783062>,
    <0.5735524, 0.9723450>,
    <0.6101681, 0.9671308>,
    <0.6471088, 0.9725940>,
    <0.6105001, 0.9780332>,
    <0.6106551, 0.9832113>,
    <0.5736614, 0.9777601>,
    <0.6473388, 0.9783062>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105001, 0.9780332>,
    <0.6475465, 0.9834662>,
    <0.6108101, 0.9883895>,
    <0.5737710, 0.9832010>,
    <0.5368873, 0.9832238>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9783560>,
    <0.5737710, 0.9832010>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9834929>,
    <0.5368338, 0.9780581>,
    <0.6623519, 0.9725820>,
    <0.6778190, 0.9777601>,
    <0.6473388, 0.9783062>,
    <0.6468888, 0.9671308>,
    <0.6773611, 0.9671308>,
    <0.6625791, 0.9780332>,
    <0.6471088, 0.9725940>,
    <0.6621272, 0.9671308>,
    <0.6776070, 0.9728395>,
    <0.6928043, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773611, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776070, 0.9728395>,
    <0.6926092, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930704, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930704, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780836, 0.9832055>,
    <0.6628095, 0.9832113>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473388, 0.9783062>,
    <0.6780836, 0.9832055>,
    <0.6630402, 0.9883895>,
    <0.6475465, 0.9834662>,
    <0.6625791, 0.9780332>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.046223, 0.731795, -0.147353>
}

#declare TMesh011 = mesh2 {
  vertex_vectors {
    582,
    <2.2037408, 0.3609944, 18.5058918>,
    <2.0021506, 0.3609820, 18.5058918>,
    <2.0021672, 0.2806104, 18.5058918>,
    <2.2037549, 0.2806255, 18.5058918>,
    <2.1029457, 0.3609882, 18.5058918>,
    <2.0021589, 0.3207962, 18.5058918>,
    <2.1029610, 0.2806180, 18.5058918>,
    <2.2037479, 0.3208099, 18.5058918>,
    <2.1029534, 0.3208031, 18.5058918>,
    <2.4053426, 0.2806405, 18.5058918>,
    <2.4053311, 0.3610067, 18.5058918>,
    <2.3045487, 0.2806330, 18.5058918>,
    <2.4053368, 0.3208236, 18.5058918>,
    <2.3045360, 0.3610006, 18.5058918>,
    <2.3045424, 0.3208168, 18.5058918>,
    <2.4053196, 0.4413729, 18.5058918>,
    <2.2037268, 0.4413633, 18.5058918>,
    <2.4053254, 0.4011898, 18.5058918>,
    <2.3045232, 0.4413681, 18.5058918>,
    <2.2037338, 0.4011788, 18.5058918>,
    <2.3045296, 0.4011843, 18.5058918>,
    <2.0021340, 0.4413536, 18.5058918>,
    <2.1029304, 0.4413585, 18.5058918>,
    <2.0021423, 0.4011678, 18.5058918>,
    <2.1029381, 0.4011733, 18.5058918>,
    <2.0661631, 0.2804708, 18.1207908>,
    <2.0044034, 0.2804603, 18.1202395>,
    <2.0044687, 0.2804559, 18.1217627>,
    <2.0559641, 0.2804663, 18.1217627>,
    <2.0352833, 0.2804656, 18.1205151>,
    <2.0044361, 0.2804581, 18.1210011>,
    <2.0302164, 0.2804611, 18.1217627>,
    <2.0610636, 0.2804686, 18.1212767>,
    <2.0327498, 0.2804633, 18.1211389>,
    <2.1074595, 0.2804767, 18.1217627>,
    <2.1279227, 0.2804813, 18.1213420>,
    <2.0817118, 0.2804715, 18.1217627>,
    <2.1176911, 0.2804790, 18.1215524>,
    <2.0970429, 0.2804761, 18.1210664>,
    <2.0893774, 0.2804738, 18.1214145>,
    <2.1483859, 0.2804860, 18.1209214>,
    <2.0763621, 0.2804753, 18.1198188>,
    <2.1381543, 0.2804837, 18.1211317>,
    <2.1123740, 0.2804807, 18.1203701>,
    <2.0712626, 0.2804731, 18.1203048>,
    <2.1047085, 0.2804784, 18.1207182>,
    <2.0043382, 0.2804647, 18.1187163>,
    <2.0403501, 0.2804700, 18.1192675>,
    <2.0043708, 0.2804625, 18.1194779>,
    <2.0378167, 0.2804678, 18.1198913>,
    <2.1279101, 0.3610088, 18.1213420>,
    <2.1074469, 0.3610088, 18.1217627>,
    <2.1279164, 0.3207451, 18.1213420>,
    <2.1074532, 0.3207428, 18.1217627>,
    <2.1176785, 0.3610088, 18.1215524>,
    <2.1176848, 0.3207439, 18.1215524>,
    <2.1074342, 0.4415410, 18.1217627>,
    <2.1278975, 0.4415362, 18.1213420>,
    <2.1074405, 0.4012749, 18.1217627>,
    <2.1176659, 0.4415386, 18.1215524>,
    <2.1279038, 0.4012725, 18.1213420>,
    <2.1176722, 0.4012737, 18.1215524>,
    <2.1483608, 0.4415314, 18.1209214>,
    <2.1483734, 0.3610087, 18.1209214>,
    <2.1381291, 0.4415338, 18.1211317>,
    <2.1483671, 0.4012701, 18.1209214>,
    <2.1381417, 0.3610087, 18.1211317>,
    <2.1381354, 0.4012713, 18.1211317>,
    <2.1483797, 0.3207473, 18.1209214>,
    <2.1381480, 0.3207462, 18.1211317>,
    <2.0661338, 0.4415300, 18.1207908>,
    <2.0559348, 0.4415349, 18.1217627>,
    <2.0970156, 0.4415331, 18.1210664>,
    <2.0816845, 0.4415379, 18.1217627>,
    <2.0610343, 0.4415324, 18.1212767>,
    <2.0893501, 0.4415355, 18.1214145>,
    <2.0044353, 0.4415288, 18.1217627>,
    <2.0043701, 0.4415238, 18.1202395>,
    <2.0301850, 0.4415318, 18.1217627>,
    <2.0044027, 0.4415263, 18.1210011>,
    <2.0352519, 0.4415269, 18.1205151>,
    <2.0327185, 0.4415294, 18.1211389>,
    <2.0043048, 0.4415189, 18.1187163>,
    <2.0763328, 0.4415251, 18.1198188>,
    <2.0043374, 0.4415214, 18.1194779>,
    <2.0403188, 0.4415220, 18.1192675>,
    <2.0712333, 0.4415276, 18.1203048>,
    <2.0377853, 0.4415245, 18.1198913>,
    <2.1123468, 0.4415283, 18.1203701>,
    <2.1046812, 0.4415307, 18.1207182>,
    <2.0763690, 0.2804848, 18.1376413>,
    <2.0042020, 0.2804738, 18.1370901>,
    <2.0402855, 0.2804793, 18.1373657>,
    <2.0042701, 0.2804693, 18.1279032>,
    <2.0763655, 0.2804801, 18.1287301>,
    <2.0403178, 0.2804747, 18.1283166>,
    <2.1485360, 0.2804957, 18.1381926>,
    <2.1484610, 0.2804908, 18.1295570>,
    <2.1124525, 0.2804902, 18.1379170>,
    <2.1124133, 0.2804854, 18.1291435>,
    <2.1486861, 0.2805054, 18.1554639>,
    <2.0763760, 0.2804942, 18.1554639>,
    <2.1486111, 0.2805005, 18.1468283>,
    <2.1125311, 0.2804998, 18.1554639>,
    <2.0763725, 0.2804895, 18.1465526>,
    <2.1124918, 0.2804950, 18.1466904>,
    <2.0040659, 0.2804830, 18.1554639>,
    <2.0402210, 0.2804886, 18.1554639>,
    <2.0041340, 0.2804784, 18.1462770>,
    <2.0402533, 0.2804839, 18.1464148>,
    <2.1485235, 0.3610086, 18.1381926>,
    <2.1485298, 0.3207521, 18.1381926>,
    <2.1484484, 0.3610086, 18.1295570>,
    <2.1484547, 0.3207497, 18.1295570>,
    <2.1485110, 0.4415215, 18.1381926>,
    <2.1484359, 0.4415265, 18.1295570>,
    <2.1485173, 0.4012650, 18.1381926>,
    <2.1484422, 0.4012676, 18.1295570>,
    <2.1486612, 0.4415115, 18.1554639>,
    <2.1486737, 0.3610085, 18.1554639>,
    <2.1485861, 0.4415165, 18.1468283>,
    <2.1486675, 0.4012600, 18.1554639>,
    <2.1485986, 0.3610085, 18.1468283>,
    <2.1485924, 0.4012625, 18.1468283>,
    <2.1486799, 0.3207569, 18.1554639>,
    <2.1486048, 0.3207545, 18.1468283>,
    <2.0763398, 0.4415150, 18.1376413>,
    <2.1124254, 0.4415182, 18.1379170>,
    <2.0763363, 0.4415201, 18.1287301>,
    <2.1123861, 0.4415233, 18.1291435>,
    <2.0041687, 0.4415085, 18.1370901>,
    <2.0042367, 0.4415137, 18.1279032>,
    <2.0402543, 0.4415118, 18.1373657>,
    <2.0402865, 0.4415169, 18.1283166>,
    <2.0040326, 0.4414981, 18.1554639>,
    <2.0763469, 0.4415048, 18.1554639>,
    <2.0041006, 0.4415033, 18.1462770>,
    <2.0401897, 0.4415015, 18.1554639>,
    <2.0763434, 0.4415099, 18.1465526>,
    <2.0402220, 0.4415066, 18.1464148>,
    <2.1125041, 0.4415082, 18.1554639>,
    <2.1124647, 0.4415132, 18.1466904>,
    <2.0812641, 0.2805008, 18.1573801>,
    <2.0039695, 0.2804894, 18.1573801>,
    <2.0426168, 0.2804951, 18.1573801>,
    <2.0040177, 0.2804862, 18.1564220>,
    <2.0788201, 0.2804975, 18.1564220>,
    <2.0414189, 0.2804919, 18.1564220>,
    <2.1585588, 0.2805122, 18.1573801>,
    <2.1536225, 0.2805088, 18.1564220>,
    <2.1199115, 0.2805065, 18.1573801>,
    <2.1162213, 0.2805032, 18.1564220>,
    <2.1684314, 0.2805191, 18.1592964>,
    <2.0861522, 0.2805075, 18.1592964>,
    <2.1634951, 0.2805157, 18.1583383>,
    <2.1272918, 0.2805133, 18.1592964>,
    <2.0837082, 0.2805042, 18.1583383>,
    <2.1236016, 0.2805099, 18.1583383>,
    <2.0038730, 0.2804959, 18.1592964>,
    <2.0450126, 0.2805017, 18.1592964>,
    <2.0039212, 0.2804927, 18.1583383>,
    <2.0438147, 0.2804984, 18.1583383>,
    <2.1585464, 0.3610084, 18.1573801>,
    <2.1585526, 0.3207603, 18.1573801>,
    <2.1536100, 0.3610084, 18.1564220>,
    <2.1536162, 0.3207586, 18.1564220>,
    <2.1585340, 0.4415045, 18.1573801>,
    <2.1535976, 0.4415080, 18.1564220>,
    <2.1585402, 0.4012564, 18.1573801>,
    <2.1536038, 0.4012582, 18.1564220>,
    <2.1684068, 0.4414975, 18.1592964>,
    <2.1684191, 0.3610083, 18.1592964>,
    <2.1634704, 0.4415010, 18.1583383>,
    <2.1684129, 0.4012529, 18.1592964>,
    <2.1634827, 0.3610083, 18.1583383>,
    <2.1634766, 0.4012547, 18.1583383>,
    <2.1684253, 0.3207637, 18.1592964>,
    <2.1634889, 0.3207620, 18.1583383>,
    <2.0812351, 0.4414977, 18.1573801>,
    <2.1198845, 0.4415011, 18.1573801>,
    <2.0787910, 0.4415013, 18.1564220>,
    <2.1161943, 0.4415046, 18.1564220>,
    <2.0039361, 0.4414908, 18.1573801>,
    <2.0039844, 0.4414945, 18.1564220>,
    <2.0425856, 0.4414942, 18.1573801>,
    <2.0413877, 0.4414979, 18.1564220>,
    <2.0038397, 0.4414835, 18.1592964>,
    <2.0861232, 0.4414905, 18.1592964>,
    <2.0038879, 0.4414871, 18.1583383>,
    <2.0449814, 0.4414870, 18.1592964>,
    <2.0836791, 0.4414941, 18.1583383>,
    <2.0437835, 0.4414906, 18.1583383>,
    <2.1272650, 0.4414940, 18.1592964>,
    <2.1235748, 0.4414975, 18.1583383>,
    <2.0877082, 0.2805088, 18.2324892>,
    <2.0038724, 0.2804960, 18.2344341>,
    <2.0457890, 0.2805025, 18.2333227>,
    <2.0038727, 0.2804959, 18.1968653>,
    <2.0861681, 0.2805075, 18.1968653>,
    <2.0450204, 0.2805017, 18.1968653>,
    <2.1715593, 0.2805206, 18.2322113>,
    <2.1684634, 0.2805191, 18.1968653>,
    <2.1296325, 0.2805148, 18.2322113>,
    <2.1273157, 0.2805133, 18.1968653>,
    <2.1991981, 0.2805337, 18.2873438>,
    <2.1014482, 0.2805207, 18.2890109>,
    <2.1807829, 0.2805250, 18.2631118>,
    <2.1503155, 0.2805277, 18.2873438>,
    <2.0922969, 0.2805125, 18.2642232>,
    <2.1365348, 0.2805191, 18.2631118>,
    <2.0038718, 0.2804960, 18.3095719>,
    <2.0526115, 0.2805116, 18.2940122>,
    <2.0038721, 0.2804960, 18.2720030>,
    <2.0480794, 0.2805046, 18.2675574>,
    <2.1715469, 0.3610083, 18.2322113>,
    <2.1715531, 0.3207644, 18.2322113>,
    <2.1684511, 0.3610083, 18.1968653>,
    <2.1684573, 0.3207637, 18.1968653>,
    <2.1715346, 0.4414959, 18.2322113>,
    <2.1684387, 0.4414974, 18.1968653>,
    <2.1715408, 0.4012521, 18.2322113>,
    <2.1684449, 0.4012529, 18.1968653>,
    <2.1991737, 0.4414825, 18.2873438>,
    <2.1991859, 0.3610081, 18.2873438>,
    <2.1807583, 0.4414914, 18.2631118>,
    <2.1991798, 0.4012453, 18.2873438>,
    <2.1807706, 0.3610082, 18.2631118>,
    <2.1807644, 0.4012498, 18.2631118>,
    <2.1991920, 0.3207709, 18.2873438>,
    <2.1807767, 0.3207666, 18.2631118>,
    <2.0876792, 0.4414891, 18.2324892>,
    <2.1296056, 0.4414924, 18.2322113>,
    <2.0861391, 0.4414904, 18.1968653>,
    <2.1272889, 0.4414939, 18.1968653>,
    <2.0038391, 0.4414834, 18.2344341>,
    <2.0038394, 0.4414834, 18.1968653>,
    <2.0457578, 0.4414862, 18.2333227>,
    <2.0449892, 0.4414869, 18.1968653>,
    <2.0038384, 0.4414834, 18.3095719>,
    <2.1014193, 0.4414763, 18.2890109>,
    <2.0038387, 0.4414834, 18.2720030>,
    <2.0525804, 0.4414761, 18.2940122>,
    <2.0922679, 0.4414851, 18.2642232>,
    <2.0480482, 0.4414838, 18.2675574>,
    <2.1502888, 0.4414788, 18.2873438>,
    <2.1365080, 0.4414879, 18.2631118>,
    <2.1349912, 0.2805529, 18.3131904>,
    <2.0032176, 0.2805399, 18.3135798>,
    <2.0691044, 0.2805464, 18.3133573>,
    <2.0035447, 0.2805180, 18.3115759>,
    <2.1166762, 0.2805352, 18.3037960>,
    <2.0601053, 0.2805269, 18.3071303>,
    <2.2667655, 0.2805658, 18.3131347>,
    <2.2298689, 0.2805483, 18.3026846>,
    <2.2008783, 0.2805594, 18.3131347>,
    <2.1732674, 0.2805421, 18.3026846>,
    <2.3351178, 0.2805985, 18.3353648>,
    <2.1689234, 0.2805856, 18.3340315>,
    <2.3038584, 0.2805835, 18.3226946>,
    <2.2520279, 0.2805915, 18.3353648>,
    <2.1534037, 0.2805707, 18.3218058>,
    <2.2286359, 0.2805768, 18.3226946>,
    <2.0025635, 0.2805838, 18.3175878>,
    <2.0857897, 0.2805816, 18.3300317>,
    <2.0028906, 0.2805619, 18.3155838>,
    <2.0781520, 0.2805660, 18.3191392>,
    <2.2667535, 0.3610077, 18.3131347>,
    <2.2667595, 0.3207868, 18.3131347>,
    <2.2298568, 0.3610079, 18.3026846>,
    <2.2298628, 0.3207781, 18.3026846>,
    <2.2667415, 0.4414495, 18.3131347>,
    <2.2298446, 0.4414675, 18.3026846>,
    <2.2667475, 0.4012286, 18.3131347>,
    <2.2298507, 0.4012377, 18.3026846>,
    <2.3350943, 0.4414161, 18.3353648>,
    <2.3351060, 0.3610073, 18.3353648>,
    <2.3038346, 0.4414314, 18.3226946>,
    <2.3351001, 0.4012117, 18.3353648>,
    <2.3038465, 0.3610075, 18.3226946>,
    <2.3038406, 0.4012194, 18.3226946>,
    <2.3351119, 0.3208029, 18.3353648>,
    <2.3038524, 0.3207955, 18.3226946>,
    <2.1349626, 0.4414415, 18.3131904>,
    <2.2008520, 0.4414455, 18.3131347>,
    <2.1166474, 0.4414607, 18.3037960>,
    <2.1732409, 0.4414637, 18.3026846>,
    <2.0031844, 0.4414336, 18.3135798>,
    <2.0035114, 0.4414585, 18.3115759>,
    <2.0690734, 0.4414376, 18.3133573>,
    <2.0600743, 0.4414592, 18.3071303>,
    <2.0025303, 0.4413838, 18.3175878>,
    <2.1688950, 0.4414062, 18.3340315>,
    <2.0028573, 0.4414087, 18.3155838>,
    <2.0857589, 0.4413985, 18.3300317>,
    <2.1533752, 0.4414223, 18.3218058>,
    <2.0781211, 0.4414159, 18.3191392>,
    <2.2520019, 0.4414117, 18.3353648>,
    <2.2286098, 0.4414272, 18.3226946>,
    <2.1837800, 0.2805991, 18.3800376>,
    <2.0025322, 0.2805859, 18.3784821>,
    <2.0931573, 0.2805924, 18.3793709>,
    <2.0025479, 0.2805849, 18.3480349>,
    <2.1785602, 0.2805944, 18.3542569>,
    <2.0905589, 0.2805893, 18.3515903>,
    <2.3650132, 0.2806132, 18.3802598>,
    <2.3545142, 0.2806079, 18.3551457>,
    <2.2743978, 0.2806060, 18.3802598>,
    <2.2665420, 0.2806008, 18.3551457>,
    <2.3711824, 0.2806168, 18.4393764>,
    <2.1868417, 0.2806024, 18.4393764>,
    <2.3695807, 0.2806157, 18.4089292>,
    <2.2790121, 0.2806096, 18.4393764>,
    <2.1860486, 0.2806013, 18.4089292>,
    <2.2778147, 0.2806085, 18.4089292>,
    <2.0025009, 0.2805880, 18.4393764>,
    <2.0946713, 0.2805952, 18.4393764>,
    <2.0025166, 0.2805870, 18.4089292>,
    <2.0942826, 0.2805942, 18.4089292>,
    <2.3650015, 0.3610071, 18.3802598>,
    <2.3650074, 0.3208101, 18.3802598>,
    <2.3545024, 0.3610071, 18.3551457>,
    <2.3545083, 0.3208075, 18.3551457>,
    <2.3649899, 0.4414010, 18.3802598>,
    <2.3544907, 0.4414064, 18.3551457>,
    <2.3649957, 0.4012040, 18.3802598>,
    <2.3544966, 0.4012068, 18.3551457>,
    <2.3711592, 0.4413973, 18.4393764>,
    <2.3711708, 0.3610070, 18.4393764>,
    <2.3695574, 0.4413984, 18.4089292>,
    <2.3711650, 0.4012022, 18.4393764>,
    <2.3695691, 0.3610070, 18.4089292>,
    <2.3695632, 0.4012027, 18.4089292>,
    <2.3711766, 0.3208119, 18.4393764>,
    <2.3695749, 0.3208114, 18.4089292>,
    <2.1837517, 0.4413918, 18.3800376>,
    <2.2743720, 0.4413965, 18.3802598>,
    <2.1785319, 0.4413967, 18.3542569>,
    <2.2665162, 0.4414019, 18.3551457>,
    <2.0024990, 0.4413814, 18.3784821>,
    <2.0025147, 0.4413826, 18.3480349>,
    <2.0931266, 0.4413867, 18.3793709>,
    <2.0905281, 0.4413900, 18.3515903>,
    <2.0024677, 0.4413790, 18.4393764>,
    <2.1868134, 0.4413882, 18.4393764>,
    <2.0024834, 0.4413802, 18.4089292>,
    <2.0946406, 0.4413836, 18.4393764>,
    <2.1860204, 0.4413893, 18.4089292>,
    <2.0942519, 0.4413848, 18.4089292>,
    <2.2789863, 0.4413927, 18.4393764>,
    <2.2777889, 0.4413939, 18.4089292>,
    <2.1952983, 0.2806139, 18.4393764>,
    <2.0023340, 0.2805992, 18.4393764>,
    <2.0988161, 0.2806066, 18.4393764>,
    <2.0024175, 0.2805936, 18.4393764>,
    <2.1910700, 0.2806082, 18.4393764>,
    <2.0967437, 0.2806009, 18.4393764>,
    <2.3882625, 0.2806287, 18.4393764>,
    <2.3797225, 0.2806227, 18.4393764>,
    <2.2917804, 0.2806213, 18.4393764>,
    <2.2853962, 0.2806154, 18.4393764>,
    <2.4053426, 0.2806405, 18.4393764>,
    <2.2037549, 0.2806255, 18.4393764>,
    <2.3968025, 0.2806346, 18.4393764>,
    <2.3045487, 0.2806330, 18.4393764>,
    <2.1995266, 0.2806197, 18.4393764>,
    <2.2981646, 0.2806272, 18.4393764>,
    <2.0021672, 0.2806104, 18.4393764>,
    <2.1029610, 0.2806180, 18.4393764>,
    <2.0022506, 0.2806048, 18.4393764>,
    <2.1008886, 0.2806123, 18.4393764>,
    <2.3882510, 0.3610069, 18.4393764>,
    <2.3882567, 0.3208178, 18.4393764>,
    <2.3797109, 0.3610070, 18.4393764>,
    <2.3797167, 0.3208148, 18.4393764>,
    <2.3882394, 0.4413851, 18.4393764>,
    <2.3796993, 0.4413912, 18.4393764>,
    <2.3882452, 0.4011960, 18.4393764>,
    <2.3797051, 0.4011991, 18.4393764>,
    <2.4053196, 0.4413729, 18.4393764>,
    <2.4053311, 0.3610067, 18.4393764>,
    <2.3967795, 0.4413790, 18.4393764>,
    <2.4053254, 0.4011898, 18.4393764>,
    <2.3967910, 0.3610068, 18.4393764>,
    <2.3967853, 0.4011929, 18.4393764>,
    <2.4053368, 0.3208236, 18.4393764>,
    <2.3967968, 0.3208207, 18.4393764>,
    <2.1952701, 0.4413757, 18.4393764>,
    <2.2917548, 0.4413804, 18.4393764>,
    <2.1910418, 0.4413819, 18.4393764>,
    <2.2853705, 0.4413866, 18.4393764>,
    <2.0023009, 0.4413663, 18.4393764>,
    <2.0023843, 0.4413727, 18.4393764>,
    <2.0987855, 0.4413710, 18.4393764>,
    <2.0967130, 0.4413773, 18.4393764>,
    <2.0021340, 0.4413536, 18.4393764>,
    <2.2037268, 0.4413633, 18.4393764>,
    <2.0022174, 0.4413600, 18.4393764>,
    <2.1029304, 0.4413585, 18.4393764>,
    <2.1994985, 0.4413695, 18.4393764>,
    <2.1008580, 0.4413647, 18.4393764>,
    <2.3045232, 0.4413681, 18.4393764>,
    <2.2981390, 0.4413742, 18.4393764>,
    <2.2037549, 0.2806255, 18.4726341>,
    <2.0021672, 0.2806104, 18.4726341>,
    <2.1029610, 0.2806180, 18.4726341>,
    <2.0021672, 0.2806104, 18.4560052>,
    <2.2037549, 0.2806255, 18.4560052>,
    <2.1029610, 0.2806180, 18.4560052>,
    <2.4053426, 0.2806405, 18.4726341>,
    <2.4053426, 0.2806405, 18.4560052>,
    <2.3045487, 0.2806330, 18.4726341>,
    <2.3045487, 0.2806330, 18.4560052>,
    <2.4053426, 0.2806405, 18.4892630>,
    <2.2037549, 0.2806255, 18.4892630>,
    <2.3045487, 0.2806330, 18.4892630>,
    <2.0021672, 0.2806104, 18.4892630>,
    <2.1029610, 0.2806180, 18.4892630>,
    <2.4053311, 0.3610067, 18.4726341>,
    <2.4053368, 0.3208236, 18.4726341>,
    <2.4053311, 0.3610067, 18.4560052>,
    <2.4053368, 0.3208236, 18.4560052>,
    <2.4053196, 0.4413729, 18.4726341>,
    <2.4053196, 0.4413729, 18.4560052>,
    <2.4053254, 0.4011898, 18.4726341>,
    <2.4053254, 0.4011898, 18.4560052>,
    <2.4053196, 0.4413729, 18.4892630>,
    <2.4053311, 0.3610067, 18.4892630>,
    <2.4053254, 0.4011898, 18.4892630>,
    <2.4053368, 0.3208236, 18.4892630>,
    <2.2037268, 0.4413633, 18.4726341>,
    <2.3045232, 0.4413681, 18.4726341>,
    <2.2037268, 0.4413633, 18.4560052>,
    <2.3045232, 0.4413681, 18.4560052>,
    <2.0021340, 0.4413536, 18.4726341>,
    <2.0021340, 0.4413536, 18.4560052>,
    <2.1029304, 0.4413585, 18.4726341>,
    <2.1029304, 0.4413585, 18.4560052>,
    <2.0021340, 0.4413536, 18.4892630>,
    <2.2037268, 0.4413633, 18.4892630>,
    <2.1029304, 0.4413585, 18.4892630>,
    <2.3045232, 0.4413681, 18.4892630>,
    <2.0021506, 0.3609820, 18.4726341>,
    <2.0021672, 0.2806104, 18.4726341>,
    <2.0021506, 0.3609820, 18.4393764>,
    <2.0021589, 0.3207962, 18.4726341>,
    <2.0021672, 0.2806104, 18.4560052>,
    <2.0021589, 0.3207962, 18.4393764>,
    <2.0021506, 0.3609820, 18.4560052>,
    <2.0021589, 0.3207962, 18.4560052>,
    <2.0021340, 0.4413536, 18.4726341>,
    <2.0021423, 0.4011678, 18.4393764>,
    <2.0021340, 0.4413536, 18.4560052>,
    <2.0021423, 0.4011678, 18.4726341>,
    <2.0021423, 0.4011678, 18.4560052>,
    <2.0021506, 0.3609820, 18.5058918>,
    <2.0021340, 0.4413536, 18.4892630>,
    <2.0021423, 0.4011678, 18.5058918>,
    <2.0021506, 0.3609820, 18.4892630>,
    <2.0021423, 0.4011678, 18.4892630>,
    <2.0021589, 0.3207962, 18.5058918>,
    <2.0021672, 0.2806104, 18.4892630>,
    <2.0021589, 0.3207962, 18.4892630>,
    <2.0023174, 0.3609828, 18.4393764>,
    <2.0024843, 0.3609835, 18.4393764>,
    <2.0024009, 0.3609832, 18.4393764>,
    <2.0024926, 0.3207858, 18.4393764>,
    <2.0023257, 0.3207910, 18.4393764>,
    <2.0024092, 0.3207884, 18.4393764>,
    <2.0021506, 0.3609820, 18.4393764>,
    <2.0021589, 0.3207962, 18.4393764>,
    <2.0022340, 0.3609824, 18.4393764>,
    <2.0022423, 0.3207936, 18.4393764>,
    <2.0021423, 0.4011678, 18.4393764>,
    <2.0023092, 0.4011746, 18.4393764>,
    <2.0022257, 0.4011712, 18.4393764>,
    <2.0024760, 0.4011813, 18.4393764>,
    <2.0023926, 0.4011779, 18.4393764>,
    <2.0025156, 0.3609837, 18.3784821>,
    <2.0025322, 0.2805859, 18.3784821>,
    <2.0025469, 0.3609838, 18.3175878>,
    <2.0025239, 0.3207848, 18.3784821>,
    <2.0025479, 0.2805849, 18.3480349>,
    <2.0025552, 0.3207838, 18.3175878>,
    <2.0025313, 0.3609837, 18.3480349>,
    <2.0025396, 0.3207843, 18.3480349>,
    <2.0024990, 0.4413814, 18.3784821>,
    <2.0025386, 0.4011838, 18.3175878>,
    <2.0025147, 0.4413826, 18.3480349>,
    <2.0025073, 0.4011825, 18.3784821>,
    <2.0025230, 0.4011832, 18.3480349>,
    <2.0024843, 0.3609835, 18.4393764>,
    <2.0024834, 0.4413802, 18.4089292>,
    <2.0024760, 0.4011813, 18.4393764>,
    <2.0025000, 0.3609836, 18.4089292>,
    <2.0024917, 0.4011819, 18.4089292>,
    <2.0024926, 0.3207858, 18.4393764>,
    <2.0025166, 0.2805870, 18.4089292>,
    <2.0025083, 0.3207853, 18.4089292>,
    <2.0032010, 0.3609868, 18.3135798>,
    <2.0038551, 0.3609897, 18.3095719>,
    <2.0035281, 0.3609882, 18.3115759>,
    <2.0038634, 0.3207428, 18.3095719>,
    <2.0032093, 0.3207633, 18.3135798>,
    <2.0035364, 0.3207531, 18.3115759>,
    <2.0025469, 0.3609838, 18.3175878>,
    <2.0025552, 0.3207838, 18.3175878>,
    <2.0028740, 0.3609853, 18.3155838>,
    <2.0028823, 0.3207736, 18.3155838>,
    <2.0025386, 0.4011838, 18.3175878>,
    <2.0031927, 0.4012102, 18.3135798>,
    <2.0028656, 0.4011970, 18.3155838>,
    <2.0038468, 0.4012365, 18.3095719>,
    <2.0035197, 0.4012233, 18.3115759>,
    <2.0038557, 0.3609897, 18.2344341>,
    <2.0038724, 0.2804960, 18.2344341>,
    <2.0038563, 0.3609897, 18.1592964>,
    <2.0038641, 0.3207428, 18.2344341>,
    <2.0038727, 0.2804959, 18.1968653>,
    <2.0038647, 0.3207428, 18.1592964>,
    <2.0038560, 0.3609897, 18.1968653>,
    <2.0038644, 0.3207428, 18.1968653>,
    <2.0038391, 0.4414834, 18.2344341>,
    <2.0038480, 0.4012366, 18.1592964>,
    <2.0038394, 0.4414834, 18.1968653>,
    <2.0038474, 0.4012366, 18.2344341>,
    <2.0038477, 0.4012366, 18.1968653>,
    <2.0038551, 0.3609897, 18.3095719>,
    <2.0038387, 0.4414834, 18.2720030>,
    <2.0038468, 0.4012365, 18.3095719>,
    <2.0038554, 0.3609897, 18.2720030>,
    <2.0038471, 0.4012365, 18.2720030>,
    <2.0038634, 0.3207428, 18.3095719>,
    <2.0038721, 0.2804960, 18.2720030>,
    <2.0038637, 0.3207428, 18.2720030>,
    <2.0039528, 0.3609901, 18.1573801>,
    <2.0040493, 0.3609906, 18.1554639>,
    <2.0040010, 0.3609903, 18.1564220>,
    <2.0040576, 0.3207368, 18.1554639>,
    <2.0039611, 0.3207398, 18.1573801>,
    <2.0040094, 0.3207383, 18.1564220>,
    <2.0038563, 0.3609897, 18.1592964>,
    <2.0038647, 0.3207428, 18.1592964>,
    <2.0039046, 0.3609899, 18.1583383>,
    <2.0039129, 0.3207413, 18.1583383>,
    <2.0038480, 0.4012366, 18.1592964>,
    <2.0039445, 0.4012405, 18.1573801>,
    <2.0038962, 0.4012385, 18.1583383>,
    <2.0040409, 0.4012444, 18.1554639>,
    <2.0039927, 0.4012424, 18.1564220>,
    <2.0042444, 0.3609914, 18.1389725>,
    <2.0042673, 0.2804695, 18.1386133>,
    <2.0043812, 0.3609921, 18.1258340>,
    <2.0042548, 0.3207304, 18.1388528>,
    <2.0043680, 0.2804627, 18.1301880>,
    <2.0044020, 0.3207251, 18.1251156>,
    <2.0043263, 0.3609918, 18.1316249>,
    <2.0043430, 0.3207272, 18.1311460>,
    <2.0042339, 0.4415135, 18.1386133>,
    <2.0043853, 0.4012591, 18.1251156>,
    <2.0043346, 0.4415211, 18.1301880>,
    <2.0042381, 0.4012525, 18.1388528>,
    <2.0043263, 0.4012565, 18.1311460>,
    <2.0040493, 0.3609906, 18.1554639>,
    <2.0041333, 0.4415058, 18.1470386>,
    <2.0040409, 0.4012444, 18.1554639>,
    <2.0041499, 0.3609910, 18.1470386>,
    <2.0041416, 0.4012484, 18.1470386>,
    <2.0040576, 0.3207368, 18.1554639>,
    <2.0041666, 0.2804762, 18.1470386>,
    <2.0041583, 0.3207336, 18.1470386>,
    <2.0043805, 0.3609920, 18.1205987>,
    <2.0043944, 0.3609921, 18.1224380>,
    <2.0043909, 0.3207262, 18.1204790>,
    <2.0044111, 0.3207251, 18.1219591>,
    <2.0043215, 0.3609918, 18.1187163>,
    <2.0043298, 0.3207282, 18.1187163>,
    <2.0043541, 0.3609919, 18.1194779>,
    <2.0043625, 0.3207272, 18.1194779>,
    <2.0043131, 0.4012553, 18.1187163>,
    <2.0043742, 0.4012579, 18.1204790>,
    <2.0043458, 0.4012566, 18.1194779>,
    <2.0043944, 0.4012592, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0001979, 0.9999962, 0.0027618>,
    <-0.0001970, 0.9999967, 0.0025777>,
    <-0.0001935, 0.9999966, 0.0026141>,
    <-0.0001949, 0.9999961, 0.0027737>,
    <-0.0001959, 0.9999958, 0.0028851>,
    <-0.0001985, 0.9999958, 0.0028852>,
    <-0.0001985, 0.9999958, 0.0028852>,
    <-0.0002015, 0.9999958, 0.0028854>,
    <-0.0002015, 0.9999962, 0.0027469>,
    <-0.0002015, 0.9999962, 0.0027469>,
    <-0.0002015, 0.9999968, 0.0025299>,
    <-0.0001955, 0.9999974, 0.0022739>,
    <-0.0001913, 0.9999972, 0.0023663>,
    <-0.0002015, 0.9999968, 0.0025299>,
    <-0.0002015, 0.9999977, 0.0021412>,
    <-0.0002015, 0.9999977, 0.0021412>,
    <-0.0002015, 0.9999992, 0.0012430>,
    <-0.0001926, 0.9999986, 0.0016774>,
    <-0.0001926, 0.9999986, 0.0016774>,
    <-0.0001874, 0.9999981, 0.0019299>,
    <-0.0001882, 0.9999970, 0.0024345>,
    <-0.0001908, 0.9999965, 0.0026427>,
    <-0.0001874, 0.9999981, 0.0019299>,
    <-0.0001840, 0.9999978, 0.0020951>,
    <-0.0001840, 0.9999978, 0.0020951>,
    <-0.0001816, 0.9999975, 0.0022114>,
    <-0.0001858, 0.9999969, 0.0024868>,
    <-0.0001858, 0.9999969, 0.0024868>,
    <-0.0001886, 0.9999964, 0.0026659>,
    <-0.0001925, 0.9999961, 0.0027835>,
    <-0.0001886, 0.9999964, 0.0026659>,
    <-0.0001905, 0.9999961, 0.0027917>,
    <-0.0001905, 0.9999961, 0.0027917>,
    <-0.0001919, 0.9999958, 0.0028850>,
    <-0.0001938, 0.9999958, 0.0028850>,
    <-0.0001938, 0.9999958, 0.0028850>,
    <-0.0001959, 0.9999958, 0.0028851>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <-0.0205528, -0.0000032, -0.9997888>,
    <0.0000673, -0.9999647, 0.0084002>,
    <0.0000798, -0.9999829, 0.0058449>,
    <0.0000506, -0.9999847, 0.0055388>,
    <0.0000320, -0.9999709, 0.0076225>,
    <-0.0000008, -0.9999362, 0.0112934>,
    <0.0000429, -0.9999100, 0.0134174>,
    <0.0000429, -0.9999100, 0.0134174>,
    <0.0001180, -0.9998543, 0.0170703>,
    <0.0001180, -0.9999547, 0.0095163>,
    <0.0001180, -0.9999547, 0.0095163>,
    <0.0001180, -0.9999805, 0.0062463>,
    <0.0000873, -0.9999908, 0.0042964>,
    <0.0000626, -0.9999912, 0.0041960>,
    <0.0001180, -0.9999805, 0.0062463>,
    <0.0001180, -0.9999902, 0.0044211>,
    <0.0001180, -0.9999902, 0.0044211>,
    <0.0001180, -0.9999947, 0.0032565>,
    <0.0000924, -0.9999947, 0.0032576>,
    <0.0000924, -0.9999947, 0.0032576>,
    <0.0000710, -0.9999947, 0.0032585>,
    <0.0000423, -0.9999915, 0.0041134>,
    <0.0000276, -0.9999860, 0.0052978>,
    <0.0000710, -0.9999947, 0.0032585>,
    <0.0000528, -0.9999947, 0.0032593>,
    <0.0000528, -0.9999947, 0.0032593>,
    <0.0000373, -0.9999947, 0.0032599>,
    <0.0000253, -0.9999918, 0.0040444>,
    <0.0000253, -0.9999918, 0.0040444>,
    <0.0000091, -0.9999870, 0.0051030>,
    <0.0000060, -0.9999752, 0.0070495>,
    <0.0000091, -0.9999870, 0.0051030>,
    <-0.0000140, -0.9999782, 0.0066097>,
    <-0.0000140, -0.9999782, 0.0066097>,
    <-0.0000494, -0.9999602, 0.0089256>,
    <-0.0000293, -0.9999509, 0.0099046>,
    <-0.0000293, -0.9999509, 0.0099046>,
    <-0.0000008, -0.9999362, 0.0112934>,
    <0.0001437, -0.9999999, 0.0005130>,
    <0.0001435, -0.9999999, 0.0005281>,
    <0.0001473, -0.9999998, 0.0005281>,
    <0.0001474, -0.9999999, 0.0005130>,
    <0.0001475, -0.9999999, 0.0004984>,
    <0.0001438, -0.9999999, 0.0004984>,
    <0.0001438, -0.9999999, 0.0004984>,
    <0.0001401, -0.9999999, 0.0004983>,
    <0.0001399, -0.9999999, 0.0005130>,
    <0.0001399, -0.9999999, 0.0005130>,
    <0.0001397, -0.9999999, 0.0005281>,
    <0.0001433, -0.9999998, 0.0005437>,
    <0.0001472, -0.9999998, 0.0005437>,
    <0.0001397, -0.9999999, 0.0005281>,
    <0.0001395, -0.9999998, 0.0005437>,
    <0.0001395, -0.9999998, 0.0005437>,
    <0.0001392, -0.9999998, 0.0005598>,
    <0.0001431, -0.9999998, 0.0005598>,
    <0.0001431, -0.9999998, 0.0005598>,
    <0.0001470, -0.9999998, 0.0005598>,
    <0.0001510, -0.9999998, 0.0005437>,
    <0.0001511, -0.9999998, 0.0005281>,
    <0.0001470, -0.9999998, 0.0005598>,
    <0.0001509, -0.9999998, 0.0005597>,
    <0.0001509, -0.9999998, 0.0005597>,
    <0.0001548, -0.9999998, 0.0005597>,
    <0.0001548, -0.9999998, 0.0005437>,
    <0.0001548, -0.9999998, 0.0005437>,
    <0.0001548, -0.9999998, 0.0005281>,
    <0.0001511, -0.9999999, 0.0005131>,
    <0.0001548, -0.9999998, 0.0005281>,
    <0.0001548, -0.9999999, 0.0005131>,
    <0.0001548, -0.9999999, 0.0005131>,
    <0.0001548, -0.9999999, 0.0004984>,
    <0.0001512, -0.9999999, 0.0004984>,
    <0.0001512, -0.9999999, 0.0004984>,
    <0.0001475, -0.9999999, 0.0004984>,
    <0.9999622, 0.0001559, -0.0086918>,
    <0.9999622, 0.0001559, -0.0086938>,
    <0.9999622, 0.0001555, -0.0086938>,
    <0.9999622, 0.0001555, -0.0086918>,
    <0.9999622, 0.0001555, -0.0086898>,
    <0.9999622, 0.0001559, -0.0086898>,
    <0.9999622, 0.0001559, -0.0086898>,
    <0.9999622, 0.0001563, -0.0086898>,
    <0.9999622, 0.0001563, -0.0086918>,
    <0.9999622, 0.0001563, -0.0086918>,
    <0.9999622, 0.0001563, -0.0086938>,
    <0.9999622, 0.0001559, -0.0086958>,
    <0.9999622, 0.0001555, -0.0086958>,
    <0.9999622, 0.0001563, -0.0086938>,
    <0.9999622, 0.0001563, -0.0086958>,
    <0.9999622, 0.0001563, -0.0086958>,
    <0.9999622, 0.0001563, -0.0086977>,
    <0.9999622, 0.0001559, -0.0086977>,
    <0.9999622, 0.0001559, -0.0086977>,
    <0.9999622, 0.0001555, -0.0086977>,
    <0.9999622, 0.0001550, -0.0086958>,
    <0.9999622, 0.0001550, -0.0086938>,
    <0.9999622, 0.0001555, -0.0086977>,
    <0.9999622, 0.0001550, -0.0086977>,
    <0.9999622, 0.0001550, -0.0086977>,
    <0.9999622, 0.0001546, -0.0086977>,
    <0.9999622, 0.0001546, -0.0086958>,
    <0.9999622, 0.0001546, -0.0086958>,
    <0.9999622, 0.0001546, -0.0086938>,
    <0.9999622, 0.0001550, -0.0086918>,
    <0.9999622, 0.0001546, -0.0086938>,
    <0.9999622, 0.0001546, -0.0086918>,
    <0.9999622, 0.0001546, -0.0086918>,
    <0.9999622, 0.0001546, -0.0086898>,
    <0.9999622, 0.0001550, -0.0086898>,
    <0.9999622, 0.0001550, -0.0086898>,
    <0.9999622, 0.0001555, -0.0086898>,
    <-0.0000951, 0.9999998, 0.0005728>,
    <-0.0000951, 0.9999998, 0.0005695>,
    <-0.0000943, 0.9999998, 0.0005695>,
    <-0.0000943, 0.9999998, 0.0005728>,
    <-0.0000943, 0.9999998, 0.0005763>,
    <-0.0000952, 0.9999998, 0.0005763>,
    <-0.0000952, 0.9999998, 0.0005763>,
    <-0.0000960, 0.9999998, 0.0005763>,
    <-0.0000960, 0.9999998, 0.0005729>,
    <-0.0000960, 0.9999998, 0.0005729>,
    <-0.0000959, 0.9999998, 0.0005695>,
    <-0.0000951, 0.9999998, 0.0005663>,
    <-0.0000943, 0.9999998, 0.0005663>,
    <-0.0000959, 0.9999998, 0.0005695>,
    <-0.0000959, 0.9999998, 0.0005663>,
    <-0.0000959, 0.9999998, 0.0005663>,
    <-0.0000958, 0.9999998, 0.0005631>,
    <-0.0000950, 0.9999998, 0.0005631>,
    <-0.0000950, 0.9999998, 0.0005631>,
    <-0.0000942, 0.9999998, 0.0005631>,
    <-0.0000935, 0.9999998, 0.0005663>,
    <-0.0000935, 0.9999998, 0.0005695>,
    <-0.0000942, 0.9999998, 0.0005631>,
    <-0.0000935, 0.9999998, 0.0005631>,
    <-0.0000935, 0.9999998, 0.0005631>,
    <-0.0000927, 0.9999998, 0.0005631>,
    <-0.0000927, 0.9999998, 0.0005663>,
    <-0.0000927, 0.9999998, 0.0005663>,
    <-0.0000927, 0.9999998, 0.0005695>,
    <-0.0000935, 0.9999998, 0.0005728>,
    <-0.0000927, 0.9999998, 0.0005695>,
    <-0.0000927, 0.9999998, 0.0005728>,
    <-0.0000927, 0.9999998, 0.0005728>,
    <-0.0000927, 0.9999998, 0.0005763>,
    <-0.0000935, 0.9999998, 0.0005763>,
    <-0.0000935, 0.9999998, 0.0005763>,
    <-0.0000943, 0.9999998, 0.0005763>,
    <0.0001510, -0.9999947, 0.0032413>,
    <0.0001510, -0.9999952, 0.0030960>,
    <0.0001474, -0.9999952, 0.0031052>,
    <0.0001474, -0.9999947, 0.0032458>,
    <0.0001474, -0.9999943, 0.0033864>,
    <0.0001510, -0.9999943, 0.0033866>,
    <0.0001510, -0.9999943, 0.0033866>,
    <0.0001548, -0.9999943, 0.0033868>,
    <0.0001548, -0.9999948, 0.0032365>,
    <0.0001548, -0.9999948, 0.0032365>,
    <0.0001548, -0.9999952, 0.0030862>,
    <0.0001510, -0.9999956, 0.0029508>,
    <0.0001474, -0.9999956, 0.0029647>,
    <0.0001548, -0.9999952, 0.0030862>,
    <0.0001548, -0.9999957, 0.0029360>,
    <0.0001548, -0.9999957, 0.0029360>,
    <0.0001548, -0.9999961, 0.0027857>,
    <0.0001510, -0.9999961, 0.0028055>,
    <0.0001510, -0.9999961, 0.0028055>,
    <0.0001474, -0.9999960, 0.0028241>,
    <0.0001440, -0.9999956, 0.0029777>,
    <0.0001440, -0.9999951, 0.0031138>,
    <0.0001474, -0.9999960, 0.0028241>,
    <0.0001440, -0.9999960, 0.0028415>,
    <0.0001440, -0.9999960, 0.0028415>,
    <0.0001408, -0.9999959, 0.0028578>,
    <0.0001408, -0.9999955, 0.0029899>,
    <0.0001408, -0.9999955, 0.0029899>,
    <0.0001408, -0.9999951, 0.0031219>,
    <0.0001440, -0.9999947, 0.0032500>,
    <0.0001408, -0.9999951, 0.0031219>,
    <0.0001408, -0.9999947, 0.0032540>,
    <0.0001408, -0.9999947, 0.0032540>,
    <0.0001408, -0.9999943, 0.0033861>,
    <0.0001440, -0.9999943, 0.0033862>,
    <0.0001440, -0.9999943, 0.0033862>,
    <0.0001474, -0.9999943, 0.0033864>,
    <0.1905399, 0.0000294, -0.9816795>,
    <0.1905394, 0.0000294, -0.9816795>,
    <0.1905394, 0.0000293, -0.9816795>,
    <0.1905399, 0.0000293, -0.9816795>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000294, -0.9816794>,
    <0.1905403, 0.0000294, -0.9816794>,
    <0.1905403, 0.0000295, -0.9816794>,
    <0.1905399, 0.0000295, -0.9816795>,
    <0.1905399, 0.0000295, -0.9816795>,
    <0.1905394, 0.0000295, -0.9816795>,
    <0.1905390, 0.0000294, -0.9816796>,
    <0.1905390, 0.0000293, -0.9816796>,
    <0.1905394, 0.0000295, -0.9816795>,
    <0.1905390, 0.0000295, -0.9816796>,
    <0.1905390, 0.0000295, -0.9816796>,
    <0.1905385, 0.0000295, -0.9816797>,
    <0.1905385, 0.0000294, -0.9816797>,
    <0.1905385, 0.0000294, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905390, 0.0000293, -0.9816796>,
    <0.1905394, 0.0000293, -0.9816795>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000293, -0.9816797>,
    <0.1905385, 0.0000292, -0.9816797>,
    <0.1905390, 0.0000292, -0.9816796>,
    <0.1905390, 0.0000292, -0.9816796>,
    <0.1905394, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000293, -0.9816795>,
    <0.1905394, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000292, -0.9816795>,
    <0.1905399, 0.0000292, -0.9816795>,
    <0.1905403, 0.0000292, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <0.1905403, 0.0000293, -0.9816794>,
    <-0.0000906, 0.9999917, 0.0040632>,
    <-0.0000906, 0.9999921, 0.0039843>,
    <-0.0000886, 0.9999921, 0.0039793>,
    <-0.0000886, 0.9999918, 0.0040557>,
    <-0.0000886, 0.9999915, 0.0041320>,
    <-0.0000906, 0.9999914, 0.0041421>,
    <-0.0000906, 0.9999914, 0.0041421>,
    <-0.0000927, 0.9999914, 0.0041529>,
    <-0.0000927, 0.9999917, 0.0040712>,
    <-0.0000927, 0.9999917, 0.0040712>,
    <-0.0000927, 0.9999920, 0.0039896>,
    <-0.0000906, 0.9999924, 0.0039053>,
    <-0.0000886, 0.9999924, 0.0039029>,
    <-0.0000927, 0.9999920, 0.0039896>,
    <-0.0000927, 0.9999924, 0.0039079>,
    <-0.0000927, 0.9999924, 0.0039079>,
    <-0.0000927, 0.9999927, 0.0038263>,
    <-0.0000906, 0.9999927, 0.0038264>,
    <-0.0000906, 0.9999927, 0.0038264>,
    <-0.0000886, 0.9999927, 0.0038265>,
    <-0.0000868, 0.9999924, 0.0039006>,
    <-0.0000868, 0.9999921, 0.0039746>,
    <-0.0000886, 0.9999927, 0.0038265>,
    <-0.0000868, 0.9999927, 0.0038266>,
    <-0.0000868, 0.9999927, 0.0038266>,
    <-0.0000851, 0.9999927, 0.0038267>,
    <-0.0000851, 0.9999924, 0.0038984>,
    <-0.0000851, 0.9999924, 0.0038984>,
    <-0.0000851, 0.9999921, 0.0039702>,
    <-0.0000868, 0.9999918, 0.0040486>,
    <-0.0000851, 0.9999921, 0.0039702>,
    <-0.0000851, 0.9999918, 0.0040420>,
    <-0.0000851, 0.9999918, 0.0040420>,
    <-0.0000851, 0.9999915, 0.0041137>,
    <-0.0000868, 0.9999915, 0.0041226>,
    <-0.0000868, 0.9999915, 0.0041226>,
    <-0.0000886, 0.9999915, 0.0041320>,
    <0.0001429, -1.0000000, 0.0000082>,
    <0.0001419, -1.0000000, 0.0000137>,
    <0.0001499, -1.0000000, 0.0000570>,
    <0.0001580, -1.0000000, 0.0000320>,
    <0.0001598, -1.0000000, 0.0000006>,
    <0.0001432, -1.0000000, 0.0000006>,
    <0.0001432, -1.0000000, 0.0000006>,
    <0.0001408, -1.0000000, 0.0000006>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000153>,
    <0.0001410, -1.0000000, 0.0000657>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001408, -1.0000000, 0.0000005>,
    <0.0001405, -1.0000000, 0.0000145>,
    <0.0001405, -1.0000000, 0.0000145>,
    <0.0001380, -1.0000000, 0.0000628>,
    <0.0001414, -1.0000000, 0.0001783>,
    <0.0001692, -1.0000000, 0.0001630>,
    <0.0001380, -1.0000000, 0.0000628>,
    <0.0001319, -1.0000000, 0.0001720>,
    <0.0001319, -1.0000000, 0.0001720>,
    <0.0001218, -0.9999999, 0.0004379>,
    <0.0001379, -0.9999999, 0.0004526>,
    <0.0001863, -0.9999999, 0.0004573>,
    <0.0002046, -1.0000000, 0.0001071>,
    <0.0003019, -0.9999998, 0.0004720>,
    <0.0004048, -0.9999998, 0.0005587>,
    <0.0002116, -1.0000000, 0.0000006>,
    <0.0002116, -1.0000000, 0.0000006>,
    <0.0001598, -1.0000000, 0.0000006>,
    <0.9990812, 0.0001532, -0.0428577>,
    <0.9990812, 0.0001532, -0.0428578>,
    <0.9831445, 0.0001507, -0.1828302>,
    <0.9831446, 0.0001507, -0.1828299>,
    <0.9831446, 0.0001507, -0.1828296>,
    <0.9990812, 0.0001532, -0.0428577>,
    <0.9990812, 0.0001532, -0.0428577>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9990812, 0.0001532, -0.0428579>,
    <0.9831444, 0.0001507, -0.1828304>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9999996, 0.0001534, -0.0008513>,
    <0.9990812, 0.0001532, -0.0428580>,
    <0.9990812, 0.0001532, -0.0428580>,
    <0.9831444, 0.0001507, -0.1828307>,
    <0.8939548, 0.0001366, -0.4481571>,
    <0.8939551, 0.0001366, -0.4481565>,
    <0.9831444, 0.0001507, -0.1828307>,
    <0.8939545, 0.0001366, -0.4481577>,
    <0.8939545, 0.0001366, -0.4481577>,
    <0.6276284, 0.0000954, -0.7785131>,
    <0.6276290, 0.0000954, -0.7785125>,
    <0.6276297, 0.0000954, -0.7785120>,
    <0.8939554, 0.0001366, -0.4481559>,
    <0.6276303, 0.0000954, -0.7785115>,
    <0.6276310, 0.0000954, -0.7785110>,
    <0.8939557, 0.0001366, -0.4481553>,
    <0.8939557, 0.0001366, -0.4481553>,
    <0.9831446, 0.0001507, -0.1828296>,
    <-0.0000844, 1.0000000, 0.0000236>,
    <-0.0000832, 1.0000000, 0.0000196>,
    <-0.0000698, 1.0000000, 0.0000816>,
    <-0.0000800, 1.0000000, 0.0001006>,
    <-0.0000835, 1.0000000, 0.0001062>,
    <-0.0000848, 1.0000000, 0.0000247>,
    <-0.0000848, 1.0000000, 0.0000247>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000821, 1.0000000, 0.0000113>,
    <-0.0000606, 1.0000000, 0.0000444>,
    <-0.0000851, 1.0000000, 0.0000007>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000851, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000817, 1.0000000, 0.0000006>,
    <-0.0000589, 1.0000000, 0.0000006>,
    <0.0000041, 1.0000000, 0.0001407>,
    <-0.0000358, 1.0000000, 0.0002272>,
    <-0.0000589, 1.0000000, 0.0000006>,
    <0.0000100, 1.0000000, 0.0000006>,
    <0.0000100, 1.0000000, 0.0000006>,
    <0.0002457, 0.9999998, 0.0006317>,
    <0.0001373, 0.9999998, 0.0005815>,
    <0.0000045, 0.9999998, 0.0006141>,
    <-0.0000685, 1.0000000, 0.0002685>,
    <-0.0000539, 0.9999998, 0.0006605>,
    <-0.0000743, 0.9999998, 0.0006962>,
    <-0.0000800, 1.0000000, 0.0002844>,
    <-0.0000800, 1.0000000, 0.0002844>,
    <-0.0000835, 1.0000000, 0.0001062>,
    <0.0002912, -0.9999984, 0.0017670>,
    <0.0001725, -0.9999993, 0.0011318>,
    <0.0001026, -0.9999983, 0.0018581>,
    <0.0001112, -0.9999949, 0.0031925>,
    <0.0001481, -0.9999397, 0.0109794>,
    <0.0012690, -0.9999369, 0.0111623>,
    <0.0012690, -0.9999369, 0.0111623>,
    <0.0004048, -0.9999998, 0.0005587>,
    <0.0001239, -0.9999995, 0.0010008>,
    <0.0000990, -0.9999989, 0.0014968>,
    <0.0001218, -0.9999999, 0.0004379>,
    <0.0001093, -0.9999995, 0.0009581>,
    <0.0001093, -0.9999995, 0.0009581>,
    <0.0000980, -0.9999990, 0.0013971>,
    <0.0000785, -0.9999992, 0.0012876>,
    <0.0000401, -0.9999988, 0.0015540>,
    <0.0000980, -0.9999990, 0.0013971>,
    <0.0000894, -0.9999993, 0.0011934>,
    <0.0000894, -0.9999993, 0.0011934>,
    <0.0000837, -0.9999998, 0.0006212>,
    <0.0000737, -0.9999998, 0.0006550>,
    <0.0000426, -0.9999998, 0.0006974>,
    <-0.0000550, -0.9999970, 0.0024349>,
    <-0.0000320, -0.9999997, 0.0007319>,
    <-0.0000818, -0.9999997, 0.0007081>,
    <-0.0005919, -0.9999409, 0.0108586>,
    <-0.0005919, -0.9999409, 0.0108586>,
    <0.0001481, -0.9999397, 0.0109794>,
    <0.3566099, 0.0000538, -0.9342534>,
    <0.3566093, 0.0000538, -0.9342536>,
    <0.2610639, 0.0000390, -0.9653215>,
    <0.2610644, 0.0000390, -0.9653214>,
    <0.2610648, 0.0000390, -0.9653213>,
    <0.3566104, 0.0000538, -0.9342532>,
    <0.3566104, 0.0000538, -0.9342532>,
    <0.6276310, 0.0000954, -0.7785110>,
    <0.3566088, 0.0000538, -0.9342538>,
    <0.2610635, 0.0000390, -0.9653216>,
    <0.6276284, 0.0000954, -0.7785131>,
    <0.3566083, 0.0000538, -0.9342540>,
    <0.3566083, 0.0000538, -0.9342540>,
    <0.2610631, 0.0000390, -0.9653217>,
    <0.3092803, 0.0000457, -0.9509709>,
    <0.3092808, 0.0000457, -0.9509708>,
    <0.2610631, 0.0000390, -0.9653217>,
    <0.3092799, 0.0000457, -0.9509711>,
    <0.3092799, 0.0000457, -0.9509711>,
    <0.5394217, 0.0000790, -0.8420358>,
    <0.5394223, 0.0000790, -0.8420354>,
    <0.5394230, 0.0000790, -0.8420350>,
    <0.3092813, 0.0000457, -0.9509706>,
    <0.5394236, 0.0000790, -0.8420345>,
    <0.5394243, 0.0000790, -0.8420341>,
    <0.3092817, 0.0000457, -0.9509705>,
    <0.3092817, 0.0000457, -0.9509705>,
    <0.2610648, 0.0000390, -0.9653213>,
    <-0.0000482, 0.9999990, 0.0014066>,
    <0.0000111, 0.9999989, 0.0014714>,
    <-0.0000551, 0.9999972, 0.0023598>,
    <-0.0000596, 0.9999979, 0.0020352>,
    <-0.0000608, 0.9999979, 0.0020296>,
    <-0.0000672, 0.9999989, 0.0014526>,
    <-0.0000672, 0.9999989, 0.0014526>,
    <-0.0000743, 0.9999998, 0.0006962>,
    <0.0001481, 0.9999977, 0.0021246>,
    <-0.0000452, 0.9999928, 0.0038027>,
    <0.0002457, 0.9999998, 0.0006317>,
    <0.0012442, 0.9999195, 0.0126234>,
    <0.0012442, 0.9999195, 0.0126234>,
    <-0.0000041, 0.9999229, 0.0124198>,
    <-0.0002251, 0.9999958, 0.0028806>,
    <-0.0001157, 0.9999981, 0.0019437>,
    <-0.0000041, 0.9999229, 0.0124198>,
    <-0.0008268, 0.9999242, 0.0122855>,
    <-0.0008268, 0.9999242, 0.0122855>,
    <-0.0002400, 0.9999997, 0.0008012>,
    <-0.0001867, 0.9999996, 0.0008670>,
    <-0.0001014, 0.9999996, 0.0008661>,
    <-0.0000696, 0.9999985, 0.0017084>,
    <-0.0000648, 0.9999996, 0.0008550>,
    <-0.0000527, 0.9999996, 0.0008534>,
    <-0.0000559, 0.9999986, 0.0016781>,
    <-0.0000559, 0.9999986, 0.0016781>,
    <-0.0000608, 0.9999979, 0.0020296>,
    <0.0000429, -1.0000000, 0.0001869>,
    <0.0000610, -1.0000000, 0.0002649>,
    <0.0000733, -1.0000000, 0.0001115>,
    <0.0000696, -1.0000000, 0.0000775>,
    <0.0000688, -1.0000000, 0.0000345>,
    <0.0000401, -1.0000000, 0.0000345>,
    <0.0000401, -1.0000000, 0.0000345>,
    <-0.0000818, -0.9999997, 0.0007081>,
    <0.0000755, -1.0000000, 0.0002809>,
    <0.0000775, -1.0000000, 0.0001238>,
    <0.0000837, -0.9999998, 0.0006212>,
    <0.0000805, -1.0000000, 0.0002738>,
    <0.0000805, -1.0000000, 0.0002738>,
    <0.0000789, -1.0000000, 0.0001224>,
    <0.0000781, -1.0000000, 0.0000537>,
    <0.0000776, -1.0000000, 0.0000514>,
    <0.0000789, -1.0000000, 0.0001224>,
    <0.0000782, -1.0000000, 0.0000530>,
    <0.0000782, -1.0000000, 0.0000530>,
    <0.0000780, -1.0000000, 0.0000325>,
    <0.0000780, -1.0000000, 0.0000330>,
    <0.0000780, -1.0000000, 0.0000330>,
    <0.0000780, -1.0000000, 0.0000335>,
    <0.0000771, -1.0000000, 0.0000443>,
    <0.0000780, -1.0000000, 0.0000335>,
    <0.0000780, -1.0000000, 0.0000340>,
    <0.0000780, -1.0000000, 0.0000340>,
    <0.0000780, -1.0000000, 0.0000345>,
    <0.0000770, -1.0000000, 0.0000345>,
    <0.0000770, -1.0000000, 0.0000345>,
    <0.0000688, -1.0000000, 0.0000345>,
    <0.8323459, 0.0001212, -0.5542565>,
    <0.8323455, 0.0001212, -0.5542572>,
    <0.9629304, 0.0001398, -0.2697499>,
    <0.9629305, 0.0001398, -0.2697495>,
    <0.9629307, 0.0001398, -0.2697490>,
    <0.8323463, 0.0001212, -0.5542558>,
    <0.8323463, 0.0001212, -0.5542558>,
    <0.5394243, 0.0000790, -0.8420341>,
    <0.8323450, 0.0001212, -0.5542578>,
    <0.9629303, 0.0001398, -0.2697504>,
    <0.5394217, 0.0000790, -0.8420358>,
    <0.8323446, 0.0001212, -0.5542585>,
    <0.8323446, 0.0001212, -0.5542585>,
    <0.9629301, 0.0001398, -0.2697508>,
    <0.9945988, 0.0001442, -0.1037943>,
    <0.9945988, 0.0001442, -0.1037941>,
    <0.9629301, 0.0001398, -0.2697508>,
    <0.9945988, 0.0001442, -0.1037945>,
    <0.9945988, 0.0001442, -0.1037945>,
    <0.9986191, 0.0001446, -0.0525351>,
    <0.9986191, 0.0001446, -0.0525350>,
    <0.9986191, 0.0001446, -0.0525350>,
    <0.9986191, 0.0001446, -0.0525349>,
    <0.9945988, 0.0001442, -0.1037939>,
    <0.9986191, 0.0001446, -0.0525349>,
    <0.9986191, 0.0001446, -0.0525347>,
    <0.9986191, 0.0001446, -0.0525347>,
    <0.9986191, 0.0001446, -0.0525346>,
    <0.9945988, 0.0001442, -0.1037937>,
    <0.9945988, 0.0001442, -0.1037937>,
    <0.9629307, 0.0001398, -0.2697490>,
    <-0.0000567, 0.9999999, 0.0003627>,
    <-0.0000734, 0.9999999, 0.0003289>,
    <-0.0000563, 1.0000000, 0.0001378>,
    <-0.0000516, 1.0000000, 0.0001578>,
    <-0.0000500, 1.0000000, 0.0001622>,
    <-0.0000509, 0.9999999, 0.0003697>,
    <-0.0000509, 0.9999999, 0.0003697>,
    <-0.0000527, 0.9999996, 0.0008534>,
    <-0.0000940, 1.0000000, 0.0002249>,
    <-0.0000606, 1.0000000, 0.0000933>,
    <-0.0002400, 0.9999997, 0.0008012>,
    <-0.0000965, 1.0000000, 0.0000391>,
    <-0.0000965, 1.0000000, 0.0000391>,
    <-0.0000614, 1.0000000, 0.0000391>,
    <-0.0000508, 1.0000000, 0.0000521>,
    <-0.0000503, 1.0000000, 0.0000621>,
    <-0.0000614, 1.0000000, 0.0000391>,
    <-0.0000510, 1.0000000, 0.0000391>,
    <-0.0000510, 1.0000000, 0.0000391>,
    <-0.0000495, 1.0000000, 0.0000391>,
    <-0.0000495, 1.0000000, 0.0000394>,
    <-0.0000495, 1.0000000, 0.0000394>,
    <-0.0000495, 1.0000000, 0.0000396>,
    <-0.0000498, 1.0000000, 0.0000667>,
    <-0.0000495, 1.0000000, 0.0000396>,
    <-0.0000495, 1.0000000, 0.0000399>,
    <-0.0000495, 1.0000000, 0.0000399>,
    <-0.0000495, 1.0000000, 0.0000401>,
    <-0.0000496, 1.0000000, 0.0000679>,
    <-0.0000496, 1.0000000, 0.0000679>,
    <-0.0000500, 1.0000000, 0.0001622>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, -0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <0.0000747, -1.0000000, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, -0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <1.0000000, 0.0001427, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, -0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <-0.0000478, 1.0000000, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, -0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <1.0000000, 0.0002062, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002064, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005139>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002063, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <0.9999998, 0.0002064, 0.0005140>,
    <-0.9869426, -0.0002042, -0.1610724>,
    <-0.9869426, -0.0002040, -0.1610724>,
    <-0.9869431, -0.0002040, -0.1610691>,
    <-0.9869431, -0.0002042, -0.1610691>,
    <-0.9869431, -0.0002043, -0.1610691>,
    <-0.9869426, -0.0002043, -0.1610724>,
    <-0.9869426, -0.0002043, -0.1610724>,
    <-0.9869420, -0.0002043, -0.1610756>,
    <-0.9869420, -0.0002042, -0.1610756>,
    <-0.9869420, -0.0002042, -0.1610756>,
    <-0.9869420, -0.0002040, -0.1610756>,
    <-0.9869426, -0.0002039, -0.1610724>,
    <-0.9869431, -0.0002039, -0.1610691>,
    <-0.9869420, -0.0002040, -0.1610756>,
    <-0.9869420, -0.0002039, -0.1610756>,
    <-0.9869420, -0.0002039, -0.1610756>,
    <-0.9869420, -0.0002037, -0.1610756>,
    <-0.9869426, -0.0002037, -0.1610724>,
    <-0.9869426, -0.0002037, -0.1610724>,
    <-0.9869431, -0.0002037, -0.1610691>,
    <-0.9869436, -0.0002039, -0.1610659>,
    <-0.9869436, -0.0002040, -0.1610659>,
    <-0.9869431, -0.0002037, -0.1610691>,
    <-0.9869436, -0.0002037, -0.1610659>,
    <-0.9869436, -0.0002037, -0.1610659>,
    <-0.9869442, -0.0002037, -0.1610627>,
    <-0.9869442, -0.0002039, -0.1610627>,
    <-0.9869442, -0.0002039, -0.1610627>,
    <-0.9869442, -0.0002040, -0.1610627>,
    <-0.9869436, -0.0002042, -0.1610659>,
    <-0.9869442, -0.0002040, -0.1610627>,
    <-0.9869442, -0.0002042, -0.1610627>,
    <-0.9869442, -0.0002042, -0.1610627>,
    <-0.9869442, -0.0002043, -0.1610627>,
    <-0.9869436, -0.0002043, -0.1610659>,
    <-0.9869436, -0.0002043, -0.1610659>,
    <-0.9869431, -0.0002043, -0.1610691>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002070, 0.0000083>,
    <1.0000000, 0.0002071, 0.0000083>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987356, -0.0002069, -0.0502712>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002069, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987355, -0.0002068, -0.0502722>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502712>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987356, -0.0002068, -0.0502702>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987357, -0.0002068, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502681>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987357, -0.0002069, -0.0502691>,
    <-0.9987356, -0.0002069, -0.0502702>,
    <0.9999404, 0.0003438, 0.0109141>,
    <0.9999447, 0.0002073, 0.0105163>,
    <0.9999338, 0.0002072, 0.0115037>,
    <0.9999321, 0.0002414, 0.0116512>,
    <0.9999286, 0.0002504, 0.0119507>,
    <0.9999285, 0.0003746, 0.0119506>,
    <0.9999285, 0.0003746, 0.0119506>,
    <0.9999722, 0.0008411, 0.0074076>,
    <0.9999724, 0.0006034, 0.0074077>,
    <0.9999725, 0.0002073, 0.0074076>,
    <0.9999404, 0.0000707, 0.0109136>,
    <0.9999321, 0.0001731, 0.0116506>,
    <0.9999725, -0.0001887, 0.0074074>,
    <0.9999725, -0.0004264, 0.0074070>,
    <0.9999286, 0.0000399, 0.0119496>,
    <0.9999286, 0.0000399, 0.0119496>,
    <0.9999286, 0.0001640, 0.0119498>,
    <0.9999294, 0.0002031, 0.0118782>,
    <0.9999298, 0.0002072, 0.0118451>,
    <0.9999286, 0.0001640, 0.0119498>,
    <0.9999286, 0.0002018, 0.0119498>,
    <0.9999286, 0.0002018, 0.0119498>,
    <0.9999286, 0.0002071, 0.0119498>,
    <0.9999286, 0.0002071, 0.0119500>,
    <0.9999286, 0.0002071, 0.0119500>,
    <0.9999286, 0.0002071, 0.0119503>,
    <0.9999294, 0.0002113, 0.0118787>,
    <0.9999286, 0.0002071, 0.0119503>,
    <0.9999286, 0.0002071, 0.0119505>,
    <0.9999286, 0.0002071, 0.0119505>,
    <0.9999286, 0.0002071, 0.0119508>,
    <0.9999286, 0.0002126, 0.0119508>,
    <0.9999286, 0.0002126, 0.0119508>,
    <0.9999286, 0.0002504, 0.0119507>,
    <0.9999903, 0.0006657, -0.0043628>,
    <0.9997832, 0.0004345, -0.0208159>,
    <0.9998818, 0.0002073, -0.0153711>,
    <0.9999996, 0.0002073, -0.0008270>,
    <0.9999722, 0.0008411, 0.0074076>,
    <0.9990811, 0.0020567, -0.0428093>,
    <0.9990811, 0.0020567, -0.0428093>,
    <0.9990829, 0.0006845, -0.0428133>,
    <0.9993788, 0.0002463, -0.0352415>,
    <0.9994752, 0.0002072, -0.0323937>,
    <0.9990829, 0.0006845, -0.0428133>,
    <0.9990830, 0.0002668, -0.0428145>,
    <0.9990830, 0.0002668, -0.0428145>,
    <0.9990830, 0.0002071, -0.0428147>,
    <0.9990830, 0.0002071, -0.0428138>,
    <0.9990830, 0.0002071, -0.0428138>,
    <0.9990831, 0.0002071, -0.0428129>,
    <0.9993789, 0.0001680, -0.0352399>,
    <0.9997834, -0.0000200, -0.0208147>,
    <0.9990831, 0.0002071, -0.0428129>,
    <0.9990831, 0.0002071, -0.0428121>,
    <0.9990831, 0.0002071, -0.0428121>,
    <0.9990832, 0.0002071, -0.0428112>,
    <0.9990832, 0.0001474, -0.0428110>,
    <0.9990832, 0.0001474, -0.0428110>,
    <0.9990832, -0.0002702, -0.0428096>,
    <0.9999905, -0.0002510, -0.0043624>,
    <0.9990832, -0.0002702, -0.0428096>,
    <0.9990821, -0.0016423, -0.0428051>,
    <0.9990821, -0.0016423, -0.0428051>,
    <0.9999725, -0.0004264, 0.0074070>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9514012>,
    <0.4350041, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289898, 0.9514012>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9514012>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559177, 0.9657316>,
    <0.6289898, 0.9514012>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4350041, 0.9657316>,
    <0.5000060, 0.9664304>,
    <0.4264019, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379340, 0.9664304>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664304>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559177, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773698, 0.9671308>,
    <0.6379340, 0.9664304>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4264019, 0.9671308>,
    <0.5000061, 0.9784166>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473432, 0.9784166>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9784166>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773698, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473432, 0.9784166>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032659, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458870>,
    <0.4677608, 0.9457545>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9514012>,
    <0.4355157, 0.9458870>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9452808>,
    <0.4677603, 0.9520086>,
    <0.4676324, 0.9588701>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9514012>,
    <0.5000059, 0.9657316>,
    <0.4350041, 0.9657316>,
    <0.4677603, 0.9520086>,
    <0.5000059, 0.9583592>,
    <0.4675006, 0.9657316>,
    <0.4352834, 0.9585413>,
    <0.4031379, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4350041, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352834, 0.9585413>,
    <0.4023474, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032659, 0.9526160>,
    <0.5322510, 0.9457545>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9514012>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9520086>,
    <0.5000059, 0.9452808>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458708>,
    <0.5967411, 0.9457545>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289898, 0.9514012>,
    <0.5644961, 0.9458708>,
    <0.5967380, 0.9395004>,
    <0.6289859, 0.9452808>,
    <0.5967441, 0.9520086>,
    <0.5967475, 0.9588701>,
    <0.5644983, 0.9526160>,
    <0.6289898, 0.9514012>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967441, 0.9520086>,
    <0.6289944, 0.9583592>,
    <0.5967509, 0.9657316>,
    <0.5645003, 0.9589842>,
    <0.5322532, 0.9588701>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9514012>,
    <0.5645003, 0.9589842>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9583592>,
    <0.5322521, 0.9520086>,
    <0.6423395, 0.9457545>,
    <0.6556982, 0.9526160>,
    <0.6289898, 0.9514012>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423438, 0.9520086>,
    <0.6289859, 0.9452808>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458870>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458870>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691099, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559177, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694415, 0.9657316>,
    <0.6557974, 0.9585413>,
    <0.6424012, 0.9588701>,
    <0.6556982, 0.9526160>,
    <0.6559177, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289898, 0.9514012>,
    <0.6557974, 0.9585413>,
    <0.6424603, 0.9657316>,
    <0.6289944, 0.9583592>,
    <0.6423438, 0.9520086>,
    <0.3997804, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4350041, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4023474, 0.9657316>,
    <0.4330510, 0.9660760>,
    <0.4665132, 0.9660812>,
    <0.4310370, 0.9664312>,
    <0.4350041, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664304>,
    <0.4330510, 0.9660760>,
    <0.4675006, 0.9657316>,
    <0.5000060, 0.9661005>,
    <0.4655215, 0.9664308>,
    <0.4643627, 0.9667808>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664304>,
    <0.5000061, 0.9671308>,
    <0.4264019, 0.9671308>,
    <0.4655215, 0.9664308>,
    <0.5000060, 0.9667584>,
    <0.4631984, 0.9671308>,
    <0.4287525, 0.9667760>,
    <0.3931576, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4264019, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4287525, 0.9667760>,
    <0.3895609, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664304>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664308>,
    <0.5000060, 0.9661005>,
    <0.5322542, 0.9657316>,
    <0.5668636, 0.9661009>,
    <0.6001027, 0.9660812>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379340, 0.9664304>,
    <0.5668636, 0.9661009>,
    <0.5967509, 0.9657316>,
    <0.6337159, 0.9661005>,
    <0.6034545, 0.9664308>,
    <0.6068113, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.6379340, 0.9664304>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034545, 0.9664308>,
    <0.6421270, 0.9667584>,
    <0.6101681, 0.9671308>,
    <0.5710692, 0.9667588>,
    <0.5356086, 0.9667808>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664304>,
    <0.5710692, 0.9667588>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667584>,
    <0.5344905, 0.9664308>,
    <0.6473391, 0.9660812>,
    <0.6665054, 0.9664312>,
    <0.6379340, 0.9664304>,
    <0.6289992, 0.9657316>,
    <0.6559177, 0.9657316>,
    <0.6522197, 0.9664308>,
    <0.6337159, 0.9661005>,
    <0.6424603, 0.9657316>,
    <0.6611304, 0.9660760>,
    <0.6749770, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559177, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6611304, 0.9660760>,
    <0.6694415, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866645, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773698, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926264, 0.9671308>,
    <0.6718601, 0.9667760>,
    <0.6571745, 0.9667808>,
    <0.6665054, 0.9664312>,
    <0.6773698, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379340, 0.9664304>,
    <0.6718601, 0.9667760>,
    <0.6621316, 0.9671308>,
    <0.6421270, 0.9667584>,
    <0.6522197, 0.9664308>,
    <0.3896428, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4264019, 0.9671308>,
    <0.3895222, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3895609, 0.9671308>,
    <0.4263743, 0.9728710>,
    <0.4631912, 0.9726096>,
    <0.4263507, 0.9777601>,
    <0.4264019, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9784166>,
    <0.4263743, 0.9728710>,
    <0.4631984, 0.9671308>,
    <0.5000061, 0.9727240>,
    <0.4631779, 0.9780884>,
    <0.4631249, 0.9832389>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9784166>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631779, 0.9780884>,
    <0.5000061, 0.9835252>,
    <0.4630714, 0.9883895>,
    <0.4262411, 0.9832069>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262411, 0.9832069>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895222, 0.9777601>,
    <0.5367803, 0.9726096>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9784166>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9780884>,
    <0.5000061, 0.9727240>,
    <0.5367268, 0.9671308>,
    <0.5735535, 0.9723987>,
    <0.6103352, 0.9726096>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473432, 0.9784166>,
    <0.5735535, 0.9723987>,
    <0.6101681, 0.9671308>,
    <0.6471140, 0.9727240>,
    <0.6105023, 0.9780884>,
    <0.6106562, 0.9832389>,
    <0.5736614, 0.9777601>,
    <0.6473432, 0.9784166>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105023, 0.9780884>,
    <0.6475489, 0.9835252>,
    <0.6108101, 0.9883895>,
    <0.5737711, 0.9832050>,
    <0.5368873, 0.9832389>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9784166>,
    <0.5737711, 0.9832050>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9835252>,
    <0.5368338, 0.9780884>,
    <0.6623552, 0.9726096>,
    <0.6778190, 0.9777601>,
    <0.6473432, 0.9784166>,
    <0.6468888, 0.9671308>,
    <0.6773698, 0.9671308>,
    <0.6625813, 0.9780884>,
    <0.6471140, 0.9727240>,
    <0.6621316, 0.9671308>,
    <0.6776124, 0.9728710>,
    <0.6928064, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773698, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776124, 0.9728710>,
    <0.6926264, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930704, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930704, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780837, 0.9832069>,
    <0.6628106, 0.9832389>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473432, 0.9784166>,
    <0.6780837, 0.9832069>,
    <0.6630402, 0.9883895>,
    <0.6475489, 0.9835252>,
    <0.6625813, 0.9780884>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.05, -0.822255, -0.147353>
}

#declare Corbeau = union {
  object { TMesh007 }
  object { TMesh008 }
  object { TMesh009 }
  object { TMesh010 }
  object { TMesh011 }
  box { // Cube005
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    material {
      Tchainette
    }
    scale <0.029241, 1.931993, 0.402271>
    translate  <2.150751, 0.0, 17.966123>
  }
  object { Cube006 }
  object { Cube007 }
  object { // Cube008 -> Cube007
    Cube007
    scale <1.0, -1.0, 1.0>
    rotate <-0.0, 0.0, -0.0>
  }
  object { // Cube009 -> Cube006
    Cube006
    scale <1.0, -1.0, 1.0>
  }
  object { Cube010 }
  object { Cube011 }
  object { Elment_chainette24 }
  object { Cube012 }
  object { // Cube013 -> Cube012
    Cube012
    scale <1.0, -1.0, 1.0>
    translate  0.0*y
  }
  object { // Cube014 -> Cube011
    Cube011
    scale <1.0, -1.0, 1.0>
  }
  object { // Elment_chainette25 -> Elment_chainette24
    Elment_chainette24
    translate  <0.0, -0.0, 0.6>
  }
  object { // Elment_chainette26 -> Elment_chainette24
    Elment_chainette24
    translate  <0.0, -0.0, 1.2>
  }
  object { // Elment_chainette27 -> Elment_chainette24
    Elment_chainette24
    translate  <0.0, -0.0, 1.8>
  }
  object { HgtFld007 }
  object { Cube015 }
  object { // Cube016 -> Cube015
    Cube015
    rotate 0.0*y
    translate  <0.0, 0.471614, 0.0>
  }
  object { // Cube017 -> Cube015
    Cube015
    rotate 0.0*y
    translate  <0.0, -0.471614, 0.0>
  }
  object { TMesh012 }
  object { // TMesh013 -> TMesh012
    TMesh012
    scale <1.0, -1.0, 1.0>
    translate  0.0*x
  }
  translate  0.180579*x
  material {
    Tchainette
    scale <1.0, 0.894873, 21.21979>
  }
  scale <1.0, 1.0, 0.8>
  translate  <0.002297, 0.0, 4.035706>
}
#declare Cube088 = object {
  box { // Cube088
    <-1, -1, -1>, <1, 1, 1>
    translate  1.0*z
    material {
      T_peinture_Bois
    }
    scale <0.08, 0.08, 0.718255>
    translate  <0.0, 0.402955, 6.379402>
  }
}
#declare Cube090 = object {
  box { // Cube090
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, -1.0, 1.0>
    material {
      T_peinture_Bois
    }
    scale <0.04, 0.04, 0.616725>
    translate  <0.0, 0.34267, 6.462158>
  }
}
#declare Cube092 = object {
  box { // Cube092
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, -1.0, 0.0>
    material {
      T_peinture_Bois
    }
    scale <0.04, 0.04, 0.263746>
    rotate -90.0*x
    translate  <0.0, -0.000189, 6.471943>
  }
}
#declare Cube096 = object {
  box { // Cube096
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, -1.0, 0.0>
    material {
      T_peinture_Bois
    }
    scale <0.03, 0.02, 0.34>
    rotate -90.0*x
    translate  <0.0, -0.000189, 6.882725>
  }
}
#declare Fenetre1 = union {
  object { Cube088 }
  object { // Cube089 -> Cube088
    Cube088
    scale <1.0, -1.0, 1.0>
  }
  object { Cube090 }
  object { // Cube091 -> Cube090
    Cube090
    scale <1.0, -1.0, 1.0>
    translate  -0.000356*y
  }
  object { Cube092 }
  object { // Cube093 -> Cube092
    Cube092
    scale <1.0, 1.224063, 1.0>
    rotate <0.0, 0.0, 0.0>
    translate  <0.0, 0.0, 1.222648>
  }
  box { // Cube094
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, 0.0, 1.0>
    material {
      T_peinture_Bois
    }
    scale <0.04, 0.025, 0.604277>
    translate  6.524397*z
  }
  box { // Cube095
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, 0.0, 1.0>
    material {
      Mat_verre_noir
    }
    scale <0.01, 0.293418, 0.598053>
    translate  <0.02, 0.0, 6.524397>
  }
  object { Cube096 }
  object { // Cube097 -> Cube096
    Cube096
    rotate -0.0*x
    translate  <0.0, -0.0, 0.42323>
  }
  scale 0.679075
  translate  <-0.1, 0.0, 4.095583>
}
#declare TransSweep010 = prism {
  linear_sweep
  linear_spline
  -1.0,0.0
  5  // control points
  <0.002925, -0.103464>,
  <0.58702, -0.230472>,
  <0.58702, 0.23613>,
  <0.002925, 0.097901>,
  <0.002925, -0.103464>
  rotate -x*90
  translate  -0.5*z
  scale <1.0, 1.0, 0.6>
  rotate -90.0*y
  translate  7.714479*z
}
#declare Entourage_fenetre1 = union {
  object { Cube098 }
  object { Cube099 }
  object { // Cube100 -> Cube099
    Cube099
    translate  <-0.0, 0.0, 0.629272>
  }
  object { // Cube101 -> Cube098
    Cube098
    translate  <0.0, 0.0, 0.629272>
  }
  object { // Cube102 -> Cube098
    Cube098
    translate  <0.0, 0.0, 1.258543>
  }
  object { TransSweep006 }
  object { // TransSweep007 -> TransSweep006
    TransSweep006
    scale <1.0, -1.0, 1.0>
    rotate -0.0*y
    translate  0.0*x
  }
  object { TransSweep008 }
  object { // TransSweep009 -> TransSweep008
    TransSweep008
    scale <1.0, -1.0, 1.0>
    rotate -0.0*y
    translate  0.0*x
  }
  object { TransSweep010 }
  scale 0.679075
  translate  4.095583*z
}
#declare Ouvertures1 = union {
  object { Entourage_fenetre1 }
}
#declare Decoupefenetres1 = difference {
  object { Ouvertures1 }
  box { // Cube103
    <-1, -1, -1>, <1, 1, 1>
    translate  1.0*z
    scale <-0.5, -0.24636, -0.466453>
    rotate <-180.0, 0.0, -180.0>
    translate  <0.25, 0.0, 8.443887>
    material {
      Tchainette
      // Transform to parent space
    }
  }
  material {
    Tchainette
  }
}
#declare Ensemble_fenetre6 = union {
  object { Fenetre1 }
  object { Decoupefenetres1 }
  translate  <-2.422953, 0.0, -0.125737>
}
#declare Cube104 = object {
  box { // Cube104
    <-1, -1, -1>, <1, 1, 1>
    translate  1.0*z
    scale <-0.5, -0.24636, -0.466453>
    rotate <180.0, 0.0, -90.0>
    translate  <0.0, -2.172953, 19.744457>
    material {
      Tchainette
      // Transform to parent space
    }
  }
}
#declare TMesh003 = mesh2 {
  vertex_vectors {
    582,
    <2.1729169, 0.1670810, 18.5417983>,
    <2.0016629, 0.2021583, 18.5417983>,
    <2.0011917, 0.0330344, 18.5417983>,
    <2.1732628, -0.0371492, 18.5417983>,
    <2.0872899, 0.1846196, 18.5417983>,
    <2.0014273, 0.1175963, 18.5417983>,
    <2.0872272, -0.0020574, 18.5417983>,
    <2.1730898, 0.0649659, 18.5417983>,
    <2.0872586, 0.0912811, 18.5417983>,
    <2.3453338, -0.1073328, 18.5417983>,
    <2.3441709, 0.1320038, 18.5417983>,
    <2.2592983, -0.0722410, 18.5417983>,
    <2.3447524, 0.0123355, 18.5417983>,
    <2.2585439, 0.1495424, 18.5417983>,
    <2.2589211, 0.0386507, 18.5417983>,
    <2.3430079, 0.3713404, 18.5417983>,
    <2.1725710, 0.3713112, 18.5417983>,
    <2.3435894, 0.2516721, 18.5417983>,
    <2.2577895, 0.3713258, 18.5417983>,
    <2.1727439, 0.2691961, 18.5417983>,
    <2.2581667, 0.2604341, 18.5417983>,
    <2.0021340, 0.3712821, 18.5417983>,
    <2.0873525, 0.3712967, 18.5417983>,
    <2.0018984, 0.2867202, 18.5417983>,
    <2.0873212, 0.2779581, 18.5417983>,
    <2.0586650, 0.0090783, 18.1202395>,
    <2.0032615, 0.0316559, 18.1202395>,
    <2.0033220, 0.0316156, 18.1217627>,
    <2.0553199, 0.0104277, 18.1217627>,
    <2.0309633, 0.0203671, 18.1202395>,
    <2.0032917, 0.0316358, 18.1210011>,
    <2.0293209, 0.0210217, 18.1217627>,
    <2.0569925, 0.0097530, 18.1210011>,
    <2.0301421, 0.0206944, 18.1210011>,
    <2.1073179, -0.0107603, 18.1217627>,
    <2.1140685, -0.0134993, 18.1202395>,
    <2.0813189, -0.0001663, 18.1217627>,
    <2.1106932, -0.0121298, 18.1210011>,
    <2.0863668, -0.0022105, 18.1202395>,
    <2.0838428, -0.0011884, 18.1210011>,
    <2.1208191, -0.0162383, 18.1187163>,
    <2.0620101, 0.0077289, 18.1187163>,
    <2.1174438, -0.0148688, 18.1194779>,
    <2.0914146, -0.0042547, 18.1187163>,
    <2.0603376, 0.0084036, 18.1194779>,
    <2.0888907, -0.0032326, 18.1194779>,
    <2.0032011, 0.0316961, 18.1187163>,
    <2.0326056, 0.0197125, 18.1187163>,
    <2.0032313, 0.0316760, 18.1194779>,
    <2.0317844, 0.0200398, 18.1194779>,
    <2.1140920, 0.1791675, 18.1202395>,
    <2.1073761, 0.1805442, 18.1217627>,
    <2.1140803, 0.0828341, 18.1202395>,
    <2.1073470, 0.0848920, 18.1217627>,
    <2.1107340, 0.1798559, 18.1210011>,
    <2.1107136, 0.0838630, 18.1210011>,
    <2.1074342, 0.3718488, 18.1217627>,
    <2.1141156, 0.3718344, 18.1202395>,
    <2.1074051, 0.2761965, 18.1217627>,
    <2.1107749, 0.3718416, 18.1210011>,
    <2.1141038, 0.2755010, 18.1202395>,
    <2.1107545, 0.2758487, 18.1210011>,
    <2.1207969, 0.3718200, 18.1187163>,
    <2.1208080, 0.1777908, 18.1187163>,
    <2.1174562, 0.3718272, 18.1194779>,
    <2.1208025, 0.2748054, 18.1187163>,
    <2.1174500, 0.1784792, 18.1194779>,
    <2.1174531, 0.2751532, 18.1194779>,
    <2.1208136, 0.0807763, 18.1187163>,
    <2.1174469, 0.0818052, 18.1194779>,
    <2.0592428, 0.3718157, 18.1202395>,
    <2.0559348, 0.3718304, 18.1217627>,
    <2.0866792, 0.3718250, 18.1202395>,
    <2.0816845, 0.3718396, 18.1217627>,
    <2.0575888, 0.3718230, 18.1210011>,
    <2.0841818, 0.3718323, 18.1210011>,
    <2.0044353, 0.3718120, 18.1217627>,
    <2.0043701, 0.3717970, 18.1202395>,
    <2.0301850, 0.3718212, 18.1217627>,
    <2.0044027, 0.3718045, 18.1210011>,
    <2.0318064, 0.3718063, 18.1202395>,
    <2.0309957, 0.3718138, 18.1210011>,
    <2.0043048, 0.3717820, 18.1187163>,
    <2.0625508, 0.3718010, 18.1187163>,
    <2.0043374, 0.3717895, 18.1194779>,
    <2.0334278, 0.3717915, 18.1187163>,
    <2.0608968, 0.3718083, 18.1194779>,
    <2.0326171, 0.3717989, 18.1194779>,
    <2.0916739, 0.3718105, 18.1187163>,
    <2.0891765, 0.3718177, 18.1194779>,
    <2.0689854, 0.0049151, 18.1370901>,
    <2.0030751, 0.0317800, 18.1370901>,
    <2.0360303, 0.0183476, 18.1370901>,
    <2.0031381, 0.0317381, 18.1279032>,
    <2.0654978, 0.0063220, 18.1279032>,
    <2.0343179, 0.0190301, 18.1279032>,
    <2.1348957, -0.0219497, 18.1370901>,
    <2.1278574, -0.0190940, 18.1279032>,
    <2.1019406, -0.0085173, 18.1370901>,
    <2.0966776, -0.0063860, 18.1279032>,
    <2.1489723, -0.0276612, 18.1554639>,
    <2.0759607, 0.0021014, 18.1554639>,
    <2.1419340, -0.0248054, 18.1462770>,
    <2.1124665, -0.0127799, 18.1554639>,
    <2.0724731, 0.0035083, 18.1462770>,
    <2.1072035, -0.0106486, 18.1462770>,
    <2.0029492, 0.0318639, 18.1554639>,
    <2.0394549, 0.0169827, 18.1554639>,
    <2.0030121, 0.0318220, 18.1462770>,
    <2.0377426, 0.0176651, 18.1462770>,
    <2.1348124, 0.1749201, 18.1370901>,
    <2.1348540, 0.0764852, 18.1370901>,
    <2.1278102, 0.1763555, 18.1279032>,
    <2.1278338, 0.0786307, 18.1279032>,
    <2.1347291, 0.3717899, 18.1370901>,
    <2.1277630, 0.3718049, 18.1279032>,
    <2.1347707, 0.2733550, 18.1370901>,
    <2.1277866, 0.2740802, 18.1279032>,
    <2.1486612, 0.3717598, 18.1554639>,
    <2.1488168, 0.1720493, 18.1554639>,
    <2.1416951, 0.3717749, 18.1462770>,
    <2.1487390, 0.2719046, 18.1554639>,
    <2.1418146, 0.1734847, 18.1462770>,
    <2.1417549, 0.2726298, 18.1462770>,
    <2.1488945, 0.0721941, 18.1554639>,
    <2.1418743, 0.0743396, 18.1462770>,
    <2.0694489, 0.3717703, 18.1370901>,
    <2.1020890, 0.3717801, 18.1370901>,
    <2.0659999, 0.3717856, 18.1279032>,
    <2.0968814, 0.3717953, 18.1279032>,
    <2.0041687, 0.3717506, 18.1370901>,
    <2.0042367, 0.3717663, 18.1279032>,
    <2.0368088, 0.3717604, 18.1370901>,
    <2.0351183, 0.3717759, 18.1279032>,
    <2.0040326, 0.3717193, 18.1554639>,
    <2.0763469, 0.3717395, 18.1554639>,
    <2.0041006, 0.3717349, 18.1462770>,
    <2.0401897, 0.3717294, 18.1554639>,
    <2.0728979, 0.3717549, 18.1462770>,
    <2.0384993, 0.3717449, 18.1462770>,
    <2.1125041, 0.3717497, 18.1554639>,
    <2.1072965, 0.3717649, 18.1462770>,
    <2.0809036, 0.0001075, 18.1573801>,
    <2.0028599, 0.0319234, 18.1573801>,
    <2.0418818, 0.0160154, 18.1573801>,
    <2.0029045, 0.0318937, 18.1564220>,
    <2.0784322, 0.0011044, 18.1564220>,
    <2.0406684, 0.0164990, 18.1564220>,
    <2.1589474, -0.0317085, 18.1573801>,
    <2.1539599, -0.0296848, 18.1564220>,
    <2.1199255, -0.0158005, 18.1573801>,
    <2.1161960, -0.0142902, 18.1564220>,
    <2.1689225, -0.0357558, 18.1592964>,
    <2.0858466, -0.0018864, 18.1592964>,
    <2.1639350, -0.0337321, 18.1583383>,
    <2.1273846, -0.0188211, 18.1592964>,
    <2.0833751, -0.0008895, 18.1583383>,
    <2.1236550, -0.0173108, 18.1583383>,
    <2.0027706, 0.0319829, 18.1592964>,
    <2.0443086, 0.0150482, 18.1592964>,
    <2.0028152, 0.0319531, 18.1583383>,
    <2.0430952, 0.0155318, 18.1583383>,
    <2.1587407, 0.1700150, 18.1573801>,
    <2.1588441, 0.0691533, 18.1573801>,
    <2.1537787, 0.1710322, 18.1564220>,
    <2.1538693, 0.0706737, 18.1564220>,
    <2.1585340, 0.3717385, 18.1573801>,
    <2.1535976, 0.3717492, 18.1564220>,
    <2.1586373, 0.2708768, 18.1573801>,
    <2.1536882, 0.2713907, 18.1564220>,
    <2.1684068, 0.3717172, 18.1592964>,
    <2.1686646, 0.1679807, 18.1592964>,
    <2.1634704, 0.3717279, 18.1583383>,
    <2.1685357, 0.2698490, 18.1592964>,
    <2.1637027, 0.1689979, 18.1583383>,
    <2.1635865, 0.2703629, 18.1583383>,
    <2.1687936, 0.0661125, 18.1592964>,
    <2.1638188, 0.0676329, 18.1583383>,
    <2.0812351, 0.3717178, 18.1573801>,
    <2.1198845, 0.3717282, 18.1573801>,
    <2.0787910, 0.3717287, 18.1564220>,
    <2.1161943, 0.3717389, 18.1564220>,
    <2.0039361, 0.3716971, 18.1573801>,
    <2.0039844, 0.3717082, 18.1564220>,
    <2.0425856, 0.3717074, 18.1573801>,
    <2.0413877, 0.3717184, 18.1564220>,
    <2.0038397, 0.3716749, 18.1592964>,
    <2.0861232, 0.3716960, 18.1592964>,
    <2.0038879, 0.3716860, 18.1583383>,
    <2.0449814, 0.3716854, 18.1592964>,
    <2.0836791, 0.3717069, 18.1583383>,
    <2.0437835, 0.3716964, 18.1583383>,
    <2.1272650, 0.3717066, 18.1592964>,
    <2.1235748, 0.3717174, 18.1583383>,
    <2.0869275, -0.0023231, 18.2324892>,
    <2.0027700, 0.0319832, 18.2344341>,
    <2.0448476, 0.0148309, 18.2333227>,
    <2.0027703, 0.0319831, 18.1968653>,
    <2.0858626, -0.0018929, 18.1968653>,
    <2.0443164, 0.0150451, 18.1968653>,
    <2.1710991, -0.0366389, 18.2322113>,
    <2.1689548, -0.0357689, 18.1968653>,
    <2.1290121, -0.0194802, 18.2322113>,
    <2.1274087, -0.0188309, 18.1968653>,
    <2.1901713, -0.0443772, 18.2873438>,
    <2.0963900, -0.0061433, 18.2890109>,
    <2.1774673, -0.0392227, 18.2631118>,
    <2.1432736, -0.0252555, 18.2873438>,
    <2.0900901, -0.0036007, 18.2642232>,
    <2.1337740, -0.0214086, 18.2631118>,
    <2.0027694, 0.0319836, 18.3095719>,
    <2.0495348, 0.0129501, 18.2940122>,
    <2.0027697, 0.0319834, 18.2720030>,
    <2.0464252, 0.0141945, 18.2675574>,
    <2.1708301, 0.1675368, 18.2322113>,
    <2.1709646, 0.0654490, 18.2322113>,
    <2.1686968, 0.1679741, 18.1968653>,
    <2.1688258, 0.0661026, 18.1968653>,
    <2.1705610, 0.3717126, 18.2322113>,
    <2.1684387, 0.3717171, 18.1968653>,
    <2.1706955, 0.2696247, 18.2322113>,
    <2.1685678, 0.2698456, 18.1968653>,
    <2.1894375, 0.3716718, 18.2873438>,
    <2.1898044, 0.1636473, 18.2873438>,
    <2.1768638, 0.3716990, 18.2631118>,
    <2.1896209, 0.2676596, 18.2873438>,
    <2.1771655, 0.1662381, 18.2631118>,
    <2.1770147, 0.2689685, 18.2631118>,
    <2.1899878, 0.0596350, 18.2873438>,
    <2.1773164, 0.0635077, 18.2631118>,
    <2.0871924, 0.3716919, 18.2324892>,
    <2.1288754, 0.3717019, 18.2322113>,
    <2.0861391, 0.3716960, 18.1968653>,
    <2.1272889, 0.3717065, 18.1968653>,
    <2.0038391, 0.3716747, 18.2344341>,
    <2.0038394, 0.3716748, 18.1968653>,
    <2.0455144, 0.3716830, 18.2333227>,
    <2.0449892, 0.3716854, 18.1968653>,
    <2.0038384, 0.3716746, 18.3095719>,
    <2.0965512, 0.3716532, 18.2890109>,
    <2.0038387, 0.3716746, 18.2720030>,
    <2.0501463, 0.3716527, 18.2940122>,
    <2.0903206, 0.3716797, 18.2642232>,
    <2.0470746, 0.3716760, 18.2675574>,
    <2.1429867, 0.3716607, 18.2873438>,
    <2.1335871, 0.3716882, 18.2631118>,
    <2.1194806, -0.0154541, 18.3131904>,
    <2.0021640, 0.0323869, 18.3135798>,
    <2.0608223, 0.0084664, 18.3133573>,
    <2.0024667, 0.0321852, 18.3115759>,
    <2.1068665, -0.0103682, 18.3037960>,
    <2.0546619, 0.0109117, 18.3071303>,
    <2.2367979, -0.0632955, 18.3131347>,
    <2.2113231, -0.0529593, 18.3026846>,
    <2.1781392, -0.0393747, 18.3131347>,
    <2.1590901, -0.0316606, 18.3026846>,
    <2.2842175, -0.0825355, 18.3353648>,
    <2.1429646, -0.0249237, 18.3340315>,
    <2.2624710, -0.0737121, 18.3226946>,
    <2.2135978, -0.0537341, 18.3353648>,
    <2.1321932, -0.0205798, 18.3218058>,
    <2.1973366, -0.0471489, 18.3226946>,
    <2.0015586, 0.0327901, 18.3175878>,
    <2.0723044, 0.0039047, 18.3300317>,
    <2.0018613, 0.0325885, 18.3155838>,
    <2.0670317, 0.0060014, 18.3191392>,
    <2.2361918, 0.1541384, 18.3131347>,
    <2.2364948, 0.0454214, 18.3131347>,
    <2.2108477, 0.1593337, 18.3026846>,
    <2.2110854, 0.0531872, 18.3026846>,
    <2.2355857, 0.3715722, 18.3131347>,
    <2.2103722, 0.3716266, 18.3026846>,
    <2.2358887, 0.2628553, 18.3131347>,
    <2.2106099, 0.2654801, 18.3026846>,
    <2.2825188, 0.3714709, 18.3353648>,
    <2.2833682, 0.1444677, 18.3353648>,
    <2.2609953, 0.3715174, 18.3226946>,
    <2.2829435, 0.2579693, 18.3353648>,
    <2.2617332, 0.1489027, 18.3226946>,
    <2.2613642, 0.2602100, 18.3226946>,
    <2.2837929, 0.0309661, 18.3353648>,
    <2.2621021, 0.0375953, 18.3226946>,
    <2.1193847, 0.3715480, 18.3131904>,
    <2.1774851, 0.3715601, 18.3131347>,
    <2.1069112, 0.3716059, 18.3037960>,
    <2.1586366, 0.3716151, 18.3026846>,
    <2.0031844, 0.3715240, 18.3135798>,
    <2.0035114, 0.3715993, 18.3115759>,
    <2.0612845, 0.3715360, 18.3133573>,
    <2.0552062, 0.3716014, 18.3071303>,
    <2.0025303, 0.3713733, 18.3175878>,
    <2.1426072, 0.3714412, 18.3340315>,
    <2.0028573, 0.3714486, 18.3155838>,
    <2.0726150, 0.3714179, 18.3300317>,
    <2.1319555, 0.3714897, 18.3218058>,
    <2.0674113, 0.3714703, 18.3191392>,
    <2.2125703, 0.3714577, 18.3353648>,
    <2.1964803, 0.3715047, 18.3226946>,
    <2.1535564, -0.0291992, 18.3800376>,
    <2.0015296, 0.0328094, 18.3784821>,
    <2.0775441, 0.0018043, 18.3793709>,
    <2.0015441, 0.0327997, 18.3480349>,
    <2.1497555, -0.0276642, 18.3542569>,
    <2.0756543, 0.0025648, 18.3515903>,
    <2.3055697, -0.0911989, 18.3802598>,
    <2.2979128, -0.0880922, 18.3551457>,
    <2.2295641, -0.0601998, 18.3802598>,
    <2.2238387, -0.0578812, 18.3551457>,
    <2.3108192, -0.0933288, 18.4393764>,
    <2.1561599, -0.0302501, 18.4393764>,
    <2.3092008, -0.0926722, 18.4089292>,
    <2.2334896, -0.0617895, 18.4393764>,
    <2.1553580, -0.0299266, 18.4089292>,
    <2.2322794, -0.0612994, 18.4089292>,
    <2.0015006, 0.0328287, 18.4393764>,
    <2.0788303, 0.0012893, 18.4393764>,
    <2.0015151, 0.0328190, 18.4089292>,
    <2.0784365, 0.0014462, 18.4089292>,
    <2.3046107, 0.1401132, 18.3802598>,
    <2.3050902, 0.0244572, 18.3802598>,
    <2.2969932, 0.1416747, 18.3551457>,
    <2.2974530, 0.0267913, 18.3551457>,
    <2.3036518, 0.3714253, 18.3802598>,
    <2.2960735, 0.3714417, 18.3551457>,
    <2.3041313, 0.2557693, 18.3802598>,
    <2.2965334, 0.2565582, 18.3551457>,
    <2.3088475, 0.3714141, 18.4393764>,
    <2.3098333, 0.1390426, 18.4393764>,
    <2.3072457, 0.3714176, 18.4089292>,
    <2.3093404, 0.2552284, 18.4393764>,
    <2.3082233, 0.1393727, 18.4089292>,
    <2.3077345, 0.2553951, 18.4089292>,
    <2.3103263, 0.0228569, 18.4393764>,
    <2.3087121, 0.0233502, 18.4089292>,
    <2.1530827, 0.3713974, 18.3800376>,
    <2.2283685, 0.3714116, 18.3802598>,
    <2.1493233, 0.3714124, 18.3542569>,
    <2.2227033, 0.3714282, 18.3551457>,
    <2.0024990, 0.3713661, 18.3784821>,
    <2.0025147, 0.3713697, 18.3480349>,
    <2.0777921, 0.3713820, 18.3793709>,
    <2.0759238, 0.3713922, 18.3515903>,
    <2.0024677, 0.3713589, 18.4393764>,
    <2.1556576, 0.3713865, 18.4393764>,
    <2.0024834, 0.3713625, 18.4089292>,
    <2.0790627, 0.3713727, 18.4393764>,
    <2.1548645, 0.3713900, 18.4089292>,
    <2.0786740, 0.3713763, 18.4089292>,
    <2.2322525, 0.3714003, 18.4393764>,
    <2.2310551, 0.3714038, 18.4089292>,
    <2.1647113, -0.0336996, 18.4393764>,
    <2.0013462, 0.0329316, 18.4393764>,
    <2.0830288, -0.0003840, 18.4393764>,
    <2.0014234, 0.0328801, 18.4393764>,
    <2.1604356, -0.0319749, 18.4393764>,
    <2.0809295, 0.0004526, 18.4393764>,
    <2.3280765, -0.1003308, 18.4393764>,
    <2.3194479, -0.0968298, 18.4393764>,
    <2.2463939, -0.0670152, 18.4393764>,
    <2.2399417, -0.0644023, 18.4393764>,
    <2.3453338, -0.1073328, 18.4393764>,
    <2.1732628, -0.0371492, 18.4393764>,
    <2.3367052, -0.1038318, 18.4393764>,
    <2.2592983, -0.0722410, 18.4393764>,
    <2.1689871, -0.0354244, 18.4393764>,
    <2.2528461, -0.0696281, 18.4393764>,
    <2.0011917, 0.0330344, 18.4393764>,
    <2.0872272, -0.0020574, 18.4393764>,
    <2.0012689, 0.0329830, 18.4393764>,
    <2.0851280, -0.0012207, 18.4393764>,
    <2.3270021, 0.1355232, 18.4393764>,
    <2.3275393, 0.0175962, 18.4393764>,
    <2.3184177, 0.1372829, 18.4393764>,
    <2.3189328, 0.0202265, 18.4393764>,
    <2.3259277, 0.3713772, 18.4393764>,
    <2.3173876, 0.3713957, 18.4393764>,
    <2.3264649, 0.2534502, 18.4393764>,
    <2.3179027, 0.2543393, 18.4393764>,
    <2.3430079, 0.3713404, 18.4393764>,
    <2.3441709, 0.1320038, 18.4393764>,
    <2.3344678, 0.3713588, 18.4393764>,
    <2.3435894, 0.2516721, 18.4393764>,
    <2.3355865, 0.1337635, 18.4393764>,
    <2.3350272, 0.2525612, 18.4393764>,
    <2.3447524, 0.0123355, 18.4393764>,
    <2.3361458, 0.0149659, 18.4393764>,
    <2.1641143, 0.3713489, 18.4393764>,
    <2.2450210, 0.3713631, 18.4393764>,
    <2.1598859, 0.3713677, 18.4393764>,
    <2.2386368, 0.3713817, 18.4393764>,
    <2.0023009, 0.3713205, 18.4393764>,
    <2.0023843, 0.3713397, 18.4393764>,
    <2.0832076, 0.3713347, 18.4393764>,
    <2.0811351, 0.3713537, 18.4393764>,
    <2.0021340, 0.3712821, 18.4393764>,
    <2.1725710, 0.3713112, 18.4393764>,
    <2.0022174, 0.3713013, 18.4393764>,
    <2.0873525, 0.3712967, 18.4393764>,
    <2.1683426, 0.3713300, 18.4393764>,
    <2.0852800, 0.3713157, 18.4393764>,
    <2.2577895, 0.3713258, 18.4393764>,
    <2.2514052, 0.3713444, 18.4393764>,
    <2.1732628, -0.0371492, 18.4905874>,
    <2.0011917, 0.0330344, 18.4905874>,
    <2.0872272, -0.0020574, 18.4905874>,
    <2.0011917, 0.0330344, 18.4649819>,
    <2.1732628, -0.0371492, 18.4649819>,
    <2.0872272, -0.0020574, 18.4649819>,
    <2.3453338, -0.1073328, 18.4905874>,
    <2.3453338, -0.1073328, 18.4649819>,
    <2.2592983, -0.0722410, 18.4905874>,
    <2.2592983, -0.0722410, 18.4649819>,
    <2.3453338, -0.1073328, 18.5161929>,
    <2.1732628, -0.0371492, 18.5161929>,
    <2.2592983, -0.0722410, 18.5161929>,
    <2.0011917, 0.0330344, 18.5161929>,
    <2.0872272, -0.0020574, 18.5161929>,
    <2.3441709, 0.1320038, 18.4905874>,
    <2.3447524, 0.0123355, 18.4905874>,
    <2.3441709, 0.1320038, 18.4649819>,
    <2.3447524, 0.0123355, 18.4649819>,
    <2.3430079, 0.3713404, 18.4905874>,
    <2.3430079, 0.3713404, 18.4649819>,
    <2.3435894, 0.2516721, 18.4905874>,
    <2.3435894, 0.2516721, 18.4649819>,
    <2.3430079, 0.3713404, 18.5161929>,
    <2.3441709, 0.1320038, 18.5161929>,
    <2.3435894, 0.2516721, 18.5161929>,
    <2.3447524, 0.0123355, 18.5161929>,
    <2.1725710, 0.3713112, 18.4905874>,
    <2.2577895, 0.3713258, 18.4905874>,
    <2.1725710, 0.3713112, 18.4649819>,
    <2.2577895, 0.3713258, 18.4649819>,
    <2.0021340, 0.3712821, 18.4905874>,
    <2.0021340, 0.3712821, 18.4649819>,
    <2.0873525, 0.3712967, 18.4905874>,
    <2.0873525, 0.3712967, 18.4649819>,
    <2.0021340, 0.3712821, 18.5161929>,
    <2.1725710, 0.3713112, 18.5161929>,
    <2.0873525, 0.3712967, 18.5161929>,
    <2.2577895, 0.3713258, 18.5161929>,
    <2.0016629, 0.2021583, 18.4905874>,
    <2.0011917, 0.0330344, 18.4905874>,
    <2.0016629, 0.2021583, 18.4393764>,
    <2.0014273, 0.1175963, 18.4905874>,
    <2.0011917, 0.0330344, 18.4649819>,
    <2.0014273, 0.1175963, 18.4393764>,
    <2.0016629, 0.2021583, 18.4649819>,
    <2.0014273, 0.1175963, 18.4649819>,
    <2.0021340, 0.3712821, 18.4905874>,
    <2.0018984, 0.2867202, 18.4393764>,
    <2.0021340, 0.3712821, 18.4649819>,
    <2.0018984, 0.2867202, 18.4905874>,
    <2.0018984, 0.2867202, 18.4649819>,
    <2.0016629, 0.2021583, 18.5417983>,
    <2.0021340, 0.3712821, 18.5161929>,
    <2.0018984, 0.2867202, 18.5417983>,
    <2.0016629, 0.2021583, 18.5161929>,
    <2.0018984, 0.2867202, 18.5161929>,
    <2.0014273, 0.1175963, 18.5417983>,
    <2.0011917, 0.0330344, 18.5161929>,
    <2.0014273, 0.1175963, 18.5161929>,
    <2.0018235, 0.2021260, 18.4393764>,
    <2.0019842, 0.2020938, 18.4393764>,
    <2.0019038, 0.2021099, 18.4393764>,
    <2.0017424, 0.1174612, 18.4393764>,
    <2.0015848, 0.1175288, 18.4393764>,
    <2.0016636, 0.1174950, 18.4393764>,
    <2.0016629, 0.2021583, 18.4393764>,
    <2.0014273, 0.1175963, 18.4393764>,
    <2.0017432, 0.2021421, 18.4393764>,
    <2.0015061, 0.1175626, 18.4393764>,
    <2.0018984, 0.2867202, 18.4393764>,
    <2.0020622, 0.2867233, 18.4393764>,
    <2.0019803, 0.2867217, 18.4393764>,
    <2.0022259, 0.2867264, 18.4393764>,
    <2.0021441, 0.2867248, 18.4393764>,
    <2.0020143, 0.2020878, 18.3784821>,
    <2.0015296, 0.0328094, 18.3784821>,
    <2.0020444, 0.2020817, 18.3175878>,
    <2.0017719, 0.1174486, 18.3784821>,
    <2.0015441, 0.0327997, 18.3480349>,
    <2.0018015, 0.1174359, 18.3175878>,
    <2.0020294, 0.2020847, 18.3480349>,
    <2.0017867, 0.1174422, 18.3480349>,
    <2.0024990, 0.3713661, 18.3784821>,
    <2.0022874, 0.2867275, 18.3175878>,
    <2.0025147, 0.3713697, 18.3480349>,
    <2.0022567, 0.2867270, 18.3784821>,
    <2.0022720, 0.2867272, 18.3480349>,
    <2.0019842, 0.2020938, 18.4393764>,
    <2.0024834, 0.3713625, 18.4089292>,
    <2.0022259, 0.2867264, 18.4393764>,
    <2.0019992, 0.2020908, 18.4089292>,
    <2.0022413, 0.2867267, 18.4089292>,
    <2.0017424, 0.1174612, 18.4393764>,
    <2.0015151, 0.0328190, 18.4089292>,
    <2.0017572, 0.1174549, 18.4089292>,
    <2.0026742, 0.2019554, 18.3135798>,
    <2.0033039, 0.2018291, 18.3095719>,
    <2.0029891, 0.2018923, 18.3115759>,
    <2.0030367, 0.1169064, 18.3095719>,
    <2.0024191, 0.1171711, 18.3135798>,
    <2.0027279, 0.1170388, 18.3115759>,
    <2.0020444, 0.2020817, 18.3175878>,
    <2.0018015, 0.1174359, 18.3175878>,
    <2.0023593, 0.2020186, 18.3155838>,
    <2.0021103, 0.1173035, 18.3155838>,
    <2.0022874, 0.2867275, 18.3175878>,
    <2.0029293, 0.2867397, 18.3135798>,
    <2.0026083, 0.2867336, 18.3155838>,
    <2.0035712, 0.2867518, 18.3095719>,
    <2.0032502, 0.2867458, 18.3115759>,
    <2.0033045, 0.2018290, 18.2344341>,
    <2.0027700, 0.0319832, 18.2344341>,
    <2.0033051, 0.2018289, 18.1592964>,
    <2.0030373, 0.1169061, 18.2344341>,
    <2.0027703, 0.0319831, 18.1968653>,
    <2.0030379, 0.1169059, 18.1592964>,
    <2.0033048, 0.2018289, 18.1968653>,
    <2.0030376, 0.1169060, 18.1968653>,
    <2.0038391, 0.3716747, 18.2344341>,
    <2.0035724, 0.2867519, 18.1592964>,
    <2.0038394, 0.3716748, 18.1968653>,
    <2.0035718, 0.2867518, 18.2344341>,
    <2.0035721, 0.2867519, 18.1968653>,
    <2.0033039, 0.2018291, 18.3095719>,
    <2.0038387, 0.3716746, 18.2720030>,
    <2.0035712, 0.2867518, 18.3095719>,
    <2.0033042, 0.2018290, 18.2720030>,
    <2.0035715, 0.2867518, 18.2720030>,
    <2.0030367, 0.1169064, 18.3095719>,
    <2.0027697, 0.0319834, 18.2720030>,
    <2.0030370, 0.1169062, 18.2720030>,
    <2.0033980, 0.2018102, 18.1573801>,
    <2.0034909, 0.2017916, 18.1554639>,
    <2.0034444, 0.2018009, 18.1564220>,
    <2.0032200, 0.1168278, 18.1554639>,
    <2.0031289, 0.1168668, 18.1573801>,
    <2.0031745, 0.1168473, 18.1564220>,
    <2.0033051, 0.2018289, 18.1592964>,
    <2.0030379, 0.1169059, 18.1592964>,
    <2.0033516, 0.2018195, 18.1583383>,
    <2.0030834, 0.1168863, 18.1583383>,
    <2.0035724, 0.2867519, 18.1592964>,
    <2.0036671, 0.2867537, 18.1573801>,
    <2.0036197, 0.2867528, 18.1583383>,
    <2.0037617, 0.2867554, 18.1554639>,
    <2.0037144, 0.2867545, 18.1564220>,
    <2.0036787, 0.2017539, 18.1389725>,
    <2.0031356, 0.0317398, 18.1386133>,
    <2.0038104, 0.2017275, 18.1258340>,
    <2.0034061, 0.1167471, 18.1388528>,
    <2.0032288, 0.0316777, 18.1301880>,
    <2.0035448, 0.1166831, 18.1251156>,
    <2.0037576, 0.2017381, 18.1316249>,
    <2.0034892, 0.1167087, 18.1311460>,
    <2.0042339, 0.3717656, 18.1386133>,
    <2.0041002, 0.2867671, 18.1251156>,
    <2.0043346, 0.3717888, 18.1301880>,
    <2.0039553, 0.2867600, 18.1388528>,
    <2.0040421, 0.2867643, 18.1311460>,
    <2.0034909, 0.2017916, 18.1554639>,
    <2.0041333, 0.3717425, 18.1470386>,
    <2.0037617, 0.2867554, 18.1554639>,
    <2.0035878, 0.2017722, 18.1470386>,
    <2.0038605, 0.2867573, 18.1470386>,
    <2.0032200, 0.1168278, 18.1554639>,
    <2.0030424, 0.0318019, 18.1470386>,
    <2.0033151, 0.1167870, 18.1470386>,
    <2.0038098, 0.2017276, 18.1205987>,
    <2.0038231, 0.2017250, 18.1224380>,
    <2.0035347, 0.1166920, 18.1204790>,
    <2.0035534, 0.1166812, 18.1219591>,
    <2.0037530, 0.2017390, 18.1187163>,
    <2.0034770, 0.1167176, 18.1187163>,
    <2.0037844, 0.2017327, 18.1194779>,
    <2.0035079, 0.1167044, 18.1194779>,
    <2.0040289, 0.2867605, 18.1187163>,
    <2.0040889, 0.2867625, 18.1204790>,
    <2.0040609, 0.2867611, 18.1194779>,
    <2.0041089, 0.2867655, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.3773516, 0.9260271, 0.0089233>,
    <0.3773535, 0.9260316, 0.0083508>,
    <0.3773669, 0.9260259, 0.0083853>,
    <0.3773651, 0.9260214, 0.0089402>,
    <0.3773632, 0.9260167, 0.0094950>,
    <0.3773497, 0.9260222, 0.0094957>,
    <0.3773497, 0.9260222, 0.0094957>,
    <0.3773353, 0.9260280, 0.0094964>,
    <0.3773373, 0.9260331, 0.0089052>,
    <0.3773373, 0.9260331, 0.0089052>,
    <0.3773392, 0.9260378, 0.0083140>,
    <0.3773553, 0.9260359, 0.0077783>,
    <0.3773686, 0.9260300, 0.0078304>,
    <0.3773392, 0.9260378, 0.0083140>,
    <0.3773410, 0.9260422, 0.0077228>,
    <0.3773410, 0.9260422, 0.0077228>,
    <0.3773427, 0.9260462, 0.0071315>,
    <0.3773569, 0.9260399, 0.0072058>,
    <0.3773569, 0.9260399, 0.0072058>,
    <0.3773702, 0.9260339, 0.0072755>,
    <0.3773811, 0.9260245, 0.0078794>,
    <0.3773795, 0.9260204, 0.0084177>,
    <0.3773702, 0.9260339, 0.0072755>,
    <0.3773827, 0.9260283, 0.0073411>,
    <0.3773827, 0.9260283, 0.0073411>,
    <0.3773945, 0.9260230, 0.0074028>,
    <0.3773930, 0.9260193, 0.0079256>,
    <0.3773930, 0.9260193, 0.0079256>,
    <0.3773913, 0.9260153, 0.0084483>,
    <0.3773777, 0.9260161, 0.0089561>,
    <0.3773913, 0.9260153, 0.0084483>,
    <0.3773896, 0.9260111, 0.0089711>,
    <0.3773896, 0.9260111, 0.0089711>,
    <0.3773878, 0.9260066, 0.0094938>,
    <0.3773758, 0.9260115, 0.0094944>,
    <0.3773758, 0.9260115, 0.0094944>,
    <0.3773632, 0.9260167, 0.0094950>,
    <-0.2206332, 0.0000469, -0.9753569>,
    <-0.2211788, 0.0000471, -0.9752333>,
    <-0.2211827, 0.0000270, -0.9752324>,
    <-0.2206390, 0.0000269, -0.9753555>,
    <-0.2200979, 0.0000269, -0.9754778>,
    <-0.2200902, 0.0000468, -0.9754795>,
    <-0.2200902, 0.0000468, -0.9754795>,
    <-0.2200825, 0.0000669, -0.9754813>,
    <-0.2206273, 0.0000671, -0.9753582>,
    <-0.2206273, 0.0000671, -0.9753582>,
    <-0.2211749, 0.0000672, -0.9752342>,
    <-0.2217270, 0.0000472, -0.9751088>,
    <-0.2217290, 0.0000271, -0.9751083>,
    <-0.2211749, 0.0000672, -0.9752342>,
    <-0.2217250, 0.0000674, -0.9751092>,
    <-0.2217250, 0.0000674, -0.9751092>,
    <-0.2222778, 0.0000676, -0.9749834>,
    <-0.2222779, 0.0000473, -0.9749834>,
    <-0.2222779, 0.0000473, -0.9749834>,
    <-0.2222779, 0.0000271, -0.9749833>,
    <-0.2217310, 0.0000071, -0.9751079>,
    <-0.2211866, 0.0000071, -0.9752315>,
    <-0.2222779, 0.0000271, -0.9749833>,
    <-0.2222780, 0.0000071, -0.9749833>,
    <-0.2222780, 0.0000071, -0.9749833>,
    <-0.2222780, -0.0000127, -0.9749833>,
    <-0.2217329, -0.0000127, -0.9751074>,
    <-0.2217329, -0.0000127, -0.9751074>,
    <-0.2211904, -0.0000127, -0.9752306>,
    <-0.2206448, 0.0000071, -0.9753542>,
    <-0.2211904, -0.0000127, -0.9752306>,
    <-0.2206505, -0.0000126, -0.9753529>,
    <-0.2206505, -0.0000126, -0.9753529>,
    <-0.2201132, -0.0000126, -0.9754743>,
    <-0.2201056, 0.0000071, -0.9754761>,
    <-0.2201056, 0.0000071, -0.9754761>,
    <-0.2200979, 0.0000269, -0.9754778>,
    <0.0003486, -0.9999426, 0.0107096>,
    <0.0003486, -0.9999456, 0.0104237>,
    <0.0003407, -0.9999458, 0.0104065>,
    <0.0003407, -0.9999429, 0.0106836>,
    <0.0003407, -0.9999399, 0.0109607>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003571, -0.9999391, 0.0110326>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003486, -0.9999486, 0.0101378>,
    <0.0003407, -0.9999486, 0.0101293>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999514, 0.0098515>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999487, 0.0101214>,
    <0.0003332, -0.9999460, 0.0103903>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003262, -0.9999514, 0.0098528>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003332, -0.9999431, 0.0106591>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999406, 0.0108971>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003407, -0.9999399, 0.0109607>,
    <-0.3774272, -0.9260380, 0.0015558>,
    <-0.3774272, -0.9260381, 0.0014706>,
    <-0.3774476, -0.9260298, 0.0014796>,
    <-0.3774476, -0.9260296, 0.0015602>,
    <-0.3774475, -0.9260295, 0.0016409>,
    <-0.3774271, -0.9260378, 0.0016411>,
    <-0.3774271, -0.9260378, 0.0016411>,
    <-0.3774043, -0.9260471, 0.0016413>,
    <-0.3774044, -0.9260473, 0.0015509>,
    <-0.3774044, -0.9260473, 0.0015509>,
    <-0.3774044, -0.9260474, 0.0014605>,
    <-0.3774273, -0.9260382, 0.0013854>,
    <-0.3774477, -0.9260299, 0.0013990>,
    <-0.3774044, -0.9260474, 0.0014605>,
    <-0.3774045, -0.9260475, 0.0013701>,
    <-0.3774045, -0.9260475, 0.0013701>,
    <-0.3774045, -0.9260476, 0.0012798>,
    <-0.3774273, -0.9260383, 0.0013001>,
    <-0.3774273, -0.9260383, 0.0013001>,
    <-0.3774477, -0.9260300, 0.0013183>,
    <-0.3774659, -0.9260224, 0.0014112>,
    <-0.3774659, -0.9260223, 0.0014877>,
    <-0.3774477, -0.9260300, 0.0013183>,
    <-0.3774660, -0.9260225, 0.0013347>,
    <-0.3774660, -0.9260225, 0.0013347>,
    <-0.3774825, -0.9260157, 0.0013494>,
    <-0.3774824, -0.9260156, 0.0014222>,
    <-0.3774824, -0.9260156, 0.0014222>,
    <-0.3774824, -0.9260155, 0.0014950>,
    <-0.3774659, -0.9260222, 0.0015642>,
    <-0.3774824, -0.9260155, 0.0014950>,
    <-0.3774824, -0.9260154, 0.0015678>,
    <-0.3774824, -0.9260154, 0.0015678>,
    <-0.3774823, -0.9260153, 0.0016406>,
    <-0.3774658, -0.9260221, 0.0016407>,
    <-0.3774658, -0.9260221, 0.0016407>,
    <-0.3774475, -0.9260295, 0.0016409>,
    <0.7945895, 0.0001919, -0.6071470>,
    <0.7953358, 0.0001921, -0.6061691>,
    <0.7953466, 0.0003366, -0.6061548>,
    <0.7946057, 0.0003363, -0.6071257>,
    <0.7938650, 0.0003360, -0.6080939>,
    <0.7938434, 0.0001918, -0.6081222>,
    <0.7938434, 0.0001918, -0.6081222>,
    <0.7938215, 0.0000454, -0.6081509>,
    <0.7945730, 0.0000455, -0.6071686>,
    <0.7945730, 0.0000455, -0.6071686>,
    <0.7953248, 0.0000455, -0.6061836>,
    <0.7960823, 0.0001923, -0.6051884>,
    <0.7960877, 0.0003369, -0.6051811>,
    <0.7953248, 0.0000455, -0.6061836>,
    <0.7960767, 0.0000456, -0.6051957>,
    <0.7960767, 0.0000456, -0.6051957>,
    <0.7968288, 0.0000456, -0.6042051>,
    <0.7968289, 0.0001925, -0.6042049>,
    <0.7968289, 0.0001925, -0.6042049>,
    <0.7968290, 0.0003372, -0.6042048>,
    <0.7960931, 0.0004795, -0.6051740>,
    <0.7953573, 0.0004791, -0.6061407>,
    <0.7968290, 0.0003372, -0.6042048>,
    <0.7968291, 0.0004799, -0.6042046>,
    <0.7968291, 0.0004799, -0.6042046>,
    <0.7968291, 0.0006206, -0.6042044>,
    <0.7960984, 0.0006200, -0.6051669>,
    <0.7960984, 0.0006200, -0.6051669>,
    <0.7953678, 0.0006195, -0.6061267>,
    <0.7946217, 0.0004786, -0.6071047>,
    <0.7953678, 0.0006195, -0.6061267>,
    <0.7946375, 0.0006189, -0.6070840>,
    <0.7946375, 0.0006189, -0.6070840>,
    <0.7939073, 0.0006183, -0.6080385>,
    <0.7938863, 0.0004782, -0.6080660>,
    <0.7938863, 0.0004782, -0.6080660>,
    <0.7938650, 0.0003360, -0.6080939>,
    <-0.0003128, 0.9999983, 0.0018311>,
    <-0.0003128, 0.9999984, 0.0017886>,
    <-0.0003008, 0.9999984, 0.0017841>,
    <-0.0003008, 0.9999983, 0.0018243>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003262, 0.9999982, 0.0018839>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003128, 0.9999984, 0.0017460>,
    <-0.0003008, 0.9999984, 0.0017438>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999985, 0.0017033>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999984, 0.0017418>,
    <-0.0002901, 0.9999984, 0.0017800>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002803, 0.9999985, 0.0017037>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002901, 0.9999983, 0.0018183>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018491>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <-0.3774721, -0.9259595, 0.0106678>,
    <-0.3774740, -0.9259641, 0.0101898>,
    <-0.3774839, -0.9259597, 0.0102200>,
    <-0.3774821, -0.9259553, 0.0106826>,
    <-0.3774802, -0.9259506, 0.0111453>,
    <-0.3774701, -0.9259547, 0.0111459>,
    <-0.3774701, -0.9259547, 0.0111459>,
    <-0.3774594, -0.9259591, 0.0111465>,
    <-0.3774614, -0.9259640, 0.0106520>,
    <-0.3774614, -0.9259640, 0.0106520>,
    <-0.3774634, -0.9259688, 0.0101575>,
    <-0.3774758, -0.9259685, 0.0097117>,
    <-0.3774857, -0.9259640, 0.0097574>,
    <-0.3774634, -0.9259688, 0.0101575>,
    <-0.3774652, -0.9259733, 0.0096629>,
    <-0.3774652, -0.9259733, 0.0096629>,
    <-0.3774670, -0.9259777, 0.0091684>,
    <-0.3774775, -0.9259727, 0.0092337>,
    <-0.3774775, -0.9259727, 0.0092337>,
    <-0.3774874, -0.9259681, 0.0092947>,
    <-0.3774950, -0.9259598, 0.0098002>,
    <-0.3774933, -0.9259556, 0.0102484>,
    <-0.3774874, -0.9259681, 0.0092947>,
    <-0.3774966, -0.9259638, 0.0093520>,
    <-0.3774966, -0.9259638, 0.0093520>,
    <-0.3775053, -0.9259597, 0.0094058>,
    <-0.3775037, -0.9259558, 0.0098404>,
    <-0.3775037, -0.9259558, 0.0098404>,
    <-0.3775020, -0.9259517, 0.0102750>,
    <-0.3774915, -0.9259513, 0.0106965>,
    <-0.3775020, -0.9259517, 0.0102750>,
    <-0.3775003, -0.9259475, 0.0107096>,
    <-0.3775003, -0.9259475, 0.0107096>,
    <-0.3774985, -0.9259431, 0.0111442>,
    <-0.3774897, -0.9259467, 0.0111447>,
    <-0.3774897, -0.9259467, 0.0111447>,
    <-0.3774802, -0.9259506, 0.0111453>,
    <0.1891715, 0.0001707, -0.9819440>,
    <0.1896252, 0.0001711, -0.9818565>,
    <0.1896297, 0.0001943, -0.9818557>,
    <0.1891783, 0.0001939, -0.9819427>,
    <0.1887291, 0.0001934, -0.9820292>,
    <0.1887200, 0.0001703, -0.9820309>,
    <0.1887200, 0.0001703, -0.9820309>,
    <0.1887109, 0.0001470, -0.9820327>,
    <0.1891646, 0.0001473, -0.9819454>,
    <0.1891646, 0.0001473, -0.9819454>,
    <0.1896205, 0.0001477, -0.9818574>,
    <0.1900809, 0.0001715, -0.9817684>,
    <0.1900833, 0.0001948, -0.9817680>,
    <0.1896205, 0.0001477, -0.9818574>,
    <0.1900786, 0.0001480, -0.9817689>,
    <0.1900786, 0.0001480, -0.9817689>,
    <0.1905388, 0.0001484, -0.9816797>,
    <0.1905389, 0.0001719, -0.9816796>,
    <0.1905389, 0.0001719, -0.9816796>,
    <0.1905389, 0.0001953, -0.9816796>,
    <0.1900856, 0.0002178, -0.9817675>,
    <0.1896343, 0.0002173, -0.9818548>,
    <0.1905389, 0.0001953, -0.9816796>,
    <0.1905390, 0.0002183, -0.9816796>,
    <0.1905390, 0.0002183, -0.9816796>,
    <0.1905390, 0.0002412, -0.9816796>,
    <0.1900878, 0.0002406, -0.9817671>,
    <0.1900878, 0.0002406, -0.9817671>,
    <0.1896388, 0.0002400, -0.9818539>,
    <0.1891851, 0.0002168, -0.9819414>,
    <0.1896388, 0.0002400, -0.9818539>,
    <0.1891918, 0.0002395, -0.9819401>,
    <0.1891918, 0.0002395, -0.9819401>,
    <0.1887469, 0.0002389, -0.9820257>,
    <0.1887380, 0.0002163, -0.9820275>,
    <0.1887380, 0.0002163, -0.9820275>,
    <0.1887291, 0.0001934, -0.9820292>,
    <-0.0002740, 0.9999244, 0.0122917>,
    <-0.0002740, 0.9999273, 0.0120530>,
    <-0.0002681, 0.9999275, 0.0120379>,
    <-0.0002681, 0.9999247, 0.0122689>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002803, 0.9999210, 0.0125631>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002740, 0.9999302, 0.0118142>,
    <-0.0002681, 0.9999303, 0.0118068>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999330, 0.0115751>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999303, 0.0117999>,
    <-0.0002625, 0.9999277, 0.0120237>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002573, 0.9999330, 0.0115763>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002625, 0.9999250, 0.0122476>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999225, 0.0124445>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <-0.3775157, -0.9260032, 0.0000286>,
    <-0.3775187, -0.9260020, 0.0000483>,
    <-0.3774932, -0.9260123, 0.0002015>,
    <-0.3774704, -0.9260217, 0.0001124>,
    <-0.3774656, -0.9260236, 0.0000018>,
    <-0.3775149, -0.9260035, 0.0000018>,
    <-0.3775149, -0.9260035, 0.0000018>,
    <-0.3775220, -0.9260006, 0.0000018>,
    <-0.3775220, -0.9260006, 0.0000018>,
    <-0.3775220, -0.9260006, 0.0000018>,
    <-0.3775220, -0.9260006, 0.0000017>,
    <-0.3775216, -0.9260008, 0.0000551>,
    <-0.3775183, -0.9260021, 0.0002362>,
    <-0.3775220, -0.9260006, 0.0000017>,
    <-0.3775220, -0.9260006, 0.0000016>,
    <-0.3775220, -0.9260006, 0.0000016>,
    <-0.3775220, -0.9260006, 0.0000016>,
    <-0.3775226, -0.9260004, 0.0000540>,
    <-0.3775226, -0.9260004, 0.0000540>,
    <-0.3775268, -0.9259986, 0.0002329>,
    <-0.3775098, -0.9260054, 0.0006391>,
    <-0.3774290, -0.9260383, 0.0005766>,
    <-0.3775268, -0.9259986, 0.0002329>,
    <-0.3775375, -0.9259941, 0.0006314>,
    <-0.3775375, -0.9259941, 0.0006314>,
    <-0.3775558, -0.9259855, 0.0015801>,
    <-0.3775069, -0.9260054, 0.0016064>,
    <-0.3773598, -0.9260653, 0.0016090>,
    <-0.3773274, -0.9260799, 0.0003748>,
    <-0.3770120, -0.9262069, 0.0016370>,
    <-0.3767203, -0.9263252, 0.0018395>,
    <-0.3773093, -0.9260873, 0.0000018>,
    <-0.3773093, -0.9260873, 0.0000018>,
    <-0.3774656, -0.9260236, 0.0000018>,
    <0.9995566, 0.0012744, -0.0297495>,
    <0.9995587, 0.0012744, -0.0296768>,
    <0.9919312, 0.0013238, -0.1267707>,
    <0.9918922, 0.0013237, -0.1270755>,
    <0.9918531, 0.0013237, -0.1273802>,
    <0.9995544, 0.0012744, -0.0298221>,
    <0.9995544, 0.0012744, -0.0298221>,
    <0.9999988, 0.0012658, -0.0008596>,
    <0.9999988, 0.0012658, -0.0008575>,
    <0.9999988, 0.0012658, -0.0008575>,
    <0.9999988, 0.0012658, -0.0008554>,
    <0.9995609, 0.0012744, -0.0296042>,
    <0.9919701, 0.0013238, -0.1264658>,
    <0.9999988, 0.0012658, -0.0008554>,
    <0.9999988, 0.0012658, -0.0008534>,
    <0.9999988, 0.0012658, -0.0008534>,
    <0.9999988, 0.0012658, -0.0008513>,
    <0.9995630, 0.0012744, -0.0295316>,
    <0.9995630, 0.0012744, -0.0295316>,
    <0.9920089, 0.0013239, -0.1261610>,
    <0.9458403, 0.0014125, -0.3246293>,
    <0.9455975, 0.0014121, -0.3253358>,
    <0.9920089, 0.0013239, -0.1261610>,
    <0.9460826, 0.0014129, -0.3239223>,
    <0.9460826, 0.0014129, -0.3239223>,
    <0.7631614, 0.0013707, -0.6462065>,
    <0.7623940, 0.0013693, -0.6471117>,
    <0.7616271, 0.0013679, -0.6480141>,
    <0.9453543, 0.0014118, -0.3260417>,
    <0.7608607, 0.0013665, -0.6489138>,
    <0.7600948, 0.0013652, -0.6498108>,
    <0.9451108, 0.0014114, -0.3267471>,
    <0.9451108, 0.0014114, -0.3267471>,
    <0.9918531, 0.0013237, -0.1273802>,
    <-0.0002557, 1.0000000, 0.0000687>,
    <-0.0002521, 1.0000000, 0.0000578>,
    <-0.0002128, 0.9999999, 0.0002410>,
    <-0.0002438, 0.9999999, 0.0002938>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002573, 1.0000000, 0.0000021>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002485, 1.0000000, 0.0000335>,
    <-0.0001849, 1.0000000, 0.0001319>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000127, 0.9999999, 0.0004262>,
    <-0.0001114, 0.9999998, 0.0006796>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0004444, 0.9999983, 0.0017942>,
    <0.0000146, 0.9999983, 0.0018600>,
    <-0.0002126, 0.9999997, 0.0007890>,
    <-0.0001727, 0.9999981, 0.0019562>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <-0.3770014, -0.9261930, 0.0060381>,
    <-0.3773780, -0.9260510, 0.0039224>,
    <-0.3775828, -0.9259546, 0.0062769>,
    <-0.3775413, -0.9259316, 0.0106385>,
    <-0.3771996, -0.9254271, 0.0361267>,
    <-0.3737680, -0.9267926, 0.0367824>,
    <-0.3737680, -0.9267926, 0.0367824>,
    <-0.3767203, -0.9263252, 0.0018395>,
    <-0.3775322, -0.9259899, 0.0034955>,
    <-0.3775968, -0.9259559, 0.0051322>,
    <-0.3775558, -0.9259855, 0.0015801>,
    <-0.3775787, -0.9259713, 0.0033908>,
    <-0.3775787, -0.9259713, 0.0033908>,
    <-0.3776004, -0.9259559, 0.0048656>,
    <-0.3776569, -0.9259353, 0.0043598>,
    <-0.3777810, -0.9258806, 0.0051607>,
    <-0.3776004, -0.9259559, 0.0048656>,
    <-0.3776211, -0.9259511, 0.0041089>,
    <-0.3776211, -0.9259511, 0.0041089>,
    <-0.3776372, -0.9259512, 0.0021212>,
    <-0.3776706, -0.9259374, 0.0022070>,
    <-0.3777740, -0.9258949, 0.0023153>,
    <-0.3780808, -0.9257383, 0.0079709>,
    <-0.3780201, -0.9257943, 0.0024013>,
    <-0.3781858, -0.9257268, 0.0023300>,
    <-0.3795975, -0.9244639, 0.0356675>,
    <-0.3795975, -0.9244639, 0.0356675>,
    <-0.3771996, -0.9254271, 0.0361267>,
    <0.4852325, 0.0010944, -0.8743845>,
    <0.4861039, 0.0010963, -0.8739003>,
    <0.3661381, 0.0010209, -0.9305600>,
    <0.3654112, 0.0010189, -0.9308456>,
    <0.3646869, 0.0010169, -0.9311296>,
    <0.4843638, 0.0010924, -0.8748660>,
    <0.4843638, 0.0010924, -0.8748660>,
    <0.7600948, 0.0013652, -0.6498108>,
    <0.4869779, 0.0010983, -0.8734136>,
    <0.3668677, 0.0010229, -0.9302726>,
    <0.7631614, 0.0013707, -0.6462065>,
    <0.4878546, 0.0011003, -0.8729242>,
    <0.4878546, 0.0011003, -0.8729242>,
    <0.3676000, 0.0010250, -0.9299834>,
    <0.4272788, 0.0014106, -0.9041188>,
    <0.4264941, 0.0014080, -0.9044892>,
    <0.3676000, 0.0010250, -0.9299834>,
    <0.4280660, 0.0014132, -0.9037464>,
    <0.4280660, 0.0014132, -0.9037464>,
    <0.6790855, 0.0025234, -0.7340549>,
    <0.6782763, 0.0025204, -0.7348026>,
    <0.6774682, 0.0025174, -0.7355478>,
    <0.4257121, 0.0014054, -0.9048576>,
    <0.6766612, 0.0025144, -0.7362902>,
    <0.6758553, 0.0025114, -0.7370300>,
    <0.4249325, 0.0014028, -0.9052239>,
    <0.4249325, 0.0014028, -0.9052239>,
    <0.3646869, 0.0010169, -0.9311296>,
    <-0.0001605, 0.9999912, 0.0041835>,
    <0.0000373, 0.9999900, 0.0044632>,
    <-0.0001893, 0.9999751, 0.0070592>,
    <-0.0002044, 0.9999817, 0.0060433>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <0.0004994, 0.9999785, 0.0065314>,
    <-0.0001552, 0.9999344, 0.0114548>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0041270, 0.9992606, 0.0382247>,
    <0.0041270, 0.9992606, 0.0382247>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0007848, 0.9999631, 0.0085524>,
    <-0.0004049, 0.9999833, 0.0057588>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0006662, 0.9999964, 0.0025817>,
    <-0.0003625, 0.9999966, 0.0025763>,
    <-0.0002448, 0.9999871, 0.0050692>,
    <-0.0002322, 0.9999967, 0.0025453>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <-0.3777722, -0.9258984, 0.0006185>,
    <-0.3777113, -0.9259230, 0.0008818>,
    <-0.3776690, -0.9259406, 0.0003706>,
    <-0.3776817, -0.9259354, 0.0002568>,
    <-0.3776843, -0.9259344, 0.0001137>,
    <-0.3777813, -0.9258949, 0.0001136>,
    <-0.3777813, -0.9258949, 0.0001136>,
    <-0.3781858, -0.9257268, 0.0023300>,
    <-0.3776626, -0.9259428, 0.0009436>,
    <-0.3776551, -0.9259463, 0.0004133>,
    <-0.3776372, -0.9259512, 0.0021212>,
    <-0.3776459, -0.9259496, 0.0009282>,
    <-0.3776459, -0.9259496, 0.0009282>,
    <-0.3776503, -0.9259482, 0.0004106>,
    <-0.3776529, -0.9259472, 0.0001764>,
    <-0.3776545, -0.9259466, 0.0001691>,
    <-0.3776503, -0.9259482, 0.0004106>,
    <-0.3776524, -0.9259474, 0.0001740>,
    <-0.3776524, -0.9259474, 0.0001740>,
    <-0.3776533, -0.9259471, 0.0001042>,
    <-0.3776533, -0.9259471, 0.0001066>,
    <-0.3776533, -0.9259471, 0.0001066>,
    <-0.3776533, -0.9259471, 0.0001090>,
    <-0.3776561, -0.9259459, 0.0001458>,
    <-0.3776533, -0.9259471, 0.0001090>,
    <-0.3776533, -0.9259471, 0.0001113>,
    <-0.3776533, -0.9259471, 0.0001113>,
    <-0.3776533, -0.9259471, 0.0001137>,
    <-0.3776565, -0.9259457, 0.0001137>,
    <-0.3776565, -0.9259457, 0.0001137>,
    <-0.3776843, -0.9259344, 0.0001137>,
    <0.9036903, 0.0036000, -0.4281715>,
    <0.9040499, 0.0036014, -0.4274118>,
    <0.9789154, 0.0040460, -0.2042262>,
    <0.9788271, 0.0040457, -0.2046491>,
    <0.9787386, 0.0040453, -0.2050718>,
    <0.9033304, 0.0035985, -0.4289304>,
    <0.9033304, 0.0035985, -0.4289304>,
    <0.6758553, 0.0025114, -0.7370300>,
    <0.9044091, 0.0036028, -0.4266511>,
    <0.9790035, 0.0040464, -0.2038032>,
    <0.6790855, 0.0025234, -0.7340549>,
    <0.9047680, 0.0036042, -0.4258896>,
    <0.9047680, 0.0036042, -0.4258896>,
    <0.9790915, 0.0040468, -0.2033801>,
    <0.9961348, 0.0041904, -0.0877376>,
    <0.9961182, 0.0041903, -0.0879255>,
    <0.9790915, 0.0040468, -0.2033801>,
    <0.9961513, 0.0041905, -0.0875497>,
    <0.9961513, 0.0041905, -0.0875497>,
    <0.9986101, 0.0042368, -0.0525342>,
    <0.9986042, 0.0042367, -0.0526473>,
    <0.9986042, 0.0042367, -0.0526473>,
    <0.9985982, 0.0042367, -0.0527604>,
    <0.9961016, 0.0041903, -0.0881134>,
    <0.9985982, 0.0042367, -0.0527604>,
    <0.9985922, 0.0042367, -0.0528735>,
    <0.9985922, 0.0042367, -0.0528735>,
    <0.9985862, 0.0042367, -0.0529867>,
    <0.9960850, 0.0041902, -0.0883012>,
    <0.9960850, 0.0041902, -0.0883012>,
    <0.9787386, 0.0040453, -0.2050718>,
    <-0.0002053, 0.9999994, 0.0010841>,
    <-0.0002659, 0.9999995, 0.0009839>,
    <-0.0002050, 0.9999999, 0.0004143>,
    <-0.0001877, 0.9999999, 0.0004740>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0003403, 0.9999997, 0.0006738>,
    <-0.0002205, 0.9999999, 0.0002809>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001852, 1.0000000, 0.0001577>,
    <-0.0001833, 1.0000000, 0.0001881>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001801, 1.0000000, 0.0001183>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001813, 1.0000000, 0.0002019>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001230>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.9999958, -0.0028667, 0.0004859>,
    <0.9999958, -0.0028667, 0.0004951>,
    <0.9999958, -0.0028634, 0.0004951>,
    <0.9999958, -0.0028634, 0.0004859>,
    <0.9999958, -0.0028634, 0.0004766>,
    <0.9999958, -0.0028667, 0.0004766>,
    <0.9999958, -0.0028667, 0.0004766>,
    <0.9999958, -0.0028700, 0.0004766>,
    <0.9999958, -0.0028700, 0.0004859>,
    <0.9999958, -0.0028700, 0.0004859>,
    <0.9999958, -0.0028700, 0.0004951>,
    <0.9999958, -0.0028667, 0.0005043>,
    <0.9999958, -0.0028634, 0.0005043>,
    <0.9999958, -0.0028700, 0.0004951>,
    <0.9999958, -0.0028700, 0.0005043>,
    <0.9999958, -0.0028700, 0.0005043>,
    <0.9999957, -0.0028700, 0.0005136>,
    <0.9999958, -0.0028667, 0.0005136>,
    <0.9999958, -0.0028667, 0.0005136>,
    <0.9999958, -0.0028634, 0.0005136>,
    <0.9999958, -0.0028601, 0.0005043>,
    <0.9999958, -0.0028601, 0.0004951>,
    <0.9999958, -0.0028634, 0.0005136>,
    <0.9999958, -0.0028601, 0.0005136>,
    <0.9999958, -0.0028601, 0.0005136>,
    <0.9999958, -0.0028567, 0.0005136>,
    <0.9999958, -0.0028567, 0.0005043>,
    <0.9999958, -0.0028567, 0.0005043>,
    <0.9999958, -0.0028567, 0.0004951>,
    <0.9999958, -0.0028601, 0.0004859>,
    <0.9999958, -0.0028567, 0.0004951>,
    <0.9999958, -0.0028567, 0.0004859>,
    <0.9999958, -0.0028567, 0.0004859>,
    <0.9999958, -0.0028567, 0.0004766>,
    <0.9999958, -0.0028601, 0.0004766>,
    <0.9999958, -0.0028601, 0.0004766>,
    <0.9999958, -0.0028634, 0.0004766>,
    <-0.9883002, 0.0030419, -0.1524907>,
    <-0.9883011, 0.0029735, -0.1524863>,
    <-0.9878611, 0.0029722, -0.1553116>,
    <-0.9878605, 0.0030405, -0.1553137>,
    <-0.9878600, 0.0031088, -0.1553157>,
    <-0.9882993, 0.0031101, -0.1524950>,
    <-0.9882993, 0.0031101, -0.1524950>,
    <-0.9887310, 0.0031115, -0.1496706>,
    <-0.9887322, 0.0030432, -0.1496639>,
    <-0.9887322, 0.0030432, -0.1496639>,
    <-0.9887335, 0.0029748, -0.1496572>,
    <-0.9883020, 0.0029051, -0.1524819>,
    <-0.9878616, 0.0029038, -0.1553095>,
    <-0.9887335, 0.0029748, -0.1496572>,
    <-0.9887347, 0.0029063, -0.1496505>,
    <-0.9887347, 0.0029063, -0.1496505>,
    <-0.9887359, 0.0028377, -0.1496438>,
    <-0.9883029, 0.0028365, -0.1524775>,
    <-0.9883029, 0.0028365, -0.1524775>,
    <-0.9878621, 0.0028352, -0.1553075>,
    <-0.9874135, 0.0029025, -0.1581334>,
    <-0.9874133, 0.0029709, -0.1581332>,
    <-0.9878621, 0.0028352, -0.1553075>,
    <-0.9874137, 0.0028339, -0.1581336>,
    <-0.9874137, 0.0028339, -0.1581336>,
    <-0.9869575, 0.0028326, -0.1609559>,
    <-0.9869578, 0.0029011, -0.1609534>,
    <-0.9869578, 0.0029011, -0.1609534>,
    <-0.9869580, 0.0029695, -0.1609508>,
    <-0.9874132, 0.0030392, -0.1581329>,
    <-0.9869580, 0.0029695, -0.1609508>,
    <-0.9869582, 0.0030378, -0.1609483>,
    <-0.9869582, 0.0030378, -0.1609483>,
    <-0.9869584, 0.0031059, -0.1609458>,
    <-0.9874130, 0.0031073, -0.1581327>,
    <-0.9874130, 0.0031073, -0.1581327>,
    <-0.9878600, 0.0031088, -0.1553157>,
    <0.9999950, -0.0031471, 0.0000079>,
    <0.9999950, -0.0031471, 0.0000080>,
    <0.9999950, -0.0031471, 0.0000080>,
    <0.9999950, -0.0031471, 0.0000079>,
    <0.9999950, -0.0031471, 0.0000077>,
    <0.9999950, -0.0031471, 0.0000077>,
    <0.9999950, -0.0031471, 0.0000077>,
    <0.9999950, -0.0031472, 0.0000077>,
    <0.9999950, -0.0031472, 0.0000079>,
    <0.9999950, -0.0031472, 0.0000079>,
    <0.9999950, -0.0031472, 0.0000080>,
    <0.9999950, -0.0031471, 0.0000082>,
    <0.9999950, -0.0031471, 0.0000082>,
    <0.9999950, -0.0031472, 0.0000080>,
    <0.9999950, -0.0031472, 0.0000082>,
    <0.9999950, -0.0031472, 0.0000082>,
    <0.9999950, -0.0031472, 0.0000083>,
    <0.9999950, -0.0031471, 0.0000083>,
    <0.9999950, -0.0031471, 0.0000083>,
    <0.9999950, -0.0031471, 0.0000083>,
    <0.9999950, -0.0031470, 0.0000082>,
    <0.9999950, -0.0031470, 0.0000080>,
    <0.9999950, -0.0031471, 0.0000083>,
    <0.9999950, -0.0031470, 0.0000083>,
    <0.9999950, -0.0031470, 0.0000083>,
    <0.9999950, -0.0031469, 0.0000083>,
    <0.9999950, -0.0031469, 0.0000082>,
    <0.9999950, -0.0031469, 0.0000082>,
    <0.9999950, -0.0031469, 0.0000080>,
    <0.9999950, -0.0031470, 0.0000079>,
    <0.9999950, -0.0031469, 0.0000080>,
    <0.9999950, -0.0031469, 0.0000079>,
    <0.9999950, -0.0031469, 0.0000079>,
    <0.9999950, -0.0031469, 0.0000077>,
    <0.9999950, -0.0031470, 0.0000077>,
    <0.9999950, -0.0031470, 0.0000077>,
    <0.9999950, -0.0031471, 0.0000077>,
    <-0.9988645, 0.0031741, -0.0475356>,
    <-0.9988645, 0.0031640, -0.0475354>,
    <-0.9988214, 0.0031638, -0.0484339>,
    <-0.9988213, 0.0031740, -0.0484340>,
    <-0.9988213, 0.0031841, -0.0484341>,
    <-0.9988645, 0.0031843, -0.0475358>,
    <-0.9988645, 0.0031843, -0.0475358>,
    <-0.9989068, 0.0031844, -0.0466374>,
    <-0.9989069, 0.0031743, -0.0466371>,
    <-0.9989069, 0.0031743, -0.0466371>,
    <-0.9989069, 0.0031641, -0.0466368>,
    <-0.9988646, 0.0031538, -0.0475352>,
    <-0.9988214, 0.0031537, -0.0484338>,
    <-0.9989069, 0.0031641, -0.0466368>,
    <-0.9989069, 0.0031539, -0.0466365>,
    <-0.9989069, 0.0031539, -0.0466365>,
    <-0.9989070, 0.0031438, -0.0466362>,
    <-0.9988646, 0.0031436, -0.0475350>,
    <-0.9988646, 0.0031436, -0.0475350>,
    <-0.9988215, 0.0031435, -0.0484337>,
    <-0.9987774, 0.0031535, -0.0493322>,
    <-0.9987774, 0.0031637, -0.0493322>,
    <-0.9988215, 0.0031435, -0.0484337>,
    <-0.9987775, 0.0031434, -0.0493323>,
    <-0.9987775, 0.0031434, -0.0493323>,
    <-0.9987327, 0.0031432, -0.0502307>,
    <-0.9987327, 0.0031534, -0.0502306>,
    <-0.9987327, 0.0031534, -0.0502306>,
    <-0.9987326, 0.0031635, -0.0502305>,
    <-0.9987774, 0.0031738, -0.0493322>,
    <-0.9987326, 0.0031635, -0.0502305>,
    <-0.9987326, 0.0031737, -0.0502304>,
    <-0.9987326, 0.0031737, -0.0502304>,
    <-0.9987326, 0.0031839, -0.0502302>,
    <-0.9987774, 0.0031840, -0.0493322>,
    <-0.9987774, 0.0031840, -0.0493322>,
    <-0.9988213, 0.0031841, -0.0484341>,
    <0.9999420, -0.0031868, 0.0102878>,
    <0.9999434, -0.0032502, 0.0101314>,
    <0.9999334, -0.0032301, 0.0110827>,
    <0.9999343, -0.0032139, 0.0109988>,
    <0.9999334, -0.0032088, 0.0110850>,
    <0.9999335, -0.0031699, 0.0110847>,
    <0.9999335, -0.0031699, 0.0110847>,
    <0.9999720, -0.0029756, 0.0068702>,
    <0.9999707, -0.0030848, 0.0070035>,
    <0.9999692, -0.0032633, 0.0071366>,
    <0.9999368, -0.0033114, 0.0107409>,
    <0.9999292, -0.0032451, 0.0114501>,
    <0.9999676, -0.0034461, 0.0072691>,
    <0.9999663, -0.0035537, 0.0074011>,
    <0.9999232, -0.0033226, 0.0119404>,
    <0.9999232, -0.0033226, 0.0119404>,
    <0.9999234, -0.0032482, 0.0119406>,
    <0.9999269, -0.0032107, 0.0116604>,
    <0.9999297, -0.0032089, 0.0114115>,
    <0.9999234, -0.0032482, 0.0119406>,
    <0.9999236, -0.0032111, 0.0119407>,
    <0.9999236, -0.0032111, 0.0119407>,
    <0.9999236, -0.0031877, 0.0119408>,
    <0.9999262, -0.0031877, 0.0117268>,
    <0.9999262, -0.0031877, 0.0117268>,
    <0.9999286, -0.0031877, 0.0115128>,
    <0.9999318, -0.0032069, 0.0112269>,
    <0.9999286, -0.0031877, 0.0115128>,
    <0.9999311, -0.0031877, 0.0112988>,
    <0.9999311, -0.0031877, 0.0112988>,
    <0.9999335, -0.0031877, 0.0110849>,
    <0.9999334, -0.0032062, 0.0110850>,
    <0.9999334, -0.0032062, 0.0110850>,
    <0.9999334, -0.0032088, 0.0110850>,
    <0.9999872, -0.0030585, -0.0040199>,
    <0.9998036, -0.0031560, -0.0195669>,
    <0.9998850, -0.0032586, -0.0148087>,
    <0.9999944, -0.0032647, -0.0007967>,
    <0.9999720, -0.0029756, 0.0068702>,
    <0.9992088, -0.0024432, -0.0396977>,
    <0.9992088, -0.0024432, -0.0396977>,
    <0.9992065, -0.0030444, -0.0397135>,
    <0.9994407, -0.0032327, -0.0332831>,
    <0.9995076, -0.0032505, -0.0312093>,
    <0.9992065, -0.0030444, -0.0397135>,
    <0.9992057, -0.0032230, -0.0397181>,
    <0.9992057, -0.0032230, -0.0397181>,
    <0.9992056, -0.0032427, -0.0397187>,
    <0.9991749, -0.0032426, -0.0404837>,
    <0.9991749, -0.0032426, -0.0404837>,
    <0.9991437, -0.0032425, -0.0412486>,
    <0.9993952, -0.0032682, -0.0346215>,
    <0.9997834, -0.0033633, -0.0205399>,
    <0.9991437, -0.0032425, -0.0412486>,
    <0.9991118, -0.0032424, -0.0420135>,
    <0.9991118, -0.0032424, -0.0420135>,
    <0.9990793, -0.0032422, -0.0427783>,
    <0.9990792, -0.0032771, -0.0427780>,
    <0.9990792, -0.0032771, -0.0427780>,
    <0.9990786, -0.0034795, -0.0427760>,
    <0.9999843, -0.0034767, -0.0043855>,
    <0.9990786, -0.0034795, -0.0427760>,
    <0.9990764, -0.0041300, -0.0427695>,
    <0.9990764, -0.0041300, -0.0427695>,
    <0.9999663, -0.0035537, 0.0074011>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9511689>,
    <0.4350534, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9511689>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4350534, 0.9657316>,
    <0.5000060, 0.9664288>,
    <0.4263703, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664288>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559367, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4263703, 0.9671308>,
    <0.5000061, 0.9786956>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9786956>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773948, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032662, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458857>,
    <0.4677608, 0.9456965>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9511689>,
    <0.4355157, 0.9458857>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9451631>,
    <0.4677604, 0.9518925>,
    <0.4676447, 0.9588120>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9511689>,
    <0.5000059, 0.9657316>,
    <0.4350534, 0.9657316>,
    <0.4677604, 0.9518925>,
    <0.5000059, 0.9579835>,
    <0.4675262, 0.9657316>,
    <0.4353083, 0.9584665>,
    <0.4031502, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4350534, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4353083, 0.9584665>,
    <0.4024181, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032662, 0.9526160>,
    <0.5322510, 0.9456965>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9511689>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9518925>,
    <0.5000059, 0.9451631>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458645>,
    <0.5967410, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5644961, 0.9458645>,
    <0.5967380, 0.9395004>,
    <0.6289858, 0.9451388>,
    <0.5967440, 0.9518685>,
    <0.5967474, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967440, 0.9518685>,
    <0.6289941, 0.9579003>,
    <0.5967509, 0.9657316>,
    <0.5645003, 0.9587163>,
    <0.5322532, 0.9588120>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9511689>,
    <0.5645003, 0.9587163>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9579835>,
    <0.5322521, 0.9518925>,
    <0.6423395, 0.9456845>,
    <0.6556982, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423437, 0.9518685>,
    <0.6289858, 0.9451388>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458854>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458854>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691147, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694793, 0.9657316>,
    <0.6558043, 0.9584513>,
    <0.6424060, 0.9588001>,
    <0.6556982, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.6558043, 0.9584513>,
    <0.6424701, 0.9657316>,
    <0.6289941, 0.9579003>,
    <0.6423437, 0.9518685>,
    <0.3997928, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4350534, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4024181, 0.9657316>,
    <0.4331639, 0.9660607>,
    <0.4665256, 0.9660808>,
    <0.4310370, 0.9664312>,
    <0.4350534, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664288>,
    <0.4331639, 0.9660607>,
    <0.4675262, 0.9657316>,
    <0.5000060, 0.9660919>,
    <0.4655215, 0.9664300>,
    <0.4643549, 0.9667804>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664288>,
    <0.5000061, 0.9671308>,
    <0.4263703, 0.9671308>,
    <0.4655215, 0.9664300>,
    <0.5000060, 0.9667632>,
    <0.4631816, 0.9671308>,
    <0.4286561, 0.9667881>,
    <0.3931497, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4263703, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4286561, 0.9667881>,
    <0.3895082, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660808>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664288>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664300>,
    <0.5000060, 0.9660919>,
    <0.5322542, 0.9657316>,
    <0.5668008, 0.9660911>,
    <0.6000933, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5668008, 0.9660911>,
    <0.5967509, 0.9657316>,
    <0.6335597, 0.9660883>,
    <0.6034357, 0.9664293>,
    <0.6068019, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034357, 0.9664293>,
    <0.6422052, 0.9667645>,
    <0.6101681, 0.9671308>,
    <0.5711142, 0.9667658>,
    <0.5356086, 0.9667804>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664288>,
    <0.5711142, 0.9667658>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667632>,
    <0.5344905, 0.9664300>,
    <0.6473345, 0.9660805>,
    <0.6665054, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6289992, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6522009, 0.9664293>,
    <0.6335597, 0.9660883>,
    <0.6424701, 0.9657316>,
    <0.6608384, 0.9660561>,
    <0.6749817, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559367, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6608384, 0.9660561>,
    <0.6694793, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866708, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926707, 0.9671308>,
    <0.6721189, 0.9667919>,
    <0.6571714, 0.9667801>,
    <0.6665054, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.6721189, 0.9667919>,
    <0.6621448, 0.9671308>,
    <0.6422052, 0.9667645>,
    <0.6522009, 0.9664293>,
    <0.3896350, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4263703, 0.9671308>,
    <0.3895220, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3895082, 0.9671308>,
    <0.4263596, 0.9729583>,
    <0.4631833, 0.9726793>,
    <0.4263507, 0.9777601>,
    <0.4263703, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9786956>,
    <0.4263596, 0.9729583>,
    <0.4631816, 0.9671308>,
    <0.5000061, 0.9731107>,
    <0.4631777, 0.9782279>,
    <0.4631249, 0.9833087>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9786956>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631777, 0.9782279>,
    <0.5000061, 0.9836699>,
    <0.4630714, 0.9883895>,
    <0.4262410, 0.9832092>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262410, 0.9832092>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895220, 0.9777601>,
    <0.5367803, 0.9726793>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9786956>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9782279>,
    <0.5000061, 0.9731107>,
    <0.5367268, 0.9671308>,
    <0.5735589, 0.9726676>,
    <0.6103387, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5735589, 0.9726676>,
    <0.6101681, 0.9671308>,
    <0.6471335, 0.9732089>,
    <0.6105094, 0.9782626>,
    <0.6106597, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105094, 0.9782626>,
    <0.6475562, 0.9837065>,
    <0.6108101, 0.9883895>,
    <0.5737713, 0.9832167>,
    <0.5368873, 0.9833087>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9786956>,
    <0.5737713, 0.9832167>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9836699>,
    <0.5368338, 0.9782279>,
    <0.6623650, 0.9726967>,
    <0.6778190, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6468888, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6625884, 0.9782625>,
    <0.6471335, 0.9732089>,
    <0.6621448, 0.9671308>,
    <0.6776281, 0.9729776>,
    <0.6928127, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773948, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776281, 0.9729776>,
    <0.6926707, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930705, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930705, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780838, 0.9832100>,
    <0.6628141, 0.9833260>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.6780838, 0.9832100>,
    <0.6630402, 0.9883895>,
    <0.6475562, 0.9837065>,
    <0.6625884, 0.9782625>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.011335, -0.86281, -0.147353>
}

#declare TMesh004 = mesh2 {
  vertex_vectors {
    582,
    <2.1725850, 0.1168106, 18.5417983>,
    <2.0021506, 0.1167733, 18.5417983>,
    <2.0021672, -0.1263783, 18.5417983>,
    <2.1725990, -0.1263328, 18.5417983>,
    <2.0873678, 0.1167919, 18.5417983>,
    <2.0021589, -0.0048025, 18.5417983>,
    <2.0873831, -0.1263556, 18.5417983>,
    <2.1725920, -0.0047611, 18.5417983>,
    <2.0873754, -0.0047818, 18.5417983>,
    <2.3430309, -0.1262872, 18.5417983>,
    <2.3430194, 0.1168480, 18.5417983>,
    <2.2578150, -0.1263100, 18.5417983>,
    <2.3430251, -0.0047196, 18.5417983>,
    <2.2578022, 0.1168293, 18.5417983>,
    <2.2578086, -0.0047404, 18.5417983>,
    <2.3430079, 0.3599832, 18.5417983>,
    <2.1725710, 0.3599540, 18.5417983>,
    <2.3430137, 0.2384156, 18.5417983>,
    <2.2577895, 0.3599686, 18.5417983>,
    <2.1725780, 0.2383823, 18.5417983>,
    <2.2577958, 0.2383989, 18.5417983>,
    <2.0021340, 0.3599249, 18.5417983>,
    <2.0873525, 0.3599394, 18.5417983>,
    <2.0021423, 0.2383491, 18.5417983>,
    <2.0873601, 0.2383657, 18.5417983>,
    <2.0592721, -0.1268007, 18.1202395>,
    <2.0044034, -0.1268325, 18.1202395>,
    <2.0044687, -0.1268457, 18.1217627>,
    <2.0559641, -0.1268143, 18.1217627>,
    <2.0318378, -0.1268166, 18.1202395>,
    <2.0044361, -0.1268391, 18.1210011>,
    <2.0302164, -0.1268300, 18.1217627>,
    <2.0576181, -0.1268075, 18.1210011>,
    <2.0310271, -0.1268233, 18.1210011>,
    <2.1074595, -0.1267829, 18.1217627>,
    <2.1141408, -0.1267689, 18.1202395>,
    <2.0817118, -0.1267986, 18.1217627>,
    <2.1108002, -0.1267759, 18.1210011>,
    <2.0867065, -0.1267848, 18.1202395>,
    <2.0842091, -0.1267917, 18.1210011>,
    <2.1208221, -0.1267548, 18.1187163>,
    <2.0625801, -0.1267870, 18.1187163>,
    <2.1174814, -0.1267619, 18.1194779>,
    <2.0917011, -0.1267709, 18.1187163>,
    <2.0609261, -0.1267939, 18.1194779>,
    <2.0892038, -0.1267779, 18.1194779>,
    <2.0043382, -0.1268192, 18.1187163>,
    <2.0334591, -0.1268031, 18.1187163>,
    <2.0043708, -0.1268259, 18.1194779>,
    <2.0326485, -0.1268099, 18.1194779>,
    <2.1141282, 0.1168541, 18.1202395>,
    <2.1074469, 0.1168543, 18.1217627>,
    <2.1141345, -0.0049574, 18.1202395>,
    <2.1074532, -0.0049643, 18.1217627>,
    <2.1107875, 0.1168542, 18.1210011>,
    <2.1107938, -0.0049608, 18.1210011>,
    <2.1074342, 0.3604916, 18.1217627>,
    <2.1141156, 0.3604772, 18.1202395>,
    <2.1074405, 0.2386730, 18.1217627>,
    <2.1107749, 0.3604844, 18.1210011>,
    <2.1141219, 0.2386657, 18.1202395>,
    <2.1107812, 0.2386693, 18.1210011>,
    <2.1207969, 0.3604627, 18.1187163>,
    <2.1208095, 0.1168540, 18.1187163>,
    <2.1174562, 0.3604700, 18.1194779>,
    <2.1208032, 0.2386584, 18.1187163>,
    <2.1174688, 0.1168541, 18.1194779>,
    <2.1174625, 0.2386620, 18.1194779>,
    <2.1208158, -0.0049504, 18.1187163>,
    <2.1174751, -0.0049539, 18.1194779>,
    <2.0592428, 0.3604585, 18.1202395>,
    <2.0559348, 0.3604732, 18.1217627>,
    <2.0866792, 0.3604678, 18.1202395>,
    <2.0816845, 0.3604824, 18.1217627>,
    <2.0575888, 0.3604658, 18.1210011>,
    <2.0841818, 0.3604751, 18.1210011>,
    <2.0044353, 0.3604548, 18.1217627>,
    <2.0043701, 0.3604398, 18.1202395>,
    <2.0301850, 0.3604640, 18.1217627>,
    <2.0044027, 0.3604473, 18.1210011>,
    <2.0318064, 0.3604491, 18.1202395>,
    <2.0309957, 0.3604566, 18.1210011>,
    <2.0043048, 0.3604247, 18.1187163>,
    <2.0625508, 0.3604437, 18.1187163>,
    <2.0043374, 0.3604323, 18.1194779>,
    <2.0334278, 0.3604342, 18.1187163>,
    <2.0608968, 0.3604511, 18.1194779>,
    <2.0326171, 0.3604417, 18.1194779>,
    <2.0916739, 0.3604532, 18.1187163>,
    <2.0891765, 0.3604605, 18.1194779>,
    <2.0694781, -0.1267585, 18.1370901>,
    <2.0042020, -0.1267916, 18.1370901>,
    <2.0368401, -0.1267751, 18.1370901>,
    <2.0042701, -0.1268054, 18.1279032>,
    <2.0660291, -0.1267728, 18.1279032>,
    <2.0351496, -0.1267891, 18.1279032>,
    <2.1347541, -0.1267255, 18.1370901>,
    <2.1277881, -0.1267402, 18.1279032>,
    <2.1021161, -0.1267420, 18.1370901>,
    <2.0969086, -0.1267565, 18.1279032>,
    <2.1486861, -0.1266962, 18.1554639>,
    <2.0763760, -0.1267301, 18.1554639>,
    <2.1417201, -0.1267108, 18.1462770>,
    <2.1125311, -0.1267131, 18.1554639>,
    <2.0729270, -0.1267443, 18.1462770>,
    <2.1073236, -0.1267276, 18.1462770>,
    <2.0040659, -0.1267639, 18.1554639>,
    <2.0402210, -0.1267470, 18.1554639>,
    <2.0041340, -0.1267778, 18.1462770>,
    <2.0385305, -0.1267610, 18.1462770>,
    <2.1347416, 0.1168536, 18.1370901>,
    <2.1347478, -0.0049360, 18.1370901>,
    <2.1277755, 0.1168538, 18.1279032>,
    <2.1277818, -0.0049432, 18.1279032>,
    <2.1347291, 0.3604327, 18.1370901>,
    <2.1277630, 0.3604477, 18.1279032>,
    <2.1347353, 0.2386431, 18.1370901>,
    <2.1277693, 0.2386507, 18.1279032>,
    <2.1486612, 0.3604026, 18.1554639>,
    <2.1486737, 0.1168532, 18.1554639>,
    <2.1416951, 0.3604176, 18.1462770>,
    <2.1486675, 0.2386279, 18.1554639>,
    <2.1417076, 0.1168534, 18.1462770>,
    <2.1417014, 0.2386355, 18.1462770>,
    <2.1486799, -0.0049215, 18.1554639>,
    <2.1417139, -0.0049287, 18.1462770>,
    <2.0694489, 0.3604130, 18.1370901>,
    <2.1020890, 0.3604229, 18.1370901>,
    <2.0659999, 0.3604284, 18.1279032>,
    <2.0968814, 0.3604381, 18.1279032>,
    <2.0041687, 0.3603934, 18.1370901>,
    <2.0042367, 0.3604091, 18.1279032>,
    <2.0368088, 0.3604032, 18.1370901>,
    <2.0351183, 0.3604187, 18.1279032>,
    <2.0040326, 0.3603621, 18.1554639>,
    <2.0763469, 0.3603823, 18.1554639>,
    <2.0041006, 0.3603777, 18.1462770>,
    <2.0401897, 0.3603722, 18.1554639>,
    <2.0728979, 0.3603977, 18.1462770>,
    <2.0384993, 0.3603877, 18.1462770>,
    <2.1125041, 0.3603925, 18.1554639>,
    <2.1072965, 0.3604077, 18.1462770>,
    <2.0812641, -0.1267099, 18.1573801>,
    <2.0039695, -0.1267443, 18.1573801>,
    <2.0426168, -0.1267271, 18.1573801>,
    <2.0040177, -0.1267541, 18.1564220>,
    <2.0788201, -0.1267200, 18.1564220>,
    <2.0414189, -0.1267371, 18.1564220>,
    <2.1585588, -0.1266754, 18.1573801>,
    <2.1536225, -0.1266858, 18.1564220>,
    <2.1199115, -0.1266926, 18.1573801>,
    <2.1162213, -0.1267029, 18.1564220>,
    <2.1684314, -0.1266546, 18.1592964>,
    <2.0861522, -0.1266897, 18.1592964>,
    <2.1634951, -0.1266650, 18.1583383>,
    <2.1272918, -0.1266722, 18.1592964>,
    <2.0837082, -0.1266998, 18.1583383>,
    <2.1236016, -0.1266824, 18.1583383>,
    <2.0038730, -0.1267248, 18.1592964>,
    <2.0450126, -0.1267072, 18.1592964>,
    <2.0039212, -0.1267346, 18.1583383>,
    <2.0438147, -0.1267172, 18.1583383>,
    <2.1585464, 0.1168529, 18.1573801>,
    <2.1585526, -0.0049112, 18.1573801>,
    <2.1536100, 0.1168531, 18.1564220>,
    <2.1536162, -0.0049164, 18.1564220>,
    <2.1585340, 0.3603813, 18.1573801>,
    <2.1535976, 0.3603920, 18.1564220>,
    <2.1585402, 0.2386171, 18.1573801>,
    <2.1536038, 0.2386225, 18.1564220>,
    <2.1684068, 0.3603600, 18.1592964>,
    <2.1684191, 0.1168527, 18.1592964>,
    <2.1634704, 0.3603706, 18.1583383>,
    <2.1684129, 0.2386063, 18.1592964>,
    <2.1634827, 0.1168528, 18.1583383>,
    <2.1634766, 0.2386117, 18.1583383>,
    <2.1684253, -0.0049010, 18.1592964>,
    <2.1634889, -0.0049061, 18.1583383>,
    <2.0812351, 0.3603606, 18.1573801>,
    <2.1198845, 0.3603709, 18.1573801>,
    <2.0787910, 0.3603715, 18.1564220>,
    <2.1161943, 0.3603817, 18.1564220>,
    <2.0039361, 0.3603399, 18.1573801>,
    <2.0039844, 0.3603510, 18.1564220>,
    <2.0425856, 0.3603502, 18.1573801>,
    <2.0413877, 0.3603612, 18.1564220>,
    <2.0038397, 0.3603176, 18.1592964>,
    <2.0861232, 0.3603388, 18.1592964>,
    <2.0038879, 0.3603287, 18.1583383>,
    <2.0449814, 0.3603282, 18.1592964>,
    <2.0836791, 0.3603497, 18.1583383>,
    <2.0437835, 0.3603392, 18.1583383>,
    <2.1272650, 0.3603494, 18.1592964>,
    <2.1235748, 0.3603602, 18.1583383>,
    <2.0872214, -0.1266858, 18.2324892>,
    <2.0038724, -0.1267246, 18.2344341>,
    <2.0455456, -0.1267050, 18.2333227>,
    <2.0038727, -0.1267247, 18.1968653>,
    <2.0861681, -0.1266896, 18.1968653>,
    <2.0450204, -0.1267072, 18.1968653>,
    <2.1705857, -0.1266501, 18.2322113>,
    <2.1684634, -0.1266546, 18.1968653>,
    <2.1289022, -0.1266677, 18.2322113>,
    <2.1273157, -0.1266721, 18.1968653>,
    <2.1894619, -0.1266104, 18.2873438>,
    <2.0965801, -0.1266498, 18.2890109>,
    <2.1768884, -0.1266368, 18.2631118>,
    <2.1430133, -0.1266285, 18.2873438>,
    <2.0903496, -0.1266745, 18.2642232>,
    <2.1336139, -0.1266546, 18.2631118>,
    <2.0038718, -0.1267245, 18.3095719>,
    <2.0501774, -0.1266773, 18.2940122>,
    <2.0038721, -0.1267246, 18.2720030>,
    <2.0471057, -0.1266985, 18.2675574>,
    <2.1705733, 0.1168526, 18.2322113>,
    <2.1705795, -0.0048987, 18.2322113>,
    <2.1684511, 0.1168527, 18.1968653>,
    <2.1684573, -0.0049009, 18.1968653>,
    <2.1705610, 0.3603553, 18.2322113>,
    <2.1684387, 0.3603599, 18.1968653>,
    <2.1705672, 0.2386040, 18.2322113>,
    <2.1684449, 0.2386063, 18.1968653>,
    <2.1894375, 0.3603146, 18.2873438>,
    <2.1894497, 0.1168521, 18.2873438>,
    <2.1768638, 0.3603417, 18.2631118>,
    <2.1894436, 0.2385834, 18.2873438>,
    <2.1768761, 0.1168524, 18.2631118>,
    <2.1768700, 0.2385971, 18.2631118>,
    <2.1894558, -0.0048791, 18.2873438>,
    <2.1768823, -0.0048922, 18.2631118>,
    <2.0871924, 0.3603347, 18.2324892>,
    <2.1288754, 0.3603447, 18.2322113>,
    <2.0861391, 0.3603387, 18.1968653>,
    <2.1272889, 0.3603493, 18.1968653>,
    <2.0038391, 0.3603175, 18.2344341>,
    <2.0038394, 0.3603176, 18.1968653>,
    <2.0455144, 0.3603258, 18.2333227>,
    <2.0449892, 0.3603282, 18.1968653>,
    <2.0038384, 0.3603174, 18.3095719>,
    <2.0965512, 0.3602960, 18.2890109>,
    <2.0038387, 0.3603174, 18.2720030>,
    <2.0501463, 0.3602955, 18.2940122>,
    <2.0903206, 0.3603225, 18.2642232>,
    <2.0470746, 0.3603188, 18.2675574>,
    <2.1429867, 0.3603035, 18.2873438>,
    <2.1335871, 0.3603310, 18.2631118>,
    <2.1194133, -0.1265524, 18.3131904>,
    <2.0032176, -0.1265917, 18.3135798>,
    <2.0613154, -0.1265720, 18.3133573>,
    <2.0035447, -0.1266581, 18.3115759>,
    <2.1069400, -0.1266060, 18.3037960>,
    <2.0552372, -0.1266310, 18.3071303>,
    <2.2356097, -0.1265133, 18.3131347>,
    <2.2103965, -0.1265663, 18.3026846>,
    <2.1775114, -0.1265328, 18.3131347>,
    <2.1586631, -0.1265851, 18.3026846>,
    <2.2825423, -0.1264145, 18.3353648>,
    <2.1426356, -0.1264535, 18.3340315>,
    <2.2610191, -0.1264598, 18.3226946>,
    <2.2125963, -0.1264355, 18.3353648>,
    <2.1319840, -0.1264985, 18.3218058>,
    <2.1965064, -0.1264801, 18.3226946>,
    <2.0025635, -0.1264588, 18.3175878>,
    <2.0726458, -0.1264655, 18.3300317>,
    <2.0028906, -0.1265252, 18.3155838>,
    <2.0674422, -0.1265128, 18.3191392>,
    <2.2355977, 0.1168509, 18.3131347>,
    <2.2356037, -0.0048312, 18.3131347>,
    <2.2103844, 0.1168515, 18.3026846>,
    <2.2103904, -0.0048574, 18.3026846>,
    <2.2355857, 0.3602150, 18.3131347>,
    <2.2103722, 0.3602694, 18.3026846>,
    <2.2355917, 0.2385329, 18.3131347>,
    <2.2103783, 0.2385605, 18.3026846>,
    <2.2825188, 0.3601137, 18.3353648>,
    <2.2825305, 0.1168496, 18.3353648>,
    <2.2609953, 0.3601602, 18.3226946>,
    <2.2825246, 0.2384817, 18.3353648>,
    <2.2610072, 0.1168502, 18.3226946>,
    <2.2610013, 0.2385052, 18.3226946>,
    <2.2825364, -0.0047825, 18.3353648>,
    <2.2610131, -0.0048048, 18.3226946>,
    <2.1193847, 0.3601908, 18.3131904>,
    <2.1774851, 0.3602029, 18.3131347>,
    <2.1069112, 0.3602487, 18.3037960>,
    <2.1586366, 0.3602579, 18.3026846>,
    <2.0031844, 0.3601667, 18.3135798>,
    <2.0035114, 0.3602420, 18.3115759>,
    <2.0612845, 0.3601788, 18.3133573>,
    <2.0552062, 0.3602442, 18.3071303>,
    <2.0025303, 0.3600161, 18.3175878>,
    <2.1426072, 0.3600840, 18.3340315>,
    <2.0028573, 0.3600914, 18.3155838>,
    <2.0726150, 0.3600607, 18.3300317>,
    <2.1319555, 0.3601325, 18.3218058>,
    <2.0674113, 0.3601131, 18.3191392>,
    <2.2125703, 0.3601005, 18.3353648>,
    <2.1964803, 0.3601475, 18.3226946>,
    <2.1531110, -0.1264127, 18.3800376>,
    <2.0025322, -0.1264525, 18.3784821>,
    <2.0778228, -0.1264328, 18.3793709>,
    <2.0025479, -0.1264556, 18.3480349>,
    <2.1493516, -0.1264267, 18.3542569>,
    <2.0759546, -0.1264422, 18.3515903>,
    <2.3036751, -0.1263701, 18.3802598>,
    <2.2960969, -0.1263860, 18.3551457>,
    <2.2283943, -0.1263916, 18.3802598>,
    <2.2227291, -0.1264074, 18.3551457>,
    <2.3088707, -0.1263591, 18.4393764>,
    <2.1556858, -0.1264026, 18.4393764>,
    <2.3072690, -0.1263625, 18.4089292>,
    <2.2322783, -0.1263809, 18.4393764>,
    <2.1548928, -0.1264059, 18.4089292>,
    <2.2310809, -0.1263842, 18.4089292>,
    <2.0025009, -0.1264461, 18.4393764>,
    <2.0790934, -0.1264244, 18.4393764>,
    <2.0025166, -0.1264493, 18.4089292>,
    <2.0787047, -0.1264276, 18.4089292>,
    <2.3036635, 0.1168490, 18.3802598>,
    <2.3036693, -0.0047605, 18.3802598>,
    <2.2960852, 0.1168492, 18.3551457>,
    <2.2960911, -0.0047684, 18.3551457>,
    <2.3036518, 0.3600681, 18.3802598>,
    <2.2960735, 0.3600845, 18.3551457>,
    <2.3036576, 0.2384586, 18.3802598>,
    <2.2960794, 0.2384668, 18.3551457>,
    <2.3088475, 0.3600569, 18.4393764>,
    <2.3088591, 0.1168489, 18.4393764>,
    <2.3072457, 0.3600603, 18.4089292>,
    <2.3088533, 0.2384529, 18.4393764>,
    <2.3072574, 0.1168489, 18.4089292>,
    <2.3072515, 0.2384546, 18.4089292>,
    <2.3088649, -0.0047551, 18.4393764>,
    <2.3072632, -0.0047568, 18.4089292>,
    <2.1530827, 0.3600402, 18.3800376>,
    <2.2283685, 0.3600544, 18.3802598>,
    <2.1493233, 0.3600552, 18.3542569>,
    <2.2227033, 0.3600710, 18.3551457>,
    <2.0024990, 0.3600089, 18.3784821>,
    <2.0025147, 0.3600125, 18.3480349>,
    <2.0777921, 0.3600248, 18.3793709>,
    <2.0759238, 0.3600350, 18.3515903>,
    <2.0024677, 0.3600017, 18.4393764>,
    <2.1556576, 0.3600293, 18.4393764>,
    <2.0024834, 0.3600053, 18.4089292>,
    <2.0790627, 0.3600155, 18.4393764>,
    <2.1548645, 0.3600328, 18.4089292>,
    <2.0786740, 0.3600191, 18.4089292>,
    <2.2322525, 0.3600431, 18.4393764>,
    <2.2310551, 0.3600466, 18.4089292>,
    <2.1641424, -0.1263677, 18.4393764>,
    <2.0023340, -0.1264122, 18.4393764>,
    <2.0832382, -0.1263900, 18.4393764>,
    <2.0024175, -0.1264292, 18.4393764>,
    <2.1599141, -0.1263852, 18.4393764>,
    <2.0811658, -0.1264072, 18.4393764>,
    <2.3259508, -0.1263232, 18.4393764>,
    <2.3174108, -0.1263412, 18.4393764>,
    <2.2450466, -0.1263454, 18.4393764>,
    <2.2386625, -0.1263632, 18.4393764>,
    <2.3430309, -0.1262872, 18.4393764>,
    <2.1725990, -0.1263328, 18.4393764>,
    <2.3344909, -0.1263052, 18.4393764>,
    <2.2578150, -0.1263100, 18.4393764>,
    <2.1683707, -0.1263502, 18.4393764>,
    <2.2514308, -0.1263277, 18.4393764>,
    <2.0021672, -0.1263783, 18.4393764>,
    <2.0873831, -0.1263556, 18.4393764>,
    <2.0022506, -0.1263953, 18.4393764>,
    <2.0853107, -0.1263728, 18.4393764>,
    <2.3259393, 0.1168484, 18.4393764>,
    <2.3259450, -0.0047374, 18.4393764>,
    <2.3173992, 0.1168486, 18.4393764>,
    <2.3174050, -0.0047463, 18.4393764>,
    <2.3259277, 0.3600200, 18.4393764>,
    <2.3173876, 0.3600385, 18.4393764>,
    <2.3259335, 0.2384342, 18.4393764>,
    <2.3173934, 0.2384436, 18.4393764>,
    <2.3430079, 0.3599832, 18.4393764>,
    <2.3430194, 0.1168480, 18.4393764>,
    <2.3344678, 0.3600016, 18.4393764>,
    <2.3430137, 0.2384156, 18.4393764>,
    <2.3344793, 0.1168482, 18.4393764>,
    <2.3344736, 0.2384249, 18.4393764>,
    <2.3430251, -0.0047196, 18.4393764>,
    <2.3344851, -0.0047285, 18.4393764>,
    <2.1641143, 0.3599917, 18.4393764>,
    <2.2450210, 0.3600058, 18.4393764>,
    <2.1598859, 0.3600105, 18.4393764>,
    <2.2386368, 0.3600245, 18.4393764>,
    <2.0023009, 0.3599633, 18.4393764>,
    <2.0023843, 0.3599825, 18.4393764>,
    <2.0832076, 0.3599775, 18.4393764>,
    <2.0811351, 0.3599965, 18.4393764>,
    <2.0021340, 0.3599249, 18.4393764>,
    <2.1725710, 0.3599540, 18.4393764>,
    <2.0022174, 0.3599441, 18.4393764>,
    <2.0873525, 0.3599394, 18.4393764>,
    <2.1683426, 0.3599728, 18.4393764>,
    <2.0852800, 0.3599585, 18.4393764>,
    <2.2577895, 0.3599686, 18.4393764>,
    <2.2514052, 0.3599872, 18.4393764>,
    <2.1725990, -0.1263328, 18.4905874>,
    <2.0021672, -0.1263783, 18.4905874>,
    <2.0873831, -0.1263556, 18.4905874>,
    <2.0021672, -0.1263783, 18.4649819>,
    <2.1725990, -0.1263328, 18.4649819>,
    <2.0873831, -0.1263556, 18.4649819>,
    <2.3430309, -0.1262872, 18.4905874>,
    <2.3430309, -0.1262872, 18.4649819>,
    <2.2578150, -0.1263100, 18.4905874>,
    <2.2578150, -0.1263100, 18.4649819>,
    <2.3430309, -0.1262872, 18.5161929>,
    <2.1725990, -0.1263328, 18.5161929>,
    <2.2578150, -0.1263100, 18.5161929>,
    <2.0021672, -0.1263783, 18.5161929>,
    <2.0873831, -0.1263556, 18.5161929>,
    <2.3430194, 0.1168480, 18.4905874>,
    <2.3430251, -0.0047196, 18.4905874>,
    <2.3430194, 0.1168480, 18.4649819>,
    <2.3430251, -0.0047196, 18.4649819>,
    <2.3430079, 0.3599832, 18.4905874>,
    <2.3430079, 0.3599832, 18.4649819>,
    <2.3430137, 0.2384156, 18.4905874>,
    <2.3430137, 0.2384156, 18.4649819>,
    <2.3430079, 0.3599832, 18.5161929>,
    <2.3430194, 0.1168480, 18.5161929>,
    <2.3430137, 0.2384156, 18.5161929>,
    <2.3430251, -0.0047196, 18.5161929>,
    <2.1725710, 0.3599540, 18.4905874>,
    <2.2577895, 0.3599686, 18.4905874>,
    <2.1725710, 0.3599540, 18.4649819>,
    <2.2577895, 0.3599686, 18.4649819>,
    <2.0021340, 0.3599249, 18.4905874>,
    <2.0021340, 0.3599249, 18.4649819>,
    <2.0873525, 0.3599394, 18.4905874>,
    <2.0873525, 0.3599394, 18.4649819>,
    <2.0021340, 0.3599249, 18.5161929>,
    <2.1725710, 0.3599540, 18.5161929>,
    <2.0873525, 0.3599394, 18.5161929>,
    <2.2577895, 0.3599686, 18.5161929>,
    <2.0021506, 0.1167733, 18.4905874>,
    <2.0021672, -0.1263783, 18.4905874>,
    <2.0021506, 0.1167733, 18.4393764>,
    <2.0021589, -0.0048025, 18.4905874>,
    <2.0021672, -0.1263783, 18.4649819>,
    <2.0021589, -0.0048025, 18.4393764>,
    <2.0021506, 0.1167733, 18.4649819>,
    <2.0021589, -0.0048025, 18.4649819>,
    <2.0021340, 0.3599249, 18.4905874>,
    <2.0021423, 0.2383491, 18.4393764>,
    <2.0021340, 0.3599249, 18.4649819>,
    <2.0021423, 0.2383491, 18.4905874>,
    <2.0021423, 0.2383491, 18.4649819>,
    <2.0021506, 0.1167733, 18.5417983>,
    <2.0021340, 0.3599249, 18.5161929>,
    <2.0021423, 0.2383491, 18.5417983>,
    <2.0021506, 0.1167733, 18.5161929>,
    <2.0021423, 0.2383491, 18.5161929>,
    <2.0021589, -0.0048025, 18.5417983>,
    <2.0021672, -0.1263783, 18.5161929>,
    <2.0021589, -0.0048025, 18.5161929>,
    <2.0023174, 0.1167755, 18.4393764>,
    <2.0024843, 0.1167778, 18.4393764>,
    <2.0024009, 0.1167767, 18.4393764>,
    <2.0024926, -0.0048341, 18.4393764>,
    <2.0023257, -0.0048183, 18.4393764>,
    <2.0024092, -0.0048262, 18.4393764>,
    <2.0021506, 0.1167733, 18.4393764>,
    <2.0021589, -0.0048025, 18.4393764>,
    <2.0022340, 0.1167744, 18.4393764>,
    <2.0022423, -0.0048104, 18.4393764>,
    <2.0021423, 0.2383491, 18.4393764>,
    <2.0023092, 0.2383694, 18.4393764>,
    <2.0022257, 0.2383592, 18.4393764>,
    <2.0024760, 0.2383898, 18.4393764>,
    <2.0023926, 0.2383796, 18.4393764>,
    <2.0025156, 0.1167782, 18.3784821>,
    <2.0025322, -0.1264525, 18.3784821>,
    <2.0025469, 0.1167787, 18.3175878>,
    <2.0025239, -0.0048371, 18.3784821>,
    <2.0025479, -0.1264556, 18.3480349>,
    <2.0025552, -0.0048401, 18.3175878>,
    <2.0025313, 0.1167784, 18.3480349>,
    <2.0025396, -0.0048386, 18.3480349>,
    <2.0024990, 0.3600089, 18.3784821>,
    <2.0025386, 0.2383974, 18.3175878>,
    <2.0025147, 0.3600125, 18.3480349>,
    <2.0025073, 0.2383936, 18.3784821>,
    <2.0025230, 0.2383955, 18.3480349>,
    <2.0024843, 0.1167778, 18.4393764>,
    <2.0024834, 0.3600053, 18.4089292>,
    <2.0024760, 0.2383898, 18.4393764>,
    <2.0025000, 0.1167780, 18.4089292>,
    <2.0024917, 0.2383917, 18.4089292>,
    <2.0024926, -0.0048341, 18.4393764>,
    <2.0025166, -0.1264493, 18.4089292>,
    <2.0025083, -0.0048356, 18.4089292>,
    <2.0032010, 0.1167875, 18.3135798>,
    <2.0038551, 0.1167964, 18.3095719>,
    <2.0035281, 0.1167920, 18.3115759>,
    <2.0038634, -0.0049640, 18.3095719>,
    <2.0032093, -0.0049021, 18.3135798>,
    <2.0035364, -0.0049330, 18.3115759>,
    <2.0025469, 0.1167787, 18.3175878>,
    <2.0025552, -0.0048401, 18.3175878>,
    <2.0028740, 0.1167831, 18.3155838>,
    <2.0028823, -0.0048711, 18.3155838>,
    <2.0025386, 0.2383974, 18.3175878>,
    <2.0031927, 0.2384771, 18.3135798>,
    <2.0028656, 0.2384373, 18.3155838>,
    <2.0038468, 0.2385569, 18.3095719>,
    <2.0035197, 0.2385170, 18.3115759>,
    <2.0038557, 0.1167964, 18.2344341>,
    <2.0038724, -0.1267246, 18.2344341>,
    <2.0038563, 0.1167964, 18.1592964>,
    <2.0038641, -0.0049641, 18.2344341>,
    <2.0038727, -0.1267247, 18.1968653>,
    <2.0038647, -0.0049642, 18.1592964>,
    <2.0038560, 0.1167964, 18.1968653>,
    <2.0038644, -0.0049641, 18.1968653>,
    <2.0038391, 0.3603175, 18.2344341>,
    <2.0038480, 0.2385570, 18.1592964>,
    <2.0038394, 0.3603176, 18.1968653>,
    <2.0038474, 0.2385570, 18.2344341>,
    <2.0038477, 0.2385570, 18.1968653>,
    <2.0038551, 0.1167964, 18.3095719>,
    <2.0038387, 0.3603174, 18.2720030>,
    <2.0038468, 0.2385569, 18.3095719>,
    <2.0038554, 0.1167964, 18.2720030>,
    <2.0038471, 0.2385569, 18.2720030>,
    <2.0038634, -0.0049640, 18.3095719>,
    <2.0038721, -0.1267246, 18.2720030>,
    <2.0038637, -0.0049641, 18.2720030>,
    <2.0039528, 0.1167978, 18.1573801>,
    <2.0040493, 0.1167991, 18.1554639>,
    <2.0040010, 0.1167984, 18.1564220>,
    <2.0040576, -0.0049824, 18.1554639>,
    <2.0039611, -0.0049733, 18.1573801>,
    <2.0040094, -0.0049779, 18.1564220>,
    <2.0038563, 0.1167964, 18.1592964>,
    <2.0038647, -0.0049642, 18.1592964>,
    <2.0039046, 0.1167971, 18.1583383>,
    <2.0039129, -0.0049687, 18.1583383>,
    <2.0038480, 0.2385570, 18.1592964>,
    <2.0039445, 0.2385688, 18.1573801>,
    <2.0038962, 0.2385629, 18.1583383>,
    <2.0040409, 0.2385806, 18.1554639>,
    <2.0039927, 0.2385747, 18.1564220>,
    <2.0042444, 0.1168017, 18.1389725>,
    <2.0042673, -0.1268048, 18.1386133>,
    <2.0043812, 0.1168036, 18.1258340>,
    <2.0042548, -0.0050016, 18.1388528>,
    <2.0043680, -0.1268253, 18.1301880>,
    <2.0044020, -0.0050178, 18.1251156>,
    <2.0043263, 0.1168028, 18.1316249>,
    <2.0043430, -0.0050113, 18.1311460>,
    <2.0042339, 0.3604084, 18.1386133>,
    <2.0043853, 0.2386253, 18.1251156>,
    <2.0043346, 0.3604316, 18.1301880>,
    <2.0042381, 0.2386051, 18.1388528>,
    <2.0043263, 0.2386172, 18.1311460>,
    <2.0040493, 0.1167991, 18.1554639>,
    <2.0041333, 0.3603852, 18.1470386>,
    <2.0040409, 0.2385806, 18.1554639>,
    <2.0041499, 0.1168004, 18.1470386>,
    <2.0041416, 0.2385928, 18.1470386>,
    <2.0040576, -0.0049824, 18.1554639>,
    <2.0041666, -0.1267844, 18.1470386>,
    <2.0041583, -0.0049920, 18.1470386>,
    <2.0043805, 0.1168036, 18.1205987>,
    <2.0043944, 0.1168038, 18.1224380>,
    <2.0043909, -0.0050145, 18.1204790>,
    <2.0044111, -0.0050177, 18.1219591>,
    <2.0043215, 0.1168028, 18.1187163>,
    <2.0043298, -0.0050082, 18.1187163>,
    <2.0043541, 0.1168032, 18.1194779>,
    <2.0043625, -0.0050113, 18.1194779>,
    <2.0043131, 0.2386138, 18.1187163>,
    <2.0043742, 0.2386217, 18.1204790>,
    <2.0043458, 0.2386177, 18.1194779>,
    <2.0043944, 0.2386255, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0005941, 0.9999662, 0.0082020>,
    <-0.0005941, 0.9999704, 0.0076758>,
    <-0.0005795, 0.9999701, 0.0077076>,
    <-0.0005795, 0.9999661, 0.0082176>,
    <-0.0005795, 0.9999617, 0.0087276>,
    <-0.0005941, 0.9999617, 0.0087283>,
    <-0.0005941, 0.9999617, 0.0087283>,
    <-0.0006097, 0.9999617, 0.0087289>,
    <-0.0006097, 0.9999663, 0.0081855>,
    <-0.0006097, 0.9999663, 0.0081855>,
    <-0.0006097, 0.9999706, 0.0076420>,
    <-0.0005941, 0.9999743, 0.0071496>,
    <-0.0005795, 0.9999739, 0.0071975>,
    <-0.0006097, 0.9999706, 0.0076420>,
    <-0.0006097, 0.9999746, 0.0070986>,
    <-0.0006097, 0.9999746, 0.0070986>,
    <-0.0006097, 0.9999783, 0.0065551>,
    <-0.0005941, 0.9999779, 0.0066234>,
    <-0.0005941, 0.9999779, 0.0066234>,
    <-0.0005795, 0.9999775, 0.0066875>,
    <-0.0005658, 0.9999736, 0.0072426>,
    <-0.0005658, 0.9999699, 0.0077374>,
    <-0.0005795, 0.9999775, 0.0066875>,
    <-0.0005658, 0.9999771, 0.0067477>,
    <-0.0005658, 0.9999771, 0.0067477>,
    <-0.0005529, 0.9999767, 0.0068045>,
    <-0.0005529, 0.9999733, 0.0072850>,
    <-0.0005529, 0.9999733, 0.0072850>,
    <-0.0005529, 0.9999697, 0.0077655>,
    <-0.0005658, 0.9999660, 0.0082322>,
    <-0.0005529, 0.9999697, 0.0077655>,
    <-0.0005529, 0.9999658, 0.0082460>,
    <-0.0005529, 0.9999658, 0.0082460>,
    <-0.0005528, 0.9999618, 0.0087265>,
    <-0.0005658, 0.9999618, 0.0087270>,
    <-0.0005658, 0.9999618, 0.0087270>,
    <-0.0005795, 0.9999617, 0.0087276>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <0.0003486, -0.9999426, 0.0107096>,
    <0.0003486, -0.9999456, 0.0104237>,
    <0.0003407, -0.9999458, 0.0104065>,
    <0.0003407, -0.9999429, 0.0106836>,
    <0.0003407, -0.9999399, 0.0109607>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003571, -0.9999391, 0.0110326>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003486, -0.9999486, 0.0101378>,
    <0.0003407, -0.9999486, 0.0101293>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999514, 0.0098515>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999487, 0.0101214>,
    <0.0003332, -0.9999460, 0.0103903>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003262, -0.9999514, 0.0098528>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003332, -0.9999431, 0.0106591>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999406, 0.0108971>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003407, -0.9999399, 0.0109607>,
    <0.0005282, -0.9999988, 0.0014301>,
    <0.0005282, -0.9999989, 0.0013517>,
    <0.0005061, -0.9999989, 0.0013600>,
    <0.0005061, -0.9999988, 0.0014341>,
    <0.0005061, -0.9999987, 0.0015083>,
    <0.0005282, -0.9999987, 0.0015084>,
    <0.0005282, -0.9999987, 0.0015084>,
    <0.0005529, -0.9999987, 0.0015086>,
    <0.0005529, -0.9999988, 0.0014255>,
    <0.0005529, -0.9999988, 0.0014255>,
    <0.0005529, -0.9999989, 0.0013425>,
    <0.0005282, -0.9999990, 0.0012734>,
    <0.0005061, -0.9999990, 0.0012859>,
    <0.0005529, -0.9999989, 0.0013425>,
    <0.0005529, -0.9999991, 0.0012594>,
    <0.0005529, -0.9999991, 0.0012594>,
    <0.0005529, -0.9999992, 0.0011763>,
    <0.0005282, -0.9999991, 0.0011951>,
    <0.0005282, -0.9999991, 0.0011951>,
    <0.0005061, -0.9999991, 0.0012118>,
    <0.0004863, -0.9999990, 0.0012971>,
    <0.0004863, -0.9999989, 0.0013674>,
    <0.0005061, -0.9999991, 0.0012118>,
    <0.0004863, -0.9999991, 0.0012268>,
    <0.0004863, -0.9999991, 0.0012268>,
    <0.0004684, -0.9999991, 0.0012403>,
    <0.0004684, -0.9999990, 0.0013072>,
    <0.0004684, -0.9999990, 0.0013072>,
    <0.0004684, -0.9999989, 0.0013742>,
    <0.0004863, -0.9999988, 0.0014378>,
    <0.0004684, -0.9999989, 0.0013742>,
    <0.0004684, -0.9999989, 0.0014411>,
    <0.0004684, -0.9999989, 0.0014411>,
    <0.0004684, -0.9999988, 0.0015080>,
    <0.0004863, -0.9999987, 0.0015081>,
    <0.0004863, -0.9999987, 0.0015081>,
    <0.0005061, -0.9999987, 0.0015083>,
    <0.7968310, 0.0000411, -0.6042023>,
    <0.7968303, 0.0000411, -0.6042032>,
    <0.7968303, 0.0000409, -0.6042032>,
    <0.7968310, 0.0000409, -0.6042023>,
    <0.7968317, 0.0000409, -0.6042013>,
    <0.7968317, 0.0000411, -0.6042013>,
    <0.7968317, 0.0000411, -0.6042013>,
    <0.7968317, 0.0000412, -0.6042013>,
    <0.7968310, 0.0000412, -0.6042023>,
    <0.7968310, 0.0000412, -0.6042023>,
    <0.7968303, 0.0000412, -0.6042032>,
    <0.7968295, 0.0000411, -0.6042042>,
    <0.7968295, 0.0000409, -0.6042042>,
    <0.7968303, 0.0000412, -0.6042032>,
    <0.7968295, 0.0000412, -0.6042042>,
    <0.7968295, 0.0000412, -0.6042042>,
    <0.7968288, 0.0000412, -0.6042051>,
    <0.7968288, 0.0000411, -0.6042051>,
    <0.7968288, 0.0000411, -0.6042051>,
    <0.7968288, 0.0000409, -0.6042051>,
    <0.7968295, 0.0000408, -0.6042042>,
    <0.7968303, 0.0000408, -0.6042032>,
    <0.7968288, 0.0000409, -0.6042051>,
    <0.7968288, 0.0000408, -0.6042051>,
    <0.7968288, 0.0000408, -0.6042051>,
    <0.7968288, 0.0000407, -0.6042051>,
    <0.7968295, 0.0000407, -0.6042042>,
    <0.7968295, 0.0000407, -0.6042042>,
    <0.7968303, 0.0000407, -0.6042032>,
    <0.7968310, 0.0000408, -0.6042023>,
    <0.7968303, 0.0000407, -0.6042032>,
    <0.7968310, 0.0000407, -0.6042023>,
    <0.7968310, 0.0000407, -0.6042023>,
    <0.7968317, 0.0000407, -0.6042013>,
    <0.7968317, 0.0000408, -0.6042013>,
    <0.7968317, 0.0000408, -0.6042013>,
    <0.7968317, 0.0000409, -0.6042013>,
    <-0.0003128, 0.9999983, 0.0018311>,
    <-0.0003128, 0.9999984, 0.0017886>,
    <-0.0003008, 0.9999984, 0.0017841>,
    <-0.0003008, 0.9999983, 0.0018243>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003262, 0.9999982, 0.0018839>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003128, 0.9999984, 0.0017460>,
    <-0.0003008, 0.9999984, 0.0017438>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999985, 0.0017033>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999984, 0.0017418>,
    <-0.0002901, 0.9999984, 0.0017800>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002803, 0.9999985, 0.0017037>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002901, 0.9999983, 0.0018183>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018491>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <0.0004568, -0.9999518, 0.0098056>,
    <0.0004568, -0.9999560, 0.0093662>,
    <0.0004459, -0.9999558, 0.0093940>,
    <0.0004459, -0.9999517, 0.0098193>,
    <0.0004459, -0.9999474, 0.0102445>,
    <0.0004568, -0.9999474, 0.0102451>,
    <0.0004568, -0.9999474, 0.0102451>,
    <0.0004684, -0.9999474, 0.0102456>,
    <0.0004684, -0.9999520, 0.0097911>,
    <0.0004684, -0.9999520, 0.0097911>,
    <0.0004684, -0.9999563, 0.0093365>,
    <0.0004568, -0.9999601, 0.0089268>,
    <0.0004459, -0.9999597, 0.0089688>,
    <0.0004684, -0.9999563, 0.0093365>,
    <0.0004684, -0.9999604, 0.0088820>,
    <0.0004684, -0.9999604, 0.0088820>,
    <0.0004684, -0.9999644, 0.0084274>,
    <0.0004568, -0.9999639, 0.0084874>,
    <0.0004568, -0.9999639, 0.0084874>,
    <0.0004459, -0.9999634, 0.0085435>,
    <0.0004357, -0.9999593, 0.0090081>,
    <0.0004357, -0.9999555, 0.0094201>,
    <0.0004459, -0.9999634, 0.0085435>,
    <0.0004357, -0.9999630, 0.0085961>,
    <0.0004357, -0.9999630, 0.0085961>,
    <0.0004261, -0.9999625, 0.0086456>,
    <0.0004261, -0.9999590, 0.0090451>,
    <0.0004261, -0.9999590, 0.0090451>,
    <0.0004261, -0.9999553, 0.0094445>,
    <0.0004357, -0.9999516, 0.0098320>,
    <0.0004261, -0.9999553, 0.0094445>,
    <0.0004261, -0.9999515, 0.0098440>,
    <0.0004261, -0.9999515, 0.0098440>,
    <0.0004261, -0.9999474, 0.0102435>,
    <0.0004357, -0.9999474, 0.0102440>,
    <0.0004357, -0.9999474, 0.0102440>,
    <0.0004459, -0.9999474, 0.0102445>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <-0.0002740, 0.9999244, 0.0122917>,
    <-0.0002740, 0.9999273, 0.0120530>,
    <-0.0002681, 0.9999275, 0.0120379>,
    <-0.0002681, 0.9999247, 0.0122689>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002803, 0.9999210, 0.0125631>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002740, 0.9999302, 0.0118142>,
    <-0.0002681, 0.9999303, 0.0118068>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999330, 0.0115751>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999303, 0.0117999>,
    <-0.0002625, 0.9999277, 0.0120237>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002573, 0.9999330, 0.0115763>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002625, 0.9999250, 0.0122476>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999225, 0.0124445>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <0.0004328, -0.9999999, 0.0000263>,
    <0.0004297, -0.9999999, 0.0000444>,
    <0.0004572, -0.9999999, 0.0001852>,
    <0.0004819, -0.9999999, 0.0001033>,
    <0.0004871, -0.9999999, 0.0000017>,
    <0.0004338, -0.9999999, 0.0000017>,
    <0.0004338, -0.9999999, 0.0000017>,
    <0.0004261, -0.9999999, 0.0000017>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004264, -0.9999999, 0.0000506>,
    <0.0004300, -0.9999999, 0.0002171>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000015>,
    <0.0004261, -0.9999999, 0.0000015>,
    <0.0004261, -0.9999999, 0.0000014>,
    <0.0004254, -0.9999999, 0.0000496>,
    <0.0004254, -0.9999999, 0.0000496>,
    <0.0004208, -0.9999999, 0.0002141>,
    <0.0004392, -0.9999997, 0.0005874>,
    <0.0005266, -0.9999997, 0.0005300>,
    <0.0004208, -0.9999999, 0.0002141>,
    <0.0004092, -0.9999997, 0.0005804>,
    <0.0004092, -0.9999997, 0.0005804>,
    <0.0003889, -0.9999989, 0.0014524>,
    <0.0004419, -0.9999988, 0.0014766>,
    <0.0006011, -0.9999987, 0.0014789>,
    <0.0006366, -0.9999997, 0.0003445>,
    <0.0009775, -0.9999984, 0.0015046>,
    <0.0012929, -0.9999977, 0.0016908>,
    <0.0006563, -0.9999998, 0.0000017>,
    <0.0006563, -0.9999998, 0.0000017>,
    <0.0004871, -0.9999999, 0.0000017>,
    <0.9995639, 0.0000507, -0.0295315>,
    <0.9995638, 0.0000507, -0.0295315>,
    <0.9920098, 0.0000502, -0.1261608>,
    <0.9920098, 0.0000502, -0.1261605>,
    <0.9920099, 0.0000502, -0.1261602>,
    <0.9995639, 0.0000507, -0.0295314>,
    <0.9995639, 0.0000507, -0.0295314>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9995638, 0.0000507, -0.0295316>,
    <0.9920098, 0.0000502, -0.1261611>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9995638, 0.0000507, -0.0295317>,
    <0.9995638, 0.0000507, -0.0295317>,
    <0.9920097, 0.0000502, -0.1261614>,
    <0.9460835, 0.0000478, -0.3239228>,
    <0.9460838, 0.0000478, -0.3239221>,
    <0.9920097, 0.0000502, -0.1261614>,
    <0.9460833, 0.0000478, -0.3239235>,
    <0.9460833, 0.0000478, -0.3239235>,
    <0.7631609, 0.0000384, -0.6462085>,
    <0.7631617, 0.0000384, -0.6462076>,
    <0.7631625, 0.0000384, -0.6462067>,
    <0.9460840, 0.0000478, -0.3239213>,
    <0.7631632, 0.0000384, -0.6462057>,
    <0.7631640, 0.0000384, -0.6462048>,
    <0.9460843, 0.0000478, -0.3239206>,
    <0.9460843, 0.0000478, -0.3239206>,
    <0.9920099, 0.0000502, -0.1261602>,
    <-0.0002557, 1.0000000, 0.0000687>,
    <-0.0002521, 1.0000000, 0.0000578>,
    <-0.0002128, 0.9999999, 0.0002410>,
    <-0.0002438, 0.9999999, 0.0002938>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002573, 1.0000000, 0.0000021>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002485, 1.0000000, 0.0000335>,
    <-0.0001849, 1.0000000, 0.0001319>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000127, 0.9999999, 0.0004262>,
    <-0.0001114, 0.9999998, 0.0006796>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0004444, 0.9999983, 0.0017942>,
    <0.0000146, 0.9999983, 0.0018600>,
    <-0.0002126, 0.9999997, 0.0007890>,
    <-0.0001727, 0.9999981, 0.0019562>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <0.0009820, -0.9999841, 0.0055500>,
    <0.0005787, -0.9999933, 0.0036053>,
    <0.0003522, -0.9999833, 0.0057696>,
    <0.0003820, -0.9999521, 0.0097787>,
    <0.0005080, -0.9994483, 0.0332100>,
    <0.0042098, -0.9994193, 0.0338132>,
    <0.0042098, -0.9994193, 0.0338132>,
    <0.0012929, -0.9999977, 0.0016908>,
    <0.0004125, -0.9999948, 0.0032130>,
    <0.0003397, -0.9999888, 0.0047174>,
    <0.0003889, -0.9999989, 0.0014524>,
    <0.0003623, -0.9999951, 0.0031167>,
    <0.0003623, -0.9999951, 0.0031167>,
    <0.0003364, -0.9999899, 0.0044723>,
    <0.0002761, -0.9999919, 0.0040074>,
    <0.0001403, -0.9999887, 0.0047436>,
    <0.0003364, -0.9999899, 0.0044723>,
    <0.0003153, -0.9999928, 0.0037768>,
    <0.0003153, -0.9999928, 0.0037768>,
    <0.0003004, -0.9999981, 0.0019498>,
    <0.0002642, -0.9999979, 0.0020286>,
    <0.0001522, -0.9999977, 0.0021282>,
    <-0.0001919, -0.9999731, 0.0073266>,
    <-0.0001143, -0.9999976, 0.0022072>,
    <-0.0002937, -0.9999977, 0.0021417>,
    <-0.0020821, -0.9994602, 0.0327876>,
    <-0.0020821, -0.9994602, 0.0327876>,
    <0.0005080, -0.9994483, 0.0332100>,
    <0.4878559, 0.0000243, -0.8729242>,
    <0.4878549, 0.0000243, -0.8729247>,
    <0.3675999, 0.0000181, -0.9299841>,
    <0.3676006, 0.0000181, -0.9299837>,
    <0.3676014, 0.0000181, -0.9299834>,
    <0.4878568, 0.0000243, -0.8729237>,
    <0.4878568, 0.0000243, -0.8729237>,
    <0.7631640, 0.0000384, -0.6462048>,
    <0.4878540, 0.0000243, -0.8729252>,
    <0.3675991, 0.0000181, -0.9299844>,
    <0.7631609, 0.0000384, -0.6462085>,
    <0.4878531, 0.0000243, -0.8729257>,
    <0.4878531, 0.0000243, -0.8729257>,
    <0.3675983, 0.0000181, -0.9299847>,
    <0.4280648, 0.0000209, -0.9037480>,
    <0.4280657, 0.0000209, -0.9037476>,
    <0.3675983, 0.0000181, -0.9299847>,
    <0.4280639, 0.0000209, -0.9037484>,
    <0.4280639, 0.0000209, -0.9037484>,
    <0.6790848, 0.0000329, -0.7340599>,
    <0.6790857, 0.0000329, -0.7340590>,
    <0.6790866, 0.0000329, -0.7340582>,
    <0.4280665, 0.0000209, -0.9037472>,
    <0.6790875, 0.0000329, -0.7340574>,
    <0.6790884, 0.0000329, -0.7340565>,
    <0.4280674, 0.0000209, -0.9037468>,
    <0.4280674, 0.0000209, -0.9037468>,
    <0.3676014, 0.0000181, -0.9299834>,
    <-0.0001605, 0.9999912, 0.0041835>,
    <0.0000373, 0.9999900, 0.0044632>,
    <-0.0001893, 0.9999751, 0.0070592>,
    <-0.0002044, 0.9999817, 0.0060433>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <0.0004994, 0.9999785, 0.0065314>,
    <-0.0001552, 0.9999344, 0.0114548>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0041270, 0.9992606, 0.0382247>,
    <0.0041270, 0.9992606, 0.0382247>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0007848, 0.9999631, 0.0085524>,
    <-0.0004049, 0.9999833, 0.0057588>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0006662, 0.9999964, 0.0025817>,
    <-0.0003625, 0.9999966, 0.0025763>,
    <-0.0002448, 0.9999871, 0.0050692>,
    <-0.0002322, 0.9999967, 0.0025453>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <0.0001552, -0.9999998, 0.0005685>,
    <0.0002210, -0.9999996, 0.0008105>,
    <0.0002669, -0.9999999, 0.0003406>,
    <0.0002531, -0.9999999, 0.0002361>,
    <0.0002504, -1.0000000, 0.0001045>,
    <0.0001454, -1.0000000, 0.0001045>,
    <0.0001454, -1.0000000, 0.0001045>,
    <-0.0002937, -0.9999977, 0.0021417>,
    <0.0002737, -0.9999996, 0.0008673>,
    <0.0002820, -0.9999999, 0.0003799>,
    <0.0003004, -0.9999981, 0.0019498>,
    <0.0002917, -0.9999996, 0.0008532>,
    <0.0002917, -0.9999996, 0.0008532>,
    <0.0002871, -0.9999999, 0.0003774>,
    <0.0002844, -0.9999999, 0.0001621>,
    <0.0002826, -0.9999999, 0.0001554>,
    <0.0002871, -0.9999999, 0.0003774>,
    <0.0002849, -0.9999999, 0.0001599>,
    <0.0002849, -0.9999999, 0.0001599>,
    <0.0002839, -1.0000000, 0.0000958>,
    <0.0002839, -1.0000000, 0.0000980>,
    <0.0002839, -1.0000000, 0.0000980>,
    <0.0002839, -1.0000000, 0.0001001>,
    <0.0002809, -1.0000000, 0.0001341>,
    <0.0002839, -1.0000000, 0.0001001>,
    <0.0002839, -1.0000000, 0.0001023>,
    <0.0002839, -1.0000000, 0.0001023>,
    <0.0002839, -1.0000000, 0.0001045>,
    <0.0002804, -1.0000000, 0.0001045>,
    <0.0002804, -1.0000000, 0.0001045>,
    <0.0002504, -1.0000000, 0.0001045>,
    <0.9047737, 0.0000436, -0.4258927>,
    <0.9047733, 0.0000436, -0.4258936>,
    <0.9790994, 0.0000470, -0.2033825>,
    <0.9790995, 0.0000470, -0.2033820>,
    <0.9790996, 0.0000470, -0.2033815>,
    <0.9047741, 0.0000436, -0.4258919>,
    <0.9047741, 0.0000436, -0.4258919>,
    <0.6790884, 0.0000329, -0.7340565>,
    <0.9047729, 0.0000436, -0.4258945>,
    <0.9790993, 0.0000470, -0.2033830>,
    <0.6790848, 0.0000329, -0.7340599>,
    <0.9047724, 0.0000436, -0.4258953>,
    <0.9047724, 0.0000436, -0.4258953>,
    <0.9790992, 0.0000470, -0.2033835>,
    <0.9961600, 0.0000477, -0.0875510>,
    <0.9961601, 0.0000477, -0.0875508>,
    <0.9790992, 0.0000470, -0.2033835>,
    <0.9961600, 0.0000477, -0.0875512>,
    <0.9961600, 0.0000477, -0.0875512>,
    <0.9986191, 0.0000478, -0.0525351>,
    <0.9986191, 0.0000478, -0.0525350>,
    <0.9986191, 0.0000478, -0.0525350>,
    <0.9986191, 0.0000478, -0.0525349>,
    <0.9961601, 0.0000477, -0.0875506>,
    <0.9986191, 0.0000478, -0.0525349>,
    <0.9986191, 0.0000478, -0.0525347>,
    <0.9986191, 0.0000478, -0.0525347>,
    <0.9986191, 0.0000478, -0.0525346>,
    <0.9961601, 0.0000477, -0.0875504>,
    <0.9961601, 0.0000477, -0.0875504>,
    <0.9790996, 0.0000470, -0.2033815>,
    <-0.0002053, 0.9999994, 0.0010841>,
    <-0.0002659, 0.9999995, 0.0009839>,
    <-0.0002050, 0.9999999, 0.0004143>,
    <-0.0001877, 0.9999999, 0.0004740>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0003403, 0.9999997, 0.0006738>,
    <-0.0002205, 0.9999999, 0.0002809>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001852, 1.0000000, 0.0001577>,
    <-0.0001833, 1.0000000, 0.0001881>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001801, 1.0000000, 0.0001183>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001813, 1.0000000, 0.0002019>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001230>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <-0.9869426, -0.0000675, -0.1610724>,
    <-0.9869426, -0.0000674, -0.1610724>,
    <-0.9869431, -0.0000674, -0.1610692>,
    <-0.9869431, -0.0000675, -0.1610692>,
    <-0.9869431, -0.0000675, -0.1610692>,
    <-0.9869426, -0.0000675, -0.1610724>,
    <-0.9869426, -0.0000675, -0.1610724>,
    <-0.9869421, -0.0000675, -0.1610756>,
    <-0.9869421, -0.0000675, -0.1610756>,
    <-0.9869421, -0.0000675, -0.1610756>,
    <-0.9869421, -0.0000674, -0.1610756>,
    <-0.9869426, -0.0000674, -0.1610724>,
    <-0.9869431, -0.0000674, -0.1610692>,
    <-0.9869421, -0.0000674, -0.1610756>,
    <-0.9869421, -0.0000674, -0.1610756>,
    <-0.9869421, -0.0000674, -0.1610756>,
    <-0.9869421, -0.0000673, -0.1610756>,
    <-0.9869426, -0.0000673, -0.1610724>,
    <-0.9869426, -0.0000673, -0.1610724>,
    <-0.9869431, -0.0000673, -0.1610692>,
    <-0.9869436, -0.0000674, -0.1610659>,
    <-0.9869436, -0.0000674, -0.1610659>,
    <-0.9869431, -0.0000673, -0.1610692>,
    <-0.9869436, -0.0000673, -0.1610659>,
    <-0.9869436, -0.0000673, -0.1610659>,
    <-0.9869442, -0.0000673, -0.1610627>,
    <-0.9869442, -0.0000674, -0.1610627>,
    <-0.9869442, -0.0000674, -0.1610627>,
    <-0.9869442, -0.0000674, -0.1610627>,
    <-0.9869436, -0.0000675, -0.1610659>,
    <-0.9869442, -0.0000674, -0.1610627>,
    <-0.9869442, -0.0000675, -0.1610627>,
    <-0.9869442, -0.0000675, -0.1610627>,
    <-0.9869442, -0.0000675, -0.1610627>,
    <-0.9869436, -0.0000675, -0.1610659>,
    <-0.9869436, -0.0000675, -0.1610659>,
    <-0.9869431, -0.0000675, -0.1610692>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <0.9999404, 0.0001137, 0.0109141>,
    <0.9999447, 0.0000685, 0.0105163>,
    <0.9999338, 0.0000685, 0.0115037>,
    <0.9999321, 0.0000798, 0.0116512>,
    <0.9999286, 0.0000828, 0.0119507>,
    <0.9999286, 0.0001238, 0.0119506>,
    <0.9999286, 0.0001238, 0.0119506>,
    <0.9999725, 0.0002780, 0.0074076>,
    <0.9999725, 0.0001995, 0.0074077>,
    <0.9999726, 0.0000685, 0.0074076>,
    <0.9999404, 0.0000234, 0.0109136>,
    <0.9999321, 0.0000572, 0.0116506>,
    <0.9999726, -0.0000624, 0.0074074>,
    <0.9999726, -0.0001409, 0.0074070>,
    <0.9999286, 0.0000132, 0.0119496>,
    <0.9999286, 0.0000132, 0.0119496>,
    <0.9999286, 0.0000542, 0.0119498>,
    <0.9999294, 0.0000671, 0.0118782>,
    <0.9999298, 0.0000685, 0.0118451>,
    <0.9999286, 0.0000542, 0.0119498>,
    <0.9999286, 0.0000667, 0.0119498>,
    <0.9999286, 0.0000667, 0.0119498>,
    <0.9999286, 0.0000685, 0.0119498>,
    <0.9999286, 0.0000685, 0.0119500>,
    <0.9999286, 0.0000685, 0.0119500>,
    <0.9999286, 0.0000685, 0.0119503>,
    <0.9999294, 0.0000698, 0.0118787>,
    <0.9999286, 0.0000685, 0.0119503>,
    <0.9999286, 0.0000685, 0.0119505>,
    <0.9999286, 0.0000685, 0.0119505>,
    <0.9999286, 0.0000685, 0.0119508>,
    <0.9999286, 0.0000703, 0.0119508>,
    <0.9999286, 0.0000703, 0.0119508>,
    <0.9999286, 0.0000828, 0.0119507>,
    <0.9999905, 0.0002200, -0.0043628>,
    <0.9997833, 0.0001436, -0.0208159>,
    <0.9998819, 0.0000685, -0.0153711>,
    <0.9999997, 0.0000685, -0.0008270>,
    <0.9999725, 0.0002780, 0.0074076>,
    <0.9990830, 0.0006798, -0.0428094>,
    <0.9990830, 0.0006798, -0.0428094>,
    <0.9990831, 0.0002263, -0.0428133>,
    <0.9993788, 0.0000814, -0.0352415>,
    <0.9994752, 0.0000685, -0.0323937>,
    <0.9990831, 0.0002263, -0.0428133>,
    <0.9990830, 0.0000882, -0.0428145>,
    <0.9990830, 0.0000882, -0.0428145>,
    <0.9990830, 0.0000685, -0.0428147>,
    <0.9990831, 0.0000685, -0.0428138>,
    <0.9990831, 0.0000685, -0.0428138>,
    <0.9990831, 0.0000685, -0.0428129>,
    <0.9993789, 0.0000555, -0.0352399>,
    <0.9997834, -0.0000066, -0.0208147>,
    <0.9990831, 0.0000685, -0.0428129>,
    <0.9990831, 0.0000685, -0.0428121>,
    <0.9990831, 0.0000685, -0.0428121>,
    <0.9990832, 0.0000685, -0.0428112>,
    <0.9990832, 0.0000487, -0.0428110>,
    <0.9990832, 0.0000487, -0.0428110>,
    <0.9990832, -0.0000893, -0.0428096>,
    <0.9999905, -0.0000830, -0.0043624>,
    <0.9990832, -0.0000893, -0.0428096>,
    <0.9990833, -0.0005429, -0.0428051>,
    <0.9990833, -0.0005429, -0.0428051>,
    <0.9999726, -0.0001409, 0.0074070>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4349582, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4349582, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4263414, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559367, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773948, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032658, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458854>,
    <0.4677608, 0.9456845>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4355157, 0.9458854>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9451388>,
    <0.4677604, 0.9518685>,
    <0.4676209, 0.9588001>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.4677604, 0.9518685>,
    <0.5000059, 0.9579003>,
    <0.4674769, 0.9657316>,
    <0.4352664, 0.9584513>,
    <0.4031264, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4349582, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352664, 0.9584513>,
    <0.4022562, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032658, 0.9526160>,
    <0.5322510, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9518685>,
    <0.5000059, 0.9451388>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458642>,
    <0.5967410, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5644961, 0.9458642>,
    <0.5967380, 0.9395004>,
    <0.6289858, 0.9451388>,
    <0.5967440, 0.9518685>,
    <0.5967474, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967440, 0.9518685>,
    <0.6289941, 0.9579003>,
    <0.5967509, 0.9657316>,
    <0.5645003, 0.9587016>,
    <0.5322532, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.5645003, 0.9587016>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9579003>,
    <0.5322521, 0.9518685>,
    <0.6423395, 0.9456845>,
    <0.6556982, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423437, 0.9518685>,
    <0.6289858, 0.9451388>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458854>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458854>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691147, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694793, 0.9657316>,
    <0.6558043, 0.9584513>,
    <0.6424060, 0.9588001>,
    <0.6556982, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.6558043, 0.9584513>,
    <0.6424701, 0.9657316>,
    <0.6289941, 0.9579003>,
    <0.6423437, 0.9518685>,
    <0.3997689, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4022562, 0.9657316>,
    <0.4331396, 0.9660561>,
    <0.4665018, 0.9660805>,
    <0.4310370, 0.9664312>,
    <0.4349582, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4331396, 0.9660561>,
    <0.4674769, 0.9657316>,
    <0.5000060, 0.9660883>,
    <0.4655215, 0.9664293>,
    <0.4643476, 0.9667801>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000061, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.4655215, 0.9664293>,
    <0.5000060, 0.9667645>,
    <0.4631665, 0.9671308>,
    <0.4286164, 0.9667919>,
    <0.3931424, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4263414, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4286164, 0.9667919>,
    <0.3894539, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664293>,
    <0.5000060, 0.9660883>,
    <0.5322542, 0.9657316>,
    <0.5667950, 0.9660902>,
    <0.6000933, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5667950, 0.9660902>,
    <0.5967509, 0.9657316>,
    <0.6335597, 0.9660883>,
    <0.6034357, 0.9664293>,
    <0.6068019, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034357, 0.9664293>,
    <0.6422052, 0.9667645>,
    <0.6101681, 0.9671308>,
    <0.5711180, 0.9667664>,
    <0.5356086, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.5711180, 0.9667664>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667645>,
    <0.5344905, 0.9664293>,
    <0.6473345, 0.9660805>,
    <0.6665054, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6289992, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6522009, 0.9664293>,
    <0.6335597, 0.9660883>,
    <0.6424701, 0.9657316>,
    <0.6608384, 0.9660561>,
    <0.6749817, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559367, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6608384, 0.9660561>,
    <0.6694793, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866708, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926707, 0.9671308>,
    <0.6721189, 0.9667919>,
    <0.6571714, 0.9667801>,
    <0.6665054, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.6721189, 0.9667919>,
    <0.6621448, 0.9671308>,
    <0.6422052, 0.9667645>,
    <0.6522009, 0.9664293>,
    <0.3896277, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.3895219, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3894539, 0.9671308>,
    <0.4263465, 0.9729776>,
    <0.4631761, 0.9726967>,
    <0.4263507, 0.9777601>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4263465, 0.9729776>,
    <0.4631665, 0.9671308>,
    <0.5000061, 0.9732089>,
    <0.4631777, 0.9782626>,
    <0.4631249, 0.9833260>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631777, 0.9782626>,
    <0.5000061, 0.9837065>,
    <0.4630714, 0.9883895>,
    <0.4262410, 0.9832100>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262410, 0.9832100>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895219, 0.9777601>,
    <0.5367803, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9782626>,
    <0.5000061, 0.9732089>,
    <0.5367268, 0.9671308>,
    <0.5735592, 0.9726839>,
    <0.6103387, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5735592, 0.9726839>,
    <0.6101681, 0.9671308>,
    <0.6471335, 0.9732089>,
    <0.6105094, 0.9782626>,
    <0.6106597, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105094, 0.9782626>,
    <0.6475562, 0.9837065>,
    <0.6108101, 0.9883895>,
    <0.5737713, 0.9832176>,
    <0.5368873, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.5737713, 0.9832176>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9837065>,
    <0.5368338, 0.9782626>,
    <0.6623650, 0.9726967>,
    <0.6778190, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6468888, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6625884, 0.9782625>,
    <0.6471335, 0.9732089>,
    <0.6621448, 0.9671308>,
    <0.6776281, 0.9729776>,
    <0.6928127, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773948, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776281, 0.9729776>,
    <0.6926707, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930705, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930705, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780838, 0.9832100>,
    <0.6628141, 0.9833260>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.6780838, 0.9832100>,
    <0.6630402, 0.9883895>,
    <0.6475562, 0.9837065>,
    <0.6625884, 0.9782625>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.011335, -0.36281, -0.147353>
}

#declare TMesh005 = mesh2 {
  vertex_vectors {
    582,
    <2.1725850, 0.1125493, 18.5417983>,
    <2.0021506, 0.1125124, 18.5417983>,
    <2.0021672, -0.1349001, 18.5417983>,
    <2.1725990, -0.1348554, 18.5417983>,
    <2.0873678, 0.1125308, 18.5417983>,
    <2.0021589, -0.0111938, 18.5417983>,
    <2.0873831, -0.1348777, 18.5417983>,
    <2.1725920, -0.0111531, 18.5417983>,
    <2.0873754, -0.0111734, 18.5417983>,
    <2.3430309, -0.1348108, 18.5417983>,
    <2.3430194, 0.1125862, 18.5417983>,
    <2.2578150, -0.1348331, 18.5417983>,
    <2.3430251, -0.0111123, 18.5417983>,
    <2.2578022, 0.1125678, 18.5417983>,
    <2.2578086, -0.0111327, 18.5417983>,
    <2.3430079, 0.3599832, 18.5417983>,
    <2.1725710, 0.3599540, 18.5417983>,
    <2.3430137, 0.2362847, 18.5417983>,
    <2.2577895, 0.3599686, 18.5417983>,
    <2.1725780, 0.2362517, 18.5417983>,
    <2.2577958, 0.2362682, 18.5417983>,
    <2.0021340, 0.3599249, 18.5417983>,
    <2.0873525, 0.3599394, 18.5417983>,
    <2.0021423, 0.2362186, 18.5417983>,
    <2.0873601, 0.2362351, 18.5417983>,
    <2.0592721, -0.1353143, 18.1202395>,
    <2.0044034, -0.1353455, 18.1202395>,
    <2.0044687, -0.1353585, 18.1217627>,
    <2.0559641, -0.1353277, 18.1217627>,
    <2.0318378, -0.1353299, 18.1202395>,
    <2.0044361, -0.1353520, 18.1210011>,
    <2.0302164, -0.1353431, 18.1217627>,
    <2.0576181, -0.1353210, 18.1210011>,
    <2.0310271, -0.1353365, 18.1210011>,
    <2.1074595, -0.1352969, 18.1217627>,
    <2.1141408, -0.1352831, 18.1202395>,
    <2.0817118, -0.1353123, 18.1217627>,
    <2.1108002, -0.1352900, 18.1210011>,
    <2.0867065, -0.1352987, 18.1202395>,
    <2.0842091, -0.1353055, 18.1210011>,
    <2.1208221, -0.1352693, 18.1187163>,
    <2.0625801, -0.1353009, 18.1187163>,
    <2.1174814, -0.1352762, 18.1194779>,
    <2.0917011, -0.1352851, 18.1187163>,
    <2.0609261, -0.1353076, 18.1194779>,
    <2.0892038, -0.1352919, 18.1194779>,
    <2.0043382, -0.1353325, 18.1187163>,
    <2.0334591, -0.1353167, 18.1187163>,
    <2.0043708, -0.1353390, 18.1194779>,
    <2.0326485, -0.1353233, 18.1194779>,
    <2.1141282, 0.1125970, 18.1202395>,
    <2.1074469, 0.1125974, 18.1217627>,
    <2.1141345, -0.0113430, 18.1202395>,
    <2.1074532, -0.0113498, 18.1217627>,
    <2.1107875, 0.1125972, 18.1210011>,
    <2.1107938, -0.0113464, 18.1210011>,
    <2.1074342, 0.3604916, 18.1217627>,
    <2.1141156, 0.3604772, 18.1202395>,
    <2.1074405, 0.2365445, 18.1217627>,
    <2.1107749, 0.3604844, 18.1210011>,
    <2.1141219, 0.2365371, 18.1202395>,
    <2.1107812, 0.2365408, 18.1210011>,
    <2.1207969, 0.3604627, 18.1187163>,
    <2.1208095, 0.1125967, 18.1187163>,
    <2.1174562, 0.3604700, 18.1194779>,
    <2.1208032, 0.2365297, 18.1187163>,
    <2.1174688, 0.1125969, 18.1194779>,
    <2.1174625, 0.2365334, 18.1194779>,
    <2.1208158, -0.0113363, 18.1187163>,
    <2.1174751, -0.0113397, 18.1194779>,
    <2.0592428, 0.3604585, 18.1202395>,
    <2.0559348, 0.3604732, 18.1217627>,
    <2.0866792, 0.3604678, 18.1202395>,
    <2.0816845, 0.3604824, 18.1217627>,
    <2.0575888, 0.3604658, 18.1210011>,
    <2.0841818, 0.3604751, 18.1210011>,
    <2.0044353, 0.3604548, 18.1217627>,
    <2.0043701, 0.3604398, 18.1202395>,
    <2.0301850, 0.3604640, 18.1217627>,
    <2.0044027, 0.3604473, 18.1210011>,
    <2.0318064, 0.3604491, 18.1202395>,
    <2.0309957, 0.3604566, 18.1210011>,
    <2.0043048, 0.3604247, 18.1187163>,
    <2.0625508, 0.3604437, 18.1187163>,
    <2.0043374, 0.3604323, 18.1194779>,
    <2.0334278, 0.3604342, 18.1187163>,
    <2.0608968, 0.3604511, 18.1194779>,
    <2.0326171, 0.3604417, 18.1194779>,
    <2.0916739, 0.3604532, 18.1187163>,
    <2.0891765, 0.3604605, 18.1194779>,
    <2.0694781, -0.1352729, 18.1370901>,
    <2.0042020, -0.1353053, 18.1370901>,
    <2.0368401, -0.1352891, 18.1370901>,
    <2.0042701, -0.1353189, 18.1279032>,
    <2.0660291, -0.1352869, 18.1279032>,
    <2.0351496, -0.1353029, 18.1279032>,
    <2.1347541, -0.1352406, 18.1370901>,
    <2.1277881, -0.1352549, 18.1279032>,
    <2.1021161, -0.1352568, 18.1370901>,
    <2.0969086, -0.1352709, 18.1279032>,
    <2.1486861, -0.1352118, 18.1554639>,
    <2.0763760, -0.1352450, 18.1554639>,
    <2.1417201, -0.1352262, 18.1462770>,
    <2.1125311, -0.1352284, 18.1554639>,
    <2.0729270, -0.1352590, 18.1462770>,
    <2.1073236, -0.1352426, 18.1462770>,
    <2.0040659, -0.1352782, 18.1554639>,
    <2.0402210, -0.1352616, 18.1554639>,
    <2.0041340, -0.1352918, 18.1462770>,
    <2.0385305, -0.1352754, 18.1462770>,
    <2.1347416, 0.1125961, 18.1370901>,
    <2.1347478, -0.0113222, 18.1370901>,
    <2.1277755, 0.1125964, 18.1279032>,
    <2.1277818, -0.0113293, 18.1279032>,
    <2.1347291, 0.3604327, 18.1370901>,
    <2.1277630, 0.3604477, 18.1279032>,
    <2.1347353, 0.2365144, 18.1370901>,
    <2.1277693, 0.2365221, 18.1279032>,
    <2.1486612, 0.3604026, 18.1554639>,
    <2.1486737, 0.1125954, 18.1554639>,
    <2.1416951, 0.3604176, 18.1462770>,
    <2.1486675, 0.2364990, 18.1554639>,
    <2.1417076, 0.1125957, 18.1462770>,
    <2.1417014, 0.2365067, 18.1462770>,
    <2.1486799, -0.0113082, 18.1554639>,
    <2.1417139, -0.0113152, 18.1462770>,
    <2.0694489, 0.3604130, 18.1370901>,
    <2.1020890, 0.3604229, 18.1370901>,
    <2.0659999, 0.3604284, 18.1279032>,
    <2.0968814, 0.3604381, 18.1279032>,
    <2.0041687, 0.3603934, 18.1370901>,
    <2.0042367, 0.3604091, 18.1279032>,
    <2.0368088, 0.3604032, 18.1370901>,
    <2.0351183, 0.3604187, 18.1279032>,
    <2.0040326, 0.3603621, 18.1554639>,
    <2.0763469, 0.3603823, 18.1554639>,
    <2.0041006, 0.3603777, 18.1462770>,
    <2.0401897, 0.3603722, 18.1554639>,
    <2.0728979, 0.3603977, 18.1462770>,
    <2.0384993, 0.3603877, 18.1462770>,
    <2.1125041, 0.3603925, 18.1554639>,
    <2.1072965, 0.3604077, 18.1462770>,
    <2.0812641, -0.1352252, 18.1573801>,
    <2.0039695, -0.1352590, 18.1573801>,
    <2.0426168, -0.1352421, 18.1573801>,
    <2.0040177, -0.1352686, 18.1564220>,
    <2.0788201, -0.1352351, 18.1564220>,
    <2.0414189, -0.1352519, 18.1564220>,
    <2.1585588, -0.1351914, 18.1573801>,
    <2.1536225, -0.1352016, 18.1564220>,
    <2.1199115, -0.1352083, 18.1573801>,
    <2.1162213, -0.1352184, 18.1564220>,
    <2.1684314, -0.1351711, 18.1592964>,
    <2.0861522, -0.1352054, 18.1592964>,
    <2.1634951, -0.1351812, 18.1583383>,
    <2.1272918, -0.1351882, 18.1592964>,
    <2.0837082, -0.1352153, 18.1583383>,
    <2.1236016, -0.1351983, 18.1583383>,
    <2.0038730, -0.1352398, 18.1592964>,
    <2.0450126, -0.1352226, 18.1592964>,
    <2.0039212, -0.1352494, 18.1583383>,
    <2.0438147, -0.1352324, 18.1583383>,
    <2.1585464, 0.1125949, 18.1573801>,
    <2.1585526, -0.0112982, 18.1573801>,
    <2.1536100, 0.1125952, 18.1564220>,
    <2.1536162, -0.0113032, 18.1564220>,
    <2.1585340, 0.3603813, 18.1573801>,
    <2.1535976, 0.3603920, 18.1564220>,
    <2.1585402, 0.2364881, 18.1573801>,
    <2.1536038, 0.2364936, 18.1564220>,
    <2.1684068, 0.3603600, 18.1592964>,
    <2.1684191, 0.1125945, 18.1592964>,
    <2.1634704, 0.3603706, 18.1583383>,
    <2.1684129, 0.2364772, 18.1592964>,
    <2.1634827, 0.1125947, 18.1583383>,
    <2.1634766, 0.2364827, 18.1583383>,
    <2.1684253, -0.0112883, 18.1592964>,
    <2.1634889, -0.0112933, 18.1583383>,
    <2.0812351, 0.3603606, 18.1573801>,
    <2.1198845, 0.3603709, 18.1573801>,
    <2.0787910, 0.3603715, 18.1564220>,
    <2.1161943, 0.3603817, 18.1564220>,
    <2.0039361, 0.3603399, 18.1573801>,
    <2.0039844, 0.3603510, 18.1564220>,
    <2.0425856, 0.3603502, 18.1573801>,
    <2.0413877, 0.3603612, 18.1564220>,
    <2.0038397, 0.3603176, 18.1592964>,
    <2.0861232, 0.3603388, 18.1592964>,
    <2.0038879, 0.3603287, 18.1583383>,
    <2.0449814, 0.3603282, 18.1592964>,
    <2.0836791, 0.3603497, 18.1583383>,
    <2.0437835, 0.3603392, 18.1583383>,
    <2.1272650, 0.3603494, 18.1592964>,
    <2.1235748, 0.3603602, 18.1583383>,
    <2.0872214, -0.1352016, 18.2324892>,
    <2.0038724, -0.1352397, 18.2344341>,
    <2.0455456, -0.1352204, 18.2333227>,
    <2.0038727, -0.1352398, 18.1968653>,
    <2.0861681, -0.1352054, 18.1968653>,
    <2.0450204, -0.1352226, 18.1968653>,
    <2.1705857, -0.1351666, 18.2322113>,
    <2.1684634, -0.1351710, 18.1968653>,
    <2.1289022, -0.1351839, 18.2322113>,
    <2.1273157, -0.1351882, 18.1968653>,
    <2.1894619, -0.1351277, 18.2873438>,
    <2.0965801, -0.1351663, 18.2890109>,
    <2.1768884, -0.1351536, 18.2631118>,
    <2.1430133, -0.1351455, 18.2873438>,
    <2.0903496, -0.1351905, 18.2642232>,
    <2.1336139, -0.1351710, 18.2631118>,
    <2.0038718, -0.1352396, 18.3095719>,
    <2.0501774, -0.1351933, 18.2940122>,
    <2.0038721, -0.1352396, 18.2720030>,
    <2.0471057, -0.1352141, 18.2675574>,
    <2.1705733, 0.1125944, 18.2322113>,
    <2.1705795, -0.0112861, 18.2322113>,
    <2.1684511, 0.1125945, 18.1968653>,
    <2.1684573, -0.0112883, 18.1968653>,
    <2.1705610, 0.3603553, 18.2322113>,
    <2.1684387, 0.3603599, 18.1968653>,
    <2.1705672, 0.2364749, 18.2322113>,
    <2.1684449, 0.2364772, 18.1968653>,
    <2.1894375, 0.3603146, 18.2873438>,
    <2.1894497, 0.1125935, 18.2873438>,
    <2.1768638, 0.3603417, 18.2631118>,
    <2.1894436, 0.2364540, 18.2873438>,
    <2.1768761, 0.1125941, 18.2631118>,
    <2.1768700, 0.2364679, 18.2631118>,
    <2.1894558, -0.0112671, 18.2873438>,
    <2.1768823, -0.0112798, 18.2631118>,
    <2.0871924, 0.3603347, 18.2324892>,
    <2.1288754, 0.3603447, 18.2322113>,
    <2.0861391, 0.3603387, 18.1968653>,
    <2.1272889, 0.3603493, 18.1968653>,
    <2.0038391, 0.3603175, 18.2344341>,
    <2.0038394, 0.3603176, 18.1968653>,
    <2.0455144, 0.3603258, 18.2333227>,
    <2.0449892, 0.3603282, 18.1968653>,
    <2.0038384, 0.3603174, 18.3095719>,
    <2.0965512, 0.3602960, 18.2890109>,
    <2.0038387, 0.3603174, 18.2720030>,
    <2.0501463, 0.3602955, 18.2940122>,
    <2.0903206, 0.3603225, 18.2642232>,
    <2.0470746, 0.3603188, 18.2675574>,
    <2.1429867, 0.3603035, 18.2873438>,
    <2.1335871, 0.3603310, 18.2631118>,
    <2.1194133, -0.1350708, 18.3131904>,
    <2.0032176, -0.1351093, 18.3135798>,
    <2.0613154, -0.1350900, 18.3133573>,
    <2.0035447, -0.1351744, 18.3115759>,
    <2.1069400, -0.1351233, 18.3037960>,
    <2.0552372, -0.1351479, 18.3071303>,
    <2.2356097, -0.1350324, 18.3131347>,
    <2.2103965, -0.1350845, 18.3026846>,
    <2.1775114, -0.1350516, 18.3131347>,
    <2.1586631, -0.1351029, 18.3026846>,
    <2.2825423, -0.1349356, 18.3353648>,
    <2.1426356, -0.1349738, 18.3340315>,
    <2.2610191, -0.1349800, 18.3226946>,
    <2.2125963, -0.1349561, 18.3353648>,
    <2.1319840, -0.1350179, 18.3218058>,
    <2.1965064, -0.1349999, 18.3226946>,
    <2.0025635, -0.1349790, 18.3175878>,
    <2.0726458, -0.1349856, 18.3300317>,
    <2.0028906, -0.1350441, 18.3155838>,
    <2.0674422, -0.1350320, 18.3191392>,
    <2.2355977, 0.1125913, 18.3131347>,
    <2.2356037, -0.0112206, 18.3131347>,
    <2.2103844, 0.1125925, 18.3026846>,
    <2.2103904, -0.0112460, 18.3026846>,
    <2.2355857, 0.3602150, 18.3131347>,
    <2.2103722, 0.3602694, 18.3026846>,
    <2.2355917, 0.2364031, 18.3131347>,
    <2.2103783, 0.2364310, 18.3026846>,
    <2.2825188, 0.3601137, 18.3353648>,
    <2.2825305, 0.1125891, 18.3353648>,
    <2.2609953, 0.3601602, 18.3226946>,
    <2.2825246, 0.2363514, 18.3353648>,
    <2.2610072, 0.1125901, 18.3226946>,
    <2.2610013, 0.2363751, 18.3226946>,
    <2.2825364, -0.0111733, 18.3353648>,
    <2.2610131, -0.0111950, 18.3226946>,
    <2.1193847, 0.3601908, 18.3131904>,
    <2.1774851, 0.3602029, 18.3131347>,
    <2.1069112, 0.3602487, 18.3037960>,
    <2.1586366, 0.3602579, 18.3026846>,
    <2.0031844, 0.3601667, 18.3135798>,
    <2.0035114, 0.3602420, 18.3115759>,
    <2.0612845, 0.3601788, 18.3133573>,
    <2.0552062, 0.3602442, 18.3071303>,
    <2.0025303, 0.3600161, 18.3175878>,
    <2.1426072, 0.3600840, 18.3340315>,
    <2.0028573, 0.3600914, 18.3155838>,
    <2.0726150, 0.3600607, 18.3300317>,
    <2.1319555, 0.3601325, 18.3218058>,
    <2.0674113, 0.3601131, 18.3191392>,
    <2.2125703, 0.3601005, 18.3353648>,
    <2.1964803, 0.3601475, 18.3226946>,
    <2.1531110, -0.1349338, 18.3800376>,
    <2.0025322, -0.1349728, 18.3784821>,
    <2.0778228, -0.1349535, 18.3793709>,
    <2.0025479, -0.1349759, 18.3480349>,
    <2.1493516, -0.1349476, 18.3542569>,
    <2.0759546, -0.1349627, 18.3515903>,
    <2.3036751, -0.1348920, 18.3802598>,
    <2.2960969, -0.1349076, 18.3551457>,
    <2.2283943, -0.1349131, 18.3802598>,
    <2.2227291, -0.1349286, 18.3551457>,
    <2.3088707, -0.1348812, 18.4393764>,
    <2.1556858, -0.1349239, 18.4393764>,
    <2.3072690, -0.1348846, 18.4089292>,
    <2.2322783, -0.1349026, 18.4393764>,
    <2.1548928, -0.1349271, 18.4089292>,
    <2.2310809, -0.1349058, 18.4089292>,
    <2.0025009, -0.1349665, 18.4393764>,
    <2.0790934, -0.1349452, 18.4393764>,
    <2.0025166, -0.1349697, 18.4089292>,
    <2.0787047, -0.1349484, 18.4089292>,
    <2.3036635, 0.1125881, 18.3802598>,
    <2.3036693, -0.0111520, 18.3802598>,
    <2.2960852, 0.1125884, 18.3551457>,
    <2.2960911, -0.0111596, 18.3551457>,
    <2.3036518, 0.3600681, 18.3802598>,
    <2.2960735, 0.3600845, 18.3551457>,
    <2.3036576, 0.2363281, 18.3802598>,
    <2.2960794, 0.2363364, 18.3551457>,
    <2.3088475, 0.3600569, 18.4393764>,
    <2.3088591, 0.1125878, 18.4393764>,
    <2.3072457, 0.3600603, 18.4089292>,
    <2.3088533, 0.2363224, 18.4393764>,
    <2.3072574, 0.1125879, 18.4089292>,
    <2.3072515, 0.2363241, 18.4089292>,
    <2.3088649, -0.0111467, 18.4393764>,
    <2.3072632, -0.0111483, 18.4089292>,
    <2.1530827, 0.3600402, 18.3800376>,
    <2.2283685, 0.3600544, 18.3802598>,
    <2.1493233, 0.3600552, 18.3542569>,
    <2.2227033, 0.3600710, 18.3551457>,
    <2.0024990, 0.3600089, 18.3784821>,
    <2.0025147, 0.3600125, 18.3480349>,
    <2.0777921, 0.3600248, 18.3793709>,
    <2.0759238, 0.3600350, 18.3515903>,
    <2.0024677, 0.3600017, 18.4393764>,
    <2.1556576, 0.3600293, 18.4393764>,
    <2.0024834, 0.3600053, 18.4089292>,
    <2.0790627, 0.3600155, 18.4393764>,
    <2.1548645, 0.3600328, 18.4089292>,
    <2.0786740, 0.3600191, 18.4089292>,
    <2.2322525, 0.3600431, 18.4393764>,
    <2.2310551, 0.3600466, 18.4089292>,
    <2.1641424, -0.1348897, 18.4393764>,
    <2.0023340, -0.1349333, 18.4393764>,
    <2.0832382, -0.1349115, 18.4393764>,
    <2.0024175, -0.1349499, 18.4393764>,
    <2.1599141, -0.1349068, 18.4393764>,
    <2.0811658, -0.1349283, 18.4393764>,
    <2.3259508, -0.1348460, 18.4393764>,
    <2.3174108, -0.1348636, 18.4393764>,
    <2.2450466, -0.1348678, 18.4393764>,
    <2.2386625, -0.1348852, 18.4393764>,
    <2.3430309, -0.1348108, 18.4393764>,
    <2.1725990, -0.1348554, 18.4393764>,
    <2.3344909, -0.1348284, 18.4393764>,
    <2.2578150, -0.1348331, 18.4393764>,
    <2.1683707, -0.1348725, 18.4393764>,
    <2.2514308, -0.1348505, 18.4393764>,
    <2.0021672, -0.1349001, 18.4393764>,
    <2.0873831, -0.1348777, 18.4393764>,
    <2.0022506, -0.1349167, 18.4393764>,
    <2.0853107, -0.1348946, 18.4393764>,
    <2.3259393, 0.1125870, 18.4393764>,
    <2.3259450, -0.0111295, 18.4393764>,
    <2.3173992, 0.1125874, 18.4393764>,
    <2.3174050, -0.0111381, 18.4393764>,
    <2.3259277, 0.3600200, 18.4393764>,
    <2.3173876, 0.3600385, 18.4393764>,
    <2.3259335, 0.2363035, 18.4393764>,
    <2.3173934, 0.2363129, 18.4393764>,
    <2.3430079, 0.3599832, 18.4393764>,
    <2.3430194, 0.1125862, 18.4393764>,
    <2.3344678, 0.3600016, 18.4393764>,
    <2.3430137, 0.2362847, 18.4393764>,
    <2.3344793, 0.1125866, 18.4393764>,
    <2.3344736, 0.2362941, 18.4393764>,
    <2.3430251, -0.0111123, 18.4393764>,
    <2.3344851, -0.0111209, 18.4393764>,
    <2.1641143, 0.3599917, 18.4393764>,
    <2.2450210, 0.3600058, 18.4393764>,
    <2.1598859, 0.3600105, 18.4393764>,
    <2.2386368, 0.3600245, 18.4393764>,
    <2.0023009, 0.3599633, 18.4393764>,
    <2.0023843, 0.3599825, 18.4393764>,
    <2.0832076, 0.3599775, 18.4393764>,
    <2.0811351, 0.3599965, 18.4393764>,
    <2.0021340, 0.3599249, 18.4393764>,
    <2.1725710, 0.3599540, 18.4393764>,
    <2.0022174, 0.3599441, 18.4393764>,
    <2.0873525, 0.3599394, 18.4393764>,
    <2.1683426, 0.3599728, 18.4393764>,
    <2.0852800, 0.3599585, 18.4393764>,
    <2.2577895, 0.3599686, 18.4393764>,
    <2.2514052, 0.3599872, 18.4393764>,
    <2.1725990, -0.1348554, 18.4905874>,
    <2.0021672, -0.1349001, 18.4905874>,
    <2.0873831, -0.1348777, 18.4905874>,
    <2.0021672, -0.1349001, 18.4649819>,
    <2.1725990, -0.1348554, 18.4649819>,
    <2.0873831, -0.1348777, 18.4649819>,
    <2.3430309, -0.1348108, 18.4905874>,
    <2.3430309, -0.1348108, 18.4649819>,
    <2.2578150, -0.1348331, 18.4905874>,
    <2.2578150, -0.1348331, 18.4649819>,
    <2.3430309, -0.1348108, 18.5161929>,
    <2.1725990, -0.1348554, 18.5161929>,
    <2.2578150, -0.1348331, 18.5161929>,
    <2.0021672, -0.1349001, 18.5161929>,
    <2.0873831, -0.1348777, 18.5161929>,
    <2.3430194, 0.1125862, 18.4905874>,
    <2.3430251, -0.0111123, 18.4905874>,
    <2.3430194, 0.1125862, 18.4649819>,
    <2.3430251, -0.0111123, 18.4649819>,
    <2.3430079, 0.3599832, 18.4905874>,
    <2.3430079, 0.3599832, 18.4649819>,
    <2.3430137, 0.2362847, 18.4905874>,
    <2.3430137, 0.2362847, 18.4649819>,
    <2.3430079, 0.3599832, 18.5161929>,
    <2.3430194, 0.1125862, 18.5161929>,
    <2.3430137, 0.2362847, 18.5161929>,
    <2.3430251, -0.0111123, 18.5161929>,
    <2.1725710, 0.3599540, 18.4905874>,
    <2.2577895, 0.3599686, 18.4905874>,
    <2.1725710, 0.3599540, 18.4649819>,
    <2.2577895, 0.3599686, 18.4649819>,
    <2.0021340, 0.3599249, 18.4905874>,
    <2.0021340, 0.3599249, 18.4649819>,
    <2.0873525, 0.3599394, 18.4905874>,
    <2.0873525, 0.3599394, 18.4649819>,
    <2.0021340, 0.3599249, 18.5161929>,
    <2.1725710, 0.3599540, 18.5161929>,
    <2.0873525, 0.3599394, 18.5161929>,
    <2.2577895, 0.3599686, 18.5161929>,
    <2.0021506, 0.1125124, 18.4905874>,
    <2.0021672, -0.1349001, 18.4905874>,
    <2.0021506, 0.1125124, 18.4393764>,
    <2.0021589, -0.0111938, 18.4905874>,
    <2.0021672, -0.1349001, 18.4649819>,
    <2.0021589, -0.0111938, 18.4393764>,
    <2.0021506, 0.1125124, 18.4649819>,
    <2.0021589, -0.0111938, 18.4649819>,
    <2.0021340, 0.3599249, 18.4905874>,
    <2.0021423, 0.2362186, 18.4393764>,
    <2.0021340, 0.3599249, 18.4649819>,
    <2.0021423, 0.2362186, 18.4905874>,
    <2.0021423, 0.2362186, 18.4649819>,
    <2.0021506, 0.1125124, 18.5417983>,
    <2.0021340, 0.3599249, 18.5161929>,
    <2.0021423, 0.2362186, 18.5417983>,
    <2.0021506, 0.1125124, 18.5161929>,
    <2.0021423, 0.2362186, 18.5161929>,
    <2.0021589, -0.0111938, 18.5417983>,
    <2.0021672, -0.1349001, 18.5161929>,
    <2.0021589, -0.0111938, 18.5161929>,
    <2.0023174, 0.1125150, 18.4393764>,
    <2.0024843, 0.1125176, 18.4393764>,
    <2.0024009, 0.1125163, 18.4393764>,
    <2.0024926, -0.0112245, 18.4393764>,
    <2.0023257, -0.0112092, 18.4393764>,
    <2.0024092, -0.0112168, 18.4393764>,
    <2.0021506, 0.1125124, 18.4393764>,
    <2.0021589, -0.0111938, 18.4393764>,
    <2.0022340, 0.1125137, 18.4393764>,
    <2.0022423, -0.0112015, 18.4393764>,
    <2.0021423, 0.2362186, 18.4393764>,
    <2.0023092, 0.2362391, 18.4393764>,
    <2.0022257, 0.2362289, 18.4393764>,
    <2.0024760, 0.2362597, 18.4393764>,
    <2.0023926, 0.2362494, 18.4393764>,
    <2.0025156, 0.1125181, 18.3784821>,
    <2.0025322, -0.1349728, 18.3784821>,
    <2.0025469, 0.1125186, 18.3175878>,
    <2.0025239, -0.0112274, 18.3784821>,
    <2.0025479, -0.1349759, 18.3480349>,
    <2.0025552, -0.0112302, 18.3175878>,
    <2.0025313, 0.1125183, 18.3480349>,
    <2.0025396, -0.0112288, 18.3480349>,
    <2.0024990, 0.3600089, 18.3784821>,
    <2.0025386, 0.2362673, 18.3175878>,
    <2.0025147, 0.3600125, 18.3480349>,
    <2.0025073, 0.2362635, 18.3784821>,
    <2.0025230, 0.2362654, 18.3480349>,
    <2.0024843, 0.1125176, 18.4393764>,
    <2.0024834, 0.3600053, 18.4089292>,
    <2.0024760, 0.2362597, 18.4393764>,
    <2.0025000, 0.1125178, 18.4089292>,
    <2.0024917, 0.2362616, 18.4089292>,
    <2.0024926, -0.0112245, 18.4393764>,
    <2.0025166, -0.1349697, 18.4089292>,
    <2.0025083, -0.0112259, 18.4089292>,
    <2.0032010, 0.1125287, 18.3135798>,
    <2.0038551, 0.1125389, 18.3095719>,
    <2.0035281, 0.1125338, 18.3115759>,
    <2.0038634, -0.0113503, 18.3095719>,
    <2.0032093, -0.0112903, 18.3135798>,
    <2.0035364, -0.0113203, 18.3115759>,
    <2.0025469, 0.1125186, 18.3175878>,
    <2.0025552, -0.0112302, 18.3175878>,
    <2.0028740, 0.1125236, 18.3155838>,
    <2.0028823, -0.0112603, 18.3155838>,
    <2.0025386, 0.2362673, 18.3175878>,
    <2.0031927, 0.2363477, 18.3135798>,
    <2.0028656, 0.2363075, 18.3155838>,
    <2.0038468, 0.2364281, 18.3095719>,
    <2.0035197, 0.2363879, 18.3115759>,
    <2.0038557, 0.1125389, 18.2344341>,
    <2.0038724, -0.1352397, 18.2344341>,
    <2.0038563, 0.1125389, 18.1592964>,
    <2.0038641, -0.0113504, 18.2344341>,
    <2.0038727, -0.1352398, 18.1968653>,
    <2.0038647, -0.0113505, 18.1592964>,
    <2.0038560, 0.1125389, 18.1968653>,
    <2.0038644, -0.0113504, 18.1968653>,
    <2.0038391, 0.3603175, 18.2344341>,
    <2.0038480, 0.2364283, 18.1592964>,
    <2.0038394, 0.3603176, 18.1968653>,
    <2.0038474, 0.2364282, 18.2344341>,
    <2.0038477, 0.2364282, 18.1968653>,
    <2.0038551, 0.1125389, 18.3095719>,
    <2.0038387, 0.3603174, 18.2720030>,
    <2.0038468, 0.2364281, 18.3095719>,
    <2.0038554, 0.1125389, 18.2720030>,
    <2.0038471, 0.2364282, 18.2720030>,
    <2.0038634, -0.0113503, 18.3095719>,
    <2.0038721, -0.1352396, 18.2720030>,
    <2.0038637, -0.0113504, 18.2720030>,
    <2.0039528, 0.1125404, 18.1573801>,
    <2.0040493, 0.1125419, 18.1554639>,
    <2.0040010, 0.1125412, 18.1564220>,
    <2.0040576, -0.0113682, 18.1554639>,
    <2.0039611, -0.0113593, 18.1573801>,
    <2.0040094, -0.0113637, 18.1564220>,
    <2.0038563, 0.1125389, 18.1592964>,
    <2.0038647, -0.0113505, 18.1592964>,
    <2.0039046, 0.1125397, 18.1583383>,
    <2.0039129, -0.0113549, 18.1583383>,
    <2.0038480, 0.2364283, 18.1592964>,
    <2.0039445, 0.2364401, 18.1573801>,
    <2.0038962, 0.2364342, 18.1583383>,
    <2.0040409, 0.2364520, 18.1554639>,
    <2.0039927, 0.2364461, 18.1564220>,
    <2.0042444, 0.1125449, 18.1389725>,
    <2.0042673, -0.1353183, 18.1386133>,
    <2.0043812, 0.1125471, 18.1258340>,
    <2.0042548, -0.0113867, 18.1388528>,
    <2.0043680, -0.1353384, 18.1301880>,
    <2.0044020, -0.0114025, 18.1251156>,
    <2.0043263, 0.1125462, 18.1316249>,
    <2.0043430, -0.0113962, 18.1311460>,
    <2.0042339, 0.3604084, 18.1386133>,
    <2.0043853, 0.2364970, 18.1251156>,
    <2.0043346, 0.3604316, 18.1301880>,
    <2.0042381, 0.2364767, 18.1388528>,
    <2.0043263, 0.2364889, 18.1311460>,
    <2.0040493, 0.1125419, 18.1554639>,
    <2.0041333, 0.3603852, 18.1470386>,
    <2.0040409, 0.2364520, 18.1554639>,
    <2.0041499, 0.1125435, 18.1470386>,
    <2.0041416, 0.2364644, 18.1470386>,
    <2.0040576, -0.0113682, 18.1554639>,
    <2.0041666, -0.1352983, 18.1470386>,
    <2.0041583, -0.0113774, 18.1470386>,
    <2.0043805, 0.1125471, 18.1205987>,
    <2.0043944, 0.1125473, 18.1224380>,
    <2.0043909, -0.0113992, 18.1204790>,
    <2.0044111, -0.0114024, 18.1219591>,
    <2.0043215, 0.1125461, 18.1187163>,
    <2.0043298, -0.0113932, 18.1187163>,
    <2.0043541, 0.1125467, 18.1194779>,
    <2.0043625, -0.0113962, 18.1194779>,
    <2.0043131, 0.2364854, 18.1187163>,
    <2.0043742, 0.2364934, 18.1204790>,
    <2.0043458, 0.2364895, 18.1194779>,
    <2.0043944, 0.2364972, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0005827, 0.9999675, 0.0080437>,
    <-0.0005827, 0.9999715, 0.0075276>,
    <-0.0005683, 0.9999713, 0.0075588>,
    <-0.0005683, 0.9999674, 0.0080589>,
    <-0.0005683, 0.9999632, 0.0085591>,
    <-0.0005827, 0.9999632, 0.0085598>,
    <-0.0005827, 0.9999632, 0.0085598>,
    <-0.0005979, 0.9999632, 0.0085604>,
    <-0.0005979, 0.9999676, 0.0080275>,
    <-0.0005979, 0.9999676, 0.0080275>,
    <-0.0005979, 0.9999717, 0.0074945>,
    <-0.0005827, 0.9999752, 0.0070116>,
    <-0.0005683, 0.9999749, 0.0070586>,
    <-0.0005979, 0.9999717, 0.0074945>,
    <-0.0005979, 0.9999756, 0.0069615>,
    <-0.0005979, 0.9999756, 0.0069615>,
    <-0.0005979, 0.9999792, 0.0064286>,
    <-0.0005827, 0.9999787, 0.0064955>,
    <-0.0005827, 0.9999787, 0.0064955>,
    <-0.0005683, 0.9999783, 0.0065584>,
    <-0.0005549, 0.9999746, 0.0071027>,
    <-0.0005549, 0.9999711, 0.0075880>,
    <-0.0005683, 0.9999783, 0.0065584>,
    <-0.0005549, 0.9999780, 0.0066174>,
    <-0.0005549, 0.9999780, 0.0066174>,
    <-0.0005422, 0.9999776, 0.0066731>,
    <-0.0005422, 0.9999743, 0.0071443>,
    <-0.0005422, 0.9999743, 0.0071443>,
    <-0.0005422, 0.9999709, 0.0076156>,
    <-0.0005549, 0.9999673, 0.0080733>,
    <-0.0005422, 0.9999709, 0.0076156>,
    <-0.0005422, 0.9999672, 0.0080868>,
    <-0.0005422, 0.9999672, 0.0080868>,
    <-0.0005422, 0.9999632, 0.0085580>,
    <-0.0005549, 0.9999632, 0.0085586>,
    <-0.0005549, 0.9999632, 0.0085586>,
    <-0.0005683, 0.9999632, 0.0085591>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <0.0003486, -0.9999426, 0.0107096>,
    <0.0003486, -0.9999456, 0.0104237>,
    <0.0003407, -0.9999458, 0.0104065>,
    <0.0003407, -0.9999429, 0.0106836>,
    <0.0003407, -0.9999399, 0.0109607>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003571, -0.9999391, 0.0110326>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003486, -0.9999486, 0.0101378>,
    <0.0003407, -0.9999486, 0.0101293>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999514, 0.0098515>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999487, 0.0101214>,
    <0.0003332, -0.9999460, 0.0103903>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003262, -0.9999514, 0.0098528>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003332, -0.9999431, 0.0106591>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999406, 0.0108971>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003407, -0.9999399, 0.0109607>,
    <0.0005180, -0.9999989, 0.0014025>,
    <0.0005180, -0.9999990, 0.0013256>,
    <0.0004963, -0.9999990, 0.0013338>,
    <0.0004963, -0.9999989, 0.0014064>,
    <0.0004963, -0.9999988, 0.0014791>,
    <0.0005180, -0.9999988, 0.0014793>,
    <0.0005180, -0.9999988, 0.0014793>,
    <0.0005422, -0.9999988, 0.0014795>,
    <0.0005422, -0.9999989, 0.0013980>,
    <0.0005422, -0.9999989, 0.0013980>,
    <0.0005422, -0.9999990, 0.0013165>,
    <0.0005180, -0.9999991, 0.0012488>,
    <0.0004963, -0.9999991, 0.0012611>,
    <0.0005422, -0.9999990, 0.0013165>,
    <0.0005422, -0.9999991, 0.0012351>,
    <0.0005422, -0.9999991, 0.0012351>,
    <0.0005422, -0.9999992, 0.0011536>,
    <0.0005180, -0.9999992, 0.0011720>,
    <0.0005180, -0.9999992, 0.0011720>,
    <0.0004963, -0.9999992, 0.0011884>,
    <0.0004769, -0.9999991, 0.0012721>,
    <0.0004769, -0.9999990, 0.0013410>,
    <0.0004963, -0.9999992, 0.0011884>,
    <0.0004769, -0.9999992, 0.0012031>,
    <0.0004769, -0.9999992, 0.0012031>,
    <0.0004594, -0.9999992, 0.0012164>,
    <0.0004594, -0.9999991, 0.0012820>,
    <0.0004594, -0.9999991, 0.0012820>,
    <0.0004594, -0.9999990, 0.0013476>,
    <0.0004769, -0.9999989, 0.0014100>,
    <0.0004594, -0.9999990, 0.0013476>,
    <0.0004594, -0.9999989, 0.0014132>,
    <0.0004594, -0.9999989, 0.0014132>,
    <0.0004594, -0.9999988, 0.0014789>,
    <0.0004769, -0.9999988, 0.0014790>,
    <0.0004769, -0.9999988, 0.0014790>,
    <0.0004963, -0.9999988, 0.0014791>,
    <0.7968310, 0.0000404, -0.6042023>,
    <0.7968303, 0.0000404, -0.6042032>,
    <0.7968303, 0.0000402, -0.6042032>,
    <0.7968310, 0.0000402, -0.6042023>,
    <0.7968317, 0.0000402, -0.6042013>,
    <0.7968317, 0.0000404, -0.6042013>,
    <0.7968317, 0.0000404, -0.6042013>,
    <0.7968317, 0.0000405, -0.6042013>,
    <0.7968310, 0.0000405, -0.6042023>,
    <0.7968310, 0.0000405, -0.6042023>,
    <0.7968303, 0.0000405, -0.6042032>,
    <0.7968295, 0.0000404, -0.6042042>,
    <0.7968295, 0.0000402, -0.6042042>,
    <0.7968303, 0.0000405, -0.6042032>,
    <0.7968295, 0.0000405, -0.6042042>,
    <0.7968295, 0.0000405, -0.6042042>,
    <0.7968288, 0.0000405, -0.6042051>,
    <0.7968288, 0.0000404, -0.6042051>,
    <0.7968288, 0.0000404, -0.6042051>,
    <0.7968288, 0.0000402, -0.6042051>,
    <0.7968295, 0.0000401, -0.6042042>,
    <0.7968303, 0.0000401, -0.6042032>,
    <0.7968288, 0.0000402, -0.6042051>,
    <0.7968288, 0.0000401, -0.6042051>,
    <0.7968288, 0.0000401, -0.6042051>,
    <0.7968288, 0.0000400, -0.6042051>,
    <0.7968295, 0.0000400, -0.6042042>,
    <0.7968295, 0.0000400, -0.6042042>,
    <0.7968303, 0.0000400, -0.6042032>,
    <0.7968310, 0.0000401, -0.6042023>,
    <0.7968303, 0.0000400, -0.6042032>,
    <0.7968310, 0.0000400, -0.6042023>,
    <0.7968310, 0.0000400, -0.6042023>,
    <0.7968317, 0.0000400, -0.6042013>,
    <0.7968317, 0.0000401, -0.6042013>,
    <0.7968317, 0.0000401, -0.6042013>,
    <0.7968317, 0.0000402, -0.6042013>,
    <-0.0003128, 0.9999983, 0.0018311>,
    <-0.0003128, 0.9999984, 0.0017886>,
    <-0.0003008, 0.9999984, 0.0017841>,
    <-0.0003008, 0.9999983, 0.0018243>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003262, 0.9999982, 0.0018839>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003128, 0.9999984, 0.0017460>,
    <-0.0003008, 0.9999984, 0.0017438>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999985, 0.0017033>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999984, 0.0017418>,
    <-0.0002901, 0.9999984, 0.0017800>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002803, 0.9999985, 0.0017037>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002901, 0.9999983, 0.0018183>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018491>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <0.0004480, -0.9999537, 0.0096163>,
    <0.0004480, -0.9999577, 0.0091854>,
    <0.0004373, -0.9999575, 0.0092127>,
    <0.0004373, -0.9999535, 0.0096297>,
    <0.0004373, -0.9999494, 0.0100467>,
    <0.0004479, -0.9999494, 0.0100473>,
    <0.0004479, -0.9999494, 0.0100473>,
    <0.0004594, -0.9999494, 0.0100479>,
    <0.0004594, -0.9999538, 0.0096021>,
    <0.0004594, -0.9999538, 0.0096021>,
    <0.0004594, -0.9999580, 0.0091563>,
    <0.0004480, -0.9999616, 0.0087545>,
    <0.0004373, -0.9999612, 0.0087956>,
    <0.0004594, -0.9999580, 0.0091563>,
    <0.0004594, -0.9999620, 0.0087105>,
    <0.0004594, -0.9999620, 0.0087105>,
    <0.0004594, -0.9999657, 0.0082647>,
    <0.0004480, -0.9999653, 0.0083235>,
    <0.0004480, -0.9999653, 0.0083235>,
    <0.0004373, -0.9999648, 0.0083786>,
    <0.0004273, -0.9999609, 0.0088342>,
    <0.0004273, -0.9999572, 0.0092382>,
    <0.0004373, -0.9999648, 0.0083786>,
    <0.0004273, -0.9999644, 0.0084302>,
    <0.0004273, -0.9999644, 0.0084302>,
    <0.0004178, -0.9999640, 0.0084786>,
    <0.0004178, -0.9999606, 0.0088704>,
    <0.0004178, -0.9999606, 0.0088704>,
    <0.0004178, -0.9999570, 0.0092622>,
    <0.0004272, -0.9999534, 0.0096422>,
    <0.0004178, -0.9999570, 0.0092622>,
    <0.0004178, -0.9999533, 0.0096540>,
    <0.0004178, -0.9999533, 0.0096540>,
    <0.0004178, -0.9999495, 0.0100458>,
    <0.0004272, -0.9999494, 0.0100462>,
    <0.0004272, -0.9999494, 0.0100462>,
    <0.0004373, -0.9999494, 0.0100467>,
    <0.1905399, 0.0000096, -0.9816795>,
    <0.1905394, 0.0000096, -0.9816795>,
    <0.1905394, 0.0000095, -0.9816795>,
    <0.1905399, 0.0000095, -0.9816795>,
    <0.1905403, 0.0000095, -0.9816794>,
    <0.1905403, 0.0000096, -0.9816794>,
    <0.1905403, 0.0000096, -0.9816794>,
    <0.1905403, 0.0000096, -0.9816794>,
    <0.1905399, 0.0000096, -0.9816795>,
    <0.1905399, 0.0000096, -0.9816795>,
    <0.1905394, 0.0000096, -0.9816795>,
    <0.1905390, 0.0000096, -0.9816796>,
    <0.1905390, 0.0000095, -0.9816796>,
    <0.1905394, 0.0000096, -0.9816795>,
    <0.1905390, 0.0000096, -0.9816796>,
    <0.1905390, 0.0000096, -0.9816796>,
    <0.1905385, 0.0000096, -0.9816797>,
    <0.1905385, 0.0000096, -0.9816797>,
    <0.1905385, 0.0000096, -0.9816797>,
    <0.1905385, 0.0000095, -0.9816797>,
    <0.1905390, 0.0000095, -0.9816796>,
    <0.1905394, 0.0000095, -0.9816795>,
    <0.1905385, 0.0000095, -0.9816797>,
    <0.1905385, 0.0000095, -0.9816797>,
    <0.1905385, 0.0000095, -0.9816797>,
    <0.1905385, 0.0000095, -0.9816797>,
    <0.1905390, 0.0000095, -0.9816796>,
    <0.1905390, 0.0000095, -0.9816796>,
    <0.1905394, 0.0000095, -0.9816795>,
    <0.1905399, 0.0000095, -0.9816795>,
    <0.1905394, 0.0000095, -0.9816795>,
    <0.1905399, 0.0000095, -0.9816795>,
    <0.1905399, 0.0000095, -0.9816795>,
    <0.1905403, 0.0000095, -0.9816794>,
    <0.1905403, 0.0000095, -0.9816794>,
    <0.1905403, 0.0000095, -0.9816794>,
    <0.1905403, 0.0000095, -0.9816794>,
    <-0.0002740, 0.9999244, 0.0122917>,
    <-0.0002740, 0.9999273, 0.0120530>,
    <-0.0002681, 0.9999275, 0.0120379>,
    <-0.0002681, 0.9999247, 0.0122689>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002803, 0.9999210, 0.0125631>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002740, 0.9999302, 0.0118142>,
    <-0.0002681, 0.9999303, 0.0118068>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999330, 0.0115751>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999303, 0.0117999>,
    <-0.0002625, 0.9999277, 0.0120237>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002573, 0.9999330, 0.0115763>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002625, 0.9999250, 0.0122476>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999225, 0.0124445>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <0.0004245, -0.9999999, 0.0000258>,
    <0.0004214, -0.9999999, 0.0000435>,
    <0.0004484, -0.9999999, 0.0001816>,
    <0.0004726, -0.9999999, 0.0001013>,
    <0.0004777, -0.9999999, 0.0000017>,
    <0.0004254, -0.9999999, 0.0000017>,
    <0.0004254, -0.9999999, 0.0000017>,
    <0.0004179, -0.9999999, 0.0000017>,
    <0.0004179, -0.9999999, 0.0000016>,
    <0.0004179, -0.9999999, 0.0000016>,
    <0.0004179, -0.9999999, 0.0000015>,
    <0.0004182, -0.9999999, 0.0000497>,
    <0.0004217, -0.9999999, 0.0002129>,
    <0.0004179, -0.9999999, 0.0000015>,
    <0.0004179, -0.9999999, 0.0000015>,
    <0.0004179, -0.9999999, 0.0000015>,
    <0.0004179, -0.9999999, 0.0000014>,
    <0.0004172, -0.9999999, 0.0000486>,
    <0.0004172, -0.9999999, 0.0000486>,
    <0.0004127, -0.9999999, 0.0002100>,
    <0.0004307, -0.9999997, 0.0005761>,
    <0.0005164, -0.9999997, 0.0005197>,
    <0.0004127, -0.9999999, 0.0002100>,
    <0.0004013, -0.9999998, 0.0005691>,
    <0.0004013, -0.9999998, 0.0005691>,
    <0.0003814, -0.9999989, 0.0014244>,
    <0.0004334, -0.9999989, 0.0014481>,
    <0.0005895, -0.9999988, 0.0014504>,
    <0.0006243, -0.9999997, 0.0003378>,
    <0.0009586, -0.9999985, 0.0014756>,
    <0.0012679, -0.9999978, 0.0016581>,
    <0.0006436, -0.9999998, 0.0000017>,
    <0.0006436, -0.9999998, 0.0000017>,
    <0.0004777, -0.9999999, 0.0000017>,
    <0.9995639, 0.0000498, -0.0295315>,
    <0.9995638, 0.0000498, -0.0295315>,
    <0.9920098, 0.0000494, -0.1261608>,
    <0.9920098, 0.0000494, -0.1261605>,
    <0.9920099, 0.0000494, -0.1261602>,
    <0.9995639, 0.0000498, -0.0295314>,
    <0.9995639, 0.0000498, -0.0295314>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9995638, 0.0000498, -0.0295316>,
    <0.9920098, 0.0000494, -0.1261611>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9995638, 0.0000498, -0.0295317>,
    <0.9995638, 0.0000498, -0.0295317>,
    <0.9920097, 0.0000494, -0.1261614>,
    <0.9460835, 0.0000470, -0.3239228>,
    <0.9460838, 0.0000470, -0.3239221>,
    <0.9920097, 0.0000494, -0.1261614>,
    <0.9460833, 0.0000470, -0.3239235>,
    <0.9460833, 0.0000470, -0.3239235>,
    <0.7631609, 0.0000377, -0.6462085>,
    <0.7631617, 0.0000377, -0.6462076>,
    <0.7631625, 0.0000377, -0.6462067>,
    <0.9460840, 0.0000470, -0.3239213>,
    <0.7631632, 0.0000377, -0.6462057>,
    <0.7631640, 0.0000377, -0.6462048>,
    <0.9460843, 0.0000470, -0.3239206>,
    <0.9460843, 0.0000470, -0.3239206>,
    <0.9920099, 0.0000494, -0.1261602>,
    <-0.0002557, 1.0000000, 0.0000687>,
    <-0.0002521, 1.0000000, 0.0000578>,
    <-0.0002128, 0.9999999, 0.0002410>,
    <-0.0002438, 0.9999999, 0.0002938>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002573, 1.0000000, 0.0000021>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002485, 1.0000000, 0.0000335>,
    <-0.0001849, 1.0000000, 0.0001319>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000127, 0.9999999, 0.0004262>,
    <-0.0001114, 0.9999998, 0.0006796>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0004444, 0.9999983, 0.0017942>,
    <0.0000146, 0.9999983, 0.0018600>,
    <-0.0002126, 0.9999997, 0.0007890>,
    <-0.0001727, 0.9999981, 0.0019562>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <0.0009631, -0.9999847, 0.0054429>,
    <0.0005675, -0.9999936, 0.0035357>,
    <0.0003454, -0.9999839, 0.0056582>,
    <0.0003746, -0.9999539, 0.0095899>,
    <0.0004982, -0.9994694, 0.0325694>,
    <0.0041287, -0.9994415, 0.0331611>,
    <0.0041287, -0.9994415, 0.0331611>,
    <0.0012679, -0.9999978, 0.0016581>,
    <0.0004046, -0.9999950, 0.0031510>,
    <0.0003331, -0.9999892, 0.0046263>,
    <0.0003814, -0.9999989, 0.0014244>,
    <0.0003553, -0.9999953, 0.0030566>,
    <0.0003553, -0.9999953, 0.0030566>,
    <0.0003299, -0.9999903, 0.0043860>,
    <0.0002708, -0.9999922, 0.0039301>,
    <0.0001376, -0.9999892, 0.0046520>,
    <0.0003299, -0.9999903, 0.0043860>,
    <0.0003092, -0.9999931, 0.0037039>,
    <0.0003092, -0.9999931, 0.0037039>,
    <0.0002946, -0.9999981, 0.0019121>,
    <0.0002591, -0.9999980, 0.0019894>,
    <0.0001493, -0.9999978, 0.0020871>,
    <-0.0001882, -0.9999742, 0.0071852>,
    <-0.0001121, -0.9999977, 0.0021646>,
    <-0.0002880, -0.9999978, 0.0021003>,
    <-0.0020420, -0.9994808, 0.0321552>,
    <-0.0020420, -0.9994808, 0.0321552>,
    <0.0004982, -0.9994694, 0.0325694>,
    <0.4878559, 0.0000239, -0.8729242>,
    <0.4878549, 0.0000239, -0.8729247>,
    <0.3675999, 0.0000178, -0.9299841>,
    <0.3676006, 0.0000178, -0.9299837>,
    <0.3676014, 0.0000178, -0.9299834>,
    <0.4878568, 0.0000239, -0.8729237>,
    <0.4878568, 0.0000239, -0.8729237>,
    <0.7631640, 0.0000377, -0.6462048>,
    <0.4878540, 0.0000239, -0.8729252>,
    <0.3675991, 0.0000178, -0.9299844>,
    <0.7631609, 0.0000377, -0.6462085>,
    <0.4878531, 0.0000239, -0.8729257>,
    <0.4878531, 0.0000239, -0.8729257>,
    <0.3675983, 0.0000178, -0.9299847>,
    <0.4280648, 0.0000206, -0.9037480>,
    <0.4280657, 0.0000206, -0.9037476>,
    <0.3675983, 0.0000178, -0.9299847>,
    <0.4280639, 0.0000206, -0.9037484>,
    <0.4280639, 0.0000206, -0.9037484>,
    <0.6790848, 0.0000323, -0.7340599>,
    <0.6790857, 0.0000323, -0.7340590>,
    <0.6790866, 0.0000323, -0.7340582>,
    <0.4280665, 0.0000206, -0.9037472>,
    <0.6790875, 0.0000323, -0.7340574>,
    <0.6790884, 0.0000323, -0.7340565>,
    <0.4280674, 0.0000206, -0.9037468>,
    <0.4280674, 0.0000206, -0.9037468>,
    <0.3676014, 0.0000178, -0.9299834>,
    <-0.0001605, 0.9999912, 0.0041835>,
    <0.0000373, 0.9999900, 0.0044632>,
    <-0.0001893, 0.9999751, 0.0070592>,
    <-0.0002044, 0.9999817, 0.0060433>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <0.0004994, 0.9999785, 0.0065314>,
    <-0.0001552, 0.9999344, 0.0114548>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0041270, 0.9992606, 0.0382247>,
    <0.0041270, 0.9992606, 0.0382247>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0007848, 0.9999631, 0.0085524>,
    <-0.0004049, 0.9999833, 0.0057588>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0006662, 0.9999964, 0.0025817>,
    <-0.0003625, 0.9999966, 0.0025763>,
    <-0.0002448, 0.9999871, 0.0050692>,
    <-0.0002322, 0.9999967, 0.0025453>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <0.0001522, -0.9999998, 0.0005576>,
    <0.0002167, -0.9999997, 0.0007949>,
    <0.0002617, -0.9999999, 0.0003340>,
    <0.0002483, -0.9999999, 0.0002315>,
    <0.0002455, -1.0000000, 0.0001025>,
    <0.0001426, -1.0000000, 0.0001024>,
    <0.0001426, -1.0000000, 0.0001024>,
    <-0.0002880, -0.9999978, 0.0021003>,
    <0.0002684, -0.9999996, 0.0008505>,
    <0.0002766, -0.9999999, 0.0003726>,
    <0.0002946, -0.9999981, 0.0019121>,
    <0.0002861, -0.9999996, 0.0008367>,
    <0.0002861, -0.9999996, 0.0008367>,
    <0.0002816, -0.9999999, 0.0003702>,
    <0.0002789, -0.9999999, 0.0001590>,
    <0.0002772, -0.9999999, 0.0001524>,
    <0.0002816, -0.9999999, 0.0003702>,
    <0.0002794, -0.9999999, 0.0001568>,
    <0.0002794, -0.9999999, 0.0001568>,
    <0.0002784, -1.0000000, 0.0000939>,
    <0.0002784, -1.0000000, 0.0000961>,
    <0.0002784, -1.0000000, 0.0000961>,
    <0.0002784, -1.0000000, 0.0000982>,
    <0.0002755, -1.0000000, 0.0001315>,
    <0.0002784, -1.0000000, 0.0000982>,
    <0.0002784, -1.0000000, 0.0001004>,
    <0.0002784, -1.0000000, 0.0001004>,
    <0.0002784, -1.0000000, 0.0001025>,
    <0.0002750, -1.0000000, 0.0001025>,
    <0.0002750, -1.0000000, 0.0001025>,
    <0.0002455, -1.0000000, 0.0001025>,
    <0.9047737, 0.0000428, -0.4258927>,
    <0.9047733, 0.0000428, -0.4258936>,
    <0.9790994, 0.0000462, -0.2033825>,
    <0.9790995, 0.0000462, -0.2033820>,
    <0.9790996, 0.0000462, -0.2033815>,
    <0.9047741, 0.0000428, -0.4258919>,
    <0.9047741, 0.0000428, -0.4258919>,
    <0.6790884, 0.0000323, -0.7340565>,
    <0.9047729, 0.0000428, -0.4258945>,
    <0.9790993, 0.0000462, -0.2033830>,
    <0.6790848, 0.0000323, -0.7340599>,
    <0.9047724, 0.0000428, -0.4258953>,
    <0.9047724, 0.0000428, -0.4258953>,
    <0.9790992, 0.0000462, -0.2033835>,
    <0.9961600, 0.0000469, -0.0875510>,
    <0.9961601, 0.0000469, -0.0875508>,
    <0.9790992, 0.0000462, -0.2033835>,
    <0.9961600, 0.0000469, -0.0875512>,
    <0.9961600, 0.0000469, -0.0875512>,
    <0.9986191, 0.0000470, -0.0525351>,
    <0.9986191, 0.0000470, -0.0525350>,
    <0.9986191, 0.0000470, -0.0525350>,
    <0.9986191, 0.0000470, -0.0525349>,
    <0.9961601, 0.0000469, -0.0875506>,
    <0.9986191, 0.0000470, -0.0525349>,
    <0.9986191, 0.0000470, -0.0525347>,
    <0.9986191, 0.0000470, -0.0525347>,
    <0.9986191, 0.0000470, -0.0525346>,
    <0.9961601, 0.0000469, -0.0875504>,
    <0.9961601, 0.0000469, -0.0875504>,
    <0.9790996, 0.0000462, -0.2033815>,
    <-0.0002053, 0.9999994, 0.0010841>,
    <-0.0002659, 0.9999995, 0.0009839>,
    <-0.0002050, 0.9999999, 0.0004143>,
    <-0.0001877, 0.9999999, 0.0004740>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0003403, 0.9999997, 0.0006738>,
    <-0.0002205, 0.9999999, 0.0002809>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001852, 1.0000000, 0.0001577>,
    <-0.0001833, 1.0000000, 0.0001881>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001801, 1.0000000, 0.0001183>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001813, 1.0000000, 0.0002019>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001230>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <-0.9869426, -0.0000663, -0.1610724>,
    <-0.9869426, -0.0000663, -0.1610724>,
    <-0.9869431, -0.0000663, -0.1610692>,
    <-0.9869431, -0.0000663, -0.1610692>,
    <-0.9869431, -0.0000664, -0.1610692>,
    <-0.9869426, -0.0000664, -0.1610724>,
    <-0.9869426, -0.0000664, -0.1610724>,
    <-0.9869421, -0.0000664, -0.1610757>,
    <-0.9869421, -0.0000663, -0.1610757>,
    <-0.9869421, -0.0000663, -0.1610757>,
    <-0.9869421, -0.0000663, -0.1610757>,
    <-0.9869426, -0.0000662, -0.1610724>,
    <-0.9869431, -0.0000662, -0.1610692>,
    <-0.9869421, -0.0000663, -0.1610757>,
    <-0.9869421, -0.0000662, -0.1610757>,
    <-0.9869421, -0.0000662, -0.1610757>,
    <-0.9869421, -0.0000662, -0.1610757>,
    <-0.9869426, -0.0000662, -0.1610724>,
    <-0.9869426, -0.0000662, -0.1610724>,
    <-0.9869431, -0.0000662, -0.1610692>,
    <-0.9869436, -0.0000662, -0.1610659>,
    <-0.9869436, -0.0000663, -0.1610659>,
    <-0.9869431, -0.0000662, -0.1610692>,
    <-0.9869437, -0.0000662, -0.1610659>,
    <-0.9869437, -0.0000662, -0.1610659>,
    <-0.9869442, -0.0000662, -0.1610626>,
    <-0.9869442, -0.0000662, -0.1610626>,
    <-0.9869442, -0.0000662, -0.1610626>,
    <-0.9869442, -0.0000663, -0.1610627>,
    <-0.9869436, -0.0000663, -0.1610659>,
    <-0.9869442, -0.0000663, -0.1610627>,
    <-0.9869442, -0.0000663, -0.1610627>,
    <-0.9869442, -0.0000663, -0.1610627>,
    <-0.9869442, -0.0000664, -0.1610627>,
    <-0.9869436, -0.0000664, -0.1610659>,
    <-0.9869436, -0.0000664, -0.1610659>,
    <-0.9869431, -0.0000664, -0.1610692>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <0.9999404, 0.0001117, 0.0109141>,
    <0.9999447, 0.0000673, 0.0105163>,
    <0.9999338, 0.0000673, 0.0115037>,
    <0.9999321, 0.0000784, 0.0116512>,
    <0.9999286, 0.0000814, 0.0119508>,
    <0.9999286, 0.0001217, 0.0119507>,
    <0.9999286, 0.0001217, 0.0119507>,
    <0.9999725, 0.0002732, 0.0074076>,
    <0.9999725, 0.0001960, 0.0074077>,
    <0.9999726, 0.0000674, 0.0074076>,
    <0.9999404, 0.0000230, 0.0109136>,
    <0.9999321, 0.0000562, 0.0116506>,
    <0.9999726, -0.0000613, 0.0074074>,
    <0.9999726, -0.0001385, 0.0074070>,
    <0.9999286, 0.0000130, 0.0119496>,
    <0.9999286, 0.0000130, 0.0119496>,
    <0.9999286, 0.0000533, 0.0119498>,
    <0.9999295, 0.0000660, 0.0118782>,
    <0.9999298, 0.0000673, 0.0118451>,
    <0.9999286, 0.0000533, 0.0119498>,
    <0.9999286, 0.0000656, 0.0119498>,
    <0.9999286, 0.0000656, 0.0119498>,
    <0.9999286, 0.0000673, 0.0119498>,
    <0.9999286, 0.0000673, 0.0119500>,
    <0.9999286, 0.0000673, 0.0119500>,
    <0.9999286, 0.0000673, 0.0119503>,
    <0.9999294, 0.0000686, 0.0118787>,
    <0.9999286, 0.0000673, 0.0119503>,
    <0.9999286, 0.0000673, 0.0119505>,
    <0.9999286, 0.0000673, 0.0119505>,
    <0.9999286, 0.0000673, 0.0119508>,
    <0.9999286, 0.0000691, 0.0119508>,
    <0.9999286, 0.0000691, 0.0119508>,
    <0.9999286, 0.0000814, 0.0119508>,
    <0.9999905, 0.0002163, -0.0043628>,
    <0.9997833, 0.0001412, -0.0208159>,
    <0.9998819, 0.0000673, -0.0153711>,
    <0.9999997, 0.0000674, -0.0008270>,
    <0.9999725, 0.0002732, 0.0074076>,
    <0.9990830, 0.0006682, -0.0428096>,
    <0.9990830, 0.0006682, -0.0428096>,
    <0.9990831, 0.0002224, -0.0428134>,
    <0.9993788, 0.0000800, -0.0352415>,
    <0.9994752, 0.0000673, -0.0323937>,
    <0.9990831, 0.0002224, -0.0428134>,
    <0.9990830, 0.0000867, -0.0428145>,
    <0.9990830, 0.0000867, -0.0428145>,
    <0.9990830, 0.0000673, -0.0428147>,
    <0.9990831, 0.0000673, -0.0428138>,
    <0.9990831, 0.0000673, -0.0428138>,
    <0.9990831, 0.0000673, -0.0428129>,
    <0.9993789, 0.0000546, -0.0352399>,
    <0.9997834, -0.0000065, -0.0208147>,
    <0.9990831, 0.0000673, -0.0428129>,
    <0.9990831, 0.0000673, -0.0428120>,
    <0.9990831, 0.0000673, -0.0428120>,
    <0.9990832, 0.0000673, -0.0428112>,
    <0.9990832, 0.0000479, -0.0428110>,
    <0.9990832, 0.0000479, -0.0428110>,
    <0.9990832, -0.0000878, -0.0428096>,
    <0.9999905, -0.0000815, -0.0043624>,
    <0.9990832, -0.0000878, -0.0428096>,
    <0.9990833, -0.0005335, -0.0428052>,
    <0.9990833, -0.0005335, -0.0428052>,
    <0.9999726, -0.0001385, 0.0074070>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4349582, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4349582, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4263414, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559367, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773948, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032658, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458854>,
    <0.4677608, 0.9456845>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4355157, 0.9458854>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9451388>,
    <0.4677604, 0.9518685>,
    <0.4676209, 0.9588001>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.4677604, 0.9518685>,
    <0.5000059, 0.9579003>,
    <0.4674769, 0.9657316>,
    <0.4352664, 0.9584513>,
    <0.4031264, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4349582, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352664, 0.9584513>,
    <0.4022562, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032658, 0.9526160>,
    <0.5322510, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9518685>,
    <0.5000059, 0.9451388>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458642>,
    <0.5967410, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5644961, 0.9458642>,
    <0.5967380, 0.9395004>,
    <0.6289858, 0.9451388>,
    <0.5967440, 0.9518685>,
    <0.5967474, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967440, 0.9518685>,
    <0.6289941, 0.9579003>,
    <0.5967509, 0.9657316>,
    <0.5645003, 0.9587016>,
    <0.5322532, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.5645003, 0.9587016>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9579003>,
    <0.5322521, 0.9518685>,
    <0.6423395, 0.9456845>,
    <0.6556982, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423437, 0.9518685>,
    <0.6289858, 0.9451388>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458854>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458854>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691147, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694793, 0.9657316>,
    <0.6558043, 0.9584513>,
    <0.6424060, 0.9588001>,
    <0.6556982, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.6558043, 0.9584513>,
    <0.6424701, 0.9657316>,
    <0.6289941, 0.9579003>,
    <0.6423437, 0.9518685>,
    <0.3997689, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4022562, 0.9657316>,
    <0.4331396, 0.9660561>,
    <0.4665018, 0.9660805>,
    <0.4310370, 0.9664312>,
    <0.4349582, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4331396, 0.9660561>,
    <0.4674769, 0.9657316>,
    <0.5000060, 0.9660883>,
    <0.4655215, 0.9664293>,
    <0.4643476, 0.9667801>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000061, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.4655215, 0.9664293>,
    <0.5000060, 0.9667645>,
    <0.4631665, 0.9671308>,
    <0.4286164, 0.9667919>,
    <0.3931424, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4263414, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4286164, 0.9667919>,
    <0.3894539, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664293>,
    <0.5000060, 0.9660883>,
    <0.5322542, 0.9657316>,
    <0.5667950, 0.9660902>,
    <0.6000933, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5667950, 0.9660902>,
    <0.5967509, 0.9657316>,
    <0.6335597, 0.9660883>,
    <0.6034357, 0.9664293>,
    <0.6068019, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034357, 0.9664293>,
    <0.6422052, 0.9667645>,
    <0.6101681, 0.9671308>,
    <0.5711180, 0.9667664>,
    <0.5356086, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.5711180, 0.9667664>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667645>,
    <0.5344905, 0.9664293>,
    <0.6473345, 0.9660805>,
    <0.6665054, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6289992, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6522009, 0.9664293>,
    <0.6335597, 0.9660883>,
    <0.6424701, 0.9657316>,
    <0.6608384, 0.9660561>,
    <0.6749817, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559367, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6608384, 0.9660561>,
    <0.6694793, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866708, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926707, 0.9671308>,
    <0.6721189, 0.9667919>,
    <0.6571714, 0.9667801>,
    <0.6665054, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.6721189, 0.9667919>,
    <0.6621448, 0.9671308>,
    <0.6422052, 0.9667645>,
    <0.6522009, 0.9664293>,
    <0.3896277, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.3895219, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3894539, 0.9671308>,
    <0.4263465, 0.9729776>,
    <0.4631761, 0.9726967>,
    <0.4263507, 0.9777601>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4263465, 0.9729776>,
    <0.4631665, 0.9671308>,
    <0.5000061, 0.9732089>,
    <0.4631777, 0.9782626>,
    <0.4631249, 0.9833260>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631777, 0.9782626>,
    <0.5000061, 0.9837065>,
    <0.4630714, 0.9883895>,
    <0.4262410, 0.9832100>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262410, 0.9832100>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895219, 0.9777601>,
    <0.5367803, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9782626>,
    <0.5000061, 0.9732089>,
    <0.5367268, 0.9671308>,
    <0.5735592, 0.9726839>,
    <0.6103387, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5735592, 0.9726839>,
    <0.6101681, 0.9671308>,
    <0.6471335, 0.9732089>,
    <0.6105094, 0.9782626>,
    <0.6106597, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105094, 0.9782626>,
    <0.6475562, 0.9837065>,
    <0.6108101, 0.9883895>,
    <0.5737713, 0.9832176>,
    <0.5368873, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.5737713, 0.9832176>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9837065>,
    <0.5368338, 0.9782626>,
    <0.6623650, 0.9726967>,
    <0.6778190, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6468888, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6625884, 0.9782625>,
    <0.6471335, 0.9732089>,
    <0.6621448, 0.9671308>,
    <0.6776281, 0.9729776>,
    <0.6928127, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773948, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776281, 0.9729776>,
    <0.6926707, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930705, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930705, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780838, 0.9832100>,
    <0.6628141, 0.9833260>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.6780838, 0.9832100>,
    <0.6630402, 0.9883895>,
    <0.6475562, 0.9837065>,
    <0.6625884, 0.9782625>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.011335, 0.13719, -0.147353>
}

#declare TMesh006 = mesh2 {
  vertex_vectors {
    582,
    <2.1734601, 0.0653472, 18.5417983>,
    <2.0013882, 0.0307137, 18.5417983>,
    <2.0021672, -0.1348962, 18.5417983>,
    <2.1725990, -0.1348507, 18.5417983>,
    <2.0874241, 0.0480304, 18.5417983>,
    <2.0017777, -0.0520913, 18.5417983>,
    <2.0873831, -0.1348735, 18.5417983>,
    <2.1730296, -0.0347518, 18.5417983>,
    <2.0874036, -0.0434215, 18.5417983>,
    <2.3430309, -0.1348052, 18.5417983>,
    <2.3455321, 0.0999807, 18.5417983>,
    <2.2578150, -0.1348279, 18.5417983>,
    <2.3442815, -0.0174122, 18.5417983>,
    <2.2594961, 0.0826639, 18.5417983>,
    <2.2586555, -0.0260820, 18.5417983>,
    <2.3480332, 0.3347665, 18.5417983>,
    <2.1743212, 0.2655450, 18.5417983>,
    <2.3467826, 0.2173736, 18.5417983>,
    <2.2611772, 0.3001557, 18.5417983>,
    <2.1738907, 0.1654461, 18.5417983>,
    <2.2603366, 0.1914098, 18.5417983>,
    <2.0006092, 0.1963236, 18.5417983>,
    <2.0874652, 0.2309343, 18.5417983>,
    <2.0009987, 0.1135186, 18.5417983>,
    <2.0874447, 0.1394824, 18.5417983>,
    <2.0592721, -0.1353186, 18.1202395>,
    <2.0044034, -0.1353504, 18.1202395>,
    <2.0044687, -0.1353636, 18.1217627>,
    <2.0559641, -0.1353322, 18.1217627>,
    <2.0318378, -0.1353345, 18.1202395>,
    <2.0044361, -0.1353570, 18.1210011>,
    <2.0302164, -0.1353479, 18.1217627>,
    <2.0576181, -0.1353254, 18.1210011>,
    <2.0310271, -0.1353412, 18.1210011>,
    <2.1074595, -0.1353008, 18.1217627>,
    <2.1141408, -0.1352868, 18.1202395>,
    <2.0817118, -0.1353165, 18.1217627>,
    <2.1108002, -0.1352938, 18.1210011>,
    <2.0867065, -0.1353027, 18.1202395>,
    <2.0842091, -0.1353096, 18.1210011>,
    <2.1208221, -0.1352727, 18.1187163>,
    <2.0625801, -0.1353049, 18.1187163>,
    <2.1174814, -0.1352798, 18.1194779>,
    <2.0917011, -0.1352888, 18.1187163>,
    <2.0609261, -0.1353118, 18.1194779>,
    <2.0892038, -0.1352958, 18.1194779>,
    <2.0043382, -0.1353371, 18.1187163>,
    <2.0334591, -0.1353210, 18.1187163>,
    <2.0043708, -0.1353438, 18.1194779>,
    <2.0326485, -0.1353278, 18.1194779>,
    <2.1143682, 0.0535944, 18.1202395>,
    <2.1076205, 0.0522404, 18.1217627>,
    <2.1142545, -0.0408462, 18.1202395>,
    <2.1075400, -0.0415302, 18.1217627>,
    <2.1109944, 0.0529174, 18.1210011>,
    <2.1108973, -0.0411882, 18.1210011>,
    <2.1077816, 0.2397817, 18.1217627>,
    <2.1145956, 0.2424756, 18.1202395>,
    <2.1077011, 0.1460111, 18.1217627>,
    <2.1111886, 0.2411287, 18.1210011>,
    <2.1144819, 0.1480350, 18.1202395>,
    <2.1110915, 0.1470230, 18.1210011>,
    <2.1214096, 0.2451696, 18.1187163>,
    <2.1211158, 0.0549484, 18.1187163>,
    <2.1180026, 0.2438226, 18.1194779>,
    <2.1212627, 0.1500590, 18.1187163>,
    <2.1177420, 0.0542714, 18.1194779>,
    <2.1178723, 0.1490470, 18.1194779>,
    <2.1209690, -0.0401621, 18.1187163>,
    <2.1176117, -0.0405042, 18.1194779>,
    <2.0586710, 0.2201778, 18.1202395>,
    <2.0552952, 0.2188536, 18.1217627>,
    <2.0866333, 0.2313267, 18.1202395>,
    <2.0815384, 0.2293176, 18.1217627>,
    <2.0569831, 0.2195157, 18.1210011>,
    <2.0840858, 0.2303222, 18.1210011>,
    <2.0028088, 0.1979254, 18.1217627>,
    <2.0027464, 0.1978800, 18.1202395>,
    <2.0290520, 0.2083895, 18.1217627>,
    <2.0027776, 0.1979027, 18.1210011>,
    <2.0307087, 0.2090289, 18.1202395>,
    <2.0298803, 0.2087092, 18.1210011>,
    <2.0026840, 0.1978346, 18.1187163>,
    <2.0620468, 0.2215021, 18.1187163>,
    <2.0027152, 0.1978573, 18.1194779>,
    <2.0323654, 0.2096683, 18.1187163>,
    <2.0603589, 0.2208400, 18.1194779>,
    <2.0315370, 0.2093486, 18.1194779>,
    <2.0917282, 0.2333358, 18.1187163>,
    <2.0891807, 0.2323313, 18.1194779>,
    <2.0694781, -0.1352765, 18.1370901>,
    <2.0042020, -0.1353095, 18.1370901>,
    <2.0368401, -0.1352930, 18.1370901>,
    <2.0042701, -0.1353233, 18.1279032>,
    <2.0660291, -0.1352907, 18.1279032>,
    <2.0351496, -0.1353070, 18.1279032>,
    <2.1347541, -0.1352434, 18.1370901>,
    <2.1277881, -0.1352581, 18.1279032>,
    <2.1021161, -0.1352599, 18.1370901>,
    <2.0969086, -0.1352744, 18.1279032>,
    <2.1486861, -0.1352141, 18.1554639>,
    <2.0763760, -0.1352480, 18.1554639>,
    <2.1417201, -0.1352288, 18.1462770>,
    <2.1125311, -0.1352310, 18.1554639>,
    <2.0729270, -0.1352622, 18.1462770>,
    <2.1073236, -0.1352455, 18.1462770>,
    <2.0040659, -0.1352818, 18.1554639>,
    <2.0402210, -0.1352649, 18.1554639>,
    <2.0041340, -0.1352957, 18.1462770>,
    <2.0385305, -0.1352789, 18.1462770>,
    <2.1351863, 0.0577719, 18.1370901>,
    <2.1349702, -0.0387358, 18.1370901>,
    <2.1281510, 0.0563601, 18.1279032>,
    <2.1279696, -0.0394490, 18.1279032>,
    <2.1356184, 0.2507871, 18.1370901>,
    <2.1285140, 0.2479784, 18.1279032>,
    <2.1354023, 0.1542795, 18.1370901>,
    <2.1283325, 0.1521693, 18.1279032>,
    <2.1498273, 0.2564047, 18.1554639>,
    <2.1492567, 0.0605953, 18.1554639>,
    <2.1427228, 0.2535959, 18.1462770>,
    <2.1495420, 0.1585000, 18.1554639>,
    <2.1422215, 0.0591836, 18.1462770>,
    <2.1424722, 0.1563897, 18.1462770>,
    <2.1489714, -0.0373094, 18.1554639>,
    <2.1419708, -0.0380226, 18.1462770>,
    <2.0690862, 0.2242635, 18.1370901>,
    <2.1023523, 0.2375253, 18.1370901>,
    <2.0655665, 0.2228828, 18.1279032>,
    <2.0970402, 0.2354306, 18.1279032>,
    <2.0025539, 0.1977398, 18.1370901>,
    <2.0026189, 0.1977872, 18.1279032>,
    <2.0358200, 0.2110017, 18.1370901>,
    <2.0340927, 0.2103350, 18.1279032>,
    <2.0024238, 0.1976451, 18.1554639>,
    <2.0761255, 0.2270249, 18.1554639>,
    <2.0024889, 0.1976925, 18.1462770>,
    <2.0392747, 0.2123350, 18.1554639>,
    <2.0726058, 0.2256442, 18.1462770>,
    <2.0375473, 0.2116683, 18.1462770>,
    <2.1129764, 0.2417148, 18.1554639>,
    <2.1076643, 0.2396200, 18.1462770>,
    <2.0812641, -0.1352278, 18.1573801>,
    <2.0039695, -0.1352623, 18.1573801>,
    <2.0426168, -0.1352450, 18.1573801>,
    <2.0040177, -0.1352721, 18.1564220>,
    <2.0788201, -0.1352379, 18.1564220>,
    <2.0414189, -0.1352550, 18.1564220>,
    <2.1585588, -0.1351933, 18.1573801>,
    <2.1536225, -0.1352037, 18.1564220>,
    <2.1199115, -0.1352106, 18.1573801>,
    <2.1162213, -0.1352208, 18.1564220>,
    <2.1684314, -0.1351726, 18.1592964>,
    <2.0861522, -0.1352076, 18.1592964>,
    <2.1634951, -0.1351829, 18.1583383>,
    <2.1272918, -0.1351901, 18.1592964>,
    <2.0837082, -0.1352177, 18.1583383>,
    <2.1236016, -0.1352003, 18.1583383>,
    <2.0038730, -0.1352427, 18.1592964>,
    <2.0450126, -0.1352251, 18.1592964>,
    <2.0039212, -0.1352525, 18.1583383>,
    <2.0438147, -0.1352351, 18.1583383>,
    <2.1592274, 0.0625961, 18.1573801>,
    <2.1588931, -0.0362986, 18.1573801>,
    <2.1542421, 0.0615957, 18.1564220>,
    <2.1539323, -0.0368040, 18.1564220>,
    <2.1598961, 0.2603854, 18.1573801>,
    <2.1548617, 0.2583951, 18.1564220>,
    <2.1595617, 0.1614907, 18.1573801>,
    <2.1545519, 0.1599954, 18.1564220>,
    <2.1699649, 0.2643662, 18.1592964>,
    <2.1691982, 0.0645968, 18.1592964>,
    <2.1649305, 0.2623758, 18.1583383>,
    <2.1695815, 0.1644815, 18.1592964>,
    <2.1642128, 0.0635964, 18.1583383>,
    <2.1645716, 0.1629861, 18.1583383>,
    <2.1688148, -0.0352879, 18.1592964>,
    <2.1638540, -0.0357933, 18.1583383>,
    <2.0811138, 0.2289817, 18.1573801>,
    <2.1205050, 0.2446836, 18.1573801>,
    <2.0786197, 0.2280033, 18.1564220>,
    <2.1167407, 0.2431992, 18.1564220>,
    <2.0023316, 0.1975780, 18.1573801>,
    <2.0023777, 0.1976115, 18.1564220>,
    <2.0417227, 0.2132798, 18.1573801>,
    <2.0404987, 0.2128074, 18.1564220>,
    <2.0022394, 0.1975108, 18.1592964>,
    <2.0861022, 0.2309385, 18.1592964>,
    <2.0022855, 0.1975444, 18.1583383>,
    <2.0441708, 0.2142247, 18.1592964>,
    <2.0836080, 0.2299601, 18.1583383>,
    <2.0429468, 0.2137523, 18.1583383>,
    <2.1280335, 0.2476524, 18.1592964>,
    <2.1242692, 0.2461680, 18.1583383>,
    <2.0872214, -0.1352037, 18.2324892>,
    <2.0038724, -0.1352425, 18.2344341>,
    <2.0455456, -0.1352229, 18.2333227>,
    <2.0038727, -0.1352426, 18.1968653>,
    <2.0861681, -0.1352075, 18.1968653>,
    <2.0450204, -0.1352251, 18.1968653>,
    <2.1705857, -0.1351680, 18.2322113>,
    <2.1684634, -0.1351725, 18.1968653>,
    <2.1289022, -0.1351856, 18.2322113>,
    <2.1273157, -0.1351900, 18.1968653>,
    <2.1894619, -0.1351283, 18.2873438>,
    <2.0965801, -0.1351677, 18.2890109>,
    <2.1768884, -0.1351548, 18.2631118>,
    <2.1430133, -0.1351465, 18.2873438>,
    <2.0903496, -0.1351924, 18.2642232>,
    <2.1336139, -0.1351725, 18.2631118>,
    <2.0038718, -0.1352424, 18.3095719>,
    <2.0501774, -0.1351952, 18.2940122>,
    <2.0038721, -0.1352425, 18.2720030>,
    <2.0471057, -0.1352164, 18.2675574>,
    <2.1713738, 0.0650334, 18.2322113>,
    <2.1709797, -0.0350673, 18.2322113>,
    <2.1692305, 0.0646033, 18.1968653>,
    <2.1688469, -0.0352846, 18.1968653>,
    <2.1721619, 0.2652348, 18.2322113>,
    <2.1699975, 0.2643791, 18.1968653>,
    <2.1717678, 0.1651341, 18.2322113>,
    <2.1696140, 0.1644912, 18.1968653>,
    <2.1914132, 0.2728459, 18.2873438>,
    <2.1904376, 0.0688588, 18.2873438>,
    <2.1785899, 0.2677761, 18.2631118>,
    <2.1909254, 0.1708524, 18.2873438>,
    <2.1777391, 0.0663107, 18.2631118>,
    <2.1781645, 0.1670434, 18.2631118>,
    <2.1899498, -0.0331347, 18.2873438>,
    <2.1773138, -0.0344220, 18.2631118>,
    <2.0871930, 0.2313673, 18.2324892>,
    <2.1296763, 0.2483001, 18.2322113>,
    <2.0861183, 0.2309449, 18.1968653>,
    <2.1280579, 0.2476620, 18.1968653>,
    <2.0022388, 0.1975104, 18.2344341>,
    <2.0022391, 0.1975106, 18.1968653>,
    <2.0447147, 0.2144379, 18.2333227>,
    <2.0441787, 0.2142277, 18.1968653>,
    <2.0022382, 0.1975100, 18.3095719>,
    <2.0967428, 0.2351175, 18.2890109>,
    <2.0022385, 0.1975102, 18.2720030>,
    <2.0494442, 0.2162800, 18.2940122>,
    <2.0903849, 0.2326218, 18.2642232>,
    <2.0463069, 0.2150625, 18.2675574>,
    <2.1440707, 0.2539764, 18.2873438>,
    <2.1344825, 0.2501954, 18.2631118>,
    <2.1194133, -0.1350703, 18.3131904>,
    <2.0032176, -0.1351096, 18.3135798>,
    <2.0613154, -0.1350899, 18.3133573>,
    <2.0035447, -0.1351760, 18.3115759>,
    <2.1069400, -0.1351239, 18.3037960>,
    <2.0552372, -0.1351489, 18.3071303>,
    <2.2356097, -0.1350312, 18.3131347>,
    <2.2103965, -0.1350842, 18.3026846>,
    <2.1775114, -0.1350507, 18.3131347>,
    <2.1586631, -0.1351030, 18.3026846>,
    <2.2825423, -0.1349324, 18.3353648>,
    <2.1426356, -0.1349714, 18.3340315>,
    <2.2610191, -0.1349777, 18.3226946>,
    <2.2125963, -0.1349534, 18.3353648>,
    <2.1319840, -0.1350164, 18.3218058>,
    <2.1965064, -0.1349980, 18.3226946>,
    <2.0025635, -0.1349767, 18.3175878>,
    <2.0726458, -0.1349834, 18.3300317>,
    <2.0028906, -0.1350431, 18.3155838>,
    <2.0674422, -0.1350307, 18.3191392>,
    <2.2370437, 0.0782110, 18.3131347>,
    <2.2363267, -0.0284101, 18.3131347>,
    <2.2115801, 0.0731013, 18.3026846>,
    <2.2109883, -0.0309915, 18.3026846>,
    <2.2384778, 0.2914531, 18.3131347>,
    <2.2127637, 0.2812869, 18.3026846>,
    <2.2377608, 0.1848321, 18.3131347>,
    <2.2121719, 0.1771941, 18.3026846>,
    <2.2863429, 0.3103769, 18.3353648>,
    <2.2844426, 0.0877222, 18.3353648>,
    <2.2643920, 0.3016985, 18.3226946>,
    <2.2853927, 0.1990495, 18.3353648>,
    <2.2627056, 0.0833604, 18.3226946>,
    <2.2635488, 0.1925294, 18.3226946>,
    <2.2834925, -0.0236051, 18.3353648>,
    <2.2618623, -0.0258087, 18.3226946>,
    <2.1200451, 0.2442537, 18.3131904>,
    <2.1792614, 0.2678534, 18.3131347>,
    <2.1073154, 0.2392633, 18.3037960>,
    <2.1600347, 0.2602716, 18.3026846>,
    <2.0016131, 0.1970547, 18.3135798>,
    <2.0019257, 0.1972823, 18.3115759>,
    <2.0608290, 0.2206541, 18.3133573>,
    <2.0546157, 0.2182693, 18.3071303>,
    <2.0009879, 0.1965994, 18.3175878>,
    <2.1437445, 0.2535457, 18.3340315>,
    <2.0013005, 0.1968271, 18.3155838>,
    <2.0724104, 0.2251047, 18.3300317>,
    <2.1328742, 0.2492831, 18.3218058>,
    <2.0670920, 0.2230585, 18.3191392>,
    <2.2150506, 0.2819664, 18.3353648>,
    <2.1986378, 0.2754942, 18.3226946>,
    <2.1531110, -0.1349307, 18.3800376>,
    <2.0025322, -0.1349704, 18.3784821>,
    <2.0778228, -0.1349508, 18.3793709>,
    <2.0025479, -0.1349735, 18.3480349>,
    <2.1493516, -0.1349447, 18.3542569>,
    <2.0759546, -0.1349601, 18.3515903>,
    <2.3036751, -0.1348880, 18.3802598>,
    <2.2960969, -0.1349039, 18.3551457>,
    <2.2283943, -0.1349096, 18.3802598>,
    <2.2227291, -0.1349253, 18.3551457>,
    <2.3088707, -0.1348770, 18.4393764>,
    <2.1556858, -0.1349205, 18.4393764>,
    <2.3072690, -0.1348804, 18.4089292>,
    <2.2322783, -0.1348988, 18.4393764>,
    <2.1548928, -0.1349238, 18.4089292>,
    <2.2310809, -0.1349021, 18.4089292>,
    <2.0025009, -0.1349640, 18.4393764>,
    <2.0790934, -0.1349423, 18.4393764>,
    <2.0025166, -0.1349672, 18.4089292>,
    <2.0787047, -0.1349455, 18.4089292>,
    <2.3057853, 0.0920049, 18.3802598>,
    <2.3047302, -0.0214415, 18.3802598>,
    <2.2981319, 0.0904692, 18.3551457>,
    <2.2971144, -0.0222174, 18.3551457>,
    <2.3078956, 0.3188978, 18.3802598>,
    <2.3001668, 0.3158422, 18.3551457>,
    <2.3068404, 0.2054514, 18.3802598>,
    <2.2991493, 0.2031557, 18.3551457>,
    <2.3131944, 0.3209928, 18.4393764>,
    <2.3110326, 0.0930579, 18.4393764>,
    <2.3115608, 0.3203469, 18.4089292>,
    <2.3121135, 0.2070253, 18.4393764>,
    <2.3094149, 0.0927333, 18.4089292>,
    <2.3104879, 0.2065401, 18.4089292>,
    <2.3099517, -0.0209096, 18.4393764>,
    <2.3083420, -0.0210736, 18.4089292>,
    <2.1544338, 0.2577428, 18.3800376>,
    <2.2311658, 0.2883212, 18.3802598>,
    <2.1505978, 0.2562357, 18.3542569>,
    <2.2253870, 0.2860423, 18.3551457>,
    <2.0009580, 0.1965776, 18.3784821>,
    <2.0009730, 0.1965885, 18.3480349>,
    <2.0776971, 0.2271611, 18.3793709>,
    <2.0757900, 0.2264155, 18.3515903>,
    <2.0009281, 0.1965558, 18.4393764>,
    <2.1570613, 0.2587743, 18.4393764>,
    <2.0009431, 0.1965667, 18.4089292>,
    <2.0789947, 0.2276651, 18.4393764>,
    <2.1562520, 0.2584568, 18.4089292>,
    <2.0785975, 0.2275118, 18.4089292>,
    <2.2351278, 0.2898835, 18.4393764>,
    <2.2339064, 0.2894019, 18.4089292>,
    <2.1641424, -0.1348856, 18.4393764>,
    <2.0023340, -0.1349301, 18.4393764>,
    <2.0832382, -0.1349079, 18.4393764>,
    <2.0024175, -0.1349471, 18.4393764>,
    <2.1599141, -0.1349031, 18.4393764>,
    <2.0811658, -0.1349251, 18.4393764>,
    <2.3259508, -0.1348411, 18.4393764>,
    <2.3174108, -0.1348591, 18.4393764>,
    <2.2450466, -0.1348634, 18.4393764>,
    <2.2386625, -0.1348811, 18.4393764>,
    <2.3430309, -0.1348052, 18.4393764>,
    <2.1725990, -0.1348507, 18.4393764>,
    <2.3344909, -0.1348231, 18.4393764>,
    <2.2578150, -0.1348279, 18.4393764>,
    <2.1683707, -0.1348682, 18.4393764>,
    <2.2514308, -0.1348456, 18.4393764>,
    <2.0021672, -0.1348962, 18.4393764>,
    <2.0873831, -0.1348735, 18.4393764>,
    <2.0022506, -0.1349132, 18.4393764>,
    <2.0853107, -0.1348907, 18.4393764>,
    <2.3282823, 0.0965193, 18.4393764>,
    <2.3271166, -0.0191609, 18.4393764>,
    <2.3196574, 0.0947886, 18.4393764>,
    <2.3185341, -0.0200353, 18.4393764>,
    <2.3306138, 0.3278796, 18.4393764>,
    <2.3219041, 0.3244362, 18.4393764>,
    <2.3294481, 0.2121994, 18.4393764>,
    <2.3207808, 0.2096124, 18.4393764>,
    <2.3480332, 0.3347665, 18.4393764>,
    <2.3455321, 0.0999807, 18.4393764>,
    <2.3393235, 0.3313230, 18.4393764>,
    <2.3467826, 0.2173736, 18.4393764>,
    <2.3369072, 0.0982500, 18.4393764>,
    <2.3381154, 0.2147865, 18.4393764>,
    <2.3442815, -0.0174122, 18.4393764>,
    <2.3356990, -0.0182866, 18.4393764>,
    <2.1656912, 0.2621597, 18.4393764>,
    <2.2481525, 0.2950196, 18.4393764>,
    <2.1613762, 0.2604670, 18.4393764>,
    <2.2416402, 0.2924516, 18.4393764>,
    <2.0007686, 0.1964397, 18.4393764>,
    <2.0008484, 0.1964978, 18.4393764>,
    <2.0832299, 0.2292997, 18.4393764>,
    <2.0811123, 0.2284824, 18.4393764>,
    <2.0006092, 0.1963236, 18.4393764>,
    <2.1743212, 0.2655450, 18.4393764>,
    <2.0006889, 0.1963816, 18.4393764>,
    <2.0874652, 0.2309343, 18.4393764>,
    <2.1700062, 0.2638523, 18.4393764>,
    <2.0853476, 0.2301170, 18.4393764>,
    <2.2611772, 0.3001557, 18.4393764>,
    <2.2546649, 0.2975877, 18.4393764>,
    <2.1725990, -0.1348507, 18.4905874>,
    <2.0021672, -0.1348962, 18.4905874>,
    <2.0873831, -0.1348735, 18.4905874>,
    <2.0021672, -0.1348962, 18.4649819>,
    <2.1725990, -0.1348507, 18.4649819>,
    <2.0873831, -0.1348735, 18.4649819>,
    <2.3430309, -0.1348052, 18.4905874>,
    <2.3430309, -0.1348052, 18.4649819>,
    <2.2578150, -0.1348279, 18.4905874>,
    <2.2578150, -0.1348279, 18.4649819>,
    <2.3430309, -0.1348052, 18.5161929>,
    <2.1725990, -0.1348507, 18.5161929>,
    <2.2578150, -0.1348279, 18.5161929>,
    <2.0021672, -0.1348962, 18.5161929>,
    <2.0873831, -0.1348735, 18.5161929>,
    <2.3455321, 0.0999807, 18.4905874>,
    <2.3442815, -0.0174123, 18.4905874>,
    <2.3455321, 0.0999807, 18.4649819>,
    <2.3442815, -0.0174122, 18.4649819>,
    <2.3480332, 0.3347665, 18.4905874>,
    <2.3480332, 0.3347665, 18.4649819>,
    <2.3467826, 0.2173736, 18.4905874>,
    <2.3467826, 0.2173736, 18.4649819>,
    <2.3480332, 0.3347665, 18.5161929>,
    <2.3455321, 0.0999807, 18.5161929>,
    <2.3467826, 0.2173736, 18.5161929>,
    <2.3442815, -0.0174122, 18.5161929>,
    <2.1743212, 0.2655450, 18.4905874>,
    <2.2611772, 0.3001557, 18.4905874>,
    <2.1743212, 0.2655450, 18.4649819>,
    <2.2611772, 0.3001557, 18.4649819>,
    <2.0006092, 0.1963236, 18.4905874>,
    <2.0006092, 0.1963236, 18.4649819>,
    <2.0874652, 0.2309343, 18.4905874>,
    <2.0874652, 0.2309343, 18.4649819>,
    <2.0006092, 0.1963236, 18.5161929>,
    <2.1743212, 0.2655450, 18.5161929>,
    <2.0874652, 0.2309343, 18.5161929>,
    <2.2611772, 0.3001557, 18.5161929>,
    <2.0013882, 0.0307137, 18.4905874>,
    <2.0021672, -0.1348962, 18.4905874>,
    <2.0013882, 0.0307137, 18.4393764>,
    <2.0017777, -0.0520913, 18.4905874>,
    <2.0021672, -0.1348962, 18.4649819>,
    <2.0017777, -0.0520913, 18.4393764>,
    <2.0013882, 0.0307137, 18.4649819>,
    <2.0017777, -0.0520913, 18.4649819>,
    <2.0006092, 0.1963236, 18.4905874>,
    <2.0009987, 0.1135186, 18.4393764>,
    <2.0006092, 0.1963236, 18.4649819>,
    <2.0009987, 0.1135186, 18.4905874>,
    <2.0009987, 0.1135186, 18.4649819>,
    <2.0013882, 0.0307137, 18.5417983>,
    <2.0006092, 0.1963236, 18.5161929>,
    <2.0009987, 0.1135186, 18.5417983>,
    <2.0013882, 0.0307137, 18.5161929>,
    <2.0009987, 0.1135186, 18.5161929>,
    <2.0017777, -0.0520913, 18.5417983>,
    <2.0021672, -0.1348962, 18.5161929>,
    <2.0017777, -0.0520913, 18.5161929>,
    <2.0015513, 0.0307548, 18.4393764>,
    <2.0017145, 0.0307959, 18.4393764>,
    <2.0016329, 0.0307754, 18.4393764>,
    <2.0021077, -0.0520840, 18.4393764>,
    <2.0019427, -0.0520877, 18.4393764>,
    <2.0020252, -0.0520859, 18.4393764>,
    <2.0013882, 0.0307137, 18.4393764>,
    <2.0017777, -0.0520913, 18.4393764>,
    <2.0014697, 0.0307342, 18.4393764>,
    <2.0018602, -0.0520895, 18.4393764>,
    <2.0009987, 0.1135186, 18.4393764>,
    <2.0011600, 0.1135972, 18.4393764>,
    <2.0010793, 0.1135579, 18.4393764>,
    <2.0013213, 0.1136759, 18.4393764>,
    <2.0012406, 0.1136366, 18.4393764>,
    <2.0017451, 0.0308036, 18.3784821>,
    <2.0025322, -0.1349704, 18.3784821>,
    <2.0017757, 0.0308113, 18.3175878>,
    <2.0021387, -0.0520834, 18.3784821>,
    <2.0025479, -0.1349735, 18.3480349>,
    <2.0021696, -0.0520827, 18.3175878>,
    <2.0017604, 0.0308075, 18.3480349>,
    <2.0021541, -0.0520830, 18.3480349>,
    <2.0009580, 0.1965776, 18.3784821>,
    <2.0013818, 0.1137054, 18.3175878>,
    <2.0009730, 0.1965885, 18.3480349>,
    <2.0013516, 0.1136906, 18.3784821>,
    <2.0013667, 0.1136980, 18.3480349>,
    <2.0017145, 0.0307959, 18.4393764>,
    <2.0009431, 0.1965667, 18.4089292>,
    <2.0013213, 0.1136759, 18.4393764>,
    <2.0017298, 0.0307998, 18.4089292>,
    <2.0013364, 0.1136833, 18.4089292>,
    <2.0021077, -0.0520840, 18.4393764>,
    <2.0025166, -0.1349672, 18.4089292>,
    <2.0021232, -0.0520837, 18.4089292>,
    <2.0024154, 0.0309726, 18.3135798>,
    <2.0030550, 0.0311338, 18.3095719>,
    <2.0027352, 0.0310532, 18.3115759>,
    <2.0034634, -0.0520543, 18.3095719>,
    <2.0028165, -0.0520685, 18.3135798>,
    <2.0031399, -0.0520614, 18.3115759>,
    <2.0017757, 0.0308113, 18.3175878>,
    <2.0021696, -0.0520827, 18.3175878>,
    <2.0020955, 0.0308920, 18.3155838>,
    <2.0024931, -0.0520756, 18.3155838>,
    <2.0013818, 0.1137054, 18.3175878>,
    <2.0020142, 0.1140136, 18.3135798>,
    <2.0016980, 0.1138595, 18.3155838>,
    <2.0026466, 0.1143219, 18.3095719>,
    <2.0023304, 0.1141678, 18.3115759>,
    <2.0030556, 0.0311339, 18.2344341>,
    <2.0038724, -0.1352425, 18.2344341>,
    <2.0030562, 0.0311341, 18.1592964>,
    <2.0034640, -0.0520543, 18.2344341>,
    <2.0038727, -0.1352426, 18.1968653>,
    <2.0034646, -0.0520543, 18.1592964>,
    <2.0030559, 0.0311340, 18.1968653>,
    <2.0034643, -0.0520543, 18.1968653>,
    <2.0022388, 0.1975104, 18.2344341>,
    <2.0026478, 0.1143225, 18.1592964>,
    <2.0022391, 0.1975106, 18.1968653>,
    <2.0026472, 0.1143222, 18.2344341>,
    <2.0026475, 0.1143223, 18.1968653>,
    <2.0030550, 0.0311338, 18.3095719>,
    <2.0022385, 0.1975102, 18.2720030>,
    <2.0026466, 0.1143219, 18.3095719>,
    <2.0030553, 0.0311339, 18.2720030>,
    <2.0026469, 0.1143220, 18.2720030>,
    <2.0034634, -0.0520543, 18.3095719>,
    <2.0038721, -0.1352425, 18.2720030>,
    <2.0034637, -0.0520543, 18.2720030>,
    <2.0031505, 0.0311579, 18.1573801>,
    <2.0032449, 0.0311816, 18.1554639>,
    <2.0031977, 0.0311697, 18.1564220>,
    <2.0036554, -0.0520501, 18.1554639>,
    <2.0035600, -0.0520522, 18.1573801>,
    <2.0036077, -0.0520512, 18.1564220>,
    <2.0030562, 0.0311341, 18.1592964>,
    <2.0034646, -0.0520543, 18.1592964>,
    <2.0031034, 0.0311460, 18.1583383>,
    <2.0035123, -0.0520532, 18.1583383>,
    <2.0026478, 0.1143225, 18.1592964>,
    <2.0027411, 0.1143679, 18.1573801>,
    <2.0026945, 0.1143452, 18.1583383>,
    <2.0028343, 0.1144134, 18.1554639>,
    <2.0027877, 0.1143906, 18.1564220>,
    <2.0034357, 0.0312297, 18.1389725>,
    <2.0042673, -0.1353227, 18.1386133>,
    <2.0035695, 0.0312634, 18.1258340>,
    <2.0038505, -0.0520468, 18.1388528>,
    <2.0043680, -0.1353432, 18.1301880>,
    <2.0039963, -0.0520483, 18.1251156>,
    <2.0035158, 0.0312499, 18.1316249>,
    <2.0039378, -0.0520477, 18.1311460>,
    <2.0026163, 0.1977853, 18.1386133>,
    <2.0031671, 0.1145813, 18.1251156>,
    <2.0027125, 0.1978554, 18.1301880>,
    <2.0030250, 0.1145072, 18.1388528>,
    <2.0031101, 0.1145516, 18.1311460>,
    <2.0032449, 0.0311816, 18.1554639>,
    <2.0025200, 0.1977152, 18.1470386>,
    <2.0028343, 0.1144134, 18.1554639>,
    <2.0033433, 0.0312064, 18.1470386>,
    <2.0029317, 0.1144608, 18.1470386>,
    <2.0036554, -0.0520501, 18.1554639>,
    <2.0041666, -0.1353023, 18.1470386>,
    <2.0037550, -0.0520479, 18.1470386>,
    <2.0035688, 0.0312633, 18.1205987>,
    <2.0035824, 0.0312667, 18.1224380>,
    <2.0039851, -0.0520438, 18.1204790>,
    <2.0040052, -0.0520462, 18.1219591>,
    <2.0035111, 0.0312487, 18.1187163>,
    <2.0039246, -0.0520442, 18.1187163>,
    <2.0035430, 0.0312568, 18.1194779>,
    <2.0039569, -0.0520435, 18.1194779>,
    <2.0030975, 0.1145417, 18.1187163>,
    <2.0031566, 0.1145714, 18.1204790>,
    <2.0031291, 0.1145570, 18.1194779>,
    <2.0031759, 0.1145837, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0005941, 0.9999662, 0.0082020>,
    <-0.0005941, 0.9999704, 0.0076758>,
    <-0.0005795, 0.9999701, 0.0077076>,
    <-0.0005795, 0.9999661, 0.0082176>,
    <-0.0005795, 0.9999617, 0.0087276>,
    <-0.0005941, 0.9999617, 0.0087283>,
    <-0.0005941, 0.9999617, 0.0087283>,
    <-0.0006097, 0.9999617, 0.0087289>,
    <-0.0006097, 0.9999663, 0.0081855>,
    <-0.0006097, 0.9999663, 0.0081855>,
    <-0.0006097, 0.9999706, 0.0076420>,
    <-0.0005941, 0.9999743, 0.0071496>,
    <-0.0005795, 0.9999739, 0.0071975>,
    <-0.0006097, 0.9999706, 0.0076420>,
    <-0.0006097, 0.9999746, 0.0070986>,
    <-0.0006097, 0.9999746, 0.0070986>,
    <-0.0006097, 0.9999783, 0.0065551>,
    <-0.0005941, 0.9999779, 0.0066234>,
    <-0.0005941, 0.9999779, 0.0066234>,
    <-0.0005795, 0.9999775, 0.0066875>,
    <-0.0005658, 0.9999736, 0.0072426>,
    <-0.0005658, 0.9999699, 0.0077374>,
    <-0.0005795, 0.9999775, 0.0066875>,
    <-0.0005658, 0.9999771, 0.0067477>,
    <-0.0005658, 0.9999771, 0.0067477>,
    <-0.0005529, 0.9999767, 0.0068045>,
    <-0.0005529, 0.9999733, 0.0072850>,
    <-0.0005529, 0.9999733, 0.0072850>,
    <-0.0005529, 0.9999697, 0.0077655>,
    <-0.0005658, 0.9999660, 0.0082322>,
    <-0.0005529, 0.9999697, 0.0077655>,
    <-0.0005529, 0.9999658, 0.0082460>,
    <-0.0005529, 0.9999658, 0.0082460>,
    <-0.0005528, 0.9999618, 0.0087265>,
    <-0.0005658, 0.9999618, 0.0087270>,
    <-0.0005658, 0.9999618, 0.0087270>,
    <-0.0005795, 0.9999617, 0.0087276>,
    <-0.2212575, 0.0002283, -0.9752154>,
    <-0.2202436, 0.0002273, -0.9754449>,
    <-0.2202508, 0.0002652, -0.9754432>,
    <-0.2212612, 0.0002664, -0.9752145>,
    <-0.2222806, 0.0002676, -0.9749827>,
    <-0.2222806, 0.0002294, -0.9749827>,
    <-0.2222806, 0.0002294, -0.9749827>,
    <-0.2222805, 0.0001908, -0.9749827>,
    <-0.2212538, 0.0001900, -0.9752162>,
    <-0.2212538, 0.0001900, -0.9752162>,
    <-0.2202363, 0.0001891, -0.9754465>,
    <-0.2192387, 0.0002262, -0.9756712>,
    <-0.2192494, 0.0002640, -0.9756688>,
    <-0.2202363, 0.0001891, -0.9754465>,
    <-0.2192279, 0.0001882, -0.9756737>,
    <-0.2192279, 0.0001882, -0.9756737>,
    <-0.2182285, 0.0001874, -0.9758977>,
    <-0.2182427, 0.0002252, -0.9758945>,
    <-0.2182427, 0.0002252, -0.9758945>,
    <-0.2182569, 0.0002628, -0.9758913>,
    <-0.2192601, 0.0003014, -0.9756664>,
    <-0.2202580, 0.0003028, -0.9754416>,
    <-0.2182569, 0.0002628, -0.9758913>,
    <-0.2182709, 0.0003001, -0.9758882>,
    <-0.2182709, 0.0003001, -0.9758882>,
    <-0.2182849, 0.0003371, -0.9758850>,
    <-0.2192707, 0.0003386, -0.9756640>,
    <-0.2192707, 0.0003386, -0.9756640>,
    <-0.2202652, 0.0003402, -0.9754400>,
    <-0.2212649, 0.0003042, -0.9752137>,
    <-0.2202652, 0.0003402, -0.9754400>,
    <-0.2212685, 0.0003417, -0.9752129>,
    <-0.2212685, 0.0003417, -0.9752129>,
    <-0.2222808, 0.0003433, -0.9749826>,
    <-0.2222807, 0.0003056, -0.9749827>,
    <-0.2222807, 0.0003056, -0.9749827>,
    <-0.2222806, 0.0002676, -0.9749827>,
    <0.3703333, -0.9287990, 0.0136272>,
    <0.3703351, -0.9288035, 0.0132634>,
    <0.3703266, -0.9288072, 0.0132415>,
    <0.3703249, -0.9288028, 0.0135941>,
    <0.3703231, -0.9287983, 0.0139467>,
    <0.3703314, -0.9287943, 0.0139910>,
    <0.3703314, -0.9287943, 0.0139910>,
    <0.3703403, -0.9287901, 0.0140381>,
    <0.3703422, -0.9287949, 0.0136625>,
    <0.3703422, -0.9287949, 0.0136625>,
    <0.3703441, -0.9287996, 0.0132868>,
    <0.3703368, -0.9288080, 0.0128997>,
    <0.3703283, -0.9288115, 0.0128889>,
    <0.3703441, -0.9287996, 0.0132868>,
    <0.3703459, -0.9288042, 0.0129111>,
    <0.3703459, -0.9288042, 0.0129111>,
    <0.3703477, -0.9288086, 0.0125354>,
    <0.3703385, -0.9288123, 0.0125359>,
    <0.3703385, -0.9288123, 0.0125359>,
    <0.3703300, -0.9288157, 0.0125363>,
    <0.3703203, -0.9288148, 0.0128788>,
    <0.3703187, -0.9288107, 0.0132209>,
    <0.3703300, -0.9288157, 0.0125363>,
    <0.3703219, -0.9288189, 0.0125368>,
    <0.3703219, -0.9288189, 0.0125368>,
    <0.3703144, -0.9288219, 0.0125372>,
    <0.3703128, -0.9288180, 0.0128693>,
    <0.3703128, -0.9288180, 0.0128693>,
    <0.3703112, -0.9288139, 0.0132015>,
    <0.3703170, -0.9288064, 0.0135630>,
    <0.3703112, -0.9288139, 0.0132015>,
    <0.3703096, -0.9288098, 0.0135337>,
    <0.3703096, -0.9288098, 0.0135337>,
    <0.3703079, -0.9288056, 0.0138658>,
    <0.3703152, -0.9288021, 0.0139051>,
    <0.3703152, -0.9288021, 0.0139051>,
    <0.3703231, -0.9287983, 0.0139467>,
    <0.0005282, -0.9999988, 0.0014301>,
    <0.0005282, -0.9999989, 0.0013517>,
    <0.0005061, -0.9999989, 0.0013600>,
    <0.0005061, -0.9999988, 0.0014341>,
    <0.0005061, -0.9999987, 0.0015083>,
    <0.0005282, -0.9999987, 0.0015084>,
    <0.0005282, -0.9999987, 0.0015084>,
    <0.0005529, -0.9999987, 0.0015086>,
    <0.0005529, -0.9999988, 0.0014255>,
    <0.0005529, -0.9999988, 0.0014255>,
    <0.0005529, -0.9999989, 0.0013425>,
    <0.0005282, -0.9999990, 0.0012734>,
    <0.0005061, -0.9999990, 0.0012859>,
    <0.0005529, -0.9999989, 0.0013425>,
    <0.0005529, -0.9999991, 0.0012594>,
    <0.0005529, -0.9999991, 0.0012594>,
    <0.0005529, -0.9999992, 0.0011763>,
    <0.0005282, -0.9999991, 0.0011951>,
    <0.0005282, -0.9999991, 0.0011951>,
    <0.0005061, -0.9999991, 0.0012118>,
    <0.0004863, -0.9999990, 0.0012971>,
    <0.0004863, -0.9999989, 0.0013674>,
    <0.0005061, -0.9999991, 0.0012118>,
    <0.0004863, -0.9999991, 0.0012268>,
    <0.0004863, -0.9999991, 0.0012268>,
    <0.0004684, -0.9999991, 0.0012403>,
    <0.0004684, -0.9999990, 0.0013072>,
    <0.0004684, -0.9999990, 0.0013072>,
    <0.0004684, -0.9999989, 0.0013742>,
    <0.0004863, -0.9999988, 0.0014378>,
    <0.0004684, -0.9999989, 0.0013742>,
    <0.0004684, -0.9999989, 0.0014411>,
    <0.0004684, -0.9999989, 0.0014411>,
    <0.0004684, -0.9999988, 0.0015080>,
    <0.0004863, -0.9999987, 0.0015081>,
    <0.0004863, -0.9999987, 0.0015081>,
    <0.0005061, -0.9999987, 0.0015083>,
    <0.7954427, -0.0015067, -0.6060269>,
    <0.7940541, -0.0015041, -0.6078452>,
    <0.7940741, -0.0017779, -0.6078184>,
    <0.7954526, -0.0017810, -0.6060132>,
    <0.7968318, -0.0017841, -0.6041985>,
    <0.7968320, -0.0015094, -0.6041991>,
    <0.7968320, -0.0015094, -0.6041991>,
    <0.7968321, -0.0012306, -0.6041996>,
    <0.7954326, -0.0012284, -0.6060408>,
    <0.7954326, -0.0012284, -0.6060408>,
    <0.7940338, -0.0012263, -0.6078724>,
    <0.7926662, -0.0015015, -0.6096540>,
    <0.7926962, -0.0017749, -0.6096143>,
    <0.7940338, -0.0012263, -0.6078724>,
    <0.7926357, -0.0012241, -0.6096942>,
    <0.7926357, -0.0012241, -0.6096942>,
    <0.7912384, -0.0012219, -0.6115065>,
    <0.7912791, -0.0014988, -0.6114533>,
    <0.7912791, -0.0014988, -0.6114533>,
    <0.7913191, -0.0017718, -0.6114008>,
    <0.7927257, -0.0020443, -0.6095751>,
    <0.7940937, -0.0020479, -0.6077919>,
    <0.7913191, -0.0017718, -0.6114008>,
    <0.7913585, -0.0020408, -0.6113490>,
    <0.7913585, -0.0020408, -0.6113490>,
    <0.7913972, -0.0023060, -0.6112979>,
    <0.7927547, -0.0023100, -0.6095364>,
    <0.7927547, -0.0023100, -0.6095364>,
    <0.7941129, -0.0023139, -0.6077658>,
    <0.7954623, -0.0020514, -0.6059996>,
    <0.7941129, -0.0023139, -0.6077658>,
    <0.7954718, -0.0023179, -0.6059861>,
    <0.7954718, -0.0023179, -0.6059861>,
    <0.7968314, -0.0023219, -0.6041973>,
    <0.7968316, -0.0020549, -0.6041979>,
    <0.7968316, -0.0020549, -0.6041979>,
    <0.7968318, -0.0017841, -0.6041985>,
    <-0.3703280, 0.9288981, 0.0023301>,
    <-0.3703280, 0.9288982, 0.0022759>,
    <-0.3703151, 0.9289034, 0.0022702>,
    <-0.3703151, 0.9289033, 0.0023215>,
    <-0.3703151, 0.9289032, 0.0023727>,
    <-0.3703280, 0.9288980, 0.0023843>,
    <-0.3703280, 0.9288980, 0.0023843>,
    <-0.3703424, 0.9288922, 0.0023972>,
    <-0.3703425, 0.9288923, 0.0023398>,
    <-0.3703425, 0.9288923, 0.0023398>,
    <-0.3703425, 0.9288925, 0.0022823>,
    <-0.3703281, 0.9288984, 0.0022218>,
    <-0.3703152, 0.9289035, 0.0022190>,
    <-0.3703425, 0.9288925, 0.0022823>,
    <-0.3703426, 0.9288926, 0.0022249>,
    <-0.3703426, 0.9288926, 0.0022249>,
    <-0.3703426, 0.9288927, 0.0021675>,
    <-0.3703281, 0.9288985, 0.0021676>,
    <-0.3703281, 0.9288985, 0.0021676>,
    <-0.3703152, 0.9289036, 0.0021677>,
    <-0.3703036, 0.9289081, 0.0022164>,
    <-0.3703036, 0.9289080, 0.0022651>,
    <-0.3703152, 0.9289036, 0.0021677>,
    <-0.3703036, 0.9289082, 0.0021678>,
    <-0.3703036, 0.9289082, 0.0021678>,
    <-0.3702932, 0.9289124, 0.0021679>,
    <-0.3702931, 0.9289123, 0.0022142>,
    <-0.3702931, 0.9289123, 0.0022142>,
    <-0.3702931, 0.9289122, 0.0022604>,
    <-0.3703035, 0.9289079, 0.0023137>,
    <-0.3702931, 0.9289122, 0.0022604>,
    <-0.3702931, 0.9289121, 0.0023067>,
    <-0.3702931, 0.9289121, 0.0023067>,
    <-0.3702930, 0.9289120, 0.0023530>,
    <-0.3703035, 0.9289078, 0.0023623>,
    <-0.3703035, 0.9289078, 0.0023623>,
    <-0.3703151, 0.9289032, 0.0023727>,
    <0.0004568, -0.9999518, 0.0098056>,
    <0.0004568, -0.9999560, 0.0093662>,
    <0.0004459, -0.9999558, 0.0093940>,
    <0.0004459, -0.9999517, 0.0098193>,
    <0.0004459, -0.9999474, 0.0102445>,
    <0.0004568, -0.9999474, 0.0102451>,
    <0.0004568, -0.9999474, 0.0102451>,
    <0.0004684, -0.9999474, 0.0102456>,
    <0.0004684, -0.9999520, 0.0097911>,
    <0.0004684, -0.9999520, 0.0097911>,
    <0.0004684, -0.9999563, 0.0093365>,
    <0.0004568, -0.9999601, 0.0089268>,
    <0.0004459, -0.9999597, 0.0089688>,
    <0.0004684, -0.9999563, 0.0093365>,
    <0.0004684, -0.9999604, 0.0088820>,
    <0.0004684, -0.9999604, 0.0088820>,
    <0.0004684, -0.9999644, 0.0084274>,
    <0.0004568, -0.9999639, 0.0084874>,
    <0.0004568, -0.9999639, 0.0084874>,
    <0.0004459, -0.9999634, 0.0085435>,
    <0.0004357, -0.9999593, 0.0090081>,
    <0.0004357, -0.9999555, 0.0094201>,
    <0.0004459, -0.9999634, 0.0085435>,
    <0.0004357, -0.9999630, 0.0085961>,
    <0.0004357, -0.9999630, 0.0085961>,
    <0.0004261, -0.9999625, 0.0086456>,
    <0.0004261, -0.9999590, 0.0090451>,
    <0.0004261, -0.9999590, 0.0090451>,
    <0.0004261, -0.9999553, 0.0094445>,
    <0.0004357, -0.9999516, 0.0098320>,
    <0.0004261, -0.9999553, 0.0094445>,
    <0.0004261, -0.9999515, 0.0098440>,
    <0.0004261, -0.9999515, 0.0098440>,
    <0.0004261, -0.9999474, 0.0102435>,
    <0.0004357, -0.9999474, 0.0102440>,
    <0.0004357, -0.9999474, 0.0102440>,
    <0.0004459, -0.9999474, 0.0102445>,
    <0.1896912, -0.0005972, -0.9818436>,
    <0.1888483, -0.0005946, -0.9820061>,
    <0.1888567, -0.0006384, -0.9820044>,
    <0.1896955, -0.0006413, -0.9818428>,
    <0.1905416, -0.0006441, -0.9816789>,
    <0.1905415, -0.0005999, -0.9816790>,
    <0.1905415, -0.0005999, -0.9816790>,
    <0.1905414, -0.0005552, -0.9816790>,
    <0.1896868, -0.0005527, -0.9818445>,
    <0.1896868, -0.0005527, -0.9818445>,
    <0.1888397, -0.0005503, -0.9820078>,
    <0.1880126, -0.0005919, -0.9821664>,
    <0.1880252, -0.0006356, -0.9821640>,
    <0.1888397, -0.0005503, -0.9820078>,
    <0.1879999, -0.0005478, -0.9821689>,
    <0.1879999, -0.0005478, -0.9821689>,
    <0.1871675, -0.0005454, -0.9823279>,
    <0.1871843, -0.0005893, -0.9823246>,
    <0.1871843, -0.0005893, -0.9823246>,
    <0.1872009, -0.0006328, -0.9823215>,
    <0.1880377, -0.0006789, -0.9821616>,
    <0.1888651, -0.0006819, -0.9820028>,
    <0.1872009, -0.0006328, -0.9823215>,
    <0.1872173, -0.0006759, -0.9823183>,
    <0.1872173, -0.0006759, -0.9823183>,
    <0.1872336, -0.0007186, -0.9823152>,
    <0.1880500, -0.0007217, -0.9821592>,
    <0.1880500, -0.0007217, -0.9821592>,
    <0.1888735, -0.0007249, -0.9820012>,
    <0.1896998, -0.0006849, -0.9818419>,
    <0.1888735, -0.0007249, -0.9820012>,
    <0.1897040, -0.0007281, -0.9818411>,
    <0.1897040, -0.0007281, -0.9818411>,
    <0.1905418, -0.0007313, -0.9816788>,
    <0.1905417, -0.0006879, -0.9816789>,
    <0.1905417, -0.0006879, -0.9816789>,
    <0.1905416, -0.0006441, -0.9816789>,
    <-0.3702419, 0.9288037, 0.0156404>,
    <-0.3702437, 0.9288081, 0.0153366>,
    <-0.3702374, 0.9288109, 0.0153174>,
    <-0.3702357, 0.9288066, 0.0156114>,
    <-0.3702340, 0.9288023, 0.0159054>,
    <-0.3702402, 0.9287992, 0.0159441>,
    <-0.3702402, 0.9287992, 0.0159441>,
    <-0.3702467, 0.9287959, 0.0159856>,
    <-0.3702486, 0.9288005, 0.0156714>,
    <-0.3702486, 0.9288005, 0.0156714>,
    <-0.3702504, 0.9288050, 0.0153571>,
    <-0.3702454, 0.9288123, 0.0150328>,
    <-0.3702391, 0.9288150, 0.0150234>,
    <-0.3702504, 0.9288050, 0.0153571>,
    <-0.3702522, 0.9288095, 0.0150429>,
    <-0.3702522, 0.9288095, 0.0150429>,
    <-0.3702539, 0.9288138, 0.0147287>,
    <-0.3702471, 0.9288165, 0.0147291>,
    <-0.3702471, 0.9288165, 0.0147291>,
    <-0.3702407, 0.9288191, 0.0147295>,
    <-0.3702331, 0.9288175, 0.0150146>,
    <-0.3702315, 0.9288135, 0.0152994>,
    <-0.3702407, 0.9288191, 0.0147295>,
    <-0.3702347, 0.9288215, 0.0147298>,
    <-0.3702347, 0.9288215, 0.0147298>,
    <-0.3702291, 0.9288237, 0.0147302>,
    <-0.3702276, 0.9288199, 0.0150064>,
    <-0.3702276, 0.9288199, 0.0150064>,
    <-0.3702260, 0.9288160, 0.0152825>,
    <-0.3702299, 0.9288094, 0.0155842>,
    <-0.3702260, 0.9288160, 0.0152825>,
    <-0.3702244, 0.9288120, 0.0155587>,
    <-0.3702244, 0.9288120, 0.0155587>,
    <-0.3702228, 0.9288080, 0.0158349>,
    <-0.3702283, 0.9288053, 0.0158690>,
    <-0.3702283, 0.9288053, 0.0158690>,
    <-0.3702340, 0.9288023, 0.0159054>,
    <0.0004328, -0.9999999, 0.0000263>,
    <0.0004297, -0.9999999, 0.0000444>,
    <0.0004572, -0.9999999, 0.0001852>,
    <0.0004819, -0.9999999, 0.0001033>,
    <0.0004871, -0.9999999, 0.0000017>,
    <0.0004338, -0.9999999, 0.0000017>,
    <0.0004338, -0.9999999, 0.0000017>,
    <0.0004261, -0.9999999, 0.0000017>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004264, -0.9999999, 0.0000506>,
    <0.0004300, -0.9999999, 0.0002171>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000015>,
    <0.0004261, -0.9999999, 0.0000015>,
    <0.0004261, -0.9999999, 0.0000014>,
    <0.0004254, -0.9999999, 0.0000496>,
    <0.0004254, -0.9999999, 0.0000496>,
    <0.0004208, -0.9999999, 0.0002141>,
    <0.0004392, -0.9999997, 0.0005874>,
    <0.0005266, -0.9999997, 0.0005300>,
    <0.0004208, -0.9999999, 0.0002141>,
    <0.0004092, -0.9999997, 0.0005804>,
    <0.0004092, -0.9999997, 0.0005804>,
    <0.0003889, -0.9999989, 0.0014524>,
    <0.0004419, -0.9999988, 0.0014766>,
    <0.0006011, -0.9999987, 0.0014789>,
    <0.0006366, -0.9999997, 0.0003445>,
    <0.0009775, -0.9999984, 0.0015046>,
    <0.0012929, -0.9999977, 0.0016908>,
    <0.0006563, -0.9999998, 0.0000017>,
    <0.0006563, -0.9999998, 0.0000017>,
    <0.0004871, -0.9999999, 0.0000017>,
    <0.9995524, -0.0038537, -0.0296661>,
    <0.9995484, -0.0038537, -0.0298012>,
    <0.9918574, -0.0039361, -0.1272924>,
    <0.9919300, -0.0039364, -0.1267254>,
    <0.9920023, -0.0039367, -0.1261582>,
    <0.9995564, -0.0038537, -0.0295309>,
    <0.9995564, -0.0038537, -0.0295309>,
    <0.9999923, -0.0038380, -0.0008512>,
    <0.9999923, -0.0038380, -0.0008551>,
    <0.9999923, -0.0038380, -0.0008551>,
    <0.9999923, -0.0038380, -0.0008590>,
    <0.9995444, -0.0038537, -0.0299364>,
    <0.9917845, -0.0039358, -0.1278594>,
    <0.9999923, -0.0038380, -0.0008590>,
    <0.9999923, -0.0038380, -0.0008629>,
    <0.9999923, -0.0038380, -0.0008629>,
    <0.9999923, -0.0038380, -0.0008668>,
    <0.9995403, -0.0038537, -0.0300715>,
    <0.9995403, -0.0038537, -0.0300715>,
    <0.9917113, -0.0039355, -0.1284262>,
    <0.9447195, -0.0040337, -0.3278547>,
    <0.9451736, -0.0040357, -0.3265435>,
    <0.9917113, -0.0039355, -0.1284262>,
    <0.9442641, -0.0040318, -0.3291641>,
    <0.9442641, -0.0040318, -0.3291641>,
    <0.7574631, -0.0036692, -0.6528676>,
    <0.7588853, -0.0036761, -0.6512139>,
    <0.7603092, -0.0036830, -0.6495508>,
    <0.9456262, -0.0040376, -0.3252304>,
    <0.7617348, -0.0036899, -0.6478784>,
    <0.7631621, -0.0036968, -0.6461965>,
    <0.9460774, -0.0040395, -0.3239154>,
    <0.9460774, -0.0040395, -0.3239154>,
    <0.9920023, -0.0039367, -0.1261582>,
    <-0.3702675, 0.9289252, 0.0000874>,
    <-0.3702636, 0.9289267, 0.0000735>,
    <-0.3702213, 0.9289436, 0.0003067>,
    <-0.3702547, 0.9289302, 0.0003739>,
    <-0.3702661, 0.9289256, 0.0003905>,
    <-0.3702688, 0.9289246, 0.0000908>,
    <-0.3702688, 0.9289246, 0.0000908>,
    <-0.3702693, 0.9289245, 0.0000026>,
    <-0.3702693, 0.9289245, 0.0000026>,
    <-0.3702693, 0.9289245, 0.0000026>,
    <-0.3702693, 0.9289245, 0.0000025>,
    <-0.3702598, 0.9289283, 0.0000426>,
    <-0.3701912, 0.9289556, 0.0001679>,
    <-0.3702693, 0.9289245, 0.0000025>,
    <-0.3702693, 0.9289245, 0.0000025>,
    <-0.3702693, 0.9289245, 0.0000025>,
    <-0.3702693, 0.9289245, 0.0000024>,
    <-0.3702586, 0.9289287, 0.0000024>,
    <-0.3702586, 0.9289287, 0.0000024>,
    <-0.3701855, 0.9289579, 0.0000024>,
    <-0.3699782, 0.9290403, 0.0005423>,
    <-0.3701119, 0.9289868, 0.0008648>,
    <-0.3701855, 0.9289579, 0.0000024>,
    <-0.3699584, 0.9290483, 0.0000024>,
    <-0.3699584, 0.9290483, 0.0000024>,
    <-0.3691451, 0.9293686, 0.0024326>,
    <-0.3695121, 0.9292231, 0.0022834>,
    <-0.3699752, 0.9290386, 0.0023670>,
    <-0.3702209, 0.9289432, 0.0010040>,
    <-0.3701769, 0.9289579, 0.0024893>,
    <-0.3702463, 0.9289300, 0.0025810>,
    <-0.3702591, 0.9289279, 0.0010484>,
    <-0.3702591, 0.9289279, 0.0010484>,
    <-0.3702661, 0.9289256, 0.0003905>,
    <0.0009820, -0.9999841, 0.0055500>,
    <0.0005787, -0.9999933, 0.0036053>,
    <0.0003522, -0.9999833, 0.0057696>,
    <0.0003820, -0.9999521, 0.0097787>,
    <0.0005080, -0.9994483, 0.0332100>,
    <0.0042098, -0.9994193, 0.0338132>,
    <0.0042098, -0.9994193, 0.0338132>,
    <0.0012929, -0.9999977, 0.0016908>,
    <0.0004125, -0.9999948, 0.0032130>,
    <0.0003397, -0.9999888, 0.0047174>,
    <0.0003889, -0.9999989, 0.0014524>,
    <0.0003623, -0.9999951, 0.0031167>,
    <0.0003623, -0.9999951, 0.0031167>,
    <0.0003364, -0.9999899, 0.0044723>,
    <0.0002761, -0.9999919, 0.0040074>,
    <0.0001403, -0.9999887, 0.0047436>,
    <0.0003364, -0.9999899, 0.0044723>,
    <0.0003153, -0.9999928, 0.0037768>,
    <0.0003153, -0.9999928, 0.0037768>,
    <0.0003004, -0.9999981, 0.0019498>,
    <0.0002642, -0.9999979, 0.0020286>,
    <0.0001522, -0.9999977, 0.0021282>,
    <-0.0001919, -0.9999731, 0.0073266>,
    <-0.0001143, -0.9999976, 0.0022072>,
    <-0.0002937, -0.9999977, 0.0021417>,
    <-0.0020821, -0.9994602, 0.0327876>,
    <-0.0020821, -0.9994602, 0.0327876>,
    <0.0005080, -0.9994483, 0.0332100>,
    <0.4862306, -0.0027790, -0.8738261>,
    <0.4846110, -0.0027697, -0.8747254>,
    <0.3648940, -0.0024544, -0.9310458>,
    <0.3662448, -0.0024635, -0.9305153>,
    <0.3676048, -0.0024726, -0.9299788>,
    <0.4878594, -0.0027883, -0.8729178>,
    <0.4878594, -0.0027883, -0.8729178>,
    <0.7631621, -0.0036968, -0.6461965>,
    <0.4830005, -0.0027605, -0.8756157>,
    <0.3635523, -0.0024454, -0.9315706>,
    <0.7574631, -0.0036692, -0.6528676>,
    <0.4813990, -0.0027514, -0.8764972>,
    <0.4813990, -0.0027514, -0.8764972>,
    <0.3622198, -0.0024364, -0.9320895>,
    <0.4237106, -0.0032623, -0.9057917>,
    <0.4251552, -0.0032734, -0.9051146>,
    <0.3622198, -0.0024364, -0.9320895>,
    <0.4222747, -0.0032512, -0.9064621>,
    <0.4222747, -0.0032512, -0.9064621>,
    <0.6730900, -0.0057116, -0.7395385>,
    <0.6745826, -0.0057242, -0.7381771>,
    <0.6760791, -0.0057369, -0.7368067>,
    <0.4266085, -0.0032846, -0.9044304>,
    <0.6775795, -0.0057496, -0.7354271>,
    <0.6790837, -0.0057624, -0.7340383>,
    <0.4280708, -0.0032958, -0.9037392>,
    <0.4280708, -0.0032958, -0.9037392>,
    <0.3676048, -0.0024726, -0.9299788>,
    <-0.3701597, 0.9289529, 0.0053235>,
    <-0.3699458, 0.9290360, 0.0056797>,
    <-0.3701810, 0.9289162, 0.0089828>,
    <-0.3702013, 0.9289197, 0.0076901>,
    <-0.3702060, 0.9289184, 0.0076194>,
    <-0.3702265, 0.9289257, 0.0054212>,
    <-0.3702265, 0.9289257, 0.0054212>,
    <-0.3702463, 0.9289300, 0.0025810>,
    <-0.3694410, 0.9292170, 0.0083123>,
    <-0.3701199, 0.9288696, 0.0145759>,
    <-0.3691451, 0.9293686, 0.0024326>,
    <-0.3651007, 0.9296955, 0.0486595>,
    <-0.3651007, 0.9296955, 0.0486595>,
    <-0.3695850, 0.9279685, 0.0477638>,
    <-0.3708155, 0.9286428, 0.0108815>,
    <-0.3704183, 0.9288362, 0.0073277>,
    <-0.3695850, 0.9279685, 0.0477638>,
    <-0.3727090, 0.9267502, 0.0471382>,
    <-0.3727090, 0.9267502, 0.0471382>,
    <-0.3709178, 0.9286606, 0.0030824>,
    <-0.3707076, 0.9287438, 0.0032850>,
    <-0.3703806, 0.9288743, 0.0032783>,
    <-0.3702480, 0.9289105, 0.0064505>,
    <-0.3702402, 0.9289304, 0.0032388>,
    <-0.3701938, 0.9289489, 0.0032288>,
    <-0.3701970, 0.9289317, 0.0063278>,
    <-0.3701970, 0.9289317, 0.0063278>,
    <-0.3702060, 0.9289184, 0.0076194>,
    <0.0001552, -0.9999998, 0.0005685>,
    <0.0002210, -0.9999996, 0.0008105>,
    <0.0002669, -0.9999999, 0.0003406>,
    <0.0002531, -0.9999999, 0.0002361>,
    <0.0002504, -1.0000000, 0.0001045>,
    <0.0001454, -1.0000000, 0.0001045>,
    <0.0001454, -1.0000000, 0.0001045>,
    <-0.0002937, -0.9999977, 0.0021417>,
    <0.0002737, -0.9999996, 0.0008673>,
    <0.0002820, -0.9999999, 0.0003799>,
    <0.0003004, -0.9999981, 0.0019498>,
    <0.0002917, -0.9999996, 0.0008532>,
    <0.0002917, -0.9999996, 0.0008532>,
    <0.0002871, -0.9999999, 0.0003774>,
    <0.0002844, -0.9999999, 0.0001621>,
    <0.0002826, -0.9999999, 0.0001554>,
    <0.0002871, -0.9999999, 0.0003774>,
    <0.0002849, -0.9999999, 0.0001599>,
    <0.0002849, -0.9999999, 0.0001599>,
    <0.0002839, -1.0000000, 0.0000958>,
    <0.0002839, -1.0000000, 0.0000980>,
    <0.0002839, -1.0000000, 0.0000980>,
    <0.0002839, -1.0000000, 0.0001001>,
    <0.0002809, -1.0000000, 0.0001341>,
    <0.0002839, -1.0000000, 0.0001001>,
    <0.0002839, -1.0000000, 0.0001023>,
    <0.0002839, -1.0000000, 0.0001023>,
    <0.0002839, -1.0000000, 0.0001045>,
    <0.0002804, -1.0000000, 0.0001045>,
    <0.0002804, -1.0000000, 0.0001045>,
    <0.0002504, -1.0000000, 0.0001045>,
    <0.9040796, -0.0081306, -0.4272869>,
    <0.9034106, -0.0081246, -0.4286994>,
    <0.9787319, -0.0090796, -0.2049426>,
    <0.9788962, -0.0090811, -0.2041561>,
    <0.9790600, -0.0090826, -0.2033693>,
    <0.9047472, -0.0081366, -0.4258711>,
    <0.9047472, -0.0081366, -0.4258711>,
    <0.6790837, -0.0057624, -0.7340383>,
    <0.9027405, -0.0081186, -0.4301089>,
    <0.9785670, -0.0090780, -0.2057286>,
    <0.6730900, -0.0057116, -0.7395385>,
    <0.9020692, -0.0081125, -0.4315152>,
    <0.9020692, -0.0081125, -0.4315152>,
    <0.9784015, -0.0090765, -0.2065142>,
    <0.9960237, -0.0093787, -0.0885931>,
    <0.9960548, -0.0093790, -0.0882437>,
    <0.9784015, -0.0090765, -0.2065142>,
    <0.9959926, -0.0093784, -0.0889424>,
    <0.9959926, -0.0093784, -0.0889424>,
    <0.9985298, -0.0094705, -0.0533727>,
    <0.9985410, -0.0094706, -0.0531623>,
    <0.9985410, -0.0094706, -0.0531623>,
    <0.9985521, -0.0094707, -0.0529520>,
    <0.9960857, -0.0093793, -0.0878942>,
    <0.9985521, -0.0094707, -0.0529520>,
    <0.9985633, -0.0094708, -0.0527416>,
    <0.9985633, -0.0094708, -0.0527416>,
    <0.9985744, -0.0094709, -0.0525312>,
    <0.9961164, -0.0093796, -0.0875448>,
    <0.9961164, -0.0093796, -0.0875448>,
    <0.9790600, -0.0090826, -0.2033693>,
    <-0.3702129, 0.9289459, 0.0013795>,
    <-0.3702782, 0.9289201, 0.0012519>,
    <-0.3702128, 0.9289468, 0.0005271>,
    <-0.3701942, 0.9289542, 0.0006031>,
    <-0.3701878, 0.9289567, 0.0006186>,
    <-0.3701902, 0.9289549, 0.0014032>,
    <-0.3701902, 0.9289549, 0.0014032>,
    <-0.3701938, 0.9289489, 0.0032288>,
    <-0.3703585, 0.9288885, 0.0008573>,
    <-0.3702295, 0.9289402, 0.0003574>,
    <-0.3709178, 0.9286606, 0.0030824>,
    <-0.3703689, 0.9288847, 0.0001504>,
    <-0.3703689, 0.9288847, 0.0001504>,
    <-0.3702327, 0.9289390, 0.0001504>,
    <-0.3701915, 0.9289554, 0.0002007>,
    <-0.3701895, 0.9289562, 0.0002394>,
    <-0.3702327, 0.9289390, 0.0001504>,
    <-0.3701922, 0.9289552, 0.0001505>,
    <-0.3701922, 0.9289552, 0.0001505>,
    <-0.3701860, 0.9289576, 0.0001505>,
    <-0.3701860, 0.9289576, 0.0001520>,
    <-0.3701860, 0.9289576, 0.0001520>,
    <-0.3701860, 0.9289576, 0.0001535>,
    <-0.3701873, 0.9289571, 0.0002569>,
    <-0.3701860, 0.9289576, 0.0001535>,
    <-0.3701860, 0.9289576, 0.0001550>,
    <-0.3701860, 0.9289576, 0.0001550>,
    <-0.3701860, 0.9289576, 0.0001565>,
    <-0.3701866, 0.9289574, 0.0002616>,
    <-0.3701866, 0.9289574, 0.0002616>,
    <-0.3701878, 0.9289567, 0.0006186>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999886, 0.0047498, 0.0005083>,
    <0.9999886, 0.0047498, 0.0005032>,
    <0.9999886, 0.0047479, 0.0005032>,
    <0.9999886, 0.0047479, 0.0005083>,
    <0.9999886, 0.0047479, 0.0005135>,
    <0.9999886, 0.0047498, 0.0005135>,
    <0.9999886, 0.0047498, 0.0005135>,
    <0.9999886, 0.0047517, 0.0005135>,
    <0.9999886, 0.0047517, 0.0005083>,
    <0.9999886, 0.0047517, 0.0005083>,
    <0.9999886, 0.0047517, 0.0005032>,
    <0.9999886, 0.0047498, 0.0004980>,
    <0.9999886, 0.0047479, 0.0004980>,
    <0.9999886, 0.0047517, 0.0005032>,
    <0.9999886, 0.0047517, 0.0004980>,
    <0.9999886, 0.0047517, 0.0004980>,
    <0.9999886, 0.0047517, 0.0004929>,
    <0.9999886, 0.0047498, 0.0004929>,
    <0.9999886, 0.0047498, 0.0004929>,
    <0.9999886, 0.0047479, 0.0004929>,
    <0.9999886, 0.0047460, 0.0004980>,
    <0.9999886, 0.0047460, 0.0005032>,
    <0.9999886, 0.0047479, 0.0004929>,
    <0.9999886, 0.0047460, 0.0004929>,
    <0.9999886, 0.0047460, 0.0004929>,
    <0.9999886, 0.0047441, 0.0004929>,
    <0.9999886, 0.0047441, 0.0004980>,
    <0.9999886, 0.0047441, 0.0004980>,
    <0.9999886, 0.0047441, 0.0005032>,
    <0.9999886, 0.0047460, 0.0005083>,
    <0.9999886, 0.0047441, 0.0005032>,
    <0.9999886, 0.0047441, 0.0005083>,
    <0.9999886, 0.0047441, 0.0005083>,
    <0.9999886, 0.0047441, 0.0005135>,
    <0.9999886, 0.0047460, 0.0005135>,
    <0.9999886, 0.0047460, 0.0005135>,
    <0.9999886, 0.0047479, 0.0005135>,
    <-0.9872098, -0.0048076, -0.1593540>,
    <-0.9872100, -0.0047688, -0.1593539>,
    <-0.9874620, -0.0047700, -0.1577846>,
    <-0.9874616, -0.0048088, -0.1577861>,
    <-0.9874612, -0.0048476, -0.1577876>,
    <-0.9872096, -0.0048463, -0.1593541>,
    <-0.9872096, -0.0048463, -0.1593541>,
    <-0.9869556, -0.0048451, -0.1609195>,
    <-0.9869556, -0.0048063, -0.1609208>,
    <-0.9869556, -0.0048063, -0.1609208>,
    <-0.9869556, -0.0047675, -0.1609220>,
    <-0.9872102, -0.0047299, -0.1593538>,
    <-0.9874625, -0.0047311, -0.1577831>,
    <-0.9869556, -0.0047675, -0.1609220>,
    <-0.9869556, -0.0047287, -0.1609233>,
    <-0.9869556, -0.0047287, -0.1609233>,
    <-0.9869556, -0.0046897, -0.1609246>,
    <-0.9872104, -0.0046910, -0.1593537>,
    <-0.9872104, -0.0046910, -0.1593537>,
    <-0.9874629, -0.0046922, -0.1577816>,
    <-0.9877123, -0.0047323, -0.1562112>,
    <-0.9877117, -0.0047712, -0.1562141>,
    <-0.9874629, -0.0046922, -0.1577816>,
    <-0.9877130, -0.0046933, -0.1562083>,
    <-0.9877130, -0.0046933, -0.1562083>,
    <-0.9879607, -0.0046945, -0.1546338>,
    <-0.9879599, -0.0047335, -0.1546381>,
    <-0.9879599, -0.0047335, -0.1546381>,
    <-0.9879590, -0.0047724, -0.1546423>,
    <-0.9877111, -0.0048100, -0.1562169>,
    <-0.9879590, -0.0047724, -0.1546423>,
    <-0.9879581, -0.0048112, -0.1546466>,
    <-0.9879581, -0.0048112, -0.1546466>,
    <-0.9879573, -0.0048500, -0.1546509>,
    <-0.9877104, -0.0048488, -0.1562198>,
    <-0.9877104, -0.0048488, -0.1562198>,
    <-0.9874612, -0.0048476, -0.1577876>,
    <0.9999879, 0.0049092, 0.0000082>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000082>,
    <0.9999880, 0.0049091, 0.0000083>,
    <0.9999879, 0.0049092, 0.0000083>,
    <0.9999879, 0.0049092, 0.0000083>,
    <0.9999879, 0.0049092, 0.0000083>,
    <0.9999879, 0.0049092, 0.0000082>,
    <0.9999879, 0.0049092, 0.0000082>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999879, 0.0049092, 0.0000080>,
    <0.9999879, 0.0049092, 0.0000080>,
    <0.9999879, 0.0049092, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000082>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000082>,
    <0.9999880, 0.0049091, 0.0000082>,
    <0.9999880, 0.0049091, 0.0000083>,
    <0.9999880, 0.0049091, 0.0000083>,
    <0.9999880, 0.0049091, 0.0000083>,
    <0.9999880, 0.0049091, 0.0000083>,
    <-0.9987510, -0.0049204, -0.0497222>,
    <-0.9987510, -0.0049147, -0.0497222>,
    <-0.9987758, -0.0049148, -0.0492222>,
    <-0.9987757, -0.0049206, -0.0492223>,
    <-0.9987757, -0.0049263, -0.0492224>,
    <-0.9987509, -0.0049262, -0.0497222>,
    <-0.9987509, -0.0049262, -0.0497222>,
    <-0.9987259, -0.0049261, -0.0502221>,
    <-0.9987260, -0.0049203, -0.0502221>,
    <-0.9987260, -0.0049203, -0.0502221>,
    <-0.9987260, -0.0049146, -0.0502222>,
    <-0.9987510, -0.0049089, -0.0497222>,
    <-0.9987758, -0.0049090, -0.0492222>,
    <-0.9987260, -0.0049146, -0.0502222>,
    <-0.9987260, -0.0049088, -0.0502223>,
    <-0.9987260, -0.0049088, -0.0502223>,
    <-0.9987260, -0.0049030, -0.0502223>,
    <-0.9987510, -0.0049031, -0.0497222>,
    <-0.9987510, -0.0049031, -0.0497222>,
    <-0.9987758, -0.0049033, -0.0492221>,
    <-0.9988003, -0.0049091, -0.0487221>,
    <-0.9988003, -0.0049149, -0.0487222>,
    <-0.9987758, -0.0049033, -0.0492221>,
    <-0.9988003, -0.0049034, -0.0487219>,
    <-0.9988003, -0.0049034, -0.0487219>,
    <-0.9988246, -0.0049035, -0.0482217>,
    <-0.9988246, -0.0049093, -0.0482219>,
    <-0.9988246, -0.0049093, -0.0482219>,
    <-0.9988245, -0.0049150, -0.0482221>,
    <-0.9988002, -0.0049207, -0.0487224>,
    <-0.9988245, -0.0049150, -0.0482221>,
    <-0.9988245, -0.0049208, -0.0482224>,
    <-0.9988245, -0.0049208, -0.0482224>,
    <-0.9988245, -0.0049266, -0.0482226>,
    <-0.9988002, -0.0049265, -0.0487225>,
    <-0.9988002, -0.0049265, -0.0487225>,
    <-0.9987757, -0.0049263, -0.0492224>,
    <0.9999289, 0.0050315, 0.0108120>,
    <0.9999346, 0.0049675, 0.0102967>,
    <0.9999243, 0.0049561, 0.0112634>,
    <0.9999211, 0.0049719, 0.0115332>,
    <0.9999164, 0.0049756, 0.0119387>,
    <0.9999160, 0.0050444, 0.0119386>,
    <0.9999160, 0.0050444, 0.0119386>,
    <0.9999587, 0.0052757, 0.0074000>,
    <0.9999598, 0.0051637, 0.0073267>,
    <0.9999613, 0.0049751, 0.0072530>,
    <0.9999322, 0.0049023, 0.0105596>,
    <0.9999242, 0.0049396, 0.0112819>,
    <0.9999628, 0.0047889, 0.0071785>,
    <0.9999638, 0.0046760, 0.0071039>,
    <0.9999224, 0.0048861, 0.0114621>,
    <0.9999224, 0.0048861, 0.0114621>,
    <0.9999221, 0.0049347, 0.0114625>,
    <0.9999215, 0.0049421, 0.0115096>,
    <0.9999205, 0.0049440, 0.0115977>,
    <0.9999221, 0.0049347, 0.0114625>,
    <0.9999221, 0.0049414, 0.0114625>,
    <0.9999221, 0.0049414, 0.0114625>,
    <0.9999221, 0.0049320, 0.0114624>,
    <0.9999208, 0.0049320, 0.0115815>,
    <0.9999208, 0.0049320, 0.0115815>,
    <0.9999194, 0.0049320, 0.0117006>,
    <0.9999187, 0.0049459, 0.0117509>,
    <0.9999194, 0.0049320, 0.0117006>,
    <0.9999180, 0.0049320, 0.0118197>,
    <0.9999180, 0.0049320, 0.0118197>,
    <0.9999166, 0.0049320, 0.0119388>,
    <0.9999165, 0.0049465, 0.0119388>,
    <0.9999165, 0.0049465, 0.0119388>,
    <0.9999164, 0.0049756, 0.0119387>,
    <0.9999769, 0.0051945, -0.0043730>,
    <0.9997738, 0.0050800, -0.0206514>,
    <0.9998744, 0.0049721, -0.0150502>,
    <0.9999873, 0.0049759, -0.0008097>,
    <0.9999587, 0.0052757, 0.0074000>,
    <0.9990680, 0.0058606, -0.0427636>,
    <0.9990680, 0.0058606, -0.0427636>,
    <0.9990714, 0.0051973, -0.0427696>,
    <0.9993791, 0.0049844, -0.0348780>,
    <0.9994845, 0.0049663, -0.0317178>,
    <0.9990714, 0.0051973, -0.0427696>,
    <0.9990724, 0.0049929, -0.0427714>,
    <0.9990724, 0.0049929, -0.0427714>,
    <0.9990726, 0.0049603, -0.0427717>,
    <0.9990907, 0.0049604, -0.0423460>,
    <0.9990907, 0.0049604, -0.0423460>,
    <0.9991086, 0.0049605, -0.0419203>,
    <0.9994051, 0.0049475, -0.0341329>,
    <0.9997860, 0.0048649, -0.0201093>,
    <0.9991086, 0.0049605, -0.0419203>,
    <0.9991264, 0.0049606, -0.0414946>,
    <0.9991264, 0.0049606, -0.0414946>,
    <0.9991440, 0.0049607, -0.0410689>,
    <0.9991441, 0.0049368, -0.0410682>,
    <0.9991441, 0.0049368, -0.0410682>,
    <0.9991453, 0.0047459, -0.0410625>,
    <0.9999800, 0.0047607, -0.0041693>,
    <0.9991453, 0.0047459, -0.0410625>,
    <0.9991489, 0.0041108, -0.0410437>,
    <0.9991489, 0.0041108, -0.0410437>,
    <0.9999638, 0.0046760, 0.0071039>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4349582, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289897, 0.9511724>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6558937, 0.9657316>,
    <0.6289897, 0.9511724>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4349582, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4263414, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379139, 0.9664288>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6558937, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773828, 0.9671308>,
    <0.6379139, 0.9664288>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473543, 0.9786906>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773828, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473543, 0.9786906>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032658, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458854>,
    <0.4677608, 0.9456845>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4355157, 0.9458854>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9451388>,
    <0.4677604, 0.9518685>,
    <0.4676209, 0.9588001>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.4677604, 0.9518685>,
    <0.5000059, 0.9579003>,
    <0.4674769, 0.9657316>,
    <0.4352664, 0.9584513>,
    <0.4031264, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4349582, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352664, 0.9584513>,
    <0.4022562, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032658, 0.9526160>,
    <0.5322510, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9518685>,
    <0.5000059, 0.9451388>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458646>,
    <0.5967410, 0.9456973>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289897, 0.9511724>,
    <0.5644961, 0.9458646>,
    <0.5967380, 0.9395004>,
    <0.6289858, 0.9451648>,
    <0.5967440, 0.9518942>,
    <0.5967474, 0.9588129>,
    <0.5644983, 0.9526160>,
    <0.6289897, 0.9511724>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967440, 0.9518942>,
    <0.6289941, 0.9579895>,
    <0.5967509, 0.9657316>,
    <0.5645003, 0.9587186>,
    <0.5322532, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.5645003, 0.9587186>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9579003>,
    <0.5322521, 0.9518685>,
    <0.6423395, 0.9456973>,
    <0.6556982, 0.9526160>,
    <0.6289897, 0.9511724>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423437, 0.9518942>,
    <0.6289858, 0.9451648>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458857>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458857>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690524, 0.9526160>,
    <0.6691039, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6558937, 0.9657316>,
    <0.6690524, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694067, 0.9657316>,
    <0.6557854, 0.9584675>,
    <0.6423952, 0.9588129>,
    <0.6556982, 0.9526160>,
    <0.6558937, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289897, 0.9511724>,
    <0.6557854, 0.9584675>,
    <0.6424477, 0.9657316>,
    <0.6289941, 0.9579895>,
    <0.6423437, 0.9518942>,
    <0.3997689, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4022562, 0.9657316>,
    <0.4331396, 0.9660561>,
    <0.4665018, 0.9660805>,
    <0.4310370, 0.9664312>,
    <0.4349582, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4331396, 0.9660561>,
    <0.4674769, 0.9657316>,
    <0.5000060, 0.9660883>,
    <0.4655215, 0.9664293>,
    <0.4643476, 0.9667801>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000061, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.4655215, 0.9664293>,
    <0.5000060, 0.9667645>,
    <0.4631665, 0.9671308>,
    <0.4286164, 0.9667919>,
    <0.3931424, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4263414, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4286164, 0.9667919>,
    <0.3894539, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664293>,
    <0.5000060, 0.9660883>,
    <0.5322542, 0.9657316>,
    <0.5668016, 0.9660912>,
    <0.6000977, 0.9660808>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379139, 0.9664288>,
    <0.5668016, 0.9660912>,
    <0.5967509, 0.9657316>,
    <0.6336084, 0.9660921>,
    <0.6034444, 0.9664300>,
    <0.6068063, 0.9667804>,
    <0.5689750, 0.9664312>,
    <0.6379139, 0.9664288>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034444, 0.9664300>,
    <0.6421883, 0.9667632>,
    <0.6101681, 0.9671308>,
    <0.5711137, 0.9667657>,
    <0.5356086, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.5711137, 0.9667657>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667645>,
    <0.5344905, 0.9664293>,
    <0.6473280, 0.9660808>,
    <0.6665054, 0.9664312>,
    <0.6379139, 0.9664288>,
    <0.6289992, 0.9657316>,
    <0.6558937, 0.9657316>,
    <0.6522097, 0.9664300>,
    <0.6336084, 0.9660921>,
    <0.6424477, 0.9657316>,
    <0.6608902, 0.9660610>,
    <0.6749710, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6558937, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6608902, 0.9660610>,
    <0.6694067, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866678, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773828, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926475, 0.9671308>,
    <0.6720515, 0.9667879>,
    <0.6571727, 0.9667804>,
    <0.6665054, 0.9664312>,
    <0.6773828, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379139, 0.9664288>,
    <0.6720515, 0.9667879>,
    <0.6621386, 0.9671308>,
    <0.6421883, 0.9667632>,
    <0.6522097, 0.9664300>,
    <0.3896277, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.3895219, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3894539, 0.9671308>,
    <0.4263465, 0.9729776>,
    <0.4631761, 0.9726967>,
    <0.4263507, 0.9777601>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4263465, 0.9729776>,
    <0.4631665, 0.9671308>,
    <0.5000061, 0.9732089>,
    <0.4631777, 0.9782626>,
    <0.4631249, 0.9833260>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631777, 0.9782626>,
    <0.5000061, 0.9837065>,
    <0.4630714, 0.9883895>,
    <0.4262410, 0.9832100>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262410, 0.9832100>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895219, 0.9777601>,
    <0.5367803, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9782626>,
    <0.5000061, 0.9732089>,
    <0.5367268, 0.9671308>,
    <0.5735589, 0.9726651>,
    <0.6103380, 0.9726781>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473543, 0.9786906>,
    <0.5735589, 0.9726651>,
    <0.6101681, 0.9671308>,
    <0.6471293, 0.9731037>,
    <0.6105079, 0.9782254>,
    <0.6106590, 0.9833074>,
    <0.5736614, 0.9777601>,
    <0.6473543, 0.9786906>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105079, 0.9782254>,
    <0.6475546, 0.9836672>,
    <0.6108101, 0.9883895>,
    <0.5737713, 0.9832166>,
    <0.5368873, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.5737713, 0.9832166>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9837065>,
    <0.5368338, 0.9782626>,
    <0.6623612, 0.9726781>,
    <0.6778190, 0.9777601>,
    <0.6473543, 0.9786906>,
    <0.6468888, 0.9671308>,
    <0.6773828, 0.9671308>,
    <0.6625869, 0.9782254>,
    <0.6471293, 0.9731037>,
    <0.6621386, 0.9671308>,
    <0.6776219, 0.9729570>,
    <0.6928097, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773828, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776219, 0.9729570>,
    <0.6926475, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930705, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930705, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780838, 0.9832092>,
    <0.6628134, 0.9833074>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473543, 0.9786906>,
    <0.6780838, 0.9832092>,
    <0.6630402, 0.9883895>,
    <0.6475546, 0.9836672>,
    <0.6625869, 0.9782254>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.011335, 0.63719, -0.147353>
}

#declare TMesh003 = mesh2 {
  vertex_vectors {
    582,
    <2.1729169, 0.1670810, 18.5417983>,
    <2.0016629, 0.2021583, 18.5417983>,
    <2.0011917, 0.0330344, 18.5417983>,
    <2.1732628, -0.0371492, 18.5417983>,
    <2.0872899, 0.1846196, 18.5417983>,
    <2.0014273, 0.1175963, 18.5417983>,
    <2.0872272, -0.0020574, 18.5417983>,
    <2.1730898, 0.0649659, 18.5417983>,
    <2.0872586, 0.0912811, 18.5417983>,
    <2.3453338, -0.1073328, 18.5417983>,
    <2.3441709, 0.1320038, 18.5417983>,
    <2.2592983, -0.0722410, 18.5417983>,
    <2.3447524, 0.0123355, 18.5417983>,
    <2.2585439, 0.1495424, 18.5417983>,
    <2.2589211, 0.0386507, 18.5417983>,
    <2.3430079, 0.3713404, 18.5417983>,
    <2.1725710, 0.3713112, 18.5417983>,
    <2.3435894, 0.2516721, 18.5417983>,
    <2.2577895, 0.3713258, 18.5417983>,
    <2.1727439, 0.2691961, 18.5417983>,
    <2.2581667, 0.2604341, 18.5417983>,
    <2.0021340, 0.3712821, 18.5417983>,
    <2.0873525, 0.3712967, 18.5417983>,
    <2.0018984, 0.2867202, 18.5417983>,
    <2.0873212, 0.2779581, 18.5417983>,
    <2.0586650, 0.0090783, 18.1202395>,
    <2.0032615, 0.0316559, 18.1202395>,
    <2.0033220, 0.0316156, 18.1217627>,
    <2.0553199, 0.0104277, 18.1217627>,
    <2.0309633, 0.0203671, 18.1202395>,
    <2.0032917, 0.0316358, 18.1210011>,
    <2.0293209, 0.0210217, 18.1217627>,
    <2.0569925, 0.0097530, 18.1210011>,
    <2.0301421, 0.0206944, 18.1210011>,
    <2.1073179, -0.0107603, 18.1217627>,
    <2.1140685, -0.0134993, 18.1202395>,
    <2.0813189, -0.0001663, 18.1217627>,
    <2.1106932, -0.0121298, 18.1210011>,
    <2.0863668, -0.0022105, 18.1202395>,
    <2.0838428, -0.0011884, 18.1210011>,
    <2.1208191, -0.0162383, 18.1187163>,
    <2.0620101, 0.0077289, 18.1187163>,
    <2.1174438, -0.0148688, 18.1194779>,
    <2.0914146, -0.0042547, 18.1187163>,
    <2.0603376, 0.0084036, 18.1194779>,
    <2.0888907, -0.0032326, 18.1194779>,
    <2.0032011, 0.0316961, 18.1187163>,
    <2.0326056, 0.0197125, 18.1187163>,
    <2.0032313, 0.0316760, 18.1194779>,
    <2.0317844, 0.0200398, 18.1194779>,
    <2.1140920, 0.1791675, 18.1202395>,
    <2.1073761, 0.1805442, 18.1217627>,
    <2.1140803, 0.0828341, 18.1202395>,
    <2.1073470, 0.0848920, 18.1217627>,
    <2.1107340, 0.1798559, 18.1210011>,
    <2.1107136, 0.0838630, 18.1210011>,
    <2.1074342, 0.3718488, 18.1217627>,
    <2.1141156, 0.3718344, 18.1202395>,
    <2.1074051, 0.2761965, 18.1217627>,
    <2.1107749, 0.3718416, 18.1210011>,
    <2.1141038, 0.2755010, 18.1202395>,
    <2.1107545, 0.2758487, 18.1210011>,
    <2.1207969, 0.3718200, 18.1187163>,
    <2.1208080, 0.1777908, 18.1187163>,
    <2.1174562, 0.3718272, 18.1194779>,
    <2.1208025, 0.2748054, 18.1187163>,
    <2.1174500, 0.1784792, 18.1194779>,
    <2.1174531, 0.2751532, 18.1194779>,
    <2.1208136, 0.0807763, 18.1187163>,
    <2.1174469, 0.0818052, 18.1194779>,
    <2.0592428, 0.3718157, 18.1202395>,
    <2.0559348, 0.3718304, 18.1217627>,
    <2.0866792, 0.3718250, 18.1202395>,
    <2.0816845, 0.3718396, 18.1217627>,
    <2.0575888, 0.3718230, 18.1210011>,
    <2.0841818, 0.3718323, 18.1210011>,
    <2.0044353, 0.3718120, 18.1217627>,
    <2.0043701, 0.3717970, 18.1202395>,
    <2.0301850, 0.3718212, 18.1217627>,
    <2.0044027, 0.3718045, 18.1210011>,
    <2.0318064, 0.3718063, 18.1202395>,
    <2.0309957, 0.3718138, 18.1210011>,
    <2.0043048, 0.3717820, 18.1187163>,
    <2.0625508, 0.3718010, 18.1187163>,
    <2.0043374, 0.3717895, 18.1194779>,
    <2.0334278, 0.3717915, 18.1187163>,
    <2.0608968, 0.3718083, 18.1194779>,
    <2.0326171, 0.3717989, 18.1194779>,
    <2.0916739, 0.3718105, 18.1187163>,
    <2.0891765, 0.3718177, 18.1194779>,
    <2.0689854, 0.0049151, 18.1370901>,
    <2.0030751, 0.0317800, 18.1370901>,
    <2.0360303, 0.0183476, 18.1370901>,
    <2.0031381, 0.0317381, 18.1279032>,
    <2.0654978, 0.0063220, 18.1279032>,
    <2.0343179, 0.0190301, 18.1279032>,
    <2.1348957, -0.0219497, 18.1370901>,
    <2.1278574, -0.0190940, 18.1279032>,
    <2.1019406, -0.0085173, 18.1370901>,
    <2.0966776, -0.0063860, 18.1279032>,
    <2.1489723, -0.0276612, 18.1554639>,
    <2.0759607, 0.0021014, 18.1554639>,
    <2.1419340, -0.0248054, 18.1462770>,
    <2.1124665, -0.0127799, 18.1554639>,
    <2.0724731, 0.0035083, 18.1462770>,
    <2.1072035, -0.0106486, 18.1462770>,
    <2.0029492, 0.0318639, 18.1554639>,
    <2.0394549, 0.0169827, 18.1554639>,
    <2.0030121, 0.0318220, 18.1462770>,
    <2.0377426, 0.0176651, 18.1462770>,
    <2.1348124, 0.1749201, 18.1370901>,
    <2.1348540, 0.0764852, 18.1370901>,
    <2.1278102, 0.1763555, 18.1279032>,
    <2.1278338, 0.0786307, 18.1279032>,
    <2.1347291, 0.3717899, 18.1370901>,
    <2.1277630, 0.3718049, 18.1279032>,
    <2.1347707, 0.2733550, 18.1370901>,
    <2.1277866, 0.2740802, 18.1279032>,
    <2.1486612, 0.3717598, 18.1554639>,
    <2.1488168, 0.1720493, 18.1554639>,
    <2.1416951, 0.3717749, 18.1462770>,
    <2.1487390, 0.2719046, 18.1554639>,
    <2.1418146, 0.1734847, 18.1462770>,
    <2.1417549, 0.2726298, 18.1462770>,
    <2.1488945, 0.0721941, 18.1554639>,
    <2.1418743, 0.0743396, 18.1462770>,
    <2.0694489, 0.3717703, 18.1370901>,
    <2.1020890, 0.3717801, 18.1370901>,
    <2.0659999, 0.3717856, 18.1279032>,
    <2.0968814, 0.3717953, 18.1279032>,
    <2.0041687, 0.3717506, 18.1370901>,
    <2.0042367, 0.3717663, 18.1279032>,
    <2.0368088, 0.3717604, 18.1370901>,
    <2.0351183, 0.3717759, 18.1279032>,
    <2.0040326, 0.3717193, 18.1554639>,
    <2.0763469, 0.3717395, 18.1554639>,
    <2.0041006, 0.3717349, 18.1462770>,
    <2.0401897, 0.3717294, 18.1554639>,
    <2.0728979, 0.3717549, 18.1462770>,
    <2.0384993, 0.3717449, 18.1462770>,
    <2.1125041, 0.3717497, 18.1554639>,
    <2.1072965, 0.3717649, 18.1462770>,
    <2.0809036, 0.0001075, 18.1573801>,
    <2.0028599, 0.0319234, 18.1573801>,
    <2.0418818, 0.0160154, 18.1573801>,
    <2.0029045, 0.0318937, 18.1564220>,
    <2.0784322, 0.0011044, 18.1564220>,
    <2.0406684, 0.0164990, 18.1564220>,
    <2.1589474, -0.0317085, 18.1573801>,
    <2.1539599, -0.0296848, 18.1564220>,
    <2.1199255, -0.0158005, 18.1573801>,
    <2.1161960, -0.0142902, 18.1564220>,
    <2.1689225, -0.0357558, 18.1592964>,
    <2.0858466, -0.0018864, 18.1592964>,
    <2.1639350, -0.0337321, 18.1583383>,
    <2.1273846, -0.0188211, 18.1592964>,
    <2.0833751, -0.0008895, 18.1583383>,
    <2.1236550, -0.0173108, 18.1583383>,
    <2.0027706, 0.0319829, 18.1592964>,
    <2.0443086, 0.0150482, 18.1592964>,
    <2.0028152, 0.0319531, 18.1583383>,
    <2.0430952, 0.0155318, 18.1583383>,
    <2.1587407, 0.1700150, 18.1573801>,
    <2.1588441, 0.0691533, 18.1573801>,
    <2.1537787, 0.1710322, 18.1564220>,
    <2.1538693, 0.0706737, 18.1564220>,
    <2.1585340, 0.3717385, 18.1573801>,
    <2.1535976, 0.3717492, 18.1564220>,
    <2.1586373, 0.2708768, 18.1573801>,
    <2.1536882, 0.2713907, 18.1564220>,
    <2.1684068, 0.3717172, 18.1592964>,
    <2.1686646, 0.1679807, 18.1592964>,
    <2.1634704, 0.3717279, 18.1583383>,
    <2.1685357, 0.2698490, 18.1592964>,
    <2.1637027, 0.1689979, 18.1583383>,
    <2.1635865, 0.2703629, 18.1583383>,
    <2.1687936, 0.0661125, 18.1592964>,
    <2.1638188, 0.0676329, 18.1583383>,
    <2.0812351, 0.3717178, 18.1573801>,
    <2.1198845, 0.3717282, 18.1573801>,
    <2.0787910, 0.3717287, 18.1564220>,
    <2.1161943, 0.3717389, 18.1564220>,
    <2.0039361, 0.3716971, 18.1573801>,
    <2.0039844, 0.3717082, 18.1564220>,
    <2.0425856, 0.3717074, 18.1573801>,
    <2.0413877, 0.3717184, 18.1564220>,
    <2.0038397, 0.3716749, 18.1592964>,
    <2.0861232, 0.3716960, 18.1592964>,
    <2.0038879, 0.3716860, 18.1583383>,
    <2.0449814, 0.3716854, 18.1592964>,
    <2.0836791, 0.3717069, 18.1583383>,
    <2.0437835, 0.3716964, 18.1583383>,
    <2.1272650, 0.3717066, 18.1592964>,
    <2.1235748, 0.3717174, 18.1583383>,
    <2.0869275, -0.0023231, 18.2324892>,
    <2.0027700, 0.0319832, 18.2344341>,
    <2.0448476, 0.0148309, 18.2333227>,
    <2.0027703, 0.0319831, 18.1968653>,
    <2.0858626, -0.0018929, 18.1968653>,
    <2.0443164, 0.0150451, 18.1968653>,
    <2.1710991, -0.0366389, 18.2322113>,
    <2.1689548, -0.0357689, 18.1968653>,
    <2.1290121, -0.0194802, 18.2322113>,
    <2.1274087, -0.0188309, 18.1968653>,
    <2.1901713, -0.0443772, 18.2873438>,
    <2.0963900, -0.0061433, 18.2890109>,
    <2.1774673, -0.0392227, 18.2631118>,
    <2.1432736, -0.0252555, 18.2873438>,
    <2.0900901, -0.0036007, 18.2642232>,
    <2.1337740, -0.0214086, 18.2631118>,
    <2.0027694, 0.0319836, 18.3095719>,
    <2.0495348, 0.0129501, 18.2940122>,
    <2.0027697, 0.0319834, 18.2720030>,
    <2.0464252, 0.0141945, 18.2675574>,
    <2.1708301, 0.1675368, 18.2322113>,
    <2.1709646, 0.0654490, 18.2322113>,
    <2.1686968, 0.1679741, 18.1968653>,
    <2.1688258, 0.0661026, 18.1968653>,
    <2.1705610, 0.3717126, 18.2322113>,
    <2.1684387, 0.3717171, 18.1968653>,
    <2.1706955, 0.2696247, 18.2322113>,
    <2.1685678, 0.2698456, 18.1968653>,
    <2.1894375, 0.3716718, 18.2873438>,
    <2.1898044, 0.1636473, 18.2873438>,
    <2.1768638, 0.3716990, 18.2631118>,
    <2.1896209, 0.2676596, 18.2873438>,
    <2.1771655, 0.1662381, 18.2631118>,
    <2.1770147, 0.2689685, 18.2631118>,
    <2.1899878, 0.0596350, 18.2873438>,
    <2.1773164, 0.0635077, 18.2631118>,
    <2.0871924, 0.3716919, 18.2324892>,
    <2.1288754, 0.3717019, 18.2322113>,
    <2.0861391, 0.3716960, 18.1968653>,
    <2.1272889, 0.3717065, 18.1968653>,
    <2.0038391, 0.3716747, 18.2344341>,
    <2.0038394, 0.3716748, 18.1968653>,
    <2.0455144, 0.3716830, 18.2333227>,
    <2.0449892, 0.3716854, 18.1968653>,
    <2.0038384, 0.3716746, 18.3095719>,
    <2.0965512, 0.3716532, 18.2890109>,
    <2.0038387, 0.3716746, 18.2720030>,
    <2.0501463, 0.3716527, 18.2940122>,
    <2.0903206, 0.3716797, 18.2642232>,
    <2.0470746, 0.3716760, 18.2675574>,
    <2.1429867, 0.3716607, 18.2873438>,
    <2.1335871, 0.3716882, 18.2631118>,
    <2.1194806, -0.0154541, 18.3131904>,
    <2.0021640, 0.0323869, 18.3135798>,
    <2.0608223, 0.0084664, 18.3133573>,
    <2.0024667, 0.0321852, 18.3115759>,
    <2.1068665, -0.0103682, 18.3037960>,
    <2.0546619, 0.0109117, 18.3071303>,
    <2.2367979, -0.0632955, 18.3131347>,
    <2.2113231, -0.0529593, 18.3026846>,
    <2.1781392, -0.0393747, 18.3131347>,
    <2.1590901, -0.0316606, 18.3026846>,
    <2.2842175, -0.0825355, 18.3353648>,
    <2.1429646, -0.0249237, 18.3340315>,
    <2.2624710, -0.0737121, 18.3226946>,
    <2.2135978, -0.0537341, 18.3353648>,
    <2.1321932, -0.0205798, 18.3218058>,
    <2.1973366, -0.0471489, 18.3226946>,
    <2.0015586, 0.0327901, 18.3175878>,
    <2.0723044, 0.0039047, 18.3300317>,
    <2.0018613, 0.0325885, 18.3155838>,
    <2.0670317, 0.0060014, 18.3191392>,
    <2.2361918, 0.1541384, 18.3131347>,
    <2.2364948, 0.0454214, 18.3131347>,
    <2.2108477, 0.1593337, 18.3026846>,
    <2.2110854, 0.0531872, 18.3026846>,
    <2.2355857, 0.3715722, 18.3131347>,
    <2.2103722, 0.3716266, 18.3026846>,
    <2.2358887, 0.2628553, 18.3131347>,
    <2.2106099, 0.2654801, 18.3026846>,
    <2.2825188, 0.3714709, 18.3353648>,
    <2.2833682, 0.1444677, 18.3353648>,
    <2.2609953, 0.3715174, 18.3226946>,
    <2.2829435, 0.2579693, 18.3353648>,
    <2.2617332, 0.1489027, 18.3226946>,
    <2.2613642, 0.2602100, 18.3226946>,
    <2.2837929, 0.0309661, 18.3353648>,
    <2.2621021, 0.0375953, 18.3226946>,
    <2.1193847, 0.3715480, 18.3131904>,
    <2.1774851, 0.3715601, 18.3131347>,
    <2.1069112, 0.3716059, 18.3037960>,
    <2.1586366, 0.3716151, 18.3026846>,
    <2.0031844, 0.3715240, 18.3135798>,
    <2.0035114, 0.3715993, 18.3115759>,
    <2.0612845, 0.3715360, 18.3133573>,
    <2.0552062, 0.3716014, 18.3071303>,
    <2.0025303, 0.3713733, 18.3175878>,
    <2.1426072, 0.3714412, 18.3340315>,
    <2.0028573, 0.3714486, 18.3155838>,
    <2.0726150, 0.3714179, 18.3300317>,
    <2.1319555, 0.3714897, 18.3218058>,
    <2.0674113, 0.3714703, 18.3191392>,
    <2.2125703, 0.3714577, 18.3353648>,
    <2.1964803, 0.3715047, 18.3226946>,
    <2.1535564, -0.0291992, 18.3800376>,
    <2.0015296, 0.0328094, 18.3784821>,
    <2.0775441, 0.0018043, 18.3793709>,
    <2.0015441, 0.0327997, 18.3480349>,
    <2.1497555, -0.0276642, 18.3542569>,
    <2.0756543, 0.0025648, 18.3515903>,
    <2.3055697, -0.0911989, 18.3802598>,
    <2.2979128, -0.0880922, 18.3551457>,
    <2.2295641, -0.0601998, 18.3802598>,
    <2.2238387, -0.0578812, 18.3551457>,
    <2.3108192, -0.0933288, 18.4393764>,
    <2.1561599, -0.0302501, 18.4393764>,
    <2.3092008, -0.0926722, 18.4089292>,
    <2.2334896, -0.0617895, 18.4393764>,
    <2.1553580, -0.0299266, 18.4089292>,
    <2.2322794, -0.0612994, 18.4089292>,
    <2.0015006, 0.0328287, 18.4393764>,
    <2.0788303, 0.0012893, 18.4393764>,
    <2.0015151, 0.0328190, 18.4089292>,
    <2.0784365, 0.0014462, 18.4089292>,
    <2.3046107, 0.1401132, 18.3802598>,
    <2.3050902, 0.0244572, 18.3802598>,
    <2.2969932, 0.1416747, 18.3551457>,
    <2.2974530, 0.0267913, 18.3551457>,
    <2.3036518, 0.3714253, 18.3802598>,
    <2.2960735, 0.3714417, 18.3551457>,
    <2.3041313, 0.2557693, 18.3802598>,
    <2.2965334, 0.2565582, 18.3551457>,
    <2.3088475, 0.3714141, 18.4393764>,
    <2.3098333, 0.1390426, 18.4393764>,
    <2.3072457, 0.3714176, 18.4089292>,
    <2.3093404, 0.2552284, 18.4393764>,
    <2.3082233, 0.1393727, 18.4089292>,
    <2.3077345, 0.2553951, 18.4089292>,
    <2.3103263, 0.0228569, 18.4393764>,
    <2.3087121, 0.0233502, 18.4089292>,
    <2.1530827, 0.3713974, 18.3800376>,
    <2.2283685, 0.3714116, 18.3802598>,
    <2.1493233, 0.3714124, 18.3542569>,
    <2.2227033, 0.3714282, 18.3551457>,
    <2.0024990, 0.3713661, 18.3784821>,
    <2.0025147, 0.3713697, 18.3480349>,
    <2.0777921, 0.3713820, 18.3793709>,
    <2.0759238, 0.3713922, 18.3515903>,
    <2.0024677, 0.3713589, 18.4393764>,
    <2.1556576, 0.3713865, 18.4393764>,
    <2.0024834, 0.3713625, 18.4089292>,
    <2.0790627, 0.3713727, 18.4393764>,
    <2.1548645, 0.3713900, 18.4089292>,
    <2.0786740, 0.3713763, 18.4089292>,
    <2.2322525, 0.3714003, 18.4393764>,
    <2.2310551, 0.3714038, 18.4089292>,
    <2.1647113, -0.0336996, 18.4393764>,
    <2.0013462, 0.0329316, 18.4393764>,
    <2.0830288, -0.0003840, 18.4393764>,
    <2.0014234, 0.0328801, 18.4393764>,
    <2.1604356, -0.0319749, 18.4393764>,
    <2.0809295, 0.0004526, 18.4393764>,
    <2.3280765, -0.1003308, 18.4393764>,
    <2.3194479, -0.0968298, 18.4393764>,
    <2.2463939, -0.0670152, 18.4393764>,
    <2.2399417, -0.0644023, 18.4393764>,
    <2.3453338, -0.1073328, 18.4393764>,
    <2.1732628, -0.0371492, 18.4393764>,
    <2.3367052, -0.1038318, 18.4393764>,
    <2.2592983, -0.0722410, 18.4393764>,
    <2.1689871, -0.0354244, 18.4393764>,
    <2.2528461, -0.0696281, 18.4393764>,
    <2.0011917, 0.0330344, 18.4393764>,
    <2.0872272, -0.0020574, 18.4393764>,
    <2.0012689, 0.0329830, 18.4393764>,
    <2.0851280, -0.0012207, 18.4393764>,
    <2.3270021, 0.1355232, 18.4393764>,
    <2.3275393, 0.0175962, 18.4393764>,
    <2.3184177, 0.1372829, 18.4393764>,
    <2.3189328, 0.0202265, 18.4393764>,
    <2.3259277, 0.3713772, 18.4393764>,
    <2.3173876, 0.3713957, 18.4393764>,
    <2.3264649, 0.2534502, 18.4393764>,
    <2.3179027, 0.2543393, 18.4393764>,
    <2.3430079, 0.3713404, 18.4393764>,
    <2.3441709, 0.1320038, 18.4393764>,
    <2.3344678, 0.3713588, 18.4393764>,
    <2.3435894, 0.2516721, 18.4393764>,
    <2.3355865, 0.1337635, 18.4393764>,
    <2.3350272, 0.2525612, 18.4393764>,
    <2.3447524, 0.0123355, 18.4393764>,
    <2.3361458, 0.0149659, 18.4393764>,
    <2.1641143, 0.3713489, 18.4393764>,
    <2.2450210, 0.3713631, 18.4393764>,
    <2.1598859, 0.3713677, 18.4393764>,
    <2.2386368, 0.3713817, 18.4393764>,
    <2.0023009, 0.3713205, 18.4393764>,
    <2.0023843, 0.3713397, 18.4393764>,
    <2.0832076, 0.3713347, 18.4393764>,
    <2.0811351, 0.3713537, 18.4393764>,
    <2.0021340, 0.3712821, 18.4393764>,
    <2.1725710, 0.3713112, 18.4393764>,
    <2.0022174, 0.3713013, 18.4393764>,
    <2.0873525, 0.3712967, 18.4393764>,
    <2.1683426, 0.3713300, 18.4393764>,
    <2.0852800, 0.3713157, 18.4393764>,
    <2.2577895, 0.3713258, 18.4393764>,
    <2.2514052, 0.3713444, 18.4393764>,
    <2.1732628, -0.0371492, 18.4905874>,
    <2.0011917, 0.0330344, 18.4905874>,
    <2.0872272, -0.0020574, 18.4905874>,
    <2.0011917, 0.0330344, 18.4649819>,
    <2.1732628, -0.0371492, 18.4649819>,
    <2.0872272, -0.0020574, 18.4649819>,
    <2.3453338, -0.1073328, 18.4905874>,
    <2.3453338, -0.1073328, 18.4649819>,
    <2.2592983, -0.0722410, 18.4905874>,
    <2.2592983, -0.0722410, 18.4649819>,
    <2.3453338, -0.1073328, 18.5161929>,
    <2.1732628, -0.0371492, 18.5161929>,
    <2.2592983, -0.0722410, 18.5161929>,
    <2.0011917, 0.0330344, 18.5161929>,
    <2.0872272, -0.0020574, 18.5161929>,
    <2.3441709, 0.1320038, 18.4905874>,
    <2.3447524, 0.0123355, 18.4905874>,
    <2.3441709, 0.1320038, 18.4649819>,
    <2.3447524, 0.0123355, 18.4649819>,
    <2.3430079, 0.3713404, 18.4905874>,
    <2.3430079, 0.3713404, 18.4649819>,
    <2.3435894, 0.2516721, 18.4905874>,
    <2.3435894, 0.2516721, 18.4649819>,
    <2.3430079, 0.3713404, 18.5161929>,
    <2.3441709, 0.1320038, 18.5161929>,
    <2.3435894, 0.2516721, 18.5161929>,
    <2.3447524, 0.0123355, 18.5161929>,
    <2.1725710, 0.3713112, 18.4905874>,
    <2.2577895, 0.3713258, 18.4905874>,
    <2.1725710, 0.3713112, 18.4649819>,
    <2.2577895, 0.3713258, 18.4649819>,
    <2.0021340, 0.3712821, 18.4905874>,
    <2.0021340, 0.3712821, 18.4649819>,
    <2.0873525, 0.3712967, 18.4905874>,
    <2.0873525, 0.3712967, 18.4649819>,
    <2.0021340, 0.3712821, 18.5161929>,
    <2.1725710, 0.3713112, 18.5161929>,
    <2.0873525, 0.3712967, 18.5161929>,
    <2.2577895, 0.3713258, 18.5161929>,
    <2.0016629, 0.2021583, 18.4905874>,
    <2.0011917, 0.0330344, 18.4905874>,
    <2.0016629, 0.2021583, 18.4393764>,
    <2.0014273, 0.1175963, 18.4905874>,
    <2.0011917, 0.0330344, 18.4649819>,
    <2.0014273, 0.1175963, 18.4393764>,
    <2.0016629, 0.2021583, 18.4649819>,
    <2.0014273, 0.1175963, 18.4649819>,
    <2.0021340, 0.3712821, 18.4905874>,
    <2.0018984, 0.2867202, 18.4393764>,
    <2.0021340, 0.3712821, 18.4649819>,
    <2.0018984, 0.2867202, 18.4905874>,
    <2.0018984, 0.2867202, 18.4649819>,
    <2.0016629, 0.2021583, 18.5417983>,
    <2.0021340, 0.3712821, 18.5161929>,
    <2.0018984, 0.2867202, 18.5417983>,
    <2.0016629, 0.2021583, 18.5161929>,
    <2.0018984, 0.2867202, 18.5161929>,
    <2.0014273, 0.1175963, 18.5417983>,
    <2.0011917, 0.0330344, 18.5161929>,
    <2.0014273, 0.1175963, 18.5161929>,
    <2.0018235, 0.2021260, 18.4393764>,
    <2.0019842, 0.2020938, 18.4393764>,
    <2.0019038, 0.2021099, 18.4393764>,
    <2.0017424, 0.1174612, 18.4393764>,
    <2.0015848, 0.1175288, 18.4393764>,
    <2.0016636, 0.1174950, 18.4393764>,
    <2.0016629, 0.2021583, 18.4393764>,
    <2.0014273, 0.1175963, 18.4393764>,
    <2.0017432, 0.2021421, 18.4393764>,
    <2.0015061, 0.1175626, 18.4393764>,
    <2.0018984, 0.2867202, 18.4393764>,
    <2.0020622, 0.2867233, 18.4393764>,
    <2.0019803, 0.2867217, 18.4393764>,
    <2.0022259, 0.2867264, 18.4393764>,
    <2.0021441, 0.2867248, 18.4393764>,
    <2.0020143, 0.2020878, 18.3784821>,
    <2.0015296, 0.0328094, 18.3784821>,
    <2.0020444, 0.2020817, 18.3175878>,
    <2.0017719, 0.1174486, 18.3784821>,
    <2.0015441, 0.0327997, 18.3480349>,
    <2.0018015, 0.1174359, 18.3175878>,
    <2.0020294, 0.2020847, 18.3480349>,
    <2.0017867, 0.1174422, 18.3480349>,
    <2.0024990, 0.3713661, 18.3784821>,
    <2.0022874, 0.2867275, 18.3175878>,
    <2.0025147, 0.3713697, 18.3480349>,
    <2.0022567, 0.2867270, 18.3784821>,
    <2.0022720, 0.2867272, 18.3480349>,
    <2.0019842, 0.2020938, 18.4393764>,
    <2.0024834, 0.3713625, 18.4089292>,
    <2.0022259, 0.2867264, 18.4393764>,
    <2.0019992, 0.2020908, 18.4089292>,
    <2.0022413, 0.2867267, 18.4089292>,
    <2.0017424, 0.1174612, 18.4393764>,
    <2.0015151, 0.0328190, 18.4089292>,
    <2.0017572, 0.1174549, 18.4089292>,
    <2.0026742, 0.2019554, 18.3135798>,
    <2.0033039, 0.2018291, 18.3095719>,
    <2.0029891, 0.2018923, 18.3115759>,
    <2.0030367, 0.1169064, 18.3095719>,
    <2.0024191, 0.1171711, 18.3135798>,
    <2.0027279, 0.1170388, 18.3115759>,
    <2.0020444, 0.2020817, 18.3175878>,
    <2.0018015, 0.1174359, 18.3175878>,
    <2.0023593, 0.2020186, 18.3155838>,
    <2.0021103, 0.1173035, 18.3155838>,
    <2.0022874, 0.2867275, 18.3175878>,
    <2.0029293, 0.2867397, 18.3135798>,
    <2.0026083, 0.2867336, 18.3155838>,
    <2.0035712, 0.2867518, 18.3095719>,
    <2.0032502, 0.2867458, 18.3115759>,
    <2.0033045, 0.2018290, 18.2344341>,
    <2.0027700, 0.0319832, 18.2344341>,
    <2.0033051, 0.2018289, 18.1592964>,
    <2.0030373, 0.1169061, 18.2344341>,
    <2.0027703, 0.0319831, 18.1968653>,
    <2.0030379, 0.1169059, 18.1592964>,
    <2.0033048, 0.2018289, 18.1968653>,
    <2.0030376, 0.1169060, 18.1968653>,
    <2.0038391, 0.3716747, 18.2344341>,
    <2.0035724, 0.2867519, 18.1592964>,
    <2.0038394, 0.3716748, 18.1968653>,
    <2.0035718, 0.2867518, 18.2344341>,
    <2.0035721, 0.2867519, 18.1968653>,
    <2.0033039, 0.2018291, 18.3095719>,
    <2.0038387, 0.3716746, 18.2720030>,
    <2.0035712, 0.2867518, 18.3095719>,
    <2.0033042, 0.2018290, 18.2720030>,
    <2.0035715, 0.2867518, 18.2720030>,
    <2.0030367, 0.1169064, 18.3095719>,
    <2.0027697, 0.0319834, 18.2720030>,
    <2.0030370, 0.1169062, 18.2720030>,
    <2.0033980, 0.2018102, 18.1573801>,
    <2.0034909, 0.2017916, 18.1554639>,
    <2.0034444, 0.2018009, 18.1564220>,
    <2.0032200, 0.1168278, 18.1554639>,
    <2.0031289, 0.1168668, 18.1573801>,
    <2.0031745, 0.1168473, 18.1564220>,
    <2.0033051, 0.2018289, 18.1592964>,
    <2.0030379, 0.1169059, 18.1592964>,
    <2.0033516, 0.2018195, 18.1583383>,
    <2.0030834, 0.1168863, 18.1583383>,
    <2.0035724, 0.2867519, 18.1592964>,
    <2.0036671, 0.2867537, 18.1573801>,
    <2.0036197, 0.2867528, 18.1583383>,
    <2.0037617, 0.2867554, 18.1554639>,
    <2.0037144, 0.2867545, 18.1564220>,
    <2.0036787, 0.2017539, 18.1389725>,
    <2.0031356, 0.0317398, 18.1386133>,
    <2.0038104, 0.2017275, 18.1258340>,
    <2.0034061, 0.1167471, 18.1388528>,
    <2.0032288, 0.0316777, 18.1301880>,
    <2.0035448, 0.1166831, 18.1251156>,
    <2.0037576, 0.2017381, 18.1316249>,
    <2.0034892, 0.1167087, 18.1311460>,
    <2.0042339, 0.3717656, 18.1386133>,
    <2.0041002, 0.2867671, 18.1251156>,
    <2.0043346, 0.3717888, 18.1301880>,
    <2.0039553, 0.2867600, 18.1388528>,
    <2.0040421, 0.2867643, 18.1311460>,
    <2.0034909, 0.2017916, 18.1554639>,
    <2.0041333, 0.3717425, 18.1470386>,
    <2.0037617, 0.2867554, 18.1554639>,
    <2.0035878, 0.2017722, 18.1470386>,
    <2.0038605, 0.2867573, 18.1470386>,
    <2.0032200, 0.1168278, 18.1554639>,
    <2.0030424, 0.0318019, 18.1470386>,
    <2.0033151, 0.1167870, 18.1470386>,
    <2.0038098, 0.2017276, 18.1205987>,
    <2.0038231, 0.2017250, 18.1224380>,
    <2.0035347, 0.1166920, 18.1204790>,
    <2.0035534, 0.1166812, 18.1219591>,
    <2.0037530, 0.2017390, 18.1187163>,
    <2.0034770, 0.1167176, 18.1187163>,
    <2.0037844, 0.2017327, 18.1194779>,
    <2.0035079, 0.1167044, 18.1194779>,
    <2.0040289, 0.2867605, 18.1187163>,
    <2.0040889, 0.2867625, 18.1204790>,
    <2.0040609, 0.2867611, 18.1194779>,
    <2.0041089, 0.2867655, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.3773516, 0.9260271, 0.0089233>,
    <0.3773535, 0.9260316, 0.0083508>,
    <0.3773669, 0.9260259, 0.0083853>,
    <0.3773651, 0.9260214, 0.0089402>,
    <0.3773632, 0.9260167, 0.0094950>,
    <0.3773497, 0.9260222, 0.0094957>,
    <0.3773497, 0.9260222, 0.0094957>,
    <0.3773353, 0.9260280, 0.0094964>,
    <0.3773373, 0.9260331, 0.0089052>,
    <0.3773373, 0.9260331, 0.0089052>,
    <0.3773392, 0.9260378, 0.0083140>,
    <0.3773553, 0.9260359, 0.0077783>,
    <0.3773686, 0.9260300, 0.0078304>,
    <0.3773392, 0.9260378, 0.0083140>,
    <0.3773410, 0.9260422, 0.0077228>,
    <0.3773410, 0.9260422, 0.0077228>,
    <0.3773427, 0.9260462, 0.0071315>,
    <0.3773569, 0.9260399, 0.0072058>,
    <0.3773569, 0.9260399, 0.0072058>,
    <0.3773702, 0.9260339, 0.0072755>,
    <0.3773811, 0.9260245, 0.0078794>,
    <0.3773795, 0.9260204, 0.0084177>,
    <0.3773702, 0.9260339, 0.0072755>,
    <0.3773827, 0.9260283, 0.0073411>,
    <0.3773827, 0.9260283, 0.0073411>,
    <0.3773945, 0.9260230, 0.0074028>,
    <0.3773930, 0.9260193, 0.0079256>,
    <0.3773930, 0.9260193, 0.0079256>,
    <0.3773913, 0.9260153, 0.0084483>,
    <0.3773777, 0.9260161, 0.0089561>,
    <0.3773913, 0.9260153, 0.0084483>,
    <0.3773896, 0.9260111, 0.0089711>,
    <0.3773896, 0.9260111, 0.0089711>,
    <0.3773878, 0.9260066, 0.0094938>,
    <0.3773758, 0.9260115, 0.0094944>,
    <0.3773758, 0.9260115, 0.0094944>,
    <0.3773632, 0.9260167, 0.0094950>,
    <-0.2206332, 0.0000469, -0.9753569>,
    <-0.2211788, 0.0000471, -0.9752333>,
    <-0.2211827, 0.0000270, -0.9752324>,
    <-0.2206390, 0.0000269, -0.9753555>,
    <-0.2200979, 0.0000269, -0.9754778>,
    <-0.2200902, 0.0000468, -0.9754795>,
    <-0.2200902, 0.0000468, -0.9754795>,
    <-0.2200825, 0.0000669, -0.9754813>,
    <-0.2206273, 0.0000671, -0.9753582>,
    <-0.2206273, 0.0000671, -0.9753582>,
    <-0.2211749, 0.0000672, -0.9752342>,
    <-0.2217270, 0.0000472, -0.9751088>,
    <-0.2217290, 0.0000271, -0.9751083>,
    <-0.2211749, 0.0000672, -0.9752342>,
    <-0.2217250, 0.0000674, -0.9751092>,
    <-0.2217250, 0.0000674, -0.9751092>,
    <-0.2222778, 0.0000676, -0.9749834>,
    <-0.2222779, 0.0000473, -0.9749834>,
    <-0.2222779, 0.0000473, -0.9749834>,
    <-0.2222779, 0.0000271, -0.9749833>,
    <-0.2217310, 0.0000071, -0.9751079>,
    <-0.2211866, 0.0000071, -0.9752315>,
    <-0.2222779, 0.0000271, -0.9749833>,
    <-0.2222780, 0.0000071, -0.9749833>,
    <-0.2222780, 0.0000071, -0.9749833>,
    <-0.2222780, -0.0000127, -0.9749833>,
    <-0.2217329, -0.0000127, -0.9751074>,
    <-0.2217329, -0.0000127, -0.9751074>,
    <-0.2211904, -0.0000127, -0.9752306>,
    <-0.2206448, 0.0000071, -0.9753542>,
    <-0.2211904, -0.0000127, -0.9752306>,
    <-0.2206505, -0.0000126, -0.9753529>,
    <-0.2206505, -0.0000126, -0.9753529>,
    <-0.2201132, -0.0000126, -0.9754743>,
    <-0.2201056, 0.0000071, -0.9754761>,
    <-0.2201056, 0.0000071, -0.9754761>,
    <-0.2200979, 0.0000269, -0.9754778>,
    <0.0003486, -0.9999426, 0.0107096>,
    <0.0003486, -0.9999456, 0.0104237>,
    <0.0003407, -0.9999458, 0.0104065>,
    <0.0003407, -0.9999429, 0.0106836>,
    <0.0003407, -0.9999399, 0.0109607>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003571, -0.9999391, 0.0110326>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003486, -0.9999486, 0.0101378>,
    <0.0003407, -0.9999486, 0.0101293>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999514, 0.0098515>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999487, 0.0101214>,
    <0.0003332, -0.9999460, 0.0103903>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003262, -0.9999514, 0.0098528>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003332, -0.9999431, 0.0106591>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999406, 0.0108971>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003407, -0.9999399, 0.0109607>,
    <-0.3774272, -0.9260380, 0.0015558>,
    <-0.3774272, -0.9260381, 0.0014706>,
    <-0.3774476, -0.9260298, 0.0014796>,
    <-0.3774476, -0.9260296, 0.0015602>,
    <-0.3774475, -0.9260295, 0.0016409>,
    <-0.3774271, -0.9260378, 0.0016411>,
    <-0.3774271, -0.9260378, 0.0016411>,
    <-0.3774043, -0.9260471, 0.0016413>,
    <-0.3774044, -0.9260473, 0.0015509>,
    <-0.3774044, -0.9260473, 0.0015509>,
    <-0.3774044, -0.9260474, 0.0014605>,
    <-0.3774273, -0.9260382, 0.0013854>,
    <-0.3774477, -0.9260299, 0.0013990>,
    <-0.3774044, -0.9260474, 0.0014605>,
    <-0.3774045, -0.9260475, 0.0013701>,
    <-0.3774045, -0.9260475, 0.0013701>,
    <-0.3774045, -0.9260476, 0.0012798>,
    <-0.3774273, -0.9260383, 0.0013001>,
    <-0.3774273, -0.9260383, 0.0013001>,
    <-0.3774477, -0.9260300, 0.0013183>,
    <-0.3774659, -0.9260224, 0.0014112>,
    <-0.3774659, -0.9260223, 0.0014877>,
    <-0.3774477, -0.9260300, 0.0013183>,
    <-0.3774660, -0.9260225, 0.0013347>,
    <-0.3774660, -0.9260225, 0.0013347>,
    <-0.3774825, -0.9260157, 0.0013494>,
    <-0.3774824, -0.9260156, 0.0014222>,
    <-0.3774824, -0.9260156, 0.0014222>,
    <-0.3774824, -0.9260155, 0.0014950>,
    <-0.3774659, -0.9260222, 0.0015642>,
    <-0.3774824, -0.9260155, 0.0014950>,
    <-0.3774824, -0.9260154, 0.0015678>,
    <-0.3774824, -0.9260154, 0.0015678>,
    <-0.3774823, -0.9260153, 0.0016406>,
    <-0.3774658, -0.9260221, 0.0016407>,
    <-0.3774658, -0.9260221, 0.0016407>,
    <-0.3774475, -0.9260295, 0.0016409>,
    <0.7945895, 0.0001919, -0.6071470>,
    <0.7953358, 0.0001921, -0.6061691>,
    <0.7953466, 0.0003366, -0.6061548>,
    <0.7946057, 0.0003363, -0.6071257>,
    <0.7938650, 0.0003360, -0.6080939>,
    <0.7938434, 0.0001918, -0.6081222>,
    <0.7938434, 0.0001918, -0.6081222>,
    <0.7938215, 0.0000454, -0.6081509>,
    <0.7945730, 0.0000455, -0.6071686>,
    <0.7945730, 0.0000455, -0.6071686>,
    <0.7953248, 0.0000455, -0.6061836>,
    <0.7960823, 0.0001923, -0.6051884>,
    <0.7960877, 0.0003369, -0.6051811>,
    <0.7953248, 0.0000455, -0.6061836>,
    <0.7960767, 0.0000456, -0.6051957>,
    <0.7960767, 0.0000456, -0.6051957>,
    <0.7968288, 0.0000456, -0.6042051>,
    <0.7968289, 0.0001925, -0.6042049>,
    <0.7968289, 0.0001925, -0.6042049>,
    <0.7968290, 0.0003372, -0.6042048>,
    <0.7960931, 0.0004795, -0.6051740>,
    <0.7953573, 0.0004791, -0.6061407>,
    <0.7968290, 0.0003372, -0.6042048>,
    <0.7968291, 0.0004799, -0.6042046>,
    <0.7968291, 0.0004799, -0.6042046>,
    <0.7968291, 0.0006206, -0.6042044>,
    <0.7960984, 0.0006200, -0.6051669>,
    <0.7960984, 0.0006200, -0.6051669>,
    <0.7953678, 0.0006195, -0.6061267>,
    <0.7946217, 0.0004786, -0.6071047>,
    <0.7953678, 0.0006195, -0.6061267>,
    <0.7946375, 0.0006189, -0.6070840>,
    <0.7946375, 0.0006189, -0.6070840>,
    <0.7939073, 0.0006183, -0.6080385>,
    <0.7938863, 0.0004782, -0.6080660>,
    <0.7938863, 0.0004782, -0.6080660>,
    <0.7938650, 0.0003360, -0.6080939>,
    <-0.0003128, 0.9999983, 0.0018311>,
    <-0.0003128, 0.9999984, 0.0017886>,
    <-0.0003008, 0.9999984, 0.0017841>,
    <-0.0003008, 0.9999983, 0.0018243>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003262, 0.9999982, 0.0018839>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003128, 0.9999984, 0.0017460>,
    <-0.0003008, 0.9999984, 0.0017438>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999985, 0.0017033>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999984, 0.0017418>,
    <-0.0002901, 0.9999984, 0.0017800>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002803, 0.9999985, 0.0017037>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002901, 0.9999983, 0.0018183>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018491>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <-0.3774721, -0.9259595, 0.0106678>,
    <-0.3774740, -0.9259641, 0.0101898>,
    <-0.3774839, -0.9259597, 0.0102200>,
    <-0.3774821, -0.9259553, 0.0106826>,
    <-0.3774802, -0.9259506, 0.0111453>,
    <-0.3774701, -0.9259547, 0.0111459>,
    <-0.3774701, -0.9259547, 0.0111459>,
    <-0.3774594, -0.9259591, 0.0111465>,
    <-0.3774614, -0.9259640, 0.0106520>,
    <-0.3774614, -0.9259640, 0.0106520>,
    <-0.3774634, -0.9259688, 0.0101575>,
    <-0.3774758, -0.9259685, 0.0097117>,
    <-0.3774857, -0.9259640, 0.0097574>,
    <-0.3774634, -0.9259688, 0.0101575>,
    <-0.3774652, -0.9259733, 0.0096629>,
    <-0.3774652, -0.9259733, 0.0096629>,
    <-0.3774670, -0.9259777, 0.0091684>,
    <-0.3774775, -0.9259727, 0.0092337>,
    <-0.3774775, -0.9259727, 0.0092337>,
    <-0.3774874, -0.9259681, 0.0092947>,
    <-0.3774950, -0.9259598, 0.0098002>,
    <-0.3774933, -0.9259556, 0.0102484>,
    <-0.3774874, -0.9259681, 0.0092947>,
    <-0.3774966, -0.9259638, 0.0093520>,
    <-0.3774966, -0.9259638, 0.0093520>,
    <-0.3775053, -0.9259597, 0.0094058>,
    <-0.3775037, -0.9259558, 0.0098404>,
    <-0.3775037, -0.9259558, 0.0098404>,
    <-0.3775020, -0.9259517, 0.0102750>,
    <-0.3774915, -0.9259513, 0.0106965>,
    <-0.3775020, -0.9259517, 0.0102750>,
    <-0.3775003, -0.9259475, 0.0107096>,
    <-0.3775003, -0.9259475, 0.0107096>,
    <-0.3774985, -0.9259431, 0.0111442>,
    <-0.3774897, -0.9259467, 0.0111447>,
    <-0.3774897, -0.9259467, 0.0111447>,
    <-0.3774802, -0.9259506, 0.0111453>,
    <0.1891715, 0.0001707, -0.9819440>,
    <0.1896252, 0.0001711, -0.9818565>,
    <0.1896297, 0.0001943, -0.9818557>,
    <0.1891783, 0.0001939, -0.9819427>,
    <0.1887291, 0.0001934, -0.9820292>,
    <0.1887200, 0.0001703, -0.9820309>,
    <0.1887200, 0.0001703, -0.9820309>,
    <0.1887109, 0.0001470, -0.9820327>,
    <0.1891646, 0.0001473, -0.9819454>,
    <0.1891646, 0.0001473, -0.9819454>,
    <0.1896205, 0.0001477, -0.9818574>,
    <0.1900809, 0.0001715, -0.9817684>,
    <0.1900833, 0.0001948, -0.9817680>,
    <0.1896205, 0.0001477, -0.9818574>,
    <0.1900786, 0.0001480, -0.9817689>,
    <0.1900786, 0.0001480, -0.9817689>,
    <0.1905388, 0.0001484, -0.9816797>,
    <0.1905389, 0.0001719, -0.9816796>,
    <0.1905389, 0.0001719, -0.9816796>,
    <0.1905389, 0.0001953, -0.9816796>,
    <0.1900856, 0.0002178, -0.9817675>,
    <0.1896343, 0.0002173, -0.9818548>,
    <0.1905389, 0.0001953, -0.9816796>,
    <0.1905390, 0.0002183, -0.9816796>,
    <0.1905390, 0.0002183, -0.9816796>,
    <0.1905390, 0.0002412, -0.9816796>,
    <0.1900878, 0.0002406, -0.9817671>,
    <0.1900878, 0.0002406, -0.9817671>,
    <0.1896388, 0.0002400, -0.9818539>,
    <0.1891851, 0.0002168, -0.9819414>,
    <0.1896388, 0.0002400, -0.9818539>,
    <0.1891918, 0.0002395, -0.9819401>,
    <0.1891918, 0.0002395, -0.9819401>,
    <0.1887469, 0.0002389, -0.9820257>,
    <0.1887380, 0.0002163, -0.9820275>,
    <0.1887380, 0.0002163, -0.9820275>,
    <0.1887291, 0.0001934, -0.9820292>,
    <-0.0002740, 0.9999244, 0.0122917>,
    <-0.0002740, 0.9999273, 0.0120530>,
    <-0.0002681, 0.9999275, 0.0120379>,
    <-0.0002681, 0.9999247, 0.0122689>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002803, 0.9999210, 0.0125631>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002740, 0.9999302, 0.0118142>,
    <-0.0002681, 0.9999303, 0.0118068>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999330, 0.0115751>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999303, 0.0117999>,
    <-0.0002625, 0.9999277, 0.0120237>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002573, 0.9999330, 0.0115763>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002625, 0.9999250, 0.0122476>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999225, 0.0124445>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <-0.3775157, -0.9260032, 0.0000286>,
    <-0.3775187, -0.9260020, 0.0000483>,
    <-0.3774932, -0.9260123, 0.0002015>,
    <-0.3774704, -0.9260217, 0.0001124>,
    <-0.3774656, -0.9260236, 0.0000018>,
    <-0.3775149, -0.9260035, 0.0000018>,
    <-0.3775149, -0.9260035, 0.0000018>,
    <-0.3775220, -0.9260006, 0.0000018>,
    <-0.3775220, -0.9260006, 0.0000018>,
    <-0.3775220, -0.9260006, 0.0000018>,
    <-0.3775220, -0.9260006, 0.0000017>,
    <-0.3775216, -0.9260008, 0.0000551>,
    <-0.3775183, -0.9260021, 0.0002362>,
    <-0.3775220, -0.9260006, 0.0000017>,
    <-0.3775220, -0.9260006, 0.0000016>,
    <-0.3775220, -0.9260006, 0.0000016>,
    <-0.3775220, -0.9260006, 0.0000016>,
    <-0.3775226, -0.9260004, 0.0000540>,
    <-0.3775226, -0.9260004, 0.0000540>,
    <-0.3775268, -0.9259986, 0.0002329>,
    <-0.3775098, -0.9260054, 0.0006391>,
    <-0.3774290, -0.9260383, 0.0005766>,
    <-0.3775268, -0.9259986, 0.0002329>,
    <-0.3775375, -0.9259941, 0.0006314>,
    <-0.3775375, -0.9259941, 0.0006314>,
    <-0.3775558, -0.9259855, 0.0015801>,
    <-0.3775069, -0.9260054, 0.0016064>,
    <-0.3773598, -0.9260653, 0.0016090>,
    <-0.3773274, -0.9260799, 0.0003748>,
    <-0.3770120, -0.9262069, 0.0016370>,
    <-0.3767203, -0.9263252, 0.0018395>,
    <-0.3773093, -0.9260873, 0.0000018>,
    <-0.3773093, -0.9260873, 0.0000018>,
    <-0.3774656, -0.9260236, 0.0000018>,
    <0.9995566, 0.0012744, -0.0297495>,
    <0.9995587, 0.0012744, -0.0296768>,
    <0.9919312, 0.0013238, -0.1267707>,
    <0.9918922, 0.0013237, -0.1270755>,
    <0.9918531, 0.0013237, -0.1273802>,
    <0.9995544, 0.0012744, -0.0298221>,
    <0.9995544, 0.0012744, -0.0298221>,
    <0.9999988, 0.0012658, -0.0008596>,
    <0.9999988, 0.0012658, -0.0008575>,
    <0.9999988, 0.0012658, -0.0008575>,
    <0.9999988, 0.0012658, -0.0008554>,
    <0.9995609, 0.0012744, -0.0296042>,
    <0.9919701, 0.0013238, -0.1264658>,
    <0.9999988, 0.0012658, -0.0008554>,
    <0.9999988, 0.0012658, -0.0008534>,
    <0.9999988, 0.0012658, -0.0008534>,
    <0.9999988, 0.0012658, -0.0008513>,
    <0.9995630, 0.0012744, -0.0295316>,
    <0.9995630, 0.0012744, -0.0295316>,
    <0.9920089, 0.0013239, -0.1261610>,
    <0.9458403, 0.0014125, -0.3246293>,
    <0.9455975, 0.0014121, -0.3253358>,
    <0.9920089, 0.0013239, -0.1261610>,
    <0.9460826, 0.0014129, -0.3239223>,
    <0.9460826, 0.0014129, -0.3239223>,
    <0.7631614, 0.0013707, -0.6462065>,
    <0.7623940, 0.0013693, -0.6471117>,
    <0.7616271, 0.0013679, -0.6480141>,
    <0.9453543, 0.0014118, -0.3260417>,
    <0.7608607, 0.0013665, -0.6489138>,
    <0.7600948, 0.0013652, -0.6498108>,
    <0.9451108, 0.0014114, -0.3267471>,
    <0.9451108, 0.0014114, -0.3267471>,
    <0.9918531, 0.0013237, -0.1273802>,
    <-0.0002557, 1.0000000, 0.0000687>,
    <-0.0002521, 1.0000000, 0.0000578>,
    <-0.0002128, 0.9999999, 0.0002410>,
    <-0.0002438, 0.9999999, 0.0002938>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002573, 1.0000000, 0.0000021>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002485, 1.0000000, 0.0000335>,
    <-0.0001849, 1.0000000, 0.0001319>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000127, 0.9999999, 0.0004262>,
    <-0.0001114, 0.9999998, 0.0006796>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0004444, 0.9999983, 0.0017942>,
    <0.0000146, 0.9999983, 0.0018600>,
    <-0.0002126, 0.9999997, 0.0007890>,
    <-0.0001727, 0.9999981, 0.0019562>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <-0.3770014, -0.9261930, 0.0060381>,
    <-0.3773780, -0.9260510, 0.0039224>,
    <-0.3775828, -0.9259546, 0.0062769>,
    <-0.3775413, -0.9259316, 0.0106385>,
    <-0.3771996, -0.9254271, 0.0361267>,
    <-0.3737680, -0.9267926, 0.0367824>,
    <-0.3737680, -0.9267926, 0.0367824>,
    <-0.3767203, -0.9263252, 0.0018395>,
    <-0.3775322, -0.9259899, 0.0034955>,
    <-0.3775968, -0.9259559, 0.0051322>,
    <-0.3775558, -0.9259855, 0.0015801>,
    <-0.3775787, -0.9259713, 0.0033908>,
    <-0.3775787, -0.9259713, 0.0033908>,
    <-0.3776004, -0.9259559, 0.0048656>,
    <-0.3776569, -0.9259353, 0.0043598>,
    <-0.3777810, -0.9258806, 0.0051607>,
    <-0.3776004, -0.9259559, 0.0048656>,
    <-0.3776211, -0.9259511, 0.0041089>,
    <-0.3776211, -0.9259511, 0.0041089>,
    <-0.3776372, -0.9259512, 0.0021212>,
    <-0.3776706, -0.9259374, 0.0022070>,
    <-0.3777740, -0.9258949, 0.0023153>,
    <-0.3780808, -0.9257383, 0.0079709>,
    <-0.3780201, -0.9257943, 0.0024013>,
    <-0.3781858, -0.9257268, 0.0023300>,
    <-0.3795975, -0.9244639, 0.0356675>,
    <-0.3795975, -0.9244639, 0.0356675>,
    <-0.3771996, -0.9254271, 0.0361267>,
    <0.4852325, 0.0010944, -0.8743845>,
    <0.4861039, 0.0010963, -0.8739003>,
    <0.3661381, 0.0010209, -0.9305600>,
    <0.3654112, 0.0010189, -0.9308456>,
    <0.3646869, 0.0010169, -0.9311296>,
    <0.4843638, 0.0010924, -0.8748660>,
    <0.4843638, 0.0010924, -0.8748660>,
    <0.7600948, 0.0013652, -0.6498108>,
    <0.4869779, 0.0010983, -0.8734136>,
    <0.3668677, 0.0010229, -0.9302726>,
    <0.7631614, 0.0013707, -0.6462065>,
    <0.4878546, 0.0011003, -0.8729242>,
    <0.4878546, 0.0011003, -0.8729242>,
    <0.3676000, 0.0010250, -0.9299834>,
    <0.4272788, 0.0014106, -0.9041188>,
    <0.4264941, 0.0014080, -0.9044892>,
    <0.3676000, 0.0010250, -0.9299834>,
    <0.4280660, 0.0014132, -0.9037464>,
    <0.4280660, 0.0014132, -0.9037464>,
    <0.6790855, 0.0025234, -0.7340549>,
    <0.6782763, 0.0025204, -0.7348026>,
    <0.6774682, 0.0025174, -0.7355478>,
    <0.4257121, 0.0014054, -0.9048576>,
    <0.6766612, 0.0025144, -0.7362902>,
    <0.6758553, 0.0025114, -0.7370300>,
    <0.4249325, 0.0014028, -0.9052239>,
    <0.4249325, 0.0014028, -0.9052239>,
    <0.3646869, 0.0010169, -0.9311296>,
    <-0.0001605, 0.9999912, 0.0041835>,
    <0.0000373, 0.9999900, 0.0044632>,
    <-0.0001893, 0.9999751, 0.0070592>,
    <-0.0002044, 0.9999817, 0.0060433>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <0.0004994, 0.9999785, 0.0065314>,
    <-0.0001552, 0.9999344, 0.0114548>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0041270, 0.9992606, 0.0382247>,
    <0.0041270, 0.9992606, 0.0382247>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0007848, 0.9999631, 0.0085524>,
    <-0.0004049, 0.9999833, 0.0057588>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0006662, 0.9999964, 0.0025817>,
    <-0.0003625, 0.9999966, 0.0025763>,
    <-0.0002448, 0.9999871, 0.0050692>,
    <-0.0002322, 0.9999967, 0.0025453>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <-0.3777722, -0.9258984, 0.0006185>,
    <-0.3777113, -0.9259230, 0.0008818>,
    <-0.3776690, -0.9259406, 0.0003706>,
    <-0.3776817, -0.9259354, 0.0002568>,
    <-0.3776843, -0.9259344, 0.0001137>,
    <-0.3777813, -0.9258949, 0.0001136>,
    <-0.3777813, -0.9258949, 0.0001136>,
    <-0.3781858, -0.9257268, 0.0023300>,
    <-0.3776626, -0.9259428, 0.0009436>,
    <-0.3776551, -0.9259463, 0.0004133>,
    <-0.3776372, -0.9259512, 0.0021212>,
    <-0.3776459, -0.9259496, 0.0009282>,
    <-0.3776459, -0.9259496, 0.0009282>,
    <-0.3776503, -0.9259482, 0.0004106>,
    <-0.3776529, -0.9259472, 0.0001764>,
    <-0.3776545, -0.9259466, 0.0001691>,
    <-0.3776503, -0.9259482, 0.0004106>,
    <-0.3776524, -0.9259474, 0.0001740>,
    <-0.3776524, -0.9259474, 0.0001740>,
    <-0.3776533, -0.9259471, 0.0001042>,
    <-0.3776533, -0.9259471, 0.0001066>,
    <-0.3776533, -0.9259471, 0.0001066>,
    <-0.3776533, -0.9259471, 0.0001090>,
    <-0.3776561, -0.9259459, 0.0001458>,
    <-0.3776533, -0.9259471, 0.0001090>,
    <-0.3776533, -0.9259471, 0.0001113>,
    <-0.3776533, -0.9259471, 0.0001113>,
    <-0.3776533, -0.9259471, 0.0001137>,
    <-0.3776565, -0.9259457, 0.0001137>,
    <-0.3776565, -0.9259457, 0.0001137>,
    <-0.3776843, -0.9259344, 0.0001137>,
    <0.9036903, 0.0036000, -0.4281715>,
    <0.9040499, 0.0036014, -0.4274118>,
    <0.9789154, 0.0040460, -0.2042262>,
    <0.9788271, 0.0040457, -0.2046491>,
    <0.9787386, 0.0040453, -0.2050718>,
    <0.9033304, 0.0035985, -0.4289304>,
    <0.9033304, 0.0035985, -0.4289304>,
    <0.6758553, 0.0025114, -0.7370300>,
    <0.9044091, 0.0036028, -0.4266511>,
    <0.9790035, 0.0040464, -0.2038032>,
    <0.6790855, 0.0025234, -0.7340549>,
    <0.9047680, 0.0036042, -0.4258896>,
    <0.9047680, 0.0036042, -0.4258896>,
    <0.9790915, 0.0040468, -0.2033801>,
    <0.9961348, 0.0041904, -0.0877376>,
    <0.9961182, 0.0041903, -0.0879255>,
    <0.9790915, 0.0040468, -0.2033801>,
    <0.9961513, 0.0041905, -0.0875497>,
    <0.9961513, 0.0041905, -0.0875497>,
    <0.9986101, 0.0042368, -0.0525342>,
    <0.9986042, 0.0042367, -0.0526473>,
    <0.9986042, 0.0042367, -0.0526473>,
    <0.9985982, 0.0042367, -0.0527604>,
    <0.9961016, 0.0041903, -0.0881134>,
    <0.9985982, 0.0042367, -0.0527604>,
    <0.9985922, 0.0042367, -0.0528735>,
    <0.9985922, 0.0042367, -0.0528735>,
    <0.9985862, 0.0042367, -0.0529867>,
    <0.9960850, 0.0041902, -0.0883012>,
    <0.9960850, 0.0041902, -0.0883012>,
    <0.9787386, 0.0040453, -0.2050718>,
    <-0.0002053, 0.9999994, 0.0010841>,
    <-0.0002659, 0.9999995, 0.0009839>,
    <-0.0002050, 0.9999999, 0.0004143>,
    <-0.0001877, 0.9999999, 0.0004740>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0003403, 0.9999997, 0.0006738>,
    <-0.0002205, 0.9999999, 0.0002809>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001852, 1.0000000, 0.0001577>,
    <-0.0001833, 1.0000000, 0.0001881>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001801, 1.0000000, 0.0001183>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001813, 1.0000000, 0.0002019>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001230>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, -0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <-0.3776688, -0.9259408, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, -0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <0.9999882, 0.0048590, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, -0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.9999961, -0.0027858, 0.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.9999958, -0.0028667, 0.0004859>,
    <0.9999958, -0.0028667, 0.0004951>,
    <0.9999958, -0.0028634, 0.0004951>,
    <0.9999958, -0.0028634, 0.0004859>,
    <0.9999958, -0.0028634, 0.0004766>,
    <0.9999958, -0.0028667, 0.0004766>,
    <0.9999958, -0.0028667, 0.0004766>,
    <0.9999958, -0.0028700, 0.0004766>,
    <0.9999958, -0.0028700, 0.0004859>,
    <0.9999958, -0.0028700, 0.0004859>,
    <0.9999958, -0.0028700, 0.0004951>,
    <0.9999958, -0.0028667, 0.0005043>,
    <0.9999958, -0.0028634, 0.0005043>,
    <0.9999958, -0.0028700, 0.0004951>,
    <0.9999958, -0.0028700, 0.0005043>,
    <0.9999958, -0.0028700, 0.0005043>,
    <0.9999957, -0.0028700, 0.0005136>,
    <0.9999958, -0.0028667, 0.0005136>,
    <0.9999958, -0.0028667, 0.0005136>,
    <0.9999958, -0.0028634, 0.0005136>,
    <0.9999958, -0.0028601, 0.0005043>,
    <0.9999958, -0.0028601, 0.0004951>,
    <0.9999958, -0.0028634, 0.0005136>,
    <0.9999958, -0.0028601, 0.0005136>,
    <0.9999958, -0.0028601, 0.0005136>,
    <0.9999958, -0.0028567, 0.0005136>,
    <0.9999958, -0.0028567, 0.0005043>,
    <0.9999958, -0.0028567, 0.0005043>,
    <0.9999958, -0.0028567, 0.0004951>,
    <0.9999958, -0.0028601, 0.0004859>,
    <0.9999958, -0.0028567, 0.0004951>,
    <0.9999958, -0.0028567, 0.0004859>,
    <0.9999958, -0.0028567, 0.0004859>,
    <0.9999958, -0.0028567, 0.0004766>,
    <0.9999958, -0.0028601, 0.0004766>,
    <0.9999958, -0.0028601, 0.0004766>,
    <0.9999958, -0.0028634, 0.0004766>,
    <-0.9883002, 0.0030419, -0.1524907>,
    <-0.9883011, 0.0029735, -0.1524863>,
    <-0.9878611, 0.0029722, -0.1553116>,
    <-0.9878605, 0.0030405, -0.1553137>,
    <-0.9878600, 0.0031088, -0.1553157>,
    <-0.9882993, 0.0031101, -0.1524950>,
    <-0.9882993, 0.0031101, -0.1524950>,
    <-0.9887310, 0.0031115, -0.1496706>,
    <-0.9887322, 0.0030432, -0.1496639>,
    <-0.9887322, 0.0030432, -0.1496639>,
    <-0.9887335, 0.0029748, -0.1496572>,
    <-0.9883020, 0.0029051, -0.1524819>,
    <-0.9878616, 0.0029038, -0.1553095>,
    <-0.9887335, 0.0029748, -0.1496572>,
    <-0.9887347, 0.0029063, -0.1496505>,
    <-0.9887347, 0.0029063, -0.1496505>,
    <-0.9887359, 0.0028377, -0.1496438>,
    <-0.9883029, 0.0028365, -0.1524775>,
    <-0.9883029, 0.0028365, -0.1524775>,
    <-0.9878621, 0.0028352, -0.1553075>,
    <-0.9874135, 0.0029025, -0.1581334>,
    <-0.9874133, 0.0029709, -0.1581332>,
    <-0.9878621, 0.0028352, -0.1553075>,
    <-0.9874137, 0.0028339, -0.1581336>,
    <-0.9874137, 0.0028339, -0.1581336>,
    <-0.9869575, 0.0028326, -0.1609559>,
    <-0.9869578, 0.0029011, -0.1609534>,
    <-0.9869578, 0.0029011, -0.1609534>,
    <-0.9869580, 0.0029695, -0.1609508>,
    <-0.9874132, 0.0030392, -0.1581329>,
    <-0.9869580, 0.0029695, -0.1609508>,
    <-0.9869582, 0.0030378, -0.1609483>,
    <-0.9869582, 0.0030378, -0.1609483>,
    <-0.9869584, 0.0031059, -0.1609458>,
    <-0.9874130, 0.0031073, -0.1581327>,
    <-0.9874130, 0.0031073, -0.1581327>,
    <-0.9878600, 0.0031088, -0.1553157>,
    <0.9999950, -0.0031471, 0.0000079>,
    <0.9999950, -0.0031471, 0.0000080>,
    <0.9999950, -0.0031471, 0.0000080>,
    <0.9999950, -0.0031471, 0.0000079>,
    <0.9999950, -0.0031471, 0.0000077>,
    <0.9999950, -0.0031471, 0.0000077>,
    <0.9999950, -0.0031471, 0.0000077>,
    <0.9999950, -0.0031472, 0.0000077>,
    <0.9999950, -0.0031472, 0.0000079>,
    <0.9999950, -0.0031472, 0.0000079>,
    <0.9999950, -0.0031472, 0.0000080>,
    <0.9999950, -0.0031471, 0.0000082>,
    <0.9999950, -0.0031471, 0.0000082>,
    <0.9999950, -0.0031472, 0.0000080>,
    <0.9999950, -0.0031472, 0.0000082>,
    <0.9999950, -0.0031472, 0.0000082>,
    <0.9999950, -0.0031472, 0.0000083>,
    <0.9999950, -0.0031471, 0.0000083>,
    <0.9999950, -0.0031471, 0.0000083>,
    <0.9999950, -0.0031471, 0.0000083>,
    <0.9999950, -0.0031470, 0.0000082>,
    <0.9999950, -0.0031470, 0.0000080>,
    <0.9999950, -0.0031471, 0.0000083>,
    <0.9999950, -0.0031470, 0.0000083>,
    <0.9999950, -0.0031470, 0.0000083>,
    <0.9999950, -0.0031469, 0.0000083>,
    <0.9999950, -0.0031469, 0.0000082>,
    <0.9999950, -0.0031469, 0.0000082>,
    <0.9999950, -0.0031469, 0.0000080>,
    <0.9999950, -0.0031470, 0.0000079>,
    <0.9999950, -0.0031469, 0.0000080>,
    <0.9999950, -0.0031469, 0.0000079>,
    <0.9999950, -0.0031469, 0.0000079>,
    <0.9999950, -0.0031469, 0.0000077>,
    <0.9999950, -0.0031470, 0.0000077>,
    <0.9999950, -0.0031470, 0.0000077>,
    <0.9999950, -0.0031471, 0.0000077>,
    <-0.9988645, 0.0031741, -0.0475356>,
    <-0.9988645, 0.0031640, -0.0475354>,
    <-0.9988214, 0.0031638, -0.0484339>,
    <-0.9988213, 0.0031740, -0.0484340>,
    <-0.9988213, 0.0031841, -0.0484341>,
    <-0.9988645, 0.0031843, -0.0475358>,
    <-0.9988645, 0.0031843, -0.0475358>,
    <-0.9989068, 0.0031844, -0.0466374>,
    <-0.9989069, 0.0031743, -0.0466371>,
    <-0.9989069, 0.0031743, -0.0466371>,
    <-0.9989069, 0.0031641, -0.0466368>,
    <-0.9988646, 0.0031538, -0.0475352>,
    <-0.9988214, 0.0031537, -0.0484338>,
    <-0.9989069, 0.0031641, -0.0466368>,
    <-0.9989069, 0.0031539, -0.0466365>,
    <-0.9989069, 0.0031539, -0.0466365>,
    <-0.9989070, 0.0031438, -0.0466362>,
    <-0.9988646, 0.0031436, -0.0475350>,
    <-0.9988646, 0.0031436, -0.0475350>,
    <-0.9988215, 0.0031435, -0.0484337>,
    <-0.9987774, 0.0031535, -0.0493322>,
    <-0.9987774, 0.0031637, -0.0493322>,
    <-0.9988215, 0.0031435, -0.0484337>,
    <-0.9987775, 0.0031434, -0.0493323>,
    <-0.9987775, 0.0031434, -0.0493323>,
    <-0.9987327, 0.0031432, -0.0502307>,
    <-0.9987327, 0.0031534, -0.0502306>,
    <-0.9987327, 0.0031534, -0.0502306>,
    <-0.9987326, 0.0031635, -0.0502305>,
    <-0.9987774, 0.0031738, -0.0493322>,
    <-0.9987326, 0.0031635, -0.0502305>,
    <-0.9987326, 0.0031737, -0.0502304>,
    <-0.9987326, 0.0031737, -0.0502304>,
    <-0.9987326, 0.0031839, -0.0502302>,
    <-0.9987774, 0.0031840, -0.0493322>,
    <-0.9987774, 0.0031840, -0.0493322>,
    <-0.9988213, 0.0031841, -0.0484341>,
    <0.9999420, -0.0031868, 0.0102878>,
    <0.9999434, -0.0032502, 0.0101314>,
    <0.9999334, -0.0032301, 0.0110827>,
    <0.9999343, -0.0032139, 0.0109988>,
    <0.9999334, -0.0032088, 0.0110850>,
    <0.9999335, -0.0031699, 0.0110847>,
    <0.9999335, -0.0031699, 0.0110847>,
    <0.9999720, -0.0029756, 0.0068702>,
    <0.9999707, -0.0030848, 0.0070035>,
    <0.9999692, -0.0032633, 0.0071366>,
    <0.9999368, -0.0033114, 0.0107409>,
    <0.9999292, -0.0032451, 0.0114501>,
    <0.9999676, -0.0034461, 0.0072691>,
    <0.9999663, -0.0035537, 0.0074011>,
    <0.9999232, -0.0033226, 0.0119404>,
    <0.9999232, -0.0033226, 0.0119404>,
    <0.9999234, -0.0032482, 0.0119406>,
    <0.9999269, -0.0032107, 0.0116604>,
    <0.9999297, -0.0032089, 0.0114115>,
    <0.9999234, -0.0032482, 0.0119406>,
    <0.9999236, -0.0032111, 0.0119407>,
    <0.9999236, -0.0032111, 0.0119407>,
    <0.9999236, -0.0031877, 0.0119408>,
    <0.9999262, -0.0031877, 0.0117268>,
    <0.9999262, -0.0031877, 0.0117268>,
    <0.9999286, -0.0031877, 0.0115128>,
    <0.9999318, -0.0032069, 0.0112269>,
    <0.9999286, -0.0031877, 0.0115128>,
    <0.9999311, -0.0031877, 0.0112988>,
    <0.9999311, -0.0031877, 0.0112988>,
    <0.9999335, -0.0031877, 0.0110849>,
    <0.9999334, -0.0032062, 0.0110850>,
    <0.9999334, -0.0032062, 0.0110850>,
    <0.9999334, -0.0032088, 0.0110850>,
    <0.9999872, -0.0030585, -0.0040199>,
    <0.9998036, -0.0031560, -0.0195669>,
    <0.9998850, -0.0032586, -0.0148087>,
    <0.9999944, -0.0032647, -0.0007967>,
    <0.9999720, -0.0029756, 0.0068702>,
    <0.9992088, -0.0024432, -0.0396977>,
    <0.9992088, -0.0024432, -0.0396977>,
    <0.9992065, -0.0030444, -0.0397135>,
    <0.9994407, -0.0032327, -0.0332831>,
    <0.9995076, -0.0032505, -0.0312093>,
    <0.9992065, -0.0030444, -0.0397135>,
    <0.9992057, -0.0032230, -0.0397181>,
    <0.9992057, -0.0032230, -0.0397181>,
    <0.9992056, -0.0032427, -0.0397187>,
    <0.9991749, -0.0032426, -0.0404837>,
    <0.9991749, -0.0032426, -0.0404837>,
    <0.9991437, -0.0032425, -0.0412486>,
    <0.9993952, -0.0032682, -0.0346215>,
    <0.9997834, -0.0033633, -0.0205399>,
    <0.9991437, -0.0032425, -0.0412486>,
    <0.9991118, -0.0032424, -0.0420135>,
    <0.9991118, -0.0032424, -0.0420135>,
    <0.9990793, -0.0032422, -0.0427783>,
    <0.9990792, -0.0032771, -0.0427780>,
    <0.9990792, -0.0032771, -0.0427780>,
    <0.9990786, -0.0034795, -0.0427760>,
    <0.9999843, -0.0034767, -0.0043855>,
    <0.9990786, -0.0034795, -0.0427760>,
    <0.9990764, -0.0041300, -0.0427695>,
    <0.9990764, -0.0041300, -0.0427695>,
    <0.9999663, -0.0035537, 0.0074011>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9511689>,
    <0.4350534, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9511689>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4350534, 0.9657316>,
    <0.5000060, 0.9664288>,
    <0.4263703, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664288>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559367, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4263703, 0.9671308>,
    <0.5000061, 0.9786956>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9786956>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773948, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032662, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458857>,
    <0.4677608, 0.9456965>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9511689>,
    <0.4355157, 0.9458857>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9451631>,
    <0.4677604, 0.9518925>,
    <0.4676447, 0.9588120>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9511689>,
    <0.5000059, 0.9657316>,
    <0.4350534, 0.9657316>,
    <0.4677604, 0.9518925>,
    <0.5000059, 0.9579835>,
    <0.4675262, 0.9657316>,
    <0.4353083, 0.9584665>,
    <0.4031502, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4350534, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4353083, 0.9584665>,
    <0.4024181, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032662, 0.9526160>,
    <0.5322510, 0.9456965>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9511689>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9518925>,
    <0.5000059, 0.9451631>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458645>,
    <0.5967410, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5644961, 0.9458645>,
    <0.5967380, 0.9395004>,
    <0.6289858, 0.9451388>,
    <0.5967440, 0.9518685>,
    <0.5967474, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967440, 0.9518685>,
    <0.6289941, 0.9579003>,
    <0.5967509, 0.9657316>,
    <0.5645003, 0.9587163>,
    <0.5322532, 0.9588120>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9511689>,
    <0.5645003, 0.9587163>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9579835>,
    <0.5322521, 0.9518925>,
    <0.6423395, 0.9456845>,
    <0.6556982, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423437, 0.9518685>,
    <0.6289858, 0.9451388>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458854>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458854>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691147, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694793, 0.9657316>,
    <0.6558043, 0.9584513>,
    <0.6424060, 0.9588001>,
    <0.6556982, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.6558043, 0.9584513>,
    <0.6424701, 0.9657316>,
    <0.6289941, 0.9579003>,
    <0.6423437, 0.9518685>,
    <0.3997928, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4350534, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4024181, 0.9657316>,
    <0.4331639, 0.9660607>,
    <0.4665256, 0.9660808>,
    <0.4310370, 0.9664312>,
    <0.4350534, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664288>,
    <0.4331639, 0.9660607>,
    <0.4675262, 0.9657316>,
    <0.5000060, 0.9660919>,
    <0.4655215, 0.9664300>,
    <0.4643549, 0.9667804>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664288>,
    <0.5000061, 0.9671308>,
    <0.4263703, 0.9671308>,
    <0.4655215, 0.9664300>,
    <0.5000060, 0.9667632>,
    <0.4631816, 0.9671308>,
    <0.4286561, 0.9667881>,
    <0.3931497, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4263703, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4286561, 0.9667881>,
    <0.3895082, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660808>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664288>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664300>,
    <0.5000060, 0.9660919>,
    <0.5322542, 0.9657316>,
    <0.5668008, 0.9660911>,
    <0.6000933, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5668008, 0.9660911>,
    <0.5967509, 0.9657316>,
    <0.6335597, 0.9660883>,
    <0.6034357, 0.9664293>,
    <0.6068019, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034357, 0.9664293>,
    <0.6422052, 0.9667645>,
    <0.6101681, 0.9671308>,
    <0.5711142, 0.9667658>,
    <0.5356086, 0.9667804>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664288>,
    <0.5711142, 0.9667658>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667632>,
    <0.5344905, 0.9664300>,
    <0.6473345, 0.9660805>,
    <0.6665054, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6289992, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6522009, 0.9664293>,
    <0.6335597, 0.9660883>,
    <0.6424701, 0.9657316>,
    <0.6608384, 0.9660561>,
    <0.6749817, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559367, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6608384, 0.9660561>,
    <0.6694793, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866708, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926707, 0.9671308>,
    <0.6721189, 0.9667919>,
    <0.6571714, 0.9667801>,
    <0.6665054, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.6721189, 0.9667919>,
    <0.6621448, 0.9671308>,
    <0.6422052, 0.9667645>,
    <0.6522009, 0.9664293>,
    <0.3896350, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4263703, 0.9671308>,
    <0.3895220, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3895082, 0.9671308>,
    <0.4263596, 0.9729583>,
    <0.4631833, 0.9726793>,
    <0.4263507, 0.9777601>,
    <0.4263703, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9786956>,
    <0.4263596, 0.9729583>,
    <0.4631816, 0.9671308>,
    <0.5000061, 0.9731107>,
    <0.4631777, 0.9782279>,
    <0.4631249, 0.9833087>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9786956>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631777, 0.9782279>,
    <0.5000061, 0.9836699>,
    <0.4630714, 0.9883895>,
    <0.4262410, 0.9832092>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262410, 0.9832092>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895220, 0.9777601>,
    <0.5367803, 0.9726793>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9786956>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9782279>,
    <0.5000061, 0.9731107>,
    <0.5367268, 0.9671308>,
    <0.5735589, 0.9726676>,
    <0.6103387, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5735589, 0.9726676>,
    <0.6101681, 0.9671308>,
    <0.6471335, 0.9732089>,
    <0.6105094, 0.9782626>,
    <0.6106597, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105094, 0.9782626>,
    <0.6475562, 0.9837065>,
    <0.6108101, 0.9883895>,
    <0.5737713, 0.9832167>,
    <0.5368873, 0.9833087>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9786956>,
    <0.5737713, 0.9832167>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9836699>,
    <0.5368338, 0.9782279>,
    <0.6623650, 0.9726967>,
    <0.6778190, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6468888, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6625884, 0.9782625>,
    <0.6471335, 0.9732089>,
    <0.6621448, 0.9671308>,
    <0.6776281, 0.9729776>,
    <0.6928127, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773948, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776281, 0.9729776>,
    <0.6926707, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930705, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930705, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780838, 0.9832100>,
    <0.6628141, 0.9833260>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.6780838, 0.9832100>,
    <0.6630402, 0.9883895>,
    <0.6475562, 0.9837065>,
    <0.6625884, 0.9782625>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.011335, -0.86281, -0.147353>
}

#declare TMesh004 = mesh2 {
  vertex_vectors {
    582,
    <2.1725850, 0.1168106, 18.5417983>,
    <2.0021506, 0.1167733, 18.5417983>,
    <2.0021672, -0.1263783, 18.5417983>,
    <2.1725990, -0.1263328, 18.5417983>,
    <2.0873678, 0.1167919, 18.5417983>,
    <2.0021589, -0.0048025, 18.5417983>,
    <2.0873831, -0.1263556, 18.5417983>,
    <2.1725920, -0.0047611, 18.5417983>,
    <2.0873754, -0.0047818, 18.5417983>,
    <2.3430309, -0.1262872, 18.5417983>,
    <2.3430194, 0.1168480, 18.5417983>,
    <2.2578150, -0.1263100, 18.5417983>,
    <2.3430251, -0.0047196, 18.5417983>,
    <2.2578022, 0.1168293, 18.5417983>,
    <2.2578086, -0.0047404, 18.5417983>,
    <2.3430079, 0.3599832, 18.5417983>,
    <2.1725710, 0.3599540, 18.5417983>,
    <2.3430137, 0.2384156, 18.5417983>,
    <2.2577895, 0.3599686, 18.5417983>,
    <2.1725780, 0.2383823, 18.5417983>,
    <2.2577958, 0.2383989, 18.5417983>,
    <2.0021340, 0.3599249, 18.5417983>,
    <2.0873525, 0.3599394, 18.5417983>,
    <2.0021423, 0.2383491, 18.5417983>,
    <2.0873601, 0.2383657, 18.5417983>,
    <2.0592721, -0.1268007, 18.1202395>,
    <2.0044034, -0.1268325, 18.1202395>,
    <2.0044687, -0.1268457, 18.1217627>,
    <2.0559641, -0.1268143, 18.1217627>,
    <2.0318378, -0.1268166, 18.1202395>,
    <2.0044361, -0.1268391, 18.1210011>,
    <2.0302164, -0.1268300, 18.1217627>,
    <2.0576181, -0.1268075, 18.1210011>,
    <2.0310271, -0.1268233, 18.1210011>,
    <2.1074595, -0.1267829, 18.1217627>,
    <2.1141408, -0.1267689, 18.1202395>,
    <2.0817118, -0.1267986, 18.1217627>,
    <2.1108002, -0.1267759, 18.1210011>,
    <2.0867065, -0.1267848, 18.1202395>,
    <2.0842091, -0.1267917, 18.1210011>,
    <2.1208221, -0.1267548, 18.1187163>,
    <2.0625801, -0.1267870, 18.1187163>,
    <2.1174814, -0.1267619, 18.1194779>,
    <2.0917011, -0.1267709, 18.1187163>,
    <2.0609261, -0.1267939, 18.1194779>,
    <2.0892038, -0.1267779, 18.1194779>,
    <2.0043382, -0.1268192, 18.1187163>,
    <2.0334591, -0.1268031, 18.1187163>,
    <2.0043708, -0.1268259, 18.1194779>,
    <2.0326485, -0.1268099, 18.1194779>,
    <2.1141282, 0.1168541, 18.1202395>,
    <2.1074469, 0.1168543, 18.1217627>,
    <2.1141345, -0.0049574, 18.1202395>,
    <2.1074532, -0.0049643, 18.1217627>,
    <2.1107875, 0.1168542, 18.1210011>,
    <2.1107938, -0.0049608, 18.1210011>,
    <2.1074342, 0.3604916, 18.1217627>,
    <2.1141156, 0.3604772, 18.1202395>,
    <2.1074405, 0.2386730, 18.1217627>,
    <2.1107749, 0.3604844, 18.1210011>,
    <2.1141219, 0.2386657, 18.1202395>,
    <2.1107812, 0.2386693, 18.1210011>,
    <2.1207969, 0.3604627, 18.1187163>,
    <2.1208095, 0.1168540, 18.1187163>,
    <2.1174562, 0.3604700, 18.1194779>,
    <2.1208032, 0.2386584, 18.1187163>,
    <2.1174688, 0.1168541, 18.1194779>,
    <2.1174625, 0.2386620, 18.1194779>,
    <2.1208158, -0.0049504, 18.1187163>,
    <2.1174751, -0.0049539, 18.1194779>,
    <2.0592428, 0.3604585, 18.1202395>,
    <2.0559348, 0.3604732, 18.1217627>,
    <2.0866792, 0.3604678, 18.1202395>,
    <2.0816845, 0.3604824, 18.1217627>,
    <2.0575888, 0.3604658, 18.1210011>,
    <2.0841818, 0.3604751, 18.1210011>,
    <2.0044353, 0.3604548, 18.1217627>,
    <2.0043701, 0.3604398, 18.1202395>,
    <2.0301850, 0.3604640, 18.1217627>,
    <2.0044027, 0.3604473, 18.1210011>,
    <2.0318064, 0.3604491, 18.1202395>,
    <2.0309957, 0.3604566, 18.1210011>,
    <2.0043048, 0.3604247, 18.1187163>,
    <2.0625508, 0.3604437, 18.1187163>,
    <2.0043374, 0.3604323, 18.1194779>,
    <2.0334278, 0.3604342, 18.1187163>,
    <2.0608968, 0.3604511, 18.1194779>,
    <2.0326171, 0.3604417, 18.1194779>,
    <2.0916739, 0.3604532, 18.1187163>,
    <2.0891765, 0.3604605, 18.1194779>,
    <2.0694781, -0.1267585, 18.1370901>,
    <2.0042020, -0.1267916, 18.1370901>,
    <2.0368401, -0.1267751, 18.1370901>,
    <2.0042701, -0.1268054, 18.1279032>,
    <2.0660291, -0.1267728, 18.1279032>,
    <2.0351496, -0.1267891, 18.1279032>,
    <2.1347541, -0.1267255, 18.1370901>,
    <2.1277881, -0.1267402, 18.1279032>,
    <2.1021161, -0.1267420, 18.1370901>,
    <2.0969086, -0.1267565, 18.1279032>,
    <2.1486861, -0.1266962, 18.1554639>,
    <2.0763760, -0.1267301, 18.1554639>,
    <2.1417201, -0.1267108, 18.1462770>,
    <2.1125311, -0.1267131, 18.1554639>,
    <2.0729270, -0.1267443, 18.1462770>,
    <2.1073236, -0.1267276, 18.1462770>,
    <2.0040659, -0.1267639, 18.1554639>,
    <2.0402210, -0.1267470, 18.1554639>,
    <2.0041340, -0.1267778, 18.1462770>,
    <2.0385305, -0.1267610, 18.1462770>,
    <2.1347416, 0.1168536, 18.1370901>,
    <2.1347478, -0.0049360, 18.1370901>,
    <2.1277755, 0.1168538, 18.1279032>,
    <2.1277818, -0.0049432, 18.1279032>,
    <2.1347291, 0.3604327, 18.1370901>,
    <2.1277630, 0.3604477, 18.1279032>,
    <2.1347353, 0.2386431, 18.1370901>,
    <2.1277693, 0.2386507, 18.1279032>,
    <2.1486612, 0.3604026, 18.1554639>,
    <2.1486737, 0.1168532, 18.1554639>,
    <2.1416951, 0.3604176, 18.1462770>,
    <2.1486675, 0.2386279, 18.1554639>,
    <2.1417076, 0.1168534, 18.1462770>,
    <2.1417014, 0.2386355, 18.1462770>,
    <2.1486799, -0.0049215, 18.1554639>,
    <2.1417139, -0.0049287, 18.1462770>,
    <2.0694489, 0.3604130, 18.1370901>,
    <2.1020890, 0.3604229, 18.1370901>,
    <2.0659999, 0.3604284, 18.1279032>,
    <2.0968814, 0.3604381, 18.1279032>,
    <2.0041687, 0.3603934, 18.1370901>,
    <2.0042367, 0.3604091, 18.1279032>,
    <2.0368088, 0.3604032, 18.1370901>,
    <2.0351183, 0.3604187, 18.1279032>,
    <2.0040326, 0.3603621, 18.1554639>,
    <2.0763469, 0.3603823, 18.1554639>,
    <2.0041006, 0.3603777, 18.1462770>,
    <2.0401897, 0.3603722, 18.1554639>,
    <2.0728979, 0.3603977, 18.1462770>,
    <2.0384993, 0.3603877, 18.1462770>,
    <2.1125041, 0.3603925, 18.1554639>,
    <2.1072965, 0.3604077, 18.1462770>,
    <2.0812641, -0.1267099, 18.1573801>,
    <2.0039695, -0.1267443, 18.1573801>,
    <2.0426168, -0.1267271, 18.1573801>,
    <2.0040177, -0.1267541, 18.1564220>,
    <2.0788201, -0.1267200, 18.1564220>,
    <2.0414189, -0.1267371, 18.1564220>,
    <2.1585588, -0.1266754, 18.1573801>,
    <2.1536225, -0.1266858, 18.1564220>,
    <2.1199115, -0.1266926, 18.1573801>,
    <2.1162213, -0.1267029, 18.1564220>,
    <2.1684314, -0.1266546, 18.1592964>,
    <2.0861522, -0.1266897, 18.1592964>,
    <2.1634951, -0.1266650, 18.1583383>,
    <2.1272918, -0.1266722, 18.1592964>,
    <2.0837082, -0.1266998, 18.1583383>,
    <2.1236016, -0.1266824, 18.1583383>,
    <2.0038730, -0.1267248, 18.1592964>,
    <2.0450126, -0.1267072, 18.1592964>,
    <2.0039212, -0.1267346, 18.1583383>,
    <2.0438147, -0.1267172, 18.1583383>,
    <2.1585464, 0.1168529, 18.1573801>,
    <2.1585526, -0.0049112, 18.1573801>,
    <2.1536100, 0.1168531, 18.1564220>,
    <2.1536162, -0.0049164, 18.1564220>,
    <2.1585340, 0.3603813, 18.1573801>,
    <2.1535976, 0.3603920, 18.1564220>,
    <2.1585402, 0.2386171, 18.1573801>,
    <2.1536038, 0.2386225, 18.1564220>,
    <2.1684068, 0.3603600, 18.1592964>,
    <2.1684191, 0.1168527, 18.1592964>,
    <2.1634704, 0.3603706, 18.1583383>,
    <2.1684129, 0.2386063, 18.1592964>,
    <2.1634827, 0.1168528, 18.1583383>,
    <2.1634766, 0.2386117, 18.1583383>,
    <2.1684253, -0.0049010, 18.1592964>,
    <2.1634889, -0.0049061, 18.1583383>,
    <2.0812351, 0.3603606, 18.1573801>,
    <2.1198845, 0.3603709, 18.1573801>,
    <2.0787910, 0.3603715, 18.1564220>,
    <2.1161943, 0.3603817, 18.1564220>,
    <2.0039361, 0.3603399, 18.1573801>,
    <2.0039844, 0.3603510, 18.1564220>,
    <2.0425856, 0.3603502, 18.1573801>,
    <2.0413877, 0.3603612, 18.1564220>,
    <2.0038397, 0.3603176, 18.1592964>,
    <2.0861232, 0.3603388, 18.1592964>,
    <2.0038879, 0.3603287, 18.1583383>,
    <2.0449814, 0.3603282, 18.1592964>,
    <2.0836791, 0.3603497, 18.1583383>,
    <2.0437835, 0.3603392, 18.1583383>,
    <2.1272650, 0.3603494, 18.1592964>,
    <2.1235748, 0.3603602, 18.1583383>,
    <2.0872214, -0.1266858, 18.2324892>,
    <2.0038724, -0.1267246, 18.2344341>,
    <2.0455456, -0.1267050, 18.2333227>,
    <2.0038727, -0.1267247, 18.1968653>,
    <2.0861681, -0.1266896, 18.1968653>,
    <2.0450204, -0.1267072, 18.1968653>,
    <2.1705857, -0.1266501, 18.2322113>,
    <2.1684634, -0.1266546, 18.1968653>,
    <2.1289022, -0.1266677, 18.2322113>,
    <2.1273157, -0.1266721, 18.1968653>,
    <2.1894619, -0.1266104, 18.2873438>,
    <2.0965801, -0.1266498, 18.2890109>,
    <2.1768884, -0.1266368, 18.2631118>,
    <2.1430133, -0.1266285, 18.2873438>,
    <2.0903496, -0.1266745, 18.2642232>,
    <2.1336139, -0.1266546, 18.2631118>,
    <2.0038718, -0.1267245, 18.3095719>,
    <2.0501774, -0.1266773, 18.2940122>,
    <2.0038721, -0.1267246, 18.2720030>,
    <2.0471057, -0.1266985, 18.2675574>,
    <2.1705733, 0.1168526, 18.2322113>,
    <2.1705795, -0.0048987, 18.2322113>,
    <2.1684511, 0.1168527, 18.1968653>,
    <2.1684573, -0.0049009, 18.1968653>,
    <2.1705610, 0.3603553, 18.2322113>,
    <2.1684387, 0.3603599, 18.1968653>,
    <2.1705672, 0.2386040, 18.2322113>,
    <2.1684449, 0.2386063, 18.1968653>,
    <2.1894375, 0.3603146, 18.2873438>,
    <2.1894497, 0.1168521, 18.2873438>,
    <2.1768638, 0.3603417, 18.2631118>,
    <2.1894436, 0.2385834, 18.2873438>,
    <2.1768761, 0.1168524, 18.2631118>,
    <2.1768700, 0.2385971, 18.2631118>,
    <2.1894558, -0.0048791, 18.2873438>,
    <2.1768823, -0.0048922, 18.2631118>,
    <2.0871924, 0.3603347, 18.2324892>,
    <2.1288754, 0.3603447, 18.2322113>,
    <2.0861391, 0.3603387, 18.1968653>,
    <2.1272889, 0.3603493, 18.1968653>,
    <2.0038391, 0.3603175, 18.2344341>,
    <2.0038394, 0.3603176, 18.1968653>,
    <2.0455144, 0.3603258, 18.2333227>,
    <2.0449892, 0.3603282, 18.1968653>,
    <2.0038384, 0.3603174, 18.3095719>,
    <2.0965512, 0.3602960, 18.2890109>,
    <2.0038387, 0.3603174, 18.2720030>,
    <2.0501463, 0.3602955, 18.2940122>,
    <2.0903206, 0.3603225, 18.2642232>,
    <2.0470746, 0.3603188, 18.2675574>,
    <2.1429867, 0.3603035, 18.2873438>,
    <2.1335871, 0.3603310, 18.2631118>,
    <2.1194133, -0.1265524, 18.3131904>,
    <2.0032176, -0.1265917, 18.3135798>,
    <2.0613154, -0.1265720, 18.3133573>,
    <2.0035447, -0.1266581, 18.3115759>,
    <2.1069400, -0.1266060, 18.3037960>,
    <2.0552372, -0.1266310, 18.3071303>,
    <2.2356097, -0.1265133, 18.3131347>,
    <2.2103965, -0.1265663, 18.3026846>,
    <2.1775114, -0.1265328, 18.3131347>,
    <2.1586631, -0.1265851, 18.3026846>,
    <2.2825423, -0.1264145, 18.3353648>,
    <2.1426356, -0.1264535, 18.3340315>,
    <2.2610191, -0.1264598, 18.3226946>,
    <2.2125963, -0.1264355, 18.3353648>,
    <2.1319840, -0.1264985, 18.3218058>,
    <2.1965064, -0.1264801, 18.3226946>,
    <2.0025635, -0.1264588, 18.3175878>,
    <2.0726458, -0.1264655, 18.3300317>,
    <2.0028906, -0.1265252, 18.3155838>,
    <2.0674422, -0.1265128, 18.3191392>,
    <2.2355977, 0.1168509, 18.3131347>,
    <2.2356037, -0.0048312, 18.3131347>,
    <2.2103844, 0.1168515, 18.3026846>,
    <2.2103904, -0.0048574, 18.3026846>,
    <2.2355857, 0.3602150, 18.3131347>,
    <2.2103722, 0.3602694, 18.3026846>,
    <2.2355917, 0.2385329, 18.3131347>,
    <2.2103783, 0.2385605, 18.3026846>,
    <2.2825188, 0.3601137, 18.3353648>,
    <2.2825305, 0.1168496, 18.3353648>,
    <2.2609953, 0.3601602, 18.3226946>,
    <2.2825246, 0.2384817, 18.3353648>,
    <2.2610072, 0.1168502, 18.3226946>,
    <2.2610013, 0.2385052, 18.3226946>,
    <2.2825364, -0.0047825, 18.3353648>,
    <2.2610131, -0.0048048, 18.3226946>,
    <2.1193847, 0.3601908, 18.3131904>,
    <2.1774851, 0.3602029, 18.3131347>,
    <2.1069112, 0.3602487, 18.3037960>,
    <2.1586366, 0.3602579, 18.3026846>,
    <2.0031844, 0.3601667, 18.3135798>,
    <2.0035114, 0.3602420, 18.3115759>,
    <2.0612845, 0.3601788, 18.3133573>,
    <2.0552062, 0.3602442, 18.3071303>,
    <2.0025303, 0.3600161, 18.3175878>,
    <2.1426072, 0.3600840, 18.3340315>,
    <2.0028573, 0.3600914, 18.3155838>,
    <2.0726150, 0.3600607, 18.3300317>,
    <2.1319555, 0.3601325, 18.3218058>,
    <2.0674113, 0.3601131, 18.3191392>,
    <2.2125703, 0.3601005, 18.3353648>,
    <2.1964803, 0.3601475, 18.3226946>,
    <2.1531110, -0.1264127, 18.3800376>,
    <2.0025322, -0.1264525, 18.3784821>,
    <2.0778228, -0.1264328, 18.3793709>,
    <2.0025479, -0.1264556, 18.3480349>,
    <2.1493516, -0.1264267, 18.3542569>,
    <2.0759546, -0.1264422, 18.3515903>,
    <2.3036751, -0.1263701, 18.3802598>,
    <2.2960969, -0.1263860, 18.3551457>,
    <2.2283943, -0.1263916, 18.3802598>,
    <2.2227291, -0.1264074, 18.3551457>,
    <2.3088707, -0.1263591, 18.4393764>,
    <2.1556858, -0.1264026, 18.4393764>,
    <2.3072690, -0.1263625, 18.4089292>,
    <2.2322783, -0.1263809, 18.4393764>,
    <2.1548928, -0.1264059, 18.4089292>,
    <2.2310809, -0.1263842, 18.4089292>,
    <2.0025009, -0.1264461, 18.4393764>,
    <2.0790934, -0.1264244, 18.4393764>,
    <2.0025166, -0.1264493, 18.4089292>,
    <2.0787047, -0.1264276, 18.4089292>,
    <2.3036635, 0.1168490, 18.3802598>,
    <2.3036693, -0.0047605, 18.3802598>,
    <2.2960852, 0.1168492, 18.3551457>,
    <2.2960911, -0.0047684, 18.3551457>,
    <2.3036518, 0.3600681, 18.3802598>,
    <2.2960735, 0.3600845, 18.3551457>,
    <2.3036576, 0.2384586, 18.3802598>,
    <2.2960794, 0.2384668, 18.3551457>,
    <2.3088475, 0.3600569, 18.4393764>,
    <2.3088591, 0.1168489, 18.4393764>,
    <2.3072457, 0.3600603, 18.4089292>,
    <2.3088533, 0.2384529, 18.4393764>,
    <2.3072574, 0.1168489, 18.4089292>,
    <2.3072515, 0.2384546, 18.4089292>,
    <2.3088649, -0.0047551, 18.4393764>,
    <2.3072632, -0.0047568, 18.4089292>,
    <2.1530827, 0.3600402, 18.3800376>,
    <2.2283685, 0.3600544, 18.3802598>,
    <2.1493233, 0.3600552, 18.3542569>,
    <2.2227033, 0.3600710, 18.3551457>,
    <2.0024990, 0.3600089, 18.3784821>,
    <2.0025147, 0.3600125, 18.3480349>,
    <2.0777921, 0.3600248, 18.3793709>,
    <2.0759238, 0.3600350, 18.3515903>,
    <2.0024677, 0.3600017, 18.4393764>,
    <2.1556576, 0.3600293, 18.4393764>,
    <2.0024834, 0.3600053, 18.4089292>,
    <2.0790627, 0.3600155, 18.4393764>,
    <2.1548645, 0.3600328, 18.4089292>,
    <2.0786740, 0.3600191, 18.4089292>,
    <2.2322525, 0.3600431, 18.4393764>,
    <2.2310551, 0.3600466, 18.4089292>,
    <2.1641424, -0.1263677, 18.4393764>,
    <2.0023340, -0.1264122, 18.4393764>,
    <2.0832382, -0.1263900, 18.4393764>,
    <2.0024175, -0.1264292, 18.4393764>,
    <2.1599141, -0.1263852, 18.4393764>,
    <2.0811658, -0.1264072, 18.4393764>,
    <2.3259508, -0.1263232, 18.4393764>,
    <2.3174108, -0.1263412, 18.4393764>,
    <2.2450466, -0.1263454, 18.4393764>,
    <2.2386625, -0.1263632, 18.4393764>,
    <2.3430309, -0.1262872, 18.4393764>,
    <2.1725990, -0.1263328, 18.4393764>,
    <2.3344909, -0.1263052, 18.4393764>,
    <2.2578150, -0.1263100, 18.4393764>,
    <2.1683707, -0.1263502, 18.4393764>,
    <2.2514308, -0.1263277, 18.4393764>,
    <2.0021672, -0.1263783, 18.4393764>,
    <2.0873831, -0.1263556, 18.4393764>,
    <2.0022506, -0.1263953, 18.4393764>,
    <2.0853107, -0.1263728, 18.4393764>,
    <2.3259393, 0.1168484, 18.4393764>,
    <2.3259450, -0.0047374, 18.4393764>,
    <2.3173992, 0.1168486, 18.4393764>,
    <2.3174050, -0.0047463, 18.4393764>,
    <2.3259277, 0.3600200, 18.4393764>,
    <2.3173876, 0.3600385, 18.4393764>,
    <2.3259335, 0.2384342, 18.4393764>,
    <2.3173934, 0.2384436, 18.4393764>,
    <2.3430079, 0.3599832, 18.4393764>,
    <2.3430194, 0.1168480, 18.4393764>,
    <2.3344678, 0.3600016, 18.4393764>,
    <2.3430137, 0.2384156, 18.4393764>,
    <2.3344793, 0.1168482, 18.4393764>,
    <2.3344736, 0.2384249, 18.4393764>,
    <2.3430251, -0.0047196, 18.4393764>,
    <2.3344851, -0.0047285, 18.4393764>,
    <2.1641143, 0.3599917, 18.4393764>,
    <2.2450210, 0.3600058, 18.4393764>,
    <2.1598859, 0.3600105, 18.4393764>,
    <2.2386368, 0.3600245, 18.4393764>,
    <2.0023009, 0.3599633, 18.4393764>,
    <2.0023843, 0.3599825, 18.4393764>,
    <2.0832076, 0.3599775, 18.4393764>,
    <2.0811351, 0.3599965, 18.4393764>,
    <2.0021340, 0.3599249, 18.4393764>,
    <2.1725710, 0.3599540, 18.4393764>,
    <2.0022174, 0.3599441, 18.4393764>,
    <2.0873525, 0.3599394, 18.4393764>,
    <2.1683426, 0.3599728, 18.4393764>,
    <2.0852800, 0.3599585, 18.4393764>,
    <2.2577895, 0.3599686, 18.4393764>,
    <2.2514052, 0.3599872, 18.4393764>,
    <2.1725990, -0.1263328, 18.4905874>,
    <2.0021672, -0.1263783, 18.4905874>,
    <2.0873831, -0.1263556, 18.4905874>,
    <2.0021672, -0.1263783, 18.4649819>,
    <2.1725990, -0.1263328, 18.4649819>,
    <2.0873831, -0.1263556, 18.4649819>,
    <2.3430309, -0.1262872, 18.4905874>,
    <2.3430309, -0.1262872, 18.4649819>,
    <2.2578150, -0.1263100, 18.4905874>,
    <2.2578150, -0.1263100, 18.4649819>,
    <2.3430309, -0.1262872, 18.5161929>,
    <2.1725990, -0.1263328, 18.5161929>,
    <2.2578150, -0.1263100, 18.5161929>,
    <2.0021672, -0.1263783, 18.5161929>,
    <2.0873831, -0.1263556, 18.5161929>,
    <2.3430194, 0.1168480, 18.4905874>,
    <2.3430251, -0.0047196, 18.4905874>,
    <2.3430194, 0.1168480, 18.4649819>,
    <2.3430251, -0.0047196, 18.4649819>,
    <2.3430079, 0.3599832, 18.4905874>,
    <2.3430079, 0.3599832, 18.4649819>,
    <2.3430137, 0.2384156, 18.4905874>,
    <2.3430137, 0.2384156, 18.4649819>,
    <2.3430079, 0.3599832, 18.5161929>,
    <2.3430194, 0.1168480, 18.5161929>,
    <2.3430137, 0.2384156, 18.5161929>,
    <2.3430251, -0.0047196, 18.5161929>,
    <2.1725710, 0.3599540, 18.4905874>,
    <2.2577895, 0.3599686, 18.4905874>,
    <2.1725710, 0.3599540, 18.4649819>,
    <2.2577895, 0.3599686, 18.4649819>,
    <2.0021340, 0.3599249, 18.4905874>,
    <2.0021340, 0.3599249, 18.4649819>,
    <2.0873525, 0.3599394, 18.4905874>,
    <2.0873525, 0.3599394, 18.4649819>,
    <2.0021340, 0.3599249, 18.5161929>,
    <2.1725710, 0.3599540, 18.5161929>,
    <2.0873525, 0.3599394, 18.5161929>,
    <2.2577895, 0.3599686, 18.5161929>,
    <2.0021506, 0.1167733, 18.4905874>,
    <2.0021672, -0.1263783, 18.4905874>,
    <2.0021506, 0.1167733, 18.4393764>,
    <2.0021589, -0.0048025, 18.4905874>,
    <2.0021672, -0.1263783, 18.4649819>,
    <2.0021589, -0.0048025, 18.4393764>,
    <2.0021506, 0.1167733, 18.4649819>,
    <2.0021589, -0.0048025, 18.4649819>,
    <2.0021340, 0.3599249, 18.4905874>,
    <2.0021423, 0.2383491, 18.4393764>,
    <2.0021340, 0.3599249, 18.4649819>,
    <2.0021423, 0.2383491, 18.4905874>,
    <2.0021423, 0.2383491, 18.4649819>,
    <2.0021506, 0.1167733, 18.5417983>,
    <2.0021340, 0.3599249, 18.5161929>,
    <2.0021423, 0.2383491, 18.5417983>,
    <2.0021506, 0.1167733, 18.5161929>,
    <2.0021423, 0.2383491, 18.5161929>,
    <2.0021589, -0.0048025, 18.5417983>,
    <2.0021672, -0.1263783, 18.5161929>,
    <2.0021589, -0.0048025, 18.5161929>,
    <2.0023174, 0.1167755, 18.4393764>,
    <2.0024843, 0.1167778, 18.4393764>,
    <2.0024009, 0.1167767, 18.4393764>,
    <2.0024926, -0.0048341, 18.4393764>,
    <2.0023257, -0.0048183, 18.4393764>,
    <2.0024092, -0.0048262, 18.4393764>,
    <2.0021506, 0.1167733, 18.4393764>,
    <2.0021589, -0.0048025, 18.4393764>,
    <2.0022340, 0.1167744, 18.4393764>,
    <2.0022423, -0.0048104, 18.4393764>,
    <2.0021423, 0.2383491, 18.4393764>,
    <2.0023092, 0.2383694, 18.4393764>,
    <2.0022257, 0.2383592, 18.4393764>,
    <2.0024760, 0.2383898, 18.4393764>,
    <2.0023926, 0.2383796, 18.4393764>,
    <2.0025156, 0.1167782, 18.3784821>,
    <2.0025322, -0.1264525, 18.3784821>,
    <2.0025469, 0.1167787, 18.3175878>,
    <2.0025239, -0.0048371, 18.3784821>,
    <2.0025479, -0.1264556, 18.3480349>,
    <2.0025552, -0.0048401, 18.3175878>,
    <2.0025313, 0.1167784, 18.3480349>,
    <2.0025396, -0.0048386, 18.3480349>,
    <2.0024990, 0.3600089, 18.3784821>,
    <2.0025386, 0.2383974, 18.3175878>,
    <2.0025147, 0.3600125, 18.3480349>,
    <2.0025073, 0.2383936, 18.3784821>,
    <2.0025230, 0.2383955, 18.3480349>,
    <2.0024843, 0.1167778, 18.4393764>,
    <2.0024834, 0.3600053, 18.4089292>,
    <2.0024760, 0.2383898, 18.4393764>,
    <2.0025000, 0.1167780, 18.4089292>,
    <2.0024917, 0.2383917, 18.4089292>,
    <2.0024926, -0.0048341, 18.4393764>,
    <2.0025166, -0.1264493, 18.4089292>,
    <2.0025083, -0.0048356, 18.4089292>,
    <2.0032010, 0.1167875, 18.3135798>,
    <2.0038551, 0.1167964, 18.3095719>,
    <2.0035281, 0.1167920, 18.3115759>,
    <2.0038634, -0.0049640, 18.3095719>,
    <2.0032093, -0.0049021, 18.3135798>,
    <2.0035364, -0.0049330, 18.3115759>,
    <2.0025469, 0.1167787, 18.3175878>,
    <2.0025552, -0.0048401, 18.3175878>,
    <2.0028740, 0.1167831, 18.3155838>,
    <2.0028823, -0.0048711, 18.3155838>,
    <2.0025386, 0.2383974, 18.3175878>,
    <2.0031927, 0.2384771, 18.3135798>,
    <2.0028656, 0.2384373, 18.3155838>,
    <2.0038468, 0.2385569, 18.3095719>,
    <2.0035197, 0.2385170, 18.3115759>,
    <2.0038557, 0.1167964, 18.2344341>,
    <2.0038724, -0.1267246, 18.2344341>,
    <2.0038563, 0.1167964, 18.1592964>,
    <2.0038641, -0.0049641, 18.2344341>,
    <2.0038727, -0.1267247, 18.1968653>,
    <2.0038647, -0.0049642, 18.1592964>,
    <2.0038560, 0.1167964, 18.1968653>,
    <2.0038644, -0.0049641, 18.1968653>,
    <2.0038391, 0.3603175, 18.2344341>,
    <2.0038480, 0.2385570, 18.1592964>,
    <2.0038394, 0.3603176, 18.1968653>,
    <2.0038474, 0.2385570, 18.2344341>,
    <2.0038477, 0.2385570, 18.1968653>,
    <2.0038551, 0.1167964, 18.3095719>,
    <2.0038387, 0.3603174, 18.2720030>,
    <2.0038468, 0.2385569, 18.3095719>,
    <2.0038554, 0.1167964, 18.2720030>,
    <2.0038471, 0.2385569, 18.2720030>,
    <2.0038634, -0.0049640, 18.3095719>,
    <2.0038721, -0.1267246, 18.2720030>,
    <2.0038637, -0.0049641, 18.2720030>,
    <2.0039528, 0.1167978, 18.1573801>,
    <2.0040493, 0.1167991, 18.1554639>,
    <2.0040010, 0.1167984, 18.1564220>,
    <2.0040576, -0.0049824, 18.1554639>,
    <2.0039611, -0.0049733, 18.1573801>,
    <2.0040094, -0.0049779, 18.1564220>,
    <2.0038563, 0.1167964, 18.1592964>,
    <2.0038647, -0.0049642, 18.1592964>,
    <2.0039046, 0.1167971, 18.1583383>,
    <2.0039129, -0.0049687, 18.1583383>,
    <2.0038480, 0.2385570, 18.1592964>,
    <2.0039445, 0.2385688, 18.1573801>,
    <2.0038962, 0.2385629, 18.1583383>,
    <2.0040409, 0.2385806, 18.1554639>,
    <2.0039927, 0.2385747, 18.1564220>,
    <2.0042444, 0.1168017, 18.1389725>,
    <2.0042673, -0.1268048, 18.1386133>,
    <2.0043812, 0.1168036, 18.1258340>,
    <2.0042548, -0.0050016, 18.1388528>,
    <2.0043680, -0.1268253, 18.1301880>,
    <2.0044020, -0.0050178, 18.1251156>,
    <2.0043263, 0.1168028, 18.1316249>,
    <2.0043430, -0.0050113, 18.1311460>,
    <2.0042339, 0.3604084, 18.1386133>,
    <2.0043853, 0.2386253, 18.1251156>,
    <2.0043346, 0.3604316, 18.1301880>,
    <2.0042381, 0.2386051, 18.1388528>,
    <2.0043263, 0.2386172, 18.1311460>,
    <2.0040493, 0.1167991, 18.1554639>,
    <2.0041333, 0.3603852, 18.1470386>,
    <2.0040409, 0.2385806, 18.1554639>,
    <2.0041499, 0.1168004, 18.1470386>,
    <2.0041416, 0.2385928, 18.1470386>,
    <2.0040576, -0.0049824, 18.1554639>,
    <2.0041666, -0.1267844, 18.1470386>,
    <2.0041583, -0.0049920, 18.1470386>,
    <2.0043805, 0.1168036, 18.1205987>,
    <2.0043944, 0.1168038, 18.1224380>,
    <2.0043909, -0.0050145, 18.1204790>,
    <2.0044111, -0.0050177, 18.1219591>,
    <2.0043215, 0.1168028, 18.1187163>,
    <2.0043298, -0.0050082, 18.1187163>,
    <2.0043541, 0.1168032, 18.1194779>,
    <2.0043625, -0.0050113, 18.1194779>,
    <2.0043131, 0.2386138, 18.1187163>,
    <2.0043742, 0.2386217, 18.1204790>,
    <2.0043458, 0.2386177, 18.1194779>,
    <2.0043944, 0.2386255, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0005941, 0.9999662, 0.0082020>,
    <-0.0005941, 0.9999704, 0.0076758>,
    <-0.0005795, 0.9999701, 0.0077076>,
    <-0.0005795, 0.9999661, 0.0082176>,
    <-0.0005795, 0.9999617, 0.0087276>,
    <-0.0005941, 0.9999617, 0.0087283>,
    <-0.0005941, 0.9999617, 0.0087283>,
    <-0.0006097, 0.9999617, 0.0087289>,
    <-0.0006097, 0.9999663, 0.0081855>,
    <-0.0006097, 0.9999663, 0.0081855>,
    <-0.0006097, 0.9999706, 0.0076420>,
    <-0.0005941, 0.9999743, 0.0071496>,
    <-0.0005795, 0.9999739, 0.0071975>,
    <-0.0006097, 0.9999706, 0.0076420>,
    <-0.0006097, 0.9999746, 0.0070986>,
    <-0.0006097, 0.9999746, 0.0070986>,
    <-0.0006097, 0.9999783, 0.0065551>,
    <-0.0005941, 0.9999779, 0.0066234>,
    <-0.0005941, 0.9999779, 0.0066234>,
    <-0.0005795, 0.9999775, 0.0066875>,
    <-0.0005658, 0.9999736, 0.0072426>,
    <-0.0005658, 0.9999699, 0.0077374>,
    <-0.0005795, 0.9999775, 0.0066875>,
    <-0.0005658, 0.9999771, 0.0067477>,
    <-0.0005658, 0.9999771, 0.0067477>,
    <-0.0005529, 0.9999767, 0.0068045>,
    <-0.0005529, 0.9999733, 0.0072850>,
    <-0.0005529, 0.9999733, 0.0072850>,
    <-0.0005529, 0.9999697, 0.0077655>,
    <-0.0005658, 0.9999660, 0.0082322>,
    <-0.0005529, 0.9999697, 0.0077655>,
    <-0.0005529, 0.9999658, 0.0082460>,
    <-0.0005529, 0.9999658, 0.0082460>,
    <-0.0005528, 0.9999618, 0.0087265>,
    <-0.0005658, 0.9999618, 0.0087270>,
    <-0.0005658, 0.9999618, 0.0087270>,
    <-0.0005795, 0.9999617, 0.0087276>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222780, -0.0000115, -0.9749833>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222785, -0.0000115, -0.9749832>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222790, -0.0000115, -0.9749831>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222796, -0.0000115, -0.9749830>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <-0.2222801, -0.0000115, -0.9749829>,
    <0.0003486, -0.9999426, 0.0107096>,
    <0.0003486, -0.9999456, 0.0104237>,
    <0.0003407, -0.9999458, 0.0104065>,
    <0.0003407, -0.9999429, 0.0106836>,
    <0.0003407, -0.9999399, 0.0109607>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003571, -0.9999391, 0.0110326>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003486, -0.9999486, 0.0101378>,
    <0.0003407, -0.9999486, 0.0101293>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999514, 0.0098515>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999487, 0.0101214>,
    <0.0003332, -0.9999460, 0.0103903>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003262, -0.9999514, 0.0098528>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003332, -0.9999431, 0.0106591>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999406, 0.0108971>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003407, -0.9999399, 0.0109607>,
    <0.0005282, -0.9999988, 0.0014301>,
    <0.0005282, -0.9999989, 0.0013517>,
    <0.0005061, -0.9999989, 0.0013600>,
    <0.0005061, -0.9999988, 0.0014341>,
    <0.0005061, -0.9999987, 0.0015083>,
    <0.0005282, -0.9999987, 0.0015084>,
    <0.0005282, -0.9999987, 0.0015084>,
    <0.0005529, -0.9999987, 0.0015086>,
    <0.0005529, -0.9999988, 0.0014255>,
    <0.0005529, -0.9999988, 0.0014255>,
    <0.0005529, -0.9999989, 0.0013425>,
    <0.0005282, -0.9999990, 0.0012734>,
    <0.0005061, -0.9999990, 0.0012859>,
    <0.0005529, -0.9999989, 0.0013425>,
    <0.0005529, -0.9999991, 0.0012594>,
    <0.0005529, -0.9999991, 0.0012594>,
    <0.0005529, -0.9999992, 0.0011763>,
    <0.0005282, -0.9999991, 0.0011951>,
    <0.0005282, -0.9999991, 0.0011951>,
    <0.0005061, -0.9999991, 0.0012118>,
    <0.0004863, -0.9999990, 0.0012971>,
    <0.0004863, -0.9999989, 0.0013674>,
    <0.0005061, -0.9999991, 0.0012118>,
    <0.0004863, -0.9999991, 0.0012268>,
    <0.0004863, -0.9999991, 0.0012268>,
    <0.0004684, -0.9999991, 0.0012403>,
    <0.0004684, -0.9999990, 0.0013072>,
    <0.0004684, -0.9999990, 0.0013072>,
    <0.0004684, -0.9999989, 0.0013742>,
    <0.0004863, -0.9999988, 0.0014378>,
    <0.0004684, -0.9999989, 0.0013742>,
    <0.0004684, -0.9999989, 0.0014411>,
    <0.0004684, -0.9999989, 0.0014411>,
    <0.0004684, -0.9999988, 0.0015080>,
    <0.0004863, -0.9999987, 0.0015081>,
    <0.0004863, -0.9999987, 0.0015081>,
    <0.0005061, -0.9999987, 0.0015083>,
    <0.7968310, 0.0000411, -0.6042023>,
    <0.7968303, 0.0000411, -0.6042032>,
    <0.7968303, 0.0000409, -0.6042032>,
    <0.7968310, 0.0000409, -0.6042023>,
    <0.7968317, 0.0000409, -0.6042013>,
    <0.7968317, 0.0000411, -0.6042013>,
    <0.7968317, 0.0000411, -0.6042013>,
    <0.7968317, 0.0000412, -0.6042013>,
    <0.7968310, 0.0000412, -0.6042023>,
    <0.7968310, 0.0000412, -0.6042023>,
    <0.7968303, 0.0000412, -0.6042032>,
    <0.7968295, 0.0000411, -0.6042042>,
    <0.7968295, 0.0000409, -0.6042042>,
    <0.7968303, 0.0000412, -0.6042032>,
    <0.7968295, 0.0000412, -0.6042042>,
    <0.7968295, 0.0000412, -0.6042042>,
    <0.7968288, 0.0000412, -0.6042051>,
    <0.7968288, 0.0000411, -0.6042051>,
    <0.7968288, 0.0000411, -0.6042051>,
    <0.7968288, 0.0000409, -0.6042051>,
    <0.7968295, 0.0000408, -0.6042042>,
    <0.7968303, 0.0000408, -0.6042032>,
    <0.7968288, 0.0000409, -0.6042051>,
    <0.7968288, 0.0000408, -0.6042051>,
    <0.7968288, 0.0000408, -0.6042051>,
    <0.7968288, 0.0000407, -0.6042051>,
    <0.7968295, 0.0000407, -0.6042042>,
    <0.7968295, 0.0000407, -0.6042042>,
    <0.7968303, 0.0000407, -0.6042032>,
    <0.7968310, 0.0000408, -0.6042023>,
    <0.7968303, 0.0000407, -0.6042032>,
    <0.7968310, 0.0000407, -0.6042023>,
    <0.7968310, 0.0000407, -0.6042023>,
    <0.7968317, 0.0000407, -0.6042013>,
    <0.7968317, 0.0000408, -0.6042013>,
    <0.7968317, 0.0000408, -0.6042013>,
    <0.7968317, 0.0000409, -0.6042013>,
    <-0.0003128, 0.9999983, 0.0018311>,
    <-0.0003128, 0.9999984, 0.0017886>,
    <-0.0003008, 0.9999984, 0.0017841>,
    <-0.0003008, 0.9999983, 0.0018243>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003262, 0.9999982, 0.0018839>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003128, 0.9999984, 0.0017460>,
    <-0.0003008, 0.9999984, 0.0017438>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999985, 0.0017033>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999984, 0.0017418>,
    <-0.0002901, 0.9999984, 0.0017800>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002803, 0.9999985, 0.0017037>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002901, 0.9999983, 0.0018183>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018491>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <0.0004568, -0.9999518, 0.0098056>,
    <0.0004568, -0.9999560, 0.0093662>,
    <0.0004459, -0.9999558, 0.0093940>,
    <0.0004459, -0.9999517, 0.0098193>,
    <0.0004459, -0.9999474, 0.0102445>,
    <0.0004568, -0.9999474, 0.0102451>,
    <0.0004568, -0.9999474, 0.0102451>,
    <0.0004684, -0.9999474, 0.0102456>,
    <0.0004684, -0.9999520, 0.0097911>,
    <0.0004684, -0.9999520, 0.0097911>,
    <0.0004684, -0.9999563, 0.0093365>,
    <0.0004568, -0.9999601, 0.0089268>,
    <0.0004459, -0.9999597, 0.0089688>,
    <0.0004684, -0.9999563, 0.0093365>,
    <0.0004684, -0.9999604, 0.0088820>,
    <0.0004684, -0.9999604, 0.0088820>,
    <0.0004684, -0.9999644, 0.0084274>,
    <0.0004568, -0.9999639, 0.0084874>,
    <0.0004568, -0.9999639, 0.0084874>,
    <0.0004459, -0.9999634, 0.0085435>,
    <0.0004357, -0.9999593, 0.0090081>,
    <0.0004357, -0.9999555, 0.0094201>,
    <0.0004459, -0.9999634, 0.0085435>,
    <0.0004357, -0.9999630, 0.0085961>,
    <0.0004357, -0.9999630, 0.0085961>,
    <0.0004261, -0.9999625, 0.0086456>,
    <0.0004261, -0.9999590, 0.0090451>,
    <0.0004261, -0.9999590, 0.0090451>,
    <0.0004261, -0.9999553, 0.0094445>,
    <0.0004357, -0.9999516, 0.0098320>,
    <0.0004261, -0.9999553, 0.0094445>,
    <0.0004261, -0.9999515, 0.0098440>,
    <0.0004261, -0.9999515, 0.0098440>,
    <0.0004261, -0.9999474, 0.0102435>,
    <0.0004357, -0.9999474, 0.0102440>,
    <0.0004357, -0.9999474, 0.0102440>,
    <0.0004459, -0.9999474, 0.0102445>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905385, 0.0000097, -0.9816797>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905390, 0.0000097, -0.9816796>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905394, 0.0000097, -0.9816795>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905399, 0.0000097, -0.9816795>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <0.1905403, 0.0000097, -0.9816794>,
    <-0.0002740, 0.9999244, 0.0122917>,
    <-0.0002740, 0.9999273, 0.0120530>,
    <-0.0002681, 0.9999275, 0.0120379>,
    <-0.0002681, 0.9999247, 0.0122689>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002803, 0.9999210, 0.0125631>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002740, 0.9999302, 0.0118142>,
    <-0.0002681, 0.9999303, 0.0118068>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999330, 0.0115751>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999303, 0.0117999>,
    <-0.0002625, 0.9999277, 0.0120237>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002573, 0.9999330, 0.0115763>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002625, 0.9999250, 0.0122476>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999225, 0.0124445>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <0.0004328, -0.9999999, 0.0000263>,
    <0.0004297, -0.9999999, 0.0000444>,
    <0.0004572, -0.9999999, 0.0001852>,
    <0.0004819, -0.9999999, 0.0001033>,
    <0.0004871, -0.9999999, 0.0000017>,
    <0.0004338, -0.9999999, 0.0000017>,
    <0.0004338, -0.9999999, 0.0000017>,
    <0.0004261, -0.9999999, 0.0000017>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004264, -0.9999999, 0.0000506>,
    <0.0004300, -0.9999999, 0.0002171>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000015>,
    <0.0004261, -0.9999999, 0.0000015>,
    <0.0004261, -0.9999999, 0.0000014>,
    <0.0004254, -0.9999999, 0.0000496>,
    <0.0004254, -0.9999999, 0.0000496>,
    <0.0004208, -0.9999999, 0.0002141>,
    <0.0004392, -0.9999997, 0.0005874>,
    <0.0005266, -0.9999997, 0.0005300>,
    <0.0004208, -0.9999999, 0.0002141>,
    <0.0004092, -0.9999997, 0.0005804>,
    <0.0004092, -0.9999997, 0.0005804>,
    <0.0003889, -0.9999989, 0.0014524>,
    <0.0004419, -0.9999988, 0.0014766>,
    <0.0006011, -0.9999987, 0.0014789>,
    <0.0006366, -0.9999997, 0.0003445>,
    <0.0009775, -0.9999984, 0.0015046>,
    <0.0012929, -0.9999977, 0.0016908>,
    <0.0006563, -0.9999998, 0.0000017>,
    <0.0006563, -0.9999998, 0.0000017>,
    <0.0004871, -0.9999999, 0.0000017>,
    <0.9995639, 0.0000507, -0.0295315>,
    <0.9995638, 0.0000507, -0.0295315>,
    <0.9920098, 0.0000502, -0.1261608>,
    <0.9920098, 0.0000502, -0.1261605>,
    <0.9920099, 0.0000502, -0.1261602>,
    <0.9995639, 0.0000507, -0.0295314>,
    <0.9995639, 0.0000507, -0.0295314>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9995638, 0.0000507, -0.0295316>,
    <0.9920098, 0.0000502, -0.1261611>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9999996, 0.0000507, -0.0008513>,
    <0.9995638, 0.0000507, -0.0295317>,
    <0.9995638, 0.0000507, -0.0295317>,
    <0.9920097, 0.0000502, -0.1261614>,
    <0.9460835, 0.0000478, -0.3239228>,
    <0.9460838, 0.0000478, -0.3239221>,
    <0.9920097, 0.0000502, -0.1261614>,
    <0.9460833, 0.0000478, -0.3239235>,
    <0.9460833, 0.0000478, -0.3239235>,
    <0.7631609, 0.0000384, -0.6462085>,
    <0.7631617, 0.0000384, -0.6462076>,
    <0.7631625, 0.0000384, -0.6462067>,
    <0.9460840, 0.0000478, -0.3239213>,
    <0.7631632, 0.0000384, -0.6462057>,
    <0.7631640, 0.0000384, -0.6462048>,
    <0.9460843, 0.0000478, -0.3239206>,
    <0.9460843, 0.0000478, -0.3239206>,
    <0.9920099, 0.0000502, -0.1261602>,
    <-0.0002557, 1.0000000, 0.0000687>,
    <-0.0002521, 1.0000000, 0.0000578>,
    <-0.0002128, 0.9999999, 0.0002410>,
    <-0.0002438, 0.9999999, 0.0002938>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002573, 1.0000000, 0.0000021>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002485, 1.0000000, 0.0000335>,
    <-0.0001849, 1.0000000, 0.0001319>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000127, 0.9999999, 0.0004262>,
    <-0.0001114, 0.9999998, 0.0006796>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0004444, 0.9999983, 0.0017942>,
    <0.0000146, 0.9999983, 0.0018600>,
    <-0.0002126, 0.9999997, 0.0007890>,
    <-0.0001727, 0.9999981, 0.0019562>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <0.0009820, -0.9999841, 0.0055500>,
    <0.0005787, -0.9999933, 0.0036053>,
    <0.0003522, -0.9999833, 0.0057696>,
    <0.0003820, -0.9999521, 0.0097787>,
    <0.0005080, -0.9994483, 0.0332100>,
    <0.0042098, -0.9994193, 0.0338132>,
    <0.0042098, -0.9994193, 0.0338132>,
    <0.0012929, -0.9999977, 0.0016908>,
    <0.0004125, -0.9999948, 0.0032130>,
    <0.0003397, -0.9999888, 0.0047174>,
    <0.0003889, -0.9999989, 0.0014524>,
    <0.0003623, -0.9999951, 0.0031167>,
    <0.0003623, -0.9999951, 0.0031167>,
    <0.0003364, -0.9999899, 0.0044723>,
    <0.0002761, -0.9999919, 0.0040074>,
    <0.0001403, -0.9999887, 0.0047436>,
    <0.0003364, -0.9999899, 0.0044723>,
    <0.0003153, -0.9999928, 0.0037768>,
    <0.0003153, -0.9999928, 0.0037768>,
    <0.0003004, -0.9999981, 0.0019498>,
    <0.0002642, -0.9999979, 0.0020286>,
    <0.0001522, -0.9999977, 0.0021282>,
    <-0.0001919, -0.9999731, 0.0073266>,
    <-0.0001143, -0.9999976, 0.0022072>,
    <-0.0002937, -0.9999977, 0.0021417>,
    <-0.0020821, -0.9994602, 0.0327876>,
    <-0.0020821, -0.9994602, 0.0327876>,
    <0.0005080, -0.9994483, 0.0332100>,
    <0.4878559, 0.0000243, -0.8729242>,
    <0.4878549, 0.0000243, -0.8729247>,
    <0.3675999, 0.0000181, -0.9299841>,
    <0.3676006, 0.0000181, -0.9299837>,
    <0.3676014, 0.0000181, -0.9299834>,
    <0.4878568, 0.0000243, -0.8729237>,
    <0.4878568, 0.0000243, -0.8729237>,
    <0.7631640, 0.0000384, -0.6462048>,
    <0.4878540, 0.0000243, -0.8729252>,
    <0.3675991, 0.0000181, -0.9299844>,
    <0.7631609, 0.0000384, -0.6462085>,
    <0.4878531, 0.0000243, -0.8729257>,
    <0.4878531, 0.0000243, -0.8729257>,
    <0.3675983, 0.0000181, -0.9299847>,
    <0.4280648, 0.0000209, -0.9037480>,
    <0.4280657, 0.0000209, -0.9037476>,
    <0.3675983, 0.0000181, -0.9299847>,
    <0.4280639, 0.0000209, -0.9037484>,
    <0.4280639, 0.0000209, -0.9037484>,
    <0.6790848, 0.0000329, -0.7340599>,
    <0.6790857, 0.0000329, -0.7340590>,
    <0.6790866, 0.0000329, -0.7340582>,
    <0.4280665, 0.0000209, -0.9037472>,
    <0.6790875, 0.0000329, -0.7340574>,
    <0.6790884, 0.0000329, -0.7340565>,
    <0.4280674, 0.0000209, -0.9037468>,
    <0.4280674, 0.0000209, -0.9037468>,
    <0.3676014, 0.0000181, -0.9299834>,
    <-0.0001605, 0.9999912, 0.0041835>,
    <0.0000373, 0.9999900, 0.0044632>,
    <-0.0001893, 0.9999751, 0.0070592>,
    <-0.0002044, 0.9999817, 0.0060433>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <0.0004994, 0.9999785, 0.0065314>,
    <-0.0001552, 0.9999344, 0.0114548>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0041270, 0.9992606, 0.0382247>,
    <0.0041270, 0.9992606, 0.0382247>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0007848, 0.9999631, 0.0085524>,
    <-0.0004049, 0.9999833, 0.0057588>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0006662, 0.9999964, 0.0025817>,
    <-0.0003625, 0.9999966, 0.0025763>,
    <-0.0002448, 0.9999871, 0.0050692>,
    <-0.0002322, 0.9999967, 0.0025453>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <0.0001552, -0.9999998, 0.0005685>,
    <0.0002210, -0.9999996, 0.0008105>,
    <0.0002669, -0.9999999, 0.0003406>,
    <0.0002531, -0.9999999, 0.0002361>,
    <0.0002504, -1.0000000, 0.0001045>,
    <0.0001454, -1.0000000, 0.0001045>,
    <0.0001454, -1.0000000, 0.0001045>,
    <-0.0002937, -0.9999977, 0.0021417>,
    <0.0002737, -0.9999996, 0.0008673>,
    <0.0002820, -0.9999999, 0.0003799>,
    <0.0003004, -0.9999981, 0.0019498>,
    <0.0002917, -0.9999996, 0.0008532>,
    <0.0002917, -0.9999996, 0.0008532>,
    <0.0002871, -0.9999999, 0.0003774>,
    <0.0002844, -0.9999999, 0.0001621>,
    <0.0002826, -0.9999999, 0.0001554>,
    <0.0002871, -0.9999999, 0.0003774>,
    <0.0002849, -0.9999999, 0.0001599>,
    <0.0002849, -0.9999999, 0.0001599>,
    <0.0002839, -1.0000000, 0.0000958>,
    <0.0002839, -1.0000000, 0.0000980>,
    <0.0002839, -1.0000000, 0.0000980>,
    <0.0002839, -1.0000000, 0.0001001>,
    <0.0002809, -1.0000000, 0.0001341>,
    <0.0002839, -1.0000000, 0.0001001>,
    <0.0002839, -1.0000000, 0.0001023>,
    <0.0002839, -1.0000000, 0.0001023>,
    <0.0002839, -1.0000000, 0.0001045>,
    <0.0002804, -1.0000000, 0.0001045>,
    <0.0002804, -1.0000000, 0.0001045>,
    <0.0002504, -1.0000000, 0.0001045>,
    <0.9047737, 0.0000436, -0.4258927>,
    <0.9047733, 0.0000436, -0.4258936>,
    <0.9790994, 0.0000470, -0.2033825>,
    <0.9790995, 0.0000470, -0.2033820>,
    <0.9790996, 0.0000470, -0.2033815>,
    <0.9047741, 0.0000436, -0.4258919>,
    <0.9047741, 0.0000436, -0.4258919>,
    <0.6790884, 0.0000329, -0.7340565>,
    <0.9047729, 0.0000436, -0.4258945>,
    <0.9790993, 0.0000470, -0.2033830>,
    <0.6790848, 0.0000329, -0.7340599>,
    <0.9047724, 0.0000436, -0.4258953>,
    <0.9047724, 0.0000436, -0.4258953>,
    <0.9790992, 0.0000470, -0.2033835>,
    <0.9961600, 0.0000477, -0.0875510>,
    <0.9961601, 0.0000477, -0.0875508>,
    <0.9790992, 0.0000470, -0.2033835>,
    <0.9961600, 0.0000477, -0.0875512>,
    <0.9961600, 0.0000477, -0.0875512>,
    <0.9986191, 0.0000478, -0.0525351>,
    <0.9986191, 0.0000478, -0.0525350>,
    <0.9986191, 0.0000478, -0.0525350>,
    <0.9986191, 0.0000478, -0.0525349>,
    <0.9961601, 0.0000477, -0.0875506>,
    <0.9986191, 0.0000478, -0.0525349>,
    <0.9986191, 0.0000478, -0.0525347>,
    <0.9986191, 0.0000478, -0.0525347>,
    <0.9986191, 0.0000478, -0.0525346>,
    <0.9961601, 0.0000477, -0.0875504>,
    <0.9961601, 0.0000477, -0.0875504>,
    <0.9790996, 0.0000470, -0.2033815>,
    <-0.0002053, 0.9999994, 0.0010841>,
    <-0.0002659, 0.9999995, 0.0009839>,
    <-0.0002050, 0.9999999, 0.0004143>,
    <-0.0001877, 0.9999999, 0.0004740>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0003403, 0.9999997, 0.0006738>,
    <-0.0002205, 0.9999999, 0.0002809>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001852, 1.0000000, 0.0001577>,
    <-0.0001833, 1.0000000, 0.0001881>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001801, 1.0000000, 0.0001183>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001813, 1.0000000, 0.0002019>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001230>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, -0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <1.0000000, 0.0000472, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, -0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <1.0000000, 0.0000682, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005139>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <0.9999999, 0.0000682, 0.0005140>,
    <-0.9869426, -0.0000675, -0.1610724>,
    <-0.9869426, -0.0000674, -0.1610724>,
    <-0.9869431, -0.0000674, -0.1610692>,
    <-0.9869431, -0.0000675, -0.1610692>,
    <-0.9869431, -0.0000675, -0.1610692>,
    <-0.9869426, -0.0000675, -0.1610724>,
    <-0.9869426, -0.0000675, -0.1610724>,
    <-0.9869421, -0.0000675, -0.1610756>,
    <-0.9869421, -0.0000675, -0.1610756>,
    <-0.9869421, -0.0000675, -0.1610756>,
    <-0.9869421, -0.0000674, -0.1610756>,
    <-0.9869426, -0.0000674, -0.1610724>,
    <-0.9869431, -0.0000674, -0.1610692>,
    <-0.9869421, -0.0000674, -0.1610756>,
    <-0.9869421, -0.0000674, -0.1610756>,
    <-0.9869421, -0.0000674, -0.1610756>,
    <-0.9869421, -0.0000673, -0.1610756>,
    <-0.9869426, -0.0000673, -0.1610724>,
    <-0.9869426, -0.0000673, -0.1610724>,
    <-0.9869431, -0.0000673, -0.1610692>,
    <-0.9869436, -0.0000674, -0.1610659>,
    <-0.9869436, -0.0000674, -0.1610659>,
    <-0.9869431, -0.0000673, -0.1610692>,
    <-0.9869436, -0.0000673, -0.1610659>,
    <-0.9869436, -0.0000673, -0.1610659>,
    <-0.9869442, -0.0000673, -0.1610627>,
    <-0.9869442, -0.0000674, -0.1610627>,
    <-0.9869442, -0.0000674, -0.1610627>,
    <-0.9869442, -0.0000674, -0.1610627>,
    <-0.9869436, -0.0000675, -0.1610659>,
    <-0.9869442, -0.0000674, -0.1610627>,
    <-0.9869442, -0.0000675, -0.1610627>,
    <-0.9869442, -0.0000675, -0.1610627>,
    <-0.9869442, -0.0000675, -0.1610627>,
    <-0.9869436, -0.0000675, -0.1610659>,
    <-0.9869436, -0.0000675, -0.1610659>,
    <-0.9869431, -0.0000675, -0.1610692>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <1.0000000, 0.0000684, 0.0000083>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502722>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987356, -0.0000684, -0.0502712>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987358, -0.0000684, -0.0502681>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987357, -0.0000684, -0.0502691>,
    <-0.9987357, -0.0000684, -0.0502702>,
    <0.9999404, 0.0001137, 0.0109141>,
    <0.9999447, 0.0000685, 0.0105163>,
    <0.9999338, 0.0000685, 0.0115037>,
    <0.9999321, 0.0000798, 0.0116512>,
    <0.9999286, 0.0000828, 0.0119507>,
    <0.9999286, 0.0001238, 0.0119506>,
    <0.9999286, 0.0001238, 0.0119506>,
    <0.9999725, 0.0002780, 0.0074076>,
    <0.9999725, 0.0001995, 0.0074077>,
    <0.9999726, 0.0000685, 0.0074076>,
    <0.9999404, 0.0000234, 0.0109136>,
    <0.9999321, 0.0000572, 0.0116506>,
    <0.9999726, -0.0000624, 0.0074074>,
    <0.9999726, -0.0001409, 0.0074070>,
    <0.9999286, 0.0000132, 0.0119496>,
    <0.9999286, 0.0000132, 0.0119496>,
    <0.9999286, 0.0000542, 0.0119498>,
    <0.9999294, 0.0000671, 0.0118782>,
    <0.9999298, 0.0000685, 0.0118451>,
    <0.9999286, 0.0000542, 0.0119498>,
    <0.9999286, 0.0000667, 0.0119498>,
    <0.9999286, 0.0000667, 0.0119498>,
    <0.9999286, 0.0000685, 0.0119498>,
    <0.9999286, 0.0000685, 0.0119500>,
    <0.9999286, 0.0000685, 0.0119500>,
    <0.9999286, 0.0000685, 0.0119503>,
    <0.9999294, 0.0000698, 0.0118787>,
    <0.9999286, 0.0000685, 0.0119503>,
    <0.9999286, 0.0000685, 0.0119505>,
    <0.9999286, 0.0000685, 0.0119505>,
    <0.9999286, 0.0000685, 0.0119508>,
    <0.9999286, 0.0000703, 0.0119508>,
    <0.9999286, 0.0000703, 0.0119508>,
    <0.9999286, 0.0000828, 0.0119507>,
    <0.9999905, 0.0002200, -0.0043628>,
    <0.9997833, 0.0001436, -0.0208159>,
    <0.9998819, 0.0000685, -0.0153711>,
    <0.9999997, 0.0000685, -0.0008270>,
    <0.9999725, 0.0002780, 0.0074076>,
    <0.9990830, 0.0006798, -0.0428094>,
    <0.9990830, 0.0006798, -0.0428094>,
    <0.9990831, 0.0002263, -0.0428133>,
    <0.9993788, 0.0000814, -0.0352415>,
    <0.9994752, 0.0000685, -0.0323937>,
    <0.9990831, 0.0002263, -0.0428133>,
    <0.9990830, 0.0000882, -0.0428145>,
    <0.9990830, 0.0000882, -0.0428145>,
    <0.9990830, 0.0000685, -0.0428147>,
    <0.9990831, 0.0000685, -0.0428138>,
    <0.9990831, 0.0000685, -0.0428138>,
    <0.9990831, 0.0000685, -0.0428129>,
    <0.9993789, 0.0000555, -0.0352399>,
    <0.9997834, -0.0000066, -0.0208147>,
    <0.9990831, 0.0000685, -0.0428129>,
    <0.9990831, 0.0000685, -0.0428121>,
    <0.9990831, 0.0000685, -0.0428121>,
    <0.9990832, 0.0000685, -0.0428112>,
    <0.9990832, 0.0000487, -0.0428110>,
    <0.9990832, 0.0000487, -0.0428110>,
    <0.9990832, -0.0000893, -0.0428096>,
    <0.9999905, -0.0000830, -0.0043624>,
    <0.9990832, -0.0000893, -0.0428096>,
    <0.9990833, -0.0005429, -0.0428051>,
    <0.9990833, -0.0005429, -0.0428051>,
    <0.9999726, -0.0001409, 0.0074070>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4349582, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4349582, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4263414, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559367, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773948, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032658, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458854>,
    <0.4677608, 0.9456845>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4355157, 0.9458854>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9451388>,
    <0.4677604, 0.9518685>,
    <0.4676209, 0.9588001>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.4677604, 0.9518685>,
    <0.5000059, 0.9579003>,
    <0.4674769, 0.9657316>,
    <0.4352664, 0.9584513>,
    <0.4031264, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4349582, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352664, 0.9584513>,
    <0.4022562, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032658, 0.9526160>,
    <0.5322510, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9518685>,
    <0.5000059, 0.9451388>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458642>,
    <0.5967410, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5644961, 0.9458642>,
    <0.5967380, 0.9395004>,
    <0.6289858, 0.9451388>,
    <0.5967440, 0.9518685>,
    <0.5967474, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967440, 0.9518685>,
    <0.6289941, 0.9579003>,
    <0.5967509, 0.9657316>,
    <0.5645003, 0.9587016>,
    <0.5322532, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.5645003, 0.9587016>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9579003>,
    <0.5322521, 0.9518685>,
    <0.6423395, 0.9456845>,
    <0.6556982, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423437, 0.9518685>,
    <0.6289858, 0.9451388>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458854>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458854>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691147, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694793, 0.9657316>,
    <0.6558043, 0.9584513>,
    <0.6424060, 0.9588001>,
    <0.6556982, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.6558043, 0.9584513>,
    <0.6424701, 0.9657316>,
    <0.6289941, 0.9579003>,
    <0.6423437, 0.9518685>,
    <0.3997689, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4022562, 0.9657316>,
    <0.4331396, 0.9660561>,
    <0.4665018, 0.9660805>,
    <0.4310370, 0.9664312>,
    <0.4349582, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4331396, 0.9660561>,
    <0.4674769, 0.9657316>,
    <0.5000060, 0.9660883>,
    <0.4655215, 0.9664293>,
    <0.4643476, 0.9667801>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000061, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.4655215, 0.9664293>,
    <0.5000060, 0.9667645>,
    <0.4631665, 0.9671308>,
    <0.4286164, 0.9667919>,
    <0.3931424, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4263414, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4286164, 0.9667919>,
    <0.3894539, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664293>,
    <0.5000060, 0.9660883>,
    <0.5322542, 0.9657316>,
    <0.5667950, 0.9660902>,
    <0.6000933, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5667950, 0.9660902>,
    <0.5967509, 0.9657316>,
    <0.6335597, 0.9660883>,
    <0.6034357, 0.9664293>,
    <0.6068019, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034357, 0.9664293>,
    <0.6422052, 0.9667645>,
    <0.6101681, 0.9671308>,
    <0.5711180, 0.9667664>,
    <0.5356086, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.5711180, 0.9667664>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667645>,
    <0.5344905, 0.9664293>,
    <0.6473345, 0.9660805>,
    <0.6665054, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6289992, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6522009, 0.9664293>,
    <0.6335597, 0.9660883>,
    <0.6424701, 0.9657316>,
    <0.6608384, 0.9660561>,
    <0.6749817, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559367, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6608384, 0.9660561>,
    <0.6694793, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866708, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926707, 0.9671308>,
    <0.6721189, 0.9667919>,
    <0.6571714, 0.9667801>,
    <0.6665054, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.6721189, 0.9667919>,
    <0.6621448, 0.9671308>,
    <0.6422052, 0.9667645>,
    <0.6522009, 0.9664293>,
    <0.3896277, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.3895219, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3894539, 0.9671308>,
    <0.4263465, 0.9729776>,
    <0.4631761, 0.9726967>,
    <0.4263507, 0.9777601>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4263465, 0.9729776>,
    <0.4631665, 0.9671308>,
    <0.5000061, 0.9732089>,
    <0.4631777, 0.9782626>,
    <0.4631249, 0.9833260>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631777, 0.9782626>,
    <0.5000061, 0.9837065>,
    <0.4630714, 0.9883895>,
    <0.4262410, 0.9832100>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262410, 0.9832100>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895219, 0.9777601>,
    <0.5367803, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9782626>,
    <0.5000061, 0.9732089>,
    <0.5367268, 0.9671308>,
    <0.5735592, 0.9726839>,
    <0.6103387, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5735592, 0.9726839>,
    <0.6101681, 0.9671308>,
    <0.6471335, 0.9732089>,
    <0.6105094, 0.9782626>,
    <0.6106597, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105094, 0.9782626>,
    <0.6475562, 0.9837065>,
    <0.6108101, 0.9883895>,
    <0.5737713, 0.9832176>,
    <0.5368873, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.5737713, 0.9832176>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9837065>,
    <0.5368338, 0.9782626>,
    <0.6623650, 0.9726967>,
    <0.6778190, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6468888, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6625884, 0.9782625>,
    <0.6471335, 0.9732089>,
    <0.6621448, 0.9671308>,
    <0.6776281, 0.9729776>,
    <0.6928127, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773948, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776281, 0.9729776>,
    <0.6926707, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930705, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930705, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780838, 0.9832100>,
    <0.6628141, 0.9833260>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.6780838, 0.9832100>,
    <0.6630402, 0.9883895>,
    <0.6475562, 0.9837065>,
    <0.6625884, 0.9782625>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.011335, -0.36281, -0.147353>
}

#declare TMesh005 = mesh2 {
  vertex_vectors {
    582,
    <2.1725850, 0.1125493, 18.5417983>,
    <2.0021506, 0.1125124, 18.5417983>,
    <2.0021672, -0.1349001, 18.5417983>,
    <2.1725990, -0.1348554, 18.5417983>,
    <2.0873678, 0.1125308, 18.5417983>,
    <2.0021589, -0.0111938, 18.5417983>,
    <2.0873831, -0.1348777, 18.5417983>,
    <2.1725920, -0.0111531, 18.5417983>,
    <2.0873754, -0.0111734, 18.5417983>,
    <2.3430309, -0.1348108, 18.5417983>,
    <2.3430194, 0.1125862, 18.5417983>,
    <2.2578150, -0.1348331, 18.5417983>,
    <2.3430251, -0.0111123, 18.5417983>,
    <2.2578022, 0.1125678, 18.5417983>,
    <2.2578086, -0.0111327, 18.5417983>,
    <2.3430079, 0.3599832, 18.5417983>,
    <2.1725710, 0.3599540, 18.5417983>,
    <2.3430137, 0.2362847, 18.5417983>,
    <2.2577895, 0.3599686, 18.5417983>,
    <2.1725780, 0.2362517, 18.5417983>,
    <2.2577958, 0.2362682, 18.5417983>,
    <2.0021340, 0.3599249, 18.5417983>,
    <2.0873525, 0.3599394, 18.5417983>,
    <2.0021423, 0.2362186, 18.5417983>,
    <2.0873601, 0.2362351, 18.5417983>,
    <2.0592721, -0.1353143, 18.1202395>,
    <2.0044034, -0.1353455, 18.1202395>,
    <2.0044687, -0.1353585, 18.1217627>,
    <2.0559641, -0.1353277, 18.1217627>,
    <2.0318378, -0.1353299, 18.1202395>,
    <2.0044361, -0.1353520, 18.1210011>,
    <2.0302164, -0.1353431, 18.1217627>,
    <2.0576181, -0.1353210, 18.1210011>,
    <2.0310271, -0.1353365, 18.1210011>,
    <2.1074595, -0.1352969, 18.1217627>,
    <2.1141408, -0.1352831, 18.1202395>,
    <2.0817118, -0.1353123, 18.1217627>,
    <2.1108002, -0.1352900, 18.1210011>,
    <2.0867065, -0.1352987, 18.1202395>,
    <2.0842091, -0.1353055, 18.1210011>,
    <2.1208221, -0.1352693, 18.1187163>,
    <2.0625801, -0.1353009, 18.1187163>,
    <2.1174814, -0.1352762, 18.1194779>,
    <2.0917011, -0.1352851, 18.1187163>,
    <2.0609261, -0.1353076, 18.1194779>,
    <2.0892038, -0.1352919, 18.1194779>,
    <2.0043382, -0.1353325, 18.1187163>,
    <2.0334591, -0.1353167, 18.1187163>,
    <2.0043708, -0.1353390, 18.1194779>,
    <2.0326485, -0.1353233, 18.1194779>,
    <2.1141282, 0.1125970, 18.1202395>,
    <2.1074469, 0.1125974, 18.1217627>,
    <2.1141345, -0.0113430, 18.1202395>,
    <2.1074532, -0.0113498, 18.1217627>,
    <2.1107875, 0.1125972, 18.1210011>,
    <2.1107938, -0.0113464, 18.1210011>,
    <2.1074342, 0.3604916, 18.1217627>,
    <2.1141156, 0.3604772, 18.1202395>,
    <2.1074405, 0.2365445, 18.1217627>,
    <2.1107749, 0.3604844, 18.1210011>,
    <2.1141219, 0.2365371, 18.1202395>,
    <2.1107812, 0.2365408, 18.1210011>,
    <2.1207969, 0.3604627, 18.1187163>,
    <2.1208095, 0.1125967, 18.1187163>,
    <2.1174562, 0.3604700, 18.1194779>,
    <2.1208032, 0.2365297, 18.1187163>,
    <2.1174688, 0.1125969, 18.1194779>,
    <2.1174625, 0.2365334, 18.1194779>,
    <2.1208158, -0.0113363, 18.1187163>,
    <2.1174751, -0.0113397, 18.1194779>,
    <2.0592428, 0.3604585, 18.1202395>,
    <2.0559348, 0.3604732, 18.1217627>,
    <2.0866792, 0.3604678, 18.1202395>,
    <2.0816845, 0.3604824, 18.1217627>,
    <2.0575888, 0.3604658, 18.1210011>,
    <2.0841818, 0.3604751, 18.1210011>,
    <2.0044353, 0.3604548, 18.1217627>,
    <2.0043701, 0.3604398, 18.1202395>,
    <2.0301850, 0.3604640, 18.1217627>,
    <2.0044027, 0.3604473, 18.1210011>,
    <2.0318064, 0.3604491, 18.1202395>,
    <2.0309957, 0.3604566, 18.1210011>,
    <2.0043048, 0.3604247, 18.1187163>,
    <2.0625508, 0.3604437, 18.1187163>,
    <2.0043374, 0.3604323, 18.1194779>,
    <2.0334278, 0.3604342, 18.1187163>,
    <2.0608968, 0.3604511, 18.1194779>,
    <2.0326171, 0.3604417, 18.1194779>,
    <2.0916739, 0.3604532, 18.1187163>,
    <2.0891765, 0.3604605, 18.1194779>,
    <2.0694781, -0.1352729, 18.1370901>,
    <2.0042020, -0.1353053, 18.1370901>,
    <2.0368401, -0.1352891, 18.1370901>,
    <2.0042701, -0.1353189, 18.1279032>,
    <2.0660291, -0.1352869, 18.1279032>,
    <2.0351496, -0.1353029, 18.1279032>,
    <2.1347541, -0.1352406, 18.1370901>,
    <2.1277881, -0.1352549, 18.1279032>,
    <2.1021161, -0.1352568, 18.1370901>,
    <2.0969086, -0.1352709, 18.1279032>,
    <2.1486861, -0.1352118, 18.1554639>,
    <2.0763760, -0.1352450, 18.1554639>,
    <2.1417201, -0.1352262, 18.1462770>,
    <2.1125311, -0.1352284, 18.1554639>,
    <2.0729270, -0.1352590, 18.1462770>,
    <2.1073236, -0.1352426, 18.1462770>,
    <2.0040659, -0.1352782, 18.1554639>,
    <2.0402210, -0.1352616, 18.1554639>,
    <2.0041340, -0.1352918, 18.1462770>,
    <2.0385305, -0.1352754, 18.1462770>,
    <2.1347416, 0.1125961, 18.1370901>,
    <2.1347478, -0.0113222, 18.1370901>,
    <2.1277755, 0.1125964, 18.1279032>,
    <2.1277818, -0.0113293, 18.1279032>,
    <2.1347291, 0.3604327, 18.1370901>,
    <2.1277630, 0.3604477, 18.1279032>,
    <2.1347353, 0.2365144, 18.1370901>,
    <2.1277693, 0.2365221, 18.1279032>,
    <2.1486612, 0.3604026, 18.1554639>,
    <2.1486737, 0.1125954, 18.1554639>,
    <2.1416951, 0.3604176, 18.1462770>,
    <2.1486675, 0.2364990, 18.1554639>,
    <2.1417076, 0.1125957, 18.1462770>,
    <2.1417014, 0.2365067, 18.1462770>,
    <2.1486799, -0.0113082, 18.1554639>,
    <2.1417139, -0.0113152, 18.1462770>,
    <2.0694489, 0.3604130, 18.1370901>,
    <2.1020890, 0.3604229, 18.1370901>,
    <2.0659999, 0.3604284, 18.1279032>,
    <2.0968814, 0.3604381, 18.1279032>,
    <2.0041687, 0.3603934, 18.1370901>,
    <2.0042367, 0.3604091, 18.1279032>,
    <2.0368088, 0.3604032, 18.1370901>,
    <2.0351183, 0.3604187, 18.1279032>,
    <2.0040326, 0.3603621, 18.1554639>,
    <2.0763469, 0.3603823, 18.1554639>,
    <2.0041006, 0.3603777, 18.1462770>,
    <2.0401897, 0.3603722, 18.1554639>,
    <2.0728979, 0.3603977, 18.1462770>,
    <2.0384993, 0.3603877, 18.1462770>,
    <2.1125041, 0.3603925, 18.1554639>,
    <2.1072965, 0.3604077, 18.1462770>,
    <2.0812641, -0.1352252, 18.1573801>,
    <2.0039695, -0.1352590, 18.1573801>,
    <2.0426168, -0.1352421, 18.1573801>,
    <2.0040177, -0.1352686, 18.1564220>,
    <2.0788201, -0.1352351, 18.1564220>,
    <2.0414189, -0.1352519, 18.1564220>,
    <2.1585588, -0.1351914, 18.1573801>,
    <2.1536225, -0.1352016, 18.1564220>,
    <2.1199115, -0.1352083, 18.1573801>,
    <2.1162213, -0.1352184, 18.1564220>,
    <2.1684314, -0.1351711, 18.1592964>,
    <2.0861522, -0.1352054, 18.1592964>,
    <2.1634951, -0.1351812, 18.1583383>,
    <2.1272918, -0.1351882, 18.1592964>,
    <2.0837082, -0.1352153, 18.1583383>,
    <2.1236016, -0.1351983, 18.1583383>,
    <2.0038730, -0.1352398, 18.1592964>,
    <2.0450126, -0.1352226, 18.1592964>,
    <2.0039212, -0.1352494, 18.1583383>,
    <2.0438147, -0.1352324, 18.1583383>,
    <2.1585464, 0.1125949, 18.1573801>,
    <2.1585526, -0.0112982, 18.1573801>,
    <2.1536100, 0.1125952, 18.1564220>,
    <2.1536162, -0.0113032, 18.1564220>,
    <2.1585340, 0.3603813, 18.1573801>,
    <2.1535976, 0.3603920, 18.1564220>,
    <2.1585402, 0.2364881, 18.1573801>,
    <2.1536038, 0.2364936, 18.1564220>,
    <2.1684068, 0.3603600, 18.1592964>,
    <2.1684191, 0.1125945, 18.1592964>,
    <2.1634704, 0.3603706, 18.1583383>,
    <2.1684129, 0.2364772, 18.1592964>,
    <2.1634827, 0.1125947, 18.1583383>,
    <2.1634766, 0.2364827, 18.1583383>,
    <2.1684253, -0.0112883, 18.1592964>,
    <2.1634889, -0.0112933, 18.1583383>,
    <2.0812351, 0.3603606, 18.1573801>,
    <2.1198845, 0.3603709, 18.1573801>,
    <2.0787910, 0.3603715, 18.1564220>,
    <2.1161943, 0.3603817, 18.1564220>,
    <2.0039361, 0.3603399, 18.1573801>,
    <2.0039844, 0.3603510, 18.1564220>,
    <2.0425856, 0.3603502, 18.1573801>,
    <2.0413877, 0.3603612, 18.1564220>,
    <2.0038397, 0.3603176, 18.1592964>,
    <2.0861232, 0.3603388, 18.1592964>,
    <2.0038879, 0.3603287, 18.1583383>,
    <2.0449814, 0.3603282, 18.1592964>,
    <2.0836791, 0.3603497, 18.1583383>,
    <2.0437835, 0.3603392, 18.1583383>,
    <2.1272650, 0.3603494, 18.1592964>,
    <2.1235748, 0.3603602, 18.1583383>,
    <2.0872214, -0.1352016, 18.2324892>,
    <2.0038724, -0.1352397, 18.2344341>,
    <2.0455456, -0.1352204, 18.2333227>,
    <2.0038727, -0.1352398, 18.1968653>,
    <2.0861681, -0.1352054, 18.1968653>,
    <2.0450204, -0.1352226, 18.1968653>,
    <2.1705857, -0.1351666, 18.2322113>,
    <2.1684634, -0.1351710, 18.1968653>,
    <2.1289022, -0.1351839, 18.2322113>,
    <2.1273157, -0.1351882, 18.1968653>,
    <2.1894619, -0.1351277, 18.2873438>,
    <2.0965801, -0.1351663, 18.2890109>,
    <2.1768884, -0.1351536, 18.2631118>,
    <2.1430133, -0.1351455, 18.2873438>,
    <2.0903496, -0.1351905, 18.2642232>,
    <2.1336139, -0.1351710, 18.2631118>,
    <2.0038718, -0.1352396, 18.3095719>,
    <2.0501774, -0.1351933, 18.2940122>,
    <2.0038721, -0.1352396, 18.2720030>,
    <2.0471057, -0.1352141, 18.2675574>,
    <2.1705733, 0.1125944, 18.2322113>,
    <2.1705795, -0.0112861, 18.2322113>,
    <2.1684511, 0.1125945, 18.1968653>,
    <2.1684573, -0.0112883, 18.1968653>,
    <2.1705610, 0.3603553, 18.2322113>,
    <2.1684387, 0.3603599, 18.1968653>,
    <2.1705672, 0.2364749, 18.2322113>,
    <2.1684449, 0.2364772, 18.1968653>,
    <2.1894375, 0.3603146, 18.2873438>,
    <2.1894497, 0.1125935, 18.2873438>,
    <2.1768638, 0.3603417, 18.2631118>,
    <2.1894436, 0.2364540, 18.2873438>,
    <2.1768761, 0.1125941, 18.2631118>,
    <2.1768700, 0.2364679, 18.2631118>,
    <2.1894558, -0.0112671, 18.2873438>,
    <2.1768823, -0.0112798, 18.2631118>,
    <2.0871924, 0.3603347, 18.2324892>,
    <2.1288754, 0.3603447, 18.2322113>,
    <2.0861391, 0.3603387, 18.1968653>,
    <2.1272889, 0.3603493, 18.1968653>,
    <2.0038391, 0.3603175, 18.2344341>,
    <2.0038394, 0.3603176, 18.1968653>,
    <2.0455144, 0.3603258, 18.2333227>,
    <2.0449892, 0.3603282, 18.1968653>,
    <2.0038384, 0.3603174, 18.3095719>,
    <2.0965512, 0.3602960, 18.2890109>,
    <2.0038387, 0.3603174, 18.2720030>,
    <2.0501463, 0.3602955, 18.2940122>,
    <2.0903206, 0.3603225, 18.2642232>,
    <2.0470746, 0.3603188, 18.2675574>,
    <2.1429867, 0.3603035, 18.2873438>,
    <2.1335871, 0.3603310, 18.2631118>,
    <2.1194133, -0.1350708, 18.3131904>,
    <2.0032176, -0.1351093, 18.3135798>,
    <2.0613154, -0.1350900, 18.3133573>,
    <2.0035447, -0.1351744, 18.3115759>,
    <2.1069400, -0.1351233, 18.3037960>,
    <2.0552372, -0.1351479, 18.3071303>,
    <2.2356097, -0.1350324, 18.3131347>,
    <2.2103965, -0.1350845, 18.3026846>,
    <2.1775114, -0.1350516, 18.3131347>,
    <2.1586631, -0.1351029, 18.3026846>,
    <2.2825423, -0.1349356, 18.3353648>,
    <2.1426356, -0.1349738, 18.3340315>,
    <2.2610191, -0.1349800, 18.3226946>,
    <2.2125963, -0.1349561, 18.3353648>,
    <2.1319840, -0.1350179, 18.3218058>,
    <2.1965064, -0.1349999, 18.3226946>,
    <2.0025635, -0.1349790, 18.3175878>,
    <2.0726458, -0.1349856, 18.3300317>,
    <2.0028906, -0.1350441, 18.3155838>,
    <2.0674422, -0.1350320, 18.3191392>,
    <2.2355977, 0.1125913, 18.3131347>,
    <2.2356037, -0.0112206, 18.3131347>,
    <2.2103844, 0.1125925, 18.3026846>,
    <2.2103904, -0.0112460, 18.3026846>,
    <2.2355857, 0.3602150, 18.3131347>,
    <2.2103722, 0.3602694, 18.3026846>,
    <2.2355917, 0.2364031, 18.3131347>,
    <2.2103783, 0.2364310, 18.3026846>,
    <2.2825188, 0.3601137, 18.3353648>,
    <2.2825305, 0.1125891, 18.3353648>,
    <2.2609953, 0.3601602, 18.3226946>,
    <2.2825246, 0.2363514, 18.3353648>,
    <2.2610072, 0.1125901, 18.3226946>,
    <2.2610013, 0.2363751, 18.3226946>,
    <2.2825364, -0.0111733, 18.3353648>,
    <2.2610131, -0.0111950, 18.3226946>,
    <2.1193847, 0.3601908, 18.3131904>,
    <2.1774851, 0.3602029, 18.3131347>,
    <2.1069112, 0.3602487, 18.3037960>,
    <2.1586366, 0.3602579, 18.3026846>,
    <2.0031844, 0.3601667, 18.3135798>,
    <2.0035114, 0.3602420, 18.3115759>,
    <2.0612845, 0.3601788, 18.3133573>,
    <2.0552062, 0.3602442, 18.3071303>,
    <2.0025303, 0.3600161, 18.3175878>,
    <2.1426072, 0.3600840, 18.3340315>,
    <2.0028573, 0.3600914, 18.3155838>,
    <2.0726150, 0.3600607, 18.3300317>,
    <2.1319555, 0.3601325, 18.3218058>,
    <2.0674113, 0.3601131, 18.3191392>,
    <2.2125703, 0.3601005, 18.3353648>,
    <2.1964803, 0.3601475, 18.3226946>,
    <2.1531110, -0.1349338, 18.3800376>,
    <2.0025322, -0.1349728, 18.3784821>,
    <2.0778228, -0.1349535, 18.3793709>,
    <2.0025479, -0.1349759, 18.3480349>,
    <2.1493516, -0.1349476, 18.3542569>,
    <2.0759546, -0.1349627, 18.3515903>,
    <2.3036751, -0.1348920, 18.3802598>,
    <2.2960969, -0.1349076, 18.3551457>,
    <2.2283943, -0.1349131, 18.3802598>,
    <2.2227291, -0.1349286, 18.3551457>,
    <2.3088707, -0.1348812, 18.4393764>,
    <2.1556858, -0.1349239, 18.4393764>,
    <2.3072690, -0.1348846, 18.4089292>,
    <2.2322783, -0.1349026, 18.4393764>,
    <2.1548928, -0.1349271, 18.4089292>,
    <2.2310809, -0.1349058, 18.4089292>,
    <2.0025009, -0.1349665, 18.4393764>,
    <2.0790934, -0.1349452, 18.4393764>,
    <2.0025166, -0.1349697, 18.4089292>,
    <2.0787047, -0.1349484, 18.4089292>,
    <2.3036635, 0.1125881, 18.3802598>,
    <2.3036693, -0.0111520, 18.3802598>,
    <2.2960852, 0.1125884, 18.3551457>,
    <2.2960911, -0.0111596, 18.3551457>,
    <2.3036518, 0.3600681, 18.3802598>,
    <2.2960735, 0.3600845, 18.3551457>,
    <2.3036576, 0.2363281, 18.3802598>,
    <2.2960794, 0.2363364, 18.3551457>,
    <2.3088475, 0.3600569, 18.4393764>,
    <2.3088591, 0.1125878, 18.4393764>,
    <2.3072457, 0.3600603, 18.4089292>,
    <2.3088533, 0.2363224, 18.4393764>,
    <2.3072574, 0.1125879, 18.4089292>,
    <2.3072515, 0.2363241, 18.4089292>,
    <2.3088649, -0.0111467, 18.4393764>,
    <2.3072632, -0.0111483, 18.4089292>,
    <2.1530827, 0.3600402, 18.3800376>,
    <2.2283685, 0.3600544, 18.3802598>,
    <2.1493233, 0.3600552, 18.3542569>,
    <2.2227033, 0.3600710, 18.3551457>,
    <2.0024990, 0.3600089, 18.3784821>,
    <2.0025147, 0.3600125, 18.3480349>,
    <2.0777921, 0.3600248, 18.3793709>,
    <2.0759238, 0.3600350, 18.3515903>,
    <2.0024677, 0.3600017, 18.4393764>,
    <2.1556576, 0.3600293, 18.4393764>,
    <2.0024834, 0.3600053, 18.4089292>,
    <2.0790627, 0.3600155, 18.4393764>,
    <2.1548645, 0.3600328, 18.4089292>,
    <2.0786740, 0.3600191, 18.4089292>,
    <2.2322525, 0.3600431, 18.4393764>,
    <2.2310551, 0.3600466, 18.4089292>,
    <2.1641424, -0.1348897, 18.4393764>,
    <2.0023340, -0.1349333, 18.4393764>,
    <2.0832382, -0.1349115, 18.4393764>,
    <2.0024175, -0.1349499, 18.4393764>,
    <2.1599141, -0.1349068, 18.4393764>,
    <2.0811658, -0.1349283, 18.4393764>,
    <2.3259508, -0.1348460, 18.4393764>,
    <2.3174108, -0.1348636, 18.4393764>,
    <2.2450466, -0.1348678, 18.4393764>,
    <2.2386625, -0.1348852, 18.4393764>,
    <2.3430309, -0.1348108, 18.4393764>,
    <2.1725990, -0.1348554, 18.4393764>,
    <2.3344909, -0.1348284, 18.4393764>,
    <2.2578150, -0.1348331, 18.4393764>,
    <2.1683707, -0.1348725, 18.4393764>,
    <2.2514308, -0.1348505, 18.4393764>,
    <2.0021672, -0.1349001, 18.4393764>,
    <2.0873831, -0.1348777, 18.4393764>,
    <2.0022506, -0.1349167, 18.4393764>,
    <2.0853107, -0.1348946, 18.4393764>,
    <2.3259393, 0.1125870, 18.4393764>,
    <2.3259450, -0.0111295, 18.4393764>,
    <2.3173992, 0.1125874, 18.4393764>,
    <2.3174050, -0.0111381, 18.4393764>,
    <2.3259277, 0.3600200, 18.4393764>,
    <2.3173876, 0.3600385, 18.4393764>,
    <2.3259335, 0.2363035, 18.4393764>,
    <2.3173934, 0.2363129, 18.4393764>,
    <2.3430079, 0.3599832, 18.4393764>,
    <2.3430194, 0.1125862, 18.4393764>,
    <2.3344678, 0.3600016, 18.4393764>,
    <2.3430137, 0.2362847, 18.4393764>,
    <2.3344793, 0.1125866, 18.4393764>,
    <2.3344736, 0.2362941, 18.4393764>,
    <2.3430251, -0.0111123, 18.4393764>,
    <2.3344851, -0.0111209, 18.4393764>,
    <2.1641143, 0.3599917, 18.4393764>,
    <2.2450210, 0.3600058, 18.4393764>,
    <2.1598859, 0.3600105, 18.4393764>,
    <2.2386368, 0.3600245, 18.4393764>,
    <2.0023009, 0.3599633, 18.4393764>,
    <2.0023843, 0.3599825, 18.4393764>,
    <2.0832076, 0.3599775, 18.4393764>,
    <2.0811351, 0.3599965, 18.4393764>,
    <2.0021340, 0.3599249, 18.4393764>,
    <2.1725710, 0.3599540, 18.4393764>,
    <2.0022174, 0.3599441, 18.4393764>,
    <2.0873525, 0.3599394, 18.4393764>,
    <2.1683426, 0.3599728, 18.4393764>,
    <2.0852800, 0.3599585, 18.4393764>,
    <2.2577895, 0.3599686, 18.4393764>,
    <2.2514052, 0.3599872, 18.4393764>,
    <2.1725990, -0.1348554, 18.4905874>,
    <2.0021672, -0.1349001, 18.4905874>,
    <2.0873831, -0.1348777, 18.4905874>,
    <2.0021672, -0.1349001, 18.4649819>,
    <2.1725990, -0.1348554, 18.4649819>,
    <2.0873831, -0.1348777, 18.4649819>,
    <2.3430309, -0.1348108, 18.4905874>,
    <2.3430309, -0.1348108, 18.4649819>,
    <2.2578150, -0.1348331, 18.4905874>,
    <2.2578150, -0.1348331, 18.4649819>,
    <2.3430309, -0.1348108, 18.5161929>,
    <2.1725990, -0.1348554, 18.5161929>,
    <2.2578150, -0.1348331, 18.5161929>,
    <2.0021672, -0.1349001, 18.5161929>,
    <2.0873831, -0.1348777, 18.5161929>,
    <2.3430194, 0.1125862, 18.4905874>,
    <2.3430251, -0.0111123, 18.4905874>,
    <2.3430194, 0.1125862, 18.4649819>,
    <2.3430251, -0.0111123, 18.4649819>,
    <2.3430079, 0.3599832, 18.4905874>,
    <2.3430079, 0.3599832, 18.4649819>,
    <2.3430137, 0.2362847, 18.4905874>,
    <2.3430137, 0.2362847, 18.4649819>,
    <2.3430079, 0.3599832, 18.5161929>,
    <2.3430194, 0.1125862, 18.5161929>,
    <2.3430137, 0.2362847, 18.5161929>,
    <2.3430251, -0.0111123, 18.5161929>,
    <2.1725710, 0.3599540, 18.4905874>,
    <2.2577895, 0.3599686, 18.4905874>,
    <2.1725710, 0.3599540, 18.4649819>,
    <2.2577895, 0.3599686, 18.4649819>,
    <2.0021340, 0.3599249, 18.4905874>,
    <2.0021340, 0.3599249, 18.4649819>,
    <2.0873525, 0.3599394, 18.4905874>,
    <2.0873525, 0.3599394, 18.4649819>,
    <2.0021340, 0.3599249, 18.5161929>,
    <2.1725710, 0.3599540, 18.5161929>,
    <2.0873525, 0.3599394, 18.5161929>,
    <2.2577895, 0.3599686, 18.5161929>,
    <2.0021506, 0.1125124, 18.4905874>,
    <2.0021672, -0.1349001, 18.4905874>,
    <2.0021506, 0.1125124, 18.4393764>,
    <2.0021589, -0.0111938, 18.4905874>,
    <2.0021672, -0.1349001, 18.4649819>,
    <2.0021589, -0.0111938, 18.4393764>,
    <2.0021506, 0.1125124, 18.4649819>,
    <2.0021589, -0.0111938, 18.4649819>,
    <2.0021340, 0.3599249, 18.4905874>,
    <2.0021423, 0.2362186, 18.4393764>,
    <2.0021340, 0.3599249, 18.4649819>,
    <2.0021423, 0.2362186, 18.4905874>,
    <2.0021423, 0.2362186, 18.4649819>,
    <2.0021506, 0.1125124, 18.5417983>,
    <2.0021340, 0.3599249, 18.5161929>,
    <2.0021423, 0.2362186, 18.5417983>,
    <2.0021506, 0.1125124, 18.5161929>,
    <2.0021423, 0.2362186, 18.5161929>,
    <2.0021589, -0.0111938, 18.5417983>,
    <2.0021672, -0.1349001, 18.5161929>,
    <2.0021589, -0.0111938, 18.5161929>,
    <2.0023174, 0.1125150, 18.4393764>,
    <2.0024843, 0.1125176, 18.4393764>,
    <2.0024009, 0.1125163, 18.4393764>,
    <2.0024926, -0.0112245, 18.4393764>,
    <2.0023257, -0.0112092, 18.4393764>,
    <2.0024092, -0.0112168, 18.4393764>,
    <2.0021506, 0.1125124, 18.4393764>,
    <2.0021589, -0.0111938, 18.4393764>,
    <2.0022340, 0.1125137, 18.4393764>,
    <2.0022423, -0.0112015, 18.4393764>,
    <2.0021423, 0.2362186, 18.4393764>,
    <2.0023092, 0.2362391, 18.4393764>,
    <2.0022257, 0.2362289, 18.4393764>,
    <2.0024760, 0.2362597, 18.4393764>,
    <2.0023926, 0.2362494, 18.4393764>,
    <2.0025156, 0.1125181, 18.3784821>,
    <2.0025322, -0.1349728, 18.3784821>,
    <2.0025469, 0.1125186, 18.3175878>,
    <2.0025239, -0.0112274, 18.3784821>,
    <2.0025479, -0.1349759, 18.3480349>,
    <2.0025552, -0.0112302, 18.3175878>,
    <2.0025313, 0.1125183, 18.3480349>,
    <2.0025396, -0.0112288, 18.3480349>,
    <2.0024990, 0.3600089, 18.3784821>,
    <2.0025386, 0.2362673, 18.3175878>,
    <2.0025147, 0.3600125, 18.3480349>,
    <2.0025073, 0.2362635, 18.3784821>,
    <2.0025230, 0.2362654, 18.3480349>,
    <2.0024843, 0.1125176, 18.4393764>,
    <2.0024834, 0.3600053, 18.4089292>,
    <2.0024760, 0.2362597, 18.4393764>,
    <2.0025000, 0.1125178, 18.4089292>,
    <2.0024917, 0.2362616, 18.4089292>,
    <2.0024926, -0.0112245, 18.4393764>,
    <2.0025166, -0.1349697, 18.4089292>,
    <2.0025083, -0.0112259, 18.4089292>,
    <2.0032010, 0.1125287, 18.3135798>,
    <2.0038551, 0.1125389, 18.3095719>,
    <2.0035281, 0.1125338, 18.3115759>,
    <2.0038634, -0.0113503, 18.3095719>,
    <2.0032093, -0.0112903, 18.3135798>,
    <2.0035364, -0.0113203, 18.3115759>,
    <2.0025469, 0.1125186, 18.3175878>,
    <2.0025552, -0.0112302, 18.3175878>,
    <2.0028740, 0.1125236, 18.3155838>,
    <2.0028823, -0.0112603, 18.3155838>,
    <2.0025386, 0.2362673, 18.3175878>,
    <2.0031927, 0.2363477, 18.3135798>,
    <2.0028656, 0.2363075, 18.3155838>,
    <2.0038468, 0.2364281, 18.3095719>,
    <2.0035197, 0.2363879, 18.3115759>,
    <2.0038557, 0.1125389, 18.2344341>,
    <2.0038724, -0.1352397, 18.2344341>,
    <2.0038563, 0.1125389, 18.1592964>,
    <2.0038641, -0.0113504, 18.2344341>,
    <2.0038727, -0.1352398, 18.1968653>,
    <2.0038647, -0.0113505, 18.1592964>,
    <2.0038560, 0.1125389, 18.1968653>,
    <2.0038644, -0.0113504, 18.1968653>,
    <2.0038391, 0.3603175, 18.2344341>,
    <2.0038480, 0.2364283, 18.1592964>,
    <2.0038394, 0.3603176, 18.1968653>,
    <2.0038474, 0.2364282, 18.2344341>,
    <2.0038477, 0.2364282, 18.1968653>,
    <2.0038551, 0.1125389, 18.3095719>,
    <2.0038387, 0.3603174, 18.2720030>,
    <2.0038468, 0.2364281, 18.3095719>,
    <2.0038554, 0.1125389, 18.2720030>,
    <2.0038471, 0.2364282, 18.2720030>,
    <2.0038634, -0.0113503, 18.3095719>,
    <2.0038721, -0.1352396, 18.2720030>,
    <2.0038637, -0.0113504, 18.2720030>,
    <2.0039528, 0.1125404, 18.1573801>,
    <2.0040493, 0.1125419, 18.1554639>,
    <2.0040010, 0.1125412, 18.1564220>,
    <2.0040576, -0.0113682, 18.1554639>,
    <2.0039611, -0.0113593, 18.1573801>,
    <2.0040094, -0.0113637, 18.1564220>,
    <2.0038563, 0.1125389, 18.1592964>,
    <2.0038647, -0.0113505, 18.1592964>,
    <2.0039046, 0.1125397, 18.1583383>,
    <2.0039129, -0.0113549, 18.1583383>,
    <2.0038480, 0.2364283, 18.1592964>,
    <2.0039445, 0.2364401, 18.1573801>,
    <2.0038962, 0.2364342, 18.1583383>,
    <2.0040409, 0.2364520, 18.1554639>,
    <2.0039927, 0.2364461, 18.1564220>,
    <2.0042444, 0.1125449, 18.1389725>,
    <2.0042673, -0.1353183, 18.1386133>,
    <2.0043812, 0.1125471, 18.1258340>,
    <2.0042548, -0.0113867, 18.1388528>,
    <2.0043680, -0.1353384, 18.1301880>,
    <2.0044020, -0.0114025, 18.1251156>,
    <2.0043263, 0.1125462, 18.1316249>,
    <2.0043430, -0.0113962, 18.1311460>,
    <2.0042339, 0.3604084, 18.1386133>,
    <2.0043853, 0.2364970, 18.1251156>,
    <2.0043346, 0.3604316, 18.1301880>,
    <2.0042381, 0.2364767, 18.1388528>,
    <2.0043263, 0.2364889, 18.1311460>,
    <2.0040493, 0.1125419, 18.1554639>,
    <2.0041333, 0.3603852, 18.1470386>,
    <2.0040409, 0.2364520, 18.1554639>,
    <2.0041499, 0.1125435, 18.1470386>,
    <2.0041416, 0.2364644, 18.1470386>,
    <2.0040576, -0.0113682, 18.1554639>,
    <2.0041666, -0.1352983, 18.1470386>,
    <2.0041583, -0.0113774, 18.1470386>,
    <2.0043805, 0.1125471, 18.1205987>,
    <2.0043944, 0.1125473, 18.1224380>,
    <2.0043909, -0.0113992, 18.1204790>,
    <2.0044111, -0.0114024, 18.1219591>,
    <2.0043215, 0.1125461, 18.1187163>,
    <2.0043298, -0.0113932, 18.1187163>,
    <2.0043541, 0.1125467, 18.1194779>,
    <2.0043625, -0.0113962, 18.1194779>,
    <2.0043131, 0.2364854, 18.1187163>,
    <2.0043742, 0.2364934, 18.1204790>,
    <2.0043458, 0.2364895, 18.1194779>,
    <2.0043944, 0.2364972, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0005827, 0.9999675, 0.0080437>,
    <-0.0005827, 0.9999715, 0.0075276>,
    <-0.0005683, 0.9999713, 0.0075588>,
    <-0.0005683, 0.9999674, 0.0080589>,
    <-0.0005683, 0.9999632, 0.0085591>,
    <-0.0005827, 0.9999632, 0.0085598>,
    <-0.0005827, 0.9999632, 0.0085598>,
    <-0.0005979, 0.9999632, 0.0085604>,
    <-0.0005979, 0.9999676, 0.0080275>,
    <-0.0005979, 0.9999676, 0.0080275>,
    <-0.0005979, 0.9999717, 0.0074945>,
    <-0.0005827, 0.9999752, 0.0070116>,
    <-0.0005683, 0.9999749, 0.0070586>,
    <-0.0005979, 0.9999717, 0.0074945>,
    <-0.0005979, 0.9999756, 0.0069615>,
    <-0.0005979, 0.9999756, 0.0069615>,
    <-0.0005979, 0.9999792, 0.0064286>,
    <-0.0005827, 0.9999787, 0.0064955>,
    <-0.0005827, 0.9999787, 0.0064955>,
    <-0.0005683, 0.9999783, 0.0065584>,
    <-0.0005549, 0.9999746, 0.0071027>,
    <-0.0005549, 0.9999711, 0.0075880>,
    <-0.0005683, 0.9999783, 0.0065584>,
    <-0.0005549, 0.9999780, 0.0066174>,
    <-0.0005549, 0.9999780, 0.0066174>,
    <-0.0005422, 0.9999776, 0.0066731>,
    <-0.0005422, 0.9999743, 0.0071443>,
    <-0.0005422, 0.9999743, 0.0071443>,
    <-0.0005422, 0.9999709, 0.0076156>,
    <-0.0005549, 0.9999673, 0.0080733>,
    <-0.0005422, 0.9999709, 0.0076156>,
    <-0.0005422, 0.9999672, 0.0080868>,
    <-0.0005422, 0.9999672, 0.0080868>,
    <-0.0005422, 0.9999632, 0.0085580>,
    <-0.0005549, 0.9999632, 0.0085586>,
    <-0.0005549, 0.9999632, 0.0085586>,
    <-0.0005683, 0.9999632, 0.0085591>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222780, -0.0000113, -0.9749833>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222785, -0.0000113, -0.9749832>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222790, -0.0000113, -0.9749831>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222796, -0.0000113, -0.9749830>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <-0.2222801, -0.0000113, -0.9749829>,
    <0.0003486, -0.9999426, 0.0107096>,
    <0.0003486, -0.9999456, 0.0104237>,
    <0.0003407, -0.9999458, 0.0104065>,
    <0.0003407, -0.9999429, 0.0106836>,
    <0.0003407, -0.9999399, 0.0109607>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003486, -0.9999395, 0.0109955>,
    <0.0003571, -0.9999391, 0.0110326>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999423, 0.0107373>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003486, -0.9999486, 0.0101378>,
    <0.0003407, -0.9999486, 0.0101293>,
    <0.0003571, -0.9999454, 0.0104421>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999485, 0.0101468>,
    <0.0003571, -0.9999514, 0.0098515>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003486, -0.9999514, 0.0098519>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999487, 0.0101214>,
    <0.0003332, -0.9999460, 0.0103903>,
    <0.0003407, -0.9999514, 0.0098522>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003332, -0.9999514, 0.0098525>,
    <0.0003262, -0.9999514, 0.0098528>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999488, 0.0101139>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003332, -0.9999431, 0.0106591>,
    <0.0003262, -0.9999461, 0.0103750>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999434, 0.0106361>,
    <0.0003262, -0.9999406, 0.0108971>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003332, -0.9999402, 0.0109280>,
    <0.0003407, -0.9999399, 0.0109607>,
    <0.0005180, -0.9999989, 0.0014025>,
    <0.0005180, -0.9999990, 0.0013256>,
    <0.0004963, -0.9999990, 0.0013338>,
    <0.0004963, -0.9999989, 0.0014064>,
    <0.0004963, -0.9999988, 0.0014791>,
    <0.0005180, -0.9999988, 0.0014793>,
    <0.0005180, -0.9999988, 0.0014793>,
    <0.0005422, -0.9999988, 0.0014795>,
    <0.0005422, -0.9999989, 0.0013980>,
    <0.0005422, -0.9999989, 0.0013980>,
    <0.0005422, -0.9999990, 0.0013165>,
    <0.0005180, -0.9999991, 0.0012488>,
    <0.0004963, -0.9999991, 0.0012611>,
    <0.0005422, -0.9999990, 0.0013165>,
    <0.0005422, -0.9999991, 0.0012351>,
    <0.0005422, -0.9999991, 0.0012351>,
    <0.0005422, -0.9999992, 0.0011536>,
    <0.0005180, -0.9999992, 0.0011720>,
    <0.0005180, -0.9999992, 0.0011720>,
    <0.0004963, -0.9999992, 0.0011884>,
    <0.0004769, -0.9999991, 0.0012721>,
    <0.0004769, -0.9999990, 0.0013410>,
    <0.0004963, -0.9999992, 0.0011884>,
    <0.0004769, -0.9999992, 0.0012031>,
    <0.0004769, -0.9999992, 0.0012031>,
    <0.0004594, -0.9999992, 0.0012164>,
    <0.0004594, -0.9999991, 0.0012820>,
    <0.0004594, -0.9999991, 0.0012820>,
    <0.0004594, -0.9999990, 0.0013476>,
    <0.0004769, -0.9999989, 0.0014100>,
    <0.0004594, -0.9999990, 0.0013476>,
    <0.0004594, -0.9999989, 0.0014132>,
    <0.0004594, -0.9999989, 0.0014132>,
    <0.0004594, -0.9999988, 0.0014789>,
    <0.0004769, -0.9999988, 0.0014790>,
    <0.0004769, -0.9999988, 0.0014790>,
    <0.0004963, -0.9999988, 0.0014791>,
    <0.7968310, 0.0000404, -0.6042023>,
    <0.7968303, 0.0000404, -0.6042032>,
    <0.7968303, 0.0000402, -0.6042032>,
    <0.7968310, 0.0000402, -0.6042023>,
    <0.7968317, 0.0000402, -0.6042013>,
    <0.7968317, 0.0000404, -0.6042013>,
    <0.7968317, 0.0000404, -0.6042013>,
    <0.7968317, 0.0000405, -0.6042013>,
    <0.7968310, 0.0000405, -0.6042023>,
    <0.7968310, 0.0000405, -0.6042023>,
    <0.7968303, 0.0000405, -0.6042032>,
    <0.7968295, 0.0000404, -0.6042042>,
    <0.7968295, 0.0000402, -0.6042042>,
    <0.7968303, 0.0000405, -0.6042032>,
    <0.7968295, 0.0000405, -0.6042042>,
    <0.7968295, 0.0000405, -0.6042042>,
    <0.7968288, 0.0000405, -0.6042051>,
    <0.7968288, 0.0000404, -0.6042051>,
    <0.7968288, 0.0000404, -0.6042051>,
    <0.7968288, 0.0000402, -0.6042051>,
    <0.7968295, 0.0000401, -0.6042042>,
    <0.7968303, 0.0000401, -0.6042032>,
    <0.7968288, 0.0000402, -0.6042051>,
    <0.7968288, 0.0000401, -0.6042051>,
    <0.7968288, 0.0000401, -0.6042051>,
    <0.7968288, 0.0000400, -0.6042051>,
    <0.7968295, 0.0000400, -0.6042042>,
    <0.7968295, 0.0000400, -0.6042042>,
    <0.7968303, 0.0000400, -0.6042032>,
    <0.7968310, 0.0000401, -0.6042023>,
    <0.7968303, 0.0000400, -0.6042032>,
    <0.7968310, 0.0000400, -0.6042023>,
    <0.7968310, 0.0000400, -0.6042023>,
    <0.7968317, 0.0000400, -0.6042013>,
    <0.7968317, 0.0000401, -0.6042013>,
    <0.7968317, 0.0000401, -0.6042013>,
    <0.7968317, 0.0000402, -0.6042013>,
    <-0.0003128, 0.9999983, 0.0018311>,
    <-0.0003128, 0.9999984, 0.0017886>,
    <-0.0003008, 0.9999984, 0.0017841>,
    <-0.0003008, 0.9999983, 0.0018243>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003128, 0.9999982, 0.0018737>,
    <-0.0003262, 0.9999982, 0.0018839>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0018388>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003128, 0.9999984, 0.0017460>,
    <-0.0003008, 0.9999984, 0.0017438>,
    <-0.0003262, 0.9999983, 0.0017936>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999984, 0.0017485>,
    <-0.0003262, 0.9999985, 0.0017033>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003128, 0.9999985, 0.0017034>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999984, 0.0017418>,
    <-0.0002901, 0.9999984, 0.0017800>,
    <-0.0003008, 0.9999985, 0.0017035>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002901, 0.9999985, 0.0017036>,
    <-0.0002803, 0.9999985, 0.0017037>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017400>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002901, 0.9999983, 0.0018183>,
    <-0.0002803, 0.9999984, 0.0017764>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018127>,
    <-0.0002803, 0.9999983, 0.0018491>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0002901, 0.9999982, 0.0018565>,
    <-0.0003008, 0.9999982, 0.0018646>,
    <0.0004480, -0.9999537, 0.0096163>,
    <0.0004480, -0.9999577, 0.0091854>,
    <0.0004373, -0.9999575, 0.0092127>,
    <0.0004373, -0.9999535, 0.0096297>,
    <0.0004373, -0.9999494, 0.0100467>,
    <0.0004479, -0.9999494, 0.0100473>,
    <0.0004479, -0.9999494, 0.0100473>,
    <0.0004594, -0.9999494, 0.0100479>,
    <0.0004594, -0.9999538, 0.0096021>,
    <0.0004594, -0.9999538, 0.0096021>,
    <0.0004594, -0.9999580, 0.0091563>,
    <0.0004480, -0.9999616, 0.0087545>,
    <0.0004373, -0.9999612, 0.0087956>,
    <0.0004594, -0.9999580, 0.0091563>,
    <0.0004594, -0.9999620, 0.0087105>,
    <0.0004594, -0.9999620, 0.0087105>,
    <0.0004594, -0.9999657, 0.0082647>,
    <0.0004480, -0.9999653, 0.0083235>,
    <0.0004480, -0.9999653, 0.0083235>,
    <0.0004373, -0.9999648, 0.0083786>,
    <0.0004273, -0.9999609, 0.0088342>,
    <0.0004273, -0.9999572, 0.0092382>,
    <0.0004373, -0.9999648, 0.0083786>,
    <0.0004273, -0.9999644, 0.0084302>,
    <0.0004273, -0.9999644, 0.0084302>,
    <0.0004178, -0.9999640, 0.0084786>,
    <0.0004178, -0.9999606, 0.0088704>,
    <0.0004178, -0.9999606, 0.0088704>,
    <0.0004178, -0.9999570, 0.0092622>,
    <0.0004272, -0.9999534, 0.0096422>,
    <0.0004178, -0.9999570, 0.0092622>,
    <0.0004178, -0.9999533, 0.0096540>,
    <0.0004178, -0.9999533, 0.0096540>,
    <0.0004178, -0.9999495, 0.0100458>,
    <0.0004272, -0.9999494, 0.0100462>,
    <0.0004272, -0.9999494, 0.0100462>,
    <0.0004373, -0.9999494, 0.0100467>,
    <0.1905399, 0.0000096, -0.9816795>,
    <0.1905394, 0.0000096, -0.9816795>,
    <0.1905394, 0.0000095, -0.9816795>,
    <0.1905399, 0.0000095, -0.9816795>,
    <0.1905403, 0.0000095, -0.9816794>,
    <0.1905403, 0.0000096, -0.9816794>,
    <0.1905403, 0.0000096, -0.9816794>,
    <0.1905403, 0.0000096, -0.9816794>,
    <0.1905399, 0.0000096, -0.9816795>,
    <0.1905399, 0.0000096, -0.9816795>,
    <0.1905394, 0.0000096, -0.9816795>,
    <0.1905390, 0.0000096, -0.9816796>,
    <0.1905390, 0.0000095, -0.9816796>,
    <0.1905394, 0.0000096, -0.9816795>,
    <0.1905390, 0.0000096, -0.9816796>,
    <0.1905390, 0.0000096, -0.9816796>,
    <0.1905385, 0.0000096, -0.9816797>,
    <0.1905385, 0.0000096, -0.9816797>,
    <0.1905385, 0.0000096, -0.9816797>,
    <0.1905385, 0.0000095, -0.9816797>,
    <0.1905390, 0.0000095, -0.9816796>,
    <0.1905394, 0.0000095, -0.9816795>,
    <0.1905385, 0.0000095, -0.9816797>,
    <0.1905385, 0.0000095, -0.9816797>,
    <0.1905385, 0.0000095, -0.9816797>,
    <0.1905385, 0.0000095, -0.9816797>,
    <0.1905390, 0.0000095, -0.9816796>,
    <0.1905390, 0.0000095, -0.9816796>,
    <0.1905394, 0.0000095, -0.9816795>,
    <0.1905399, 0.0000095, -0.9816795>,
    <0.1905394, 0.0000095, -0.9816795>,
    <0.1905399, 0.0000095, -0.9816795>,
    <0.1905399, 0.0000095, -0.9816795>,
    <0.1905403, 0.0000095, -0.9816794>,
    <0.1905403, 0.0000095, -0.9816794>,
    <0.1905403, 0.0000095, -0.9816794>,
    <0.1905403, 0.0000095, -0.9816794>,
    <-0.0002740, 0.9999244, 0.0122917>,
    <-0.0002740, 0.9999273, 0.0120530>,
    <-0.0002681, 0.9999275, 0.0120379>,
    <-0.0002681, 0.9999247, 0.0122689>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002740, 0.9999215, 0.0125305>,
    <-0.0002803, 0.9999210, 0.0125631>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999241, 0.0123161>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002740, 0.9999302, 0.0118142>,
    <-0.0002681, 0.9999303, 0.0118068>,
    <-0.0002803, 0.9999271, 0.0120691>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999301, 0.0118221>,
    <-0.0002803, 0.9999330, 0.0115751>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002740, 0.9999330, 0.0115755>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999303, 0.0117999>,
    <-0.0002625, 0.9999277, 0.0120237>,
    <-0.0002681, 0.9999330, 0.0115758>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002625, 0.9999330, 0.0115760>,
    <-0.0002573, 0.9999330, 0.0115763>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999304, 0.0117934>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002625, 0.9999250, 0.0122476>,
    <-0.0002573, 0.9999278, 0.0120104>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999252, 0.0122275>,
    <-0.0002573, 0.9999225, 0.0124445>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002625, 0.9999222, 0.0124714>,
    <-0.0002681, 0.9999218, 0.0125000>,
    <0.0004245, -0.9999999, 0.0000258>,
    <0.0004214, -0.9999999, 0.0000435>,
    <0.0004484, -0.9999999, 0.0001816>,
    <0.0004726, -0.9999999, 0.0001013>,
    <0.0004777, -0.9999999, 0.0000017>,
    <0.0004254, -0.9999999, 0.0000017>,
    <0.0004254, -0.9999999, 0.0000017>,
    <0.0004179, -0.9999999, 0.0000017>,
    <0.0004179, -0.9999999, 0.0000016>,
    <0.0004179, -0.9999999, 0.0000016>,
    <0.0004179, -0.9999999, 0.0000015>,
    <0.0004182, -0.9999999, 0.0000497>,
    <0.0004217, -0.9999999, 0.0002129>,
    <0.0004179, -0.9999999, 0.0000015>,
    <0.0004179, -0.9999999, 0.0000015>,
    <0.0004179, -0.9999999, 0.0000015>,
    <0.0004179, -0.9999999, 0.0000014>,
    <0.0004172, -0.9999999, 0.0000486>,
    <0.0004172, -0.9999999, 0.0000486>,
    <0.0004127, -0.9999999, 0.0002100>,
    <0.0004307, -0.9999997, 0.0005761>,
    <0.0005164, -0.9999997, 0.0005197>,
    <0.0004127, -0.9999999, 0.0002100>,
    <0.0004013, -0.9999998, 0.0005691>,
    <0.0004013, -0.9999998, 0.0005691>,
    <0.0003814, -0.9999989, 0.0014244>,
    <0.0004334, -0.9999989, 0.0014481>,
    <0.0005895, -0.9999988, 0.0014504>,
    <0.0006243, -0.9999997, 0.0003378>,
    <0.0009586, -0.9999985, 0.0014756>,
    <0.0012679, -0.9999978, 0.0016581>,
    <0.0006436, -0.9999998, 0.0000017>,
    <0.0006436, -0.9999998, 0.0000017>,
    <0.0004777, -0.9999999, 0.0000017>,
    <0.9995639, 0.0000498, -0.0295315>,
    <0.9995638, 0.0000498, -0.0295315>,
    <0.9920098, 0.0000494, -0.1261608>,
    <0.9920098, 0.0000494, -0.1261605>,
    <0.9920099, 0.0000494, -0.1261602>,
    <0.9995639, 0.0000498, -0.0295314>,
    <0.9995639, 0.0000498, -0.0295314>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9995638, 0.0000498, -0.0295316>,
    <0.9920098, 0.0000494, -0.1261611>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9999996, 0.0000498, -0.0008513>,
    <0.9995638, 0.0000498, -0.0295317>,
    <0.9995638, 0.0000498, -0.0295317>,
    <0.9920097, 0.0000494, -0.1261614>,
    <0.9460835, 0.0000470, -0.3239228>,
    <0.9460838, 0.0000470, -0.3239221>,
    <0.9920097, 0.0000494, -0.1261614>,
    <0.9460833, 0.0000470, -0.3239235>,
    <0.9460833, 0.0000470, -0.3239235>,
    <0.7631609, 0.0000377, -0.6462085>,
    <0.7631617, 0.0000377, -0.6462076>,
    <0.7631625, 0.0000377, -0.6462067>,
    <0.9460840, 0.0000470, -0.3239213>,
    <0.7631632, 0.0000377, -0.6462057>,
    <0.7631640, 0.0000377, -0.6462048>,
    <0.9460843, 0.0000470, -0.3239206>,
    <0.9460843, 0.0000470, -0.3239206>,
    <0.9920099, 0.0000494, -0.1261602>,
    <-0.0002557, 1.0000000, 0.0000687>,
    <-0.0002521, 1.0000000, 0.0000578>,
    <-0.0002128, 0.9999999, 0.0002410>,
    <-0.0002438, 0.9999999, 0.0002938>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002569, 1.0000000, 0.0000714>,
    <-0.0002573, 1.0000000, 0.0000021>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002485, 1.0000000, 0.0000335>,
    <-0.0001849, 1.0000000, 0.0001319>,
    <-0.0002573, 1.0000000, 0.0000020>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002573, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0002474, 1.0000000, 0.0000019>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000127, 0.9999999, 0.0004262>,
    <-0.0001114, 0.9999998, 0.0006796>,
    <-0.0001796, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0000311, 1.0000000, 0.0000019>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0004444, 0.9999983, 0.0017942>,
    <0.0000146, 0.9999983, 0.0018600>,
    <-0.0002126, 0.9999997, 0.0007890>,
    <-0.0001727, 0.9999981, 0.0019562>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002481, 0.9999996, 0.0008239>,
    <-0.0002545, 0.9999999, 0.0003068>,
    <0.0009631, -0.9999847, 0.0054429>,
    <0.0005675, -0.9999936, 0.0035357>,
    <0.0003454, -0.9999839, 0.0056582>,
    <0.0003746, -0.9999539, 0.0095899>,
    <0.0004982, -0.9994694, 0.0325694>,
    <0.0041287, -0.9994415, 0.0331611>,
    <0.0041287, -0.9994415, 0.0331611>,
    <0.0012679, -0.9999978, 0.0016581>,
    <0.0004046, -0.9999950, 0.0031510>,
    <0.0003331, -0.9999892, 0.0046263>,
    <0.0003814, -0.9999989, 0.0014244>,
    <0.0003553, -0.9999953, 0.0030566>,
    <0.0003553, -0.9999953, 0.0030566>,
    <0.0003299, -0.9999903, 0.0043860>,
    <0.0002708, -0.9999922, 0.0039301>,
    <0.0001376, -0.9999892, 0.0046520>,
    <0.0003299, -0.9999903, 0.0043860>,
    <0.0003092, -0.9999931, 0.0037039>,
    <0.0003092, -0.9999931, 0.0037039>,
    <0.0002946, -0.9999981, 0.0019121>,
    <0.0002591, -0.9999980, 0.0019894>,
    <0.0001493, -0.9999978, 0.0020871>,
    <-0.0001882, -0.9999742, 0.0071852>,
    <-0.0001121, -0.9999977, 0.0021646>,
    <-0.0002880, -0.9999978, 0.0021003>,
    <-0.0020420, -0.9994808, 0.0321552>,
    <-0.0020420, -0.9994808, 0.0321552>,
    <0.0004982, -0.9994694, 0.0325694>,
    <0.4878559, 0.0000239, -0.8729242>,
    <0.4878549, 0.0000239, -0.8729247>,
    <0.3675999, 0.0000178, -0.9299841>,
    <0.3676006, 0.0000178, -0.9299837>,
    <0.3676014, 0.0000178, -0.9299834>,
    <0.4878568, 0.0000239, -0.8729237>,
    <0.4878568, 0.0000239, -0.8729237>,
    <0.7631640, 0.0000377, -0.6462048>,
    <0.4878540, 0.0000239, -0.8729252>,
    <0.3675991, 0.0000178, -0.9299844>,
    <0.7631609, 0.0000377, -0.6462085>,
    <0.4878531, 0.0000239, -0.8729257>,
    <0.4878531, 0.0000239, -0.8729257>,
    <0.3675983, 0.0000178, -0.9299847>,
    <0.4280648, 0.0000206, -0.9037480>,
    <0.4280657, 0.0000206, -0.9037476>,
    <0.3675983, 0.0000178, -0.9299847>,
    <0.4280639, 0.0000206, -0.9037484>,
    <0.4280639, 0.0000206, -0.9037484>,
    <0.6790848, 0.0000323, -0.7340599>,
    <0.6790857, 0.0000323, -0.7340590>,
    <0.6790866, 0.0000323, -0.7340582>,
    <0.4280665, 0.0000206, -0.9037472>,
    <0.6790875, 0.0000323, -0.7340574>,
    <0.6790884, 0.0000323, -0.7340565>,
    <0.4280674, 0.0000206, -0.9037468>,
    <0.4280674, 0.0000206, -0.9037468>,
    <0.3676014, 0.0000178, -0.9299834>,
    <-0.0001605, 0.9999912, 0.0041835>,
    <0.0000373, 0.9999900, 0.0044632>,
    <-0.0001893, 0.9999751, 0.0070592>,
    <-0.0002044, 0.9999817, 0.0060433>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002227, 0.9999909, 0.0042603>,
    <-0.0002371, 0.9999979, 0.0020283>,
    <0.0004994, 0.9999785, 0.0065314>,
    <-0.0001552, 0.9999344, 0.0114548>,
    <0.0007846, 0.9999979, 0.0019113>,
    <0.0041270, 0.9992606, 0.0382247>,
    <0.0041270, 0.9992606, 0.0382247>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0007848, 0.9999631, 0.0085524>,
    <-0.0004049, 0.9999833, 0.0057588>,
    <-0.0000142, 0.9992947, 0.0375502>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0029078, 0.9993081, 0.0370785>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0006662, 0.9999964, 0.0025817>,
    <-0.0003625, 0.9999966, 0.0025763>,
    <-0.0002448, 0.9999871, 0.0050692>,
    <-0.0002322, 0.9999967, 0.0025453>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0001971, 0.9999876, 0.0049728>,
    <-0.0002086, 0.9999821, 0.0059878>,
    <0.0001522, -0.9999998, 0.0005576>,
    <0.0002167, -0.9999997, 0.0007949>,
    <0.0002617, -0.9999999, 0.0003340>,
    <0.0002483, -0.9999999, 0.0002315>,
    <0.0002455, -1.0000000, 0.0001025>,
    <0.0001426, -1.0000000, 0.0001024>,
    <0.0001426, -1.0000000, 0.0001024>,
    <-0.0002880, -0.9999978, 0.0021003>,
    <0.0002684, -0.9999996, 0.0008505>,
    <0.0002766, -0.9999999, 0.0003726>,
    <0.0002946, -0.9999981, 0.0019121>,
    <0.0002861, -0.9999996, 0.0008367>,
    <0.0002861, -0.9999996, 0.0008367>,
    <0.0002816, -0.9999999, 0.0003702>,
    <0.0002789, -0.9999999, 0.0001590>,
    <0.0002772, -0.9999999, 0.0001524>,
    <0.0002816, -0.9999999, 0.0003702>,
    <0.0002794, -0.9999999, 0.0001568>,
    <0.0002794, -0.9999999, 0.0001568>,
    <0.0002784, -1.0000000, 0.0000939>,
    <0.0002784, -1.0000000, 0.0000961>,
    <0.0002784, -1.0000000, 0.0000961>,
    <0.0002784, -1.0000000, 0.0000982>,
    <0.0002755, -1.0000000, 0.0001315>,
    <0.0002784, -1.0000000, 0.0000982>,
    <0.0002784, -1.0000000, 0.0001004>,
    <0.0002784, -1.0000000, 0.0001004>,
    <0.0002784, -1.0000000, 0.0001025>,
    <0.0002750, -1.0000000, 0.0001025>,
    <0.0002750, -1.0000000, 0.0001025>,
    <0.0002455, -1.0000000, 0.0001025>,
    <0.9047737, 0.0000428, -0.4258927>,
    <0.9047733, 0.0000428, -0.4258936>,
    <0.9790994, 0.0000462, -0.2033825>,
    <0.9790995, 0.0000462, -0.2033820>,
    <0.9790996, 0.0000462, -0.2033815>,
    <0.9047741, 0.0000428, -0.4258919>,
    <0.9047741, 0.0000428, -0.4258919>,
    <0.6790884, 0.0000323, -0.7340565>,
    <0.9047729, 0.0000428, -0.4258945>,
    <0.9790993, 0.0000462, -0.2033830>,
    <0.6790848, 0.0000323, -0.7340599>,
    <0.9047724, 0.0000428, -0.4258953>,
    <0.9047724, 0.0000428, -0.4258953>,
    <0.9790992, 0.0000462, -0.2033835>,
    <0.9961600, 0.0000469, -0.0875510>,
    <0.9961601, 0.0000469, -0.0875508>,
    <0.9790992, 0.0000462, -0.2033835>,
    <0.9961600, 0.0000469, -0.0875512>,
    <0.9961600, 0.0000469, -0.0875512>,
    <0.9986191, 0.0000470, -0.0525351>,
    <0.9986191, 0.0000470, -0.0525350>,
    <0.9986191, 0.0000470, -0.0525350>,
    <0.9986191, 0.0000470, -0.0525349>,
    <0.9961601, 0.0000469, -0.0875506>,
    <0.9986191, 0.0000470, -0.0525349>,
    <0.9986191, 0.0000470, -0.0525347>,
    <0.9986191, 0.0000470, -0.0525347>,
    <0.9986191, 0.0000470, -0.0525346>,
    <0.9961601, 0.0000469, -0.0875504>,
    <0.9961601, 0.0000469, -0.0875504>,
    <0.9790996, 0.0000462, -0.2033815>,
    <-0.0002053, 0.9999994, 0.0010841>,
    <-0.0002659, 0.9999995, 0.0009839>,
    <-0.0002050, 0.9999999, 0.0004143>,
    <-0.0001877, 0.9999999, 0.0004740>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001843, 0.9999994, 0.0011027>,
    <-0.0001891, 0.9999968, 0.0025373>,
    <-0.0003403, 0.9999997, 0.0006738>,
    <-0.0002205, 0.9999999, 0.0002809>,
    <-0.0008611, 0.9999967, 0.0024226>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0003498, 0.9999999, 0.0001182>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001852, 1.0000000, 0.0001577>,
    <-0.0001833, 1.0000000, 0.0001881>,
    <-0.0002234, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001858, 1.0000000, 0.0001182>,
    <-0.0001801, 1.0000000, 0.0001183>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001194>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001813, 1.0000000, 0.0002019>,
    <-0.0001801, 1.0000000, 0.0001206>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001218>,
    <-0.0001801, 1.0000000, 0.0001230>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001806, 1.0000000, 0.0002056>,
    <-0.0001818, 0.9999999, 0.0004861>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, -0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <0.0002620, -1.0000000, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, -0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <1.0000000, 0.0000464, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, -0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <-0.0001710, 1.0000000, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, -0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <1.0000000, 0.0000670, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005139>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <0.9999999, 0.0000670, 0.0005140>,
    <-0.9869426, -0.0000663, -0.1610724>,
    <-0.9869426, -0.0000663, -0.1610724>,
    <-0.9869431, -0.0000663, -0.1610692>,
    <-0.9869431, -0.0000663, -0.1610692>,
    <-0.9869431, -0.0000664, -0.1610692>,
    <-0.9869426, -0.0000664, -0.1610724>,
    <-0.9869426, -0.0000664, -0.1610724>,
    <-0.9869421, -0.0000664, -0.1610757>,
    <-0.9869421, -0.0000663, -0.1610757>,
    <-0.9869421, -0.0000663, -0.1610757>,
    <-0.9869421, -0.0000663, -0.1610757>,
    <-0.9869426, -0.0000662, -0.1610724>,
    <-0.9869431, -0.0000662, -0.1610692>,
    <-0.9869421, -0.0000663, -0.1610757>,
    <-0.9869421, -0.0000662, -0.1610757>,
    <-0.9869421, -0.0000662, -0.1610757>,
    <-0.9869421, -0.0000662, -0.1610757>,
    <-0.9869426, -0.0000662, -0.1610724>,
    <-0.9869426, -0.0000662, -0.1610724>,
    <-0.9869431, -0.0000662, -0.1610692>,
    <-0.9869436, -0.0000662, -0.1610659>,
    <-0.9869436, -0.0000663, -0.1610659>,
    <-0.9869431, -0.0000662, -0.1610692>,
    <-0.9869437, -0.0000662, -0.1610659>,
    <-0.9869437, -0.0000662, -0.1610659>,
    <-0.9869442, -0.0000662, -0.1610626>,
    <-0.9869442, -0.0000662, -0.1610626>,
    <-0.9869442, -0.0000662, -0.1610626>,
    <-0.9869442, -0.0000663, -0.1610627>,
    <-0.9869436, -0.0000663, -0.1610659>,
    <-0.9869442, -0.0000663, -0.1610627>,
    <-0.9869442, -0.0000663, -0.1610627>,
    <-0.9869442, -0.0000663, -0.1610627>,
    <-0.9869442, -0.0000664, -0.1610627>,
    <-0.9869436, -0.0000664, -0.1610659>,
    <-0.9869436, -0.0000664, -0.1610659>,
    <-0.9869431, -0.0000664, -0.1610692>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <1.0000000, 0.0000673, 0.0000083>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987355, -0.0000672, -0.0502722>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987356, -0.0000672, -0.0502712>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987358, -0.0000672, -0.0502681>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987357, -0.0000672, -0.0502691>,
    <-0.9987357, -0.0000672, -0.0502702>,
    <0.9999404, 0.0001117, 0.0109141>,
    <0.9999447, 0.0000673, 0.0105163>,
    <0.9999338, 0.0000673, 0.0115037>,
    <0.9999321, 0.0000784, 0.0116512>,
    <0.9999286, 0.0000814, 0.0119508>,
    <0.9999286, 0.0001217, 0.0119507>,
    <0.9999286, 0.0001217, 0.0119507>,
    <0.9999725, 0.0002732, 0.0074076>,
    <0.9999725, 0.0001960, 0.0074077>,
    <0.9999726, 0.0000674, 0.0074076>,
    <0.9999404, 0.0000230, 0.0109136>,
    <0.9999321, 0.0000562, 0.0116506>,
    <0.9999726, -0.0000613, 0.0074074>,
    <0.9999726, -0.0001385, 0.0074070>,
    <0.9999286, 0.0000130, 0.0119496>,
    <0.9999286, 0.0000130, 0.0119496>,
    <0.9999286, 0.0000533, 0.0119498>,
    <0.9999295, 0.0000660, 0.0118782>,
    <0.9999298, 0.0000673, 0.0118451>,
    <0.9999286, 0.0000533, 0.0119498>,
    <0.9999286, 0.0000656, 0.0119498>,
    <0.9999286, 0.0000656, 0.0119498>,
    <0.9999286, 0.0000673, 0.0119498>,
    <0.9999286, 0.0000673, 0.0119500>,
    <0.9999286, 0.0000673, 0.0119500>,
    <0.9999286, 0.0000673, 0.0119503>,
    <0.9999294, 0.0000686, 0.0118787>,
    <0.9999286, 0.0000673, 0.0119503>,
    <0.9999286, 0.0000673, 0.0119505>,
    <0.9999286, 0.0000673, 0.0119505>,
    <0.9999286, 0.0000673, 0.0119508>,
    <0.9999286, 0.0000691, 0.0119508>,
    <0.9999286, 0.0000691, 0.0119508>,
    <0.9999286, 0.0000814, 0.0119508>,
    <0.9999905, 0.0002163, -0.0043628>,
    <0.9997833, 0.0001412, -0.0208159>,
    <0.9998819, 0.0000673, -0.0153711>,
    <0.9999997, 0.0000674, -0.0008270>,
    <0.9999725, 0.0002732, 0.0074076>,
    <0.9990830, 0.0006682, -0.0428096>,
    <0.9990830, 0.0006682, -0.0428096>,
    <0.9990831, 0.0002224, -0.0428134>,
    <0.9993788, 0.0000800, -0.0352415>,
    <0.9994752, 0.0000673, -0.0323937>,
    <0.9990831, 0.0002224, -0.0428134>,
    <0.9990830, 0.0000867, -0.0428145>,
    <0.9990830, 0.0000867, -0.0428145>,
    <0.9990830, 0.0000673, -0.0428147>,
    <0.9990831, 0.0000673, -0.0428138>,
    <0.9990831, 0.0000673, -0.0428138>,
    <0.9990831, 0.0000673, -0.0428129>,
    <0.9993789, 0.0000546, -0.0352399>,
    <0.9997834, -0.0000065, -0.0208147>,
    <0.9990831, 0.0000673, -0.0428129>,
    <0.9990831, 0.0000673, -0.0428120>,
    <0.9990831, 0.0000673, -0.0428120>,
    <0.9990832, 0.0000673, -0.0428112>,
    <0.9990832, 0.0000479, -0.0428110>,
    <0.9990832, 0.0000479, -0.0428110>,
    <0.9990832, -0.0000878, -0.0428096>,
    <0.9999905, -0.0000815, -0.0043624>,
    <0.9990832, -0.0000878, -0.0428096>,
    <0.9990833, -0.0005335, -0.0428052>,
    <0.9990833, -0.0005335, -0.0428052>,
    <0.9999726, -0.0001385, 0.0074070>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4349582, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4349582, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4263414, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6559367, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773948, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032658, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458854>,
    <0.4677608, 0.9456845>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4355157, 0.9458854>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9451388>,
    <0.4677604, 0.9518685>,
    <0.4676209, 0.9588001>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.4677604, 0.9518685>,
    <0.5000059, 0.9579003>,
    <0.4674769, 0.9657316>,
    <0.4352664, 0.9584513>,
    <0.4031264, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4349582, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352664, 0.9584513>,
    <0.4022562, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032658, 0.9526160>,
    <0.5322510, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9518685>,
    <0.5000059, 0.9451388>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458642>,
    <0.5967410, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289897, 0.9511210>,
    <0.5644961, 0.9458642>,
    <0.5967380, 0.9395004>,
    <0.6289858, 0.9451388>,
    <0.5967440, 0.9518685>,
    <0.5967474, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967440, 0.9518685>,
    <0.6289941, 0.9579003>,
    <0.5967509, 0.9657316>,
    <0.5645003, 0.9587016>,
    <0.5322532, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.5645003, 0.9587016>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9579003>,
    <0.5322521, 0.9518685>,
    <0.6423395, 0.9456845>,
    <0.6556982, 0.9526160>,
    <0.6289897, 0.9511210>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423437, 0.9518685>,
    <0.6289858, 0.9451388>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458854>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458854>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690526, 0.9526160>,
    <0.6691147, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6690526, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694793, 0.9657316>,
    <0.6558043, 0.9584513>,
    <0.6424060, 0.9588001>,
    <0.6556982, 0.9526160>,
    <0.6559367, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289897, 0.9511210>,
    <0.6558043, 0.9584513>,
    <0.6424701, 0.9657316>,
    <0.6289941, 0.9579003>,
    <0.6423437, 0.9518685>,
    <0.3997689, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4022562, 0.9657316>,
    <0.4331396, 0.9660561>,
    <0.4665018, 0.9660805>,
    <0.4310370, 0.9664312>,
    <0.4349582, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4331396, 0.9660561>,
    <0.4674769, 0.9657316>,
    <0.5000060, 0.9660883>,
    <0.4655215, 0.9664293>,
    <0.4643476, 0.9667801>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000061, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.4655215, 0.9664293>,
    <0.5000060, 0.9667645>,
    <0.4631665, 0.9671308>,
    <0.4286164, 0.9667919>,
    <0.3931424, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4263414, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4286164, 0.9667919>,
    <0.3894539, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664293>,
    <0.5000060, 0.9660883>,
    <0.5322542, 0.9657316>,
    <0.5667950, 0.9660902>,
    <0.6000933, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6378965, 0.9664275>,
    <0.5667950, 0.9660902>,
    <0.5967509, 0.9657316>,
    <0.6335597, 0.9660883>,
    <0.6034357, 0.9664293>,
    <0.6068019, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034357, 0.9664293>,
    <0.6422052, 0.9667645>,
    <0.6101681, 0.9671308>,
    <0.5711180, 0.9667664>,
    <0.5356086, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.5711180, 0.9667664>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667645>,
    <0.5344905, 0.9664293>,
    <0.6473345, 0.9660805>,
    <0.6665054, 0.9664312>,
    <0.6378965, 0.9664275>,
    <0.6289992, 0.9657316>,
    <0.6559367, 0.9657316>,
    <0.6522009, 0.9664293>,
    <0.6335597, 0.9660883>,
    <0.6424701, 0.9657316>,
    <0.6608384, 0.9660561>,
    <0.6749817, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6559367, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6608384, 0.9660561>,
    <0.6694793, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866708, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926707, 0.9671308>,
    <0.6721189, 0.9667919>,
    <0.6571714, 0.9667801>,
    <0.6665054, 0.9664312>,
    <0.6773948, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6378965, 0.9664275>,
    <0.6721189, 0.9667919>,
    <0.6621448, 0.9671308>,
    <0.6422052, 0.9667645>,
    <0.6522009, 0.9664293>,
    <0.3896277, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.3895219, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3894539, 0.9671308>,
    <0.4263465, 0.9729776>,
    <0.4631761, 0.9726967>,
    <0.4263507, 0.9777601>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4263465, 0.9729776>,
    <0.4631665, 0.9671308>,
    <0.5000061, 0.9732089>,
    <0.4631777, 0.9782626>,
    <0.4631249, 0.9833260>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631777, 0.9782626>,
    <0.5000061, 0.9837065>,
    <0.4630714, 0.9883895>,
    <0.4262410, 0.9832100>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262410, 0.9832100>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895219, 0.9777601>,
    <0.5367803, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9782626>,
    <0.5000061, 0.9732089>,
    <0.5367268, 0.9671308>,
    <0.5735592, 0.9726839>,
    <0.6103387, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473573, 0.9787650>,
    <0.5735592, 0.9726839>,
    <0.6101681, 0.9671308>,
    <0.6471335, 0.9732089>,
    <0.6105094, 0.9782626>,
    <0.6106597, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105094, 0.9782626>,
    <0.6475562, 0.9837065>,
    <0.6108101, 0.9883895>,
    <0.5737713, 0.9832176>,
    <0.5368873, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.5737713, 0.9832176>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9837065>,
    <0.5368338, 0.9782626>,
    <0.6623650, 0.9726967>,
    <0.6778190, 0.9777601>,
    <0.6473573, 0.9787650>,
    <0.6468888, 0.9671308>,
    <0.6773948, 0.9671308>,
    <0.6625884, 0.9782625>,
    <0.6471335, 0.9732089>,
    <0.6621448, 0.9671308>,
    <0.6776281, 0.9729776>,
    <0.6928127, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773948, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776281, 0.9729776>,
    <0.6926707, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930705, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930705, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780838, 0.9832100>,
    <0.6628141, 0.9833260>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473573, 0.9787650>,
    <0.6780838, 0.9832100>,
    <0.6630402, 0.9883895>,
    <0.6475562, 0.9837065>,
    <0.6625884, 0.9782625>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.011335, 0.13719, -0.147353>
}

#declare TMesh006 = mesh2 {
  vertex_vectors {
    582,
    <2.1734601, 0.0653472, 18.5417983>,
    <2.0013882, 0.0307137, 18.5417983>,
    <2.0021672, -0.1348962, 18.5417983>,
    <2.1725990, -0.1348507, 18.5417983>,
    <2.0874241, 0.0480304, 18.5417983>,
    <2.0017777, -0.0520913, 18.5417983>,
    <2.0873831, -0.1348735, 18.5417983>,
    <2.1730296, -0.0347518, 18.5417983>,
    <2.0874036, -0.0434215, 18.5417983>,
    <2.3430309, -0.1348052, 18.5417983>,
    <2.3455321, 0.0999807, 18.5417983>,
    <2.2578150, -0.1348279, 18.5417983>,
    <2.3442815, -0.0174122, 18.5417983>,
    <2.2594961, 0.0826639, 18.5417983>,
    <2.2586555, -0.0260820, 18.5417983>,
    <2.3480332, 0.3347665, 18.5417983>,
    <2.1743212, 0.2655450, 18.5417983>,
    <2.3467826, 0.2173736, 18.5417983>,
    <2.2611772, 0.3001557, 18.5417983>,
    <2.1738907, 0.1654461, 18.5417983>,
    <2.2603366, 0.1914098, 18.5417983>,
    <2.0006092, 0.1963236, 18.5417983>,
    <2.0874652, 0.2309343, 18.5417983>,
    <2.0009987, 0.1135186, 18.5417983>,
    <2.0874447, 0.1394824, 18.5417983>,
    <2.0592721, -0.1353186, 18.1202395>,
    <2.0044034, -0.1353504, 18.1202395>,
    <2.0044687, -0.1353636, 18.1217627>,
    <2.0559641, -0.1353322, 18.1217627>,
    <2.0318378, -0.1353345, 18.1202395>,
    <2.0044361, -0.1353570, 18.1210011>,
    <2.0302164, -0.1353479, 18.1217627>,
    <2.0576181, -0.1353254, 18.1210011>,
    <2.0310271, -0.1353412, 18.1210011>,
    <2.1074595, -0.1353008, 18.1217627>,
    <2.1141408, -0.1352868, 18.1202395>,
    <2.0817118, -0.1353165, 18.1217627>,
    <2.1108002, -0.1352938, 18.1210011>,
    <2.0867065, -0.1353027, 18.1202395>,
    <2.0842091, -0.1353096, 18.1210011>,
    <2.1208221, -0.1352727, 18.1187163>,
    <2.0625801, -0.1353049, 18.1187163>,
    <2.1174814, -0.1352798, 18.1194779>,
    <2.0917011, -0.1352888, 18.1187163>,
    <2.0609261, -0.1353118, 18.1194779>,
    <2.0892038, -0.1352958, 18.1194779>,
    <2.0043382, -0.1353371, 18.1187163>,
    <2.0334591, -0.1353210, 18.1187163>,
    <2.0043708, -0.1353438, 18.1194779>,
    <2.0326485, -0.1353278, 18.1194779>,
    <2.1143682, 0.0535944, 18.1202395>,
    <2.1076205, 0.0522404, 18.1217627>,
    <2.1142545, -0.0408462, 18.1202395>,
    <2.1075400, -0.0415302, 18.1217627>,
    <2.1109944, 0.0529174, 18.1210011>,
    <2.1108973, -0.0411882, 18.1210011>,
    <2.1077816, 0.2397817, 18.1217627>,
    <2.1145956, 0.2424756, 18.1202395>,
    <2.1077011, 0.1460111, 18.1217627>,
    <2.1111886, 0.2411287, 18.1210011>,
    <2.1144819, 0.1480350, 18.1202395>,
    <2.1110915, 0.1470230, 18.1210011>,
    <2.1214096, 0.2451696, 18.1187163>,
    <2.1211158, 0.0549484, 18.1187163>,
    <2.1180026, 0.2438226, 18.1194779>,
    <2.1212627, 0.1500590, 18.1187163>,
    <2.1177420, 0.0542714, 18.1194779>,
    <2.1178723, 0.1490470, 18.1194779>,
    <2.1209690, -0.0401621, 18.1187163>,
    <2.1176117, -0.0405042, 18.1194779>,
    <2.0586710, 0.2201778, 18.1202395>,
    <2.0552952, 0.2188536, 18.1217627>,
    <2.0866333, 0.2313267, 18.1202395>,
    <2.0815384, 0.2293176, 18.1217627>,
    <2.0569831, 0.2195157, 18.1210011>,
    <2.0840858, 0.2303222, 18.1210011>,
    <2.0028088, 0.1979254, 18.1217627>,
    <2.0027464, 0.1978800, 18.1202395>,
    <2.0290520, 0.2083895, 18.1217627>,
    <2.0027776, 0.1979027, 18.1210011>,
    <2.0307087, 0.2090289, 18.1202395>,
    <2.0298803, 0.2087092, 18.1210011>,
    <2.0026840, 0.1978346, 18.1187163>,
    <2.0620468, 0.2215021, 18.1187163>,
    <2.0027152, 0.1978573, 18.1194779>,
    <2.0323654, 0.2096683, 18.1187163>,
    <2.0603589, 0.2208400, 18.1194779>,
    <2.0315370, 0.2093486, 18.1194779>,
    <2.0917282, 0.2333358, 18.1187163>,
    <2.0891807, 0.2323313, 18.1194779>,
    <2.0694781, -0.1352765, 18.1370901>,
    <2.0042020, -0.1353095, 18.1370901>,
    <2.0368401, -0.1352930, 18.1370901>,
    <2.0042701, -0.1353233, 18.1279032>,
    <2.0660291, -0.1352907, 18.1279032>,
    <2.0351496, -0.1353070, 18.1279032>,
    <2.1347541, -0.1352434, 18.1370901>,
    <2.1277881, -0.1352581, 18.1279032>,
    <2.1021161, -0.1352599, 18.1370901>,
    <2.0969086, -0.1352744, 18.1279032>,
    <2.1486861, -0.1352141, 18.1554639>,
    <2.0763760, -0.1352480, 18.1554639>,
    <2.1417201, -0.1352288, 18.1462770>,
    <2.1125311, -0.1352310, 18.1554639>,
    <2.0729270, -0.1352622, 18.1462770>,
    <2.1073236, -0.1352455, 18.1462770>,
    <2.0040659, -0.1352818, 18.1554639>,
    <2.0402210, -0.1352649, 18.1554639>,
    <2.0041340, -0.1352957, 18.1462770>,
    <2.0385305, -0.1352789, 18.1462770>,
    <2.1351863, 0.0577719, 18.1370901>,
    <2.1349702, -0.0387358, 18.1370901>,
    <2.1281510, 0.0563601, 18.1279032>,
    <2.1279696, -0.0394490, 18.1279032>,
    <2.1356184, 0.2507871, 18.1370901>,
    <2.1285140, 0.2479784, 18.1279032>,
    <2.1354023, 0.1542795, 18.1370901>,
    <2.1283325, 0.1521693, 18.1279032>,
    <2.1498273, 0.2564047, 18.1554639>,
    <2.1492567, 0.0605953, 18.1554639>,
    <2.1427228, 0.2535959, 18.1462770>,
    <2.1495420, 0.1585000, 18.1554639>,
    <2.1422215, 0.0591836, 18.1462770>,
    <2.1424722, 0.1563897, 18.1462770>,
    <2.1489714, -0.0373094, 18.1554639>,
    <2.1419708, -0.0380226, 18.1462770>,
    <2.0690862, 0.2242635, 18.1370901>,
    <2.1023523, 0.2375253, 18.1370901>,
    <2.0655665, 0.2228828, 18.1279032>,
    <2.0970402, 0.2354306, 18.1279032>,
    <2.0025539, 0.1977398, 18.1370901>,
    <2.0026189, 0.1977872, 18.1279032>,
    <2.0358200, 0.2110017, 18.1370901>,
    <2.0340927, 0.2103350, 18.1279032>,
    <2.0024238, 0.1976451, 18.1554639>,
    <2.0761255, 0.2270249, 18.1554639>,
    <2.0024889, 0.1976925, 18.1462770>,
    <2.0392747, 0.2123350, 18.1554639>,
    <2.0726058, 0.2256442, 18.1462770>,
    <2.0375473, 0.2116683, 18.1462770>,
    <2.1129764, 0.2417148, 18.1554639>,
    <2.1076643, 0.2396200, 18.1462770>,
    <2.0812641, -0.1352278, 18.1573801>,
    <2.0039695, -0.1352623, 18.1573801>,
    <2.0426168, -0.1352450, 18.1573801>,
    <2.0040177, -0.1352721, 18.1564220>,
    <2.0788201, -0.1352379, 18.1564220>,
    <2.0414189, -0.1352550, 18.1564220>,
    <2.1585588, -0.1351933, 18.1573801>,
    <2.1536225, -0.1352037, 18.1564220>,
    <2.1199115, -0.1352106, 18.1573801>,
    <2.1162213, -0.1352208, 18.1564220>,
    <2.1684314, -0.1351726, 18.1592964>,
    <2.0861522, -0.1352076, 18.1592964>,
    <2.1634951, -0.1351829, 18.1583383>,
    <2.1272918, -0.1351901, 18.1592964>,
    <2.0837082, -0.1352177, 18.1583383>,
    <2.1236016, -0.1352003, 18.1583383>,
    <2.0038730, -0.1352427, 18.1592964>,
    <2.0450126, -0.1352251, 18.1592964>,
    <2.0039212, -0.1352525, 18.1583383>,
    <2.0438147, -0.1352351, 18.1583383>,
    <2.1592274, 0.0625961, 18.1573801>,
    <2.1588931, -0.0362986, 18.1573801>,
    <2.1542421, 0.0615957, 18.1564220>,
    <2.1539323, -0.0368040, 18.1564220>,
    <2.1598961, 0.2603854, 18.1573801>,
    <2.1548617, 0.2583951, 18.1564220>,
    <2.1595617, 0.1614907, 18.1573801>,
    <2.1545519, 0.1599954, 18.1564220>,
    <2.1699649, 0.2643662, 18.1592964>,
    <2.1691982, 0.0645968, 18.1592964>,
    <2.1649305, 0.2623758, 18.1583383>,
    <2.1695815, 0.1644815, 18.1592964>,
    <2.1642128, 0.0635964, 18.1583383>,
    <2.1645716, 0.1629861, 18.1583383>,
    <2.1688148, -0.0352879, 18.1592964>,
    <2.1638540, -0.0357933, 18.1583383>,
    <2.0811138, 0.2289817, 18.1573801>,
    <2.1205050, 0.2446836, 18.1573801>,
    <2.0786197, 0.2280033, 18.1564220>,
    <2.1167407, 0.2431992, 18.1564220>,
    <2.0023316, 0.1975780, 18.1573801>,
    <2.0023777, 0.1976115, 18.1564220>,
    <2.0417227, 0.2132798, 18.1573801>,
    <2.0404987, 0.2128074, 18.1564220>,
    <2.0022394, 0.1975108, 18.1592964>,
    <2.0861022, 0.2309385, 18.1592964>,
    <2.0022855, 0.1975444, 18.1583383>,
    <2.0441708, 0.2142247, 18.1592964>,
    <2.0836080, 0.2299601, 18.1583383>,
    <2.0429468, 0.2137523, 18.1583383>,
    <2.1280335, 0.2476524, 18.1592964>,
    <2.1242692, 0.2461680, 18.1583383>,
    <2.0872214, -0.1352037, 18.2324892>,
    <2.0038724, -0.1352425, 18.2344341>,
    <2.0455456, -0.1352229, 18.2333227>,
    <2.0038727, -0.1352426, 18.1968653>,
    <2.0861681, -0.1352075, 18.1968653>,
    <2.0450204, -0.1352251, 18.1968653>,
    <2.1705857, -0.1351680, 18.2322113>,
    <2.1684634, -0.1351725, 18.1968653>,
    <2.1289022, -0.1351856, 18.2322113>,
    <2.1273157, -0.1351900, 18.1968653>,
    <2.1894619, -0.1351283, 18.2873438>,
    <2.0965801, -0.1351677, 18.2890109>,
    <2.1768884, -0.1351548, 18.2631118>,
    <2.1430133, -0.1351465, 18.2873438>,
    <2.0903496, -0.1351924, 18.2642232>,
    <2.1336139, -0.1351725, 18.2631118>,
    <2.0038718, -0.1352424, 18.3095719>,
    <2.0501774, -0.1351952, 18.2940122>,
    <2.0038721, -0.1352425, 18.2720030>,
    <2.0471057, -0.1352164, 18.2675574>,
    <2.1713738, 0.0650334, 18.2322113>,
    <2.1709797, -0.0350673, 18.2322113>,
    <2.1692305, 0.0646033, 18.1968653>,
    <2.1688469, -0.0352846, 18.1968653>,
    <2.1721619, 0.2652348, 18.2322113>,
    <2.1699975, 0.2643791, 18.1968653>,
    <2.1717678, 0.1651341, 18.2322113>,
    <2.1696140, 0.1644912, 18.1968653>,
    <2.1914132, 0.2728459, 18.2873438>,
    <2.1904376, 0.0688588, 18.2873438>,
    <2.1785899, 0.2677761, 18.2631118>,
    <2.1909254, 0.1708524, 18.2873438>,
    <2.1777391, 0.0663107, 18.2631118>,
    <2.1781645, 0.1670434, 18.2631118>,
    <2.1899498, -0.0331347, 18.2873438>,
    <2.1773138, -0.0344220, 18.2631118>,
    <2.0871930, 0.2313673, 18.2324892>,
    <2.1296763, 0.2483001, 18.2322113>,
    <2.0861183, 0.2309449, 18.1968653>,
    <2.1280579, 0.2476620, 18.1968653>,
    <2.0022388, 0.1975104, 18.2344341>,
    <2.0022391, 0.1975106, 18.1968653>,
    <2.0447147, 0.2144379, 18.2333227>,
    <2.0441787, 0.2142277, 18.1968653>,
    <2.0022382, 0.1975100, 18.3095719>,
    <2.0967428, 0.2351175, 18.2890109>,
    <2.0022385, 0.1975102, 18.2720030>,
    <2.0494442, 0.2162800, 18.2940122>,
    <2.0903849, 0.2326218, 18.2642232>,
    <2.0463069, 0.2150625, 18.2675574>,
    <2.1440707, 0.2539764, 18.2873438>,
    <2.1344825, 0.2501954, 18.2631118>,
    <2.1194133, -0.1350703, 18.3131904>,
    <2.0032176, -0.1351096, 18.3135798>,
    <2.0613154, -0.1350899, 18.3133573>,
    <2.0035447, -0.1351760, 18.3115759>,
    <2.1069400, -0.1351239, 18.3037960>,
    <2.0552372, -0.1351489, 18.3071303>,
    <2.2356097, -0.1350312, 18.3131347>,
    <2.2103965, -0.1350842, 18.3026846>,
    <2.1775114, -0.1350507, 18.3131347>,
    <2.1586631, -0.1351030, 18.3026846>,
    <2.2825423, -0.1349324, 18.3353648>,
    <2.1426356, -0.1349714, 18.3340315>,
    <2.2610191, -0.1349777, 18.3226946>,
    <2.2125963, -0.1349534, 18.3353648>,
    <2.1319840, -0.1350164, 18.3218058>,
    <2.1965064, -0.1349980, 18.3226946>,
    <2.0025635, -0.1349767, 18.3175878>,
    <2.0726458, -0.1349834, 18.3300317>,
    <2.0028906, -0.1350431, 18.3155838>,
    <2.0674422, -0.1350307, 18.3191392>,
    <2.2370437, 0.0782110, 18.3131347>,
    <2.2363267, -0.0284101, 18.3131347>,
    <2.2115801, 0.0731013, 18.3026846>,
    <2.2109883, -0.0309915, 18.3026846>,
    <2.2384778, 0.2914531, 18.3131347>,
    <2.2127637, 0.2812869, 18.3026846>,
    <2.2377608, 0.1848321, 18.3131347>,
    <2.2121719, 0.1771941, 18.3026846>,
    <2.2863429, 0.3103769, 18.3353648>,
    <2.2844426, 0.0877222, 18.3353648>,
    <2.2643920, 0.3016985, 18.3226946>,
    <2.2853927, 0.1990495, 18.3353648>,
    <2.2627056, 0.0833604, 18.3226946>,
    <2.2635488, 0.1925294, 18.3226946>,
    <2.2834925, -0.0236051, 18.3353648>,
    <2.2618623, -0.0258087, 18.3226946>,
    <2.1200451, 0.2442537, 18.3131904>,
    <2.1792614, 0.2678534, 18.3131347>,
    <2.1073154, 0.2392633, 18.3037960>,
    <2.1600347, 0.2602716, 18.3026846>,
    <2.0016131, 0.1970547, 18.3135798>,
    <2.0019257, 0.1972823, 18.3115759>,
    <2.0608290, 0.2206541, 18.3133573>,
    <2.0546157, 0.2182693, 18.3071303>,
    <2.0009879, 0.1965994, 18.3175878>,
    <2.1437445, 0.2535457, 18.3340315>,
    <2.0013005, 0.1968271, 18.3155838>,
    <2.0724104, 0.2251047, 18.3300317>,
    <2.1328742, 0.2492831, 18.3218058>,
    <2.0670920, 0.2230585, 18.3191392>,
    <2.2150506, 0.2819664, 18.3353648>,
    <2.1986378, 0.2754942, 18.3226946>,
    <2.1531110, -0.1349307, 18.3800376>,
    <2.0025322, -0.1349704, 18.3784821>,
    <2.0778228, -0.1349508, 18.3793709>,
    <2.0025479, -0.1349735, 18.3480349>,
    <2.1493516, -0.1349447, 18.3542569>,
    <2.0759546, -0.1349601, 18.3515903>,
    <2.3036751, -0.1348880, 18.3802598>,
    <2.2960969, -0.1349039, 18.3551457>,
    <2.2283943, -0.1349096, 18.3802598>,
    <2.2227291, -0.1349253, 18.3551457>,
    <2.3088707, -0.1348770, 18.4393764>,
    <2.1556858, -0.1349205, 18.4393764>,
    <2.3072690, -0.1348804, 18.4089292>,
    <2.2322783, -0.1348988, 18.4393764>,
    <2.1548928, -0.1349238, 18.4089292>,
    <2.2310809, -0.1349021, 18.4089292>,
    <2.0025009, -0.1349640, 18.4393764>,
    <2.0790934, -0.1349423, 18.4393764>,
    <2.0025166, -0.1349672, 18.4089292>,
    <2.0787047, -0.1349455, 18.4089292>,
    <2.3057853, 0.0920049, 18.3802598>,
    <2.3047302, -0.0214415, 18.3802598>,
    <2.2981319, 0.0904692, 18.3551457>,
    <2.2971144, -0.0222174, 18.3551457>,
    <2.3078956, 0.3188978, 18.3802598>,
    <2.3001668, 0.3158422, 18.3551457>,
    <2.3068404, 0.2054514, 18.3802598>,
    <2.2991493, 0.2031557, 18.3551457>,
    <2.3131944, 0.3209928, 18.4393764>,
    <2.3110326, 0.0930579, 18.4393764>,
    <2.3115608, 0.3203469, 18.4089292>,
    <2.3121135, 0.2070253, 18.4393764>,
    <2.3094149, 0.0927333, 18.4089292>,
    <2.3104879, 0.2065401, 18.4089292>,
    <2.3099517, -0.0209096, 18.4393764>,
    <2.3083420, -0.0210736, 18.4089292>,
    <2.1544338, 0.2577428, 18.3800376>,
    <2.2311658, 0.2883212, 18.3802598>,
    <2.1505978, 0.2562357, 18.3542569>,
    <2.2253870, 0.2860423, 18.3551457>,
    <2.0009580, 0.1965776, 18.3784821>,
    <2.0009730, 0.1965885, 18.3480349>,
    <2.0776971, 0.2271611, 18.3793709>,
    <2.0757900, 0.2264155, 18.3515903>,
    <2.0009281, 0.1965558, 18.4393764>,
    <2.1570613, 0.2587743, 18.4393764>,
    <2.0009431, 0.1965667, 18.4089292>,
    <2.0789947, 0.2276651, 18.4393764>,
    <2.1562520, 0.2584568, 18.4089292>,
    <2.0785975, 0.2275118, 18.4089292>,
    <2.2351278, 0.2898835, 18.4393764>,
    <2.2339064, 0.2894019, 18.4089292>,
    <2.1641424, -0.1348856, 18.4393764>,
    <2.0023340, -0.1349301, 18.4393764>,
    <2.0832382, -0.1349079, 18.4393764>,
    <2.0024175, -0.1349471, 18.4393764>,
    <2.1599141, -0.1349031, 18.4393764>,
    <2.0811658, -0.1349251, 18.4393764>,
    <2.3259508, -0.1348411, 18.4393764>,
    <2.3174108, -0.1348591, 18.4393764>,
    <2.2450466, -0.1348634, 18.4393764>,
    <2.2386625, -0.1348811, 18.4393764>,
    <2.3430309, -0.1348052, 18.4393764>,
    <2.1725990, -0.1348507, 18.4393764>,
    <2.3344909, -0.1348231, 18.4393764>,
    <2.2578150, -0.1348279, 18.4393764>,
    <2.1683707, -0.1348682, 18.4393764>,
    <2.2514308, -0.1348456, 18.4393764>,
    <2.0021672, -0.1348962, 18.4393764>,
    <2.0873831, -0.1348735, 18.4393764>,
    <2.0022506, -0.1349132, 18.4393764>,
    <2.0853107, -0.1348907, 18.4393764>,
    <2.3282823, 0.0965193, 18.4393764>,
    <2.3271166, -0.0191609, 18.4393764>,
    <2.3196574, 0.0947886, 18.4393764>,
    <2.3185341, -0.0200353, 18.4393764>,
    <2.3306138, 0.3278796, 18.4393764>,
    <2.3219041, 0.3244362, 18.4393764>,
    <2.3294481, 0.2121994, 18.4393764>,
    <2.3207808, 0.2096124, 18.4393764>,
    <2.3480332, 0.3347665, 18.4393764>,
    <2.3455321, 0.0999807, 18.4393764>,
    <2.3393235, 0.3313230, 18.4393764>,
    <2.3467826, 0.2173736, 18.4393764>,
    <2.3369072, 0.0982500, 18.4393764>,
    <2.3381154, 0.2147865, 18.4393764>,
    <2.3442815, -0.0174122, 18.4393764>,
    <2.3356990, -0.0182866, 18.4393764>,
    <2.1656912, 0.2621597, 18.4393764>,
    <2.2481525, 0.2950196, 18.4393764>,
    <2.1613762, 0.2604670, 18.4393764>,
    <2.2416402, 0.2924516, 18.4393764>,
    <2.0007686, 0.1964397, 18.4393764>,
    <2.0008484, 0.1964978, 18.4393764>,
    <2.0832299, 0.2292997, 18.4393764>,
    <2.0811123, 0.2284824, 18.4393764>,
    <2.0006092, 0.1963236, 18.4393764>,
    <2.1743212, 0.2655450, 18.4393764>,
    <2.0006889, 0.1963816, 18.4393764>,
    <2.0874652, 0.2309343, 18.4393764>,
    <2.1700062, 0.2638523, 18.4393764>,
    <2.0853476, 0.2301170, 18.4393764>,
    <2.2611772, 0.3001557, 18.4393764>,
    <2.2546649, 0.2975877, 18.4393764>,
    <2.1725990, -0.1348507, 18.4905874>,
    <2.0021672, -0.1348962, 18.4905874>,
    <2.0873831, -0.1348735, 18.4905874>,
    <2.0021672, -0.1348962, 18.4649819>,
    <2.1725990, -0.1348507, 18.4649819>,
    <2.0873831, -0.1348735, 18.4649819>,
    <2.3430309, -0.1348052, 18.4905874>,
    <2.3430309, -0.1348052, 18.4649819>,
    <2.2578150, -0.1348279, 18.4905874>,
    <2.2578150, -0.1348279, 18.4649819>,
    <2.3430309, -0.1348052, 18.5161929>,
    <2.1725990, -0.1348507, 18.5161929>,
    <2.2578150, -0.1348279, 18.5161929>,
    <2.0021672, -0.1348962, 18.5161929>,
    <2.0873831, -0.1348735, 18.5161929>,
    <2.3455321, 0.0999807, 18.4905874>,
    <2.3442815, -0.0174123, 18.4905874>,
    <2.3455321, 0.0999807, 18.4649819>,
    <2.3442815, -0.0174122, 18.4649819>,
    <2.3480332, 0.3347665, 18.4905874>,
    <2.3480332, 0.3347665, 18.4649819>,
    <2.3467826, 0.2173736, 18.4905874>,
    <2.3467826, 0.2173736, 18.4649819>,
    <2.3480332, 0.3347665, 18.5161929>,
    <2.3455321, 0.0999807, 18.5161929>,
    <2.3467826, 0.2173736, 18.5161929>,
    <2.3442815, -0.0174122, 18.5161929>,
    <2.1743212, 0.2655450, 18.4905874>,
    <2.2611772, 0.3001557, 18.4905874>,
    <2.1743212, 0.2655450, 18.4649819>,
    <2.2611772, 0.3001557, 18.4649819>,
    <2.0006092, 0.1963236, 18.4905874>,
    <2.0006092, 0.1963236, 18.4649819>,
    <2.0874652, 0.2309343, 18.4905874>,
    <2.0874652, 0.2309343, 18.4649819>,
    <2.0006092, 0.1963236, 18.5161929>,
    <2.1743212, 0.2655450, 18.5161929>,
    <2.0874652, 0.2309343, 18.5161929>,
    <2.2611772, 0.3001557, 18.5161929>,
    <2.0013882, 0.0307137, 18.4905874>,
    <2.0021672, -0.1348962, 18.4905874>,
    <2.0013882, 0.0307137, 18.4393764>,
    <2.0017777, -0.0520913, 18.4905874>,
    <2.0021672, -0.1348962, 18.4649819>,
    <2.0017777, -0.0520913, 18.4393764>,
    <2.0013882, 0.0307137, 18.4649819>,
    <2.0017777, -0.0520913, 18.4649819>,
    <2.0006092, 0.1963236, 18.4905874>,
    <2.0009987, 0.1135186, 18.4393764>,
    <2.0006092, 0.1963236, 18.4649819>,
    <2.0009987, 0.1135186, 18.4905874>,
    <2.0009987, 0.1135186, 18.4649819>,
    <2.0013882, 0.0307137, 18.5417983>,
    <2.0006092, 0.1963236, 18.5161929>,
    <2.0009987, 0.1135186, 18.5417983>,
    <2.0013882, 0.0307137, 18.5161929>,
    <2.0009987, 0.1135186, 18.5161929>,
    <2.0017777, -0.0520913, 18.5417983>,
    <2.0021672, -0.1348962, 18.5161929>,
    <2.0017777, -0.0520913, 18.5161929>,
    <2.0015513, 0.0307548, 18.4393764>,
    <2.0017145, 0.0307959, 18.4393764>,
    <2.0016329, 0.0307754, 18.4393764>,
    <2.0021077, -0.0520840, 18.4393764>,
    <2.0019427, -0.0520877, 18.4393764>,
    <2.0020252, -0.0520859, 18.4393764>,
    <2.0013882, 0.0307137, 18.4393764>,
    <2.0017777, -0.0520913, 18.4393764>,
    <2.0014697, 0.0307342, 18.4393764>,
    <2.0018602, -0.0520895, 18.4393764>,
    <2.0009987, 0.1135186, 18.4393764>,
    <2.0011600, 0.1135972, 18.4393764>,
    <2.0010793, 0.1135579, 18.4393764>,
    <2.0013213, 0.1136759, 18.4393764>,
    <2.0012406, 0.1136366, 18.4393764>,
    <2.0017451, 0.0308036, 18.3784821>,
    <2.0025322, -0.1349704, 18.3784821>,
    <2.0017757, 0.0308113, 18.3175878>,
    <2.0021387, -0.0520834, 18.3784821>,
    <2.0025479, -0.1349735, 18.3480349>,
    <2.0021696, -0.0520827, 18.3175878>,
    <2.0017604, 0.0308075, 18.3480349>,
    <2.0021541, -0.0520830, 18.3480349>,
    <2.0009580, 0.1965776, 18.3784821>,
    <2.0013818, 0.1137054, 18.3175878>,
    <2.0009730, 0.1965885, 18.3480349>,
    <2.0013516, 0.1136906, 18.3784821>,
    <2.0013667, 0.1136980, 18.3480349>,
    <2.0017145, 0.0307959, 18.4393764>,
    <2.0009431, 0.1965667, 18.4089292>,
    <2.0013213, 0.1136759, 18.4393764>,
    <2.0017298, 0.0307998, 18.4089292>,
    <2.0013364, 0.1136833, 18.4089292>,
    <2.0021077, -0.0520840, 18.4393764>,
    <2.0025166, -0.1349672, 18.4089292>,
    <2.0021232, -0.0520837, 18.4089292>,
    <2.0024154, 0.0309726, 18.3135798>,
    <2.0030550, 0.0311338, 18.3095719>,
    <2.0027352, 0.0310532, 18.3115759>,
    <2.0034634, -0.0520543, 18.3095719>,
    <2.0028165, -0.0520685, 18.3135798>,
    <2.0031399, -0.0520614, 18.3115759>,
    <2.0017757, 0.0308113, 18.3175878>,
    <2.0021696, -0.0520827, 18.3175878>,
    <2.0020955, 0.0308920, 18.3155838>,
    <2.0024931, -0.0520756, 18.3155838>,
    <2.0013818, 0.1137054, 18.3175878>,
    <2.0020142, 0.1140136, 18.3135798>,
    <2.0016980, 0.1138595, 18.3155838>,
    <2.0026466, 0.1143219, 18.3095719>,
    <2.0023304, 0.1141678, 18.3115759>,
    <2.0030556, 0.0311339, 18.2344341>,
    <2.0038724, -0.1352425, 18.2344341>,
    <2.0030562, 0.0311341, 18.1592964>,
    <2.0034640, -0.0520543, 18.2344341>,
    <2.0038727, -0.1352426, 18.1968653>,
    <2.0034646, -0.0520543, 18.1592964>,
    <2.0030559, 0.0311340, 18.1968653>,
    <2.0034643, -0.0520543, 18.1968653>,
    <2.0022388, 0.1975104, 18.2344341>,
    <2.0026478, 0.1143225, 18.1592964>,
    <2.0022391, 0.1975106, 18.1968653>,
    <2.0026472, 0.1143222, 18.2344341>,
    <2.0026475, 0.1143223, 18.1968653>,
    <2.0030550, 0.0311338, 18.3095719>,
    <2.0022385, 0.1975102, 18.2720030>,
    <2.0026466, 0.1143219, 18.3095719>,
    <2.0030553, 0.0311339, 18.2720030>,
    <2.0026469, 0.1143220, 18.2720030>,
    <2.0034634, -0.0520543, 18.3095719>,
    <2.0038721, -0.1352425, 18.2720030>,
    <2.0034637, -0.0520543, 18.2720030>,
    <2.0031505, 0.0311579, 18.1573801>,
    <2.0032449, 0.0311816, 18.1554639>,
    <2.0031977, 0.0311697, 18.1564220>,
    <2.0036554, -0.0520501, 18.1554639>,
    <2.0035600, -0.0520522, 18.1573801>,
    <2.0036077, -0.0520512, 18.1564220>,
    <2.0030562, 0.0311341, 18.1592964>,
    <2.0034646, -0.0520543, 18.1592964>,
    <2.0031034, 0.0311460, 18.1583383>,
    <2.0035123, -0.0520532, 18.1583383>,
    <2.0026478, 0.1143225, 18.1592964>,
    <2.0027411, 0.1143679, 18.1573801>,
    <2.0026945, 0.1143452, 18.1583383>,
    <2.0028343, 0.1144134, 18.1554639>,
    <2.0027877, 0.1143906, 18.1564220>,
    <2.0034357, 0.0312297, 18.1389725>,
    <2.0042673, -0.1353227, 18.1386133>,
    <2.0035695, 0.0312634, 18.1258340>,
    <2.0038505, -0.0520468, 18.1388528>,
    <2.0043680, -0.1353432, 18.1301880>,
    <2.0039963, -0.0520483, 18.1251156>,
    <2.0035158, 0.0312499, 18.1316249>,
    <2.0039378, -0.0520477, 18.1311460>,
    <2.0026163, 0.1977853, 18.1386133>,
    <2.0031671, 0.1145813, 18.1251156>,
    <2.0027125, 0.1978554, 18.1301880>,
    <2.0030250, 0.1145072, 18.1388528>,
    <2.0031101, 0.1145516, 18.1311460>,
    <2.0032449, 0.0311816, 18.1554639>,
    <2.0025200, 0.1977152, 18.1470386>,
    <2.0028343, 0.1144134, 18.1554639>,
    <2.0033433, 0.0312064, 18.1470386>,
    <2.0029317, 0.1144608, 18.1470386>,
    <2.0036554, -0.0520501, 18.1554639>,
    <2.0041666, -0.1353023, 18.1470386>,
    <2.0037550, -0.0520479, 18.1470386>,
    <2.0035688, 0.0312633, 18.1205987>,
    <2.0035824, 0.0312667, 18.1224380>,
    <2.0039851, -0.0520438, 18.1204790>,
    <2.0040052, -0.0520462, 18.1219591>,
    <2.0035111, 0.0312487, 18.1187163>,
    <2.0039246, -0.0520442, 18.1187163>,
    <2.0035430, 0.0312568, 18.1194779>,
    <2.0039569, -0.0520435, 18.1194779>,
    <2.0030975, 0.1145417, 18.1187163>,
    <2.0031566, 0.1145714, 18.1204790>,
    <2.0031291, 0.1145570, 18.1194779>,
    <2.0031759, 0.1145837, 18.1219591>
  }
  normal_vectors {
    1158,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0005941, 0.9999662, 0.0082020>,
    <-0.0005941, 0.9999704, 0.0076758>,
    <-0.0005795, 0.9999701, 0.0077076>,
    <-0.0005795, 0.9999661, 0.0082176>,
    <-0.0005795, 0.9999617, 0.0087276>,
    <-0.0005941, 0.9999617, 0.0087283>,
    <-0.0005941, 0.9999617, 0.0087283>,
    <-0.0006097, 0.9999617, 0.0087289>,
    <-0.0006097, 0.9999663, 0.0081855>,
    <-0.0006097, 0.9999663, 0.0081855>,
    <-0.0006097, 0.9999706, 0.0076420>,
    <-0.0005941, 0.9999743, 0.0071496>,
    <-0.0005795, 0.9999739, 0.0071975>,
    <-0.0006097, 0.9999706, 0.0076420>,
    <-0.0006097, 0.9999746, 0.0070986>,
    <-0.0006097, 0.9999746, 0.0070986>,
    <-0.0006097, 0.9999783, 0.0065551>,
    <-0.0005941, 0.9999779, 0.0066234>,
    <-0.0005941, 0.9999779, 0.0066234>,
    <-0.0005795, 0.9999775, 0.0066875>,
    <-0.0005658, 0.9999736, 0.0072426>,
    <-0.0005658, 0.9999699, 0.0077374>,
    <-0.0005795, 0.9999775, 0.0066875>,
    <-0.0005658, 0.9999771, 0.0067477>,
    <-0.0005658, 0.9999771, 0.0067477>,
    <-0.0005529, 0.9999767, 0.0068045>,
    <-0.0005529, 0.9999733, 0.0072850>,
    <-0.0005529, 0.9999733, 0.0072850>,
    <-0.0005529, 0.9999697, 0.0077655>,
    <-0.0005658, 0.9999660, 0.0082322>,
    <-0.0005529, 0.9999697, 0.0077655>,
    <-0.0005529, 0.9999658, 0.0082460>,
    <-0.0005529, 0.9999658, 0.0082460>,
    <-0.0005528, 0.9999618, 0.0087265>,
    <-0.0005658, 0.9999618, 0.0087270>,
    <-0.0005658, 0.9999618, 0.0087270>,
    <-0.0005795, 0.9999617, 0.0087276>,
    <-0.2212575, 0.0002283, -0.9752154>,
    <-0.2202436, 0.0002273, -0.9754449>,
    <-0.2202508, 0.0002652, -0.9754432>,
    <-0.2212612, 0.0002664, -0.9752145>,
    <-0.2222806, 0.0002676, -0.9749827>,
    <-0.2222806, 0.0002294, -0.9749827>,
    <-0.2222806, 0.0002294, -0.9749827>,
    <-0.2222805, 0.0001908, -0.9749827>,
    <-0.2212538, 0.0001900, -0.9752162>,
    <-0.2212538, 0.0001900, -0.9752162>,
    <-0.2202363, 0.0001891, -0.9754465>,
    <-0.2192387, 0.0002262, -0.9756712>,
    <-0.2192494, 0.0002640, -0.9756688>,
    <-0.2202363, 0.0001891, -0.9754465>,
    <-0.2192279, 0.0001882, -0.9756737>,
    <-0.2192279, 0.0001882, -0.9756737>,
    <-0.2182285, 0.0001874, -0.9758977>,
    <-0.2182427, 0.0002252, -0.9758945>,
    <-0.2182427, 0.0002252, -0.9758945>,
    <-0.2182569, 0.0002628, -0.9758913>,
    <-0.2192601, 0.0003014, -0.9756664>,
    <-0.2202580, 0.0003028, -0.9754416>,
    <-0.2182569, 0.0002628, -0.9758913>,
    <-0.2182709, 0.0003001, -0.9758882>,
    <-0.2182709, 0.0003001, -0.9758882>,
    <-0.2182849, 0.0003371, -0.9758850>,
    <-0.2192707, 0.0003386, -0.9756640>,
    <-0.2192707, 0.0003386, -0.9756640>,
    <-0.2202652, 0.0003402, -0.9754400>,
    <-0.2212649, 0.0003042, -0.9752137>,
    <-0.2202652, 0.0003402, -0.9754400>,
    <-0.2212685, 0.0003417, -0.9752129>,
    <-0.2212685, 0.0003417, -0.9752129>,
    <-0.2222808, 0.0003433, -0.9749826>,
    <-0.2222807, 0.0003056, -0.9749827>,
    <-0.2222807, 0.0003056, -0.9749827>,
    <-0.2222806, 0.0002676, -0.9749827>,
    <0.3703333, -0.9287990, 0.0136272>,
    <0.3703351, -0.9288035, 0.0132634>,
    <0.3703266, -0.9288072, 0.0132415>,
    <0.3703249, -0.9288028, 0.0135941>,
    <0.3703231, -0.9287983, 0.0139467>,
    <0.3703314, -0.9287943, 0.0139910>,
    <0.3703314, -0.9287943, 0.0139910>,
    <0.3703403, -0.9287901, 0.0140381>,
    <0.3703422, -0.9287949, 0.0136625>,
    <0.3703422, -0.9287949, 0.0136625>,
    <0.3703441, -0.9287996, 0.0132868>,
    <0.3703368, -0.9288080, 0.0128997>,
    <0.3703283, -0.9288115, 0.0128889>,
    <0.3703441, -0.9287996, 0.0132868>,
    <0.3703459, -0.9288042, 0.0129111>,
    <0.3703459, -0.9288042, 0.0129111>,
    <0.3703477, -0.9288086, 0.0125354>,
    <0.3703385, -0.9288123, 0.0125359>,
    <0.3703385, -0.9288123, 0.0125359>,
    <0.3703300, -0.9288157, 0.0125363>,
    <0.3703203, -0.9288148, 0.0128788>,
    <0.3703187, -0.9288107, 0.0132209>,
    <0.3703300, -0.9288157, 0.0125363>,
    <0.3703219, -0.9288189, 0.0125368>,
    <0.3703219, -0.9288189, 0.0125368>,
    <0.3703144, -0.9288219, 0.0125372>,
    <0.3703128, -0.9288180, 0.0128693>,
    <0.3703128, -0.9288180, 0.0128693>,
    <0.3703112, -0.9288139, 0.0132015>,
    <0.3703170, -0.9288064, 0.0135630>,
    <0.3703112, -0.9288139, 0.0132015>,
    <0.3703096, -0.9288098, 0.0135337>,
    <0.3703096, -0.9288098, 0.0135337>,
    <0.3703079, -0.9288056, 0.0138658>,
    <0.3703152, -0.9288021, 0.0139051>,
    <0.3703152, -0.9288021, 0.0139051>,
    <0.3703231, -0.9287983, 0.0139467>,
    <0.0005282, -0.9999988, 0.0014301>,
    <0.0005282, -0.9999989, 0.0013517>,
    <0.0005061, -0.9999989, 0.0013600>,
    <0.0005061, -0.9999988, 0.0014341>,
    <0.0005061, -0.9999987, 0.0015083>,
    <0.0005282, -0.9999987, 0.0015084>,
    <0.0005282, -0.9999987, 0.0015084>,
    <0.0005529, -0.9999987, 0.0015086>,
    <0.0005529, -0.9999988, 0.0014255>,
    <0.0005529, -0.9999988, 0.0014255>,
    <0.0005529, -0.9999989, 0.0013425>,
    <0.0005282, -0.9999990, 0.0012734>,
    <0.0005061, -0.9999990, 0.0012859>,
    <0.0005529, -0.9999989, 0.0013425>,
    <0.0005529, -0.9999991, 0.0012594>,
    <0.0005529, -0.9999991, 0.0012594>,
    <0.0005529, -0.9999992, 0.0011763>,
    <0.0005282, -0.9999991, 0.0011951>,
    <0.0005282, -0.9999991, 0.0011951>,
    <0.0005061, -0.9999991, 0.0012118>,
    <0.0004863, -0.9999990, 0.0012971>,
    <0.0004863, -0.9999989, 0.0013674>,
    <0.0005061, -0.9999991, 0.0012118>,
    <0.0004863, -0.9999991, 0.0012268>,
    <0.0004863, -0.9999991, 0.0012268>,
    <0.0004684, -0.9999991, 0.0012403>,
    <0.0004684, -0.9999990, 0.0013072>,
    <0.0004684, -0.9999990, 0.0013072>,
    <0.0004684, -0.9999989, 0.0013742>,
    <0.0004863, -0.9999988, 0.0014378>,
    <0.0004684, -0.9999989, 0.0013742>,
    <0.0004684, -0.9999989, 0.0014411>,
    <0.0004684, -0.9999989, 0.0014411>,
    <0.0004684, -0.9999988, 0.0015080>,
    <0.0004863, -0.9999987, 0.0015081>,
    <0.0004863, -0.9999987, 0.0015081>,
    <0.0005061, -0.9999987, 0.0015083>,
    <0.7954427, -0.0015067, -0.6060269>,
    <0.7940541, -0.0015041, -0.6078452>,
    <0.7940741, -0.0017779, -0.6078184>,
    <0.7954526, -0.0017810, -0.6060132>,
    <0.7968318, -0.0017841, -0.6041985>,
    <0.7968320, -0.0015094, -0.6041991>,
    <0.7968320, -0.0015094, -0.6041991>,
    <0.7968321, -0.0012306, -0.6041996>,
    <0.7954326, -0.0012284, -0.6060408>,
    <0.7954326, -0.0012284, -0.6060408>,
    <0.7940338, -0.0012263, -0.6078724>,
    <0.7926662, -0.0015015, -0.6096540>,
    <0.7926962, -0.0017749, -0.6096143>,
    <0.7940338, -0.0012263, -0.6078724>,
    <0.7926357, -0.0012241, -0.6096942>,
    <0.7926357, -0.0012241, -0.6096942>,
    <0.7912384, -0.0012219, -0.6115065>,
    <0.7912791, -0.0014988, -0.6114533>,
    <0.7912791, -0.0014988, -0.6114533>,
    <0.7913191, -0.0017718, -0.6114008>,
    <0.7927257, -0.0020443, -0.6095751>,
    <0.7940937, -0.0020479, -0.6077919>,
    <0.7913191, -0.0017718, -0.6114008>,
    <0.7913585, -0.0020408, -0.6113490>,
    <0.7913585, -0.0020408, -0.6113490>,
    <0.7913972, -0.0023060, -0.6112979>,
    <0.7927547, -0.0023100, -0.6095364>,
    <0.7927547, -0.0023100, -0.6095364>,
    <0.7941129, -0.0023139, -0.6077658>,
    <0.7954623, -0.0020514, -0.6059996>,
    <0.7941129, -0.0023139, -0.6077658>,
    <0.7954718, -0.0023179, -0.6059861>,
    <0.7954718, -0.0023179, -0.6059861>,
    <0.7968314, -0.0023219, -0.6041973>,
    <0.7968316, -0.0020549, -0.6041979>,
    <0.7968316, -0.0020549, -0.6041979>,
    <0.7968318, -0.0017841, -0.6041985>,
    <-0.3703280, 0.9288981, 0.0023301>,
    <-0.3703280, 0.9288982, 0.0022759>,
    <-0.3703151, 0.9289034, 0.0022702>,
    <-0.3703151, 0.9289033, 0.0023215>,
    <-0.3703151, 0.9289032, 0.0023727>,
    <-0.3703280, 0.9288980, 0.0023843>,
    <-0.3703280, 0.9288980, 0.0023843>,
    <-0.3703424, 0.9288922, 0.0023972>,
    <-0.3703425, 0.9288923, 0.0023398>,
    <-0.3703425, 0.9288923, 0.0023398>,
    <-0.3703425, 0.9288925, 0.0022823>,
    <-0.3703281, 0.9288984, 0.0022218>,
    <-0.3703152, 0.9289035, 0.0022190>,
    <-0.3703425, 0.9288925, 0.0022823>,
    <-0.3703426, 0.9288926, 0.0022249>,
    <-0.3703426, 0.9288926, 0.0022249>,
    <-0.3703426, 0.9288927, 0.0021675>,
    <-0.3703281, 0.9288985, 0.0021676>,
    <-0.3703281, 0.9288985, 0.0021676>,
    <-0.3703152, 0.9289036, 0.0021677>,
    <-0.3703036, 0.9289081, 0.0022164>,
    <-0.3703036, 0.9289080, 0.0022651>,
    <-0.3703152, 0.9289036, 0.0021677>,
    <-0.3703036, 0.9289082, 0.0021678>,
    <-0.3703036, 0.9289082, 0.0021678>,
    <-0.3702932, 0.9289124, 0.0021679>,
    <-0.3702931, 0.9289123, 0.0022142>,
    <-0.3702931, 0.9289123, 0.0022142>,
    <-0.3702931, 0.9289122, 0.0022604>,
    <-0.3703035, 0.9289079, 0.0023137>,
    <-0.3702931, 0.9289122, 0.0022604>,
    <-0.3702931, 0.9289121, 0.0023067>,
    <-0.3702931, 0.9289121, 0.0023067>,
    <-0.3702930, 0.9289120, 0.0023530>,
    <-0.3703035, 0.9289078, 0.0023623>,
    <-0.3703035, 0.9289078, 0.0023623>,
    <-0.3703151, 0.9289032, 0.0023727>,
    <0.0004568, -0.9999518, 0.0098056>,
    <0.0004568, -0.9999560, 0.0093662>,
    <0.0004459, -0.9999558, 0.0093940>,
    <0.0004459, -0.9999517, 0.0098193>,
    <0.0004459, -0.9999474, 0.0102445>,
    <0.0004568, -0.9999474, 0.0102451>,
    <0.0004568, -0.9999474, 0.0102451>,
    <0.0004684, -0.9999474, 0.0102456>,
    <0.0004684, -0.9999520, 0.0097911>,
    <0.0004684, -0.9999520, 0.0097911>,
    <0.0004684, -0.9999563, 0.0093365>,
    <0.0004568, -0.9999601, 0.0089268>,
    <0.0004459, -0.9999597, 0.0089688>,
    <0.0004684, -0.9999563, 0.0093365>,
    <0.0004684, -0.9999604, 0.0088820>,
    <0.0004684, -0.9999604, 0.0088820>,
    <0.0004684, -0.9999644, 0.0084274>,
    <0.0004568, -0.9999639, 0.0084874>,
    <0.0004568, -0.9999639, 0.0084874>,
    <0.0004459, -0.9999634, 0.0085435>,
    <0.0004357, -0.9999593, 0.0090081>,
    <0.0004357, -0.9999555, 0.0094201>,
    <0.0004459, -0.9999634, 0.0085435>,
    <0.0004357, -0.9999630, 0.0085961>,
    <0.0004357, -0.9999630, 0.0085961>,
    <0.0004261, -0.9999625, 0.0086456>,
    <0.0004261, -0.9999590, 0.0090451>,
    <0.0004261, -0.9999590, 0.0090451>,
    <0.0004261, -0.9999553, 0.0094445>,
    <0.0004357, -0.9999516, 0.0098320>,
    <0.0004261, -0.9999553, 0.0094445>,
    <0.0004261, -0.9999515, 0.0098440>,
    <0.0004261, -0.9999515, 0.0098440>,
    <0.0004261, -0.9999474, 0.0102435>,
    <0.0004357, -0.9999474, 0.0102440>,
    <0.0004357, -0.9999474, 0.0102440>,
    <0.0004459, -0.9999474, 0.0102445>,
    <0.1896912, -0.0005972, -0.9818436>,
    <0.1888483, -0.0005946, -0.9820061>,
    <0.1888567, -0.0006384, -0.9820044>,
    <0.1896955, -0.0006413, -0.9818428>,
    <0.1905416, -0.0006441, -0.9816789>,
    <0.1905415, -0.0005999, -0.9816790>,
    <0.1905415, -0.0005999, -0.9816790>,
    <0.1905414, -0.0005552, -0.9816790>,
    <0.1896868, -0.0005527, -0.9818445>,
    <0.1896868, -0.0005527, -0.9818445>,
    <0.1888397, -0.0005503, -0.9820078>,
    <0.1880126, -0.0005919, -0.9821664>,
    <0.1880252, -0.0006356, -0.9821640>,
    <0.1888397, -0.0005503, -0.9820078>,
    <0.1879999, -0.0005478, -0.9821689>,
    <0.1879999, -0.0005478, -0.9821689>,
    <0.1871675, -0.0005454, -0.9823279>,
    <0.1871843, -0.0005893, -0.9823246>,
    <0.1871843, -0.0005893, -0.9823246>,
    <0.1872009, -0.0006328, -0.9823215>,
    <0.1880377, -0.0006789, -0.9821616>,
    <0.1888651, -0.0006819, -0.9820028>,
    <0.1872009, -0.0006328, -0.9823215>,
    <0.1872173, -0.0006759, -0.9823183>,
    <0.1872173, -0.0006759, -0.9823183>,
    <0.1872336, -0.0007186, -0.9823152>,
    <0.1880500, -0.0007217, -0.9821592>,
    <0.1880500, -0.0007217, -0.9821592>,
    <0.1888735, -0.0007249, -0.9820012>,
    <0.1896998, -0.0006849, -0.9818419>,
    <0.1888735, -0.0007249, -0.9820012>,
    <0.1897040, -0.0007281, -0.9818411>,
    <0.1897040, -0.0007281, -0.9818411>,
    <0.1905418, -0.0007313, -0.9816788>,
    <0.1905417, -0.0006879, -0.9816789>,
    <0.1905417, -0.0006879, -0.9816789>,
    <0.1905416, -0.0006441, -0.9816789>,
    <-0.3702419, 0.9288037, 0.0156404>,
    <-0.3702437, 0.9288081, 0.0153366>,
    <-0.3702374, 0.9288109, 0.0153174>,
    <-0.3702357, 0.9288066, 0.0156114>,
    <-0.3702340, 0.9288023, 0.0159054>,
    <-0.3702402, 0.9287992, 0.0159441>,
    <-0.3702402, 0.9287992, 0.0159441>,
    <-0.3702467, 0.9287959, 0.0159856>,
    <-0.3702486, 0.9288005, 0.0156714>,
    <-0.3702486, 0.9288005, 0.0156714>,
    <-0.3702504, 0.9288050, 0.0153571>,
    <-0.3702454, 0.9288123, 0.0150328>,
    <-0.3702391, 0.9288150, 0.0150234>,
    <-0.3702504, 0.9288050, 0.0153571>,
    <-0.3702522, 0.9288095, 0.0150429>,
    <-0.3702522, 0.9288095, 0.0150429>,
    <-0.3702539, 0.9288138, 0.0147287>,
    <-0.3702471, 0.9288165, 0.0147291>,
    <-0.3702471, 0.9288165, 0.0147291>,
    <-0.3702407, 0.9288191, 0.0147295>,
    <-0.3702331, 0.9288175, 0.0150146>,
    <-0.3702315, 0.9288135, 0.0152994>,
    <-0.3702407, 0.9288191, 0.0147295>,
    <-0.3702347, 0.9288215, 0.0147298>,
    <-0.3702347, 0.9288215, 0.0147298>,
    <-0.3702291, 0.9288237, 0.0147302>,
    <-0.3702276, 0.9288199, 0.0150064>,
    <-0.3702276, 0.9288199, 0.0150064>,
    <-0.3702260, 0.9288160, 0.0152825>,
    <-0.3702299, 0.9288094, 0.0155842>,
    <-0.3702260, 0.9288160, 0.0152825>,
    <-0.3702244, 0.9288120, 0.0155587>,
    <-0.3702244, 0.9288120, 0.0155587>,
    <-0.3702228, 0.9288080, 0.0158349>,
    <-0.3702283, 0.9288053, 0.0158690>,
    <-0.3702283, 0.9288053, 0.0158690>,
    <-0.3702340, 0.9288023, 0.0159054>,
    <0.0004328, -0.9999999, 0.0000263>,
    <0.0004297, -0.9999999, 0.0000444>,
    <0.0004572, -0.9999999, 0.0001852>,
    <0.0004819, -0.9999999, 0.0001033>,
    <0.0004871, -0.9999999, 0.0000017>,
    <0.0004338, -0.9999999, 0.0000017>,
    <0.0004338, -0.9999999, 0.0000017>,
    <0.0004261, -0.9999999, 0.0000017>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004264, -0.9999999, 0.0000506>,
    <0.0004300, -0.9999999, 0.0002171>,
    <0.0004261, -0.9999999, 0.0000016>,
    <0.0004261, -0.9999999, 0.0000015>,
    <0.0004261, -0.9999999, 0.0000015>,
    <0.0004261, -0.9999999, 0.0000014>,
    <0.0004254, -0.9999999, 0.0000496>,
    <0.0004254, -0.9999999, 0.0000496>,
    <0.0004208, -0.9999999, 0.0002141>,
    <0.0004392, -0.9999997, 0.0005874>,
    <0.0005266, -0.9999997, 0.0005300>,
    <0.0004208, -0.9999999, 0.0002141>,
    <0.0004092, -0.9999997, 0.0005804>,
    <0.0004092, -0.9999997, 0.0005804>,
    <0.0003889, -0.9999989, 0.0014524>,
    <0.0004419, -0.9999988, 0.0014766>,
    <0.0006011, -0.9999987, 0.0014789>,
    <0.0006366, -0.9999997, 0.0003445>,
    <0.0009775, -0.9999984, 0.0015046>,
    <0.0012929, -0.9999977, 0.0016908>,
    <0.0006563, -0.9999998, 0.0000017>,
    <0.0006563, -0.9999998, 0.0000017>,
    <0.0004871, -0.9999999, 0.0000017>,
    <0.9995524, -0.0038537, -0.0296661>,
    <0.9995484, -0.0038537, -0.0298012>,
    <0.9918574, -0.0039361, -0.1272924>,
    <0.9919300, -0.0039364, -0.1267254>,
    <0.9920023, -0.0039367, -0.1261582>,
    <0.9995564, -0.0038537, -0.0295309>,
    <0.9995564, -0.0038537, -0.0295309>,
    <0.9999923, -0.0038380, -0.0008512>,
    <0.9999923, -0.0038380, -0.0008551>,
    <0.9999923, -0.0038380, -0.0008551>,
    <0.9999923, -0.0038380, -0.0008590>,
    <0.9995444, -0.0038537, -0.0299364>,
    <0.9917845, -0.0039358, -0.1278594>,
    <0.9999923, -0.0038380, -0.0008590>,
    <0.9999923, -0.0038380, -0.0008629>,
    <0.9999923, -0.0038380, -0.0008629>,
    <0.9999923, -0.0038380, -0.0008668>,
    <0.9995403, -0.0038537, -0.0300715>,
    <0.9995403, -0.0038537, -0.0300715>,
    <0.9917113, -0.0039355, -0.1284262>,
    <0.9447195, -0.0040337, -0.3278547>,
    <0.9451736, -0.0040357, -0.3265435>,
    <0.9917113, -0.0039355, -0.1284262>,
    <0.9442641, -0.0040318, -0.3291641>,
    <0.9442641, -0.0040318, -0.3291641>,
    <0.7574631, -0.0036692, -0.6528676>,
    <0.7588853, -0.0036761, -0.6512139>,
    <0.7603092, -0.0036830, -0.6495508>,
    <0.9456262, -0.0040376, -0.3252304>,
    <0.7617348, -0.0036899, -0.6478784>,
    <0.7631621, -0.0036968, -0.6461965>,
    <0.9460774, -0.0040395, -0.3239154>,
    <0.9460774, -0.0040395, -0.3239154>,
    <0.9920023, -0.0039367, -0.1261582>,
    <-0.3702675, 0.9289252, 0.0000874>,
    <-0.3702636, 0.9289267, 0.0000735>,
    <-0.3702213, 0.9289436, 0.0003067>,
    <-0.3702547, 0.9289302, 0.0003739>,
    <-0.3702661, 0.9289256, 0.0003905>,
    <-0.3702688, 0.9289246, 0.0000908>,
    <-0.3702688, 0.9289246, 0.0000908>,
    <-0.3702693, 0.9289245, 0.0000026>,
    <-0.3702693, 0.9289245, 0.0000026>,
    <-0.3702693, 0.9289245, 0.0000026>,
    <-0.3702693, 0.9289245, 0.0000025>,
    <-0.3702598, 0.9289283, 0.0000426>,
    <-0.3701912, 0.9289556, 0.0001679>,
    <-0.3702693, 0.9289245, 0.0000025>,
    <-0.3702693, 0.9289245, 0.0000025>,
    <-0.3702693, 0.9289245, 0.0000025>,
    <-0.3702693, 0.9289245, 0.0000024>,
    <-0.3702586, 0.9289287, 0.0000024>,
    <-0.3702586, 0.9289287, 0.0000024>,
    <-0.3701855, 0.9289579, 0.0000024>,
    <-0.3699782, 0.9290403, 0.0005423>,
    <-0.3701119, 0.9289868, 0.0008648>,
    <-0.3701855, 0.9289579, 0.0000024>,
    <-0.3699584, 0.9290483, 0.0000024>,
    <-0.3699584, 0.9290483, 0.0000024>,
    <-0.3691451, 0.9293686, 0.0024326>,
    <-0.3695121, 0.9292231, 0.0022834>,
    <-0.3699752, 0.9290386, 0.0023670>,
    <-0.3702209, 0.9289432, 0.0010040>,
    <-0.3701769, 0.9289579, 0.0024893>,
    <-0.3702463, 0.9289300, 0.0025810>,
    <-0.3702591, 0.9289279, 0.0010484>,
    <-0.3702591, 0.9289279, 0.0010484>,
    <-0.3702661, 0.9289256, 0.0003905>,
    <0.0009820, -0.9999841, 0.0055500>,
    <0.0005787, -0.9999933, 0.0036053>,
    <0.0003522, -0.9999833, 0.0057696>,
    <0.0003820, -0.9999521, 0.0097787>,
    <0.0005080, -0.9994483, 0.0332100>,
    <0.0042098, -0.9994193, 0.0338132>,
    <0.0042098, -0.9994193, 0.0338132>,
    <0.0012929, -0.9999977, 0.0016908>,
    <0.0004125, -0.9999948, 0.0032130>,
    <0.0003397, -0.9999888, 0.0047174>,
    <0.0003889, -0.9999989, 0.0014524>,
    <0.0003623, -0.9999951, 0.0031167>,
    <0.0003623, -0.9999951, 0.0031167>,
    <0.0003364, -0.9999899, 0.0044723>,
    <0.0002761, -0.9999919, 0.0040074>,
    <0.0001403, -0.9999887, 0.0047436>,
    <0.0003364, -0.9999899, 0.0044723>,
    <0.0003153, -0.9999928, 0.0037768>,
    <0.0003153, -0.9999928, 0.0037768>,
    <0.0003004, -0.9999981, 0.0019498>,
    <0.0002642, -0.9999979, 0.0020286>,
    <0.0001522, -0.9999977, 0.0021282>,
    <-0.0001919, -0.9999731, 0.0073266>,
    <-0.0001143, -0.9999976, 0.0022072>,
    <-0.0002937, -0.9999977, 0.0021417>,
    <-0.0020821, -0.9994602, 0.0327876>,
    <-0.0020821, -0.9994602, 0.0327876>,
    <0.0005080, -0.9994483, 0.0332100>,
    <0.4862306, -0.0027790, -0.8738261>,
    <0.4846110, -0.0027697, -0.8747254>,
    <0.3648940, -0.0024544, -0.9310458>,
    <0.3662448, -0.0024635, -0.9305153>,
    <0.3676048, -0.0024726, -0.9299788>,
    <0.4878594, -0.0027883, -0.8729178>,
    <0.4878594, -0.0027883, -0.8729178>,
    <0.7631621, -0.0036968, -0.6461965>,
    <0.4830005, -0.0027605, -0.8756157>,
    <0.3635523, -0.0024454, -0.9315706>,
    <0.7574631, -0.0036692, -0.6528676>,
    <0.4813990, -0.0027514, -0.8764972>,
    <0.4813990, -0.0027514, -0.8764972>,
    <0.3622198, -0.0024364, -0.9320895>,
    <0.4237106, -0.0032623, -0.9057917>,
    <0.4251552, -0.0032734, -0.9051146>,
    <0.3622198, -0.0024364, -0.9320895>,
    <0.4222747, -0.0032512, -0.9064621>,
    <0.4222747, -0.0032512, -0.9064621>,
    <0.6730900, -0.0057116, -0.7395385>,
    <0.6745826, -0.0057242, -0.7381771>,
    <0.6760791, -0.0057369, -0.7368067>,
    <0.4266085, -0.0032846, -0.9044304>,
    <0.6775795, -0.0057496, -0.7354271>,
    <0.6790837, -0.0057624, -0.7340383>,
    <0.4280708, -0.0032958, -0.9037392>,
    <0.4280708, -0.0032958, -0.9037392>,
    <0.3676048, -0.0024726, -0.9299788>,
    <-0.3701597, 0.9289529, 0.0053235>,
    <-0.3699458, 0.9290360, 0.0056797>,
    <-0.3701810, 0.9289162, 0.0089828>,
    <-0.3702013, 0.9289197, 0.0076901>,
    <-0.3702060, 0.9289184, 0.0076194>,
    <-0.3702265, 0.9289257, 0.0054212>,
    <-0.3702265, 0.9289257, 0.0054212>,
    <-0.3702463, 0.9289300, 0.0025810>,
    <-0.3694410, 0.9292170, 0.0083123>,
    <-0.3701199, 0.9288696, 0.0145759>,
    <-0.3691451, 0.9293686, 0.0024326>,
    <-0.3651007, 0.9296955, 0.0486595>,
    <-0.3651007, 0.9296955, 0.0486595>,
    <-0.3695850, 0.9279685, 0.0477638>,
    <-0.3708155, 0.9286428, 0.0108815>,
    <-0.3704183, 0.9288362, 0.0073277>,
    <-0.3695850, 0.9279685, 0.0477638>,
    <-0.3727090, 0.9267502, 0.0471382>,
    <-0.3727090, 0.9267502, 0.0471382>,
    <-0.3709178, 0.9286606, 0.0030824>,
    <-0.3707076, 0.9287438, 0.0032850>,
    <-0.3703806, 0.9288743, 0.0032783>,
    <-0.3702480, 0.9289105, 0.0064505>,
    <-0.3702402, 0.9289304, 0.0032388>,
    <-0.3701938, 0.9289489, 0.0032288>,
    <-0.3701970, 0.9289317, 0.0063278>,
    <-0.3701970, 0.9289317, 0.0063278>,
    <-0.3702060, 0.9289184, 0.0076194>,
    <0.0001552, -0.9999998, 0.0005685>,
    <0.0002210, -0.9999996, 0.0008105>,
    <0.0002669, -0.9999999, 0.0003406>,
    <0.0002531, -0.9999999, 0.0002361>,
    <0.0002504, -1.0000000, 0.0001045>,
    <0.0001454, -1.0000000, 0.0001045>,
    <0.0001454, -1.0000000, 0.0001045>,
    <-0.0002937, -0.9999977, 0.0021417>,
    <0.0002737, -0.9999996, 0.0008673>,
    <0.0002820, -0.9999999, 0.0003799>,
    <0.0003004, -0.9999981, 0.0019498>,
    <0.0002917, -0.9999996, 0.0008532>,
    <0.0002917, -0.9999996, 0.0008532>,
    <0.0002871, -0.9999999, 0.0003774>,
    <0.0002844, -0.9999999, 0.0001621>,
    <0.0002826, -0.9999999, 0.0001554>,
    <0.0002871, -0.9999999, 0.0003774>,
    <0.0002849, -0.9999999, 0.0001599>,
    <0.0002849, -0.9999999, 0.0001599>,
    <0.0002839, -1.0000000, 0.0000958>,
    <0.0002839, -1.0000000, 0.0000980>,
    <0.0002839, -1.0000000, 0.0000980>,
    <0.0002839, -1.0000000, 0.0001001>,
    <0.0002809, -1.0000000, 0.0001341>,
    <0.0002839, -1.0000000, 0.0001001>,
    <0.0002839, -1.0000000, 0.0001023>,
    <0.0002839, -1.0000000, 0.0001023>,
    <0.0002839, -1.0000000, 0.0001045>,
    <0.0002804, -1.0000000, 0.0001045>,
    <0.0002804, -1.0000000, 0.0001045>,
    <0.0002504, -1.0000000, 0.0001045>,
    <0.9040796, -0.0081306, -0.4272869>,
    <0.9034106, -0.0081246, -0.4286994>,
    <0.9787319, -0.0090796, -0.2049426>,
    <0.9788962, -0.0090811, -0.2041561>,
    <0.9790600, -0.0090826, -0.2033693>,
    <0.9047472, -0.0081366, -0.4258711>,
    <0.9047472, -0.0081366, -0.4258711>,
    <0.6790837, -0.0057624, -0.7340383>,
    <0.9027405, -0.0081186, -0.4301089>,
    <0.9785670, -0.0090780, -0.2057286>,
    <0.6730900, -0.0057116, -0.7395385>,
    <0.9020692, -0.0081125, -0.4315152>,
    <0.9020692, -0.0081125, -0.4315152>,
    <0.9784015, -0.0090765, -0.2065142>,
    <0.9960237, -0.0093787, -0.0885931>,
    <0.9960548, -0.0093790, -0.0882437>,
    <0.9784015, -0.0090765, -0.2065142>,
    <0.9959926, -0.0093784, -0.0889424>,
    <0.9959926, -0.0093784, -0.0889424>,
    <0.9985298, -0.0094705, -0.0533727>,
    <0.9985410, -0.0094706, -0.0531623>,
    <0.9985410, -0.0094706, -0.0531623>,
    <0.9985521, -0.0094707, -0.0529520>,
    <0.9960857, -0.0093793, -0.0878942>,
    <0.9985521, -0.0094707, -0.0529520>,
    <0.9985633, -0.0094708, -0.0527416>,
    <0.9985633, -0.0094708, -0.0527416>,
    <0.9985744, -0.0094709, -0.0525312>,
    <0.9961164, -0.0093796, -0.0875448>,
    <0.9961164, -0.0093796, -0.0875448>,
    <0.9790600, -0.0090826, -0.2033693>,
    <-0.3702129, 0.9289459, 0.0013795>,
    <-0.3702782, 0.9289201, 0.0012519>,
    <-0.3702128, 0.9289468, 0.0005271>,
    <-0.3701942, 0.9289542, 0.0006031>,
    <-0.3701878, 0.9289567, 0.0006186>,
    <-0.3701902, 0.9289549, 0.0014032>,
    <-0.3701902, 0.9289549, 0.0014032>,
    <-0.3701938, 0.9289489, 0.0032288>,
    <-0.3703585, 0.9288885, 0.0008573>,
    <-0.3702295, 0.9289402, 0.0003574>,
    <-0.3709178, 0.9286606, 0.0030824>,
    <-0.3703689, 0.9288847, 0.0001504>,
    <-0.3703689, 0.9288847, 0.0001504>,
    <-0.3702327, 0.9289390, 0.0001504>,
    <-0.3701915, 0.9289554, 0.0002007>,
    <-0.3701895, 0.9289562, 0.0002394>,
    <-0.3702327, 0.9289390, 0.0001504>,
    <-0.3701922, 0.9289552, 0.0001505>,
    <-0.3701922, 0.9289552, 0.0001505>,
    <-0.3701860, 0.9289576, 0.0001505>,
    <-0.3701860, 0.9289576, 0.0001520>,
    <-0.3701860, 0.9289576, 0.0001520>,
    <-0.3701860, 0.9289576, 0.0001535>,
    <-0.3701873, 0.9289571, 0.0002569>,
    <-0.3701860, 0.9289576, 0.0001535>,
    <-0.3701860, 0.9289576, 0.0001550>,
    <-0.3701860, 0.9289576, 0.0001550>,
    <-0.3701860, 0.9289576, 0.0001565>,
    <-0.3701866, 0.9289574, 0.0002616>,
    <-0.3701866, 0.9289574, 0.0002616>,
    <-0.3701878, 0.9289567, 0.0006186>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, -0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.0002672, -1.0000000, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, -0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <0.9999433, -0.0106524, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, -0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <-0.3701762, 0.9289615, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, -0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.9999889, 0.0047038, 0.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.9999886, 0.0047498, 0.0005083>,
    <0.9999886, 0.0047498, 0.0005032>,
    <0.9999886, 0.0047479, 0.0005032>,
    <0.9999886, 0.0047479, 0.0005083>,
    <0.9999886, 0.0047479, 0.0005135>,
    <0.9999886, 0.0047498, 0.0005135>,
    <0.9999886, 0.0047498, 0.0005135>,
    <0.9999886, 0.0047517, 0.0005135>,
    <0.9999886, 0.0047517, 0.0005083>,
    <0.9999886, 0.0047517, 0.0005083>,
    <0.9999886, 0.0047517, 0.0005032>,
    <0.9999886, 0.0047498, 0.0004980>,
    <0.9999886, 0.0047479, 0.0004980>,
    <0.9999886, 0.0047517, 0.0005032>,
    <0.9999886, 0.0047517, 0.0004980>,
    <0.9999886, 0.0047517, 0.0004980>,
    <0.9999886, 0.0047517, 0.0004929>,
    <0.9999886, 0.0047498, 0.0004929>,
    <0.9999886, 0.0047498, 0.0004929>,
    <0.9999886, 0.0047479, 0.0004929>,
    <0.9999886, 0.0047460, 0.0004980>,
    <0.9999886, 0.0047460, 0.0005032>,
    <0.9999886, 0.0047479, 0.0004929>,
    <0.9999886, 0.0047460, 0.0004929>,
    <0.9999886, 0.0047460, 0.0004929>,
    <0.9999886, 0.0047441, 0.0004929>,
    <0.9999886, 0.0047441, 0.0004980>,
    <0.9999886, 0.0047441, 0.0004980>,
    <0.9999886, 0.0047441, 0.0005032>,
    <0.9999886, 0.0047460, 0.0005083>,
    <0.9999886, 0.0047441, 0.0005032>,
    <0.9999886, 0.0047441, 0.0005083>,
    <0.9999886, 0.0047441, 0.0005083>,
    <0.9999886, 0.0047441, 0.0005135>,
    <0.9999886, 0.0047460, 0.0005135>,
    <0.9999886, 0.0047460, 0.0005135>,
    <0.9999886, 0.0047479, 0.0005135>,
    <-0.9872098, -0.0048076, -0.1593540>,
    <-0.9872100, -0.0047688, -0.1593539>,
    <-0.9874620, -0.0047700, -0.1577846>,
    <-0.9874616, -0.0048088, -0.1577861>,
    <-0.9874612, -0.0048476, -0.1577876>,
    <-0.9872096, -0.0048463, -0.1593541>,
    <-0.9872096, -0.0048463, -0.1593541>,
    <-0.9869556, -0.0048451, -0.1609195>,
    <-0.9869556, -0.0048063, -0.1609208>,
    <-0.9869556, -0.0048063, -0.1609208>,
    <-0.9869556, -0.0047675, -0.1609220>,
    <-0.9872102, -0.0047299, -0.1593538>,
    <-0.9874625, -0.0047311, -0.1577831>,
    <-0.9869556, -0.0047675, -0.1609220>,
    <-0.9869556, -0.0047287, -0.1609233>,
    <-0.9869556, -0.0047287, -0.1609233>,
    <-0.9869556, -0.0046897, -0.1609246>,
    <-0.9872104, -0.0046910, -0.1593537>,
    <-0.9872104, -0.0046910, -0.1593537>,
    <-0.9874629, -0.0046922, -0.1577816>,
    <-0.9877123, -0.0047323, -0.1562112>,
    <-0.9877117, -0.0047712, -0.1562141>,
    <-0.9874629, -0.0046922, -0.1577816>,
    <-0.9877130, -0.0046933, -0.1562083>,
    <-0.9877130, -0.0046933, -0.1562083>,
    <-0.9879607, -0.0046945, -0.1546338>,
    <-0.9879599, -0.0047335, -0.1546381>,
    <-0.9879599, -0.0047335, -0.1546381>,
    <-0.9879590, -0.0047724, -0.1546423>,
    <-0.9877111, -0.0048100, -0.1562169>,
    <-0.9879590, -0.0047724, -0.1546423>,
    <-0.9879581, -0.0048112, -0.1546466>,
    <-0.9879581, -0.0048112, -0.1546466>,
    <-0.9879573, -0.0048500, -0.1546509>,
    <-0.9877104, -0.0048488, -0.1562198>,
    <-0.9877104, -0.0048488, -0.1562198>,
    <-0.9874612, -0.0048476, -0.1577876>,
    <0.9999879, 0.0049092, 0.0000082>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000082>,
    <0.9999880, 0.0049091, 0.0000083>,
    <0.9999879, 0.0049092, 0.0000083>,
    <0.9999879, 0.0049092, 0.0000083>,
    <0.9999879, 0.0049092, 0.0000083>,
    <0.9999879, 0.0049092, 0.0000082>,
    <0.9999879, 0.0049092, 0.0000082>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999879, 0.0049092, 0.0000081>,
    <0.9999879, 0.0049092, 0.0000080>,
    <0.9999879, 0.0049092, 0.0000080>,
    <0.9999879, 0.0049092, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000080>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000082>,
    <0.9999880, 0.0049091, 0.0000081>,
    <0.9999880, 0.0049091, 0.0000082>,
    <0.9999880, 0.0049091, 0.0000082>,
    <0.9999880, 0.0049091, 0.0000083>,
    <0.9999880, 0.0049091, 0.0000083>,
    <0.9999880, 0.0049091, 0.0000083>,
    <0.9999880, 0.0049091, 0.0000083>,
    <-0.9987510, -0.0049204, -0.0497222>,
    <-0.9987510, -0.0049147, -0.0497222>,
    <-0.9987758, -0.0049148, -0.0492222>,
    <-0.9987757, -0.0049206, -0.0492223>,
    <-0.9987757, -0.0049263, -0.0492224>,
    <-0.9987509, -0.0049262, -0.0497222>,
    <-0.9987509, -0.0049262, -0.0497222>,
    <-0.9987259, -0.0049261, -0.0502221>,
    <-0.9987260, -0.0049203, -0.0502221>,
    <-0.9987260, -0.0049203, -0.0502221>,
    <-0.9987260, -0.0049146, -0.0502222>,
    <-0.9987510, -0.0049089, -0.0497222>,
    <-0.9987758, -0.0049090, -0.0492222>,
    <-0.9987260, -0.0049146, -0.0502222>,
    <-0.9987260, -0.0049088, -0.0502223>,
    <-0.9987260, -0.0049088, -0.0502223>,
    <-0.9987260, -0.0049030, -0.0502223>,
    <-0.9987510, -0.0049031, -0.0497222>,
    <-0.9987510, -0.0049031, -0.0497222>,
    <-0.9987758, -0.0049033, -0.0492221>,
    <-0.9988003, -0.0049091, -0.0487221>,
    <-0.9988003, -0.0049149, -0.0487222>,
    <-0.9987758, -0.0049033, -0.0492221>,
    <-0.9988003, -0.0049034, -0.0487219>,
    <-0.9988003, -0.0049034, -0.0487219>,
    <-0.9988246, -0.0049035, -0.0482217>,
    <-0.9988246, -0.0049093, -0.0482219>,
    <-0.9988246, -0.0049093, -0.0482219>,
    <-0.9988245, -0.0049150, -0.0482221>,
    <-0.9988002, -0.0049207, -0.0487224>,
    <-0.9988245, -0.0049150, -0.0482221>,
    <-0.9988245, -0.0049208, -0.0482224>,
    <-0.9988245, -0.0049208, -0.0482224>,
    <-0.9988245, -0.0049266, -0.0482226>,
    <-0.9988002, -0.0049265, -0.0487225>,
    <-0.9988002, -0.0049265, -0.0487225>,
    <-0.9987757, -0.0049263, -0.0492224>,
    <0.9999289, 0.0050315, 0.0108120>,
    <0.9999346, 0.0049675, 0.0102967>,
    <0.9999243, 0.0049561, 0.0112634>,
    <0.9999211, 0.0049719, 0.0115332>,
    <0.9999164, 0.0049756, 0.0119387>,
    <0.9999160, 0.0050444, 0.0119386>,
    <0.9999160, 0.0050444, 0.0119386>,
    <0.9999587, 0.0052757, 0.0074000>,
    <0.9999598, 0.0051637, 0.0073267>,
    <0.9999613, 0.0049751, 0.0072530>,
    <0.9999322, 0.0049023, 0.0105596>,
    <0.9999242, 0.0049396, 0.0112819>,
    <0.9999628, 0.0047889, 0.0071785>,
    <0.9999638, 0.0046760, 0.0071039>,
    <0.9999224, 0.0048861, 0.0114621>,
    <0.9999224, 0.0048861, 0.0114621>,
    <0.9999221, 0.0049347, 0.0114625>,
    <0.9999215, 0.0049421, 0.0115096>,
    <0.9999205, 0.0049440, 0.0115977>,
    <0.9999221, 0.0049347, 0.0114625>,
    <0.9999221, 0.0049414, 0.0114625>,
    <0.9999221, 0.0049414, 0.0114625>,
    <0.9999221, 0.0049320, 0.0114624>,
    <0.9999208, 0.0049320, 0.0115815>,
    <0.9999208, 0.0049320, 0.0115815>,
    <0.9999194, 0.0049320, 0.0117006>,
    <0.9999187, 0.0049459, 0.0117509>,
    <0.9999194, 0.0049320, 0.0117006>,
    <0.9999180, 0.0049320, 0.0118197>,
    <0.9999180, 0.0049320, 0.0118197>,
    <0.9999166, 0.0049320, 0.0119388>,
    <0.9999165, 0.0049465, 0.0119388>,
    <0.9999165, 0.0049465, 0.0119388>,
    <0.9999164, 0.0049756, 0.0119387>,
    <0.9999769, 0.0051945, -0.0043730>,
    <0.9997738, 0.0050800, -0.0206514>,
    <0.9998744, 0.0049721, -0.0150502>,
    <0.9999873, 0.0049759, -0.0008097>,
    <0.9999587, 0.0052757, 0.0074000>,
    <0.9990680, 0.0058606, -0.0427636>,
    <0.9990680, 0.0058606, -0.0427636>,
    <0.9990714, 0.0051973, -0.0427696>,
    <0.9993791, 0.0049844, -0.0348780>,
    <0.9994845, 0.0049663, -0.0317178>,
    <0.9990714, 0.0051973, -0.0427696>,
    <0.9990724, 0.0049929, -0.0427714>,
    <0.9990724, 0.0049929, -0.0427714>,
    <0.9990726, 0.0049603, -0.0427717>,
    <0.9990907, 0.0049604, -0.0423460>,
    <0.9990907, 0.0049604, -0.0423460>,
    <0.9991086, 0.0049605, -0.0419203>,
    <0.9994051, 0.0049475, -0.0341329>,
    <0.9997860, 0.0048649, -0.0201093>,
    <0.9991086, 0.0049605, -0.0419203>,
    <0.9991264, 0.0049606, -0.0414946>,
    <0.9991264, 0.0049606, -0.0414946>,
    <0.9991440, 0.0049607, -0.0410689>,
    <0.9991441, 0.0049368, -0.0410682>,
    <0.9991441, 0.0049368, -0.0410682>,
    <0.9991453, 0.0047459, -0.0410625>,
    <0.9999800, 0.0047607, -0.0041693>,
    <0.9991453, 0.0047459, -0.0410625>,
    <0.9991489, 0.0041108, -0.0410437>,
    <0.9991489, 0.0041108, -0.0410437>,
    <0.9999638, 0.0046760, 0.0071039>
  }
  uv_vectors {
    1469,
    <0.3461295, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.2823938, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3461295, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.7176062, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.3461295, 0.0000000>,
    <0.5000062, 0.0000000>,
    <0.6538828, 0.0000000>,
    <0.2823938, 0.0000000>,
    <0.3462850, 0.1538766>,
    <0.2826137, 0.1538766>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.2826137, 0.1538766>,
    <0.3462850, 0.1538766>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.7173863, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.3462850, 0.1538766>,
    <0.5000062, 0.1538766>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.5000062, 0.1538766>,
    <0.6537273, 0.1538766>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.6537273, 0.1538766>,
    <0.7173863, 0.1538766>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3240764, 0.9329566>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.3240764, 0.9329566>,
    <0.3756038, 0.9329566>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.6759253, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3214772, 0.9324092>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.3214772, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3213383, 0.9388315>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.3213383, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3176078, 0.9395004>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.3176078, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3175836, 0.9657316>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.3175836, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.2922845, 0.9671308>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2922845, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.2910740, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.2846200, 0.9883895>,
    <0.2846200, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.2846200, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3477037, 1.0000000>,
    <0.2846200, 1.0000000>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.4373453, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6262459, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5622069, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.6512759, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6785245, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6501666, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.4368613, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6263441, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5631259, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.6524445, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6786633, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6523852, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.4361773, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6289821, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5631750, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.6540958, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6823937, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6525037, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.4355135, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4349582, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289992, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5644940, 0.9395004>,
    <0.6289897, 0.9511724>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.6556982, 0.9526160>,
    <0.6289821, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824179, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6556879, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6558937, 0.9657316>,
    <0.6289897, 0.9511724>,
    <0.4310370, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000061, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.4349582, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4263414, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.5689750, 0.9664312>,
    <0.5000059, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6468888, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5645025, 0.9657316>,
    <0.6379139, 0.9664288>,
    <0.5734474, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.6665054, 0.9664312>,
    <0.6289992, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.7077159, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6558937, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6773828, 0.9671308>,
    <0.6379139, 0.9664288>,
    <0.4263507, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4261367, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6477448, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5734474, 0.9671308>,
    <0.6473543, 0.9786906>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.6778190, 0.9777601>,
    <0.6468888, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7089263, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6773828, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6473543, 0.9786906>,
    <0.4249958, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.4642375, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4396228, 1.0000000>,
    <0.3857793, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.5134670, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.4888523, 1.0000000>,
    <0.4619305, 1.0000000>,
    <0.5380817, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6165400, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.5650035, 1.0000000>,
    <0.6142330, 1.0000000>,
    <0.6680764, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6211540, 1.0000000>,
    <0.5538496, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.7153801, 1.0000000>,
    <0.5315419, 1.0000000>,
    <0.6188470, 1.0000000>,
    <0.6996122, 1.0000000>,
    <0.6234610, 1.0000000>,
    <0.5426958, 1.0000000>,
    <0.4063597, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.3746848, 0.9326829>,
    <0.3756038, 0.9329566>,
    <0.4378048, 0.9329566>,
    <0.4060151, 0.9326829>,
    <0.3751443, 0.9328198>,
    <0.4067043, 0.9329566>,
    <0.4375751, 0.9328198>,
    <0.4687905, 0.9328198>,
    <0.4373453, 0.9326829>,
    <0.4378048, 0.9329566>,
    <0.5000059, 0.9329566>,
    <0.5000059, 0.9326829>,
    <0.4375751, 0.9328198>,
    <0.4689053, 0.9329566>,
    <0.5000059, 0.9328198>,
    <0.4686756, 0.9326829>,
    <0.4685607, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4686756, 0.9326829>,
    <0.5000059, 0.9325460>,
    <0.4684459, 0.9324092>,
    <0.4371156, 0.9325460>,
    <0.4056704, 0.9325460>,
    <0.4373453, 0.9326829>,
    <0.4368858, 0.9324092>,
    <0.3737658, 0.9324092>,
    <0.3746848, 0.9326829>,
    <0.4371156, 0.9325460>,
    <0.4053258, 0.9324092>,
    <0.3742253, 0.9325460>,
    <0.4060151, 0.9326829>,
    <0.5312213, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5000059, 0.9326829>,
    <0.5000059, 0.9329566>,
    <0.5622069, 0.9329566>,
    <0.5313361, 0.9326829>,
    <0.5000059, 0.9328198>,
    <0.5311064, 0.9329566>,
    <0.5624367, 0.9328198>,
    <0.5936520, 0.9328198>,
    <0.5626664, 0.9326829>,
    <0.5622069, 0.9329566>,
    <0.6244079, 0.9329566>,
    <0.6253269, 0.9326829>,
    <0.5624367, 0.9328198>,
    <0.5933074, 0.9329566>,
    <0.6248674, 0.9328198>,
    <0.5939967, 0.9326829>,
    <0.5943413, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6262459, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5939967, 0.9326829>,
    <0.6257864, 0.9325460>,
    <0.5946859, 0.9324092>,
    <0.5628962, 0.9325460>,
    <0.5314510, 0.9325460>,
    <0.5626664, 0.9326829>,
    <0.5631259, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9326829>,
    <0.5628962, 0.9325460>,
    <0.5315659, 0.9324092>,
    <0.5000059, 0.9325460>,
    <0.5313361, 0.9326829>,
    <0.6377944, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6253269, 0.9326829>,
    <0.6244079, 0.9329566>,
    <0.6501666, 0.9329566>,
    <0.6383014, 0.9326829>,
    <0.6248674, 0.9328198>,
    <0.6372873, 0.9329566>,
    <0.6507213, 0.9328198>,
    <0.6636482, 0.9328198>,
    <0.6512759, 0.9326829>,
    <0.6501666, 0.9329566>,
    <0.6759253, 0.9329566>,
    <0.6772249, 0.9326829>,
    <0.6507213, 0.9328198>,
    <0.6630460, 0.9329566>,
    <0.6765751, 0.9328198>,
    <0.6642504, 0.9326829>,
    <0.6648526, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6772249, 0.9326829>,
    <0.6785245, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6642504, 0.9326829>,
    <0.6778747, 0.9325460>,
    <0.6654549, 0.9324092>,
    <0.6518306, 0.9325460>,
    <0.6388085, 0.9325460>,
    <0.6512759, 0.9326829>,
    <0.6523852, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6253269, 0.9326829>,
    <0.6518306, 0.9325460>,
    <0.6393156, 0.9324092>,
    <0.6257864, 0.9325460>,
    <0.6383014, 0.9326829>,
    <0.4053074, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.3737167, 0.9356203>,
    <0.3737658, 0.9324092>,
    <0.4368858, 0.9324092>,
    <0.4052890, 0.9356203>,
    <0.3737413, 0.9340147>,
    <0.4053258, 0.9324092>,
    <0.4368736, 0.9340147>,
    <0.4684397, 0.9340147>,
    <0.4368613, 0.9356203>,
    <0.4368858, 0.9324092>,
    <0.5000059, 0.9324092>,
    <0.5000059, 0.9356203>,
    <0.4368736, 0.9340147>,
    <0.4684459, 0.9324092>,
    <0.5000059, 0.9340147>,
    <0.4684336, 0.9356203>,
    <0.4684275, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4684336, 0.9356203>,
    <0.5000059, 0.9372259>,
    <0.4684213, 0.9388315>,
    <0.4368490, 0.9372259>,
    <0.4052706, 0.9372259>,
    <0.4368613, 0.9356203>,
    <0.4368368, 0.9388315>,
    <0.3736676, 0.9388315>,
    <0.3737167, 0.9356203>,
    <0.4368490, 0.9372259>,
    <0.4052522, 0.9388315>,
    <0.3736922, 0.9372259>,
    <0.4052890, 0.9356203>,
    <0.5315720, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5000059, 0.9356203>,
    <0.5000059, 0.9324092>,
    <0.5631259, 0.9324092>,
    <0.5315782, 0.9356203>,
    <0.5000059, 0.9340147>,
    <0.5315659, 0.9324092>,
    <0.5631382, 0.9340147>,
    <0.5947043, 0.9340147>,
    <0.5631505, 0.9356203>,
    <0.5631259, 0.9324092>,
    <0.6262459, 0.9324092>,
    <0.6262950, 0.9356203>,
    <0.5631382, 0.9340147>,
    <0.5946859, 0.9324092>,
    <0.6262705, 0.9340147>,
    <0.5947227, 0.9356203>,
    <0.5947412, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6263441, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5947227, 0.9356203>,
    <0.6263196, 0.9372259>,
    <0.5947596, 0.9388315>,
    <0.5631627, 0.9372259>,
    <0.5315843, 0.9372259>,
    <0.5631505, 0.9356203>,
    <0.5631750, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9356203>,
    <0.5631627, 0.9372259>,
    <0.5315904, 0.9388315>,
    <0.5000059, 0.9372259>,
    <0.5315782, 0.9356203>,
    <0.6393427, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6262950, 0.9356203>,
    <0.6262459, 0.9324092>,
    <0.6523852, 0.9324092>,
    <0.6393698, 0.9356203>,
    <0.6262705, 0.9340147>,
    <0.6393156, 0.9324092>,
    <0.6524148, 0.9340147>,
    <0.6654870, 0.9340147>,
    <0.6524445, 0.9356203>,
    <0.6523852, 0.9324092>,
    <0.6785245, 0.9324092>,
    <0.6785939, 0.9356203>,
    <0.6524148, 0.9340147>,
    <0.6654549, 0.9324092>,
    <0.6785592, 0.9340147>,
    <0.6655192, 0.9356203>,
    <0.6655513, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6785939, 0.9356203>,
    <0.6786633, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6655192, 0.9356203>,
    <0.6786286, 0.9372259>,
    <0.6655835, 0.9388315>,
    <0.6524741, 0.9372259>,
    <0.6393968, 0.9372259>,
    <0.6524445, 0.9356203>,
    <0.6525037, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6262950, 0.9356203>,
    <0.6524741, 0.9372259>,
    <0.6394239, 0.9388315>,
    <0.6263196, 0.9372259>,
    <0.6393698, 0.9356203>,
    <0.4047576, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.3723487, 0.9391659>,
    <0.3736676, 0.9388315>,
    <0.4368368, 0.9388315>,
    <0.4042630, 0.9391659>,
    <0.3730082, 0.9389987>,
    <0.4052522, 0.9388315>,
    <0.4365070, 0.9389987>,
    <0.4682565, 0.9389987>,
    <0.4361773, 0.9391659>,
    <0.4368368, 0.9388315>,
    <0.5000059, 0.9388315>,
    <0.5000059, 0.9391659>,
    <0.4365070, 0.9389987>,
    <0.4684213, 0.9388315>,
    <0.5000059, 0.9389987>,
    <0.4680916, 0.9391659>,
    <0.4679267, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4680916, 0.9391659>,
    <0.5000059, 0.9393332>,
    <0.4677619, 0.9395004>,
    <0.4358475, 0.9393332>,
    <0.4037684, 0.9393332>,
    <0.4361773, 0.9391659>,
    <0.4355178, 0.9395004>,
    <0.3710297, 0.9395004>,
    <0.3723487, 0.9391659>,
    <0.4358475, 0.9393332>,
    <0.4032738, 0.9395004>,
    <0.3716892, 0.9393332>,
    <0.4042630, 0.9391659>,
    <0.5317553, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5000059, 0.9391659>,
    <0.5000059, 0.9388315>,
    <0.5631750, 0.9388315>,
    <0.5319202, 0.9391659>,
    <0.5000059, 0.9389987>,
    <0.5315904, 0.9388315>,
    <0.5635047, 0.9389987>,
    <0.5952542, 0.9389987>,
    <0.5638345, 0.9391659>,
    <0.5631750, 0.9388315>,
    <0.6263441, 0.9388315>,
    <0.6276631, 0.9391659>,
    <0.5635047, 0.9389987>,
    <0.5947596, 0.9388315>,
    <0.6270036, 0.9389987>,
    <0.5957488, 0.9391659>,
    <0.5962434, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6289821, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5957488, 0.9391659>,
    <0.6283226, 0.9393332>,
    <0.5967380, 0.9395004>,
    <0.5641643, 0.9393332>,
    <0.5320851, 0.9393332>,
    <0.5638345, 0.9391659>,
    <0.5644940, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9391659>,
    <0.5641643, 0.9393332>,
    <0.5322500, 0.9395004>,
    <0.5000059, 0.9393332>,
    <0.5319202, 0.9391659>,
    <0.6401517, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6276631, 0.9391659>,
    <0.6263441, 0.9388315>,
    <0.6525037, 0.9388315>,
    <0.6408795, 0.9391659>,
    <0.6270036, 0.9389987>,
    <0.6394239, 0.9388315>,
    <0.6532998, 0.9389987>,
    <0.6664478, 0.9389987>,
    <0.6540958, 0.9391659>,
    <0.6525037, 0.9388315>,
    <0.6786633, 0.9388315>,
    <0.6805285, 0.9391659>,
    <0.6532998, 0.9389987>,
    <0.6655835, 0.9388315>,
    <0.6795959, 0.9389987>,
    <0.6673122, 0.9391659>,
    <0.6681765, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6805285, 0.9391659>,
    <0.6823937, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6673122, 0.9391659>,
    <0.6814611, 0.9393332>,
    <0.6690408, 0.9395004>,
    <0.6548919, 0.9393332>,
    <0.6416072, 0.9393332>,
    <0.6540958, 0.9391659>,
    <0.6556879, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6276631, 0.9391659>,
    <0.6548919, 0.9393332>,
    <0.6423350, 0.9395004>,
    <0.6283226, 0.9393332>,
    <0.6408795, 0.9391659>,
    <0.4032706, 0.9460582>,
    <0.4355135, 0.9526160>,
    <0.3710212, 0.9526160>,
    <0.3710297, 0.9395004>,
    <0.4355178, 0.9395004>,
    <0.4032658, 0.9526160>,
    <0.3710254, 0.9460582>,
    <0.4032738, 0.9395004>,
    <0.4355157, 0.9458854>,
    <0.4677608, 0.9456845>,
    <0.4355135, 0.9526160>,
    <0.4355178, 0.9395004>,
    <0.5000059, 0.9395004>,
    <0.5000059, 0.9511210>,
    <0.4355157, 0.9458854>,
    <0.4677619, 0.9395004>,
    <0.5000059, 0.9451388>,
    <0.4677604, 0.9518685>,
    <0.4676209, 0.9588001>,
    <0.4355135, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.4677604, 0.9518685>,
    <0.5000059, 0.9579003>,
    <0.4674769, 0.9657316>,
    <0.4352664, 0.9584513>,
    <0.4031264, 0.9591738>,
    <0.4355135, 0.9526160>,
    <0.4349582, 0.9657316>,
    <0.3710126, 0.9657316>,
    <0.3710212, 0.9526160>,
    <0.4352664, 0.9584513>,
    <0.4022562, 0.9657316>,
    <0.3710169, 0.9591738>,
    <0.4032658, 0.9526160>,
    <0.5322510, 0.9456845>,
    <0.5644983, 0.9526160>,
    <0.5000059, 0.9511210>,
    <0.5000059, 0.9395004>,
    <0.5644940, 0.9395004>,
    <0.5322521, 0.9518685>,
    <0.5000059, 0.9451388>,
    <0.5322500, 0.9395004>,
    <0.5644961, 0.9458646>,
    <0.5967410, 0.9456973>,
    <0.5644983, 0.9526160>,
    <0.5644940, 0.9395004>,
    <0.6289821, 0.9395004>,
    <0.6289897, 0.9511724>,
    <0.5644961, 0.9458646>,
    <0.5967380, 0.9395004>,
    <0.6289858, 0.9451648>,
    <0.5967440, 0.9518942>,
    <0.5967474, 0.9588129>,
    <0.5644983, 0.9526160>,
    <0.6289897, 0.9511724>,
    <0.6289992, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5967440, 0.9518942>,
    <0.6289941, 0.9579895>,
    <0.5967509, 0.9657316>,
    <0.5645003, 0.9587186>,
    <0.5322532, 0.9588001>,
    <0.5644983, 0.9526160>,
    <0.5645025, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000059, 0.9511210>,
    <0.5645003, 0.9587186>,
    <0.5322542, 0.9657316>,
    <0.5000059, 0.9579003>,
    <0.5322521, 0.9518685>,
    <0.6423395, 0.9456973>,
    <0.6556982, 0.9526160>,
    <0.6289897, 0.9511724>,
    <0.6289821, 0.9395004>,
    <0.6556879, 0.9395004>,
    <0.6423437, 0.9518942>,
    <0.6289858, 0.9451648>,
    <0.6423350, 0.9395004>,
    <0.6556929, 0.9458857>,
    <0.6690464, 0.9460582>,
    <0.6556982, 0.9526160>,
    <0.6556879, 0.9395004>,
    <0.6823937, 0.9395004>,
    <0.6824058, 0.9526160>,
    <0.6556929, 0.9458857>,
    <0.6690408, 0.9395004>,
    <0.6823998, 0.9460582>,
    <0.6690524, 0.9526160>,
    <0.6691039, 0.9591738>,
    <0.6556982, 0.9526160>,
    <0.6824058, 0.9526160>,
    <0.6824179, 0.9657316>,
    <0.6558937, 0.9657316>,
    <0.6690524, 0.9526160>,
    <0.6824118, 0.9591738>,
    <0.6694067, 0.9657316>,
    <0.6557854, 0.9584675>,
    <0.6423952, 0.9588129>,
    <0.6556982, 0.9526160>,
    <0.6558937, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6289897, 0.9511724>,
    <0.6557854, 0.9584675>,
    <0.6424477, 0.9657316>,
    <0.6289941, 0.9579895>,
    <0.6423437, 0.9518942>,
    <0.3997689, 0.9660814>,
    <0.4310370, 0.9664312>,
    <0.3620680, 0.9664312>,
    <0.3710126, 0.9657316>,
    <0.4349582, 0.9657316>,
    <0.3965525, 0.9664312>,
    <0.3665403, 0.9660814>,
    <0.4022562, 0.9657316>,
    <0.4331396, 0.9660561>,
    <0.4665018, 0.9660805>,
    <0.4310370, 0.9664312>,
    <0.4349582, 0.9657316>,
    <0.5000059, 0.9657316>,
    <0.5000060, 0.9664275>,
    <0.4331396, 0.9660561>,
    <0.4674769, 0.9657316>,
    <0.5000060, 0.9660883>,
    <0.4655215, 0.9664293>,
    <0.4643476, 0.9667801>,
    <0.4310370, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000061, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.4655215, 0.9664293>,
    <0.5000060, 0.9667645>,
    <0.4631665, 0.9671308>,
    <0.4286164, 0.9667919>,
    <0.3931424, 0.9667810>,
    <0.4310370, 0.9664312>,
    <0.4263414, 0.9671308>,
    <0.3531234, 0.9671308>,
    <0.3620680, 0.9664312>,
    <0.4286164, 0.9667919>,
    <0.3894539, 0.9671308>,
    <0.3575957, 0.9667810>,
    <0.3965525, 0.9664312>,
    <0.5333724, 0.9660805>,
    <0.5689750, 0.9664312>,
    <0.5000060, 0.9664275>,
    <0.5000059, 0.9657316>,
    <0.5645025, 0.9657316>,
    <0.5344905, 0.9664293>,
    <0.5000060, 0.9660883>,
    <0.5322542, 0.9657316>,
    <0.5668016, 0.9660912>,
    <0.6000977, 0.9660808>,
    <0.5689750, 0.9664312>,
    <0.5645025, 0.9657316>,
    <0.6289992, 0.9657316>,
    <0.6379139, 0.9664288>,
    <0.5668016, 0.9660912>,
    <0.5967509, 0.9657316>,
    <0.6336084, 0.9660921>,
    <0.6034444, 0.9664300>,
    <0.6068063, 0.9667804>,
    <0.5689750, 0.9664312>,
    <0.6379139, 0.9664288>,
    <0.6468888, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.6034444, 0.9664300>,
    <0.6421883, 0.9667632>,
    <0.6101681, 0.9671308>,
    <0.5711137, 0.9667657>,
    <0.5356086, 0.9667801>,
    <0.5689750, 0.9664312>,
    <0.5734474, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000060, 0.9664275>,
    <0.5711137, 0.9667657>,
    <0.5367268, 0.9671308>,
    <0.5000060, 0.9667645>,
    <0.5344905, 0.9664293>,
    <0.6473280, 0.9660808>,
    <0.6665054, 0.9664312>,
    <0.6379139, 0.9664288>,
    <0.6289992, 0.9657316>,
    <0.6558937, 0.9657316>,
    <0.6522097, 0.9664300>,
    <0.6336084, 0.9660921>,
    <0.6424477, 0.9657316>,
    <0.6608902, 0.9660610>,
    <0.6749710, 0.9660814>,
    <0.6665054, 0.9664312>,
    <0.6558937, 0.9657316>,
    <0.6824179, 0.9657316>,
    <0.6950669, 0.9664312>,
    <0.6608902, 0.9660610>,
    <0.6694067, 0.9657316>,
    <0.6887424, 0.9660814>,
    <0.6807862, 0.9664312>,
    <0.6866678, 0.9667810>,
    <0.6665054, 0.9664312>,
    <0.6950669, 0.9664312>,
    <0.7077159, 0.9671308>,
    <0.6773828, 0.9671308>,
    <0.6807862, 0.9664312>,
    <0.7013914, 0.9667810>,
    <0.6926475, 0.9671308>,
    <0.6720515, 0.9667879>,
    <0.6571727, 0.9667804>,
    <0.6665054, 0.9664312>,
    <0.6773828, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6379139, 0.9664288>,
    <0.6720515, 0.9667879>,
    <0.6621386, 0.9671308>,
    <0.6421883, 0.9667632>,
    <0.6522097, 0.9664300>,
    <0.3896277, 0.9724455>,
    <0.4263507, 0.9777601>,
    <0.3526954, 0.9777601>,
    <0.3531234, 0.9671308>,
    <0.4263414, 0.9671308>,
    <0.3895219, 0.9777601>,
    <0.3529094, 0.9724455>,
    <0.3894539, 0.9671308>,
    <0.4263465, 0.9729776>,
    <0.4631761, 0.9726967>,
    <0.4263507, 0.9777601>,
    <0.4263414, 0.9671308>,
    <0.5000061, 0.9671308>,
    <0.5000061, 0.9787650>,
    <0.4263465, 0.9729776>,
    <0.4631665, 0.9671308>,
    <0.5000061, 0.9732089>,
    <0.4631777, 0.9782626>,
    <0.4631249, 0.9833260>,
    <0.4263507, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.4631777, 0.9782626>,
    <0.5000061, 0.9837065>,
    <0.4630714, 0.9883895>,
    <0.4262410, 0.9832100>,
    <0.3893626, 0.9830748>,
    <0.4263507, 0.9777601>,
    <0.4261367, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.3526954, 0.9777601>,
    <0.4262410, 0.9832100>,
    <0.3892021, 0.9883895>,
    <0.3524814, 0.9830748>,
    <0.3895219, 0.9777601>,
    <0.5367803, 0.9726967>,
    <0.5736614, 0.9777601>,
    <0.5000061, 0.9787650>,
    <0.5000061, 0.9671308>,
    <0.5734474, 0.9671308>,
    <0.5368338, 0.9782626>,
    <0.5000061, 0.9732089>,
    <0.5367268, 0.9671308>,
    <0.5735589, 0.9726651>,
    <0.6103380, 0.9726781>,
    <0.5736614, 0.9777601>,
    <0.5734474, 0.9671308>,
    <0.6468888, 0.9671308>,
    <0.6473543, 0.9786906>,
    <0.5735589, 0.9726651>,
    <0.6101681, 0.9671308>,
    <0.6471293, 0.9731037>,
    <0.6105079, 0.9782254>,
    <0.6106590, 0.9833074>,
    <0.5736614, 0.9777601>,
    <0.6473543, 0.9786906>,
    <0.6477448, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6105079, 0.9782254>,
    <0.6475546, 0.9836672>,
    <0.6108101, 0.9883895>,
    <0.5737713, 0.9832166>,
    <0.5368873, 0.9833260>,
    <0.5736614, 0.9777601>,
    <0.5738754, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9787650>,
    <0.5737713, 0.9832166>,
    <0.5369408, 0.9883895>,
    <0.5000061, 0.9837065>,
    <0.5368338, 0.9782626>,
    <0.6623612, 0.9726781>,
    <0.6778190, 0.9777601>,
    <0.6473543, 0.9786906>,
    <0.6468888, 0.9671308>,
    <0.6773828, 0.9671308>,
    <0.6625869, 0.9782254>,
    <0.6471293, 0.9731037>,
    <0.6621386, 0.9671308>,
    <0.6776219, 0.9729570>,
    <0.6928097, 0.9724455>,
    <0.6778190, 0.9777601>,
    <0.6773828, 0.9671308>,
    <0.7077159, 0.9671308>,
    <0.7083211, 0.9777601>,
    <0.6776219, 0.9729570>,
    <0.6926475, 0.9671308>,
    <0.7080185, 0.9724455>,
    <0.6930705, 0.9777601>,
    <0.6933505, 0.9830748>,
    <0.6778190, 0.9777601>,
    <0.7083211, 0.9777601>,
    <0.7089263, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6930705, 0.9777601>,
    <0.7086237, 0.9830748>,
    <0.6936309, 0.9883895>,
    <0.6780838, 0.9832092>,
    <0.6628134, 0.9833074>,
    <0.6778190, 0.9777601>,
    <0.6783356, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6473543, 0.9786906>,
    <0.6780838, 0.9832092>,
    <0.6630402, 0.9883895>,
    <0.6475546, 0.9836672>,
    <0.6625869, 0.9782254>,
    <0.3883464, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.3522674, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.3511265, 0.9883895>,
    <0.3892021, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4627862, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4261367, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4255663, 0.9883895>,
    <0.4630714, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.4622158, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.4625010, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.4619305, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3866350, 0.9883895>,
    <0.4249958, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3477037, 0.9883895>,
    <0.3499856, 0.9883895>,
    <0.4244254, 0.9883895>,
    <0.3857793, 0.9883895>,
    <0.3488446, 0.9883895>,
    <0.3874907, 0.9883895>,
    <0.5372260, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5369408, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6116658, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5738754, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.5744459, 0.9883895>,
    <0.6108101, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6133773, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.6125215, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6142330, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5377965, 0.9883895>,
    <0.5750164, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5755869, 0.9883895>,
    <0.5380817, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5375113, 0.9883895>,
    <0.6642992, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6477448, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.6488857, 0.9883895>,
    <0.6630402, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6951263, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6783356, 0.9883895>,
    <0.7089263, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.6797127, 0.9883895>,
    <0.6936309, 0.9883895>,
    <0.7105398, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.6981169, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.7121532, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6966216, 0.9883895>,
    <0.7137666, 0.9883895>,
    <0.6996122, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6668174, 0.9883895>,
    <0.6810899, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6500267, 0.9883895>,
    <0.6824671, 0.9883895>,
    <0.6680764, 0.9883895>,
    <0.6511676, 0.9883895>,
    <0.6655583, 0.9883895>,
    <0.3857793, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.3477037, 0.9941947>,
    <0.3477037, 0.9883895>,
    <0.4238549, 0.9883895>,
    <0.3857793, 0.9941947>,
    <0.3477037, 0.9912921>,
    <0.3857793, 0.9883895>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9912921>,
    <0.4238549, 0.9941947>,
    <0.4238549, 0.9883895>,
    <0.5000061, 0.9883895>,
    <0.5000061, 0.9941947>,
    <0.4238549, 0.9912921>,
    <0.4619305, 0.9883895>,
    <0.5000061, 0.9912921>,
    <0.4619305, 0.9941947>,
    <0.4619305, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 1.0000000>,
    <0.4238549, 1.0000000>,
    <0.4619305, 0.9941947>,
    <0.5000061, 0.9970974>,
    <0.4619305, 1.0000000>,
    <0.4238549, 0.9970974>,
    <0.3857793, 0.9970974>,
    <0.4238549, 0.9941947>,
    <0.4238549, 1.0000000>,
    <0.3477037, 1.0000000>,
    <0.3477037, 0.9941947>,
    <0.4238549, 0.9970974>,
    <0.3857793, 1.0000000>,
    <0.3477037, 0.9970974>,
    <0.3857793, 0.9941947>,
    <0.5380817, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5000061, 0.9941947>,
    <0.5000061, 0.9883895>,
    <0.5761574, 0.9883895>,
    <0.5380817, 0.9941947>,
    <0.5000061, 0.9912921>,
    <0.5380817, 0.9883895>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9912921>,
    <0.5761574, 0.9941947>,
    <0.5761574, 0.9883895>,
    <0.6523086, 0.9883895>,
    <0.6523086, 0.9941947>,
    <0.5761574, 0.9912921>,
    <0.6142330, 0.9883895>,
    <0.6523086, 0.9912921>,
    <0.6142330, 0.9941947>,
    <0.6142330, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 1.0000000>,
    <0.5761574, 1.0000000>,
    <0.6142330, 0.9941947>,
    <0.6523086, 0.9970974>,
    <0.6142330, 1.0000000>,
    <0.5761574, 0.9970974>,
    <0.5380817, 0.9970974>,
    <0.5761574, 0.9941947>,
    <0.5761574, 1.0000000>,
    <0.5000061, 1.0000000>,
    <0.5000061, 0.9941947>,
    <0.5761574, 0.9970974>,
    <0.5380817, 1.0000000>,
    <0.5000061, 0.9970974>,
    <0.5380817, 0.9941947>,
    <0.6680764, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6523086, 0.9941947>,
    <0.6523086, 0.9883895>,
    <0.6838443, 0.9883895>,
    <0.6680765, 0.9941947>,
    <0.6523086, 0.9912921>,
    <0.6680764, 0.9883895>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9912921>,
    <0.6838443, 0.9941947>,
    <0.6838443, 0.9883895>,
    <0.7153801, 0.9883895>,
    <0.7153801, 0.9941947>,
    <0.6838443, 0.9912921>,
    <0.6996122, 0.9883895>,
    <0.7153801, 0.9912921>,
    <0.6996122, 0.9941947>,
    <0.6996122, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.7153801, 0.9941947>,
    <0.7153801, 1.0000000>,
    <0.6838443, 1.0000000>,
    <0.6996122, 0.9941947>,
    <0.7153801, 0.9970974>,
    <0.6996122, 1.0000000>,
    <0.6838443, 0.9970974>,
    <0.6680764, 0.9970974>,
    <0.6838443, 0.9941947>,
    <0.6838443, 1.0000000>,
    <0.6523086, 1.0000000>,
    <0.6523086, 0.9941947>,
    <0.6838443, 0.9970974>,
    <0.6680764, 1.0000000>,
    <0.6523086, 0.9970974>,
    <0.6680765, 0.9941947>
  }
  texture_list {
    1,
    texture { T_Pierre }
  }
  face_indices {
    1056,   // 0 triangles and 528 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <20, 19, 0>, 0,
    <20, 0, 13>, 0,
    <20, 13, 10>, 0,
    <20, 10, 17>, 0,
    <20, 17, 15>, 0,
    <20, 15, 18>, 0,
    <20, 18, 16>, 0,
    <20, 16, 19>, 0,
    <24, 4, 0>, 0,
    <24, 0, 19>, 0,
    <24, 19, 16>, 0,
    <24, 16, 22>, 0,
    <24, 22, 21>, 0,
    <24, 21, 23>, 0,
    <24, 23, 1>, 0,
    <24, 1, 4>, 0,
    <33, 32, 25>, 0,
    <33, 25, 29>, 0,
    <33, 29, 26>, 0,
    <33, 26, 30>, 0,
    <33, 30, 27>, 0,
    <33, 27, 31>, 0,
    <33, 31, 28>, 0,
    <33, 28, 32>, 0,
    <39, 38, 25>, 0,
    <39, 25, 32>, 0,
    <39, 32, 28>, 0,
    <39, 28, 36>, 0,
    <39, 36, 34>, 0,
    <39, 34, 37>, 0,
    <39, 37, 35>, 0,
    <39, 35, 38>, 0,
    <45, 44, 25>, 0,
    <45, 25, 38>, 0,
    <45, 38, 35>, 0,
    <45, 35, 42>, 0,
    <45, 42, 40>, 0,
    <45, 40, 43>, 0,
    <45, 43, 41>, 0,
    <45, 41, 44>, 0,
    <49, 29, 25>, 0,
    <49, 25, 44>, 0,
    <49, 44, 41>, 0,
    <49, 41, 47>, 0,
    <49, 47, 46>, 0,
    <49, 46, 48>, 0,
    <49, 48, 26>, 0,
    <49, 26, 29>, 0,
    <55, 54, 50>, 0,
    <55, 50, 52>, 0,
    <55, 52, 35>, 0,
    <55, 35, 37>, 0,
    <55, 37, 34>, 0,
    <55, 34, 53>, 0,
    <55, 53, 51>, 0,
    <55, 51, 54>, 0,
    <61, 60, 50>, 0,
    <61, 50, 54>, 0,
    <61, 54, 51>, 0,
    <61, 51, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <67, 66, 50>, 0,
    <67, 50, 60>, 0,
    <67, 60, 57>, 0,
    <67, 57, 64>, 0,
    <67, 64, 62>, 0,
    <67, 62, 65>, 0,
    <67, 65, 63>, 0,
    <67, 63, 66>, 0,
    <69, 52, 50>, 0,
    <69, 50, 66>, 0,
    <69, 66, 63>, 0,
    <69, 63, 68>, 0,
    <69, 68, 40>, 0,
    <69, 40, 42>, 0,
    <69, 42, 35>, 0,
    <69, 35, 52>, 0,
    <75, 74, 70>, 0,
    <75, 70, 72>, 0,
    <75, 72, 57>, 0,
    <75, 57, 59>, 0,
    <75, 59, 56>, 0,
    <75, 56, 73>, 0,
    <75, 73, 71>, 0,
    <75, 71, 74>, 0,
    <81, 80, 70>, 0,
    <81, 70, 74>, 0,
    <81, 74, 71>, 0,
    <81, 71, 78>, 0,
    <81, 78, 76>, 0,
    <81, 76, 79>, 0,
    <81, 79, 77>, 0,
    <81, 77, 80>, 0,
    <87, 86, 70>, 0,
    <87, 70, 80>, 0,
    <87, 80, 77>, 0,
    <87, 77, 84>, 0,
    <87, 84, 82>, 0,
    <87, 82, 85>, 0,
    <87, 85, 83>, 0,
    <87, 83, 86>, 0,
    <89, 72, 70>, 0,
    <89, 70, 86>, 0,
    <89, 86, 83>, 0,
    <89, 83, 88>, 0,
    <89, 88, 62>, 0,
    <89, 62, 64>, 0,
    <89, 64, 57>, 0,
    <89, 57, 72>, 0,
    <95, 94, 90>, 0,
    <95, 90, 92>, 0,
    <95, 92, 91>, 0,
    <95, 91, 93>, 0,
    <95, 93, 46>, 0,
    <95, 46, 47>, 0,
    <95, 47, 41>, 0,
    <95, 41, 94>, 0,
    <99, 98, 90>, 0,
    <99, 90, 94>, 0,
    <99, 94, 41>, 0,
    <99, 41, 43>, 0,
    <99, 43, 40>, 0,
    <99, 40, 97>, 0,
    <99, 97, 96>, 0,
    <99, 96, 98>, 0,
    <105, 104, 90>, 0,
    <105, 90, 98>, 0,
    <105, 98, 96>, 0,
    <105, 96, 102>, 0,
    <105, 102, 100>, 0,
    <105, 100, 103>, 0,
    <105, 103, 101>, 0,
    <105, 101, 104>, 0,
    <109, 92, 90>, 0,
    <109, 90, 104>, 0,
    <109, 104, 101>, 0,
    <109, 101, 107>, 0,
    <109, 107, 106>, 0,
    <109, 106, 108>, 0,
    <109, 108, 91>, 0,
    <109, 91, 92>, 0,
    <113, 112, 110>, 0,
    <113, 110, 111>, 0,
    <113, 111, 96>, 0,
    <113, 96, 97>, 0,
    <113, 97, 40>, 0,
    <113, 40, 68>, 0,
    <113, 68, 63>, 0,
    <113, 63, 112>, 0,
    <117, 116, 110>, 0,
    <117, 110, 112>, 0,
    <117, 112, 63>, 0,
    <117, 63, 65>, 0,
    <117, 65, 62>, 0,
    <117, 62, 115>, 0,
    <117, 115, 114>, 0,
    <117, 114, 116>, 0,
    <123, 122, 110>, 0,
    <123, 110, 116>, 0,
    <123, 116, 114>, 0,
    <123, 114, 120>, 0,
    <123, 120, 118>, 0,
    <123, 118, 121>, 0,
    <123, 121, 119>, 0,
    <123, 119, 122>, 0,
    <125, 111, 110>, 0,
    <125, 110, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 124>, 0,
    <125, 124, 100>, 0,
    <125, 100, 102>, 0,
    <125, 102, 96>, 0,
    <125, 96, 111>, 0,
    <129, 128, 126>, 0,
    <129, 126, 127>, 0,
    <129, 127, 114>, 0,
    <129, 114, 115>, 0,
    <129, 115, 62>, 0,
    <129, 62, 88>, 0,
    <129, 88, 83>, 0,
    <129, 83, 128>, 0,
    <133, 132, 126>, 0,
    <133, 126, 128>, 0,
    <133, 128, 83>, 0,
    <133, 83, 85>, 0,
    <133, 85, 82>, 0,
    <133, 82, 131>, 0,
    <133, 131, 130>, 0,
    <133, 130, 132>, 0,
    <139, 138, 126>, 0,
    <139, 126, 132>, 0,
    <139, 132, 130>, 0,
    <139, 130, 136>, 0,
    <139, 136, 134>, 0,
    <139, 134, 137>, 0,
    <139, 137, 135>, 0,
    <139, 135, 138>, 0,
    <141, 127, 126>, 0,
    <141, 126, 138>, 0,
    <141, 138, 135>, 0,
    <141, 135, 140>, 0,
    <141, 140, 118>, 0,
    <141, 118, 120>, 0,
    <141, 120, 114>, 0,
    <141, 114, 127>, 0,
    <147, 146, 142>, 0,
    <147, 142, 144>, 0,
    <147, 144, 143>, 0,
    <147, 143, 145>, 0,
    <147, 145, 106>, 0,
    <147, 106, 107>, 0,
    <147, 107, 101>, 0,
    <147, 101, 146>, 0,
    <151, 150, 142>, 0,
    <151, 142, 146>, 0,
    <151, 146, 101>, 0,
    <151, 101, 103>, 0,
    <151, 103, 100>, 0,
    <151, 100, 149>, 0,
    <151, 149, 148>, 0,
    <151, 148, 150>, 0,
    <157, 156, 142>, 0,
    <157, 142, 150>, 0,
    <157, 150, 148>, 0,
    <157, 148, 154>, 0,
    <157, 154, 152>, 0,
    <157, 152, 155>, 0,
    <157, 155, 153>, 0,
    <157, 153, 156>, 0,
    <161, 144, 142>, 0,
    <161, 142, 156>, 0,
    <161, 156, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 158>, 0,
    <161, 158, 160>, 0,
    <161, 160, 143>, 0,
    <161, 143, 144>, 0,
    <165, 164, 162>, 0,
    <165, 162, 163>, 0,
    <165, 163, 148>, 0,
    <165, 148, 149>, 0,
    <165, 149, 100>, 0,
    <165, 100, 124>, 0,
    <165, 124, 119>, 0,
    <165, 119, 164>, 0,
    <169, 168, 162>, 0,
    <169, 162, 164>, 0,
    <169, 164, 119>, 0,
    <169, 119, 121>, 0,
    <169, 121, 118>, 0,
    <169, 118, 167>, 0,
    <169, 167, 166>, 0,
    <169, 166, 168>, 0,
    <175, 174, 162>, 0,
    <175, 162, 168>, 0,
    <175, 168, 166>, 0,
    <175, 166, 172>, 0,
    <175, 172, 170>, 0,
    <175, 170, 173>, 0,
    <175, 173, 171>, 0,
    <175, 171, 174>, 0,
    <177, 163, 162>, 0,
    <177, 162, 174>, 0,
    <177, 174, 171>, 0,
    <177, 171, 176>, 0,
    <177, 176, 152>, 0,
    <177, 152, 154>, 0,
    <177, 154, 148>, 0,
    <177, 148, 163>, 0,
    <181, 180, 178>, 0,
    <181, 178, 179>, 0,
    <181, 179, 166>, 0,
    <181, 166, 167>, 0,
    <181, 167, 118>, 0,
    <181, 118, 140>, 0,
    <181, 140, 135>, 0,
    <181, 135, 180>, 0,
    <185, 184, 178>, 0,
    <185, 178, 180>, 0,
    <185, 180, 135>, 0,
    <185, 135, 137>, 0,
    <185, 137, 134>, 0,
    <185, 134, 183>, 0,
    <185, 183, 182>, 0,
    <185, 182, 184>, 0,
    <191, 190, 178>, 0,
    <191, 178, 184>, 0,
    <191, 184, 182>, 0,
    <191, 182, 188>, 0,
    <191, 188, 186>, 0,
    <191, 186, 189>, 0,
    <191, 189, 187>, 0,
    <191, 187, 190>, 0,
    <193, 179, 178>, 0,
    <193, 178, 190>, 0,
    <193, 190, 187>, 0,
    <193, 187, 192>, 0,
    <193, 192, 170>, 0,
    <193, 170, 172>, 0,
    <193, 172, 166>, 0,
    <193, 166, 179>, 0,
    <199, 198, 194>, 0,
    <199, 194, 196>, 0,
    <199, 196, 195>, 0,
    <199, 195, 197>, 0,
    <199, 197, 158>, 0,
    <199, 158, 159>, 0,
    <199, 159, 153>, 0,
    <199, 153, 198>, 0,
    <203, 202, 194>, 0,
    <203, 194, 198>, 0,
    <203, 198, 153>, 0,
    <203, 153, 155>, 0,
    <203, 155, 152>, 0,
    <203, 152, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <209, 208, 194>, 0,
    <209, 194, 202>, 0,
    <209, 202, 200>, 0,
    <209, 200, 206>, 0,
    <209, 206, 204>, 0,
    <209, 204, 207>, 0,
    <209, 207, 205>, 0,
    <209, 205, 208>, 0,
    <213, 196, 194>, 0,
    <213, 194, 208>, 0,
    <213, 208, 205>, 0,
    <213, 205, 211>, 0,
    <213, 211, 210>, 0,
    <213, 210, 212>, 0,
    <213, 212, 195>, 0,
    <213, 195, 196>, 0,
    <217, 216, 214>, 0,
    <217, 214, 215>, 0,
    <217, 215, 200>, 0,
    <217, 200, 201>, 0,
    <217, 201, 152>, 0,
    <217, 152, 176>, 0,
    <217, 176, 171>, 0,
    <217, 171, 216>, 0,
    <221, 220, 214>, 0,
    <221, 214, 216>, 0,
    <221, 216, 171>, 0,
    <221, 171, 173>, 0,
    <221, 173, 170>, 0,
    <221, 170, 219>, 0,
    <221, 219, 218>, 0,
    <221, 218, 220>, 0,
    <227, 226, 214>, 0,
    <227, 214, 220>, 0,
    <227, 220, 218>, 0,
    <227, 218, 224>, 0,
    <227, 224, 222>, 0,
    <227, 222, 225>, 0,
    <227, 225, 223>, 0,
    <227, 223, 226>, 0,
    <229, 215, 214>, 0,
    <229, 214, 226>, 0,
    <229, 226, 223>, 0,
    <229, 223, 228>, 0,
    <229, 228, 204>, 0,
    <229, 204, 206>, 0,
    <229, 206, 200>, 0,
    <229, 200, 215>, 0,
    <233, 232, 230>, 0,
    <233, 230, 231>, 0,
    <233, 231, 218>, 0,
    <233, 218, 219>, 0,
    <233, 219, 170>, 0,
    <233, 170, 192>, 0,
    <233, 192, 187>, 0,
    <233, 187, 232>, 0,
    <237, 236, 230>, 0,
    <237, 230, 232>, 0,
    <237, 232, 187>, 0,
    <237, 187, 189>, 0,
    <237, 189, 186>, 0,
    <237, 186, 235>, 0,
    <237, 235, 234>, 0,
    <237, 234, 236>, 0,
    <243, 242, 230>, 0,
    <243, 230, 236>, 0,
    <243, 236, 234>, 0,
    <243, 234, 240>, 0,
    <243, 240, 238>, 0,
    <243, 238, 241>, 0,
    <243, 241, 239>, 0,
    <243, 239, 242>, 0,
    <245, 231, 230>, 0,
    <245, 230, 242>, 0,
    <245, 242, 239>, 0,
    <245, 239, 244>, 0,
    <245, 244, 222>, 0,
    <245, 222, 224>, 0,
    <245, 224, 218>, 0,
    <245, 218, 231>, 0,
    <251, 250, 246>, 0,
    <251, 246, 248>, 0,
    <251, 248, 247>, 0,
    <251, 247, 249>, 0,
    <251, 249, 210>, 0,
    <251, 210, 211>, 0,
    <251, 211, 205>, 0,
    <251, 205, 250>, 0,
    <255, 254, 246>, 0,
    <255, 246, 250>, 0,
    <255, 250, 205>, 0,
    <255, 205, 207>, 0,
    <255, 207, 204>, 0,
    <255, 204, 253>, 0,
    <255, 253, 252>, 0,
    <255, 252, 254>, 0,
    <261, 260, 246>, 0,
    <261, 246, 254>, 0,
    <261, 254, 252>, 0,
    <261, 252, 258>, 0,
    <261, 258, 256>, 0,
    <261, 256, 259>, 0,
    <261, 259, 257>, 0,
    <261, 257, 260>, 0,
    <265, 248, 246>, 0,
    <265, 246, 260>, 0,
    <265, 260, 257>, 0,
    <265, 257, 263>, 0,
    <265, 263, 262>, 0,
    <265, 262, 264>, 0,
    <265, 264, 247>, 0,
    <265, 247, 248>, 0,
    <269, 268, 266>, 0,
    <269, 266, 267>, 0,
    <269, 267, 252>, 0,
    <269, 252, 253>, 0,
    <269, 253, 204>, 0,
    <269, 204, 228>, 0,
    <269, 228, 223>, 0,
    <269, 223, 268>, 0,
    <273, 272, 266>, 0,
    <273, 266, 268>, 0,
    <273, 268, 223>, 0,
    <273, 223, 225>, 0,
    <273, 225, 222>, 0,
    <273, 222, 271>, 0,
    <273, 271, 270>, 0,
    <273, 270, 272>, 0,
    <279, 278, 266>, 0,
    <279, 266, 272>, 0,
    <279, 272, 270>, 0,
    <279, 270, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <281, 267, 266>, 0,
    <281, 266, 278>, 0,
    <281, 278, 275>, 0,
    <281, 275, 280>, 0,
    <281, 280, 256>, 0,
    <281, 256, 258>, 0,
    <281, 258, 252>, 0,
    <281, 252, 267>, 0,
    <285, 284, 282>, 0,
    <285, 282, 283>, 0,
    <285, 283, 270>, 0,
    <285, 270, 271>, 0,
    <285, 271, 222>, 0,
    <285, 222, 244>, 0,
    <285, 244, 239>, 0,
    <285, 239, 284>, 0,
    <289, 288, 282>, 0,
    <289, 282, 284>, 0,
    <289, 284, 239>, 0,
    <289, 239, 241>, 0,
    <289, 241, 238>, 0,
    <289, 238, 287>, 0,
    <289, 287, 286>, 0,
    <289, 286, 288>, 0,
    <295, 294, 282>, 0,
    <295, 282, 288>, 0,
    <295, 288, 286>, 0,
    <295, 286, 292>, 0,
    <295, 292, 290>, 0,
    <295, 290, 293>, 0,
    <295, 293, 291>, 0,
    <295, 291, 294>, 0,
    <297, 283, 282>, 0,
    <297, 282, 294>, 0,
    <297, 294, 291>, 0,
    <297, 291, 296>, 0,
    <297, 296, 274>, 0,
    <297, 274, 276>, 0,
    <297, 276, 270>, 0,
    <297, 270, 283>, 0,
    <303, 302, 298>, 0,
    <303, 298, 300>, 0,
    <303, 300, 299>, 0,
    <303, 299, 301>, 0,
    <303, 301, 262>, 0,
    <303, 262, 263>, 0,
    <303, 263, 257>, 0,
    <303, 257, 302>, 0,
    <307, 306, 298>, 0,
    <307, 298, 302>, 0,
    <307, 302, 257>, 0,
    <307, 257, 259>, 0,
    <307, 259, 256>, 0,
    <307, 256, 305>, 0,
    <307, 305, 304>, 0,
    <307, 304, 306>, 0,
    <313, 312, 298>, 0,
    <313, 298, 306>, 0,
    <313, 306, 304>, 0,
    <313, 304, 310>, 0,
    <313, 310, 308>, 0,
    <313, 308, 311>, 0,
    <313, 311, 309>, 0,
    <313, 309, 312>, 0,
    <317, 300, 298>, 0,
    <317, 298, 312>, 0,
    <317, 312, 309>, 0,
    <317, 309, 315>, 0,
    <317, 315, 314>, 0,
    <317, 314, 316>, 0,
    <317, 316, 299>, 0,
    <317, 299, 300>, 0,
    <321, 320, 318>, 0,
    <321, 318, 319>, 0,
    <321, 319, 304>, 0,
    <321, 304, 305>, 0,
    <321, 305, 256>, 0,
    <321, 256, 280>, 0,
    <321, 280, 275>, 0,
    <321, 275, 320>, 0,
    <325, 324, 318>, 0,
    <325, 318, 320>, 0,
    <325, 320, 275>, 0,
    <325, 275, 277>, 0,
    <325, 277, 274>, 0,
    <325, 274, 323>, 0,
    <325, 323, 322>, 0,
    <325, 322, 324>, 0,
    <331, 330, 318>, 0,
    <331, 318, 324>, 0,
    <331, 324, 322>, 0,
    <331, 322, 328>, 0,
    <331, 328, 326>, 0,
    <331, 326, 329>, 0,
    <331, 329, 327>, 0,
    <331, 327, 330>, 0,
    <333, 319, 318>, 0,
    <333, 318, 330>, 0,
    <333, 330, 327>, 0,
    <333, 327, 332>, 0,
    <333, 332, 308>, 0,
    <333, 308, 310>, 0,
    <333, 310, 304>, 0,
    <333, 304, 319>, 0,
    <337, 336, 334>, 0,
    <337, 334, 335>, 0,
    <337, 335, 322>, 0,
    <337, 322, 323>, 0,
    <337, 323, 274>, 0,
    <337, 274, 296>, 0,
    <337, 296, 291>, 0,
    <337, 291, 336>, 0,
    <341, 340, 334>, 0,
    <341, 334, 336>, 0,
    <341, 336, 291>, 0,
    <341, 291, 293>, 0,
    <341, 293, 290>, 0,
    <341, 290, 339>, 0,
    <341, 339, 338>, 0,
    <341, 338, 340>, 0,
    <347, 346, 334>, 0,
    <347, 334, 340>, 0,
    <347, 340, 338>, 0,
    <347, 338, 344>, 0,
    <347, 344, 342>, 0,
    <347, 342, 345>, 0,
    <347, 345, 343>, 0,
    <347, 343, 346>, 0,
    <349, 335, 334>, 0,
    <349, 334, 346>, 0,
    <349, 346, 343>, 0,
    <349, 343, 348>, 0,
    <349, 348, 326>, 0,
    <349, 326, 328>, 0,
    <349, 328, 322>, 0,
    <349, 322, 335>, 0,
    <355, 354, 350>, 0,
    <355, 350, 352>, 0,
    <355, 352, 351>, 0,
    <355, 351, 353>, 0,
    <355, 353, 314>, 0,
    <355, 314, 315>, 0,
    <355, 315, 309>, 0,
    <355, 309, 354>, 0,
    <359, 358, 350>, 0,
    <359, 350, 354>, 0,
    <359, 354, 309>, 0,
    <359, 309, 311>, 0,
    <359, 311, 308>, 0,
    <359, 308, 357>, 0,
    <359, 357, 356>, 0,
    <359, 356, 358>, 0,
    <365, 364, 350>, 0,
    <365, 350, 358>, 0,
    <365, 358, 356>, 0,
    <365, 356, 362>, 0,
    <365, 362, 360>, 0,
    <365, 360, 363>, 0,
    <365, 363, 361>, 0,
    <365, 361, 364>, 0,
    <369, 352, 350>, 0,
    <369, 350, 364>, 0,
    <369, 364, 361>, 0,
    <369, 361, 367>, 0,
    <369, 367, 366>, 0,
    <369, 366, 368>, 0,
    <369, 368, 351>, 0,
    <369, 351, 352>, 0,
    <373, 372, 370>, 0,
    <373, 370, 371>, 0,
    <373, 371, 356>, 0,
    <373, 356, 357>, 0,
    <373, 357, 308>, 0,
    <373, 308, 332>, 0,
    <373, 332, 327>, 0,
    <373, 327, 372>, 0,
    <377, 376, 370>, 0,
    <377, 370, 372>, 0,
    <377, 372, 327>, 0,
    <377, 327, 329>, 0,
    <377, 329, 326>, 0,
    <377, 326, 375>, 0,
    <377, 375, 374>, 0,
    <377, 374, 376>, 0,
    <383, 382, 370>, 0,
    <383, 370, 376>, 0,
    <383, 376, 374>, 0,
    <383, 374, 380>, 0,
    <383, 380, 378>, 0,
    <383, 378, 381>, 0,
    <383, 381, 379>, 0,
    <383, 379, 382>, 0,
    <385, 371, 370>, 0,
    <385, 370, 382>, 0,
    <385, 382, 379>, 0,
    <385, 379, 384>, 0,
    <385, 384, 360>, 0,
    <385, 360, 362>, 0,
    <385, 362, 356>, 0,
    <385, 356, 371>, 0,
    <389, 388, 386>, 0,
    <389, 386, 387>, 0,
    <389, 387, 374>, 0,
    <389, 374, 375>, 0,
    <389, 375, 326>, 0,
    <389, 326, 348>, 0,
    <389, 348, 343>, 0,
    <389, 343, 388>, 0,
    <393, 392, 386>, 0,
    <393, 386, 388>, 0,
    <393, 388, 343>, 0,
    <393, 343, 345>, 0,
    <393, 345, 342>, 0,
    <393, 342, 391>, 0,
    <393, 391, 390>, 0,
    <393, 390, 392>, 0,
    <399, 398, 386>, 0,
    <399, 386, 392>, 0,
    <399, 392, 390>, 0,
    <399, 390, 396>, 0,
    <399, 396, 394>, 0,
    <399, 394, 397>, 0,
    <399, 397, 395>, 0,
    <399, 395, 398>, 0,
    <401, 387, 386>, 0,
    <401, 386, 398>, 0,
    <401, 398, 395>, 0,
    <401, 395, 400>, 0,
    <401, 400, 378>, 0,
    <401, 378, 380>, 0,
    <401, 380, 374>, 0,
    <401, 374, 387>, 0,
    <407, 406, 402>, 0,
    <407, 402, 404>, 0,
    <407, 404, 403>, 0,
    <407, 403, 405>, 0,
    <407, 405, 366>, 0,
    <407, 366, 367>, 0,
    <407, 367, 361>, 0,
    <407, 361, 406>, 0,
    <411, 410, 402>, 0,
    <411, 402, 406>, 0,
    <411, 406, 361>, 0,
    <411, 361, 363>, 0,
    <411, 363, 360>, 0,
    <411, 360, 409>, 0,
    <411, 409, 408>, 0,
    <411, 408, 410>, 0,
    <414, 413, 402>, 0,
    <414, 402, 410>, 0,
    <414, 410, 408>, 0,
    <414, 408, 412>, 0,
    <414, 412, 9>, 0,
    <414, 9, 11>, 0,
    <414, 11, 3>, 0,
    <414, 3, 413>, 0,
    <416, 404, 402>, 0,
    <416, 402, 413>, 0,
    <416, 413, 3>, 0,
    <416, 3, 6>, 0,
    <416, 6, 2>, 0,
    <416, 2, 415>, 0,
    <416, 415, 403>, 0,
    <416, 403, 404>, 0,
    <420, 419, 417>, 0,
    <420, 417, 418>, 0,
    <420, 418, 408>, 0,
    <420, 408, 409>, 0,
    <420, 409, 360>, 0,
    <420, 360, 384>, 0,
    <420, 384, 379>, 0,
    <420, 379, 419>, 0,
    <424, 423, 417>, 0,
    <424, 417, 419>, 0,
    <424, 419, 379>, 0,
    <424, 379, 381>, 0,
    <424, 381, 378>, 0,
    <424, 378, 422>, 0,
    <424, 422, 421>, 0,
    <424, 421, 423>, 0,
    <427, 426, 417>, 0,
    <427, 417, 423>, 0,
    <427, 423, 421>, 0,
    <427, 421, 425>, 0,
    <427, 425, 15>, 0,
    <427, 15, 17>, 0,
    <427, 17, 10>, 0,
    <427, 10, 426>, 0,
    <428, 418, 417>, 0,
    <428, 417, 426>, 0,
    <428, 426, 10>, 0,
    <428, 10, 12>, 0,
    <428, 12, 9>, 0,
    <428, 9, 412>, 0,
    <428, 412, 408>, 0,
    <428, 408, 418>, 0,
    <432, 431, 429>, 0,
    <432, 429, 430>, 0,
    <432, 430, 421>, 0,
    <432, 421, 422>, 0,
    <432, 422, 378>, 0,
    <432, 378, 400>, 0,
    <432, 400, 395>, 0,
    <432, 395, 431>, 0,
    <436, 435, 429>, 0,
    <436, 429, 431>, 0,
    <436, 431, 395>, 0,
    <436, 395, 397>, 0,
    <436, 397, 394>, 0,
    <436, 394, 434>, 0,
    <436, 434, 433>, 0,
    <436, 433, 435>, 0,
    <439, 438, 429>, 0,
    <439, 429, 435>, 0,
    <439, 435, 433>, 0,
    <439, 433, 437>, 0,
    <439, 437, 21>, 0,
    <439, 21, 22>, 0,
    <439, 22, 16>, 0,
    <439, 16, 438>, 0,
    <440, 430, 429>, 0,
    <440, 429, 438>, 0,
    <440, 438, 16>, 0,
    <440, 16, 18>, 0,
    <440, 18, 15>, 0,
    <440, 15, 425>, 0,
    <440, 425, 421>, 0,
    <440, 421, 430>, 0,
    <448, 447, 441>, 0,
    <448, 441, 444>, 0,
    <448, 444, 442>, 0,
    <448, 442, 445>, 0,
    <448, 445, 366>, 0,
    <448, 366, 446>, 0,
    <448, 446, 443>, 0,
    <448, 443, 447>, 0,
    <453, 452, 441>, 0,
    <453, 441, 447>, 0,
    <453, 447, 443>, 0,
    <453, 443, 450>, 0,
    <453, 450, 394>, 0,
    <453, 394, 451>, 0,
    <453, 451, 449>, 0,
    <453, 449, 452>, 0,
    <458, 457, 441>, 0,
    <458, 441, 452>, 0,
    <458, 452, 449>, 0,
    <458, 449, 455>, 0,
    <458, 455, 21>, 0,
    <458, 21, 456>, 0,
    <458, 456, 454>, 0,
    <458, 454, 457>, 0,
    <461, 444, 441>, 0,
    <461, 441, 457>, 0,
    <461, 457, 454>, 0,
    <461, 454, 459>, 0,
    <461, 459, 2>, 0,
    <461, 2, 460>, 0,
    <461, 460, 442>, 0,
    <461, 442, 444>, 0,
    <467, 466, 462>, 0,
    <467, 462, 464>, 0,
    <467, 464, 463>, 0,
    <467, 463, 465>, 0,
    <467, 465, 314>, 0,
    <467, 314, 353>, 0,
    <467, 353, 351>, 0,
    <467, 351, 466>, 0,
    <471, 470, 462>, 0,
    <471, 462, 466>, 0,
    <471, 466, 351>, 0,
    <471, 351, 368>, 0,
    <471, 368, 366>, 0,
    <471, 366, 469>, 0,
    <471, 469, 468>, 0,
    <471, 468, 470>, 0,
    <474, 473, 462>, 0,
    <474, 462, 470>, 0,
    <474, 470, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 394>, 0,
    <474, 394, 396>, 0,
    <474, 396, 390>, 0,
    <474, 390, 473>, 0,
    <476, 464, 462>, 0,
    <476, 462, 473>, 0,
    <476, 473, 390>, 0,
    <476, 390, 391>, 0,
    <476, 391, 342>, 0,
    <476, 342, 475>, 0,
    <476, 475, 463>, 0,
    <476, 463, 464>, 0,
    <484, 483, 477>, 0,
    <484, 477, 480>, 0,
    <484, 480, 478>, 0,
    <484, 478, 481>, 0,
    <484, 481, 262>, 0,
    <484, 262, 482>, 0,
    <484, 482, 479>, 0,
    <484, 479, 483>, 0,
    <489, 488, 477>, 0,
    <489, 477, 483>, 0,
    <489, 483, 479>, 0,
    <489, 479, 486>, 0,
    <489, 486, 290>, 0,
    <489, 290, 487>, 0,
    <489, 487, 485>, 0,
    <489, 485, 488>, 0,
    <494, 493, 477>, 0,
    <494, 477, 488>, 0,
    <494, 488, 485>, 0,
    <494, 485, 491>, 0,
    <494, 491, 342>, 0,
    <494, 342, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 480, 477>, 0,
    <497, 477, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 314>, 0,
    <497, 314, 496>, 0,
    <497, 496, 478>, 0,
    <497, 478, 480>, 0,
    <503, 502, 498>, 0,
    <503, 498, 500>, 0,
    <503, 500, 499>, 0,
    <503, 499, 501>, 0,
    <503, 501, 210>, 0,
    <503, 210, 249>, 0,
    <503, 249, 247>, 0,
    <503, 247, 502>, 0,
    <507, 506, 498>, 0,
    <507, 498, 502>, 0,
    <507, 502, 247>, 0,
    <507, 247, 264>, 0,
    <507, 264, 262>, 0,
    <507, 262, 505>, 0,
    <507, 505, 504>, 0,
    <507, 504, 506>, 0,
    <510, 509, 498>, 0,
    <510, 498, 506>, 0,
    <510, 506, 504>, 0,
    <510, 504, 508>, 0,
    <510, 508, 290>, 0,
    <510, 290, 292>, 0,
    <510, 292, 286>, 0,
    <510, 286, 509>, 0,
    <512, 500, 498>, 0,
    <512, 498, 509>, 0,
    <512, 509, 286>, 0,
    <512, 286, 287>, 0,
    <512, 287, 238>, 0,
    <512, 238, 511>, 0,
    <512, 511, 499>, 0,
    <512, 499, 500>, 0,
    <520, 519, 513>, 0,
    <520, 513, 516>, 0,
    <520, 516, 514>, 0,
    <520, 514, 517>, 0,
    <520, 517, 158>, 0,
    <520, 158, 518>, 0,
    <520, 518, 515>, 0,
    <520, 515, 519>, 0,
    <525, 524, 513>, 0,
    <525, 513, 519>, 0,
    <525, 519, 515>, 0,
    <525, 515, 522>, 0,
    <525, 522, 186>, 0,
    <525, 186, 523>, 0,
    <525, 523, 521>, 0,
    <525, 521, 524>, 0,
    <530, 529, 513>, 0,
    <530, 513, 524>, 0,
    <530, 524, 521>, 0,
    <530, 521, 527>, 0,
    <530, 527, 238>, 0,
    <530, 238, 528>, 0,
    <530, 528, 526>, 0,
    <530, 526, 529>, 0,
    <533, 516, 513>, 0,
    <533, 513, 529>, 0,
    <533, 529, 526>, 0,
    <533, 526, 531>, 0,
    <533, 531, 210>, 0,
    <533, 210, 532>, 0,
    <533, 532, 514>, 0,
    <533, 514, 516>, 0,
    <539, 538, 534>, 0,
    <539, 534, 536>, 0,
    <539, 536, 535>, 0,
    <539, 535, 537>, 0,
    <539, 537, 106>, 0,
    <539, 106, 145>, 0,
    <539, 145, 143>, 0,
    <539, 143, 538>, 0,
    <543, 542, 534>, 0,
    <543, 534, 538>, 0,
    <543, 538, 143>, 0,
    <543, 143, 160>, 0,
    <543, 160, 158>, 0,
    <543, 158, 541>, 0,
    <543, 541, 540>, 0,
    <543, 540, 542>, 0,
    <546, 545, 534>, 0,
    <546, 534, 542>, 0,
    <546, 542, 540>, 0,
    <546, 540, 544>, 0,
    <546, 544, 186>, 0,
    <546, 186, 188>, 0,
    <546, 188, 182>, 0,
    <546, 182, 545>, 0,
    <548, 536, 534>, 0,
    <548, 534, 545>, 0,
    <548, 545, 182>, 0,
    <548, 182, 183>, 0,
    <548, 183, 134>, 0,
    <548, 134, 547>, 0,
    <548, 547, 535>, 0,
    <548, 535, 536>, 0,
    <556, 555, 549>, 0,
    <556, 549, 552>, 0,
    <556, 552, 550>, 0,
    <556, 550, 553>, 0,
    <556, 553, 27>, 0,
    <556, 27, 554>, 0,
    <556, 554, 551>, 0,
    <556, 551, 555>, 0,
    <561, 560, 549>, 0,
    <561, 549, 555>, 0,
    <561, 555, 551>, 0,
    <561, 551, 558>, 0,
    <561, 558, 76>, 0,
    <561, 76, 559>, 0,
    <561, 559, 557>, 0,
    <561, 557, 560>, 0,
    <566, 565, 549>, 0,
    <566, 549, 560>, 0,
    <566, 560, 557>, 0,
    <566, 557, 563>, 0,
    <566, 563, 134>, 0,
    <566, 134, 564>, 0,
    <566, 564, 562>, 0,
    <566, 562, 565>, 0,
    <569, 552, 549>, 0,
    <569, 549, 565>, 0,
    <569, 565, 562>, 0,
    <569, 562, 567>, 0,
    <569, 567, 106>, 0,
    <569, 106, 568>, 0,
    <569, 568, 550>, 0,
    <569, 550, 552>, 0,
    <573, 572, 570>, 0,
    <573, 570, 571>, 0,
    <573, 571, 551>, 0,
    <573, 551, 554>, 0,
    <573, 554, 27>, 0,
    <573, 27, 30>, 0,
    <573, 30, 26>, 0,
    <573, 26, 572>, 0,
    <577, 576, 570>, 0,
    <577, 570, 572>, 0,
    <577, 572, 26>, 0,
    <577, 26, 48>, 0,
    <577, 48, 46>, 0,
    <577, 46, 575>, 0,
    <577, 575, 574>, 0,
    <577, 574, 576>, 0,
    <580, 579, 570>, 0,
    <580, 570, 576>, 0,
    <580, 576, 574>, 0,
    <580, 574, 578>, 0,
    <580, 578, 82>, 0,
    <580, 82, 84>, 0,
    <580, 84, 77>, 0,
    <580, 77, 579>, 0,
    <581, 571, 570>, 0,
    <581, 570, 579>, 0,
    <581, 579, 77>, 0,
    <581, 77, 79>, 0,
    <581, 79, 76>, 0,
    <581, 76, 558>, 0,
    <581, 558, 551>, 0,
    <581, 551, 571>, 0
  }
  normal_indices {
    1056,   // from 0 triangles and 528 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 9, 10>,
    <0, 10, 1>,
    <11, 12, 2>,
    <11, 2, 1>,
    <11, 1, 13>,
    <11, 13, 14>,
    <11, 15, 16>,
    <11, 16, 17>,
    <11, 18, 19>,
    <11, 19, 12>,
    <20, 21, 2>,
    <20, 2, 12>,
    <20, 12, 22>,
    <20, 22, 23>,
    <20, 24, 25>,
    <20, 25, 26>,
    <20, 27, 28>,
    <20, 28, 21>,
    <29, 3, 2>,
    <29, 2, 21>,
    <29, 21, 30>,
    <29, 30, 31>,
    <29, 32, 33>,
    <29, 33, 34>,
    <29, 35, 36>,
    <29, 36, 3>,
    <37, 38, 39>,
    <37, 39, 40>,
    <37, 40, 41>,
    <37, 41, 42>,
    <37, 43, 44>,
    <37, 44, 45>,
    <37, 46, 47>,
    <37, 47, 38>,
    <48, 49, 39>,
    <48, 39, 38>,
    <48, 38, 50>,
    <48, 50, 51>,
    <48, 52, 53>,
    <48, 53, 54>,
    <48, 55, 56>,
    <48, 56, 49>,
    <57, 58, 39>,
    <57, 39, 49>,
    <57, 49, 59>,
    <57, 59, 60>,
    <57, 61, 62>,
    <57, 62, 63>,
    <57, 64, 65>,
    <57, 65, 58>,
    <66, 40, 39>,
    <66, 39, 58>,
    <66, 58, 67>,
    <66, 67, 68>,
    <66, 69, 70>,
    <66, 70, 71>,
    <66, 72, 73>,
    <66, 73, 40>,
    <74, 75, 76>,
    <74, 76, 77>,
    <74, 77, 78>,
    <74, 78, 79>,
    <74, 80, 81>,
    <74, 81, 82>,
    <74, 83, 84>,
    <74, 84, 75>,
    <85, 86, 76>,
    <85, 76, 75>,
    <85, 75, 87>,
    <85, 87, 88>,
    <85, 89, 90>,
    <85, 90, 91>,
    <85, 92, 93>,
    <85, 93, 86>,
    <94, 95, 76>,
    <94, 76, 86>,
    <94, 86, 96>,
    <94, 96, 97>,
    <94, 98, 99>,
    <94, 99, 100>,
    <94, 101, 102>,
    <94, 102, 95>,
    <103, 77, 76>,
    <103, 76, 95>,
    <103, 95, 104>,
    <103, 104, 105>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 109, 110>,
    <103, 110, 77>,
    <111, 112, 113>,
    <111, 113, 114>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 117, 118>,
    <111, 118, 119>,
    <111, 120, 121>,
    <111, 121, 112>,
    <122, 123, 113>,
    <122, 113, 112>,
    <122, 112, 124>,
    <122, 124, 125>,
    <122, 126, 127>,
    <122, 127, 128>,
    <122, 129, 130>,
    <122, 130, 123>,
    <131, 132, 113>,
    <131, 113, 123>,
    <131, 123, 133>,
    <131, 133, 134>,
    <131, 135, 136>,
    <131, 136, 137>,
    <131, 138, 139>,
    <131, 139, 132>,
    <140, 114, 113>,
    <140, 113, 132>,
    <140, 132, 141>,
    <140, 141, 142>,
    <140, 143, 144>,
    <140, 144, 145>,
    <140, 146, 147>,
    <140, 147, 114>,
    <148, 149, 150>,
    <148, 150, 151>,
    <148, 151, 152>,
    <148, 152, 153>,
    <148, 154, 155>,
    <148, 155, 156>,
    <148, 157, 158>,
    <148, 158, 149>,
    <159, 160, 150>,
    <159, 150, 149>,
    <159, 149, 161>,
    <159, 161, 162>,
    <159, 163, 164>,
    <159, 164, 165>,
    <159, 166, 167>,
    <159, 167, 160>,
    <168, 169, 150>,
    <168, 150, 160>,
    <168, 160, 170>,
    <168, 170, 171>,
    <168, 172, 173>,
    <168, 173, 174>,
    <168, 175, 176>,
    <168, 176, 169>,
    <177, 151, 150>,
    <177, 150, 169>,
    <177, 169, 178>,
    <177, 178, 179>,
    <177, 180, 181>,
    <177, 181, 182>,
    <177, 183, 184>,
    <177, 184, 151>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 189>,
    <185, 189, 190>,
    <185, 191, 192>,
    <185, 192, 193>,
    <185, 194, 195>,
    <185, 195, 186>,
    <196, 197, 187>,
    <196, 187, 186>,
    <196, 186, 198>,
    <196, 198, 199>,
    <196, 200, 201>,
    <196, 201, 202>,
    <196, 203, 204>,
    <196, 204, 197>,
    <205, 206, 187>,
    <205, 187, 197>,
    <205, 197, 207>,
    <205, 207, 208>,
    <205, 209, 210>,
    <205, 210, 211>,
    <205, 212, 213>,
    <205, 213, 206>,
    <214, 188, 187>,
    <214, 187, 206>,
    <214, 206, 215>,
    <214, 215, 216>,
    <214, 217, 218>,
    <214, 218, 219>,
    <214, 220, 221>,
    <214, 221, 188>,
    <222, 223, 224>,
    <222, 224, 225>,
    <222, 225, 226>,
    <222, 226, 227>,
    <222, 228, 229>,
    <222, 229, 230>,
    <222, 231, 232>,
    <222, 232, 223>,
    <233, 234, 224>,
    <233, 224, 223>,
    <233, 223, 235>,
    <233, 235, 236>,
    <233, 237, 238>,
    <233, 238, 239>,
    <233, 240, 241>,
    <233, 241, 234>,
    <242, 243, 224>,
    <242, 224, 234>,
    <242, 234, 244>,
    <242, 244, 245>,
    <242, 246, 247>,
    <242, 247, 248>,
    <242, 249, 250>,
    <242, 250, 243>,
    <251, 225, 224>,
    <251, 224, 243>,
    <251, 243, 252>,
    <251, 252, 253>,
    <251, 254, 255>,
    <251, 255, 256>,
    <251, 257, 258>,
    <251, 258, 225>,
    <259, 260, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 265, 266>,
    <259, 266, 267>,
    <259, 268, 269>,
    <259, 269, 260>,
    <270, 271, 261>,
    <270, 261, 260>,
    <270, 260, 272>,
    <270, 272, 273>,
    <270, 274, 275>,
    <270, 275, 276>,
    <270, 277, 278>,
    <270, 278, 271>,
    <279, 280, 261>,
    <279, 261, 271>,
    <279, 271, 281>,
    <279, 281, 282>,
    <279, 283, 284>,
    <279, 284, 285>,
    <279, 286, 287>,
    <279, 287, 280>,
    <288, 262, 261>,
    <288, 261, 280>,
    <288, 280, 289>,
    <288, 289, 290>,
    <288, 291, 292>,
    <288, 292, 293>,
    <288, 294, 295>,
    <288, 295, 262>,
    <296, 297, 298>,
    <296, 298, 299>,
    <296, 299, 300>,
    <296, 300, 301>,
    <296, 302, 303>,
    <296, 303, 304>,
    <296, 305, 306>,
    <296, 306, 297>,
    <307, 308, 298>,
    <307, 298, 297>,
    <307, 297, 309>,
    <307, 309, 310>,
    <307, 311, 312>,
    <307, 312, 313>,
    <307, 314, 315>,
    <307, 315, 308>,
    <316, 317, 298>,
    <316, 298, 308>,
    <316, 308, 318>,
    <316, 318, 319>,
    <316, 320, 321>,
    <316, 321, 322>,
    <316, 323, 324>,
    <316, 324, 317>,
    <325, 299, 298>,
    <325, 298, 317>,
    <325, 317, 326>,
    <325, 326, 327>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 299>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 338>,
    <333, 339, 340>,
    <333, 340, 341>,
    <333, 342, 343>,
    <333, 343, 334>,
    <344, 345, 335>,
    <344, 335, 334>,
    <344, 334, 346>,
    <344, 346, 347>,
    <344, 348, 349>,
    <344, 349, 350>,
    <344, 351, 352>,
    <344, 352, 345>,
    <353, 354, 335>,
    <353, 335, 345>,
    <353, 345, 355>,
    <353, 355, 356>,
    <353, 357, 358>,
    <353, 358, 359>,
    <353, 360, 361>,
    <353, 361, 354>,
    <362, 336, 335>,
    <362, 335, 354>,
    <362, 354, 363>,
    <362, 363, 364>,
    <362, 365, 366>,
    <362, 366, 367>,
    <362, 368, 369>,
    <362, 369, 336>,
    <370, 371, 372>,
    <370, 372, 373>,
    <370, 373, 374>,
    <370, 374, 375>,
    <370, 376, 377>,
    <370, 377, 378>,
    <370, 379, 380>,
    <370, 380, 371>,
    <381, 382, 372>,
    <381, 372, 371>,
    <381, 371, 383>,
    <381, 383, 384>,
    <381, 385, 386>,
    <381, 386, 387>,
    <381, 388, 389>,
    <381, 389, 382>,
    <390, 391, 372>,
    <390, 372, 382>,
    <390, 382, 392>,
    <390, 392, 393>,
    <390, 394, 395>,
    <390, 395, 396>,
    <390, 396, 397>,
    <390, 397, 391>,
    <398, 373, 372>,
    <398, 372, 391>,
    <398, 391, 397>,
    <398, 397, 399>,
    <398, 399, 400>,
    <398, 400, 401>,
    <398, 402, 403>,
    <398, 403, 373>,
    <404, 405, 406>,
    <404, 406, 407>,
    <404, 407, 408>,
    <404, 408, 409>,
    <404, 410, 411>,
    <404, 411, 412>,
    <404, 413, 414>,
    <404, 414, 405>,
    <415, 416, 406>,
    <415, 406, 405>,
    <415, 405, 417>,
    <415, 417, 418>,
    <415, 419, 420>,
    <415, 420, 421>,
    <415, 422, 423>,
    <415, 423, 416>,
    <424, 425, 406>,
    <424, 406, 416>,
    <424, 416, 426>,
    <424, 426, 427>,
    <424, 428, 429>,
    <424, 429, 430>,
    <424, 430, 431>,
    <424, 431, 425>,
    <432, 407, 406>,
    <432, 406, 425>,
    <432, 425, 431>,
    <432, 431, 433>,
    <432, 433, 434>,
    <432, 434, 435>,
    <432, 436, 437>,
    <432, 437, 407>,
    <438, 439, 440>,
    <438, 440, 441>,
    <438, 441, 442>,
    <438, 442, 443>,
    <438, 444, 445>,
    <438, 445, 446>,
    <438, 447, 448>,
    <438, 448, 439>,
    <449, 450, 440>,
    <449, 440, 439>,
    <449, 439, 451>,
    <449, 451, 452>,
    <449, 453, 454>,
    <449, 454, 455>,
    <449, 456, 457>,
    <449, 457, 450>,
    <458, 459, 440>,
    <458, 440, 450>,
    <458, 450, 460>,
    <458, 460, 461>,
    <458, 462, 463>,
    <458, 463, 464>,
    <458, 464, 465>,
    <458, 465, 459>,
    <466, 441, 440>,
    <466, 440, 459>,
    <466, 459, 465>,
    <466, 465, 467>,
    <466, 467, 468>,
    <466, 468, 469>,
    <466, 470, 471>,
    <466, 471, 441>,
    <472, 473, 474>,
    <472, 474, 475>,
    <472, 475, 476>,
    <472, 476, 477>,
    <472, 478, 479>,
    <472, 479, 399>,
    <472, 399, 397>,
    <472, 397, 473>,
    <480, 481, 474>,
    <480, 474, 473>,
    <480, 473, 397>,
    <480, 397, 396>,
    <480, 396, 482>,
    <480, 482, 483>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 487, 474>,
    <486, 474, 481>,
    <486, 481, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 492>,
    <486, 492, 493>,
    <486, 493, 487>,
    <494, 475, 474>,
    <494, 474, 487>,
    <494, 487, 493>,
    <494, 493, 495>,
    <494, 495, 496>,
    <494, 496, 497>,
    <494, 498, 499>,
    <494, 499, 475>,
    <500, 501, 502>,
    <500, 502, 503>,
    <500, 503, 504>,
    <500, 504, 505>,
    <500, 506, 507>,
    <500, 507, 433>,
    <500, 433, 431>,
    <500, 431, 501>,
    <508, 509, 502>,
    <508, 502, 501>,
    <508, 501, 431>,
    <508, 431, 430>,
    <508, 430, 510>,
    <508, 510, 511>,
    <508, 512, 513>,
    <508, 513, 509>,
    <514, 515, 502>,
    <514, 502, 509>,
    <514, 509, 516>,
    <514, 516, 517>,
    <514, 518, 519>,
    <514, 519, 520>,
    <514, 520, 521>,
    <514, 521, 515>,
    <522, 503, 502>,
    <522, 502, 515>,
    <522, 515, 521>,
    <522, 521, 523>,
    <522, 523, 524>,
    <522, 524, 525>,
    <522, 526, 527>,
    <522, 527, 503>,
    <528, 529, 530>,
    <528, 530, 531>,
    <528, 531, 532>,
    <528, 532, 533>,
    <528, 534, 535>,
    <528, 535, 467>,
    <528, 467, 465>,
    <528, 465, 529>,
    <536, 537, 530>,
    <536, 530, 529>,
    <536, 529, 465>,
    <536, 465, 464>,
    <536, 464, 538>,
    <536, 538, 539>,
    <536, 540, 541>,
    <536, 541, 537>,
    <542, 543, 530>,
    <542, 530, 537>,
    <542, 537, 544>,
    <542, 544, 545>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 549, 543>,
    <550, 531, 530>,
    <550, 530, 543>,
    <550, 543, 549>,
    <550, 549, 551>,
    <550, 551, 552>,
    <550, 552, 553>,
    <550, 554, 555>,
    <550, 555, 531>,
    <556, 557, 558>,
    <556, 558, 559>,
    <556, 559, 560>,
    <556, 560, 561>,
    <556, 562, 563>,
    <556, 563, 495>,
    <556, 495, 493>,
    <556, 493, 557>,
    <564, 565, 558>,
    <564, 558, 557>,
    <564, 557, 493>,
    <564, 493, 492>,
    <564, 492, 566>,
    <564, 566, 567>,
    <564, 568, 569>,
    <564, 569, 565>,
    <570, 571, 558>,
    <570, 558, 565>,
    <570, 565, 572>,
    <570, 572, 573>,
    <570, 574, 575>,
    <570, 575, 576>,
    <570, 577, 578>,
    <570, 578, 571>,
    <579, 559, 558>,
    <579, 558, 571>,
    <579, 571, 580>,
    <579, 580, 581>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 585, 586>,
    <579, 586, 559>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 591>,
    <587, 591, 592>,
    <587, 593, 594>,
    <587, 594, 523>,
    <587, 523, 521>,
    <587, 521, 588>,
    <595, 596, 589>,
    <595, 589, 588>,
    <595, 588, 521>,
    <595, 521, 520>,
    <595, 520, 597>,
    <595, 597, 598>,
    <595, 599, 600>,
    <595, 600, 596>,
    <601, 602, 589>,
    <601, 589, 596>,
    <601, 596, 603>,
    <601, 603, 604>,
    <601, 605, 606>,
    <601, 606, 607>,
    <601, 608, 609>,
    <601, 609, 602>,
    <610, 590, 589>,
    <610, 589, 602>,
    <610, 602, 611>,
    <610, 611, 612>,
    <610, 613, 614>,
    <610, 614, 615>,
    <610, 616, 617>,
    <610, 617, 590>,
    <618, 619, 620>,
    <618, 620, 621>,
    <618, 621, 622>,
    <618, 622, 623>,
    <618, 624, 625>,
    <618, 625, 551>,
    <618, 551, 549>,
    <618, 549, 619>,
    <626, 627, 620>,
    <626, 620, 619>,
    <626, 619, 549>,
    <626, 549, 548>,
    <626, 548, 628>,
    <626, 628, 629>,
    <626, 630, 631>,
    <626, 631, 627>,
    <632, 633, 620>,
    <632, 620, 627>,
    <632, 627, 634>,
    <632, 634, 635>,
    <632, 636, 637>,
    <632, 637, 638>,
    <632, 639, 640>,
    <632, 640, 633>,
    <641, 621, 620>,
    <641, 620, 633>,
    <641, 633, 642>,
    <641, 642, 643>,
    <641, 644, 645>,
    <641, 645, 646>,
    <641, 647, 648>,
    <641, 648, 621>,
    <649, 650, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 655, 656>,
    <649, 656, 657>,
    <649, 658, 659>,
    <649, 659, 650>,
    <660, 661, 651>,
    <660, 651, 650>,
    <660, 650, 662>,
    <660, 662, 663>,
    <660, 664, 665>,
    <660, 665, 666>,
    <660, 667, 668>,
    <660, 668, 661>,
    <669, 670, 651>,
    <669, 651, 661>,
    <669, 661, 671>,
    <669, 671, 672>,
    <669, 673, 674>,
    <669, 674, 675>,
    <669, 676, 677>,
    <669, 677, 670>,
    <678, 652, 651>,
    <678, 651, 670>,
    <678, 670, 679>,
    <678, 679, 680>,
    <678, 681, 682>,
    <678, 682, 683>,
    <678, 684, 685>,
    <678, 685, 652>,
    <686, 687, 688>,
    <686, 688, 689>,
    <686, 689, 690>,
    <686, 690, 691>,
    <686, 692, 693>,
    <686, 693, 694>,
    <686, 695, 696>,
    <686, 696, 687>,
    <697, 698, 688>,
    <697, 688, 687>,
    <697, 687, 699>,
    <697, 699, 700>,
    <697, 701, 702>,
    <697, 702, 703>,
    <697, 704, 705>,
    <697, 705, 698>,
    <706, 707, 688>,
    <706, 688, 698>,
    <706, 698, 708>,
    <706, 708, 709>,
    <706, 710, 711>,
    <706, 711, 712>,
    <706, 713, 714>,
    <706, 714, 707>,
    <715, 689, 688>,
    <715, 688, 707>,
    <715, 707, 716>,
    <715, 716, 717>,
    <715, 718, 719>,
    <715, 719, 720>,
    <715, 721, 722>,
    <715, 722, 689>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 727>,
    <723, 727, 728>,
    <723, 729, 730>,
    <723, 730, 731>,
    <723, 732, 733>,
    <723, 733, 724>,
    <734, 735, 725>,
    <734, 725, 724>,
    <734, 724, 736>,
    <734, 736, 737>,
    <734, 738, 739>,
    <734, 739, 740>,
    <734, 741, 742>,
    <734, 742, 735>,
    <743, 744, 725>,
    <743, 725, 735>,
    <743, 735, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 749>,
    <743, 750, 751>,
    <743, 751, 744>,
    <752, 726, 725>,
    <752, 725, 744>,
    <752, 744, 753>,
    <752, 753, 754>,
    <752, 755, 756>,
    <752, 756, 757>,
    <752, 758, 759>,
    <752, 759, 726>,
    <760, 761, 762>,
    <760, 762, 763>,
    <760, 763, 764>,
    <760, 764, 765>,
    <760, 766, 767>,
    <760, 767, 768>,
    <760, 769, 770>,
    <760, 770, 761>,
    <771, 772, 762>,
    <771, 762, 761>,
    <771, 761, 773>,
    <771, 773, 774>,
    <771, 775, 776>,
    <771, 776, 777>,
    <771, 778, 779>,
    <771, 779, 772>,
    <780, 781, 762>,
    <780, 762, 772>,
    <780, 772, 782>,
    <780, 782, 783>,
    <780, 784, 785>,
    <780, 785, 786>,
    <780, 787, 788>,
    <780, 788, 781>,
    <789, 763, 762>,
    <789, 762, 781>,
    <789, 781, 790>,
    <789, 790, 791>,
    <789, 792, 793>,
    <789, 793, 794>,
    <789, 795, 796>,
    <789, 796, 763>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 801>,
    <797, 801, 802>,
    <797, 803, 804>,
    <797, 804, 805>,
    <797, 806, 807>,
    <797, 807, 798>,
    <808, 809, 799>,
    <808, 799, 798>,
    <808, 798, 810>,
    <808, 810, 811>,
    <808, 812, 813>,
    <808, 813, 814>,
    <808, 815, 816>,
    <808, 816, 809>,
    <817, 818, 799>,
    <817, 799, 809>,
    <817, 809, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 823>,
    <817, 824, 825>,
    <817, 825, 818>,
    <826, 800, 799>,
    <826, 799, 818>,
    <826, 818, 827>,
    <826, 827, 828>,
    <826, 829, 830>,
    <826, 830, 831>,
    <826, 832, 833>,
    <826, 833, 800>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 843, 844>,
    <834, 844, 835>,
    <845, 846, 836>,
    <845, 836, 835>,
    <845, 835, 847>,
    <845, 847, 848>,
    <845, 849, 850>,
    <845, 850, 851>,
    <845, 852, 853>,
    <845, 853, 846>,
    <854, 855, 836>,
    <854, 836, 846>,
    <854, 846, 856>,
    <854, 856, 857>,
    <854, 858, 859>,
    <854, 859, 860>,
    <854, 861, 862>,
    <854, 862, 855>,
    <863, 837, 836>,
    <863, 836, 855>,
    <863, 855, 864>,
    <863, 864, 865>,
    <863, 866, 867>,
    <863, 867, 868>,
    <863, 869, 870>,
    <863, 870, 837>,
    <871, 872, 873>,
    <871, 873, 874>,
    <871, 874, 875>,
    <871, 875, 876>,
    <871, 877, 878>,
    <871, 878, 879>,
    <871, 880, 881>,
    <871, 881, 872>,
    <882, 883, 873>,
    <882, 873, 872>,
    <882, 872, 884>,
    <882, 884, 885>,
    <882, 886, 887>,
    <882, 887, 888>,
    <882, 889, 890>,
    <882, 890, 883>,
    <891, 892, 873>,
    <891, 873, 883>,
    <891, 883, 893>,
    <891, 893, 894>,
    <891, 895, 896>,
    <891, 896, 897>,
    <891, 898, 899>,
    <891, 899, 892>,
    <900, 874, 873>,
    <900, 873, 892>,
    <900, 892, 901>,
    <900, 901, 902>,
    <900, 903, 904>,
    <900, 904, 905>,
    <900, 906, 907>,
    <900, 907, 874>,
    <908, 909, 910>,
    <908, 910, 911>,
    <908, 911, 912>,
    <908, 912, 913>,
    <908, 914, 915>,
    <908, 915, 916>,
    <908, 917, 918>,
    <908, 918, 909>,
    <919, 920, 910>,
    <919, 910, 909>,
    <919, 909, 921>,
    <919, 921, 922>,
    <919, 923, 924>,
    <919, 924, 925>,
    <919, 926, 927>,
    <919, 927, 920>,
    <928, 929, 910>,
    <928, 910, 920>,
    <928, 920, 930>,
    <928, 930, 931>,
    <928, 932, 933>,
    <928, 933, 934>,
    <928, 935, 936>,
    <928, 936, 929>,
    <937, 911, 910>,
    <937, 910, 929>,
    <937, 929, 938>,
    <937, 938, 939>,
    <937, 940, 941>,
    <937, 941, 942>,
    <937, 943, 944>,
    <937, 944, 911>,
    <945, 946, 947>,
    <945, 947, 948>,
    <945, 948, 949>,
    <945, 949, 950>,
    <945, 951, 952>,
    <945, 952, 953>,
    <945, 954, 955>,
    <945, 955, 946>,
    <956, 957, 947>,
    <956, 947, 946>,
    <956, 946, 958>,
    <956, 958, 959>,
    <956, 960, 961>,
    <956, 961, 962>,
    <956, 963, 964>,
    <956, 964, 957>,
    <965, 966, 947>,
    <965, 947, 957>,
    <965, 957, 967>,
    <965, 967, 968>,
    <965, 969, 970>,
    <965, 970, 971>,
    <965, 972, 973>,
    <965, 973, 966>,
    <974, 948, 947>,
    <974, 947, 966>,
    <974, 966, 975>,
    <974, 975, 976>,
    <974, 977, 978>,
    <974, 978, 979>,
    <974, 980, 981>,
    <974, 981, 948>,
    <982, 983, 984>,
    <982, 984, 985>,
    <982, 985, 986>,
    <982, 986, 987>,
    <982, 988, 989>,
    <982, 989, 990>,
    <982, 991, 992>,
    <982, 992, 983>,
    <993, 994, 984>,
    <993, 984, 983>,
    <993, 983, 995>,
    <993, 995, 996>,
    <993, 997, 998>,
    <993, 998, 999>,
    <993, 1000, 1001>,
    <993, 1001, 994>,
    <1002, 1003, 984>,
    <1002, 984, 994>,
    <1002, 994, 1004>,
    <1002, 1004, 1005>,
    <1002, 1006, 1007>,
    <1002, 1007, 1008>,
    <1002, 1009, 1010>,
    <1002, 1010, 1003>,
    <1011, 985, 984>,
    <1011, 984, 1003>,
    <1011, 1003, 1012>,
    <1011, 1012, 1013>,
    <1011, 1014, 1015>,
    <1011, 1015, 1016>,
    <1011, 1017, 1018>,
    <1011, 1018, 985>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1023>,
    <1019, 1023, 1024>,
    <1019, 1025, 1026>,
    <1019, 1026, 1027>,
    <1019, 1028, 1029>,
    <1019, 1029, 1020>,
    <1030, 1031, 1021>,
    <1030, 1021, 1020>,
    <1030, 1020, 1032>,
    <1030, 1032, 1033>,
    <1030, 1034, 1035>,
    <1030, 1035, 1036>,
    <1030, 1037, 1038>,
    <1030, 1038, 1031>,
    <1039, 1040, 1021>,
    <1039, 1021, 1031>,
    <1039, 1031, 1041>,
    <1039, 1041, 1042>,
    <1039, 1043, 1044>,
    <1039, 1044, 1045>,
    <1039, 1046, 1047>,
    <1039, 1047, 1040>,
    <1048, 1022, 1021>,
    <1048, 1021, 1040>,
    <1048, 1040, 1049>,
    <1048, 1049, 1050>,
    <1048, 1051, 1052>,
    <1048, 1052, 1053>,
    <1048, 1054, 1055>,
    <1048, 1055, 1022>,
    <1056, 1057, 1058>,
    <1056, 1058, 1059>,
    <1056, 1059, 1060>,
    <1056, 1060, 1061>,
    <1056, 1062, 1063>,
    <1056, 1063, 1064>,
    <1056, 1065, 1066>,
    <1056, 1066, 1057>,
    <1067, 1068, 1058>,
    <1067, 1058, 1057>,
    <1067, 1057, 1069>,
    <1067, 1069, 1070>,
    <1067, 1071, 1072>,
    <1067, 1072, 1073>,
    <1067, 1074, 1075>,
    <1067, 1075, 1068>,
    <1076, 1077, 1058>,
    <1076, 1058, 1068>,
    <1076, 1068, 1078>,
    <1076, 1078, 1079>,
    <1076, 1080, 1081>,
    <1076, 1081, 1082>,
    <1076, 1083, 1084>,
    <1076, 1084, 1077>,
    <1085, 1059, 1058>,
    <1085, 1058, 1077>,
    <1085, 1077, 1086>,
    <1085, 1086, 1087>,
    <1085, 1088, 1089>,
    <1085, 1089, 1090>,
    <1085, 1091, 1092>,
    <1085, 1092, 1059>,
    <1093, 1094, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1099, 1100>,
    <1093, 1100, 1101>,
    <1093, 1101, 1102>,
    <1093, 1102, 1094>,
    <1103, 1104, 1095>,
    <1103, 1095, 1094>,
    <1103, 1094, 1102>,
    <1103, 1102, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1107>,
    <1103, 1108, 1109>,
    <1103, 1109, 1104>,
    <1110, 1111, 1095>,
    <1110, 1095, 1104>,
    <1110, 1104, 1112>,
    <1110, 1112, 1113>,
    <1110, 1114, 1115>,
    <1110, 1115, 1116>,
    <1110, 1117, 1118>,
    <1110, 1118, 1111>,
    <1119, 1096, 1095>,
    <1119, 1095, 1111>,
    <1119, 1111, 1120>,
    <1119, 1120, 1121>,
    <1119, 1122, 1123>,
    <1119, 1123, 1124>,
    <1119, 1125, 1126>,
    <1119, 1126, 1096>,
    <1127, 1128, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1102>,
    <1127, 1102, 1101>,
    <1127, 1101, 1131>,
    <1127, 1131, 1132>,
    <1127, 1133, 1134>,
    <1127, 1134, 1128>,
    <1135, 1136, 1129>,
    <1135, 1129, 1128>,
    <1135, 1128, 1137>,
    <1135, 1137, 1138>,
    <1135, 1139, 1140>,
    <1135, 1140, 1141>,
    <1135, 1142, 1143>,
    <1135, 1143, 1136>,
    <1144, 1145, 1129>,
    <1144, 1129, 1136>,
    <1144, 1136, 1146>,
    <1144, 1146, 1147>,
    <1144, 1148, 1149>,
    <1144, 1149, 1150>,
    <1144, 1151, 1152>,
    <1144, 1152, 1145>,
    <1153, 1130, 1129>,
    <1153, 1129, 1145>,
    <1153, 1145, 1154>,
    <1153, 1154, 1155>,
    <1153, 1156, 1157>,
    <1153, 1157, 1105>,
    <1153, 1105, 1102>,
    <1153, 1102, 1130>
  }
  uv_indices {
    1056,   // from 0 triangles and 528 quads
    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1054, 1047>,
    <1046, 1047, 1051>    <1046, 1051, 1048>,
    <1046, 1048, 1052>    <1046, 1052, 1049>,
    <1046, 1049, 1053>    <1046, 1053, 1050>,
    <1046, 1050, 1054>    <1055, 1063, 1056>,
    <1055, 1056, 1060>    <1055, 1060, 1057>,
    <1055, 1057, 1061>    <1055, 1061, 1058>,
    <1055, 1058, 1062>    <1055, 1062, 1059>,
    <1055, 1059, 1063>    <1064, 1072, 1065>,
    <1064, 1065, 1069>    <1064, 1069, 1066>,
    <1064, 1066, 1070>    <1064, 1070, 1067>,
    <1064, 1067, 1071>    <1064, 1071, 1068>,
    <1064, 1068, 1072>    <1073, 1081, 1074>,
    <1073, 1074, 1078>    <1073, 1078, 1075>,
    <1073, 1075, 1079>    <1073, 1079, 1076>,
    <1073, 1076, 1080>    <1073, 1080, 1077>,
    <1073, 1077, 1081>    <1082, 1090, 1083>,
    <1082, 1083, 1087>    <1082, 1087, 1084>,
    <1082, 1084, 1088>    <1082, 1088, 1085>,
    <1082, 1085, 1089>    <1082, 1089, 1086>,
    <1082, 1086, 1090>    <1091, 1099, 1092>,
    <1091, 1092, 1096>    <1091, 1096, 1093>,
    <1091, 1093, 1097>    <1091, 1097, 1094>,
    <1091, 1094, 1098>    <1091, 1098, 1095>,
    <1091, 1095, 1099>    <1100, 1108, 1101>,
    <1100, 1101, 1105>    <1100, 1105, 1102>,
    <1100, 1102, 1106>    <1100, 1106, 1103>,
    <1100, 1103, 1107>    <1100, 1107, 1104>,
    <1100, 1104, 1108>    <1109, 1117, 1110>,
    <1109, 1110, 1114>    <1109, 1114, 1111>,
    <1109, 1111, 1115>    <1109, 1115, 1112>,
    <1109, 1112, 1116>    <1109, 1116, 1113>,
    <1109, 1113, 1117>    <1118, 1126, 1119>,
    <1118, 1119, 1123>    <1118, 1123, 1120>,
    <1118, 1120, 1124>    <1118, 1124, 1121>,
    <1118, 1121, 1125>    <1118, 1125, 1122>,
    <1118, 1122, 1126>    <1127, 1135, 1128>,
    <1127, 1128, 1132>    <1127, 1132, 1129>,
    <1127, 1129, 1133>    <1127, 1133, 1130>,
    <1127, 1130, 1134>    <1127, 1134, 1131>,
    <1127, 1131, 1135>    <1136, 1144, 1137>,
    <1136, 1137, 1141>    <1136, 1141, 1138>,
    <1136, 1138, 1142>    <1136, 1142, 1139>,
    <1136, 1139, 1143>    <1136, 1143, 1140>,
    <1136, 1140, 1144>    <1145, 1153, 1146>,
    <1145, 1146, 1150>    <1145, 1150, 1147>,
    <1145, 1147, 1151>    <1145, 1151, 1148>,
    <1145, 1148, 1152>    <1145, 1152, 1149>,
    <1145, 1149, 1153>    <1154, 1162, 1155>,
    <1154, 1155, 1159>    <1154, 1159, 1156>,
    <1154, 1156, 1160>    <1154, 1160, 1157>,
    <1154, 1157, 1161>    <1154, 1161, 1158>,
    <1154, 1158, 1162>    <1163, 1171, 1164>,
    <1163, 1164, 1168>    <1163, 1168, 1165>,
    <1163, 1165, 1169>    <1163, 1169, 1166>,
    <1163, 1166, 1170>    <1163, 1170, 1167>,
    <1163, 1167, 1171>    <1172, 1180, 1173>,
    <1172, 1173, 1177>    <1172, 1177, 1174>,
    <1172, 1174, 1178>    <1172, 1178, 1175>,
    <1172, 1175, 1179>    <1172, 1179, 1176>,
    <1172, 1176, 1180>    <1181, 1189, 1182>,
    <1181, 1182, 1186>    <1181, 1186, 1183>,
    <1181, 1183, 1187>    <1181, 1187, 1184>,
    <1181, 1184, 1188>    <1181, 1188, 1185>,
    <1181, 1185, 1189>    <1190, 1198, 1191>,
    <1190, 1191, 1195>    <1190, 1195, 1192>,
    <1190, 1192, 1196>    <1190, 1196, 1193>,
    <1190, 1193, 1197>    <1190, 1197, 1194>,
    <1190, 1194, 1198>    <1199, 1207, 1200>,
    <1199, 1200, 1204>    <1199, 1204, 1201>,
    <1199, 1201, 1205>    <1199, 1205, 1202>,
    <1199, 1202, 1206>    <1199, 1206, 1203>,
    <1199, 1203, 1207>    <1208, 1216, 1209>,
    <1208, 1209, 1213>    <1208, 1213, 1210>,
    <1208, 1210, 1214>    <1208, 1214, 1211>,
    <1208, 1211, 1215>    <1208, 1215, 1212>,
    <1208, 1212, 1216>    <1217, 1225, 1218>,
    <1217, 1218, 1222>    <1217, 1222, 1219>,
    <1217, 1219, 1223>    <1217, 1223, 1220>,
    <1217, 1220, 1224>    <1217, 1224, 1221>,
    <1217, 1221, 1225>    <1226, 1234, 1227>,
    <1226, 1227, 1231>    <1226, 1231, 1228>,
    <1226, 1228, 1232>    <1226, 1232, 1229>,
    <1226, 1229, 1233>    <1226, 1233, 1230>,
    <1226, 1230, 1234>    <1235, 1243, 1236>,
    <1235, 1236, 1240>    <1235, 1240, 1237>,
    <1235, 1237, 1241>    <1235, 1241, 1238>,
    <1235, 1238, 1242>    <1235, 1242, 1239>,
    <1235, 1239, 1243>    <1244, 1252, 1245>,
    <1244, 1245, 1249>    <1244, 1249, 1246>,
    <1244, 1246, 1250>    <1244, 1250, 1247>,
    <1244, 1247, 1251>    <1244, 1251, 1248>,
    <1244, 1248, 1252>    <1253, 1261, 1254>,
    <1253, 1254, 1258>    <1253, 1258, 1255>,
    <1253, 1255, 1259>    <1253, 1259, 1256>,
    <1253, 1256, 1260>    <1253, 1260, 1257>,
    <1253, 1257, 1261>    <1262, 1270, 1263>,
    <1262, 1263, 1267>    <1262, 1267, 1264>,
    <1262, 1264, 1268>    <1262, 1268, 1265>,
    <1262, 1265, 1269>    <1262, 1269, 1266>,
    <1262, 1266, 1270>    <1271, 1279, 1272>,
    <1271, 1272, 1276>    <1271, 1276, 1273>,
    <1271, 1273, 1277>    <1271, 1277, 1274>,
    <1271, 1274, 1278>    <1271, 1278, 1275>,
    <1271, 1275, 1279>    <1280, 1288, 1281>,
    <1280, 1281, 1285>    <1280, 1285, 1282>,
    <1280, 1282, 1286>    <1280, 1286, 1283>,
    <1280, 1283, 1287>    <1280, 1287, 1284>,
    <1280, 1284, 1288>    <1289, 1297, 1290>,
    <1289, 1290, 1294>    <1289, 1294, 1291>,
    <1289, 1291, 1295>    <1289, 1295, 1292>,
    <1289, 1292, 1296>    <1289, 1296, 1293>,
    <1289, 1293, 1297>    <1298, 1306, 1299>,
    <1298, 1299, 1303>    <1298, 1303, 1300>,
    <1298, 1300, 1304>    <1298, 1304, 1301>,
    <1298, 1301, 1305>    <1298, 1305, 1302>,
    <1298, 1302, 1306>    <1307, 1315, 1308>,
    <1307, 1308, 1312>    <1307, 1312, 1309>,
    <1307, 1309, 1313>    <1307, 1313, 1310>,
    <1307, 1310, 1314>    <1307, 1314, 1311>,
    <1307, 1311, 1315>    <1316, 1324, 1317>,
    <1316, 1317, 1321>    <1316, 1321, 1318>,
    <1316, 1318, 1322>    <1316, 1322, 1319>,
    <1316, 1319, 1323>    <1316, 1323, 1320>,
    <1316, 1320, 1324>    <1325, 1333, 1326>,
    <1325, 1326, 1330>    <1325, 1330, 1327>,
    <1325, 1327, 1331>    <1325, 1331, 1328>,
    <1325, 1328, 1332>    <1325, 1332, 1329>,
    <1325, 1329, 1333>    <1334, 1342, 1335>,
    <1334, 1335, 1339>    <1334, 1339, 1336>,
    <1334, 1336, 1340>    <1334, 1340, 1337>,
    <1334, 1337, 1341>    <1334, 1341, 1338>,
    <1334, 1338, 1342>    <1343, 1351, 1344>,
    <1343, 1344, 1348>    <1343, 1348, 1345>,
    <1343, 1345, 1349>    <1343, 1349, 1346>,
    <1343, 1346, 1350>    <1343, 1350, 1347>,
    <1343, 1347, 1351>    <1352, 1360, 1353>,
    <1352, 1353, 1357>    <1352, 1357, 1354>,
    <1352, 1354, 1358>    <1352, 1358, 1355>,
    <1352, 1355, 1359>    <1352, 1359, 1356>,
    <1352, 1356, 1360>    <1361, 1369, 1362>,
    <1361, 1362, 1366>    <1361, 1366, 1363>,
    <1361, 1363, 1367>    <1361, 1367, 1364>,
    <1361, 1364, 1368>    <1361, 1368, 1365>,
    <1361, 1365, 1369>    <1370, 1378, 1371>,
    <1370, 1371, 1375>    <1370, 1375, 1372>,
    <1370, 1372, 1376>    <1370, 1376, 1373>,
    <1370, 1373, 1377>    <1370, 1377, 1374>,
    <1370, 1374, 1378>    <1379, 1387, 1380>,
    <1379, 1380, 1384>    <1379, 1384, 1381>,
    <1379, 1381, 1385>    <1379, 1385, 1382>,
    <1379, 1382, 1386>    <1379, 1386, 1383>,
    <1379, 1383, 1387>    <1388, 1396, 1389>,
    <1388, 1389, 1393>    <1388, 1393, 1390>,
    <1388, 1390, 1394>    <1388, 1394, 1391>,
    <1388, 1391, 1395>    <1388, 1395, 1392>,
    <1388, 1392, 1396>    <1397, 1405, 1398>,
    <1397, 1398, 1402>    <1397, 1402, 1399>,
    <1397, 1399, 1403>    <1397, 1403, 1400>,
    <1397, 1400, 1404>    <1397, 1404, 1401>,
    <1397, 1401, 1405>    <1406, 1414, 1407>,
    <1406, 1407, 1411>    <1406, 1411, 1408>,
    <1406, 1408, 1412>    <1406, 1412, 1409>,
    <1406, 1409, 1413>    <1406, 1413, 1410>,
    <1406, 1410, 1414>    <1415, 1423, 1416>,
    <1415, 1416, 1420>    <1415, 1420, 1417>,
    <1415, 1417, 1421>    <1415, 1421, 1418>,
    <1415, 1418, 1422>    <1415, 1422, 1419>,
    <1415, 1419, 1423>    <1424, 1432, 1425>,
    <1424, 1425, 1429>    <1424, 1429, 1426>,
    <1424, 1426, 1430>    <1424, 1430, 1427>,
    <1424, 1427, 1431>    <1424, 1431, 1428>,
    <1424, 1428, 1432>    <1433, 1441, 1434>,
    <1433, 1434, 1438>    <1433, 1438, 1435>,
    <1433, 1435, 1439>    <1433, 1439, 1436>,
    <1433, 1436, 1440>    <1433, 1440, 1437>,
    <1433, 1437, 1441>    <1442, 1450, 1443>,
    <1442, 1443, 1447>    <1442, 1447, 1444>,
    <1442, 1444, 1448>    <1442, 1448, 1445>,
    <1442, 1445, 1449>    <1442, 1449, 1446>,
    <1442, 1446, 1450>    <1451, 1459, 1452>,
    <1451, 1452, 1456>    <1451, 1456, 1453>,
    <1451, 1453, 1457>    <1451, 1457, 1454>,
    <1451, 1454, 1458>    <1451, 1458, 1455>,
    <1451, 1455, 1459>    <1460, 1468, 1461>,
    <1460, 1461, 1465>    <1460, 1465, 1462>,
    <1460, 1462, 1466>    <1460, 1466, 1463>,
    <1460, 1463, 1467>    <1460, 1467, 1464>,
    <1460, 1464, 1468>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>    <0, 0, 0>,
    <0, 0, 0>
  }
  translate  <0.0, 0.0, 0.0>
  translate  <0.011335, 0.63719, -0.147353>
}

#declare Moulure = union {
  object { TMesh003 }
  object { TMesh004 }
  object { TMesh005 }
  object { TMesh006 }
}
#declare Chainette = union {
  object { Elment_chainette1 }
  object { // Elment_chainette2 -> Elment_chainette1
    Elment_chainette1
    translate  0.6*z
  }
  object { // Elment_chainette3 -> Elment_chainette1
    Elment_chainette1
    translate  1.2*z
  }
  object { // Elment_chainette4 -> Elment_chainette1
    Elment_chainette1
    translate  1.8*z
  }
  object { // Elment_chainette5 -> Elment_chainette1
    Elment_chainette1
    translate  2.4*z
  }
  object { // Elment_chainette6 -> Elment_chainette1
    Elment_chainette1
    translate  3.0*z
  }
  object { // Elment_chainette7 -> Elment_chainette1
    Elment_chainette1
    translate  3.6*z
  }
  object { // Elment_chainette8 -> Elment_chainette1
    Elment_chainette1
    translate  4.2*z
  }
  object { // Elment_chainette9 -> Elment_chainette1
    Elment_chainette1
    translate  4.8*z
  }
  object { // Elment_chainette10 -> Elment_chainette1
    Elment_chainette1
    translate  5.4*z
  }
  object { // Elment_chainette11 -> Elment_chainette1
    Elment_chainette1
    translate  6.0*z
  }
  object { // Elment_chainette12 -> Elment_chainette1
    Elment_chainette1
    translate  6.6*z
  }
  object { // Elment_chainette13 -> Elment_chainette1
    Elment_chainette1
    translate  7.2*z
  }
  object { // Elment_chainette14 -> Elment_chainette1
    Elment_chainette1
    translate  7.8*z
  }
  object { // Elment_chainette15 -> Elment_chainette1
    Elment_chainette1
    translate  8.4*z
  }
  object { // Elment_chainette16 -> Elment_chainette1
    Elment_chainette1
    translate  9.0*z
  }
  object { // Elment_chainette17 -> Elment_chainette1
    Elment_chainette1
    translate  9.6*z
  }
  object { // Elment_chainette18 -> Elment_chainette1
    Elment_chainette1
    translate  10.2*z
  }
  object { // Elment_chainette19 -> Elment_chainette1
    Elment_chainette1
    translate  10.8*z
  }
  object { // Elment_chainette20 -> Elment_chainette1
    Elment_chainette1
    translate  11.4*z
  }
  object { // Elment_chainette21 -> Elment_chainette1
    Elment_chainette1
    translate  12.0*z
  }
  object { // Elment_chainette22 -> Elment_chainette1
    Elment_chainette1
    translate  12.6*z
  }
  object { // Elment_chainette23 -> Elment_chainette1
    Elment_chainette1
    translate  13.2*z
  }
  translate  <0.418855, -1.019829, -7.971559>
  material {
    Tchainette
    scale <1.506189, 0.310166, 28.878397>
    translate <0.807778, 0.172112, -6.952899>
  }
  scale 0.718742
  rotate <-1.417487, -0.657999, -0.004106>
  translate  <-0.033101, 0.086632, 7.971559>
}


#declare Aile2 = union { 
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-20.174618, -3.564253, -1.949357>, <-20.174618, -3.564253, -1.949357>, <-20.149410, -3.762917, -1.934879>, <-20.149410, -3.762917, -1.934879>, 
      <-15.479721, -1.642144, -0.481616>, <-15.300936, -2.496549, -0.412088>, <-15.100416, -3.777686, -0.655198>, <-15.100416, -3.777686, -0.655198>, 
      <-10.800997, -0.236167, 2.189677>, <-10.462826, -1.694224, 2.291678>, <-12.070319, -3.927719, 2.161793>, <-12.070319, -3.927719, 2.161793>, 
      <-9.529535, 0.156809, 2.022653>, <-9.287086, -1.149002, 2.112139>, <-10.082800, -3.218283, 1.962014>, <-10.082800, -3.218283, 1.962014>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-20.149410, -3.762917, -1.934879>, <-20.149410, -3.762917, -1.934879>, <-20.174618, -3.564253, -1.949357>, <-20.174618, -3.564253, -1.949357>, 
      <-15.100416, -3.777686, -0.655198>, <-15.100416, -3.777686, -0.655198>, <-15.239906, -2.512887, -0.657857>, <-15.404043, -1.662403, -0.786369>, 
      <-12.070319, -3.927719, 2.161793>, <-12.070319, -3.927719, 2.161793>, <-10.438338, -1.712604, 2.039209>, <-10.770631, -0.258958, 1.876616>, 
      <-10.082800, -3.218283, 1.962014>, <-10.082800, -3.218283, 1.962014>, <-9.299512, -1.168654, 1.861604>, <-9.544943, 0.132440, 1.711989>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-20.174618, -3.564253, -1.949357>, <-20.174618, -3.564253, -1.949357>, <-20.174618, -3.564253, -1.949357>, <-20.174618, -3.564253, -1.949357>, 
      <-15.404043, -1.662403, -0.786369>, <-15.568179, -0.811919, -0.914881>, <-15.606207, -0.666193, -0.894425>, <-15.606207, -0.666193, -0.894425>, 
      <-10.770631, -0.258958, 1.876616>, <-11.102924, 1.194689, 1.714022>, <-11.147991, 1.406420, 1.733726>, <-11.147991, 1.406420, 1.733726>, 
      <-9.544943, 0.132440, 1.711989>, <-9.790374, 1.433535, 1.562375>, <-9.813558, 1.647651, 1.583214>, <-9.813558, 1.647651, 1.583214>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-20.174618, -3.564253, -1.949357>, <-20.174618, -3.564253, -1.949357>, <-20.174618, -3.564253, -1.949357>, <-20.174618, -3.564253, -1.949357>, 
      <-15.606207, -0.666193, -0.894425>, <-15.606207, -0.666193, -0.894425>, <-15.658505, -0.787738, -0.551144>, <-15.479721, -1.642144, -0.481616>, 
      <-11.147991, 1.406420, 1.733726>, <-11.147991, 1.406420, 1.733726>, <-11.139167, 1.221891, 2.087677>, <-10.800997, -0.236167, 2.189677>, 
      <-9.813558, 1.647651, 1.583214>, <-9.813558, 1.647651, 1.583214>, <-9.771983, 1.462620, 1.933167>, <-9.529535, 0.156809, 2.022653>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.529535, 0.156809, 2.022653>, <-9.287086, -1.149002, 2.112139>, <-10.082800, -3.218283, 1.962014>, <-10.082800, -3.218283, 1.962014>, 
      <-8.258073, 0.549784, 1.855628>, <-8.111346, -0.603780, 1.932600>, <-8.095281, -2.508848, 1.762234>, <-8.095281, -2.508848, 1.762234>, 
      <-4.751568, 0.746950, 1.186940>, <-4.705429, -0.525019, 1.249646>, <-4.689365, -2.430087, 1.079280>, <-4.689365, -2.430087, 1.079280>, 
      <-1.024287, -0.525625, 1.509037>, <-0.798271, -3.194370, 1.696236>, <-1.030090, -2.817990, 0.269170>, <-1.030090, -2.817990, 0.269170>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.082800, -3.218283, 1.962014>, <-10.082800, -3.218283, 1.962014>, <-9.299512, -1.168654, 1.861604>, <-9.544943, 0.132440, 1.711989>, 
      <-8.095281, -2.508848, 1.762234>, <-8.095281, -2.508848, 1.762234>, <-8.160687, -0.624704, 1.683998>, <-8.319255, 0.523838, 1.547363>, 
      <-4.689365, -2.430087, 1.079280>, <-4.689365, -2.430087, 1.079280>, <-4.754770, -0.545943, 1.001045>, <-4.812751, 0.721004, 0.878675>, 
      <-1.030090, -2.817990, 0.269170>, <-1.030090, -2.817990, 0.269170>, <-0.900483, -3.243144, 0.045493>, <-1.125221, -0.597431, -0.024226>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.544943, 0.132440, 1.711989>, <-9.790374, 1.433535, 1.562375>, <-9.813558, 1.647651, 1.583214>, <-9.813558, 1.647651, 1.583214>, 
      <-8.319255, 0.523838, 1.547363>, <-8.477824, 1.672381, 1.410728>, <-8.479125, 1.888882, 1.432701>, <-8.479125, 1.888882, 1.432701>, 
      <-4.812751, 0.721004, 0.878675>, <-4.870732, 1.987952, 0.756305>, <-4.872033, 2.204452, 0.778278>, <-4.872033, 2.204452, 0.778278>, 
      <-1.125221, -0.597431, -0.024226>, <-1.349959, 2.048282, -0.093944>, <-1.345551, 2.271640, 0.005972>, <-1.345551, 2.271640, 0.005972>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.813558, 1.647651, 1.583214>, <-9.813558, 1.647651, 1.583214>, <-9.771983, 1.462620, 1.933167>, <-9.529535, 0.156809, 2.022653>, 
      <-8.479125, 1.888882, 1.432701>, <-8.479125, 1.888882, 1.432701>, <-8.404799, 1.703349, 1.778657>, <-8.258073, 0.549784, 1.855628>, 
      <-4.872033, 2.204452, 0.778278>, <-4.872033, 2.204452, 0.778278>, <-4.797708, 2.018920, 1.124235>, <-4.751568, 0.746950, 1.186940>, 
      <-1.345551, 2.271640, 0.005972>, <-1.345551, 2.271640, 0.005972>, <-1.250304, 2.143120, 1.321838>, <-1.024287, -0.525625, 1.509037>
    }
  }
  material {
    T_Aile
    scale <3.241477, 16.962219, 1.0>
    rotate <-0.0, -0.0, -38.817162>
    translate <-3.474539, 4.388892, 0.000000>
  }
  photons {
    collect off
  }
  scale <1.341523, 1.046898, 1.213809>
  rotate <2.12368, 9.217231, -3.356475>
  translate  <0.242124, 0.33622, -0.763404>
}
#declare Bec2 = union { 
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-0.207992, 0.000167, 0.102995>, <-0.207992, -0.000837, 0.407501>, <0.207992, -0.000837, 0.407501>, <0.207992, 0.000167, 0.102995>, 
      <-0.207992, 0.316869, 0.001146>, <-0.207992, 0.315958, 0.178232>, <0.207992, 0.315958, 0.178232>, <0.207992, 0.316869, 0.001146>, 
      <-0.268572, 0.934675, 0.118545>, <-0.268572, 0.920167, 0.578491>, <0.268572, 0.920167, 0.578491>, <0.268572, 0.934675, 0.118545>, 
      <-0.024126, 1.362628, -0.090542>, <-0.024126, 1.362628, -0.090542>, <0.024126, 1.362628, -0.090542>, <0.024126, 1.362628, -0.090542>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <0.207992, 0.000167, 0.102995>, <0.207992, 0.001172, -0.201511>, <-0.207992, 0.001172, -0.201511>, <-0.207992, 0.000167, 0.102995>, 
      <0.207992, 0.316869, 0.001146>, <0.207992, 0.317781, -0.175940>, <-0.207992, 0.317781, -0.175940>, <-0.207992, 0.316869, 0.001146>, 
      <0.268572, 0.934675, 0.118545>, <0.268572, 0.949184, -0.341402>, <-0.268572, 0.949184, -0.341401>, <-0.268572, 0.934675, 0.118545>, 
      <0.024126, 1.362628, -0.090542>, <0.024126, 1.362628, -0.090542>, <-0.024126, 1.362628, -0.090542>, <-0.024126, 1.362628, -0.090542>
    }
  }
  material {
    T_Bec
  }
  photons {
    collect off
  }
  rotate <-21.919657, 2.63649, 9.77064>
  translate  <-0.298897, 8.417439, -0.522823>
}
#declare Oeil2 = object {
  sphere { // Oeil2
    <0,0,0>,1
    material {
      T_Oeil
    }
    photons {
      collect off
    }
    scale <0.118497, 0.15, 0.15407>
    rotate <-13.659382, -0.621444, -6.467489>
    translate  <-0.698656, 8.098416, 0.0>
  }
}
#declare Corps = mesh2 {
  vertex_vectors {
    1528,
    <-0.3046617, 7.3865883, -0.6163216>,
    <-0.5738331, 7.0975547, -0.5915940>,
    <-0.5907857, 7.0975547, -0.4097140>,
    <-0.4799848, 7.2298823, -0.6082298>,
    <-0.5847389, 7.1023033, -0.5035710>,
    <-0.4932803, 7.2298823, -0.4927931>,
    <-0.5046936, 7.2172192, -0.5481085>,
    <-0.4866937, 7.0975547, -0.7260122>,
    <-0.4267258, 7.2298823, -0.6956818>,
    <-0.5360492, 7.1023033, -0.6632987>,
    <-0.4711183, 7.2172192, -0.6600471>,
    <-0.3582349, 7.0975547, -0.8063134>,
    <-0.3450011, 7.2298823, -0.7481530>,
    <-0.4264034, 7.1023033, -0.7697839>,
    <-0.3944446, 7.2172192, -0.7346728>,
    <-0.2110323, 7.0975547, -0.8324974>,
    <-0.2509727, 7.2298823, -0.7656434>,
    <-0.2886420, 7.1023033, -0.8230265>,
    <-0.2980848, 7.2172192, -0.7719857>,
    <-0.0641373, 7.0975547, -0.8045643>,
    <-0.1569443, 7.2298823, -0.7481530>,
    <-0.1415087, 7.1023033, -0.8230265>,
    <-0.1951629, 7.2172192, -0.7719857>,
    <0.0633987, 7.0975547, -0.7225142>,
    <-0.0752196, 7.2298823, -0.6956818>,
    <-0.0037472, 7.1023033, -0.7697839>,
    <-0.0988031, 7.2172192, -0.7346728>,
    <0.1507342, 7.0975547, -0.5863469>,
    <-0.0196190, 7.2298823, -0.6082298>,
    <0.1058985, 7.1023033, -0.6632987>,
    <-0.0221294, 7.2172192, -0.6600471>,
    <0.1754423, 7.0975547, -0.4035924>,
    <-0.0016402, 7.2298823, -0.4927931>,
    <0.1622828, 7.1023033, -0.5035710>,
    <0.0176902, 7.2172192, -0.5481085>,
    <-0.7313106, 6.6917661, -0.5265790>,
    <-0.7624424, 6.6917661, -0.2293011>,
    <-0.6631941, 6.9095129, -0.5594720>,
    <-0.7574236, 6.6917661, -0.3834452>,
    <-0.6867442, 6.9095129, -0.3129381>,
    <-0.6835088, 6.9095129, -0.4407705>,
    <-0.5881082, 6.6917661, -0.7467849>,
    <-0.5455691, 6.9095129, -0.7420897>,
    <-0.6719187, 6.6917661, -0.6476923>,
    <-0.6146572, 6.9095129, -0.6599117>,
    <-0.3777016, 6.6917661, -0.8789084>,
    <-0.3719726, 6.9095129, -0.8516603>,
    <-0.4887393, 6.6917661, -0.8238570>,
    <-0.4636009, 6.9095129, -0.8060059>,
    <-0.1361784, 6.6917661, -0.9229496>,
    <-0.1726161, 6.9095129, -0.8881838>,
    <-0.2588848, 6.6917661, -0.9119393>,
    <-0.2739044, 6.9095129, -0.8790529>,
    <0.1053449, 6.6917661, -0.8789084>,
    <0.0267404, 6.9095129, -0.8516603>,
    <-0.0134719, 6.6917661, -0.9119393>,
    <-0.0713278, 6.9095129, -0.8790529>,
    <0.3157515, 6.6917661, -0.7467849>,
    <0.2003368, 6.9095129, -0.7420897>,
    <0.2163826, 6.6917661, -0.8238570>,
    <0.1183687, 6.9095129, -0.8060059>,
    <0.4603289, 6.6917661, -0.5265790>,
    <0.3198025, 6.9095129, -0.5594720>,
    <0.3995620, 6.6917661, -0.6476923>,
    <0.2694250, 6.9095129, -0.6599117>,
    <0.4983357, 6.6917661, -0.2293011>,
    <0.3525553, 6.9095129, -0.3129381>,
    <0.4905669, 6.6917661, -0.3834452>,
    <0.3456388, 6.9095129, -0.4407705>,
    <-0.8112555, 6.1904657, -0.4589531>,
    <-0.8540254, 6.1904657, -0.0992385>,
    <-0.7792650, 6.4513285, -0.4926574>,
    <-0.8457756, 6.1904657, -0.2857572>,
    <-0.8166837, 6.4513285, -0.1584223>,
    <-0.8100255, 6.4513285, -0.3317294>,
    <-0.6339918, 6.1904657, -0.7254084>,
    <-0.6165693, 6.4513285, -0.7402390>,
    <-0.7372209, 6.1904657, -0.6055035>,
    <-0.7115385, 6.4513285, -0.6288273>,
    <-0.3756280, 6.1904657, -0.8852816>,
    <-0.3784532, 6.4513285, -0.8887879>,
    <-0.5118879, 6.1904657, -0.8186678>,
    <-0.5040809, 6.4513285, -0.8268925>,
    <-0.0795146, 6.1904657, -0.9385727>,
    <-0.1052989, 6.4513285, -0.9383042>,
    <-0.2299306, 6.1904657, -0.9252499>,
    <-0.2440660, 6.4513285, -0.9259251>,
    <0.2165988, 6.1904657, -0.8852816>,
    <0.1678554, 6.4513285, -0.8887879>,
    <0.0709015, 6.1904657, -0.9252499>,
    <0.0334681, 6.4513285, -0.9259251>,
    <0.4749627, 6.1904657, -0.7254084>,
    <0.4059714, 6.4513285, -0.7402390>,
    <0.3528588, 6.1904657, -0.8186678>,
    <0.2934831, 6.4513285, -0.8268925>,
    <0.6528774, 6.1904657, -0.4589531>,
    <0.5696477, 6.4513285, -0.4926574>,
    <0.5781918, 6.1904657, -0.6055035>,
    <0.5009406, 6.4513285, -0.6288273>,
    <0.6989026, 6.1904657, -0.0992385>,
    <0.6119688, 6.4513285, -0.1584223>,
    <0.6893507, 6.1904657, -0.2857572>,
    <0.6033496, 6.4513285, -0.3317294>,
    <-0.8506778, 5.6165272, -0.4002256>,
    <-0.9032562, 5.6165272, -0.0117031>,
    <-0.8314800, 5.9114434, -0.4267122>,
    <-0.8914597, 5.6165272, -0.2131592>,
    <-0.8790246, 5.9114434, -0.0506865>,
    <-0.8691349, 5.9114434, -0.2456628>,
    <-0.6528014, 5.6165272, -0.6880201>,
    <-0.6434155, 5.9114434, -0.7052499>,
    <-0.7674466, 5.6165272, -0.5585126>,
    <-0.7526708, 5.9114434, -0.5799079>,
    <-0.3674686, 5.6165272, -0.8606967>,
    <-0.3706264, 5.9114434, -0.8723724>,
    <-0.5177771, 5.6165272, -0.7887481>,
    <-0.5144226, 5.9114434, -0.8027380>,
    <-0.0413779, 5.6165272, -0.9182556>,
    <-0.0583622, 5.9114434, -0.9280800>,
    <-0.2069706, 5.6165272, -0.9038659>,
    <-0.2169615, 5.9114434, -0.9141531>,
    <0.2847129, 5.6165272, -0.8606967>,
    <0.2539021, 5.9114434, -0.8723724>,
    <0.1242149, 5.6165272, -0.9038659>,
    <0.1002372, 5.9114434, -0.9141531>,
    <0.5700456, 5.6165272, -0.6880201>,
    <0.5266912, 5.9114434, -0.7052499>,
    <0.4350214, 5.6165272, -0.7887481>,
    <0.3976983, 5.9114434, -0.8027380>,
    <0.7680847, 5.6165272, -0.4002256>,
    <0.7151365, 5.9114434, -0.4267122>,
    <0.6846909, 5.6165272, -0.5585126>,
    <0.6359465, 5.9114434, -0.5799079>,
    <0.8214763, 5.6165272, -0.0117031>,
    <0.7645851, 5.9114434, -0.0506865>,
    <0.8093545, 5.6165272, -0.2131592>,
    <0.7539338, 5.9114434, -0.2456628>,
    <-0.9196461, 5.0077259, -0.3770981>,
    <-0.9859139, 5.0077259, 0.0417369>,
    <-0.8795877, 5.3079827, -0.3837840>,
    <-0.9687055, 5.0077259, -0.1754368>,
    <-0.9382953, 5.3079827, 0.0187748>,
    <-0.9241062, 5.3079827, -0.1899594>,
    <-0.6962396, 5.0077259, -0.6873462>,
    <-0.6701107, 5.3079827, -0.6819757>,
    <-0.8248384, 5.0077259, -0.5477346>,
    <-0.7911072, 5.3079827, -0.5477894>,
    <-0.3789987, 5.0077259, -0.8734951>,
    <-0.3701745, 5.3079827, -0.8608907>,
    <-0.5458068, 5.0077259, -0.7959331>,
    <-0.5280439, 5.3079827, -0.7863428>,
    <-0.0180899, 5.0077259, -0.9355447>,
    <-0.0280979, 5.3079827, -0.9205290>,
    <-0.2012735, 5.0077259, -0.9200323>,
    <-0.2017700, 5.3079827, -0.9056195>,
    <0.3428188, 5.0077259, -0.8734951>,
    <0.3139786, 5.3079827, -0.8608907>,
    <0.1650937, 5.0077259, -0.9200323>,
    <0.1455741, 5.3079827, -0.9056195>,
    <0.6600597, 5.0077259, -0.6873462>,
    <0.6139148, 5.3079827, -0.6819757>,
    <0.5096270, 5.0077259, -0.7959331>,
    <0.4718480, 5.3079827, -0.7863428>,
    <0.8833194, 5.0077259, -0.3770981>,
    <0.8233813, 5.3079827, -0.3837840>,
    <0.7886585, 5.0077259, -0.5477346>,
    <0.7349114, 5.3079827, -0.5477894>,
    <0.9488531, 5.0077259, 0.0417369>,
    <0.8820362, 5.3079827, 0.0187748>,
    <0.9319384, 5.0077259, -0.1754368>,
    <0.8678681, 5.3079827, -0.1899594>,
    <-1.0381736, 4.4643781, -0.3914643>,
    <-1.1250426, 4.4643781, 0.0693907>,
    <-0.9722893, 4.7376724, -0.3798786>,
    <-1.0994219, 4.4643781, -0.1695712>,
    <-1.0478837, 4.7376724, 0.0581727>,
    <-1.0268889, 4.7376724, -0.1689650>,
    <-0.7779612, 4.4643781, -0.7328385>,
    <-0.7320843, 4.7376724, -0.7043611>,
    <-0.9265721, 4.4643781, -0.5792201>,
    <-0.8698259, 4.7376724, -0.5583440>,
    <-0.4156583, 4.4643781, -0.9376630>,
    <-0.3941957, 4.7376724, -0.8990506>,
    <-0.6056844, 4.4643781, -0.8523194>,
    <-0.5716498, 4.7376724, -0.8179300>,
    <-0.0060238, 4.4643781, -1.0059378>,
    <-0.0109214, 4.7376724, -0.9639471>,
    <-0.2137992, 4.4643781, -0.9888691>,
    <-0.2053951, 4.7376724, -0.9477230>,
    <0.4036107, 4.4643781, -0.9376630>,
    <0.3723529, 4.7376724, -0.8990506>,
    <0.2017517, 4.4643781, -0.9888691>,
    <0.1835523, 4.7376724, -0.9477230>,
    <0.7659136, 4.4643781, -0.7328385>,
    <0.7102415, 4.7376724, -0.7043611>,
    <0.5936368, 4.4643781, -0.8523194>,
    <0.5498070, 4.7376724, -0.8179300>,
    <1.0257909, 4.4643781, -0.3914643>,
    <0.9501922, 4.7376724, -0.3798786>,
    <0.9145246, 4.4643781, -0.5792201>,
    <0.8479831, 4.7376724, -0.5583440>,
    <1.1109839, 4.4643781, 0.0693907>,
    <1.0245153, 4.7376724, 0.0581727>,
    <1.0860335, 4.4643781, -0.1695712>,
    <1.0040290, 4.7376724, -0.1689650>,
    <-1.2029088, 3.8008799, -0.4353003>,
    <-1.3176425, 3.8008799, 0.0809225>,
    <-1.1179555, 4.1543989, -0.4111941>,
    <-1.2804432, 3.8008799, -0.1867486>,
    <-1.2182283, 4.1543989, 0.0766992>,
    <-1.1870700, 4.1543989, -0.1762825>,
    <-0.8942989, 3.8008799, -0.8176876>,
    <-0.8341866, 4.1543989, -0.7725965>,
    <-1.0691310, 3.8008799, -0.6456133>,
    <-0.9955794, 4.1543989, -0.6099654>,
    <-0.4735051, 3.8008799, -1.0471200>,
    <-0.4432792, 4.1543989, -0.9894379>,
    <-0.6936015, 3.8008799, -0.9515232>,
    <-0.6480223, 4.1543989, -0.8990873>,
    <-0.0009808, 3.8008799, -1.1235974>,
    <-0.0028285, 4.1543989, -1.0617184>,
    <-0.2404761, 3.8008799, -1.1044781>,
    <-0.2261503, 4.1543989, -1.0436483>,
    <0.4715435, 3.8008799, -1.0471200>,
    <0.4376222, 4.1543989, -0.9894379>,
    <0.2385145, 3.8008799, -1.1044781>,
    <0.2204933, 4.1543989, -1.0436483>,
    <0.8923373, 3.8008799, -0.8176876>,
    <0.8285297, 4.1543989, -0.7725965>,
    <0.6916399, 3.8008799, -0.9515232>,
    <0.6423653, 4.1543989, -0.8990873>,
    <1.2005228, 3.8008799, -0.4353003>,
    <1.1119066, 4.1543989, -0.4111941>,
    <1.0671694, 3.8008799, -0.6456133>,
    <0.9899224, 4.1543989, -0.6099654>,
    <1.3131347, 3.8008799, 0.0809225>,
    <1.2102198, 4.1543989, 0.0766992>,
    <1.2767841, 3.8008799, -0.1867486>,
    <1.1798453, 4.1543989, -0.1762825>,
    <-1.3586827, 2.9911822, -0.4835026>,
    <-1.5014612, 2.9911822, 0.0831721>,
    <-1.2843073, 3.3969664, -0.4600157>,
    <-1.4523019, 2.9911822, -0.2106592>,
    <-1.4134868, 3.3969664, 0.0828852>,
    <-1.3701518, 3.3969664, -0.1986189>,
    <-1.0043670, 2.9911822, -0.9032616>,
    <-0.9518360, 3.3969664, -0.8621645>,
    <-1.2037472, 2.9911822, -0.7143700>,
    <-1.1395102, 3.3969664, -0.6811975>,
    <-0.5297804, 2.9911822, -1.1551170>,
    <-0.5027828, 3.3969664, -1.1034538>,
    <-0.7774135, 2.9911822, -1.0501772>,
    <-0.7373601, 3.3969664, -1.0029166>,
    <-0.0000498, 2.9911822, -1.2390688>,
    <-0.0001260, 3.3969664, -1.1838835>,
    <-0.2683613, 2.9911822, -1.2180808>,
    <-0.2548046, 3.3969664, -1.1637761>,
    <0.5296761, 2.9911822, -1.1551170>,
    <0.5025307, 3.3969664, -1.1034538>,
    <0.2682605, 2.9911822, -1.2180808>,
    <0.2545525, 3.3969664, -1.1637761>,
    <1.0042484, 2.9911822, -0.9032616>,
    <0.9515839, 3.3969664, -0.8621645>,
    <0.7773032, 2.9911822, -1.0501772>,
    <0.7371080, 3.3969664, -1.0029166>,
    <1.3581182, 2.9911822, -0.4835026>,
    <1.2836227, 3.3969664, -0.4600157>,
    <1.2036181, 2.9911822, -0.7143700>,
    <1.1392581, 3.3969664, -0.6811975>,
    <1.4987527, 2.9911822, 0.0831721>,
    <1.4106398, 3.3969664, 0.0828852>,
    <1.4504547, 2.9911822, -0.2106592>,
    <1.3681697, 3.3969664, -0.1986189>,
    <0.1492430, 7.0975547, -0.2217123>,
    <-0.0194960, 7.2298823, -0.3773564>,
    <0.1624906, 7.1023033, -0.3172219>,
    <0.0177693, 7.2172192, -0.4175135>,
    <0.0602526, 7.0975547, -0.0872941>,
    <-0.0750669, 7.2298823, -0.2899044>,
    <0.1063438, 7.1023033, -0.1574942>,
    <-0.0219598, 7.2172192, -0.3055749>,
    <-0.0683721, 7.0975547, -0.0069930>,
    <-0.1568467, 7.2298823, -0.2374332>,
    <-0.0033613, 7.1023033, -0.0510090>,
    <-0.0986561, 7.2172192, -0.2309491>,
    <-0.2158594, 7.0975547, 0.0191911>,
    <-0.2509727, 7.2298823, -0.2199428>,
    <-0.1413602, 7.1023033, 0.0022335>,
    <-0.1951064, 7.2172192, -0.1936363>,
    <-0.3630380, 7.0975547, -0.0087420>,
    <-0.3450987, 7.2298823, -0.2374332>,
    <-0.2887905, 7.1023033, 0.0022335>,
    <-0.2981413, 7.2172192, -0.1936363>,
    <-0.4907368, 7.0975547, -0.0907922>,
    <-0.4268785, 7.2298823, -0.2899044>,
    <-0.4267894, 7.1023033, -0.0510090>,
    <-0.3945916, 7.2172192, -0.2309491>,
    <-0.5757780, 7.0975547, -0.2269595>,
    <-0.4801078, 7.2298823, -0.3773564>,
    <-0.5364945, 7.1023033, -0.1574942>,
    <-0.4712879, 7.2172192, -0.3055749>,
    <-0.5849467, 7.1023033, -0.3172219>,
    <-0.5047727, 7.2172192, -0.4175135>,
    <0.4623434, 6.6917661, 0.0679769>,
    <0.3207567, 6.9095129, -0.0664042>,
    <0.4916950, 6.6917661, -0.0751570>,
    <0.3461732, 6.9095129, -0.1851057>,
    <0.3181688, 6.6917661, 0.2881827>,
    <0.2014819, 6.9095129, 0.1162135>,
    <0.4019794, 6.6917661, 0.1890901>,
    <0.2705700, 6.9095129, 0.0340355>,
    <0.1068759, 6.6917661, 0.4203063>,
    <0.0274656, 6.9095129, 0.2257841>,
    <0.2184776, 6.6917661, 0.3652548>,
    <0.1193611, 6.9095129, 0.1801297>,
    <-0.1361784, 6.6917661, 0.4643475>,
    <-0.1726161, 6.9095129, 0.2623076>,
    <-0.0126661, 6.6917661, 0.4533372>,
    <-0.0709461, 6.9095129, 0.2531768>,
    <-0.3792326, 6.6917661, 0.4203063>,
    <-0.3726979, 6.9095129, 0.2257841>,
    <-0.2596906, 6.6917661, 0.4533372>,
    <-0.2742861, 6.9095129, 0.2531768>,
    <-0.5905256, 6.6917661, 0.2881827>,
    <-0.5467141, 6.9095129, 0.1162135>,
    <-0.4908343, 6.6917661, 0.3652548>,
    <-0.4645933, 6.9095129, 0.1801297>,
    <-0.7333251, 6.6917661, 0.0679769>,
    <-0.6641483, 6.9095129, -0.0664042>,
    <-0.6743361, 6.6917661, 0.1890901>,
    <-0.6158022, 6.9095129, 0.0340355>,
    <-0.7585517, 6.6917661, -0.0751570>,
    <-0.6840432, 6.9095129, -0.1851057>,
    <0.6590798, 6.1904657, 0.2604762>,
    <0.5733586, 6.4513285, 0.1758129>,
    <0.6928240, 6.1904657, 0.0872803>,
    <0.6054277, 6.4513285, 0.0148848>,
    <0.4824056, 6.1904657, 0.5269315>,
    <0.4104245, 6.4513285, 0.4233944>,
    <0.5856347, 6.1904657, 0.4070266>,
    <0.5053937, 6.4513285, 0.3119827>,
    <0.2213127, 6.1904657, 0.6868047>,
    <0.1706756, 6.4513285, 0.5719434>,
    <0.3593093, 6.1904657, 0.6201909>,
    <0.2973424, 6.4513285, 0.5100480>,
    <-0.0795146, 6.1904657, 0.7400958>,
    <-0.1052989, 6.4513285, 0.6214597>,
    <0.0733824, 6.1904657, 0.7267730>,
    <0.0349525, 6.4513285, 0.6090806>,
    <-0.3803418, 6.1904657, 0.6868047>,
    <-0.3812735, 6.4513285, 0.5719434>,
    <-0.2324116, 6.1904657, 0.7267730>,
    <-0.2455503, 6.4513285, 0.6090806>,
    <-0.6414347, 6.1904657, 0.5269315>,
    <-0.6210223, 6.4513285, 0.4233944>,
    <-0.5183385, 6.1904657, 0.6201909>,
    <-0.5079402, 6.4513285, 0.5100480>,
    <-0.8174579, 6.1904657, 0.2604762>,
    <-0.7829759, 6.4513285, 0.1758129>,
    <-0.7446639, 6.1904657, 0.4070266>,
    <-0.7159915, 6.4513285, 0.3119827>,
    <-0.8492490, 6.1904657, 0.0872803>,
    <-0.8121036, 6.4513285, 0.0148848>,
    <0.7824973, 5.6165272, 0.3768194>,
    <0.7247848, 5.9114434, 0.3253393>,
    <0.8174256, 5.6165272, 0.1897530>,
    <0.7593369, 5.9114434, 0.1442899>,
    <0.5873408, 5.6165272, 0.6646138>,
    <0.5382690, 5.9114434, 0.6038769>,
    <0.7019861, 5.6165272, 0.5351063>,
    <0.6475243, 5.9114434, 0.4785350>,
    <0.2956665, 5.6165272, 0.8372905>,
    <0.2612348, 5.9114434, 0.7709995>,
    <0.4500105, 5.6165272, 0.7653419>,
    <0.4077324, 5.9114434, 0.7013651>,
    <-0.0413779, 5.6165272, 0.8948494>,
    <-0.0583622, 5.9114434, 0.8267070>,
    <0.1299799, 5.6165272, 0.8804597>,
    <0.1040965, 5.9114434, 0.8127802>,
    <-0.3784222, 5.6165272, 0.8372905>,
    <-0.3779591, 5.9114434, 0.7709995>,
    <-0.2127357, 5.6165272, 0.8804597>,
    <-0.2208208, 5.9114434, 0.8127802>,
    <-0.6700965, 5.6165272, 0.6646138>,
    <-0.6549934, 5.9114434, 0.6038769>,
    <-0.5327663, 5.6165272, 0.7653419>,
    <-0.5244567, 5.9114434, 0.7013651>,
    <-0.8650904, 5.6165272, 0.3768194>,
    <-0.8411283, 5.9114434, 0.3253393>,
    <-0.7847418, 5.6165272, 0.5351063>,
    <-0.7642486, 5.9114434, 0.4785350>,
    <-0.8995308, 5.6165272, 0.1897530>,
    <-0.8745380, 5.9114434, 0.1442899>,
    <0.9127177, 5.0077259, 0.4605718>,
    <0.8442413, 5.3079827, 0.4213336>,
    <0.9484014, 5.0077259, 0.2589105>,
    <0.8795498, 5.3079827, 0.2275090>,
    <0.6953376, 5.0077259, 0.7708199>,
    <0.6389468, 5.3079827, 0.7195253>,
    <0.8239365, 5.0077259, 0.6312083>,
    <0.7599434, 5.3079827, 0.5853390>,
    <0.3651615, 5.0077259, 0.9569688>,
    <0.3298323, 5.3079827, 0.8984403>,
    <0.5402012, 5.0077259, 0.8794068>,
    <0.4935425, 5.3079827, 0.8238923>,
    <-0.0180899, 5.0077259, 1.0190184>,
    <-0.0280979, 5.3079827, 0.9580786>,
    <0.1768530, 5.0077259, 1.0035060>,
    <0.1539181, 5.3079827, 0.9431690>,
    <-0.4013414, 5.0077259, 0.9569688>,
    <-0.3860281, 5.3079827, 0.8984403>,
    <-0.2130329, 5.0077259, 1.0035060>,
    <-0.2101140, 5.3079827, 0.9431690>,
    <-0.7315175, 5.0077259, 0.7708199>,
    <-0.6951427, 5.3079827, 0.7195253>,
    <-0.5763811, 5.0077259, 0.8794068>,
    <-0.5497384, 5.3079827, 0.8238923>,
    <-0.9490444, 5.0077259, 0.4605718>,
    <-0.9004477, 5.3079827, 0.4213336>,
    <-0.8601163, 5.0077259, 0.6312083>,
    <-0.8161393, 5.3079827, 0.5853390>,
    <-0.9851685, 5.0077259, 0.2589105>,
    <-0.9357878, 5.3079827, 0.2275090>,
    <1.0799686, 4.4643781, 0.5302458>,
    <0.9906274, 4.7376724, 0.4962241>,
    <1.1163731, 4.4643781, 0.3083526>,
    <1.0266728, 4.7376724, 0.2853105>,
    <0.8309269, 4.4643781, 0.8716199>,
    <0.7587637, 4.7376724, 0.8207066>,
    <0.9795378, 4.4643781, 0.7180016>,
    <0.8965054, 4.7376724, 0.6746895>,
    <0.4447858, 4.4643781, 1.0764444>,
    <0.4030836, 4.7376724, 1.0153961>,
    <0.6499816, 4.4643781, 0.9911009>,
    <0.5918596, 4.7376724, 0.9342754>,
    <-0.0060238, 4.4643781, 1.1447193>,
    <-0.0109214, 4.7376724, 1.0802926>,
    <0.2234228, 4.4643781, 1.1276505>,
    <0.1997264, 4.7376724, 1.0640684>,
    <-0.4568333, 4.4643781, 1.0764444>,
    <-0.4249264, 4.7376724, 1.0153961>,
    <-0.2354703, 4.4643781, 1.1276505>,
    <-0.2215692, 4.7376724, 1.0640684>,
    <-0.8429744, 4.4643781, 0.8716199>,
    <-0.7806065, 4.7376724, 0.8207066>,
    <-0.6620292, 4.4643781, 0.9911009>,
    <-0.6137024, 4.7376724, 0.9342754>,
    <-1.0923514, 4.4643781, 0.5302458>,
    <-1.0127245, 4.7376724, 0.4962241>,
    <-0.9915854, 4.4643781, 0.7180016>,
    <-0.9183482, 4.7376724, 0.6746895>,
    <-1.1297615, 4.4643781, 0.3083526>,
    <-1.0495327, 4.7376724, 0.2853105>,
    <1.2897582, 3.8008799, 0.5971454>,
    <1.1827392, 4.1543989, 0.5645924>,
    <1.3267559, 3.8008799, 0.3485936>,
    <1.2195116, 4.1543989, 0.3296809>,
    <0.9994197, 3.8008799, 0.9795327>,
    <0.9135288, 4.1543989, 0.9259948>,
    <1.1742518, 3.8008799, 0.8074584>,
    <1.0749216, 4.1543989, 0.7633637>,
    <0.5393624, 3.8008799, 1.2089650>,
    <0.4914550, 4.1543989, 1.1428363>,
    <0.7844446, 3.8008799, 1.1133682>,
    <0.7160312, 4.1543989, 1.0524857>,
    <-0.0009808, 3.8008799, 1.2854425>,
    <-0.0028285, 4.1543989, 1.2151167>,
    <0.2742087, 3.8008799, 1.2663231>,
    <0.2488264, 4.1543989, 1.1970466>,
    <-0.5413240, 3.8008799, 1.2089650>,
    <-0.4971120, 4.1543989, 1.1428363>,
    <-0.2761703, 3.8008799, 1.2663231>,
    <-0.2544833, 4.1543989, 1.1970466>,
    <-1.0013813, 3.8008799, 0.9795327>,
    <-0.9191858, 4.1543989, 0.9259948>,
    <-0.7864063, 3.8008799, 1.1133682>,
    <-0.7216882, 4.1543989, 1.0524857>,
    <-1.2921441, 3.8008799, 0.5971454>,
    <-1.1887881, 4.1543989, 0.5645924>,
    <-1.1762134, 3.8008799, 0.8074584>,
    <-1.0805785, 4.1543989, 0.7633637>,
    <-1.3304150, 3.8008799, 0.3485936>,
    <-1.2267362, 4.1543989, 0.3296809>,
    <1.4843341, 2.9911822, 0.6498467>,
    <1.3918441, 3.3969664, 0.6257861>,
    <1.5211369, 2.9911822, 0.3770034>,
    <1.4287736, 3.3969664, 0.3643894>,
    <1.1556902, 2.9911822, 1.0696057>,
    <1.0814496, 3.3969664, 1.0279349>,
    <1.3550705, 2.9911822, 0.8807142>,
    <1.2691238, 3.3969664, 0.8469679>,
    <0.6255546, 2.9911822, 1.3214611>,
    <0.5847790, 3.3969664, 1.2692242>,
    <0.9085371, 2.9911822, 1.2165213>,
    <0.8496582, 3.3969664, 1.1686870>,
    <-0.0001244, 2.9911822, 1.4054129>,
    <-0.0001260, 3.3969664, 1.3496539>,
    <0.3186863, 2.9911822, 1.3844249>,
    <0.2978411, 3.3969664, 1.3295465>,
    <-0.6257986, 2.9911822, 1.3214611>,
    <-0.5850311, 3.3969664, 1.2692242>,
    <-0.3189338, 2.9911822, 1.3844249>,
    <-0.2980932, 3.3969664, 1.3295465>,
    <-1.1559200, 2.9911822, 1.0696057>,
    <-1.0817017, 3.3969664, 1.0279349>,
    <-0.9087752, 2.9911822, 1.2165213>,
    <-0.8499103, 3.3969664, 1.1686870>,
    <-1.4849626, 2.9911822, 0.6498467>,
    <-1.3925287, 3.3969664, 0.6257861>,
    <-1.3552896, 2.9911822, 0.8807142>,
    <-1.2693759, 3.3969664, 0.8469679>,
    <-1.5230172, 2.9911822, 0.3770034>,
    <-1.4307557, 3.3969664, 0.3643894>,
    <-1.4791761, 2.2907830, -0.5223726>,
    <-1.6442707, 2.2907830, 0.0806367>,
    <-1.4225670, 2.6320514, -0.5039236>,
    <-1.5855752, 2.2907830, -0.2320348>,
    <-1.5772653, 2.6320514, 0.0823678>,
    <-1.5229998, 2.6320514, -0.2216351>,
    <-1.0895857, 2.2907830, -0.9690462>,
    <-1.0494606, 2.6320514, -0.9382135>,
    <-1.3077992, 2.2907830, -0.7680431>,
    <-1.2588722, 2.6320514, -0.7427830>,
    <-0.5742483, 2.2907830, -1.2370503>,
    <-0.5531661, 2.6320514, -1.1987875>,
    <-0.8426765, 2.2907830, -1.1253819>,
    <-0.8118772, 2.6320514, -1.0902150>,
    <-0.0015419, 2.2907830, -1.3263850>,
    <-0.0005376, 2.6320514, -1.2856455>,
    <-0.2914779, 2.2907830, -1.3040514>,
    <-0.2803716, 2.6320514, -1.2639310>,
    <0.5711201, 2.2907830, -1.2370503>,
    <0.5520719, 2.6320514, -1.1987875>,
    <0.2883830, 2.2907830, -1.3040514>,
    <0.2792916, 2.6320514, -1.2639310>,
    <1.0863242, 2.2907830, -0.9690462>,
    <1.0483095, 2.6320514, -0.9382135>,
    <0.8394927, 2.2907830, -1.1253819>,
    <0.8107593, 2.6320514, -1.0902150>,
    <1.4753225, 2.2907830, -0.5223726>,
    <1.4209211, 2.6320514, -0.5039236>,
    <1.3044378, 2.2907830, -0.7680431>,
    <1.2576786, 2.6320514, -0.7427830>,
    <1.6382668, 2.2907830, 0.0806367>,
    <1.5734910, 2.6320514, 0.0823678>,
    <1.5804670, 2.2907830, -0.2320348>,
    <1.5200920, 2.6320514, -0.2216351>,
    <-1.5771572, 1.5788248, -0.5553385>,
    <-1.7586847, 1.5788248, 0.0750428>,
    <-1.5317263, 1.9385866, -0.5399437>,
    <-1.6931117, 1.5788248, -0.2518215>,
    <-1.7058488, 1.9385866, 0.0781428>,
    <-1.6433581, 1.9385866, -0.2423465>,
    <-1.1600257, 1.5788248, -1.0222875>,
    <-1.1272111, 1.9385866, -0.9977856>,
    <-1.3930629, 1.5788248, -0.8121605>,
    <-1.3534424, 1.9385866, -0.7917568>,
    <-0.6121563, 1.5788248, -1.3024570>,
    <-0.5943352, 1.9385866, -1.2724907>,
    <-0.8972418, 1.5788248, -1.1857197>,
    <-0.8717367, 1.9385866, -1.1580302>,
    <-0.0048595, 1.5788248, -1.3958468>,
    <-0.0030149, 1.9385866, -1.3640591>,
    <-0.3122139, 1.5788248, -1.3724994>,
    <-0.3023227, 1.9385866, -1.3411670>,
    <0.6023063, 1.5788248, -1.3024570>,
    <0.5882225, 1.9385866, -1.2724907>,
    <0.3024622, 1.5788248, -1.3724994>,
    <0.2962721, 1.9385866, -1.3411670>,
    <1.1497824, 1.5788248, -1.0222875>,
    <1.1208494, 1.9385866, -0.9977856>,
    <0.8872279, 1.5788248, -1.1857197>,
    <0.8655202, 1.9385866, -1.1580302>,
    <1.5659582, 1.5788248, -0.5553385>,
    <1.5246131, 1.9385866, -0.5399437>,
    <1.3825248, 1.5788248, -0.8121605>,
    <1.3468941, 1.9385866, -0.7917568>,
    <1.7450986, 1.5788248, 0.0750428>,
    <1.6964922, 1.9385866, 0.0781428>,
    <1.6805853, 1.5788248, -0.2518215>,
    <1.6349652, 1.9385866, -0.2423465>,
    <-1.6426798, 0.8475771, -0.5777141>,
    <-1.8340240, 0.8475771, 0.0676745>,
    <-1.6124084, 1.2148607, -0.5672583>,
    <-1.7644272, 0.8475771, -0.2669715>,
    <-1.7994633, 1.2148607, 0.0714935>,
    <-1.7315997, 1.2148607, -0.2597112>,
    <-1.2080683, 0.8475771, -1.0557797>,
    <-1.1857183, 1.2148607, -1.0404079>,
    <-1.4505892, 0.8475771, -0.8406502>,
    <-1.4239218, 1.2148607, -0.8274906>,
    <-0.6391195, 0.8475771, -1.3426191>,
    <-0.6264410, 1.2148607, -1.3242976>,
    <-0.9350302, 0.8475771, -1.2231027>,
    <-0.9173760, 1.2148607, -1.2060102>,
    <-0.0092578, 0.8475771, -1.4382323>,
    <-0.0069786, 1.2148607, -1.4189275>,
    <-0.3279805, 0.8475771, -1.4143290>,
    <-0.3204598, 1.2148607, -1.3952700>,
    <0.6203604, 0.8475771, -1.3426191>,
    <0.6122986, 1.2148607, -1.3242976>,
    <0.3094040, 0.8475771, -1.4143290>,
    <0.3064563, 1.2148607, -1.3952700>,
    <1.1885792, 0.8475771, -1.0557797>,
    <1.1710205, 1.2148607, -1.0404079>,
    <0.9159670, 0.8475771, -1.2231027>,
    <0.9030021, 1.2148607, -1.2060102>,
    <1.6217506, 0.8475771, -0.5777141>,
    <1.5965227, 1.2148607, -0.5672583>,
    <1.4305526, 0.8475771, -0.8406502>,
    <1.4088074, 1.2148607, -0.8274906>,
    <1.8103354, 0.8475771, 0.0676745>,
    <1.7810176, 1.2148607, 0.0714935>,
    <1.7420371, 0.8475771, -0.2669715>,
    <1.7143262, 1.2148607, -0.2597112>,
    <-1.6976149, 0.1065190, -0.5977554>,
    <-1.8950050, 0.1065190, 0.0599683>,
    <-1.6731716, 0.4778570, -0.5887165>,
    <-1.8231827, 0.1065190, -0.2810736>,
    <-1.8682064, 0.4778570, 0.0637653>,
    <-1.7971994, 0.4778570, -0.2745586>,
    <-1.2494538, 0.1065190, -1.0849581>,
    <-1.2308549, 0.4778570, -1.0720364>,
    <-1.4995191, 0.1065190, -0.8657169>,
    <-1.4776351, 0.4778570, -0.8545425>,
    <-0.6629656, 0.1065190, -1.3772797>,
    <-0.6521216, 0.4778570, -1.3620283>,
    <-0.9679775, 0.1065190, -1.2554791>,
    <-0.9530958, 0.4778570, -1.2411984>,
    <-0.0138370, 0.1065190, -1.4747203>,
    <-0.0115827, 0.4778570, -1.4586923>,
    <-0.3422937, 0.1065190, -1.4503602>,
    <-0.3356960, 0.4778570, -1.4345263>,
    <0.6349287, 0.1065190, -1.3772797>,
    <0.6286525, 0.4778570, -1.3620283>,
    <0.3145289, 0.1065190, -1.4503602>,
    <0.3124547, 0.4778570, -1.4345263>,
    <1.2203280, 0.1065190, -1.0849581>,
    <1.2064743, 0.4778570, -1.0720364>,
    <0.9394868, 0.1065190, -1.2554791>,
    <0.9292469, 0.4778570, -1.2411984>,
    <1.6665229, 0.1065190, -0.5977554>,
    <1.6470857, 0.4778570, -0.5887165>,
    <1.4695767, 0.1065190, -0.8657169>,
    <1.4525710, 0.4778570, -0.8545425>,
    <1.8607054, 0.1065190, 0.0599683>,
    <1.8391383, 0.4778570, 0.0637653>,
    <1.7904565, 0.1065190, -0.2810736>,
    <1.7695672, 0.4778570, -0.2745586>,
    <-1.7095710, -0.6384540, -0.6024296>,
    <-1.9054463, -0.6384540, 0.0535132>,
    <-1.7097409, -0.2656179, -0.6023207>,
    <-1.8346021, -0.6384540, -0.2866053>,
    <-1.9074141, -0.2656179, 0.0564854>,
    <-1.8356432, -0.2656179, -0.2851177>,
    <-1.2602122, -0.6384540, -1.0883132>,
    <-1.2592407, -0.2656179, -1.0903252>,
    <-1.5111923, -0.6384540, -0.8696656>,
    <-1.5107005, -0.2656179, -0.8707232>,
    <-0.6706799, -0.6384540, -1.3798434>,
    <-0.6691694, -0.2656179, -1.3831279>,
    <-0.9773772, -0.6384540, -1.2583725>,
    <-0.9760799, -0.2656179, -1.2611268>,
    <-0.0176694, -0.6384540, -1.4770201>,
    <-0.0159048, -0.2656179, -1.4807288>,
    <-0.3481131, -0.6384540, -1.4527259>,
    <-0.3464606, -0.2656179, -1.4563286>,
    <0.6348777, -0.6384540, -1.3798434>,
    <0.6369427, -0.2656179, -1.3831279>,
    <0.3126584, -0.6384540, -1.4527259>,
    <0.3145467, -0.2656179, -1.4563286>,
    <1.2230196, -0.6384540, -1.0883132>,
    <1.2257624, -0.2656179, -1.0903252>,
    <0.9409956, -0.6384540, -1.2583725>,
    <0.9433317, -0.2656179, -1.2611268>,
    <1.6699686, -0.6384540, -0.6024296>,
    <1.6740570, -0.2656179, -0.6023207>,
    <1.4729569, -0.6384540, -0.8696656>,
    <1.4762836, -0.2656179, -0.8707232>,
    <1.8622532, -0.6384540, 0.0535132>,
    <1.8683160, -0.2656179, 0.0564854>,
    <1.7932161, -0.6384540, -0.2866053>,
    <1.7982445, -0.2656179, -0.2851177>,
    <-1.6724300, -1.3858239, -0.5893478>,
    <-1.8584290, -1.3858239, 0.0498863>,
    <-1.6971269, -1.0118893, -0.5980996>,
    <-1.7920999, -1.3858239, -0.2815684>,
    <-1.8891138, -1.0118893, 0.0512480>,
    <-1.8200807, -1.0118893, -0.2854507>,
    <-1.2356951, -1.3858239, -1.0628546>,
    <-1.2523648, -1.0118893, -1.0790978>,
    <-1.4801579, -1.3858239, -0.8497766>,
    <-1.5010071, -1.0118893, -0.8626486>,
    <-0.6594084, -1.3858239, -1.3469587>,
    <-0.6674439, -1.0118893, -1.3676968>,
    <-0.9594529, -1.3858239, -1.2285820>,
    <-0.9718435, -1.0118893, -1.2474472>,
    <-0.0198227, -1.3858239, -1.4416601>,
    <-0.0190142, -1.0118893, -1.4638964>,
    <-0.3435392, -1.3858239, -1.4179847>,
    <-0.3471672, -1.0118893, -1.4398465>,
    <0.6192431, -1.3858239, -1.3469587>,
    <0.6289168, -1.0118893, -1.3676968>,
    <0.3037639, -1.3858239, -1.4179847>,
    <0.3090141, -1.0118893, -1.4398465>,
    <1.1939700, -1.3858239, -1.0628546>,
    <1.2123415, -1.0118893, -1.0790978>,
    <0.9186376, -1.3858239, -1.2285820>,
    <0.9326929, -1.0118893, -1.2474472>,
    <1.6280459, -1.3858239, -0.5893478>,
    <1.6545381, -1.0118893, -0.5980996>,
    <1.4372630, -1.3858239, -0.8497766>,
    <1.4598616, -1.0118893, -0.8626486>,
    <1.8102389, -1.3858239, 0.0498863>,
    <1.8427998, -1.0118893, 0.0512480>,
    <1.7458482, -1.3858239, -0.2815684>,
    <1.7756558, -1.0118893, -0.2854507>,
    <-1.5863639, -2.0752537, -0.5586485>,
    <-1.7540523, -2.0752537, 0.0506588>,
    <-1.6355018, -1.7601581, -0.5761917>,
    <-1.6958453, -2.0752537, -0.2652783>,
    <-1.8134044, -1.7601581, 0.0496245>,
    <-1.7506811, -1.7601581, -0.2748728>,
    <-1.1758749, -2.0752537, -1.0099873>,
    <-1.2101997, -1.7601581, -1.0397592>,
    <-1.4065188, -2.0752537, -0.8068848>,
    <-1.4486576, -1.7601581, -0.8311538>,
    <-0.6287262, -2.0752537, -1.2807905>,
    <-0.6465202, -1.7601581, -1.3178997>,
    <-0.9139974, -2.0752537, -1.1679558>,
    <-0.9401794, -1.7601581, -1.2020079>,
    <-0.0193640, -2.0752537, -1.3710583>,
    <-0.0199781, -1.7601581, -1.4106133>,
    <-0.3279017, -2.0752537, -1.3484913>,
    <-0.3371454, -1.7601581, -1.3874349>,
    <0.5894903, -2.0752537, -1.2807905>,
    <0.6060399, -1.7601581, -1.3178997>,
    <0.2890467, -2.0752537, -1.3484913>,
    <0.2970581, -1.7601581, -1.3874349>,
    <1.1351152, -2.0752537, -1.0099873>,
    <1.1681473, -1.7601581, -1.0397592>,
    <0.8741265, -2.0752537, -1.1679558>,
    <0.8990441, -1.7601581, -1.2020079>,
    <1.5429983, -2.0752537, -0.5586485>,
    <1.5907725, -1.7601581, -0.5761917>,
    <1.3646163, -2.0752537, -0.8068848>,
    <1.4054262, -1.7601581, -0.8311538>,
    <1.7069266, -2.0752537, 0.0506588>,
    <1.7648535, -1.7601581, 0.0496245>,
    <1.6506299, -2.0752537, -0.2652783>,
    <1.7040780, -1.7601581, -0.2748728>,
    <-1.4580580, -2.4293115, -0.5108007>,
    <-1.5999935, -2.4293115, 0.0566488>,
    <-1.5250378, -2.2714726, -0.5367355>,
    <-1.5531346, -2.4293115, -0.2375842>,
    <-1.6803852, -2.2714726, 0.0531859>,
    <-1.6276136, -2.2714726, -0.2526993>,
    <-1.0854567, -2.4293115, -0.9311336>,
    <-1.1327175, -2.2714726, -0.9737143>,
    <-1.2960692, -2.4293115, -0.7419838>,
    <-1.3537545, -2.2714726, -0.7770739>,
    <-0.5808351, -2.4293115, -1.1833334>,
    <-0.6059733, -2.2714726, -1.2359016>,
    <-0.8445088, -2.4293115, -1.0782502>,
    <-0.8808807, -2.2714726, -1.1266569>,
    <-0.0157493, -2.4293115, -1.2674000>,
    <-0.0178637, -2.2714726, -1.3232974>,
    <-0.3020454, -2.4293115, -1.2463833>,
    <-0.3157246, -2.2714726, -1.3014484>,
    <0.5489234, -2.4293115, -1.1833334>,
    <0.5697773, -2.2714726, -1.2359016>,
    <0.2704435, -2.4293115, -1.2463833>,
    <0.2798800, -2.2714726, -1.3014484>,
    <1.0523057, -2.4293115, -0.9311336>,
    <1.0951158, -2.2714726, -0.9737143>,
    <0.8120807, -2.4293115, -1.0782502>,
    <0.8440990, -2.2714726, -1.1266569>,
    <1.4227194, -2.4293115, -0.5108007>,
    <1.4850038, -2.2714726, -0.5367355>,
    <1.2619888, -2.4293115, -0.7419838>,
    <1.3150985, -2.2714726, -0.7770739>,
    <1.5612562, -2.4293115, 0.0566488>,
    <1.6367411, -2.2714726, 0.0531859>,
    <1.5160873, -2.4293115, -0.2375842>,
    <1.5857884, -2.2714726, -0.2526993>,
    <1.6300331, 2.2907830, 0.6836460>,
    <1.5625651, 2.6320514, 0.6686592>,
    <1.6671174, 2.2907830, 0.3933082>,
    <1.5994179, 2.6320514, 0.3863708>,
    <1.2718148, 2.2907830, 1.1303196>,
    <1.2182132, 2.6320514, 1.1029492>,
    <1.4900284, 2.2907830, 0.9293165>,
    <1.4276248, 2.6320514, 0.9075187>,
    <0.6882729, 2.2907830, 1.3983237>,
    <0.6595392, 2.6320514, 1.3635231>,
    <1.0001040, 2.2907830, 1.2866553>,
    <0.9579463, 2.6320514, 1.2549506>,
    <-0.0022414, 2.2907830, 1.4876584>,
    <-0.0008359, 2.6320514, 1.4503811>,
    <0.3496987, 2.2907830, 1.4653247>,
    <0.3357068, 2.6320514, 1.4286666>,
    <-0.6927113, 2.2907830, 1.3983237>,
    <-0.6611920, 2.6320514, 1.3635231>,
    <-0.3541705, 2.2907830, 1.4653247>,
    <-0.3373738, 2.6320514, 1.4286666>,
    <-1.2761200, 2.2907830, 1.1303196>,
    <-1.2198092, 2.6320514, 1.1029492>,
    <-1.0044868, 2.2907830, 1.2866553>,
    <-0.9595755, 2.6320514, 1.2549506>,
    <-1.6344862, 2.2907830, 0.6836460>,
    <-1.5644666, 2.6320514, 0.6686592>,
    <-1.4942336, 2.2907830, 0.9293165>,
    <-1.4291782, 2.6320514, 0.9075187>,
    <-1.6725365, 2.2907830, 0.3933082>,
    <-1.6024582, 2.6320514, 0.3863708>,
    <1.7401874, 1.5788248, 0.7054241>,
    <1.6902339, 1.9385866, 0.6962293>,
    <1.7781904, 1.5788248, 0.4019072>,
    <1.7277360, 1.9385866, 0.3986321>,
    <1.3583792, 1.5788248, 1.1723732>,
    <1.3192915, 1.9385866, 1.1540711>,
    <1.5914165, 1.5788248, 0.9622461>,
    <1.5455229, 1.9385866, 0.9480423>,
    <0.7334598, 1.5788248, 1.4525426>,
    <0.7132961, 1.9385866, 1.4287763>,
    <1.0675771, 1.5788248, 1.3358054>,
    <1.0372282, 1.9385866, 1.3143158>,
    <-0.0069236, 1.5788248, 1.5459324>,
    <-0.0043216, 1.9385866, 1.5203446>,
    <0.3704764, 1.5788248, 1.5225850>,
    <0.3614585, 1.9385866, 1.4974525>,
    <-0.7471759, 1.5788248, 1.4525426>,
    <-0.7218564, 1.9385866, 1.4287763>,
    <-0.3842908, 1.5788248, 1.5225850>,
    <-0.3700809, 1.9385866, 1.4974525>,
    <-1.3717022, 1.5788248, 1.1723732>,
    <-1.3276028, 1.9385866, 1.1540711>,
    <-1.0811295, 1.5788248, 1.3358054>,
    <-1.0456847, 1.9385866, 1.3143158>,
    <-1.7531557, 1.5788248, 0.7054241>,
    <-1.6984671, 1.9385866, 0.6962293>,
    <-1.6044446, 1.5788248, 0.9622461>,
    <-1.5536475, 1.9385866, 0.9480423>,
    <-1.7916342, 1.5788248, 0.4019072>,
    <-1.7367097, 1.9385866, 0.3986321>,
    <1.8065082, 0.8475771, 0.7130631>,
    <1.7769136, 1.2148607, 0.7102454>,
    <1.8455694, 0.8475771, 0.4023204>,
    <1.8153969, 1.2148607, 0.4026982>,
    <1.4094000, 0.8475771, 1.1911287>,
    <1.3868138, 1.2148607, 1.1833949>,
    <1.6519209, 0.8475771, 0.9759992>,
    <1.6250173, 1.2148607, 0.9704776>,
    <0.7584351, 0.8475771, 1.4779681>,
    <0.7476146, 1.2148607, 1.4672846>,
    <1.1065379, 0.8475771, 1.3584517>,
    <1.0894089, 1.2148607, 1.3489972>,
    <-0.0130906, 0.8475771, 1.5735812>,
    <-0.0098946, 1.2148607, 1.5619145>,
    <0.3801921, 0.8475771, 1.5496779>,
    <0.3762428, 1.2148607, 1.5382570>,
    <-0.7843730, 0.8475771, 1.4779681>,
    <-0.7672188, 1.2148607, 1.4672846>,
    <-0.4063125, 0.8475771, 1.5496779>,
    <-0.3959858, 1.2148607, 1.5382570>,
    <-1.4346079, 0.8475771, 1.1911287>,
    <-1.4058625, 1.2148607, 1.1833949>,
    <-1.1321717, 0.8475771, 1.3584517>,
    <-1.1087816, 1.2148607, 1.3489972>,
    <-1.8307226, 0.8475771, 0.7130631>,
    <-1.7952987, 1.2148607, 0.7102454>,
    <-1.6765813, 0.8475771, 0.9759992>,
    <-1.6436494, 1.2148607, 0.9704776>,
    <-1.8696630, 0.8475771, 0.4023204>,
    <-1.8339664, 1.2148607, 0.4026982>,
    <1.8558794, 0.1065190, 0.7176919>,
    <1.8350668, 0.4778570, 0.7162472>,
    <1.8965977, 0.1065190, 0.4010101>,
    <1.8749217, 0.4778570, 0.4020893>,
    <1.4462310, 0.1065190, 1.2048946>,
    <1.4309427, 0.4778570, 1.1995671>,
    <1.6962964, 0.1065190, 0.9856534>,
    <1.6777230, 0.4778570, 0.9820731>,
    <0.7753481, 0.1065190, 1.4972162>,
    <0.7685955, 0.4778570, 1.4895590>,
    <1.1340657, 0.1065190, 1.3754156>,
    <1.1227786, 0.4778570, 1.3687290>,
    <-0.0195533, 0.1065190, 1.5946568>,
    <-0.0163676, 0.4778570, 1.5862230>,
    <0.3856259, 0.1065190, 1.5702967>,
    <0.3837584, 0.4778570, 1.5620570>,
    <-0.8140917, 0.1065190, 1.4972162>,
    <-0.8010269, 0.4778570, 1.4895590>,
    <-0.4246417, 0.1065190, 1.5702967>,
    <-0.4164177, 0.4778570, 1.5620570>,
    <-1.4838858, 0.1065190, 1.2048946>,
    <-1.4624627, 0.4778570, 1.1995671>,
    <-1.1723557, 0.1065190, 1.3754156>,
    <-1.1548303, 0.4778570, 1.3687290>,
    <-1.8918710, 0.1065190, 0.7176919>,
    <-1.8652541, 0.4778570, 0.7162472>,
    <-1.7331346, 0.1065190, 0.9856534>,
    <-1.7085594, 0.4778570, 0.9820731>,
    <-1.9318645, 0.1065190, 0.4010101>,
    <-1.9046805, 0.4778570, 0.4020893>,
    <1.8544112, -0.6384540, 0.7094560>,
    <1.8622358, -0.2656179, 0.7152915>,
    <1.8966337, -0.6384540, 0.3936317>,
    <1.9037414, -0.2656179, 0.3980886>,
    <1.4426591, -0.6384540, 1.1953396>,
    <1.4500542, -0.2656179, 1.2032960>,
    <1.6936391, -0.6384540, 0.9766920>,
    <1.7015141, -0.2656179, 0.9836940>,
    <0.7705955, -0.6384540, 1.4868698>,
    <0.7759453, -0.2656179, 1.4960987>,
    <1.1298127, -0.6384540, 1.3653989>,
    <1.1363343, -0.2656179, 1.3740976>,
    <-0.0249689, -0.6384540, 1.5840465>,
    <-0.0224753, -0.2656179, 1.5936996>,
    <0.3805032, -0.6384540, 1.5597523>,
    <0.3844784, -0.2656179, 1.5692994>,
    <-0.8200698, -0.6384540, 1.4868698>,
    <-0.8204787, -0.2656179, 1.4960987>,
    <-0.4303251, -0.6384540, 1.5597523>,
    <-0.4293247, -0.2656179, 1.5692994>,
    <-1.4907430, -0.6384540, 1.1953396>,
    <-1.4933361, -0.2656179, 1.2032960>,
    <-1.1787077, -0.6384540, 1.3653989>,
    <-1.1803462, -0.2656179, 1.3740976>,
    <-1.9002703, -0.6384540, 0.7094560>,
    <-1.9035515, -0.2656179, 0.7152915>,
    <-1.7406802, -0.6384540, 0.9766920>,
    <-1.7438573, -0.2656179, 0.9836940>,
    <-1.9412640, -0.6384540, 0.3936317>,
    <-1.9440603, -0.2656179, 0.3980886>,
    <1.7973194, -1.3858239, 0.6891205>,
    <1.8326807, -1.0118893, 0.7005957>,
    <1.8407870, -1.3858239, 0.3813411>,
    <1.8755553, -1.0118893, 0.3879468>,
    <1.3952005, -1.3858239, 1.1626273>,
    <1.4242922, -1.0118893, 1.1815939>,
    <1.6396633, -1.3858239, 0.9495492>,
    <1.6729345, -1.0118893, 0.9651447>,
    <0.7428892, -1.3858239, 1.4467314>,
    <0.7595073, -1.0118893, 1.4701929>,
    <1.0913129, -1.3858239, 1.3283547>,
    <1.1147294, -1.0118893, 1.3499433>,
    <-0.0280117, -1.3858239, 1.5414327>,
    <-0.0268693, -1.0118893, 1.5663925>,
    <0.3648181, -1.3858239, 1.5177574>,
    <0.3738873, -1.0118893, 1.5423426>,
    <-0.7983927, -1.3858239, 1.4467314>,
    <-0.8127472, -1.0118893, 1.4701929>,
    <-0.4207116, -1.3858239, 1.5177574>,
    <-0.4275012, -1.0118893, 1.5423426>,
    <-1.4491442, -1.3858239, 1.1626273>,
    <-1.4760359, -1.0118893, 1.1815939>,
    <-1.1461665, -1.3858239, 1.3283547>,
    <-1.1673458, -1.0118893, 1.3499433>,
    <-1.8487227, -1.3858239, 0.6891205>,
    <-1.8820024, -1.0118893, 0.7005957>,
    <-1.6924371, -1.3858239, 0.9495492>,
    <-1.7235560, -1.0118893, 0.9651447>,
    <-1.8906783, -1.3858239, 0.3813411>,
    <-1.9234713, -1.0118893, 0.3879468>,
    <1.6868050, -2.0752537, 0.6599662>,
    <1.7486025, -1.7601581, 0.6754406>,
    <1.7313039, -2.0752537, 0.3665960>,
    <1.7926096, -1.7601581, 0.3741217>,
    <1.3058294, -2.0752537, 1.1113049>,
    <1.3556307, -1.7601581, 1.1390082>,
    <1.5364733, -2.0752537, 0.9082025>,
    <1.5940886, -1.7601581, 0.9304028>,
    <0.6938973, -2.0752537, 1.3821082>,
    <0.7209497, -1.7601581, 1.4171487>,
    <1.0203942, -2.0752537, 1.2692735>,
    <1.0597917, -1.7601581, 1.3012568>,
    <-0.0273636, -2.0752537, 1.4723760>,
    <-0.0282314, -1.7601581, 1.5098622>,
    <0.3400681, -2.0752537, 1.4498090>,
    <0.3534826, -1.7601581, 1.4866838>,
    <-0.7481166, -2.0752537, 1.3821082>,
    <-0.7768885, -1.7601581, 1.4171487>,
    <-0.3946684, -2.0752537, 1.4498090>,
    <-0.4098145, -1.7601581, 1.4866838>,
    <-1.3585250, -2.0752537, 1.1113049>,
    <-1.4099974, -1.7601581, 1.1390082>,
    <-1.0739786, -2.0752537, 1.2692735>,
    <-1.1150755, -1.7601581, 1.3012568>,
    <-1.7370274, -2.0752537, 0.6599662>,
    <-1.8004061, -1.7601581, 0.6754406>,
    <-1.5880260, -2.0752537, 0.9082025>,
    <-1.6472763, -1.7601581, 0.9304028>,
    <-1.7800746, -2.0752537, 0.3665960>,
    <-1.8428807, -1.7601581, 0.3741217>,
    <1.5319824, -2.4293115, 0.6240983>,
    <1.6122021, -2.2714726, 0.6431073>,
    <1.5773902, -2.4293115, 0.3508819>,
    <1.6571507, -2.2714726, 0.3590710>,
    <1.1819134, -2.4293115, 1.0444313>,
    <1.2460435, -2.2714726, 1.0800861>,
    <1.3925260, -2.4293115, 0.8552815>,
    <1.4670805, -2.2714726, 0.8834456>,
    <0.6279893, -2.4293115, 1.2966311>,
    <0.6619405, -2.2714726, 1.3422734>,
    <0.9230373, -2.4293115, 1.1915478>,
    <0.9733489, -2.2714726, 1.2330287>,
    <-0.0222556, -2.4293115, 1.3806977>,
    <-0.0252435, -2.2714726, 1.4296691>,
    <0.3088611, -2.4293115, 1.3596810>,
    <0.3247618, -2.2714726, 1.4078202>,
    <-0.6720873, -2.4293115, 1.2966311>,
    <-0.7119589, -2.2714726, 1.3422734>,
    <-0.3532690, -2.4293115, 1.3596810>,
    <-0.3751316, -2.2714726, 1.4078202>,
    <-1.2247722, -2.4293115, 1.0444313>,
    <-1.2946563, -2.2714726, 1.0800861>,
    <-0.9666190, -2.4293115, 1.1915478>,
    <-1.0227817, -2.2714726, 1.2330287>,
    <-1.5728977, -2.4293115, 0.6240983>,
    <-1.6585616, -2.2714726, 0.6431073>,
    <-1.4344553, -2.4293115, 0.8552815>,
    <-1.5146390, -2.2714726, 0.8834456>,
    <-1.6173292, -2.4293115, 0.3508819>,
    <-1.7022558, -2.2714726, 0.3590710>,
    <-1.3406401, -2.8468913, -0.4489504>,
    <-1.4572610, -2.8468913, 0.0636572>,
    <-1.3919592, -2.6292672, -0.4811918>,
    <-1.4217721, -2.8468913, -0.2021394>,
    <-1.5204677, -2.6292672, 0.0604910>,
    <-1.4795566, -2.6292672, -0.2203816>,
    <-1.0031119, -2.8468913, -0.8286598>,
    <-1.0388220, -2.6292672, -0.8824383>,
    <-1.1953615, -2.8468913, -0.6577906>,
    <-1.2391678, -2.6292672, -0.7018774>,
    <-0.5366935, -2.8468913, -1.0564854>,
    <-0.5558854, -2.6292672, -1.1231863>,
    <-0.7810671, -2.8468913, -0.9615581>,
    <-0.8085609, -2.6292672, -1.0228746>,
    <-0.0108269, -2.8468913, -1.1324273>,
    <-0.0132929, -2.6292672, -1.2034356>,
    <-0.2774579, -2.8468913, -1.1134418>,
    <-0.2882958, -2.6292672, -1.1833732>,
    <0.5147547, -2.8468913, -1.0564854>,
    <0.5289510, -2.6292672, -1.1231863>,
    <0.2557328, -2.8468913, -1.1134418>,
    <0.2616229, -2.6292672, -1.1833732>,
    <0.9803183, -2.8468913, -0.8286598>,
    <1.0108416, -2.6292672, -0.8824383>,
    <0.7587721, -2.8468913, -0.9615581>,
    <0.7811907, -2.6292672, -1.0228746>,
    <1.3162225, -2.8468913, -0.4489504>,
    <1.3620755, -2.6292672, -0.4811918>,
    <1.1719268, -2.8468913, -0.6577906>,
    <1.2104030, -2.6292672, -0.7018774>,
    <1.4299237, -2.8468913, 0.0636572>,
    <1.4874309, -2.6292672, 0.0604910>,
    <1.3958306, -2.8468913, -0.2021394>,
    <1.4480600, -2.6292672, -0.2203816>,
    <-1.3106888, -3.2653112, -0.3807525>,
    <-1.4116302, -3.2653112, 0.0642445>,
    <-1.3179997, -3.0577354, -0.4151181>,
    <-1.3840907, -3.2653112, -0.1664947>,
    <-1.4258266, -3.0577354, 0.0650921>,
    <-1.3946734, -3.0577354, -0.1839057>,
    <-0.9854011, -3.2653112, -0.7103798>,
    <-0.9886254, -3.0577354, -0.7708294>,
    <-1.1720792, -3.2653112, -0.5620475>,
    <-1.1769617, -3.0577354, -0.6107593>,
    <-0.5270016, -3.2653112, -0.9081563>,
    <-0.5288290, -3.0577354, -0.9842561>,
    <-0.7677939, -3.2653112, -0.8257494>,
    <-0.7700570, -3.0577354, -0.8953283>,
    <-0.0068367, -3.2653112, -0.9740817>,
    <-0.0086842, -3.0577354, -1.0553984>,
    <-0.2707679, -3.2653112, -0.9576004>,
    <-0.2725139, -3.0577354, -1.0376128>,
    <0.5131426, -3.2653112, -0.9081563>,
    <0.5112290, -3.0577354, -0.9842561>,
    <0.2570481, -3.2653112, -0.9576004>,
    <0.2550876, -3.0577354, -1.0376128>,
    <0.9709852, -3.2653112, -0.7103798>,
    <0.9703307, -3.0577354, -0.7708294>,
    <0.7537029, -3.2653112, -0.8257494>,
    <0.7521676, -3.0577354, -0.8953283>,
    <1.2950763, -3.2653112, -0.3807525>,
    <1.2983108, -3.0577354, -0.4151181>,
    <1.1572455, -3.2653112, -0.5620475>,
    <1.1581459, -3.0577354, -0.6107593>,
    <1.3934229, -3.2653112, 0.0642445>,
    <1.4033933, -3.0577354, 0.0650921>,
    <1.3670698, -3.2653112, -0.1664947>,
    <1.3735231, -3.0577354, -0.1839057>,
    <-1.3090774, -3.6847051, -0.3146525>,
    <-1.3989627, -3.6847051, 0.0534958>,
    <-1.3053583, -3.4731305, -0.3469114>,
    <-1.3774297, -3.6847051, -0.1373959>,
    <-1.4001373, -3.4731305, 0.0605628>,
    <-1.3758540, -3.4731305, -0.1507201>,
    <-0.9881617, -3.6847051, -0.5873549>,
    <-0.9834778, -3.4731305, -0.6487441>,
    <-1.1735171, -3.6847051, -0.4646388>,
    <-1.1688249, -3.4731305, -0.5129194>,
    <-0.5284077, -3.6847051, -0.7509764>,
    <-0.5259209, -3.4731305, -0.8298437>,
    <-0.7704245, -3.6847051, -0.6828008>,
    <-0.7665410, -3.4731305, -0.7543855>,
    <-0.0039442, -3.6847051, -0.8055169>,
    <-0.0052565, -3.4731305, -0.8902103>,
    <-0.2702135, -3.6847051, -0.7918817>,
    <-0.2695239, -3.4731305, -0.8751186>,
    <0.5204113, -3.6847051, -0.7509764>,
    <0.5152636, -3.4731305, -0.8298437>,
    <0.2622982, -3.6847051, -0.7918817>,
    <0.2589748, -3.4731305, -0.8751186>,
    <0.9798409, -3.6847051, -0.5873549>,
    <0.9723881, -3.4731305, -0.6487441>,
    <0.7622929, -3.6847051, -0.6828008>,
    <0.7557036, -3.4731305, -0.7543855>,
    <1.2999048, -3.6847051, -0.3146525>,
    <1.2932549, -3.4731305, -0.3469114>,
    <1.1649529, -3.6847051, -0.4646388>,
    <1.1574109, -3.4731305, -0.5129194>,
    <1.3875047, -3.6847051, 0.0534958>,
    <1.3855962, -3.4731305, 0.0605628>,
    <1.3669723, -3.6847051, -0.1373959>,
    <1.3624033, -3.4731305, -0.1507201>,
    <-1.3590146, -4.1331673, -0.2591125>,
    <-1.4441364, -4.1331673, 0.0270001>,
    <-1.3289154, -3.9035468, -0.2850336>,
    <-1.4262466, -4.1331673, -0.1213546>,
    <-1.4157211, -3.9035468, 0.0424920>,
    <-1.3962839, -3.9035468, -0.1273361>,
    <-1.0288473, -4.1331673, -0.4710478>,
    <-1.0047589, -3.9035468, -0.5276452>,
    <-1.2204458, -4.1331673, -0.3756769>,
    <-1.1924737, -3.9035468, -0.4184700>,
    <-0.5501678, -4.1331673, -0.5982089>,
    <-0.5372830, -3.9035468, -0.6732121>,
    <-0.8025267, -4.1331673, -0.5452251>,
    <-0.7835710, -3.9035468, -0.6125593>,
    <-0.0020711, -4.1331673, -0.6405960>,
    <-0.0029000, -3.9035468, -0.7217345>,
    <-0.2804546, -4.1331673, -0.6299992>,
    <-0.2742683, -3.9035468, -0.7096039>,
    <0.5459707, -4.1331673, -0.5982089>,
    <0.5314044, -3.9035468, -0.6732121>,
    <0.2762986, -4.1331673, -0.6299992>,
    <0.2684486, -3.9035468, -0.7096039>,
    <1.0244858, -4.1331673, -0.4710478>,
    <0.9986446, -3.9035468, -0.5276452>,
    <0.7982611, -4.1331673, -0.5452251>,
    <0.7775941, -3.9035468, -0.6125593>,
    <1.3540485, -4.1331673, -0.2591125>,
    <1.3220844, -3.9035468, -0.2850336>,
    <1.2159609, -4.1331673, -0.3756769>,
    <1.1861827, -3.9035468, -0.4184700>,
    <1.4371476, -4.1331673, 0.0270001>,
    <1.4067400, -3.9035468, 0.0424920>,
    <1.4201107, -4.1331673, -0.1213546>,
    <1.3882257, -3.9035468, -0.1273361>,
    <-1.4297406, -4.6387918, -0.2225944>,
    <-1.5142019, -4.6387918, -0.0196535>,
    <-1.3935176, -4.3770783, -0.2379468>,
    <-1.4981456, -4.6387918, -0.1248821>,
    <-1.4779324, -4.3770783, 0.0064687>,
    <-1.4611477, -4.3770783, -0.1202653>,
    <-1.0842242, -4.6387918, -0.3729210>,
    <-1.0560048, -4.3770783, -0.4189954>,
    <-1.2852946, -4.6387918, -0.3052740>,
    <-1.2521840, -4.3770783, -0.3375236>,
    <-0.5797633, -4.6387918, -0.4631170>,
    <-0.5646831, -4.3770783, -0.5276246>,
    <-0.8459460, -4.6387918, -0.4255353>,
    <-0.8238381, -4.3770783, -0.4823624>,
    <-0.0008980, -4.6387918, -0.4931823>,
    <-0.0014044, -4.3770783, -0.5638343>,
    <-0.2949795, -4.6387918, -0.4856660>,
    <-0.2875388, -4.3770783, -0.5547818>,
    <0.5779447, -4.6387918, -0.4631170>,
    <0.5618379, -4.3770783, -0.5276246>,
    <0.2931778, -4.6387918, -0.4856660>,
    <0.2847209, -4.3770783, -0.5547818>,
    <1.0823382, -4.6387918, -0.3729210>,
    <1.0530508, -4.3770783, -0.4189954>,
    <0.8440993, -4.6387918, -0.4255353>,
    <0.8209476, -4.3770783, -0.4823624>,
    <1.4274197, -4.6387918, -0.2225944>,
    <1.3900523, -4.3770783, -0.2379468>,
    <1.2833581, -4.6387918, -0.3052740>,
    <1.2491483, -4.3770783, -0.3375236>,
    <1.5101163, -4.6387918, -0.0196535>,
    <1.4725730, -4.3770783, 0.0064687>,
    <1.4947838, -4.6387918, -0.1248821>,
    <1.4565749, -4.3770783, -0.1202653>,
    <-1.5027036, -5.2296729, -0.2135603>,
    <-1.6251994, -5.3906840, -0.1121665>,
    <-1.4649998, -4.9218194, -0.2141130>,
    <-1.5841536, -5.2296729, -0.1321588>,
    <-1.5627429, -5.0256526, -0.0644110>,
    <-1.5343986, -4.9218194, -0.1360191>,
    <-1.1404550, -5.2296729, -0.3044374>,
    <-1.1114982, -4.9218194, -0.3342574>,
    <-1.3515469, -5.2296729, -0.2635427>,
    <-1.3173837, -4.9218194, -0.2801924>,
    <-0.6098255, -5.2296729, -0.3589637>,
    <-0.5943428, -4.9218194, -0.4063441>,
    <-0.8899281, -5.2296729, -0.3362444>,
    <-0.8672908, -4.9218194, -0.3763080>,
    <-0.0003293, -5.2296729, -0.3771391>,
    <-0.0005501, -4.9218194, -0.4303729>,
    <-0.3100061, -5.2296729, -0.3725953>,
    <-0.3022355, -4.9218194, -0.4243657>,
    <0.6091603, -5.2296729, -0.3589637>,
    <0.5932298, -4.9218194, -0.4063441>,
    <0.3093459, -5.2296729, -0.3725953>,
    <0.3011321, -4.9218194, -0.4243657>,
    <1.1397700, -5.2296729, -0.3044374>,
    <1.1103466, -4.9218194, -0.3342574>,
    <0.8892547, -5.2296729, -0.3362444>,
    <0.8661617, -4.9218194, -0.3763080>,
    <1.5016926, -5.2296729, -0.2135603>,
    <1.4634744, -4.9218194, -0.2141130>,
    <1.3508470, -5.2296729, -0.2635427>,
    <1.3162033, -4.9218194, -0.2801924>,
    <1.6223736, -5.3906840, -0.1121665>,
    <1.5598600, -5.0256526, -0.0644110>,
    <1.5818203, -5.2296729, -0.1321588>,
    <1.5319028, -4.9218194, -0.1360191>,
    <-1.5948577, -5.9443936, -0.2423176>,
    <-1.7116714, -5.9339047, -0.1910788>,
    <-1.5462604, -5.5658640, -0.2219940>,
    <-1.6738893, -5.9383999, -0.2176471>,
    <-1.6497739, -5.5658640, -0.1370793>,
    <-1.6187419, -5.5658640, -0.1811092>,
    <-1.2095822, -5.9634983, -0.2802722>,
    <-1.1737226, -5.5658640, -0.2848939>,
    <-1.4333268, -5.9533840, -0.2631926>,
    <-1.3908794, -5.5658640, -0.2565889>,
    <-0.6467908, -5.9805257, -0.3030450>,
    <-0.6276151, -5.5658640, -0.3226338>,
    <-0.9439095, -5.9728634, -0.2935563>,
    <-0.9159134, -5.5658640, -0.3069088>,
    <-0.0001438, -5.9873706, -0.3106359>,
    <-0.0002043, -5.5658640, -0.3352137>,
    <-0.3287082, -5.9855317, -0.3087382>,
    <-0.3189910, -5.5658640, -0.3320687>,
    <0.6465022, -5.9805257, -0.3030450>,
    <0.6272035, -5.5658640, -0.3226338>,
    <0.3284204, -5.9855317, -0.3087382>,
    <0.3185816, -5.5658640, -0.3320687>,
    <1.2092903, -5.9634983, -0.2802722>,
    <1.1733022, -5.5658640, -0.2848939>,
    <0.9436195, -5.9728634, -0.2935563>,
    <0.9154981, -5.5658640, -0.3069088>,
    <1.5943311, -5.9443936, -0.2423176>,
    <1.5455501, -5.5658640, -0.2219940>,
    <1.4330324, -5.9533840, -0.2631926>,
    <1.3904524, -5.5658640, -0.2565889>,
    <1.7095331, -5.9339047, -0.1910788>,
    <1.6471177, -5.5658640, -0.1370793>,
    <1.6726716, -5.9383999, -0.2176471>,
    <1.6171967, -5.5658640, -0.1811092>,
    <-1.6751726, -6.6107811, -0.2866866>,
    <-1.8491379, -6.5478478, -0.2866866>,
    <-1.6476831, -6.3792621, -0.2774341>,
    <-1.7800178, -6.5748192, -0.2866866>,
    <-1.7990662, -6.3373066, -0.2534261>,
    <-1.7424061, -6.3552875, -0.2658747>,
    <-1.2649237, -6.7254096, -0.2866866>,
    <-1.2463150, -6.4556811, -0.2952179>,
    <-1.4988773, -6.6647239, -0.2866866>,
    <-1.4768345, -6.4152240, -0.2872152>,
    <-0.6763841, -6.8275739, -0.2866866>,
    <-0.6664317, -6.5237906, -0.3058881>,
    <-0.9871037, -6.7816000, -0.2866866>,
    <-0.9725794, -6.4931414, -0.3014422>,
    <-0.0001120, -6.8686430, -0.2866866>,
    <-0.0001163, -6.5511701, -0.3094449>,
    <-0.3437313, -6.8576097, -0.2866866>,
    <-0.3386760, -6.5438145, -0.3085557>,
    <0.6761602, -6.8275739, -0.2866866>,
    <0.6661988, -6.5237906, -0.3058881>,
    <0.3435074, -6.8576097, -0.2866866>,
    <0.3384433, -6.5438145, -0.3085557>,
    <1.2646997, -6.7254096, -0.2866866>,
    <1.2460812, -6.4556811, -0.2952179>,
    <0.9868798, -6.7816000, -0.2866866>,
    <0.9723461, -6.4931414, -0.3014422>,
    <1.6748846, -6.6107811, -0.2866866>,
    <1.6473196, -6.3792621, -0.2774341>,
    <1.4986534, -6.6647239, -0.2866866>,
    <1.4766001, -6.4152240, -0.2872152>,
    <1.8484007, -6.5478478, -0.2866866>,
    <1.7978025, -6.3373066, -0.2534261>,
    <1.7795372, -6.5748192, -0.2866866>,
    <1.7416567, -6.3552875, -0.2658747>,
    <1.3908011, -2.8468913, 0.5762648>,
    <1.4533345, -2.6292672, 0.6021738>,
    <1.4376744, -2.8468913, 0.3294538>,
    <1.4992626, -2.6292672, 0.3413636>,
    <1.0687726, -2.8468913, 0.9559742>,
    <1.1190797, -2.6292672, 1.0034204>,
    <1.2610222, -2.8468913, 0.7851050>,
    <1.3194256, -2.6292672, 0.8228594>,
    <0.5686933, -2.8468913, 1.1837998>,
    <0.5949536, -2.6292672, 1.2441683>,
    <0.8344874, -2.8468913, 1.0888725>,
    <0.8738407, -2.6292672, 1.1438567>,
    <-0.0153147, -2.8468913, 1.2597417>,
    <-0.0187843, -2.6292672, 1.3244176>,
    <0.2819171, -2.8468913, 1.2407562>,
    <0.2936636, -2.6292672, 1.3043553>,
    <-0.5990378, -2.8468913, 1.1837998>,
    <-0.6321736, -2.6292672, 1.2441683>,
    <-0.3124752, -2.8468913, 1.2407562>,
    <-0.3311451, -2.6292672, 1.3043553>,
    <-1.0982622, -2.8468913, 0.9559742>,
    <-1.1552537, -2.6292672, 1.0034204>,
    <-0.8644757, -2.8468913, 1.0888725>,
    <-0.9106249, -2.6292672, 1.1438567>,
    <-1.4190653, -2.8468913, 0.5762648>,
    <-1.4879251, -2.6292672, 0.6021738>,
    <-1.2898707, -2.8468913, 0.7851050>,
    <-1.3548151, -2.6292672, 0.8228594>,
    <-1.4656104, -2.8468913, 0.3294538>,
    <-1.5331999, -2.6292672, 0.3413636>,
    <1.3436667, -3.2653112, 0.5092414>,
    <1.3589250, -3.0577354, 0.5453024>,
    <1.3943324, -3.2653112, 0.2949836>,
    <1.4075319, -3.0577354, 0.3140900>,
    <1.0286161, -3.2653112, 0.8388688>,
    <1.0422224, -3.0577354, 0.9010136>,
    <1.2152941, -3.2653112, 0.6905365>,
    <1.2305587, -3.0577354, 0.7409436>,
    <0.5482854, -3.2653112, 1.0366452>,
    <0.5550680, -3.0577354, 1.1144404>,
    <0.8030339, -3.2653112, 0.9542384>,
    <0.8137057, -3.0577354, 1.0255126>,
    <-0.0097606, -3.2653112, 1.1025707>,
    <-0.0123316, -3.0577354, 1.1855827>,
    <0.2741080, -3.2653112, 1.0860893>,
    <0.2763690, -3.0577354, 1.1677971>,
    <-0.5676209, -3.2653112, 1.0366452>,
    <-0.5794997, -3.0577354, 1.1144404>,
    <-0.2935828, -3.2653112, 1.0860893>,
    <-0.3009744, -3.0577354, 1.1677971>,
    <-1.0473946, -3.2653112, 0.8388688>,
    <-1.0659593, -3.0577354, 0.9010136>,
    <-0.8221374, -3.2653112, 0.9542384>,
    <-0.8378478, -3.0577354, 1.0255126>,
    <-1.3617854, -3.2653112, 0.5092414>,
    <-1.3817403, -3.0577354, 0.5453024>,
    <-1.2336550, -3.2653112, 0.6905365>,
    <-1.2537745, -3.0577354, 0.7409436>,
    <-1.4126528, -3.2653112, 0.2949836>,
    <-1.4303033, -3.0577354, 0.3140900>,
    <1.3282057, -3.6847051, 0.4216441>,
    <1.3309869, -3.4731305, 0.4680370>,
    <1.3828511, -3.6847051, 0.2443875>,
    <1.3835736, -3.4731305, 0.2718457>,
    <1.0134073, -3.6847051, 0.6943465>,
    <1.0171403, -3.4731305, 0.7698697>,
    <1.1987626, -3.6847051, 0.5716304>,
    <1.2024874, -3.4731305, 0.6340450>,
    <0.5408798, -3.6847051, 0.8579680>,
    <0.5425531, -3.4731305, 0.9509693>,
    <0.7910252, -3.6847051, 0.7897924>,
    <0.7940107, -3.4731305, 0.8755112>,
    <-0.0056472, -3.6847051, 0.9125084>,
    <-0.0075270, -3.4731305, 1.0113359>,
    <0.2722345, -3.6847051, 0.8988733>,
    <0.2722224, -3.4731305, 0.9962442>,
    <-0.5520660, -3.6847051, 0.8579680>,
    <-0.5574631, -3.4731305, 0.9509693>,
    <-0.2835018, -3.6847051, 0.8988733>,
    <-0.2872404, -3.4731305, 0.9962442>,
    <-1.0242691, -3.6847051, 0.6943465>,
    <-1.0316178, -3.4731305, 0.7698697>,
    <-0.8020762, -3.6847051, 0.7897924>,
    <-0.8087404, -3.4731305, 0.8755112>,
    <-1.3388380, -3.6847051, 0.4216441>,
    <-1.3450365, -3.4731305, 0.4680370>,
    <-1.2093812, -3.6847051, 0.5716304>,
    <-1.2166405, -3.4731305, 0.6340450>,
    <-1.3940653, -3.6847051, 0.2443875>,
    <-1.3980334, -3.4731305, 0.2718457>,
    <1.3683936, -4.1331673, 0.3131127>,
    <1.3426436, -3.9035468, 0.3700177>,
    <1.4281593, -4.1331673, 0.1753548>,
    <1.3997608, -3.9035468, 0.2123201>,
    <1.0414999, -4.1331673, 0.5250480>,
    <1.0230290, -3.9035468, 0.6126292>,
    <1.2330983, -4.1331673, 0.4296771>,
    <1.2107438, -3.9035468, 0.5034540>,
    <0.5563457, -4.1331673, 0.6522092>,
    <0.5462737, -3.9035468, 0.7581962>,
    <0.8128248, -4.1331673, 0.5992254>,
    <0.7984667, -3.9035468, 0.6975433>,
    <-0.0029344, -4.1331673, 0.6945962>,
    <-0.0041372, -3.9035468, 0.8067185>,
    <0.2813351, -4.1331673, 0.6839995>,
    <0.2756668, -3.9035468, 0.7945879>,
    <-0.5621596, -4.1331673, 0.6522092>,
    <-0.5544696, -3.9035468, 0.7581962>,
    <-0.2871901, -4.1331673, 0.6839995>,
    <-0.2839216, -3.9035468, 0.7945879>,
    <-1.0471494, -4.1331673, 0.5250480>,
    <-1.0309892, -3.9035468, 0.6126292>,
    <-0.8185702, -4.1331673, 0.5992254>,
    <-0.8065643, -3.9035468, 0.6975433>,
    <-1.3740996, -4.1331673, 0.3131127>,
    <-1.3505350, -3.9035468, 0.3700177>,
    <-1.2386245, -4.1331673, 0.4296771>,
    <-1.2185272, -3.9035468, 0.5034540>,
    <-1.4346788, -4.1331673, 0.1753548>,
    <-1.4083689, -3.9035468, 0.2123201>,
    <1.4332997, -4.6387918, 0.1832874>,
    <1.3995492, -4.3770783, 0.2508843>,
    <1.4980829, -4.6387918, 0.0855751>,
    <1.4619033, -4.3770783, 0.1332028>,
    <1.0893123, -4.6387918, 0.3336140>,
    <1.0643146, -4.3770783, 0.4319329>,
    <1.2903827, -4.6387918, 0.2659670>,
    <1.2604938, -4.3770783, 0.3504610>,
    <0.5821975, -4.6387918, 0.4238100>,
    <0.5687065, -4.3770783, 0.5405621>,
    <0.8500690, -4.6387918, 0.3862283>,
    <0.8305892, -4.3770783, 0.4952999>,
    <-0.0012519, -4.6387918, 0.4538753>,
    <-0.0019759, -4.3770783, 0.5767718>,
    <0.2952423, -4.6387918, 0.4463589>,
    <0.2880552, -4.3770783, 0.5677193>,
    <-0.5846787, -4.6387918, 0.4238100>,
    <-0.5726220, -4.3770783, 0.5405621>,
    <-0.2977404, -4.6387918, 0.4463589>,
    <-0.2919979, -4.3770783, 0.5677193>,
    <-1.0917262, -4.6387918, 0.3336140>,
    <-1.0681213, -4.3770783, 0.4319329>,
    <-0.8525222, -4.6387918, 0.3862283>,
    <-0.8344594, -4.3770783, 0.4952999>,
    <-1.4359239, -4.6387918, 0.1832874>,
    <-1.4035043, -4.3770783, 0.2508843>,
    <-1.2927460, -4.6387918, 0.2659670>,
    <-1.2642188, -4.3770783, 0.3504610>,
    <-1.5016019, -4.6387918, 0.0855751>,
    <-1.4667301, -4.3770783, 0.1332028>,
    <1.5034196, -5.2296729, 0.0318080>,
    <1.4668347, -4.9218194, 0.1102770>,
    <1.5825137, -5.2296729, -0.0495935>,
    <1.5337881, -4.9218194, 0.0321831>,
    <1.1418183, -5.2296729, 0.1226851>,
    <1.1143321, -4.9218194, 0.2304214>,
    <1.3529102, -5.2296729, 0.0817904>,
    <1.3202177, -4.9218194, 0.1763564>,
    <0.6104093, -5.2296729, 0.1772114>,
    <0.5956601, -4.9218194, 0.3025080>,
    <0.8910080, -5.2296729, 0.1544921>,
    <0.8695732, -4.9218194, 0.2724719>,
    <-0.0004332, -5.2296729, 0.1953868>,
    <-0.0007523, -4.9218194, 0.3265369>,
    <0.3099522, -5.2296729, 0.1908430>,
    <0.3023118, -4.9218194, 0.3205297>,
    <-0.6112692, -5.2296729, 0.1772114>,
    <-0.5971519, -4.9218194, 0.3025080>,
    <-0.3108170, -5.2296729, 0.1908430>,
    <-0.3038133, -4.9218194, 0.3205297>,
    <-1.1426584, -5.2296729, 0.1226851>,
    <-1.1157854, -4.9218194, 0.2304214>,
    <-0.8918596, -5.2296729, 0.1544921>,
    <-0.8710490, -4.9218194, 0.2724719>,
    <-1.5045197, -5.2296729, 0.0318080>,
    <-1.4685334, -4.9218194, 0.1102770>,
    <-1.3537355, -5.2296729, 0.0817904>,
    <-1.3216421, -4.9218194, 0.1763564>,
    <-1.5848801, -5.2296729, -0.0495935>,
    <-1.5363738, -4.9218194, 0.0321831>,
    <1.5946175, -5.9443936, -0.1398400>,
    <1.7095331, -5.9339047, -0.1910788>,
    <1.5463198, -5.5658640, -0.0521645>,
    <1.6728323, -5.9383999, -0.1645105>,
    <1.6471177, -5.5658640, -0.1370793>,
    <1.6176285, -5.5658640, -0.0930494>,
    <1.2096299, -5.9634983, -0.1018854>,
    <1.1742151, -5.5658640, 0.0107353>,
    <1.4333745, -5.9533840, -0.1189650>,
    <1.3913719, -5.5658640, -0.0175696>,
    <0.6467093, -5.9805257, -0.0791126>,
    <0.6277602, -5.5658640, 0.0484752>,
    <0.9439102, -5.9728634, -0.0886012>,
    <0.9162796, -5.5658640, 0.0327502>,
    <-0.0001610, -5.9873706, -0.0715217>,
    <-0.0002506, -5.5658640, 0.0610552>,
    <0.3285209, -5.9855317, -0.0734194>,
    <0.3188518, -5.5658640, 0.0579102>,
    <-0.6470302, -5.9805257, -0.0791126>,
    <-0.6282585, -5.5658640, 0.0484752>,
    <-0.3288427, -5.9855317, -0.0734194>,
    <-0.3193524, -5.5658640, 0.0579102>,
    <-1.2099476, -5.9634983, -0.1018854>,
    <-1.1747046, -5.5658640, 0.0107353>,
    <-0.9442298, -5.9728634, -0.0886012>,
    <-0.9167742, -5.5658640, 0.0327502>,
    <-1.5951589, -5.9443936, -0.1398400>,
    <-1.5470698, -5.5658640, -0.0521645>,
    <-1.4336897, -5.9533840, -0.1189650>,
    <-1.3918548, -5.5658640, -0.0175696>,
    <-1.7116714, -5.9339047, -0.1910788>,
    <-1.6497739, -5.5658640, -0.1370793>,
    <-1.6740577, -5.9383999, -0.1645105>,
    <-1.6191944, -5.5658640, -0.0930494>,
    <1.6473948, -6.3792621, -0.2294180>,
    <1.7978025, -6.3373066, -0.2534261>,
    <1.7416988, -6.3552875, -0.2409774>,
    <1.2461704, -6.4556811, -0.2116342>,
    <1.4766899, -6.4152240, -0.2196369>,
    <0.6662532, -6.5237906, -0.2009640>,
    <0.9724224, -6.4931414, -0.2054099>,
    <-0.0001208, -6.5511701, -0.1974072>,
    <0.3384697, -6.5438145, -0.1982964>,
    <-0.6664945, -6.5237906, -0.2009640>,
    <-0.3387113, -6.5438145, -0.1982964>,
    <-1.2464109, -6.4556811, -0.2116342>,
    <-0.9726634, -6.4931414, -0.2054099>,
    <-1.6477622, -6.3792621, -0.2294180>,
    <-1.4769298, -6.4152240, -0.2196369>,
    <-1.7990662, -6.3373066, -0.2534261>,
    <-1.7424503, -6.3552875, -0.2409774>
  }
  normal_vectors {
    1548,
    <-0.7713928, 0.6310028, -0.0823924>,
    <-0.7217537, 0.6921498, -0.0004973>,
    <-0.0000000, 1.0000000, -0.0000000>,
    <-0.7318096, 0.6431724, -0.2253533>,
    <-0.8602366, 0.4364968, -0.2635594>,
    <-0.8732518, 0.4799945, -0.0838844>,
    <-0.8589962, 0.5119809, -0.0010967>,
    <-0.7067985, 0.5532492, -0.4408529>,
    <-0.5783422, 0.5684377, -0.5851486>,
    <-0.6573893, 0.3301701, -0.6773677>,
    <-0.7828277, 0.3657178, -0.5034195>,
    <-0.4667437, 0.4928644, -0.7343262>,
    <-0.3040554, 0.5469188, -0.7800193>,
    <-0.3431274, 0.3050993, -0.8883569>,
    <-0.5071254, 0.3021781, -0.8071631>,
    <-0.1555114, 0.5030828, -0.8501317>,
    <-0.0000000, 0.5836678, -0.8119925>,
    <-0.0000000, 0.3480722, -0.9374677>,
    <-0.1681799, 0.3134355, -0.9345982>,
    <0.1516792, 0.5684690, -0.8086015>,
    <0.2729124, 0.6598054, -0.7001254>,
    <0.3228249, 0.4441091, -0.8357937>,
    <0.1705693, 0.3859818, -0.9066003>,
    <0.4041437, 0.6641201, -0.6289772>,
    <0.4663604, 0.7469748, -0.4738530>,
    <0.5735989, 0.5671568, -0.5910308>,
    <0.4668343, 0.5007475, -0.7289154>,
    <0.5504885, 0.7573976, -0.3511571>,
    <0.5442784, 0.8161013, -0.1942669>,
    <0.6906344, 0.6810863, -0.2431987>,
    <0.6567930, 0.6244266, -0.4227462>,
    <0.5735024, 0.8148010, -0.0848194>,
    <0.5257168, 0.8506596, -0.0003623>,
    <0.6752902, 0.7375516, -0.0008621>,
    <0.6957051, 0.7119912, -0.0951998>,
    <-0.9288243, 0.3593758, -0.0901918>,
    <-0.9214598, 0.3884679, -0.0021094>,
    <-0.9090726, 0.3026775, -0.2863098>,
    <-0.9342543, 0.1888774, -0.3024801>,
    <-0.9655014, 0.2399321, -0.1011912>,
    <-0.9628675, 0.2699484, -0.0037377>,
    <-0.8147286, 0.2435412, -0.5262177>,
    <-0.6804823, 0.2031317, -0.7040464>,
    <-0.6894079, 0.1010749, -0.7172870>,
    <-0.8304165, 0.1356291, -0.5403825>,
    <-0.5237981, 0.1839968, -0.8317335>,
    <-0.3533961, 0.1787730, -0.9182328>,
    <-0.3565947, 0.0779835, -0.9309988>,
    <-0.5297731, 0.0826188, -0.8441058>,
    <-0.1760879, 0.1915929, -0.9655492>,
    <-0.0000000, 0.2155874, -0.9764846>,
    <-0.0000000, 0.1064183, -0.9943215>,
    <-0.1786412, 0.0862417, -0.9801274>,
    <0.1748533, 0.2555858, -0.9508429>,
    <0.3422004, 0.3038485, -0.8891428>,
    <0.3518208, 0.1803197, -0.9185352>,
    <0.1775956, 0.1379222, -0.9743907>,
    <0.4974007, 0.3650052, -0.7869966>,
    <0.6282453, 0.4275596, -0.6500005>,
    <0.6627731, 0.2919213, -0.6895751>,
    <0.5170165, 0.2325511, -0.8237802>,
    <0.7271671, 0.4956941, -0.4748845>,
    <0.7852180, 0.5557672, -0.2730487>,
    <0.8576699, 0.4205793, -0.2958302>,
    <0.7808521, 0.3563897, -0.5130852>,
    <0.7938882, 0.5989474, -0.1048973>,
    <0.7822310, 0.6229859, -0.0017907>,
    <0.8709406, 0.4913766, -0.0033808>,
    <0.8781167, 0.4649896, -0.1126750>,
    <-0.9825402, 0.1499240, -0.1101706>,
    <-0.9842158, 0.1768655, -0.0061467>,
    <-0.9437996, 0.1058347, -0.3131156>,
    <-0.9456079, 0.0506745, -0.3213375>,
    <-0.9890963, 0.0883311, -0.1178395>,
    <-0.9936765, 0.1118761, -0.0095299>,
    <-0.8340133, 0.0603200, -0.5484371>,
    <-0.6900137, 0.0304468, -0.7231556>,
    <-0.6869401, -0.0140945, -0.7265773>,
    <-0.8323485, 0.0118519, -0.5541259>,
    <-0.5290548, 0.0139052, -0.8484737>,
    <-0.3557743, 0.0087761, -0.9345307>,
    <-0.3532405, -0.0345612, -0.9348939>,
    <-0.5257869, -0.0290453, -0.8501203>,
    <-0.1782758, 0.0142651, -0.9838771>,
    <-0.0000000, 0.0296144, -0.9995614>,
    <0.0000000, -0.0198895, -0.9998022>,
    <-0.1769645, -0.0313045, -0.9837193>,
    <0.1780291, 0.0544919, -0.9825153>,
    <0.3543807, 0.0888556, -0.9308700>,
    <0.3533241, 0.0268655, -0.9351151>,
    <0.1770512, -0.0005347, -0.9842015>,
    <0.5244518, 0.1323455, -0.8410915>,
    <0.6786297, 0.1833604, -0.7112248>,
    <0.6832267, 0.1047790, -0.7226497>,
    <0.5249876, 0.0622821, -0.8488280>,
    <0.8093987, 0.2410441, -0.5355104>,
    <0.9013007, 0.3014373, -0.3111150>,
    <0.9237904, 0.2078187, -0.3215940>,
    <0.8215060, 0.1541990, -0.5489540>,
    <0.9312145, 0.3447369, -0.1183048>,
    <0.9290791, 0.3698356, -0.0058023>,
    <0.9627876, 0.2701013, -0.0092336>,
    <0.9610245, 0.2474144, -0.1233614>,
    <-0.9901446, 0.0621165, -0.1255194>,
    <-0.9964827, 0.0825959, -0.0141452>,
    <-0.9437680, 0.0301283, -0.3292329>,
    <-0.9398476, 0.0499736, -0.3379189>,
    <-0.9879835, 0.0768863, -0.1340786>,
    <-0.9952910, 0.0947797, -0.0203121>,
    <-0.8285618, -0.0030866, -0.5598891>,
    <-0.6826143, -0.0259550, -0.7303178>,
    <-0.6776760, 0.0009684, -0.7353599>,
    <-0.8236039, 0.0215146, -0.5667572>,
    <-0.5217825, -0.0397680, -0.8521511>,
    <-0.3502420, -0.0457098, -0.9355432>,
    <-0.3471194, -0.0186727, -0.9376350>,
    <-0.5175046, -0.0121715, -0.8555938>,
    <-0.1753768, -0.0442882, -0.9835047>,
    <-0.0000000, -0.0359957, -0.9993519>,
    <0.0000000, -0.0130544, -0.9999148>,
    <-0.1737193, -0.0188472, -0.9846148>,
    <0.1755104, -0.0209975, -0.9842536>,
    <0.3506083, 0.0008364, -0.9365218>,
    <0.3471347, 0.0161449, -0.9376763>,
    <0.1737499, -0.0014231, -0.9847888>,
    <0.5219670, 0.0295846, -0.8524525>,
    <0.6814159, 0.0646471, -0.7290357>,
    <0.6760716, 0.0687776, -0.7336190>,
    <0.5171348, 0.0397069, -0.8549824>,
    <0.8233500, 0.1061398, -0.5575206>,
    <0.9318526, 0.1520810, -0.3294270>,
    <0.9309114, 0.1419346, -0.3365391>,
    <0.8191489, 0.1034461, -0.5641755>,
    <0.9739702, 0.1867194, -0.1285217>,
    <0.9783137, 0.2066624, -0.0138873>,
    <0.9818522, 0.1885860, -0.0200379>,
    <0.9759962, 0.1712241, -0.1345874>,
    <-0.9829047, 0.1149878, -0.1437920>,
    <-0.9909282, 0.1314075, -0.0281653>,
    <-0.9332560, 0.0914718, -0.3473704>,
    <-0.9225732, 0.1461891, -0.3570538>,
    <-0.9734689, 0.1687614, -0.1545251>,
    <-0.9819541, 0.1853233, -0.0377021>,
    <-0.8162448, 0.0659028, -0.5739349>,
    <-0.6707749, 0.0463186, -0.7402132>,
    <-0.6610102, 0.1001346, -0.7436656>,
    <-0.8052906, 0.1207986, -0.5804436>,
    <-0.5117947, 0.0330144, -0.8584732>,
    <-0.3430851, 0.0255911, -0.9389556>,
    <-0.3377461, 0.0761970, -0.9381479>,
    <-0.5040197, 0.0853002, -0.8594696>,
    <-0.1716258, 0.0239243, -0.9848717>,
    <0.0000000, 0.0277732, -0.9996142>,
    <0.0000000, 0.0751492, -0.9971723>,
    <-0.1689141, 0.0728642, -0.9829338>,
    <0.1715571, 0.0370395, -0.9844776>,
    <0.3427370, 0.0517860, -0.9380030>,
    <0.3371542, 0.0963722, -0.9365038>,
    <0.1687802, 0.0829730, -0.9821551>,
    <0.5107441, 0.0720207, -0.8567108>,
    <0.6683110, 0.0972771, -0.7374941>,
    <0.6578733, 0.1392869, -0.7401364>,
    <0.5024891, 0.1153090, -0.8568597>,
    <0.8113513, 0.1275110, -0.5704822>,
    <0.9250035, 0.1608045, -0.3442534>,
    <0.9143236, 0.1994465, -0.3524676>,
    <0.7998606, 0.1681008, -0.5761641>,
    <0.9721686, 0.1862159, -0.1421684>,
    <0.9789768, 0.2020646, -0.0278256>,
    <0.9702210, 0.2393396, -0.0372516>,
    <0.9629209, 0.2234182, -0.1512202>,
    <-0.9594361, 0.2278340, -0.1660541>,
    <-0.9683958, 0.2446094, -0.0487422>,
    <-0.9073319, 0.2059868, -0.3664946>,
    <-0.8938530, 0.2417269, -0.3776174>,
    <-0.9484337, 0.2614377, -0.1792311>,
    <-0.9588589, 0.2771809, -0.0613217>,
    <-0.7902866, 0.1805600, -0.5855298>,
    <-0.6480550, 0.1587589, -0.7448626>,
    <-0.6351799, 0.1973798, -0.7467180>,
    <-0.7759213, 0.2182184, -0.5918842>,
    <-0.4939767, 0.1424214, -0.8577314>,
    <-0.3309941, 0.1316967, -0.9343976>,
    <-0.3241353, 0.1703999, -0.9305376>,
    <-0.4838321, 0.1813605, -0.8561629>,
    <-0.1655385, 0.1267648, -0.9780223>,
    <0.0000000, 0.1275492, -0.9918322>,
    <0.0000000, 0.1643063, -0.9864094>,
    <-0.1621144, 0.1647257, -0.9729257>,
    <0.1653800, 0.1339886, -0.9770857>,
    <0.3303196, 0.1460992, -0.9324934>,
    <0.3236266, 0.1791131, -0.9290771>,
    <0.1619928, 0.1690974, -0.9721957>,
    <0.4923227, 0.1638106, -0.8548593>,
    <0.6448492, 0.1866139, -0.7411780>,
    <0.6328839, 0.2142288, -0.7440188>,
    <0.4826149, 0.1942969, -0.8540091>,
    <0.7851368, 0.2141748, -0.5811105>,
    <0.9000303, 0.2438283, -0.3612384>,
    <0.8893267, 0.2647507, -0.3728338>,
    <0.7724815, 0.2385916, -0.5885120>,
    <0.9501410, 0.2665940, -0.1617395>,
    <0.9579796, 0.2827546, -0.0482180>,
    <0.9518755, 0.3003786, -0.0608751>,
    <0.9424541, 0.2850492, -0.1747201>,
    <-0.9453306, 0.2617317, -0.1945418>,
    <-0.9581997, 0.2759868, -0.0753961>,
    <-0.8869685, 0.2443927, -0.3918662>,
    <-0.8861498, 0.2194532, -0.4081407>,
    <-0.9489267, 0.2345459, -0.2110127>,
    <-0.9647466, 0.2472402, -0.0902010>,
    <-0.7665246, 0.2235408, -0.6020545>,
    <-0.6258888, 0.2048565, -0.7525271>,
    <-0.6206371, 0.1855294, -0.7618323>,
    <-0.7622193, 0.2014937, -0.6151601>,
    <-0.4761703, 0.1903729, -0.8584987>,
    <-0.3188353, 0.1802569, -0.9305114>,
    <-0.3155049, 0.1645544, -0.9345472>,
    <-0.4715096, 0.1732117, -0.8646828>,
    <-0.1594443, 0.1746858, -0.9716287>,
    <0.0000000, 0.1736244, -0.9848119>,
    <0.0000000, 0.1583678, -0.9873802>,
    <-0.1577442, 0.1596295, -0.9744923>,
    <0.1593764, 0.1770341, -0.9712148>,
    <0.3185533, 0.1849399, -0.9296887>,
    <0.3153872, 0.1667436, -0.9341988>,
    <0.1577158, 0.1607261, -0.9743166>,
    <0.4755030, 0.1973343, -0.8572958>,
    <0.6246443, 0.2139445, -0.7510308>,
    <0.6201217, 0.1898004, -0.7611996>,
    <0.4712324, 0.1764724, -0.8641745>,
    <0.7648783, 0.2345893, -0.5999409>,
    <0.8851522, 0.2569831, -0.3878985>,
    <0.8861265, 0.2255009, -0.4048816>,
    <0.7617793, 0.2067284, -0.6139672>,
    <0.9425260, 0.2747021, -0.1902197>,
    <0.9544591, 0.2887342, -0.0751018>,
    <0.9631532, 0.2534295, -0.0900520>,
    <0.9482358, 0.2408346, -0.2069967>,
    <-0.9516198, 0.2077720, -0.2263859>,
    <-0.9700596, 0.2193001, -0.1043638>,
    <-0.8850915, 0.1942084, -0.4229610>,
    <-0.8816496, 0.1831913, -0.4348965>,
    <-0.9508567, 0.1963653, -0.2393995>,
    <-0.9712762, 0.2074057, -0.1166425>,
    <-0.7584010, 0.1783125, -0.6269231>,
    <-0.6162425, 0.1643623, -0.7702144>,
    <-0.6113993, 0.1544667, -0.7760998>,
    <-0.7533889, 0.1678416, -0.6357943>,
    <-0.4677475, 0.1536739, -0.8704003>,
    <-0.3128803, 0.1461430, -0.9384818>,
    <-0.3103125, 0.1369788, -0.9407141>,
    <-0.4639074, 0.1442328, -0.8740634>,
    <-0.1564225, 0.1417622, -0.9774638>,
    <0.0000000, 0.1404355, -0.9900898>,
    <-0.0000000, 0.1311928, -0.9913569>,
    <-0.1551569, 0.1326676, -0.9789411>,
    <0.1564148, 0.1421144, -0.9774139>,
    <0.3128484, 0.1468451, -0.9383829>,
    <0.3103340, 0.1366431, -0.9407558>,
    <0.1551622, 0.1325023, -0.9789626>,
    <0.4676723, 0.1547178, -0.8702557>,
    <0.6161028, 0.1657266, -0.7700338>,
    <0.6114894, 0.1537650, -0.7761681>,
    <0.4639570, 0.1437181, -0.8741219>,
    <0.7585659, 0.1799991, -0.6262412>,
    <0.8859604, 0.1962063, -0.4202110>,
    <0.8830081, 0.1822035, -0.4325489>,
    <0.7539027, 0.1669670, -0.6354154>,
    <0.9520258, 0.2098803, -0.2227042>,
    <0.9696004, 0.2213494, -0.1043048>,
    <0.9715265, 0.2062541, -0.1165995>,
    <0.9519079, 0.1953155, -0.2360575>,
    <0.5221752, 0.8492034, 0.0786557>,
    <0.4404170, 0.8839970, 0.1567873>,
    <0.5746718, 0.7932189, 0.2013856>,
    <0.6436572, 0.7598547, 0.0912480>,
    <0.3914146, 0.8848585, 0.2526263>,
    <0.2971131, 0.9058314, 0.3019821>,
    <0.3875868, 0.8307141, 0.3996131>,
    <0.4841532, 0.8150885, 0.3181609>,
    <0.2359881, 0.8978922, 0.3716169>,
    <0.1499576, 0.9106046, 0.3851129>,
    <0.1960594, 0.8383840, 0.5085991>,
    <0.2925928, 0.8347856, 0.4663930>,
    <0.0793064, 0.8973476, 0.4341402>,
    <0.0000000, 0.9060322, 0.4232088>,
    <0.0000000, 0.8299901, 0.5577781>,
    <0.0976298, 0.8335504, 0.5437482>,
    <-0.0848962, 0.8873549, 0.4532040>,
    <-0.1636531, 0.8925123, 0.4202849>,
    <-0.2127620, 0.8062931, 0.5519273>,
    <-0.1061998, 0.8177294, 0.5657210>,
    <-0.2718284, 0.8641835, 0.4234339>,
    <-0.3557712, 0.8624237, 0.3600726>,
    <-0.4560594, 0.7555872, 0.4702104>,
    <-0.3358183, 0.7819698, 0.5251183>,
    <-0.4991853, 0.8103504, 0.3068327>,
    <-0.5946124, 0.7830137, 0.1825530>,
    <-0.7420499, 0.6310682, 0.2260862>,
    <-0.6025938, 0.7029474, 0.3778169>,
    <-0.7193185, 0.6908033, 0.0732922>,
    <-0.8356669, 0.5443308, 0.0732453>,
    <0.7504039, 0.6538251, 0.0969882>,
    <0.6823256, 0.6921842, 0.2351867>,
    <0.7802504, 0.5665136, 0.2650880>,
    <0.8468597, 0.5218302, 0.1025766>,
    <0.5753506, 0.7260449, 0.3766038>,
    <0.4656398, 0.7420034, 0.4822971>,
    <0.5415039, 0.6230301, 0.5644528>,
    <0.6668096, 0.6037567, 0.4368555>,
    <0.3511082, 0.7511641, 0.5589950>,
    <0.2363336, 0.7512686, 0.6162320>,
    <0.2758685, 0.6316363, 0.7245221>,
    <0.4110043, 0.6311773, 0.6577923>,
    <0.1184762, 0.7487069, 0.6522280>,
    <0.0000000, 0.7392142, 0.6734704>,
    <0.0000000, 0.6157644, 0.7879303>,
    <0.1389008, 0.6261733, 0.7672115>,
    <-0.1235986, 0.7275815, 0.6747952>,
    <-0.2530101, 0.7076449, 0.6597155>,
    <-0.2901200, 0.5790171, 0.7619512>,
    <-0.1424679, 0.6003907, 0.7869142>,
    <-0.3898046, 0.6823862, 0.6183862>,
    <-0.5314429, 0.6438701, 0.5504542>,
    <-0.5954373, 0.5101183, 0.6206720>,
    <-0.4426495, 0.5497051, 0.7084389>,
    <-0.6794333, 0.5900842, 0.4360861>,
    <-0.8246510, 0.5037823, 0.2572044>,
    <-0.8835626, 0.3742697, 0.2814947>,
    <-0.7472908, 0.4544090, 0.4848391>,
    <-0.9015250, 0.4247496, 0.0827072>,
    <-0.9485213, 0.3028760, 0.0925930>,
    <0.9112722, 0.3981322, 0.1052322>,
    <0.8505757, 0.4409374, 0.2865228>,
    <0.8944129, 0.3317645, 0.2999298>,
    <0.9497731, 0.2947809, 0.1050489>,
    <0.7341283, 0.4768258, 0.4834179>,
    <0.5991091, 0.4944453, 0.6297556>,
    <0.6353858, 0.3748754, 0.6750951>,
    <0.7768365, 0.3618138, 0.5153794>,
    <0.4556583, 0.5007073, 0.7359808>,
    <0.3057210, 0.4993153, 0.8106904>,
    <0.3237225, 0.3737825, 0.8691895>,
    <0.4832605, 0.3776019, 0.7898583>,
    <0.1535910, 0.4923169, 0.8567578>,
    <0.0000000, 0.4809278, 0.8767602>,
    <0.0000000, 0.3545746, 0.9350277>,
    <0.1622143, 0.3656583, 0.9165045>,
    <-0.1561883, 0.4653333, 0.8712463>,
    <-0.3160411, 0.4447239, 0.8380565>,
    <-0.3302106, 0.3238579, 0.8866098>,
    <-0.1638471, 0.3408496, 0.9257298>,
    <-0.4783288, 0.4174848, 0.7725983>,
    <-0.6370584, 0.3817469, 0.6696461>,
    <-0.6590862, 0.2742588, 0.7002767>,
    <-0.4974927, 0.3022200, 0.8131200>,
    <-0.7890029, 0.3329133, 0.5163751>,
    <-0.9173920, 0.2652392, 0.2967155>,
    <-0.9343501, 0.1833590, 0.3055640>,
    <-0.8106545, 0.2361396, 0.5357960>,
    <-0.9736476, 0.2059696, 0.0979130>,
    <-0.9855819, 0.1365465, 0.0999166>,
    <0.9683709, 0.2275674, 0.1023270>,
    <0.9163590, 0.2574472, 0.3066059>,
    <0.9229760, 0.2300196, 0.3085553>,
    <0.9735987, 0.2064144, 0.0974615>,
    <0.7976163, 0.2796216, 0.5344342>,
    <0.6518803, 0.2866352, 0.7020629>,
    <0.6536402, 0.2453020, 0.7159480>,
    <0.8023779, 0.2444952, 0.5444372>,
    <0.4947917, 0.2850016, 0.8209478>,
    <0.3305596, 0.2785645, 0.9017384>,
    <0.3290956, 0.2301748, 0.9158142>,
    <0.4943041, 0.2392022, 0.8357307>,
    <0.1651927, 0.2696989, 0.9486695>,
    <0.0000000, 0.2597790, 0.9656681>,
    <0.0000000, 0.2122084, 0.9772244>,
    <0.1640209, 0.2207225, 0.9614462>,
    <-0.1661390, 0.2491649, 0.9541041>,
    <-0.3343500, 0.2373253, 0.9120783>,
    <-0.3314416, 0.1985713, 0.9223426>,
    <-0.1645973, 0.2049887, 0.9648250>,
    <-0.5032044, 0.2229741, 0.8349059>,
    <-0.6660717, 0.2043578, 0.7173467>,
    <-0.6629423, 0.1822984, 0.7261369>,
    <-0.4996441, 0.1916709, 0.8447592>,
    <-0.8180286, 0.1779268, 0.5469655>,
    <-0.9403778, 0.1394036, 0.3102518>,
    <-0.9395630, 0.1404322, 0.3122502>,
    <-0.8161195, 0.1668271, 0.5532791>,
    <-0.9896602, 0.1033631, 0.0994425>,
    <-0.9889076, 0.1126310, 0.0968302>,
    <0.9716600, 0.2181856, 0.0909503>,
    <0.9213160, 0.2373481, 0.3079654>,
    <0.9127332, 0.2716883, 0.3051288>,
    <0.9632988, 0.2553463, 0.0827873>,
    <0.7983661, 0.2451631, 0.5500060>,
    <0.6472937, 0.2399131, 0.7235002>,
    <0.6352482, 0.2609771, 0.7268774>,
    <0.7876667, 0.2731134, 0.5522592>,
    <0.4872352, 0.2291598, 0.8426670>,
    <0.3231326, 0.2172168, 0.9210875>,
    <0.3143441, 0.2284079, 0.9214215>,
    <0.4758307, 0.2444132, 0.8448949>,
    <0.1606240, 0.2067920, 0.9651098>,
    <0.0000000, 0.1992640, 0.9799458>,
    <0.0000000, 0.2088182, 0.9779545>,
    <0.1558664, 0.2160524, 0.9638605>,
    <-0.1610215, 0.1949849, 0.9674983>,
    <-0.3247816, 0.1934781, 0.9257879>,
    <-0.3156554, 0.2103470, 0.9252653>,
    <-0.1561767, 0.2070750, 0.9657789>,
    <-0.4911043, 0.1934080, 0.8493585>,
    <-0.6543025, 0.1924540, 0.7313342>,
    <-0.6412097, 0.2248025, 0.7336988>,
    <-0.4790000, 0.2171882, 0.8505224>,
    <-0.8090262, 0.1866131, 0.5573618>,
    <-0.9346129, 0.1699115, 0.3124560>,
    <-0.9246911, 0.2202592, 0.3105355>,
    <-0.7969725, 0.2284474, 0.5591482>,
    <-0.9847216, 0.1477080, 0.0922265>,
    <-0.9757220, 0.2016313, 0.0855072>,
    <0.9514791, 0.2988603, 0.0732806>,
    <0.9008873, 0.3126129, 0.3011233>,
    <0.8964526, 0.3267171, 0.2993804>,
    <0.9467487, 0.3156712, 0.0633919>,
    <0.7740407, 0.3075541, 0.5534180>,
    <0.6207273, 0.2883544, 0.7290743>,
    <0.6098577, 0.2927707, 0.7364502>,
    <0.7661829, 0.3166129, 0.5592137>,
    <0.4625235, 0.2658936, 0.8457970>,
    <0.3043028, 0.2458103, 0.9203136>,
    <0.2953287, 0.2452300, 0.9233868>,
    <0.4512840, 0.2670696, 0.8514791>,
    <0.1504975, 0.2315120, 0.9611205>,
    <0.0000000, 0.2245089, 0.9744720>,
    <0.0000000, 0.2242365, 0.9745348>,
    <0.1455763, 0.2305167, 0.9621173>,
    <-0.1507275, 0.2251715, 0.9625897>,
    <-0.3052907, 0.2330492, 0.9233015>,
    <-0.2959140, 0.2375044, 0.9252170>,
    <-0.1457108, 0.2266863, 0.9630066>,
    <-0.4649716, 0.2466496, 0.8502737>,
    <-0.6254801, 0.2627821, 0.7346566>,
    <-0.6128134, 0.2771841, 0.7400194>,
    <-0.4527652, 0.2553819, 0.8542738>,
    <-0.7815919, 0.2759814, 0.5594179>,
    <-0.9107922, 0.2763161, 0.3067685>,
    <-0.9025754, 0.3045246, 0.3043394>,
    <-0.7708596, 0.2972971, 0.5633737>,
    <-0.9622648, 0.2610370, 0.0768517>,
    <-0.9538377, 0.2926873, 0.0672884>,
    <0.9515513, 0.3028200, 0.0533875>,
    <0.9014185, 0.3117226, 0.3004558>,
    <0.9128663, 0.2732855, 0.3032988>,
    <0.9629611, 0.2661113, 0.0434815>,
    <0.7652960, 0.2987305, 0.5701598>,
    <0.6033897, 0.2731269, 0.7492146>,
    <0.6001883, 0.2342465, 0.7647893>,
    <0.7692339, 0.2592411, 0.5840148>,
    <0.4426827, 0.2470172, 0.8619829>,
    <0.2878569, 0.2256800, 0.9307024>,
    <0.2818718, 0.1905467, 0.9403405>,
    <0.4363353, 0.2098507, 0.8749709>,
    <0.1413497, 0.2118637, 0.9670233>,
    <0.0000000, 0.2065129, 0.9784439>,
    <0.0000000, 0.1740294, 0.9847405>,
    <0.1378802, 0.1784160, 0.9742468>,
    <-0.1414138, 0.2098101, 0.9674616>,
    <-0.2881389, 0.2215210, 0.9316139>,
    <-0.2819793, 0.1886073, 0.9406992>,
    <-0.1379043, 0.1774632, 0.9744174>,
    <-0.4434103, 0.2406828, 0.8633997>,
    <-0.6048815, 0.2646072, 0.7510668>,
    <-0.6007858, 0.2301926, 0.7655507>,
    <-0.4366186, 0.2068714, 0.8755389>,
    <-0.7675271, 0.2880614, 0.5726454>,
    <-0.9041893, 0.2994208, 0.3046127>,
    <-0.9134599, 0.2672778, 0.3068447>,
    <-0.7699181, 0.2540773, 0.5853810>,
    <-0.9552451, 0.2901950, 0.0573902>,
    <-0.9644371, 0.2600135, 0.0474765>,
    <0.9719422, 0.2327872, 0.0337403>,
    <0.9219787, 0.2385307, 0.3050549>,
    <0.9261569, 0.2211364, 0.3055031>,
    <0.9758964, 0.2167841, 0.0251155>,
    <0.7715322, 0.2239963, 0.5954525>,
    <0.5963360, 0.2000388, 0.7774110>,
    <0.5911637, 0.1813514, 0.7858989>,
    <0.7706086, 0.2054172, 0.6032961>,
    <0.4300951, 0.1774951, 0.8851631>,
    <0.2762949, 0.1601268, 0.9476394>,
    <0.2710592, 0.1429756, 0.9518849>,
    <0.4237365, 0.1594521, 0.8916403>,
    <0.1347217, 0.1494697, 0.9795452>,
    <0.0000000, 0.1458221, 0.9893108>,
    <0.0000000, 0.1298744, 0.9915305>,
    <0.1318539, 0.1330799, 0.9822954>,
    <-0.1347276, 0.1491908, 0.9795869>,
    <-0.2763215, 0.1595556, 0.9477280>,
    <-0.2710454, 0.1434616, 0.9518157>,
    <-0.1318509, 0.1333193, 0.9822634>,
    <-0.4301665, 0.1766082, 0.8853058>,
    <-0.5964905, 0.1988139, 0.7776066>,
    <-0.5910733, 0.1823566, 0.7857343>,
    <-0.4236972, 0.1601956, 0.8915257>,
    <-0.7714300, 0.2223791, 0.5961906>,
    <-0.9214454, 0.2366020, 0.3081524>,
    <-0.9249646, 0.2224755, 0.3081316>,
    <-0.7700607, 0.2066303, 0.6035814>,
    <-0.9722604, 0.2308608, 0.0375908>,
    <-0.9754943, 0.2181510, 0.0286543>,
    <-0.9497987, 0.1875585, -0.2504080>,
    <-0.9719689, 0.1979871, -0.1267977>,
    <-0.8783265, 0.1747478, -0.4449785>,
    <-0.8764225, 0.1605689, -0.4539838>,
    <-0.9502040, 0.1719281, -0.2599096>,
    <-0.9741665, 0.1808570, -0.1352418>,
    <-0.7488461, 0.1597020, -0.6432145>,
    <-0.6071056, 0.1465591, -0.7809887>,
    <-0.6037259, 0.1345886, -0.7857487>,
    <-0.7455227, 0.1468137, -0.6501089>,
    <-0.4605396, 0.1364360, -0.8770909>,
    <-0.3080741, 0.1291756, -0.9425519>,
    <-0.3061960, 0.1180019, -0.9446267>,
    <-0.4577842, 0.1250090, -0.8802308>,
    <-0.1540573, 0.1247560, -0.9801542>,
    <-0.0000000, 0.1230829, -0.9923964>,
    <-0.0000000, 0.1118037, -0.9937303>,
    <-0.1531211, 0.1136156, -0.9816544>,
    <0.1540756, 0.1241069, -0.9802337>,
    <0.3081487, 0.1278664, -0.9427060>,
    <0.3063222, 0.1158145, -0.9448564>,
    <0.1531522, 0.1125310, -0.9817745>,
    <0.4607113, 0.1344512, -0.8773072>,
    <0.6074164, 0.1438920, -0.7812429>,
    <0.6042408, 0.1301316, -0.7861036>,
    <0.4580723, 0.1216930, -0.8805456>,
    <0.7496811, 0.1563602, -0.6430628>,
    <0.8801090, 0.1708278, -0.4429741>,
    <0.8785392, 0.1539021, -0.4521980>,
    <0.7466370, 0.1412030, -0.6500730>,
    <0.9514195, 0.1833299, -0.2473684>,
    <0.9728780, 0.1935456, -0.1266830>,
    <0.9755987, 0.1732068, -0.1349315>,
    <0.9522666, 0.1646499, -0.2570578>,
    <-0.9516248, 0.1505210, -0.2678689>,
    <-0.9772140, 0.1576563, -0.1421174>,
    <-0.8756562, 0.1410288, -0.4618843>,
    <-0.8758245, 0.1146339, -0.4688182>,
    <-0.9537814, 0.1223483, -0.2744667>,
    <-0.9807479, 0.1278259, -0.1476285>,
    <-0.7432046, 0.1290091, -0.6565086>,
    <-0.6010756, 0.1180556, -0.7904246>,
    <-0.5990706, 0.0948493, -0.7950585>,
    <-0.7417535, 0.1044098, -0.6624956>,
    <-0.4554835, 0.1092828, -0.8835112>,
    <-0.3045605, 0.1027240, -0.9469375>,
    <-0.3031475, 0.0810510, -0.9494906>,
    <-0.4535928, 0.0870231, -0.8869501>,
    <-0.1522848, 0.0985058, -0.9834154>,
    <-0.0000000, 0.0966354, -0.9953199>,
    <-0.0000000, 0.0752473, -0.9971649>,
    <-0.1515415, 0.0771109, -0.9854385>,
    <0.1523274, 0.0970940, -0.9835492>,
    <0.3047313, 0.0998757, -0.9471872>,
    <0.3033529, 0.0777061, -0.9497046>,
    <0.1515930, 0.0754535, -0.9855589>,
    <0.4558684, 0.1049616, -0.8838365>,
    <0.6017515, 0.1122399, -0.7907574>,
    <0.5998566, 0.0880076, -0.7952526>,
    <0.4540494, 0.0819452, -0.8872002>,
    <0.7445130, 0.1216599, -0.6564292>,
    <0.8779495, 0.1322242, -0.4601319>,
    <0.8781349, 0.1041952, -0.4669287>,
    <0.7431635, 0.0957411, -0.6622248>,
    <0.9539006, 0.1408257, -0.2650316>,
    <0.9789040, 0.1474329, -0.1414586>,
    <0.9824310, 0.1156270, -0.1464912>,
    <0.9560434, 0.1107986, -0.2714861>,
    <-0.9550764, 0.0985148, -0.2795067>,
    <-0.9830881, 0.1025161, -0.1517509>,
    <-0.8755140, 0.0924021, -0.4742753>,
    <-0.8741639, 0.0854429, -0.4780555>,
    <-0.9548833, 0.0902944, -0.2829218>,
    <-0.9835986, 0.0931031, -0.1544847>,
    <-0.7400762, 0.0837985, -0.6672818>,
    <-0.5969267, 0.0754939, -0.7987360>,
    <-0.5943552, 0.0704827, -0.8011080>,
    <-0.7377495, 0.0779716, -0.6705566>,
    <-0.4515869, 0.0685302, -0.8895914>,
    <-0.3016426, 0.0631055, -0.9513303>,
    <-0.2999480, 0.0589493, -0.9521324>,
    <-0.4492864, 0.0640520, -0.8910887>,
    <-0.1507459, 0.0594414, -0.9867839>,
    <-0.0000000, 0.0576139, -0.9983389>,
    <-0.0000000, 0.0536474, -0.9985599>,
    <-0.1498565, 0.0554450, -0.9871519>,
    <0.1508062, 0.0576264, -0.9868823>,
    <0.3018815, 0.0594413, -0.9514906>,
    <0.3002323, 0.0551628, -0.9522697>,
    <0.1499286, 0.0535702, -0.9872445>,
    <0.4521114, 0.0629638, -0.8897364>,
    <0.5978130, 0.0679861, -0.7987475>,
    <0.5953902, 0.0627105, -0.8009856>,
    <0.4499062, 0.0582958, -0.8911712>,
    <0.7415657, 0.0742658, -0.6667570>,
    <0.8777924, 0.0808805, -0.4721640>,
    <0.8765135, 0.0734557, -0.4757399>,
    <0.7393943, 0.0680849, -0.6698212>,
    <0.9572419, 0.0857239, -0.2762956>,
    <0.9846640, 0.0889882, -0.1500597>,
    <0.9851870, 0.0789600, -0.1522231>,
    <0.9570660, 0.0769442, -0.2794713>,
    <-0.9550340, 0.0807777, -0.2852805>,
    <-0.9842876, 0.0823977, -0.1561683>,
    <-0.8733114, 0.0772195, -0.4810035>,
    <-0.8738020, 0.0514578, -0.4835515>,
    <-0.9564916, 0.0532793, -0.2868537>,
    <-0.9861619, 0.0534120, -0.1569453>,
    <-0.7359225, 0.0709736, -0.6733356>,
    <-0.5921790, 0.0644132, -0.8032279>,
    <-0.5908702, 0.0421976, -0.8056623>,
    <-0.7352459, 0.0471503, -0.6761586>,
    <-0.4472556, 0.0586268, -0.8924827>,
    <-0.2984128, 0.0539470, -0.9529111>,
    <-0.2972367, 0.0337723, -0.9542064>,
    <-0.4458186, 0.0376069, -0.8943330>,
    <-0.1490392, 0.0506840, -0.9875315>,
    <-0.0000000, 0.0489734, -0.9988001>,
    <-0.0000000, 0.0295219, -0.9995641>,
    <-0.1483881, 0.0310252, -0.9884424>,
    <0.1491221, 0.0488385, -0.9876120>,
    <0.2987386, 0.0502181, -0.9530128>,
    <0.2975844, 0.0302714, -0.9542155>,
    <0.1484770, 0.0292938, -0.9884819>,
    <0.4479613, 0.0529533, -0.8924834>,
    <0.5933453, 0.0567433, -0.8029455>,
    <0.5920850, 0.0349777, -0.8051161>,
    <0.4465650, 0.0322745, -0.8941689>,
    <0.7376952, 0.0611983, -0.6723545>,
    <0.8756898, 0.0653330, -0.4784339>,
    <0.8760146, 0.0402183, -0.4806048>,
    <0.7370139, 0.0379294, -0.6748124>,
    <0.9571717, 0.0675034, -0.2815415>,
    <0.9858136, 0.0683138, -0.1533129>,
    <0.9873425, 0.0400610, -0.1534600>,
    <0.9583347, 0.0407065, -0.2827325>,
    <-0.9577396, 0.0167227, -0.2871500>,
    <-0.9875594, 0.0151834, -0.1565117>,
    <-0.8743729, 0.0169297, -0.4849593>,
    <-0.8744524, -0.0174523, -0.4847972>,
    <-0.9580680, -0.0197843, -0.2858570>,
    <-0.9877004, -0.0230364, -0.1546522>,
    <-0.7347926, 0.0150242, -0.6781255>,
    <-0.5897788, 0.0121190, -0.8074739>,
    <-0.5886521, -0.0174796, -0.8081975>,
    <-0.7341718, -0.0167910, -0.6787561>,
    <-0.4445407, 0.0090818, -0.8957126>,
    <-0.2961574, 0.0063678, -0.9551179>,
    <-0.2950892, -0.0202904, -0.9552542>,
    <-0.4432669, -0.0188165, -0.8961922>,
    <-0.1477810, 0.0043213, -0.9890107>,
    <-0.0000000, 0.0031166, -0.9999951>,
    <-0.0000000, -0.0223932, -0.9997492>,
    <-0.1471808, -0.0215470, -0.9888749>,
    <0.1478740, 0.0027939, -0.9890023>,
    <0.2965196, 0.0032771, -0.9550212>,
    <0.2954695, -0.0227849, -0.9550804>,
    <0.1472788, -0.0227787, -0.9888327>,
    <0.4453109, 0.0043682, -0.8953653>,
    <0.5910123, 0.0057266, -0.8066422>,
    <0.5899250, -0.0226549, -0.8071402>,
    <0.4440708, -0.0226261, -0.8957060>,
    <0.7365124, 0.0068442, -0.6763895>,
    <0.8763620, 0.0069420, -0.4816031>,
    <0.8762981, -0.0255604, -0.4810908>,
    <0.7358860, -0.0234252, -0.6767001>,
    <0.9592149, 0.0055432, -0.2826235>,
    <0.9883109, 0.0033077, -0.1524156>,
    <0.9881424, -0.0326765, -0.1500229>,
    <0.9592817, -0.0288585, -0.2809731>,
    <-0.9575223, -0.0561399, -0.2828416>,
    <-0.9866054, -0.0611254, -0.1512395>,
    <-0.8741275, -0.0516151, -0.4829461>,
    <-0.8735062, -0.0854926, -0.4792472>,
    <-0.9561621, -0.0922441, -0.2779299>,
    <-0.9843061, -0.0989612, -0.1461101>,
    <-0.7334966, -0.0482463, -0.6779787>,
    <-0.5876001, -0.0465605, -0.8078108>,
    <-0.5867554, -0.0750975, -0.8062744>,
    <-0.7329055, -0.0793040, -0.6756926>,
    <-0.4420881, -0.0460560, -0.8957885>,
    <-0.2940958, -0.0461745, -0.9546599>,
    <-0.2932514, -0.0712662, -0.9533754>,
    <-0.4411119, -0.0726154, -0.8945095>,
    <-0.1466202, -0.0465549, -0.9880967>,
    <-0.0000000, -0.0469847, -0.9988956>,
    <-0.0000000, -0.0706434, -0.9975016>,
    <-0.1461368, -0.0706862, -0.9867358>,
    <0.1467244, -0.0474021, -0.9880410>,
    <0.2944999, -0.0478926, -0.9544507>,
    <0.2936862, -0.0720331, -0.9531840>,
    <0.1462487, -0.0710631, -0.9866921>,
    <0.4429405, -0.0486847, -0.8952282>,
    <0.5889441, -0.0501396, -0.8066169>,
    <0.5882113, -0.0767127, -0.8050606>,
    <0.4420316, -0.0737948, -0.8939588>,
    <0.7352713, -0.0528434, -0.6757098>,
    <0.8759541, -0.0572343, -0.4789870>,
    <0.8754791, -0.0880377, -0.4751692>,
    <0.7348270, -0.0813886, -0.6733537>,
    <0.9586432, -0.0624206, -0.2776814>,
    <0.9869302, -0.0677982, -0.1461922>,
    <0.9847724, -0.1019768, -0.1407976>,
    <0.9574166, -0.0950773, -0.2726055>,
    <-0.9526549, -0.1388479, -0.2704994>,
    <-0.9792024, -0.1479540, -0.1388248>,
    <-0.8716073, -0.1291405, -0.4728883>,
    <-0.8605537, -0.2201310, -0.4593361>,
    <-0.9370565, -0.2357858, -0.2575464>,
    <-0.9598334, -0.2498571, -0.1276376>,
    <-0.7317700, -0.1193027, -0.6710287>,
    <-0.5857180, -0.1118715, -0.8027572>,
    <-0.5807139, -0.1894374, -0.7917606>,
    <-0.7245579, -0.2031302, -0.6586000>,
    <-0.4400832, -0.1068962, -0.8915716>,
    <-0.2924038, -0.1037236, -0.9506532>,
    <-0.2900309, -0.1730913, -0.9412340>,
    <-0.4364963, -0.1796927, -0.8815790>,
    <-0.1456591, -0.1019640, -0.9840664>,
    <-0.0000000, -0.1013456, -0.9948513>,
    <-0.0000000, -0.1675004, -0.9858720>,
    <-0.1444704, -0.1691528, -0.9749439>,
    <0.1457807, -0.1017721, -0.9840683>,
    <0.2928781, -0.1033395, -0.9505490>,
    <0.2906087, -0.1707395, -0.9414853>,
    <0.1446168, -0.1679877, -0.9751236>,
    <0.4410942, -0.1063202, -0.8911408>,
    <0.5873393, -0.1111065, -0.8016782>,
    <0.5828079, -0.1846244, -0.7913588>,
    <0.4377553, -0.1761214, -0.8816754>,
    <0.7339524, -0.1183419, -0.6688116>,
    <0.8739457, -0.1279652, -0.4688750>,
    <0.8641793, -0.2127313, -0.4560038>,
    <0.7275558, -0.1970232, -0.6571487>,
    <0.9543451, -0.1375215, -0.2651664>,
    <0.9801568, -0.1465721, -0.1334513>,
    <0.9626755, -0.2412804, -0.1226360>,
    <0.9404043, -0.2275782, -0.2526813>,
    <-0.8953520, -0.3778680, -0.2357129>,
    <-0.9110157, -0.3971414, -0.1110363>,
    <-0.8281190, -0.3565740, -0.4325203>,
    <-0.8271602, -0.3711097, -0.4219995>,
    <-0.8938203, -0.3885956, -0.2237829>,
    <-0.9081368, -0.4067673, -0.0991361>,
    <-0.7016407, -0.3327368, -0.6300686>,
    <-0.5645069, -0.3129208, -0.7638145>,
    <-0.5616075, -0.3384982, -0.7549940>,
    <-0.6998380, -0.3528997, -0.6210383>,
    <-0.4251674, -0.2985533, -0.8544581>,
    <-0.2828034, -0.2886426, -0.9147173>,
    <-0.2799468, -0.3224870, -0.9042300>,
    <-0.4218216, -0.3288143, -0.8449542>,
    <-0.1409505, -0.2825356, -0.9488449>,
    <0.0000000, -0.2796868, -0.9600913>,
    <0.0000000, -0.3162311, -0.9486822>,
    <-0.1393305, -0.3185291, -0.9376173>,
    <0.1411746, -0.2798734, -0.9496002>,
    <0.2837039, -0.2832721, -0.9161163>,
    <0.2809850, -0.3159703, -0.9062065>,
    <0.1395880, -0.3153111, -0.9386661>,
    <0.4271938, -0.2904124, -0.8562512>,
    <0.5680526, -0.3019956, -0.7655814>,
    <0.5657542, -0.3250655, -0.7577959>,
    <0.4241714, -0.3188772, -0.8475824>,
    <0.7071096, -0.3189984, -0.6310595>,
    <0.8355745, -0.3401920, -0.4313753>,
    <0.8361734, -0.3507089, -0.4216838>,
    <0.7063252, -0.3358835, -0.6231267>,
    <0.9035473, -0.3600207, -0.2323518>,
    <0.9192651, -0.3787787, -0.1071373>,
    <0.9183881, -0.3839198, -0.0957542>,
    <0.9038780, -0.3663492, -0.2208910>,
    <0.9790240, 0.2029050, 0.0184828>,
    <0.9293989, 0.2056172, 0.3064950>,
    <0.9336465, 0.1819326, 0.3085527>,
    <0.9834256, 0.1807992, 0.0136291>,
    <0.7695094, 0.1887388, 0.6101089>,
    <0.5866561, 0.1646926, 0.7929130>,
    <0.5833119, 0.1428181, 0.7995938>,
    <0.7694219, 0.1652145, 0.6170042>,
    <0.4184163, 0.1435052, 0.8968467>,
    <0.2667631, 0.1279231, 0.9552346>,
    <0.2633520, 0.1099000, 0.9584194>,
    <0.4142360, 0.1236707, 0.9017284>,
    <0.1295236, 0.1187684, 0.9844377>,
    <0.0000000, 0.1159978, 0.9932495>,
    <0.0000000, 0.0998227, 0.9950052>,
    <0.1276707, 0.1020031, 0.9865574>,
    <-0.1295156, 0.1195380, 0.9843457>,
    <-0.2667248, 0.1294938, 0.9550336>,
    <-0.2633103, 0.1124905, 0.9581302>,
    <-0.1276624, 0.1032693, 0.9864268>,
    <-0.4183047, 0.1459305, 0.8965074>,
    <-0.5863899, 0.1680151, 0.7924126>,
    <-0.5829765, 0.1483546, 0.7988300>,
    <-0.4141055, 0.1276872, 0.9012284>,
    <-0.7686186, 0.1929174, 0.6099248>,
    <-0.9276522, 0.2103936, 0.3085385>,
    <-0.9315596, 0.1900777, 0.3099470>,
    <-0.7683656, 0.1722646, 0.6163921>,
    <-0.9779539, 0.2077053, 0.0215570>,
    <-0.9818517, 0.1889652, 0.0161048>,
    <0.9881598, 0.1530903, 0.0101805>,
    <0.9379969, 0.1527744, 0.3111620>,
    <0.9421015, 0.1174603, 0.3140825>,
    <0.9928202, 0.1193565, 0.0078848>,
    <0.7696819, 0.1370612, 0.6235416>,
    <0.5806580, 0.1172262, 0.8056639>,
    <0.5785151, 0.0861041, 0.8111143>,
    <0.7700598, 0.1030303, 0.6295972>,
    <0.4108461, 0.1007531, 0.9061205>,
    <0.2605871, 0.0891626, 0.9613243>,
    <0.2583464, 0.0631037, 0.9639891>,
    <0.4080888, 0.0724763, 0.9100608>,
    <0.1261727, 0.0826880, 0.9885561>,
    <0.0000000, 0.0811076, 0.9967053>,
    <0.0000000, 0.0569934, 0.9983746>,
    <0.1249632, 0.0580234, 0.9904633>,
    <-0.1261699, 0.0843312, 0.9884176>,
    <-0.2605675, 0.0925306, 0.9610113>,
    <-0.2583716, 0.0670301, 0.9637173>,
    <-0.1249710, 0.0599359, 0.9903484>,
    <-0.4107640, 0.1059931, 0.9055597>,
    <-0.5803955, 0.1244873, 0.8047633>,
    <-0.5784525, 0.0946371, 0.8102077>,
    <-0.4081145, 0.0786043, 0.9095405>,
    <-0.7687154, 0.1463883, 0.6226132>,
    <-0.9359181, 0.1636325, 0.3119002>,
    <-0.9403620, 0.1304037, 0.3141882>,
    <-0.7694172, 0.1140747, 0.6284777>,
    <-0.9863937, 0.1639667, 0.0119357>,
    <-0.9911682, 0.1323162, 0.0088306>,
    <0.9958263, 0.0910344, 0.0065390>,
    <0.9444392, 0.0878605, 0.3167257>,
    <0.9447099, 0.0761953, 0.3189318>,
    <0.9967866, 0.0798750, 0.0060445>,
    <0.7694410, 0.0747909, 0.6343239>,
    <0.5761394, 0.0605601, 0.8151048>,
    <0.5734511, 0.0518057, 0.8176002>,
    <0.7676802, 0.0642412, 0.6376051>,
    <0.4054731, 0.0494623, 0.9127678>,
    <0.2563278, 0.0420122, 0.9656765>,
    <0.2544852, 0.0361679, 0.9664001>,
    <0.4029380, 0.0423624, 0.9142463>,
    <0.1238972, 0.0381150, 0.9915628>,
    <0.0000000, 0.0375306, 0.9992955>,
    <0.0000000, 0.0327353, 0.9994641>,
    <0.1229488, 0.0330412, 0.9918628>,
    <-0.1239170, 0.0401960, 0.9914781>,
    <-0.2564043, 0.0462895, 0.9654606>,
    <-0.2546018, 0.0405928, 0.9661937>,
    <-0.1229780, 0.0351926, 0.9917852>,
    <-0.4056251, 0.0561527, 0.9123131>,
    <-0.5763202, 0.0699098, 0.8142283>,
    <-0.5738222, 0.0615098, 0.8166668>,
    <-0.4031890, 0.0492923, 0.9137882>,
    <-0.7692114, 0.0869612, 0.6330495>,
    <-0.9431746, 0.1022020, 0.3161904>,
    <-0.9438000, 0.0911834, 0.3176904>,
    <-0.7677751, 0.0769148, 0.6360861>,
    <-0.9944081, 0.1053983, 0.0066165>,
    <-0.9954736, 0.0948944, 0.0052237>,
    <0.9976538, 0.0681657, 0.0063584>,
    <0.9448096, 0.0641769, 0.3212725>,
    <0.9454734, 0.0337342, 0.3239476>,
    <0.9992344, 0.0384038, 0.0074662>,
    <0.7661006, 0.0536482, 0.6404777>,
    <0.5712165, 0.0432214, 0.8196607>,
    <0.5697202, 0.0185678, 0.8216289>,
    <0.7651977, 0.0255978, 0.6432863>,
    <0.4008969, 0.0355412, 0.9154335>,
    <0.2530268, 0.0306429, 0.9669739>,
    <0.2520330, 0.0108776, 0.9676575>,
    <0.3995053, 0.0137485, 0.9166278>,
    <0.1222050, 0.0282843, 0.9921018>,
    <0.0000000, 0.0282231, 0.9996016>,
    <0.0000000, 0.0099508, 0.9999505>,
    <0.1217005, 0.0096766, 0.9925197>,
    <-0.1222440, 0.0304083, 0.9920341>,
    <-0.2531853, 0.0350133, 0.9667840>,
    <-0.2522486, 0.0149815, 0.9675465>,
    <-0.1217527, 0.0116706, 0.9924919>,
    <-0.4012530, 0.0423916, 0.9149858>,
    <-0.5717948, 0.0528284, 0.8186940>,
    <-0.5705949, 0.0276054, 0.8207676>,
    <-0.4000066, 0.0201850, 0.9162900>,
    <-0.7665596, 0.0662275, 0.6387491>,
    <-0.9443273, 0.0790981, 0.3193578>,
    <-0.9457018, 0.0478609, 0.3214924>,
    <-0.7661958, 0.0374630, 0.6415143>,
    <-0.9965282, 0.0831264, 0.0046463>,
    <-0.9986044, 0.0525858, 0.0049018>,
    <0.9999561, -0.0000426, 0.0093665>,
    <0.9452083, -0.0053952, 0.3264233>,
    <0.9435143, -0.0432900, 0.3284917>,
    <0.9992193, -0.0376128, 0.0120882>,
    <0.7639835, -0.0104198, 0.6451517>,
    <0.5684034, -0.0132226, 0.8226438>,
    <0.5671862, -0.0431990, 0.8224559>,
    <0.7622156, -0.0448267, 0.6457693>,
    <0.3984565, -0.0145622, 0.9170716>,
    <0.2513433, -0.0150085, 0.9677816>,
    <0.2509653, -0.0389141, 0.9672136>,
    <0.3977385, -0.0409483, 0.9165846>,
    <0.1213657, -0.0148510, 0.9924968>,
    <0.0000000, -0.0142116, 0.9998990>,
    <0.0000000, -0.0364107, 0.9993369>,
    <0.1212074, -0.0373857, 0.9919229>,
    <-0.1214310, -0.0130916, 0.9925135>,
    <-0.2516164, -0.0113885, 0.9677600>,
    <-0.2512833, -0.0359928, 0.9672441>,
    <-0.1212832, -0.0359645, 0.9919662>,
    <-0.3991051, -0.0088861, 0.9168621>,
    <-0.5695808, -0.0052515, 0.8219186>,
    <-0.5685948, -0.0367861, 0.8217948>,
    <-0.3985008, -0.0363747, 0.9164464>,
    <-0.7655390, 0.0000618, 0.6433894>,
    <-0.9461982, 0.0071321, 0.3235089>,
    <-0.9450802, -0.0331759, 0.3251503>,
    <-0.7641939, -0.0363951, 0.6439590>,
    <-0.9999029, 0.0125658, 0.0060164>,
    <-0.9995924, -0.0273901, 0.0080533>,
    <0.9971208, -0.0741896, 0.0156867>,
    <0.9405425, -0.0798260, 0.3301631>,
    <0.9364495, -0.1149092, 0.3314487>,
    <0.9937617, -0.1096727, 0.0202399>,
    <0.7600922, -0.0775711, 0.6451687>,
    <0.5662542, -0.0713636, 0.8211355>,
    <0.5658131, -0.0977506, 0.8187187>,
    <0.7578206, -0.1086376, 0.6433551>,
    <0.3974983, -0.0654276, 0.9152674>,
    <0.2509980, -0.0608537, 0.9660729>,
    <0.2515617, -0.0808586, 0.9644577>,
    <0.3979078, -0.0880416, 0.9131911>,
    <0.1212750, -0.0579354, 0.9909268>,
    <0.0000000, -0.0566512, 0.9983940>,
    <-0.0000000, -0.0749485, 0.9971874>,
    <0.1216296, -0.0765199, 0.9896216>,
    <-0.1213574, -0.0569546, 0.9909735>,
    <-0.2513442, -0.0588422, 0.9661075>,
    <-0.2519161, -0.0799675, 0.9644395>,
    <-0.1217142, -0.0760821, 0.9896450>,
    <-0.3983298, -0.0622898, 0.9151248>,
    <-0.5677963, -0.0669822, 0.8204393>,
    <-0.5673671, -0.0958565, 0.8178668>,
    <-0.3987538, -0.0866675, 0.9129535>,
    <-0.7623024, -0.0718221, 0.6432237>,
    <-0.9424069, -0.0728949, 0.3264284>,
    <-0.9382530, -0.1118703, 0.3273626>,
    <-0.7600215, -0.1061645, 0.6411681>,
    <-0.9976825, -0.0671293, 0.0111051>,
    <-0.9941953, -0.1064989, 0.0152900>,
    <0.9874010, -0.1561198, 0.0258036>,
    <0.9295492, -0.1609766, 0.3317000>,
    <0.9086898, -0.2597298, 0.3268385>,
    <0.9664242, -0.2549408, 0.0320847>,
    <0.7543245, -0.1497108, 0.6392035>,
    <0.5653334, -0.1328179, 0.8140993>,
    <0.5606029, -0.2106960, 0.8008318>,
    <0.7420865, -0.2393462, 0.6261158>,
    <0.3987492, -0.1181287, 0.9094200>,
    <0.2525843, -0.1074265, 0.9615928>,
    <0.2530054, -0.1676662, 0.9528254>,
    <0.3978337, -0.1858085, 0.8984451>,
    <0.1222536, -0.1011344, 0.9873327>,
    <-0.0000000, -0.0991383, 0.9950737>,
    <-0.0000000, -0.1541072, 0.9880541>,
    <0.1227182, -0.1571277, 0.9799240>,
    <-0.1223346, -0.1013633, 0.9872992>,
    <-0.2529203, -0.1079077, 0.9614506>,
    <-0.2532299, -0.1705388, 0.9522558>,
    <-0.1227750, -0.1585257, 0.9796917>,
    <-0.3995376, -0.1189060, 0.9089726>,
    <-0.5667387, -0.1339378, 0.8129378>,
    <-0.5612958, -0.2169091, 0.7986849>,
    <-0.3983101, -0.1902902, 0.8972952>,
    <-0.7561998, -0.1511730, 0.6366386>,
    <-0.9308221, -0.1625849, 0.3273170>,
    <-0.9078038, -0.2688270, 0.3219073>,
    <-0.7425494, -0.2472886, 0.6224699>,
    <-0.9872857, -0.1575999, 0.0207163>,
    <-0.9641541, -0.2639487, 0.0271649>,
    <0.9169678, -0.3971226, 0.0382588>,
    <0.8605097, -0.4026686, 0.3120594>,
    <0.8560005, -0.4106286, 0.3140817>,
    <0.9142073, -0.4024849, 0.0472318>,
    <0.7107503, -0.3740775, 0.5957349>,
    <0.5447517, -0.3332114, 0.7695555>,
    <0.5443639, -0.3532177, 0.7608582>,
    <0.7079013, -0.3879717, 0.5902150>,
    <0.3910135, -0.2966174, 0.8712787>,
    <0.2505491, -0.2693892, 0.9298681>,
    <0.2518136, -0.2977078, 0.9208474>,
    <0.3920201, -0.3214891, 0.8619542>,
    <0.1220198, -0.2535348, 0.9595995>,
    <-0.0000000, -0.2493440, 0.9684150>,
    <-0.0000000, -0.2807396, 0.9597840>,
    <0.1228083, -0.2839808, 0.9509327>,
    <-0.1219918, -0.2568211, 0.9587288>,
    <-0.2503932, -0.2760532, 0.9279536>,
    <-0.2514414, -0.3059191, 0.9182542>,
    <-0.1227294, -0.2880429, 0.9497204>,
    <-0.3904751, -0.3067776, 0.8679958>,
    <-0.5432699, -0.3468433, 0.7645636>,
    <-0.5418658, -0.3698551, 0.7547110>,
    <-0.3909526, -0.3339492, 0.8576911>,
    <-0.7072065, -0.3908636, 0.5891389>,
    <-0.8537665, -0.4214965, 0.3056525>,
    <-0.8469796, -0.4337067, 0.3074475>,
    <-0.7026732, -0.4084195, 0.5826181>,
    <-0.9087153, -0.4160484, 0.0337682>,
    <-0.9037238, -0.4259266, 0.0432411>,
    <-0.9253376, -0.3086539, -0.2201890>,
    <-0.9421967, -0.3226699, -0.0902747>,
    <-0.8526129, -0.3013410, -0.4269015>,
    <-0.8733460, -0.2169506, -0.4361184>,
    <-0.9537281, -0.2068892, -0.2181731>,
    <-0.9732051, -0.2152631, -0.0808307>,
    <-0.7155834, -0.2984203, -0.6315740>,
    <-0.5693200, -0.2988480, -0.7658750>,
    <-0.5679529, -0.2679444, -0.7782257>,
    <-0.7237838, -0.2413372, -0.6464468>,
    <-0.4244155, -0.3016102, -0.8537580>,
    <-0.2800584, -0.3046406, -0.9103633>,
    <-0.2732913, -0.3108352, -0.9103259>,
    <-0.4181908, -0.2921318, -0.8601020>,
    <-0.1388895, -0.3064466, -0.9417007>,
    <0.0000000, -0.3061612, -0.9519797>,
    <0.0000000, -0.3250646, -0.9456918>,
    <-0.1347097, -0.3220907, -0.9370757>,
    <0.1391163, -0.3034614, -0.9426335>,
    <0.2809689, -0.2985442, -0.9121008>,
    <0.2740807, -0.3054218, -0.9119196>,
    <0.1349075, -0.3194766, -0.9379417>,
    <0.4264590, -0.2921875, -0.8560135>,
    <0.5728773, -0.2858838, -0.7681680>,
    <0.5709124, -0.2558638, -0.7801235>,
    <0.4199385, -0.2835815, -0.8621097>,
    <0.7210905, -0.2816522, -0.6330091>,
    <0.8601435, -0.2808222, -0.4257841>,
    <0.8790996, -0.1967546, -0.4341330>,
    <0.7282172, -0.2252503, -0.6472728>,
    <0.9334061, -0.2860222, -0.2166665>,
    <0.9501983, -0.2992830, -0.0869073>,
    <0.9783200, -0.1920278, -0.0775586>,
    <0.9592759, -0.1844271, -0.2139543>,
    <-0.9700404, -0.1058533, -0.2186702>,
    <-0.9915850, -0.1079917, -0.0713928>,
    <-0.8819282, -0.1361582, -0.4512910>,
    <-0.8763681, -0.1034788, -0.4703946>,
    <-0.9732626, -0.0617982, -0.2212261>,
    <-0.9962240, -0.0608184, -0.0619590>,
    <-0.7191128, -0.1918235, -0.6678926>,
    <-0.5542803, -0.2468275, -0.7948897>,
    <-0.5294071, -0.2439024, -0.8125514>,
    <-0.7002950, -0.1756172, -0.6919144>,
    <-0.4016288, -0.2927922, -0.8677367>,
    <-0.2592058, -0.3264785, -0.9089687>,
    <-0.2410898, -0.3379659, -0.9097553>,
    <-0.3777116, -0.2988124, -0.8763818>,
    <-0.1267725, -0.3463785, -0.9294895>,
    <0.0000000, -0.3523064, -0.9358847>,
    <0.0000000, -0.3677831, -0.9299116>,
    <-0.1171471, -0.3608013, -0.9252562>,
    <0.1269346, -0.3442365, -0.9302628>,
    <0.2598539, -0.3219717, -0.9103901>,
    <0.2415879, -0.3343695, -0.9109513>,
    <0.1172705, -0.3591087, -0.9258988>,
    <0.4030576, -0.2854971, -0.8695033>,
    <0.5566465, -0.2362131, -0.7964597>,
    <0.5312796, -0.2351021, -0.8139220>,
    <0.3788266, -0.2928952, -0.8778968>,
    <0.7225359, -0.1772442, -0.6682263>,
    <0.8860253, -0.1173945, -0.4485283>,
    <0.8797736, -0.0870513, -0.4673548>,
    <0.7030923, -0.1631969, -0.6921185>,
    <0.9731772, -0.0849418, -0.2138013>,
    <0.9939124, -0.0864438, -0.0683045>,
    <0.9973668, -0.0418788, -0.0592079>,
    <0.9754233, -0.0433761, -0.2160273>,
    <-0.9733721, -0.0313284, -0.2270801>,
    <-0.9981928, -0.0287632, -0.0527618>,
    <-0.8648543, -0.0809765, -0.4954491>,
    <-0.8476184, -0.0295534, -0.5297827>,
    <-0.9707256, 0.0327753, -0.2379444>,
    <-0.9983166, 0.0378355, -0.0439588>,
    <-0.6740659, -0.1638142, -0.7202778>,
    <-0.4989776, -0.2394367, -0.8328814>,
    <-0.4636719, -0.2171227, -0.8589913>,
    <-0.6410454, -0.1296525, -0.7564728>,
    <-0.3506817, -0.2984966, -0.8876498>,
    <-0.2216253, -0.3398055, -0.9140101>,
    <-0.2007481, -0.3285147, -0.9229184>,
    <-0.3208221, -0.2832212, -0.9038025>,
    <-0.1070929, -0.3637013, -0.9253391>,
    <0.0000000, -0.3711207, -0.9285847>,
    <0.0000000, -0.3626431, -0.9319281>,
    <-0.0964767, -0.3544778, -0.9300741>,
    <0.1071801, -0.3624112, -0.9258350>,
    <0.2219814, -0.3370462, -0.9149449>,
    <0.2009792, -0.3265133, -0.9235780>,
    <0.0965328, -0.3535482, -0.9304220>,
    <0.3514941, -0.2939018, -0.8888609>,
    <0.5003764, -0.2324779, -0.8340129>,
    <0.4646034, -0.2119227, -0.8597863>,
    <0.3213561, -0.2798489, -0.9046629>,
    <0.6763115, -0.1537263, -0.7203964>,
    <0.8678429, -0.0671875, -0.4922749>,
    <0.8500506, -0.0185379, -0.5263747>,
    <0.6426766, -0.1218941, -0.7563786>,
    <0.9750062, -0.0156995, -0.2216222>,
    <0.9986492, -0.0126988, -0.0503843>,
    <0.9978345, 0.0506710, -0.0419385>,
    <0.9716301, 0.0453182, -0.2321234>,
    <-0.9620632, 0.0949625, -0.2557664>,
    <-0.9941475, 0.1019185, -0.0358243>,
    <-0.8184756, 0.0200689, -0.5741907>,
    <-0.7762858, 0.0434691, -0.6288806>,
    <-0.9507615, 0.1253337, -0.2834504>,
    <-0.9908456, 0.1319336, -0.0286106>,
    <-0.5958052, -0.0947724, -0.7975176>,
    <-0.4203820, -0.1903073, -0.8871652>,
    <-0.3703692, -0.1678852, -0.9135870>,
    <-0.5383694, -0.0744630, -0.8394127>,
    <-0.2866203, -0.2604228, -0.9219701>,
    <-0.1778170, -0.3077440, -0.9347057>,
    <-0.1537552, -0.2804226, -0.9474822>,
    <-0.2493866, -0.2352115, -0.9394050>,
    <-0.0850787, -0.3347184, -0.9384696>,
    <0.0000000, -0.3432797, -0.9392332>,
    <0.0000000, -0.3144777, -0.9492649>,
    <-0.0733560, -0.3062236, -0.9491291>,
    <0.0851116, -0.3340834, -0.9386929>,
    <0.1779534, -0.3063718, -0.9351304>,
    <0.1538298, -0.2795103, -0.9477396>,
    <0.0733739, -0.3058013, -0.9492639>,
    <0.2869393, -0.2580930, -0.9225258>,
    <0.4209483, -0.1866657, -0.8876702>,
    <0.3706937, -0.1654449, -0.9139005>,
    <0.2495639, -0.2336609, -0.9397449>,
    <0.5969646, -0.0891773, -0.7972958>,
    <0.8206480, 0.0284224, -0.5707268>,
    <0.7785300, 0.0496228, -0.6256426>,
    <0.5392233, -0.0706101, -0.8391975>,
    <0.9626888, 0.1045318, -0.2496066>,
    <0.9931606, 0.1116473, -0.0341604>,
    <0.9898765, 0.1392845, -0.0272822>,
    <0.9516832, 0.1325588, -0.2769968>,
    <-0.9364503, 0.1348220, -0.3238578>,
    <-0.9900666, 0.1388237, -0.0222731>,
    <-0.7196480, 0.0509410, -0.6924679>,
    <-0.6458125, 0.0519450, -0.7617269>,
    <-0.9140974, 0.1342747, -0.3826177>,
    <-0.9911679, 0.1315477, -0.0167742>,
    <-0.4717681, -0.0607449, -0.8796277>,
    <-0.3168877, -0.1455389, -0.9372303>,
    <-0.2622563, -0.1206213, -0.9574300>,
    <-0.3987094, -0.0473784, -0.9158527>,
    <-0.2112387, -0.2062171, -0.9554333>,
    <-0.1296737, -0.2470790, -0.9602795>,
    <-0.1061802, -0.2088855, -0.9721587>,
    <-0.1734709, -0.1731970, -0.9694899>,
    <-0.0617612, -0.2705324, -0.9607277>,
    <0.0000000, -0.2780964, -0.9605532>,
    <0.0000000, -0.2362534, -0.9716915>,
    <-0.0505233, -0.2295378, -0.9719876>,
    <0.0617701, -0.2702654, -0.9608023>,
    <0.1297109, -0.2465038, -0.9604223>,
    <0.1061966, -0.2085616, -0.9722265>,
    <0.0505271, -0.2293869, -0.9720230>,
    <0.2113285, -0.2052419, -0.9556234>,
    <0.3170583, -0.1440009, -0.9374102>,
    <0.2623354, -0.1197577, -0.9575167>,
    <0.1735109, -0.1726496, -0.9695804>,
    <0.4723967, -0.0582572, -0.8794586>,
    <0.7220304, 0.0552532, -0.6896515>,
    <0.6482402, 0.0546736, -0.7594705>,
    <0.3991609, -0.0459488, -0.9157288>,
    <0.9379764, 0.1401298, -0.3171181>,
    <0.9893069, 0.1442937, -0.0212434>,
    <0.9906855, 0.1352261, -0.0160033>,
    <0.9165109, 0.1378227, -0.3755165>,
    <-0.8640779, 0.1378013, -0.4841283>,
    <-0.9891603, 0.1463171, -0.0123756>,
    <-0.5594660, 0.0536144, -0.8271174>,
    <-0.4751817, 0.0714097, -0.8769852>,
    <-0.7525117, 0.1457511, -0.6422482>,
    <0.9828493, -0.1844106, 0.0000000>,
    <-0.3219147, -0.0294530, -0.9463104>,
    <-0.2081551, -0.0915533, -0.9738015>,
    <-0.1555613, -0.0591806, -0.9860519>,
    <-0.2437030, -0.0065171, -0.9698280>,
    <-0.1369004, -0.1364934, -0.9811360>,
    <-0.0836358, -0.1672815, -0.9823553>,
    <-0.0621846, -0.1240575, -0.9903246>,
    <-0.1019065, -0.0975635, -0.9899982>,
    <-0.0397756, -0.1852418, -0.9818877>,
    <0.0000000, -0.1911239, -0.9815659>,
    <0.0000000, -0.1447310, -0.9894710>,
    <-0.0295671, -0.1396106, -0.9897650>,
    <0.0397771, -0.1851675, -0.9819016>,
    <0.0836421, -0.1671224, -0.9823819>,
    <0.0621866, -0.1239907, -0.9903328>,
    <0.0295676, -0.1395793, -0.9897694>,
    <0.1369159, -0.1362253, -0.9811711>,
    <0.2081869, -0.0911304, -0.9738344>,
    <0.1555722, -0.0590034, -0.9860608>,
    <0.1019116, -0.0974511, -0.9900087>,
    <0.3222285, -0.0287345, -0.9462257>,
    <0.5618589, 0.0551379, -0.8253935>,
    <0.4775564, 0.0723012, -0.8756211>,
    <0.2439110, -0.0062040, -0.9697778>,
    <0.8678575, 0.1396813, -0.4767730>,
    <0.9889290, 0.1479185, -0.0118098>,
    <0.9829497, 0.1838744, 0.0000000>,
    <0.7585710, 0.1470253, -0.6347862>,
    <-0.6175160, 0.1655783, -0.7689329>,
    <-0.7914867, 0.2094037, -0.5741941>,
    <0.9828493, -0.1844106, 0.0000000>,
    <-0.3248427, 0.0848240, -0.9419565>,
    <-0.1803033, 0.0901755, -0.9794688>,
    <-0.3781618, 0.1576947, -0.9122094>,
    <-0.5252500, 0.2254017, -0.8205526>,
    <-0.7914867, 0.2094037, -0.5741941>,
    <-0.1674125, 0.0195494, -0.9856931>,
    <-0.1062719, -0.0215943, -0.9941026>,
    <-0.0622727, 0.0174816, -0.9979061>,
    <-0.0967804, 0.0465228, -0.9942179>,
    <-0.0696417, -0.0510323, -0.9962659>,
    <-0.0425781, -0.0710047, -0.9965668>,
    <-0.0256116, -0.0156855, -0.9995489>,
    <-0.0413754, -0.0025690, -0.9991404>,
    <-0.0202815, -0.0825728, -0.9963786>,
    <0.0000000, -0.0863523, -0.9962647>,
    <0.0000000, -0.0254451, -0.9996762>,
    <-0.0123051, -0.0230698, -0.9996581>,
    <0.0202816, -0.0825628, -0.9963795>,
    <0.0425786, -0.0709834, -0.9965683>,
    <0.0256116, -0.0156807, -0.9995490>,
    <0.0123051, -0.0230676, -0.9996582>,
    <0.0696429, -0.0509964, -0.9962677>,
    <0.1062745, -0.0215370, -0.9941036>,
    <0.0622726, 0.0174947, -0.9979058>,
    <0.0413754, -0.0025609, -0.9991404>,
    <0.1675364, 0.0196597, -0.9856698>,
    <0.3263066, 0.0852458, -0.9414123>,
    <0.1809276, 0.0903329, -0.9793392>,
    <0.0968345, 0.0465528, -0.9942112>,
    <0.6242119, 0.1666944, -0.7632644>,
    <0.9829497, 0.1838744, 0.0000000>,
    <0.8006703, 0.2099773, -0.5611030>,
    <0.8006703, 0.2099773, -0.5611030>,
    <0.5330846, 0.2270468, -0.8150280>,
    <0.3821899, 0.1585279, -0.9103844>,
    <-0.1270720, 0.1283091, -0.9835596>,
    <-0.1636326, 0.1874678, -0.9685454>,
    <-0.5252500, 0.2254017, -0.8205526>,
    <-0.0659049, 0.0750371, -0.9950005>,
    <-0.2781777, -0.9605295, -0.0004455>,
    <-0.3186145, -0.9478842, -0.0005522>,
    <0.3462417, 0.9381453, 0.0000000>,
    <-0.1636326, 0.1874678, -0.9685454>,
    <-0.0385232, 0.0374100, -0.9985572>,
    <-0.0272368, 0.0112211, -0.9995660>,
    <-0.1998813, -0.9798201, -0.0002260>,
    <-0.2426937, -0.9701029, -0.0003358>,
    <-0.0196078, -0.0066809, -0.9997854>,
    <-0.0128925, -0.0181603, -0.9997520>,
    <-0.1049491, -0.9944776, -0.0000622>,
    <-0.1532293, -0.9881906, -0.0001325>,
    <-0.0064367, -0.0245169, -0.9996787>,
    <0.0000000, -0.0265410, -0.9996477>,
    <-0.0000000, -1.0000000, 0.0000000>,
    <-0.0541669, -0.9985319, -0.0000172>,
    <0.0064367, -0.0245164, -0.9996787>,
    <0.0128924, -0.0181593, -0.9997520>,
    <0.1049491, -0.9944776, -0.0000537>,
    <0.0541669, -0.9985319, -0.0000128>,
    <0.0196077, -0.0066793, -0.9997854>,
    <0.0272366, 0.0112235, -0.9995660>,
    <0.1998813, -0.9798201, -0.0002099>,
    <0.1532293, -0.9881906, -0.0001201>,
    <0.0385351, 0.0374164, -0.9985565>,
    <0.0660296, 0.0750806, -0.9949889>,
    <0.2784963, -0.9604372, -0.0004235>,
    <0.2427417, -0.9700909, -0.0003162>,
    <0.1277884, 0.1285688, -0.9834329>,
    <0.5330846, 0.2270468, -0.8150280>,
    <0.1649609, 0.1880878, -0.9681998>,
    <0.1649609, 0.1880878, -0.9681998>,
    <0.3478539, -0.9375487, 0.0000000>,
    <0.3196477, -0.9475363, -0.0005282>,
    <0.9465144, -0.3170907, 0.0596987>,
    <0.8833341, -0.3320805, 0.3308224>,
    <0.9040516, -0.2424118, 0.3520330>,
    <0.9745473, -0.2114199, 0.0745600>,
    <0.7253232, -0.3267495, 0.6059217>,
    <0.5544733, -0.3111073, 0.7718624>,
    <0.5544630, -0.2840173, 0.7822435>,
    <0.7332093, -0.2685578, 0.6247246>,
    <0.3977953, -0.2957539, 0.8684978>,
    <0.2549579, -0.2841291, 0.9242657>,
    <0.2516903, -0.3001472, 0.9200890>,
    <0.3947223, -0.2937694, 0.8705710>,
    <0.1242028, -0.2776917, 0.9526075>,
    <-0.0000000, -0.2767850, 0.9609319>,
    <-0.0000000, -0.3067220, 0.9517991>,
    <0.1222543, -0.3042942, 0.9447004>,
    <-0.1241291, -0.2814878, 0.9515023>,
    <-0.2546252, -0.2918408, 0.9219517>,
    <-0.2513591, -0.3069628, 0.9179283>,
    <-0.1221758, -0.3076214, 0.9436324>,
    <-0.3968920, -0.3075704, 0.8647989>,
    <-0.5524606, -0.3271460, 0.7666569>,
    <-0.5528560, -0.2987335, 0.7778872>,
    <-0.3939101, -0.3043697, 0.8672911>,
    <-0.7211747, -0.3469567, 0.5996067>,
    <-0.8761519, -0.3555496, 0.3254878>,
    <-0.8990286, -0.2654595, 0.3482511>,
    <-0.7301622, -0.2876987, 0.6197520>,
    <-0.9382960, -0.3411890, 0.0564869>,
    <-0.9691950, -0.2354220, 0.0723702>,
    <0.9898230, -0.1087940, 0.0917291>,
    <0.9113953, -0.1607101, 0.3788548>,
    <0.9026166, -0.1344867, 0.4088967>,
    <0.9915497, -0.0674691, 0.1108020>,
    <0.7270123, -0.2236735, 0.6491712>,
    <0.5413890, -0.2723224, 0.7954486>,
    <0.5162168, -0.2840174, 0.8079940>,
    <0.7050069, -0.2188970, 0.6745734>,
    <0.3809082, -0.3071537, 0.8721041>,
    <0.2408754, -0.3306909, 0.9124816>,
    <0.2253113, -0.3608670, 0.9049916>,
    <0.3590129, -0.3301214, 0.8730003>,
    <0.1164320, -0.3446038, 0.9314998>,
    <-0.0000000, -0.3500022, 0.9367489>,
    <-0.0000000, -0.3851217, 0.9228658>,
    <0.1084468, -0.3786700, 0.9191563>,
    <-0.1163549, -0.3473152, 0.9305018>,
    <-0.2405625, -0.3363103, 0.9105081>,
    <-0.2250397, -0.3653373, 0.9032640>,
    <-0.1083796, -0.3808089, 0.9182802>,
    <-0.3801955, -0.3160636, 0.8692268>,
    <-0.5401389, -0.2850182, 0.7918425>,
    <-0.5151786, -0.2944638, 0.8049112>,
    <-0.3584017, -0.3373101, 0.8704999>,
    <-0.7249137, -0.2407391, 0.6454029>,
    <-0.9083239, -0.1819715, 0.3766086>,
    <-0.9002034, -0.1530456, 0.4076897>,
    <-0.7032968, -0.2333194, 0.6715174>,
    <-0.9872077, -0.1311448, 0.0906753>,
    <-0.9900092, -0.0872044, 0.1108020>,
    <0.9902453, -0.0423500, 0.1327434>,
    <0.8873075, -0.1234870, 0.4443382>,
    <0.8678108, -0.0864294, 0.4893202>,
    <0.9871345, 0.0154606, 0.1591428>,
    <0.6749459, -0.2237236, 0.7031329>,
    <0.4849447, -0.2986182, 0.8219829>,
    <0.4491845, -0.2992956, 0.8418167>,
    <0.6391655, -0.2102396, 0.7397748>,
    <0.3333031, -0.3505570, 0.8752250>,
    <0.2076707, -0.3847198, 0.8993684>,
    <0.1882193, -0.3983464, 0.8977158>,
    <0.3045744, -0.3594541, 0.8820585>,
    <0.0995719, -0.4042410, 0.9092165>,
    <-0.0000000, -0.4110627, 0.9116071>,
    <-0.0000000, -0.4276557, 0.9039417>,
    <0.0898529, -0.4202478, 0.9029497>,
    <-0.0995194, -0.4058675, 0.9084974>,
    <-0.2074575, -0.3881415, 0.8979463>,
    <-0.1880751, -0.4008047, 0.8966512>,
    <-0.0898173, -0.4214078, 0.9024125>,
    <-0.3328211, -0.3561231, 0.8731589>,
    <-0.4841260, -0.3068468, 0.8194309>,
    <-0.4486465, -0.3053984, 0.8399096>,
    <-0.3042499, -0.3635046, 0.8805091>,
    <-0.6735235, -0.2353918, 0.7006831>,
    <-0.8851680, -0.1390963, 0.4439931>,
    <-0.8661293, -0.0989718, 0.4899231>,
    <-0.6381552, -0.2191692, 0.7380534>,
    <-0.9892409, -0.0592172, 0.1337751>,
    <-0.9869056, 0.0017345, 0.1612893>,
    <0.9790200, 0.0693476, 0.1916006>,
    <0.8370871, -0.0556923, 0.5442275>,
    <0.7920729, -0.0569369, 0.6077654>,
    <0.9685910, 0.0879763, 0.2325760>,
    <0.5917436, -0.2001893, 0.7808737>,
    <0.4058914, -0.2986974, 0.8637314>,
    <0.3561387, -0.3042637, 0.8835094>,
    <0.5318611, -0.2078231, 0.8209344>,
    <0.2715854, -0.3634666, 0.8911416>,
    <0.1665841, -0.4047534, 0.8991242>,
    <0.1438172, -0.4060249, 0.9024746>,
    <0.2357046, -0.3665163, 0.9000606>,
    <0.0792252, -0.4277756, 0.9004063>,
    <-0.0000000, -0.4354009, 0.9002367>,
    <-0.0000000, -0.4352413, 0.9003139>,
    <0.0682369, -0.4280246, 0.9011873>,
    <-0.0792041, -0.4285552, 0.9000373>,
    <-0.1664987, -0.4064143, 0.8983906>,
    <-0.1437709, -0.4071061, 0.9019948>,
    <-0.0682255, -0.4285313, 0.9009474>,
    <-0.2713938, -0.3662302, 0.8900679>,
    <-0.4055798, -0.3029285, 0.8624033>,
    <-0.3559655, -0.3070579, 0.8826121>,
    <-0.2355997, -0.3683232, 0.8993502>,
    <-0.5910280, -0.2065912, 0.7797474>,
    <-0.8355282, -0.0653072, 0.5455526>,
    <-0.7902487, -0.0641279, 0.6094215>,
    <-0.5312927, -0.2121905, 0.8201849>,
    <-0.9790832, 0.0586078, 0.1948363>,
    <-0.9682981, 0.0795050, 0.2368074>,
    <0.9550877, 0.0811444, 0.2849967>,
    <0.7311017, -0.0793921, 0.6776335>,
    <0.6519338, -0.1122363, 0.7499236>,
    <0.9334346, 0.0577440, 0.3540699>,
    <0.4631278, -0.2237386, 0.8575859>,
    <0.3034404, -0.3106354, 0.9007939>,
    <0.2502803, -0.3141810, 0.9157784>,
    <0.3889515, -0.2402123, 0.8893901>,
    <0.1991725, -0.3664105, 0.9088859>,
    <0.1211227, -0.4019678, 0.9076074>,
    <0.0991348, -0.3929254, 0.9142111>,
    <0.1633246, -0.3620547, 0.9177371>,
    <0.0573980, -0.4218596, 0.9048425>,
    <-0.0000000, -0.4283604, 0.9036080>,
    <-0.0000000, -0.4160294, 0.9093511>,
    <0.0469552, -0.4103415, 0.9107223>,
    <-0.0573925, -0.4221724, 0.9046970>,
    <-0.1211002, -0.4026349, 0.9073147>,
    <-0.0991259, -0.3932974, 0.9140521>,
    <-0.0469531, -0.4105163, 0.9106436>,
    <-0.1991210, -0.3675256, 0.9084469>,
    <-0.3033529, -0.3123686, 0.9002238>,
    <-0.2502450, -0.3151459, 0.9154564>,
    <-0.1633041, -0.3626751, 0.9174958>,
    <-0.4626684, -0.2265275, 0.8571017>,
    <-0.7289613, -0.0845363, 0.6793152>,
    <-0.6496335, -0.1155954, 0.7514080>,
    <-0.3885978, -0.2418050, 0.8891131>,
    <-0.9540854, 0.0744423, 0.2901368>,
    <-0.9314246, 0.0525941, 0.3601140>,
    <0.8842923, 0.0253825, 0.4662433>,
    <0.5607459, -0.1451393, 0.8151678>,
    <0.4748923, -0.1589138, 0.8655771>,
    <0.7704981, -0.0218159, 0.6370688>,
    <0.9829497, 0.1838744, 0.0000000>,
    <0.3125467, -0.2511506, 0.9160993>,
    <0.1983198, -0.3125258, 0.9289763>,
    <0.1482796, -0.3057042, 0.9405095>,
    <0.2360588, -0.2550494, 0.9376706>,
    <0.1289104, -0.3529974, 0.9267011>,
    <0.0781695, -0.3794814, 0.9218912>,
    <0.0582829, -0.3626021, 0.9301198>,
    <0.0961499, -0.3398951, 0.9355354>,
    <0.0370220, -0.3945678, 0.9181207>,
    <-0.0000000, -0.3994995, 0.9167334>,
    <-0.0000000, -0.3799303, 0.9250151>,
    <0.0276078, -0.3756554, 0.9263481>,
    <-0.0370213, -0.3946541, 0.9180836>,
    <-0.0781668, -0.3796646, 0.9218160>,
    <-0.0582824, -0.3626800, 0.9300895>,
    <-0.0276077, -0.3756922, 0.9263332>,
    <-0.1289044, -0.3533019, 0.9265859>,
    <-0.1983099, -0.3129986, 0.9288192>,
    <-0.1482784, -0.3059040, 0.9404447>,
    <-0.0961489, -0.3400242, 0.9354886>,
    <-0.3122875, -0.2519519, 0.9159677>,
    <-0.5584229, -0.1471265, 0.8164054>,
    <-0.4725445, -0.1601691, 0.8666300>,
    <-0.2358782, -0.2554008, 0.9376204>,
    <-0.8807734, 0.0216923, 0.4730408>,
    <0.9828493, -0.1844106, 0.0000000>,
    <-0.7643912, -0.0251078, 0.6442637>,
    <0.6352529, -0.0499799, 0.7706853>,
    <0.8188503, 0.0482952, 0.5719718>,
    <0.9829497, 0.1838744, 0.0000000>,
    <0.3256341, -0.1763125, 0.9289114>,
    <0.2004544, -0.1831831, 0.9624251>,
    <0.4119775, -0.1040042, 0.9052390>,
    <0.5747586, -0.0111390, 0.8182472>,
    <0.8188503, 0.0482952, 0.5719718>,
    <0.1647040, -0.2455287, 0.9552949>,
    <0.1037342, -0.2813159, 0.9539919>,
    <0.0738630, -0.2355451, 0.9690525>,
    <0.1118600, -0.2182977, 0.9694501>,
    <0.0676891, -0.3049254, 0.9499677>,
    <0.0412922, -0.3201886, 0.9464535>,
    <0.0312407, -0.2504213, 0.9676328>,
    <0.0498697, -0.2451812, 0.9681938>,
    <0.0196542, -0.3287604, 0.9442088>,
    <-0.0000000, -0.3315123, 0.9434509>,
    <-0.0000000, -0.2536323, 0.9673007>,
    <0.0151559, -0.2529332, 0.9673650>,
    <-0.0196543, -0.3287730, 0.9442044>,
    <-0.0412924, -0.3202152, 0.9464445>,
    <-0.0312410, -0.2504292, 0.9676307>,
    <-0.0151560, -0.2529370, 0.9673640>,
    <-0.0676896, -0.3049692, 0.9499536>,
    <-0.1037353, -0.2813834, 0.9539719>,
    <-0.0738645, -0.2355645, 0.9690477>,
    <-0.0498704, -0.2451939, 0.9681905>,
    <-0.1645905, -0.2456559, 0.9552817>,
    <-0.3241796, -0.1768811, 0.9293119>,
    <-0.1997699, -0.1833966, 0.9625267>,
    <-0.1118005, -0.2183384, 0.9694478>,
    <-0.6283728, -0.0527227, 0.7761236>,
    <0.9828493, -0.1844106, 0.0000000>,
    <-0.8096144, 0.0438493, 0.5853219>,
    <-0.8096144, 0.0438493, 0.5853219>,
    <-0.5664820, -0.0146373, 0.8239441>,
    <-0.4076652, -0.1054498, 0.9070223>,
    <0.2010754, -0.1510133, 0.9678655>,
    <0.2520463, -0.0929922, 0.9632368>,
    <0.5747586, -0.0111390, 0.8182472>,
    <0.1236019, -0.1973974, 0.9725003>,
    <0.3478539, -0.9375487, 0.0000000>,
    <0.2520463, -0.0929922, 0.9632368>,
    <0.0844737, -0.2201342, 0.9718051>,
    <0.0622844, -0.2304441, 0.9710902>,
    <0.0448335, -0.2350976, 0.9709372>,
    <0.0293542, -0.2368528, 0.9711020>,
    <0.0146795, -0.2373009, 0.9713253>,
    <-0.0000000, -0.2373064, 0.9714349>,
    <-0.0146795, -0.2373025, 0.9713249>,
    <-0.0293545, -0.2368559, 0.9711012>,
    <-0.0448341, -0.2351025, 0.9709360>,
    <-0.0622856, -0.2304512, 0.9710884>,
    <-0.0844486, -0.2201503, 0.9718036>,
    <-0.1233712, -0.1974852, 0.9725118>,
    <-0.1999614, -0.1514739, 0.9680243>,
    <-0.5664820, -0.0146373, 0.8239441>,
    <-0.2500445, -0.0940804, 0.9636527>,
    <-0.2500445, -0.0940804, 0.9636527>,
    <0.3462417, 0.9381453, 0.0000000>
  }
  uv_vectors {
    3910,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0416667, 0.0833333>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0511712, 0.0511712>,
    <0.0606733, 0.1250000>,
    <0.0000000, 0.0501834>,
    <0.1666667, 0.0833333>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1762031, 0.0512031>,
    <0.1870180, 0.1250000>,
    <0.1250000, 0.0511712>,
    <0.2916667, 0.0833333>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.3012724, 0.0512724>,
    <0.3136624, 0.1250000>,
    <0.2500000, 0.0512031>,
    <0.4166667, 0.0833333>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4259690, 0.0509690>,
    <0.4402492, 0.1250000>,
    <0.3750000, 0.0512724>,
    <0.5416667, 0.0833333>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5505055, 0.0505055>,
    <0.5663993, 0.1250000>,
    <0.5000000, 0.0509690>,
    <0.6666667, 0.0833333>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6751349, 0.0501349>,
    <0.6925959, 0.1250000>,
    <0.6250000, 0.0505055>,
    <0.7916667, 0.0833333>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7999859, 0.0499859>,
    <0.8187198, 0.1250000>,
    <0.7500000, 0.0501349>,
    <0.9166667, 0.0833333>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9245636, 0.0495636>,
    <0.9433350, 0.1250000>,
    <0.8750000, 0.0499859>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0606733, 0.1250000>,
    <0.1250000, 0.1903126>,
    <0.0606797, 0.2500000>,
    <0.0000000, 0.1892013>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1870180, 0.1250000>,
    <0.2500000, 0.1911067>,
    <0.1862935, 0.2500000>,
    <0.1250000, 0.1903126>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3136624, 0.1250000>,
    <0.3750000, 0.1913700>,
    <0.3120446, 0.2500000>,
    <0.2500000, 0.1911067>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4402492, 0.1250000>,
    <0.5000000, 0.1909922>,
    <0.4374688, 0.2500000>,
    <0.3750000, 0.1913700>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5663993, 0.1250000>,
    <0.6250000, 0.1901560>,
    <0.5625312, 0.2500000>,
    <0.5000000, 0.1909922>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6925959, 0.1250000>,
    <0.7500000, 0.1891990>,
    <0.6879554, 0.2500000>,
    <0.6250000, 0.1901560>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8187198, 0.1250000>,
    <0.8750000, 0.1883413>,
    <0.8138476, 0.2500000>,
    <0.7500000, 0.1891990>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9433350, 0.1250000>,
    <1.0000000, 0.1876481>,
    <0.9391729, 0.2500000>,
    <0.8750000, 0.1883413>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0606797, 0.2500000>,
    <0.1250000, 0.3146294>,
    <0.0607627, 0.3750000>,
    <0.0000000, 0.3141163>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1862935, 0.2500000>,
    <0.2500000, 0.3149376>,
    <0.1863427, 0.3750000>,
    <0.1250000, 0.3146294>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3120446, 0.2500000>,
    <0.3750000, 0.3150247>,
    <0.3120960, 0.3750000>,
    <0.2500000, 0.3149376>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4374688, 0.2500000>,
    <0.5000000, 0.3148805>,
    <0.4374845, 0.3750000>,
    <0.3750000, 0.3150247>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5625312, 0.2500000>,
    <0.6250000, 0.3145395>,
    <0.5625155, 0.3750000>,
    <0.5000000, 0.3148805>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6879554, 0.2500000>,
    <0.7500000, 0.3140827>,
    <0.6879040, 0.3750000>,
    <0.6250000, 0.3145395>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8138476, 0.2500000>,
    <0.8750000, 0.3136058>,
    <0.8137133, 0.3750000>,
    <0.7500000, 0.3140827>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9391729, 0.2500000>,
    <1.0000000, 0.3131787>,
    <0.9391784, 0.3750000>,
    <0.8750000, 0.3136058>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0607627, 0.3750000>,
    <0.1250000, 0.4391339>,
    <0.0608565, 0.5000000>,
    <0.0000000, 0.4390176>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1863427, 0.3750000>,
    <0.2500000, 0.4392008>,
    <0.1864564, 0.5000000>,
    <0.1250000, 0.4391339>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3120960, 0.3750000>,
    <0.3750000, 0.4392186>,
    <0.3121613, 0.5000000>,
    <0.2500000, 0.4392008>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4374845, 0.3750000>,
    <0.5000000, 0.4391883>,
    <0.4375027, 0.5000000>,
    <0.3750000, 0.4392186>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5625155, 0.3750000>,
    <0.6250000, 0.4391151>,
    <0.5624973, 0.5000000>,
    <0.5000000, 0.4391883>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6879040, 0.3750000>,
    <0.7500000, 0.4390105>,
    <0.6878387, 0.5000000>,
    <0.6250000, 0.4391151>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8137133, 0.3750000>,
    <0.8750000, 0.4388917>,
    <0.8135568, 0.5000000>,
    <0.7500000, 0.4390105>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9391784, 0.3750000>,
    <1.0000000, 0.4387783>,
    <0.9391294, 0.5000000>,
    <0.8750000, 0.4388917>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0608565, 0.5000000>,
    <0.1250000, 0.5617520>,
    <0.0609850, 0.6250000>,
    <0.0000000, 0.5617762>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1864564, 0.5000000>,
    <0.2500000, 0.5617169>,
    <0.1866246, 0.6250000>,
    <0.1250000, 0.5617520>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3121613, 0.5000000>,
    <0.3750000, 0.5616890>,
    <0.3122343, 0.6250000>,
    <0.2500000, 0.5617169>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4375027, 0.5000000>,
    <0.5000000, 0.5616758>,
    <0.4375208, 0.6250000>,
    <0.3750000, 0.5616890>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5624973, 0.5000000>,
    <0.6250000, 0.5616800>,
    <0.5624792, 0.6250000>,
    <0.5000000, 0.5616758>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6878387, 0.5000000>,
    <0.7500000, 0.5617002>,
    <0.6877657, 0.6250000>,
    <0.6250000, 0.5616800>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8135568, 0.5000000>,
    <0.8750000, 0.5617303>,
    <0.8133640, 0.6250000>,
    <0.7500000, 0.5617002>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9391294, 0.5000000>,
    <1.0000000, 0.5617545>,
    <0.9390273, 0.6250000>,
    <0.8750000, 0.5617303>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0609850, 0.6250000>,
    <0.1250000, 0.6881976>,
    <0.0611530, 0.7500000>,
    <0.0000000, 0.6882387>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1866246, 0.6250000>,
    <0.2500000, 0.6881374>,
    <0.1868229, 0.7500000>,
    <0.1250000, 0.6881976>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3122343, 0.6250000>,
    <0.3750000, 0.6880875>,
    <0.3122991, 0.7500000>,
    <0.2500000, 0.6881374>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4375208, 0.6250000>,
    <0.5000000, 0.6880595>,
    <0.4375334, 0.7500000>,
    <0.3750000, 0.6880875>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5624792, 0.6250000>,
    <0.6250000, 0.6880573>,
    <0.5624666, 0.7500000>,
    <0.5000000, 0.6880595>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6877657, 0.6250000>,
    <0.7500000, 0.6880799>,
    <0.6877009, 0.7500000>,
    <0.6250000, 0.6880573>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8133640, 0.6250000>,
    <0.8750000, 0.6881194>,
    <0.8131526, 0.7500000>,
    <0.7500000, 0.6880799>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9390273, 0.6250000>,
    <1.0000000, 0.6881530>,
    <0.9388738, 0.7500000>,
    <0.8750000, 0.6881194>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0611530, 0.7500000>,
    <0.1250000, 0.8164861>,
    <0.0613363, 0.8750000>,
    <0.0000000, 0.8164335>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1868229, 0.7500000>,
    <0.2500000, 0.8165394>,
    <0.1870012, 0.8750000>,
    <0.1250000, 0.8164861>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3122991, 0.7500000>,
    <0.3750000, 0.8165727>,
    <0.3123353, 0.8750000>,
    <0.2500000, 0.8165394>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4375334, 0.7500000>,
    <0.5000000, 0.8165739>,
    <0.4375355, 0.8750000>,
    <0.3750000, 0.8165727>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5624666, 0.7500000>,
    <0.6250000, 0.8165398>,
    <0.5624645, 0.8750000>,
    <0.5000000, 0.8165739>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6877009, 0.7500000>,
    <0.7500000, 0.8164771>,
    <0.6876647, 0.8750000>,
    <0.6250000, 0.8165398>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8131526, 0.7500000>,
    <0.8750000, 0.8164022>,
    <0.8129703, 0.8750000>,
    <0.7500000, 0.8164771>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9388738, 0.7500000>,
    <1.0000000, 0.8163431>,
    <0.9386955, 0.8750000>,
    <0.8750000, 0.8164022>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0613363, 0.8750000>,
    <0.1250000, 0.9375331>,
    <0.0614920, 1.0000000>,
    <0.0000000, 0.9375058>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1870012, 0.8750000>,
    <0.2500000, 0.9375624>,
    <0.1871169, 1.0000000>,
    <0.1250000, 0.9375331>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3123353, 0.8750000>,
    <0.3750000, 0.9375822>,
    <0.3123372, 1.0000000>,
    <0.2500000, 0.9375624>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4375355, 0.8750000>,
    <0.5000000, 0.9375864>,
    <0.4375275, 1.0000000>,
    <0.3750000, 0.9375822>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5624645, 0.8750000>,
    <0.6250000, 0.9375733>,
    <0.5624723, 1.0000000>,
    <0.5000000, 0.9375864>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6876647, 0.8750000>,
    <0.7500000, 0.9375452>,
    <0.6876626, 1.0000000>,
    <0.6250000, 0.9375733>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8129703, 0.8750000>,
    <0.8750000, 0.9375091>,
    <0.8128567, 1.0000000>,
    <0.7500000, 0.9375452>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9386955, 0.8750000>,
    <1.0000000, 0.9374789>,
    <0.9385381, 1.0000000>,
    <0.8750000, 0.9375091>,
    <0.0416667, 0.0833333>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0495323, 0.0495323>,
    <0.0655827, 0.1250000>,
    <0.0000000, 0.0495636>,
    <0.1666667, 0.0833333>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1740898, 0.0490898>,
    <0.1901079, 0.1250000>,
    <0.1250000, 0.0495323>,
    <0.2916667, 0.0833333>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2989009, 0.0489009>,
    <0.3146643, 0.1250000>,
    <0.2500000, 0.0490898>,
    <0.4166667, 0.0833333>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4238462, 0.0488462>,
    <0.4386771, 0.1250000>,
    <0.3750000, 0.0489009>,
    <0.5416667, 0.0833333>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5489090, 0.0489090>,
    <0.5625739, 0.1250000>,
    <0.5000000, 0.0488462>,
    <0.6666667, 0.0833333>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6741287, 0.0491287>,
    <0.6870170, 0.1250000>,
    <0.6250000, 0.0489090>,
    <0.7916667, 0.0833333>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7997911, 0.0497911>,
    <0.8120796, 0.1250000>,
    <0.7500000, 0.0491287>,
    <0.9166667, 0.0833333>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9251834, 0.0501834>,
    <0.9381625, 0.1250000>,
    <0.8750000, 0.0497911>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0655827, 0.1250000>,
    <0.1250000, 0.1868946>,
    <0.0607992, 0.2500000>,
    <0.0000000, 0.1876481>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1901079, 0.1250000>,
    <0.2500000, 0.1864791>,
    <0.1861939, 0.2500000>,
    <0.1250000, 0.1868946>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3146643, 0.1250000>,
    <0.3750000, 0.1863219>,
    <0.3121086, 0.2500000>,
    <0.2500000, 0.1864791>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4386771, 0.1250000>,
    <0.5000000, 0.1863609>,
    <0.4374951, 0.2500000>,
    <0.3750000, 0.1863219>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5625739, 0.1250000>,
    <0.6250000, 0.1865823>,
    <0.5625049, 0.2500000>,
    <0.5000000, 0.1863609>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6870170, 0.1250000>,
    <0.7500000, 0.1870246>,
    <0.6878914, 0.2500000>,
    <0.6250000, 0.1865823>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8120796, 0.1250000>,
    <0.8750000, 0.1877942>,
    <0.8136655, 0.2500000>,
    <0.7500000, 0.1870246>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9381625, 0.1250000>,
    <1.0000000, 0.1892013>,
    <0.9393473, 0.2500000>,
    <0.8750000, 0.1877942>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0607992, 0.2500000>,
    <0.1250000, 0.3126526>,
    <0.0607501, 0.3750000>,
    <0.0000000, 0.3131787>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1861939, 0.2500000>,
    <0.2500000, 0.3123789>,
    <0.1863932, 0.3750000>,
    <0.1250000, 0.3126526>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3121086, 0.2500000>,
    <0.3750000, 0.3123022>,
    <0.3122560, 0.3750000>,
    <0.2500000, 0.3123789>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4374951, 0.2500000>,
    <0.5000000, 0.3123761>,
    <0.4375493, 0.3750000>,
    <0.3750000, 0.3123022>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5625049, 0.2500000>,
    <0.6250000, 0.3125839>,
    <0.5624507, 0.3750000>,
    <0.5000000, 0.3123761>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6878914, 0.2500000>,
    <0.7500000, 0.3129328>,
    <0.6877440, 0.3750000>,
    <0.6250000, 0.3125839>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8136655, 0.2500000>,
    <0.8750000, 0.3134489>,
    <0.8135514, 0.3750000>,
    <0.7500000, 0.3129328>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9393473, 0.2500000>,
    <1.0000000, 0.3141163>,
    <0.9393078, 0.3750000>,
    <0.8750000, 0.3134489>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0607501, 0.3750000>,
    <0.1250000, 0.4386468>,
    <0.0607137, 0.5000000>,
    <0.0000000, 0.4387783>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1863932, 0.3750000>,
    <0.2500000, 0.4385730>,
    <0.1866755, 0.5000000>,
    <0.1250000, 0.4386468>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3122560, 0.3750000>,
    <0.3750000, 0.4385507>,
    <0.3124962, 0.5000000>,
    <0.2500000, 0.4385730>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4375493, 0.3750000>,
    <0.5000000, 0.4385739>,
    <0.4376353, 0.5000000>,
    <0.3750000, 0.4385507>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5624507, 0.3750000>,
    <0.6250000, 0.4386387>,
    <0.5623647, 0.5000000>,
    <0.5000000, 0.4385739>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6877440, 0.3750000>,
    <0.7500000, 0.4387399>,
    <0.6875038, 0.5000000>,
    <0.6250000, 0.4386387>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8135514, 0.3750000>,
    <0.8750000, 0.4388711>,
    <0.8133115, 0.5000000>,
    <0.7500000, 0.4387399>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9393078, 0.3750000>,
    <1.0000000, 0.4390176>,
    <0.9392999, 0.5000000>,
    <0.8750000, 0.4388711>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0607137, 0.5000000>,
    <0.1250000, 0.5617699>,
    <0.0606663, 0.6250000>,
    <0.0000000, 0.5617545>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1866755, 0.5000000>,
    <0.2500000, 0.5617199>,
    <0.1870850, 0.6250000>,
    <0.1250000, 0.5617699>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3124962, 0.5000000>,
    <0.3750000, 0.5616537>,
    <0.3128432, 0.6250000>,
    <0.2500000, 0.5617199>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4376353, 0.5000000>,
    <0.5000000, 0.5616261>,
    <0.4377544, 0.6250000>,
    <0.3750000, 0.5616537>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5623647, 0.5000000>,
    <0.6250000, 0.5616599>,
    <0.5622456, 0.6250000>,
    <0.5000000, 0.5616261>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6875038, 0.5000000>,
    <0.7500000, 0.5617332>,
    <0.6871568, 0.6250000>,
    <0.6250000, 0.5616599>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8133115, 0.5000000>,
    <0.8750000, 0.5617895>,
    <0.8129260, 0.6250000>,
    <0.7500000, 0.5617332>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9392999, 0.5000000>,
    <1.0000000, 0.5617762>,
    <0.9393220, 0.6250000>,
    <0.8750000, 0.5617895>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0606663, 0.6250000>,
    <0.1250000, 0.6881779>,
    <0.0605918, 0.7500000>,
    <0.0000000, 0.6881530>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1870850, 0.6250000>,
    <0.2500000, 0.6880885>,
    <0.1876185, 0.7500000>,
    <0.1250000, 0.6881779>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3128432, 0.6250000>,
    <0.3750000, 0.6879700>,
    <0.3132690, 0.7500000>,
    <0.2500000, 0.6880885>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4377544, 0.6250000>,
    <0.5000000, 0.6879278>,
    <0.4378926, 0.7500000>,
    <0.3750000, 0.6879700>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5622456, 0.6250000>,
    <0.6250000, 0.6880069>,
    <0.5621074, 0.7500000>,
    <0.5000000, 0.6879278>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6871568, 0.6250000>,
    <0.7500000, 0.6881574>,
    <0.6867310, 0.7500000>,
    <0.6250000, 0.6880069>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8129260, 0.6250000>,
    <0.8750000, 0.6882661>,
    <0.8124047, 0.7500000>,
    <0.7500000, 0.6881574>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9393220, 0.6250000>,
    <1.0000000, 0.6882387>,
    <0.9393835, 0.7500000>,
    <0.8750000, 0.6882661>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0605918, 0.7500000>,
    <0.1250000, 0.8162922>,
    <0.0604868, 0.8750000>,
    <0.0000000, 0.8163431>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1876185, 0.7500000>,
    <0.2500000, 0.8163189>,
    <0.1881908, 0.8750000>,
    <0.1250000, 0.8162922>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3132690, 0.7500000>,
    <0.3750000, 0.8163786>,
    <0.3136906, 0.8750000>,
    <0.2500000, 0.8163189>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4378926, 0.7500000>,
    <0.5000000, 0.8164215>,
    <0.4380216, 0.8750000>,
    <0.3750000, 0.8163786>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5621074, 0.7500000>,
    <0.6250000, 0.8164228>,
    <0.5619784, 0.8750000>,
    <0.5000000, 0.8164215>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6867310, 0.7500000>,
    <0.7500000, 0.8163972>,
    <0.6863094, 0.8750000>,
    <0.6250000, 0.8164228>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8124047, 0.7500000>,
    <0.8750000, 0.8163879>,
    <0.8118358, 0.8750000>,
    <0.7500000, 0.8163972>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9393835, 0.7500000>,
    <1.0000000, 0.8164335>,
    <0.9394846, 0.8750000>,
    <0.8750000, 0.8163879>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0604868, 0.8750000>,
    <0.1250000, 0.9374467>,
    <0.0603763, 1.0000000>,
    <0.0000000, 0.9374789>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1881908, 0.8750000>,
    <0.2500000, 0.9374719>,
    <0.1886658, 1.0000000>,
    <0.1250000, 0.9374467>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3136906, 0.8750000>,
    <0.3750000, 0.9375196>,
    <0.3140156, 1.0000000>,
    <0.2500000, 0.9374719>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4380216, 0.8750000>,
    <0.5000000, 0.9375466>,
    <0.4381163, 1.0000000>,
    <0.3750000, 0.9375196>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5619784, 0.8750000>,
    <0.6250000, 0.9375337>,
    <0.5618835, 1.0000000>,
    <0.5000000, 0.9375466>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6863094, 0.8750000>,
    <0.7500000, 0.9374968>,
    <0.6859842, 1.0000000>,
    <0.6250000, 0.9375337>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8118358, 0.8750000>,
    <0.8750000, 0.9374767>,
    <0.8113588, 1.0000000>,
    <0.7500000, 0.9374968>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9394846, 0.8750000>,
    <1.0000000, 0.9375058>,
    <0.9395979, 1.0000000>,
    <0.8750000, 0.9374767>,
    <0.0625000, 0.0625000>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0614920, 0.0000000>,
    <0.1250000, 0.0608389>,
    <0.0616120, 0.1250000>,
    <0.0000000, 0.0608164>,
    <0.1875000, 0.0625000>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1871169, 0.0000000>,
    <0.2500000, 0.0608564>,
    <0.1872003, 0.1250000>,
    <0.1250000, 0.0608389>,
    <0.3125000, 0.0625000>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.3123372, 0.0000000>,
    <0.3750000, 0.0608655>,
    <0.3123379, 0.1250000>,
    <0.2500000, 0.0608564>,
    <0.4375000, 0.0625000>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4375275, 0.0000000>,
    <0.5000000, 0.0608666>,
    <0.4375210, 0.1250000>,
    <0.3750000, 0.0608655>,
    <0.5625000, 0.0625000>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5624723, 0.0000000>,
    <0.6250000, 0.0608601>,
    <0.5624767, 0.1250000>,
    <0.5000000, 0.0608666>,
    <0.6875000, 0.0625000>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6876626, 0.0000000>,
    <0.7500000, 0.0608457>,
    <0.6876606, 0.1250000>,
    <0.6250000, 0.0608601>,
    <0.8125000, 0.0625000>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.8128567, 0.0000000>,
    <0.8750000, 0.0608230>,
    <0.8127781, 0.1250000>,
    <0.7500000, 0.0608457>,
    <0.9375000, 0.0625000>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9385381, 0.0000000>,
    <1.0000000, 0.0607970>,
    <0.9384153, 0.1250000>,
    <0.8750000, 0.0608230>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0616120, 0.1250000>,
    <0.1250000, 0.1880574>,
    <0.0616963, 0.2500000>,
    <0.0000000, 0.1880275>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1872003, 0.1250000>,
    <0.2500000, 0.1880855>,
    <0.1872812, 0.2500000>,
    <0.1250000, 0.1880574>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3123379, 0.1250000>,
    <0.3750000, 0.1881025>,
    <0.3123584, 0.2500000>,
    <0.2500000, 0.1880855>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4375210, 0.1250000>,
    <0.5000000, 0.1881080>,
    <0.4375231, 0.2500000>,
    <0.3750000, 0.1881025>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5624767, 0.1250000>,
    <0.6250000, 0.1881021>,
    <0.5624705, 0.2500000>,
    <0.5000000, 0.1881080>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6876606, 0.1250000>,
    <0.7500000, 0.1880846>,
    <0.6876373, 0.2500000>,
    <0.6250000, 0.1881021>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8127781, 0.1250000>,
    <0.8750000, 0.1880562>,
    <0.8127026, 0.2500000>,
    <0.7500000, 0.1880846>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9384153, 0.1250000>,
    <1.0000000, 0.1880258>,
    <0.9383296, 0.2500000>,
    <0.8750000, 0.1880562>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0616963, 0.2500000>,
    <0.1250000, 0.3127396>,
    <0.0617539, 0.3750000>,
    <0.0000000, 0.3127267>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1872812, 0.2500000>,
    <0.2500000, 0.3127526>,
    <0.1873613, 0.3750000>,
    <0.1250000, 0.3127396>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3123584, 0.2500000>,
    <0.3750000, 0.3127610>,
    <0.3123931, 0.3750000>,
    <0.2500000, 0.3127526>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4375231, 0.2500000>,
    <0.5000000, 0.3127642>,
    <0.4375315, 0.3750000>,
    <0.3750000, 0.3127610>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5624705, 0.2500000>,
    <0.6250000, 0.3127622>,
    <0.5624570, 0.3750000>,
    <0.5000000, 0.3127642>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6876373, 0.2500000>,
    <0.7500000, 0.3127550>,
    <0.6875991, 0.3750000>,
    <0.6250000, 0.3127622>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8127026, 0.2500000>,
    <0.8750000, 0.3127434>,
    <0.8126277, 0.3750000>,
    <0.7500000, 0.3127550>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9383296, 0.2500000>,
    <1.0000000, 0.3127317>,
    <0.9382719, 0.3750000>,
    <0.8750000, 0.3127434>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0617539, 0.3750000>,
    <0.1250000, 0.4375936>,
    <0.0617877, 0.5000000>,
    <0.0000000, 0.4375845>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1873613, 0.3750000>,
    <0.2500000, 0.4376051>,
    <0.1874371, 0.5000000>,
    <0.1250000, 0.4375936>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3123931, 0.3750000>,
    <0.3750000, 0.4376138>,
    <0.3124366, 0.5000000>,
    <0.2500000, 0.4376051>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4375315, 0.3750000>,
    <0.5000000, 0.4376177>,
    <0.4375441, 0.5000000>,
    <0.3750000, 0.4376138>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5624570, 0.3750000>,
    <0.6250000, 0.4376164>,
    <0.5624392, 0.5000000>,
    <0.5000000, 0.4376177>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6875991, 0.3750000>,
    <0.7500000, 0.4376104>,
    <0.6875519, 0.5000000>,
    <0.6250000, 0.4376164>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8126277, 0.3750000>,
    <0.8750000, 0.4376015>,
    <0.8125565, 0.5000000>,
    <0.7500000, 0.4376104>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9382719, 0.3750000>,
    <1.0000000, 0.4375944>,
    <0.9382385, 0.5000000>,
    <0.8750000, 0.4376015>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0617877, 0.5000000>,
    <0.1250000, 0.5625397>,
    <0.0617955, 0.6250000>,
    <0.0000000, 0.5625413>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1874371, 0.5000000>,
    <0.2500000, 0.5625452>,
    <0.1875040, 0.6250000>,
    <0.1250000, 0.5625397>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3124366, 0.5000000>,
    <0.3750000, 0.5625519>,
    <0.3124860, 0.6250000>,
    <0.2500000, 0.5625452>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4375441, 0.5000000>,
    <0.5000000, 0.5625560>,
    <0.4375602, 0.6250000>,
    <0.3750000, 0.5625519>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5624392, 0.5000000>,
    <0.6250000, 0.5625560>,
    <0.5624187, 0.6250000>,
    <0.5000000, 0.5625560>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6875519, 0.5000000>,
    <0.7500000, 0.5625534>,
    <0.6874992, 0.6250000>,
    <0.6250000, 0.5625560>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8125565, 0.5000000>,
    <0.8750000, 0.5625518>,
    <0.8124934, 0.6250000>,
    <0.7500000, 0.5625534>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9382385, 0.5000000>,
    <1.0000000, 0.5625559>,
    <0.9382319, 0.6250000>,
    <0.8750000, 0.5625518>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0617955, 0.6250000>,
    <0.1250000, 0.6875988>,
    <0.0617704, 0.7500000>,
    <0.0000000, 0.6876164>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1875040, 0.6250000>,
    <0.2500000, 0.6875858>,
    <0.1875555, 0.7500000>,
    <0.1250000, 0.6875988>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3124860, 0.6250000>,
    <0.3750000, 0.6875792>,
    <0.3125397, 0.7500000>,
    <0.2500000, 0.6875858>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4375602, 0.6250000>,
    <0.5000000, 0.6875775>,
    <0.4375795, 0.7500000>,
    <0.3750000, 0.6875792>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5624187, 0.6250000>,
    <0.6250000, 0.6875797>,
    <0.5623962, 0.7500000>,
    <0.5000000, 0.6875775>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6874992, 0.6250000>,
    <0.7500000, 0.6875865>,
    <0.6874431, 0.7500000>,
    <0.6250000, 0.6875797>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8124934, 0.6250000>,
    <0.8750000, 0.6875998>,
    <0.8124443, 0.7500000>,
    <0.7500000, 0.6875865>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9382319, 0.6250000>,
    <1.0000000, 0.6876171>,
    <0.9382586, 0.7500000>,
    <0.8750000, 0.6875998>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0617704, 0.7500000>,
    <0.1250000, 0.8073802>,
    <0.0616999, 0.8750000>,
    <0.0000000, 0.8074480>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1875555, 0.7500000>,
    <0.2500000, 0.8073186>,
    <0.1875799, 0.8750000>,
    <0.1250000, 0.8073802>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3125397, 0.7500000>,
    <0.3750000, 0.8072807>,
    <0.3125962, 0.8750000>,
    <0.2500000, 0.8073186>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4375795, 0.7500000>,
    <0.5000000, 0.8072660>,
    <0.4376025, 0.8750000>,
    <0.3750000, 0.8072807>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5623962, 0.7500000>,
    <0.6250000, 0.8072732>,
    <0.5623726, 0.8750000>,
    <0.5000000, 0.8072660>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6874431, 0.7500000>,
    <0.7500000, 0.8073034>,
    <0.6873862, 0.8750000>,
    <0.6250000, 0.8072732>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8124443, 0.7500000>,
    <0.8750000, 0.8073573>,
    <0.8124200, 0.8750000>,
    <0.7500000, 0.8073034>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9382586, 0.7500000>,
    <1.0000000, 0.8074192>,
    <0.9383311, 0.8750000>,
    <0.8750000, 0.8073573>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0616999, 0.8750000>,
    <0.1250000, 0.9320202>,
    <0.0615789, 1.0000000>,
    <0.0000000, 0.9322578>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1875799, 0.8750000>,
    <0.2500000, 0.9318264>,
    <0.1875879, 1.0000000>,
    <0.1250000, 0.9320202>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3125962, 0.8750000>,
    <0.3750000, 0.9317158>,
    <0.3126691, 1.0000000>,
    <0.2500000, 0.9318264>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4376025, 0.8750000>,
    <0.5000000, 0.9316637>,
    <0.4376349, 1.0000000>,
    <0.3750000, 0.9317158>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5623726, 0.8750000>,
    <0.6250000, 0.9316564>,
    <0.5623433, 1.0000000>,
    <0.5000000, 0.9316637>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6873862, 0.8750000>,
    <0.7500000, 0.9317083>,
    <0.6873154, 1.0000000>,
    <0.6250000, 0.9316564>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8124200, 0.8750000>,
    <0.8750000, 0.9318490>,
    <0.8124087, 1.0000000>,
    <0.7500000, 0.9317083>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9383311, 0.8750000>,
    <1.0000000, 0.9320530>,
    <0.9384539, 1.0000000>,
    <0.8750000, 0.9318490>,
    <0.0625000, 0.0625000>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0603763, 0.0000000>,
    <0.1250000, 0.0607689>,
    <0.0603054, 0.1250000>,
    <0.0000000, 0.0607970>,
    <0.1875000, 0.0625000>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1886658, 0.0000000>,
    <0.2500000, 0.0607880>,
    <0.1890011, 0.1250000>,
    <0.1250000, 0.0607689>,
    <0.3125000, 0.0625000>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.3140156, 0.0000000>,
    <0.3750000, 0.0608267>,
    <0.3142204, 0.1250000>,
    <0.2500000, 0.0607880>,
    <0.4375000, 0.0625000>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4381163, 0.0000000>,
    <0.5000000, 0.0608485>,
    <0.4381725, 0.1250000>,
    <0.3750000, 0.0608267>,
    <0.5625000, 0.0625000>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5618835, 0.0000000>,
    <0.6250000, 0.0608372>,
    <0.5618255, 0.1250000>,
    <0.5000000, 0.0608485>,
    <0.6875000, 0.0625000>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6859842, 0.0000000>,
    <0.7500000, 0.0608065>,
    <0.6857778, 0.1250000>,
    <0.6250000, 0.0608372>,
    <0.8125000, 0.0625000>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.8113588, 0.0000000>,
    <0.8750000, 0.0607909>,
    <0.8110202, 0.1250000>,
    <0.7500000, 0.0608065>,
    <0.9375000, 0.0625000>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9395979, 0.0000000>,
    <1.0000000, 0.0608164>,
    <0.9396761, 0.1250000>,
    <0.8750000, 0.0607909>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0603054, 0.1250000>,
    <0.1250000, 0.1880032>,
    <0.0602688, 0.2500000>,
    <0.0000000, 0.1880258>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1890011, 0.1250000>,
    <0.2500000, 0.1880364>,
    <0.1892384, 0.2500000>,
    <0.1250000, 0.1880032>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3142204, 0.1250000>,
    <0.3750000, 0.1880865>,
    <0.3143494, 0.2500000>,
    <0.2500000, 0.1880364>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4381725, 0.1250000>,
    <0.5000000, 0.1881092>,
    <0.4382056, 0.2500000>,
    <0.3750000, 0.1880865>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5618255, 0.1250000>,
    <0.6250000, 0.1880868>,
    <0.5617890, 0.2500000>,
    <0.5000000, 0.1881092>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6857778, 0.1250000>,
    <0.7500000, 0.1880372>,
    <0.6856455, 0.2500000>,
    <0.6250000, 0.1880868>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8110202, 0.1250000>,
    <0.8750000, 0.1880045>,
    <0.8107803, 0.2500000>,
    <0.7500000, 0.1880372>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9396761, 0.1250000>,
    <1.0000000, 0.1880275>,
    <0.9397238, 0.2500000>,
    <0.8750000, 0.1880045>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0602688, 0.2500000>,
    <0.1250000, 0.3127247>,
    <0.0602578, 0.3750000>,
    <0.0000000, 0.3127317>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1892384, 0.2500000>,
    <0.2500000, 0.3127403>,
    <0.1894046, 0.3750000>,
    <0.1250000, 0.3127247>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3143494, 0.2500000>,
    <0.3750000, 0.3127613>,
    <0.3144291, 0.3750000>,
    <0.2500000, 0.3127403>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4382056, 0.2500000>,
    <0.5000000, 0.3127695>,
    <0.4382243, 0.3750000>,
    <0.3750000, 0.3127613>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5617890, 0.2500000>,
    <0.6250000, 0.3127581>,
    <0.5617659, 0.3750000>,
    <0.5000000, 0.3127695>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6856455, 0.2500000>,
    <0.7500000, 0.3127348>,
    <0.6855617, 0.3750000>,
    <0.6250000, 0.3127581>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8107803, 0.2500000>,
    <0.8750000, 0.3127185>,
    <0.8106117, 0.3750000>,
    <0.7500000, 0.3127348>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9397238, 0.2500000>,
    <1.0000000, 0.3127267>,
    <0.9397477, 0.3750000>,
    <0.8750000, 0.3127185>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0602578, 0.3750000>,
    <0.1250000, 0.4375916>,
    <0.0602692, 0.5000000>,
    <0.0000000, 0.4375944>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1894046, 0.3750000>,
    <0.2500000, 0.4376050>,
    <0.1895059, 0.5000000>,
    <0.1250000, 0.4375916>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3144291, 0.3750000>,
    <0.3750000, 0.4376211>,
    <0.3144680, 0.5000000>,
    <0.2500000, 0.4376050>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4382243, 0.3750000>,
    <0.5000000, 0.4376262>,
    <0.4382318, 0.5000000>,
    <0.3750000, 0.4376211>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5617659, 0.3750000>,
    <0.6250000, 0.4376154>,
    <0.5617541, 0.5000000>,
    <0.5000000, 0.4376262>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6855617, 0.3750000>,
    <0.7500000, 0.4375950>,
    <0.6855185, 0.5000000>,
    <0.6250000, 0.4376154>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8106117, 0.3750000>,
    <0.8750000, 0.4375799>,
    <0.8105084, 0.5000000>,
    <0.7500000, 0.4375950>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9397477, 0.3750000>,
    <1.0000000, 0.4375845>,
    <0.9397491, 0.5000000>,
    <0.8750000, 0.4375799>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0602692, 0.5000000>,
    <0.1250000, 0.5625642>,
    <0.0603030, 0.6250000>,
    <0.0000000, 0.5625559>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1895059, 0.5000000>,
    <0.2500000, 0.5625700>,
    <0.1895351, 0.6250000>,
    <0.1250000, 0.5625642>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3144680, 0.5000000>,
    <0.3750000, 0.5625713>,
    <0.3144652, 0.6250000>,
    <0.2500000, 0.5625700>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4382318, 0.5000000>,
    <0.5000000, 0.5625688>,
    <0.4382282, 0.6250000>,
    <0.3750000, 0.5625713>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5617541, 0.5000000>,
    <0.6250000, 0.5625635>,
    <0.5617538, 0.6250000>,
    <0.5000000, 0.5625688>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6855185, 0.5000000>,
    <0.7500000, 0.5625562>,
    <0.6855175, 0.6250000>,
    <0.6250000, 0.5625635>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8105084, 0.5000000>,
    <0.8750000, 0.5625477>,
    <0.8104778, 0.6250000>,
    <0.7500000, 0.5625562>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9397491, 0.5000000>,
    <1.0000000, 0.5625413>,
    <0.9397262, 0.6250000>,
    <0.8750000, 0.5625477>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0603030, 0.6250000>,
    <0.1250000, 0.6876339>,
    <0.0603614, 0.7500000>,
    <0.0000000, 0.6876171>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1895351, 0.6250000>,
    <0.2500000, 0.6876171>,
    <0.1894741, 0.7500000>,
    <0.1250000, 0.6876339>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3144652, 0.6250000>,
    <0.3750000, 0.6875890>,
    <0.3144117, 0.7500000>,
    <0.2500000, 0.6876171>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4382282, 0.6250000>,
    <0.5000000, 0.6875761>,
    <0.4382114, 0.7500000>,
    <0.3750000, 0.6875890>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5617538, 0.6250000>,
    <0.6250000, 0.6875889>,
    <0.5617678, 0.7500000>,
    <0.5000000, 0.6875761>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6855175, 0.6250000>,
    <0.7500000, 0.6876170>,
    <0.6855684, 0.7500000>,
    <0.6250000, 0.6875889>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8104778, 0.6250000>,
    <0.8750000, 0.6876335>,
    <0.8105382, 0.7500000>,
    <0.7500000, 0.6876170>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9397262, 0.6250000>,
    <1.0000000, 0.6876164>,
    <0.9396745, 0.7500000>,
    <0.8750000, 0.6876335>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0603614, 0.7500000>,
    <0.1250000, 0.8074704>,
    <0.0604475, 0.8750000>,
    <0.0000000, 0.8074192>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1894741, 0.7500000>,
    <0.2500000, 0.8073958>,
    <0.1892901, 0.8750000>,
    <0.1250000, 0.8074704>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3144117, 0.7500000>,
    <0.3750000, 0.8072835>,
    <0.3142877, 0.8750000>,
    <0.2500000, 0.8073958>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4382114, 0.7500000>,
    <0.5000000, 0.8072379>,
    <0.4381759, 0.8750000>,
    <0.3750000, 0.8072835>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5617678, 0.7500000>,
    <0.6250000, 0.8073003>,
    <0.5618024, 0.8750000>,
    <0.5000000, 0.8072379>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6855684, 0.7500000>,
    <0.7500000, 0.8074250>,
    <0.6856920, 0.8750000>,
    <0.6250000, 0.8073003>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8105382, 0.7500000>,
    <0.8750000, 0.8075043>,
    <0.8107231, 0.8750000>,
    <0.7500000, 0.8074250>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9396745, 0.7500000>,
    <1.0000000, 0.8074480>,
    <0.9395879, 0.8750000>,
    <0.8750000, 0.8075043>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0604475, 0.8750000>,
    <0.1250000, 0.9322696>,
    <0.0605636, 1.0000000>,
    <0.0000000, 0.9320530>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1892901, 0.8750000>,
    <0.2500000, 0.9320245>,
    <0.1889796, 1.0000000>,
    <0.1250000, 0.9322696>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3142877, 0.8750000>,
    <0.3750000, 0.9315999>,
    <0.3140799, 1.0000000>,
    <0.2500000, 0.9320245>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4381759, 0.8750000>,
    <0.5000000, 0.9314337>,
    <0.4381169, 1.0000000>,
    <0.3750000, 0.9315999>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5618024, 0.8750000>,
    <0.6250000, 0.9317311>,
    <0.5618636, 1.0000000>,
    <0.5000000, 0.9314337>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6856920, 0.8750000>,
    <0.7500000, 0.9322335>,
    <0.6859027, 1.0000000>,
    <0.6250000, 0.9317311>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8107231, 0.8750000>,
    <0.8750000, 0.9324999>,
    <0.8110362, 1.0000000>,
    <0.7500000, 0.9322335>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9395879, 0.8750000>,
    <1.0000000, 0.9322578>,
    <0.9394615, 1.0000000>,
    <0.8750000, 0.9324999>,
    <0.0625000, 0.0625000>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0615789, 0.0000000>,
    <0.1250000, 0.0643864>,
    <0.0615114, 0.1250000>,
    <0.0000000, 0.0641146>,
    <0.1875000, 0.0625000>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1875879, 0.0000000>,
    <0.2500000, 0.0647801>,
    <0.1878429, 0.1250000>,
    <0.1250000, 0.0643864>,
    <0.3125000, 0.0625000>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.3126691, 0.0000000>,
    <0.3750000, 0.0650832>,
    <0.3129062, 0.1250000>,
    <0.2500000, 0.0647801>,
    <0.4375000, 0.0625000>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4376349, 0.0000000>,
    <0.5000000, 0.0652025>,
    <0.4377214, 0.1250000>,
    <0.3750000, 0.0650832>,
    <0.5625000, 0.0625000>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5623433, 0.0000000>,
    <0.6250000, 0.0651123>,
    <0.5622623, 0.1250000>,
    <0.5000000, 0.0652025>,
    <0.6875000, 0.0625000>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6873154, 0.0000000>,
    <0.7500000, 0.0648362>,
    <0.6870817, 0.1250000>,
    <0.6250000, 0.0651123>,
    <0.8125000, 0.0625000>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.8124087, 0.0000000>,
    <0.8750000, 0.0644635>,
    <0.8121465, 0.1250000>,
    <0.7500000, 0.0648362>,
    <0.9375000, 0.0625000>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9384539, 0.0000000>,
    <1.0000000, 0.0642016>,
    <0.9385243, 0.1250000>,
    <0.8750000, 0.0644635>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0615114, 0.1250000>,
    <0.1250000, 0.1868813>,
    <0.0616971, 0.2500000>,
    <0.0000000, 0.1867408>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1878429, 0.1250000>,
    <0.2500000, 0.1870854>,
    <0.1888692, 0.2500000>,
    <0.1250000, 0.1868813>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3129062, 0.1250000>,
    <0.3750000, 0.1872300>,
    <0.3135239, 0.2500000>,
    <0.2500000, 0.1870854>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4377214, 0.1250000>,
    <0.5000000, 0.1872847>,
    <0.4379145, 0.2500000>,
    <0.3750000, 0.1872300>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5622623, 0.1250000>,
    <0.6250000, 0.1872457>,
    <0.5620746, 0.2500000>,
    <0.5000000, 0.1872847>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6870817, 0.1250000>,
    <0.7500000, 0.1871179>,
    <0.6864666, 0.2500000>,
    <0.6250000, 0.1872457>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8121465, 0.1250000>,
    <0.8750000, 0.1869312>,
    <0.8111089, 0.2500000>,
    <0.7500000, 0.1871179>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9385243, 0.1250000>,
    <1.0000000, 0.1868019>,
    <0.9383469, 0.2500000>,
    <0.8750000, 0.1869312>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0616971, 0.2500000>,
    <0.1250000, 0.3130045>,
    <0.0621526, 0.3750000>,
    <0.0000000, 0.3130249>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1888692, 0.2500000>,
    <0.2500000, 0.3130112>,
    <0.1904636, 0.3750000>,
    <0.1250000, 0.3130045>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3135239, 0.2500000>,
    <0.3750000, 0.3130194>,
    <0.3142501, 0.3750000>,
    <0.2500000, 0.3130112>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4379145, 0.2500000>,
    <0.5000000, 0.3130239>,
    <0.4381159, 0.3750000>,
    <0.3750000, 0.3130194>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5620746, 0.2500000>,
    <0.6250000, 0.3130246>,
    <0.5618776, 0.3750000>,
    <0.5000000, 0.3130239>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6864666, 0.2500000>,
    <0.7500000, 0.3130226>,
    <0.6857433, 0.3750000>,
    <0.6250000, 0.3130246>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8111089, 0.2500000>,
    <0.8750000, 0.3130237>,
    <0.8095019, 0.3750000>,
    <0.7500000, 0.3130226>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9383469, 0.2500000>,
    <1.0000000, 0.3130513>,
    <0.9379050, 0.3750000>,
    <0.8750000, 0.3130237>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0621526, 0.3750000>,
    <0.1250000, 0.4390537>,
    <0.0632968, 0.5000000>,
    <0.0000000, 0.4391789>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1904636, 0.3750000>,
    <0.2500000, 0.4388797>,
    <0.1927117, 0.5000000>,
    <0.1250000, 0.4390537>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3142501, 0.3750000>,
    <0.3750000, 0.4387499>,
    <0.3149815, 0.5000000>,
    <0.2500000, 0.4388797>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4381159, 0.3750000>,
    <0.5000000, 0.4387035>,
    <0.4382958, 0.5000000>,
    <0.3750000, 0.4387499>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5618776, 0.3750000>,
    <0.6250000, 0.4387501>,
    <0.5617011, 0.5000000>,
    <0.5000000, 0.4387035>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6857433, 0.3750000>,
    <0.7500000, 0.4388803>,
    <0.6850147, 0.5000000>,
    <0.6250000, 0.4387501>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8095019, 0.3750000>,
    <0.8750000, 0.4390557>,
    <0.8072412, 0.5000000>,
    <0.7500000, 0.4388803>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9379050, 0.3750000>,
    <1.0000000, 0.4391840>,
    <0.9367864, 0.5000000>,
    <0.8750000, 0.4390557>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0632968, 0.5000000>,
    <0.1250000, 0.5646253>,
    <0.0660525, 0.6250000>,
    <0.0000000, 0.5647443>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1927117, 0.5000000>,
    <0.2500000, 0.5644729>,
    <0.1950463, 0.6250000>,
    <0.1250000, 0.5646253>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3149815, 0.5000000>,
    <0.3750000, 0.5643637>,
    <0.3155229, 0.6250000>,
    <0.2500000, 0.5644729>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4382958, 0.5000000>,
    <0.5000000, 0.5643244>,
    <0.4384164, 0.6250000>,
    <0.3750000, 0.5643637>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5617011, 0.5000000>,
    <0.6250000, 0.5643607>,
    <0.5615823, 0.6250000>,
    <0.5000000, 0.5643244>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6850147, 0.5000000>,
    <0.7500000, 0.5644669>,
    <0.6844754, 0.6250000>,
    <0.6250000, 0.5643607>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8072412, 0.5000000>,
    <0.8750000, 0.5646171>,
    <0.8048989, 0.6250000>,
    <0.7500000, 0.5644669>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9367864, 0.5000000>,
    <1.0000000, 0.5647363>,
    <0.9340717, 0.6250000>,
    <0.8750000, 0.5646171>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0660525, 0.6250000>,
    <0.1250000, 0.6901042>,
    <0.0509506, 0.7500000>,
    <0.0000000, 0.6859452>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1950463, 0.6250000>,
    <0.2500000, 0.6899778>,
    <0.1968211, 0.7500000>,
    <0.1250000, 0.6901042>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3155229, 0.6250000>,
    <0.3750000, 0.6898745>,
    <0.3158366, 0.7500000>,
    <0.2500000, 0.6899778>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4384164, 0.6250000>,
    <0.5000000, 0.6898356>,
    <0.4384819, 0.7500000>,
    <0.3750000, 0.6898745>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5615823, 0.6250000>,
    <0.6250000, 0.6898728>,
    <0.5615177, 0.7500000>,
    <0.5000000, 0.6898356>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6844754, 0.6250000>,
    <0.7500000, 0.6899745>,
    <0.6841629, 0.7500000>,
    <0.6250000, 0.6898728>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8048989, 0.6250000>,
    <0.8750000, 0.6900997>,
    <0.8031243, 0.7500000>,
    <0.7500000, 0.6899745>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9340717, 0.6250000>,
    <1.0000000, 0.6859340>,
    <0.9492727, 0.7500000>,
    <0.8750000, 0.6900997>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0509506, 0.7500000>,
    <0.1250000, 0.8162322>,
    <0.0801770, 0.8750000>,
    <0.0000000, 0.8348189>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1968211, 0.7500000>,
    <0.2500000, 0.8176578>,
    <0.1974133, 0.8750000>,
    <0.1250000, 0.8162322>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3158366, 0.7500000>,
    <0.3750000, 0.8188770>,
    <0.3159602, 0.8750000>,
    <0.2500000, 0.8176578>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4384819, 0.7500000>,
    <0.5000000, 0.8193516>,
    <0.4385052, 0.8750000>,
    <0.3750000, 0.8188770>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5615177, 0.7500000>,
    <0.6250000, 0.8188762>,
    <0.5614947, 0.8750000>,
    <0.5000000, 0.8193516>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6841629, 0.7500000>,
    <0.7500000, 0.8176563>,
    <0.6840397, 0.8750000>,
    <0.6250000, 0.8188762>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8031243, 0.7500000>,
    <0.8750000, 0.8162305>,
    <0.8025441, 0.8750000>,
    <0.7500000, 0.8176563>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9492727, 0.7500000>,
    <1.0000000, 0.8348215>,
    <0.9195858, 0.8750000>,
    <0.8750000, 0.8162305>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0801770, 0.8750000>,
    <0.1250000, 0.9183504>,
    <0.0748777, 1.0000000>,
    <0.0000000, 0.9180067>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1974133, 0.8750000>,
    <0.2500000, 0.9192416>,
    <0.1959103, 1.0000000>,
    <0.1250000, 0.9183504>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3159602, 0.8750000>,
    <0.3750000, 0.9198832>,
    <0.3157065, 1.0000000>,
    <0.2500000, 0.9192416>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4385052, 0.8750000>,
    <0.5000000, 0.9201043>,
    <0.4384028, 1.0000000>,
    <0.3750000, 0.9198832>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5614947, 0.8750000>,
    <0.6250000, 0.9198831>,
    <0.5615972, 1.0000000>,
    <0.5000000, 0.9201043>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6840397, 0.8750000>,
    <0.7500000, 0.9192414>,
    <0.6842935, 1.0000000>,
    <0.6250000, 0.9198831>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8025441, 0.8750000>,
    <0.8750000, 0.9183502>,
    <0.8040795, 1.0000000>,
    <0.7500000, 0.9192414>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9195858, 0.8750000>,
    <1.0000000, 0.9180098>,
    <0.9250748, 1.0000000>,
    <0.8750000, 0.9183502>,
    <0.0625000, 0.0625000>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0605636, 0.0000000>,
    <0.1250000, 0.0641791>,
    <0.0607250, 0.1250000>,
    <0.0000000, 0.0642016>,
    <0.1875000, 0.0625000>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1889796, 0.0000000>,
    <0.2500000, 0.0645898>,
    <0.1889074, 0.1250000>,
    <0.1250000, 0.0641791>,
    <0.3125000, 0.0625000>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.3140799, 0.0000000>,
    <0.3750000, 0.0650785>,
    <0.3139598, 0.1250000>,
    <0.2500000, 0.0645898>,
    <0.4375000, 0.0625000>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4381169, 0.0000000>,
    <0.5000000, 0.0652747>,
    <0.4380782, 0.1250000>,
    <0.3750000, 0.0650785>,
    <0.5625000, 0.0625000>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5618636, 0.0000000>,
    <0.6250000, 0.0650237>,
    <0.5619069, 0.1250000>,
    <0.5000000, 0.0652747>,
    <0.6875000, 0.0625000>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6859027, 0.0000000>,
    <0.7500000, 0.0645032>,
    <0.6860271, 0.1250000>,
    <0.6250000, 0.0650237>,
    <0.8125000, 0.0625000>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.8110362, 0.0000000>,
    <0.8750000, 0.0640844>,
    <0.8111117, 0.1250000>,
    <0.7500000, 0.0645032>,
    <0.9375000, 0.0625000>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9394615, 0.0000000>,
    <1.0000000, 0.0641146>,
    <0.9392848, 0.1250000>,
    <0.8750000, 0.0640844>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0607250, 0.1250000>,
    <0.1250000, 0.1868790>,
    <0.0610343, 0.2500000>,
    <0.0000000, 0.1868019>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1889074, 0.1250000>,
    <0.2500000, 0.1871571>,
    <0.1897108, 0.2500000>,
    <0.1250000, 0.1868790>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3139598, 0.1250000>,
    <0.3750000, 0.1874158>,
    <0.3142239, 0.2500000>,
    <0.2500000, 0.1871571>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4380782, 0.1250000>,
    <0.5000000, 0.1875068>,
    <0.4381380, 0.2500000>,
    <0.3750000, 0.1874158>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5619069, 0.1250000>,
    <0.6250000, 0.1873841>,
    <0.5618517, 0.2500000>,
    <0.5000000, 0.1875068>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6860271, 0.1250000>,
    <0.7500000, 0.1871004>,
    <0.6857662, 0.2500000>,
    <0.6250000, 0.1873841>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8111117, 0.1250000>,
    <0.8750000, 0.1868105>,
    <0.8103123, 0.2500000>,
    <0.7500000, 0.1871004>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9392848, 0.1250000>,
    <1.0000000, 0.1867408>,
    <0.9389591, 0.2500000>,
    <0.8750000, 0.1868105>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0610343, 0.2500000>,
    <0.1250000, 0.3131376>,
    <0.0615935, 0.3750000>,
    <0.0000000, 0.3130513>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1897108, 0.2500000>,
    <0.2500000, 0.3132611>,
    <0.1910942, 0.3750000>,
    <0.1250000, 0.3131376>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3142239, 0.2500000>,
    <0.3750000, 0.3133579>,
    <0.3146533, 0.3750000>,
    <0.2500000, 0.3132611>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4381380, 0.2500000>,
    <0.5000000, 0.3133891>,
    <0.4382358, 0.3750000>,
    <0.3750000, 0.3133579>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5618517, 0.2500000>,
    <0.6250000, 0.3133438>,
    <0.5617580, 0.3750000>,
    <0.5000000, 0.3133891>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6857662, 0.2500000>,
    <0.7500000, 0.3132354>,
    <0.6853400, 0.3750000>,
    <0.6250000, 0.3133438>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8103123, 0.2500000>,
    <0.8750000, 0.3131064>,
    <0.8089356, 0.3750000>,
    <0.7500000, 0.3132354>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9389591, 0.2500000>,
    <1.0000000, 0.3130249>,
    <0.9383785, 0.3750000>,
    <0.8750000, 0.3131064>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0615935, 0.3750000>,
    <0.1250000, 0.4392069>,
    <0.0628215, 0.5000000>,
    <0.0000000, 0.4391840>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1910942, 0.3750000>,
    <0.2500000, 0.4391463>,
    <0.1931416, 0.5000000>,
    <0.1250000, 0.4392069>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3146533, 0.3750000>,
    <0.3750000, 0.4390862>,
    <0.3151739, 0.5000000>,
    <0.2500000, 0.4391463>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4382358, 0.3750000>,
    <0.5000000, 0.4390619>,
    <0.4383490, 0.5000000>,
    <0.3750000, 0.4390862>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5617580, 0.3750000>,
    <0.6250000, 0.4390821>,
    <0.5616479, 0.5000000>,
    <0.5000000, 0.4390619>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6853400, 0.3750000>,
    <0.7500000, 0.4391393>,
    <0.6848222, 0.5000000>,
    <0.6250000, 0.4390821>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8089356, 0.3750000>,
    <0.8750000, 0.4391992>,
    <0.8068980, 0.5000000>,
    <0.7500000, 0.4391393>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9383785, 0.3750000>,
    <1.0000000, 0.4391789>,
    <0.9371169, 0.5000000>,
    <0.8750000, 0.4391992>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0628215, 0.5000000>,
    <0.1250000, 0.5647285>,
    <0.0656713, 0.6250000>,
    <0.0000000, 0.5647363>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1931416, 0.5000000>,
    <0.2500000, 0.5646432>,
    <0.1952923, 0.6250000>,
    <0.1250000, 0.5647285>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3151739, 0.5000000>,
    <0.3750000, 0.5645658>,
    <0.3155961, 0.6250000>,
    <0.2500000, 0.5646432>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4383490, 0.5000000>,
    <0.5000000, 0.5645371>,
    <0.4384357, 0.6250000>,
    <0.3750000, 0.5645658>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5616479, 0.5000000>,
    <0.6250000, 0.5645682>,
    <0.5615631, 0.6250000>,
    <0.5000000, 0.5645371>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6848222, 0.5000000>,
    <0.7500000, 0.5646481>,
    <0.6844022, 0.6250000>,
    <0.6250000, 0.5645682>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8068980, 0.5000000>,
    <0.8750000, 0.5647357>,
    <0.8047567, 0.6250000>,
    <0.7500000, 0.5646481>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9371169, 0.5000000>,
    <1.0000000, 0.5647443>,
    <0.9342163, 0.6250000>,
    <0.8750000, 0.5647357>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0656713, 0.6250000>,
    <0.1250000, 0.6901044>,
    <0.0487907, 0.7500000>,
    <0.0000000, 0.6859340>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1952923, 0.6250000>,
    <0.2500000, 0.6899844>,
    <0.1969392, 0.7500000>,
    <0.1250000, 0.6901044>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3155961, 0.6250000>,
    <0.3750000, 0.6898873>,
    <0.3158567, 0.7500000>,
    <0.2500000, 0.6899844>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4384357, 0.6250000>,
    <0.5000000, 0.6898519>,
    <0.4384871, 0.7500000>,
    <0.3750000, 0.6898873>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5615631, 0.6250000>,
    <0.6250000, 0.6898889>,
    <0.5615126, 0.7500000>,
    <0.5000000, 0.6898519>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6844022, 0.6250000>,
    <0.7500000, 0.6899876>,
    <0.6841428, 0.7500000>,
    <0.6250000, 0.6898889>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8047567, 0.6250000>,
    <0.8750000, 0.6901088>,
    <0.8031131, 0.7500000>,
    <0.7500000, 0.6899876>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9342163, 0.6250000>,
    <1.0000000, 0.6859452>,
    <0.9509952, 0.7500000>,
    <0.8750000, 0.6901088>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0487907, 0.7500000>,
    <0.1250000, 0.8160756>,
    <0.0804540, 0.8750000>,
    <0.0000000, 0.8348215>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1969392, 0.7500000>,
    <0.2500000, 0.8172829>,
    <0.1974666, 0.8750000>,
    <0.1250000, 0.8160756>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3158567, 0.7500000>,
    <0.3750000, 0.8183079>,
    <0.3159633, 0.8750000>,
    <0.2500000, 0.8172829>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4384871, 0.7500000>,
    <0.5000000, 0.8187064>,
    <0.4385060, 0.8750000>,
    <0.3750000, 0.8183079>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5615126, 0.7500000>,
    <0.6250000, 0.8183088>,
    <0.5614939, 0.8750000>,
    <0.5000000, 0.8187064>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6841428, 0.7500000>,
    <0.7500000, 0.8172845>,
    <0.6840366, 0.8750000>,
    <0.6250000, 0.8183088>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8031131, 0.7500000>,
    <0.8750000, 0.8160774>,
    <0.8025756, 0.8750000>,
    <0.7500000, 0.8172845>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9509952, 0.7500000>,
    <1.0000000, 0.8348189>,
    <0.9197819, 0.8750000>,
    <0.8750000, 0.8160774>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0804540, 0.8750000>,
    <0.1250000, 0.9186692>,
    <0.0749252, 1.0000000>,
    <0.0000000, 0.9180098>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1974666, 0.8750000>,
    <0.2500000, 0.9196125>,
    <0.1959205, 1.0000000>,
    <0.1250000, 0.9186692>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3159633, 0.8750000>,
    <0.3750000, 0.9202227>,
    <0.3157065, 1.0000000>,
    <0.2500000, 0.9196125>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4385060, 0.8750000>,
    <0.5000000, 0.9204268>,
    <0.4384028, 1.0000000>,
    <0.3750000, 0.9202227>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5614939, 0.8750000>,
    <0.6250000, 0.9202228>,
    <0.5615972, 1.0000000>,
    <0.5000000, 0.9204268>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6840366, 0.8750000>,
    <0.7500000, 0.9196127>,
    <0.6842935, 1.0000000>,
    <0.6250000, 0.9202228>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8025756, 0.8750000>,
    <0.8750000, 0.9186694>,
    <0.8040897, 1.0000000>,
    <0.7500000, 0.9196127>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9197819, 0.8750000>,
    <1.0000000, 0.9180067>,
    <0.9251223, 1.0000000>,
    <0.8750000, 0.9186694>
  }
  texture_list {
    1,
    texture { T_Corps }
  }
  face_indices {
    3040,   // 0 triangles and 1520 quads
    <6, 5, 0>, 0,
    <6, 0, 3>, 0,
    <6, 3, 1>, 0,
    <6, 1, 4>, 0,
    <6, 4, 2>, 0,
    <6, 2, 5>, 0,
    <10, 3, 0>, 0,
    <10, 0, 8>, 0,
    <10, 8, 7>, 0,
    <10, 7, 9>, 0,
    <10, 9, 1>, 0,
    <10, 1, 3>, 0,
    <14, 8, 0>, 0,
    <14, 0, 12>, 0,
    <14, 12, 11>, 0,
    <14, 11, 13>, 0,
    <14, 13, 7>, 0,
    <14, 7, 8>, 0,
    <18, 12, 0>, 0,
    <18, 0, 16>, 0,
    <18, 16, 15>, 0,
    <18, 15, 17>, 0,
    <18, 17, 11>, 0,
    <18, 11, 12>, 0,
    <22, 16, 0>, 0,
    <22, 0, 20>, 0,
    <22, 20, 19>, 0,
    <22, 19, 21>, 0,
    <22, 21, 15>, 0,
    <22, 15, 16>, 0,
    <26, 20, 0>, 0,
    <26, 0, 24>, 0,
    <26, 24, 23>, 0,
    <26, 23, 25>, 0,
    <26, 25, 19>, 0,
    <26, 19, 20>, 0,
    <30, 24, 0>, 0,
    <30, 0, 28>, 0,
    <30, 28, 27>, 0,
    <30, 27, 29>, 0,
    <30, 29, 23>, 0,
    <30, 23, 24>, 0,
    <34, 28, 0>, 0,
    <34, 0, 32>, 0,
    <34, 32, 31>, 0,
    <34, 31, 33>, 0,
    <34, 33, 27>, 0,
    <34, 27, 28>, 0,
    <40, 39, 2>, 0,
    <40, 2, 4>, 0,
    <40, 4, 1>, 0,
    <40, 1, 37>, 0,
    <40, 37, 35>, 0,
    <40, 35, 38>, 0,
    <40, 38, 36>, 0,
    <40, 36, 39>, 0,
    <44, 37, 1>, 0,
    <44, 1, 9>, 0,
    <44, 9, 7>, 0,
    <44, 7, 42>, 0,
    <44, 42, 41>, 0,
    <44, 41, 43>, 0,
    <44, 43, 35>, 0,
    <44, 35, 37>, 0,
    <48, 42, 7>, 0,
    <48, 7, 13>, 0,
    <48, 13, 11>, 0,
    <48, 11, 46>, 0,
    <48, 46, 45>, 0,
    <48, 45, 47>, 0,
    <48, 47, 41>, 0,
    <48, 41, 42>, 0,
    <52, 46, 11>, 0,
    <52, 11, 17>, 0,
    <52, 17, 15>, 0,
    <52, 15, 50>, 0,
    <52, 50, 49>, 0,
    <52, 49, 51>, 0,
    <52, 51, 45>, 0,
    <52, 45, 46>, 0,
    <56, 50, 15>, 0,
    <56, 15, 21>, 0,
    <56, 21, 19>, 0,
    <56, 19, 54>, 0,
    <56, 54, 53>, 0,
    <56, 53, 55>, 0,
    <56, 55, 49>, 0,
    <56, 49, 50>, 0,
    <60, 54, 19>, 0,
    <60, 19, 25>, 0,
    <60, 25, 23>, 0,
    <60, 23, 58>, 0,
    <60, 58, 57>, 0,
    <60, 57, 59>, 0,
    <60, 59, 53>, 0,
    <60, 53, 54>, 0,
    <64, 58, 23>, 0,
    <64, 23, 29>, 0,
    <64, 29, 27>, 0,
    <64, 27, 62>, 0,
    <64, 62, 61>, 0,
    <64, 61, 63>, 0,
    <64, 63, 57>, 0,
    <64, 57, 58>, 0,
    <68, 62, 27>, 0,
    <68, 27, 33>, 0,
    <68, 33, 31>, 0,
    <68, 31, 66>, 0,
    <68, 66, 65>, 0,
    <68, 65, 67>, 0,
    <68, 67, 61>, 0,
    <68, 61, 62>, 0,
    <74, 73, 36>, 0,
    <74, 36, 38>, 0,
    <74, 38, 35>, 0,
    <74, 35, 71>, 0,
    <74, 71, 69>, 0,
    <74, 69, 72>, 0,
    <74, 72, 70>, 0,
    <74, 70, 73>, 0,
    <78, 71, 35>, 0,
    <78, 35, 43>, 0,
    <78, 43, 41>, 0,
    <78, 41, 76>, 0,
    <78, 76, 75>, 0,
    <78, 75, 77>, 0,
    <78, 77, 69>, 0,
    <78, 69, 71>, 0,
    <82, 76, 41>, 0,
    <82, 41, 47>, 0,
    <82, 47, 45>, 0,
    <82, 45, 80>, 0,
    <82, 80, 79>, 0,
    <82, 79, 81>, 0,
    <82, 81, 75>, 0,
    <82, 75, 76>, 0,
    <86, 80, 45>, 0,
    <86, 45, 51>, 0,
    <86, 51, 49>, 0,
    <86, 49, 84>, 0,
    <86, 84, 83>, 0,
    <86, 83, 85>, 0,
    <86, 85, 79>, 0,
    <86, 79, 80>, 0,
    <90, 84, 49>, 0,
    <90, 49, 55>, 0,
    <90, 55, 53>, 0,
    <90, 53, 88>, 0,
    <90, 88, 87>, 0,
    <90, 87, 89>, 0,
    <90, 89, 83>, 0,
    <90, 83, 84>, 0,
    <94, 88, 53>, 0,
    <94, 53, 59>, 0,
    <94, 59, 57>, 0,
    <94, 57, 92>, 0,
    <94, 92, 91>, 0,
    <94, 91, 93>, 0,
    <94, 93, 87>, 0,
    <94, 87, 88>, 0,
    <98, 92, 57>, 0,
    <98, 57, 63>, 0,
    <98, 63, 61>, 0,
    <98, 61, 96>, 0,
    <98, 96, 95>, 0,
    <98, 95, 97>, 0,
    <98, 97, 91>, 0,
    <98, 91, 92>, 0,
    <102, 96, 61>, 0,
    <102, 61, 67>, 0,
    <102, 67, 65>, 0,
    <102, 65, 100>, 0,
    <102, 100, 99>, 0,
    <102, 99, 101>, 0,
    <102, 101, 95>, 0,
    <102, 95, 96>, 0,
    <108, 107, 70>, 0,
    <108, 70, 72>, 0,
    <108, 72, 69>, 0,
    <108, 69, 105>, 0,
    <108, 105, 103>, 0,
    <108, 103, 106>, 0,
    <108, 106, 104>, 0,
    <108, 104, 107>, 0,
    <112, 105, 69>, 0,
    <112, 69, 77>, 0,
    <112, 77, 75>, 0,
    <112, 75, 110>, 0,
    <112, 110, 109>, 0,
    <112, 109, 111>, 0,
    <112, 111, 103>, 0,
    <112, 103, 105>, 0,
    <116, 110, 75>, 0,
    <116, 75, 81>, 0,
    <116, 81, 79>, 0,
    <116, 79, 114>, 0,
    <116, 114, 113>, 0,
    <116, 113, 115>, 0,
    <116, 115, 109>, 0,
    <116, 109, 110>, 0,
    <120, 114, 79>, 0,
    <120, 79, 85>, 0,
    <120, 85, 83>, 0,
    <120, 83, 118>, 0,
    <120, 118, 117>, 0,
    <120, 117, 119>, 0,
    <120, 119, 113>, 0,
    <120, 113, 114>, 0,
    <124, 118, 83>, 0,
    <124, 83, 89>, 0,
    <124, 89, 87>, 0,
    <124, 87, 122>, 0,
    <124, 122, 121>, 0,
    <124, 121, 123>, 0,
    <124, 123, 117>, 0,
    <124, 117, 118>, 0,
    <128, 122, 87>, 0,
    <128, 87, 93>, 0,
    <128, 93, 91>, 0,
    <128, 91, 126>, 0,
    <128, 126, 125>, 0,
    <128, 125, 127>, 0,
    <128, 127, 121>, 0,
    <128, 121, 122>, 0,
    <132, 126, 91>, 0,
    <132, 91, 97>, 0,
    <132, 97, 95>, 0,
    <132, 95, 130>, 0,
    <132, 130, 129>, 0,
    <132, 129, 131>, 0,
    <132, 131, 125>, 0,
    <132, 125, 126>, 0,
    <136, 130, 95>, 0,
    <136, 95, 101>, 0,
    <136, 101, 99>, 0,
    <136, 99, 134>, 0,
    <136, 134, 133>, 0,
    <136, 133, 135>, 0,
    <136, 135, 129>, 0,
    <136, 129, 130>, 0,
    <142, 141, 104>, 0,
    <142, 104, 106>, 0,
    <142, 106, 103>, 0,
    <142, 103, 139>, 0,
    <142, 139, 137>, 0,
    <142, 137, 140>, 0,
    <142, 140, 138>, 0,
    <142, 138, 141>, 0,
    <146, 139, 103>, 0,
    <146, 103, 111>, 0,
    <146, 111, 109>, 0,
    <146, 109, 144>, 0,
    <146, 144, 143>, 0,
    <146, 143, 145>, 0,
    <146, 145, 137>, 0,
    <146, 137, 139>, 0,
    <150, 144, 109>, 0,
    <150, 109, 115>, 0,
    <150, 115, 113>, 0,
    <150, 113, 148>, 0,
    <150, 148, 147>, 0,
    <150, 147, 149>, 0,
    <150, 149, 143>, 0,
    <150, 143, 144>, 0,
    <154, 148, 113>, 0,
    <154, 113, 119>, 0,
    <154, 119, 117>, 0,
    <154, 117, 152>, 0,
    <154, 152, 151>, 0,
    <154, 151, 153>, 0,
    <154, 153, 147>, 0,
    <154, 147, 148>, 0,
    <158, 152, 117>, 0,
    <158, 117, 123>, 0,
    <158, 123, 121>, 0,
    <158, 121, 156>, 0,
    <158, 156, 155>, 0,
    <158, 155, 157>, 0,
    <158, 157, 151>, 0,
    <158, 151, 152>, 0,
    <162, 156, 121>, 0,
    <162, 121, 127>, 0,
    <162, 127, 125>, 0,
    <162, 125, 160>, 0,
    <162, 160, 159>, 0,
    <162, 159, 161>, 0,
    <162, 161, 155>, 0,
    <162, 155, 156>, 0,
    <166, 160, 125>, 0,
    <166, 125, 131>, 0,
    <166, 131, 129>, 0,
    <166, 129, 164>, 0,
    <166, 164, 163>, 0,
    <166, 163, 165>, 0,
    <166, 165, 159>, 0,
    <166, 159, 160>, 0,
    <170, 164, 129>, 0,
    <170, 129, 135>, 0,
    <170, 135, 133>, 0,
    <170, 133, 168>, 0,
    <170, 168, 167>, 0,
    <170, 167, 169>, 0,
    <170, 169, 163>, 0,
    <170, 163, 164>, 0,
    <176, 175, 138>, 0,
    <176, 138, 140>, 0,
    <176, 140, 137>, 0,
    <176, 137, 173>, 0,
    <176, 173, 171>, 0,
    <176, 171, 174>, 0,
    <176, 174, 172>, 0,
    <176, 172, 175>, 0,
    <180, 173, 137>, 0,
    <180, 137, 145>, 0,
    <180, 145, 143>, 0,
    <180, 143, 178>, 0,
    <180, 178, 177>, 0,
    <180, 177, 179>, 0,
    <180, 179, 171>, 0,
    <180, 171, 173>, 0,
    <184, 178, 143>, 0,
    <184, 143, 149>, 0,
    <184, 149, 147>, 0,
    <184, 147, 182>, 0,
    <184, 182, 181>, 0,
    <184, 181, 183>, 0,
    <184, 183, 177>, 0,
    <184, 177, 178>, 0,
    <188, 182, 147>, 0,
    <188, 147, 153>, 0,
    <188, 153, 151>, 0,
    <188, 151, 186>, 0,
    <188, 186, 185>, 0,
    <188, 185, 187>, 0,
    <188, 187, 181>, 0,
    <188, 181, 182>, 0,
    <192, 186, 151>, 0,
    <192, 151, 157>, 0,
    <192, 157, 155>, 0,
    <192, 155, 190>, 0,
    <192, 190, 189>, 0,
    <192, 189, 191>, 0,
    <192, 191, 185>, 0,
    <192, 185, 186>, 0,
    <196, 190, 155>, 0,
    <196, 155, 161>, 0,
    <196, 161, 159>, 0,
    <196, 159, 194>, 0,
    <196, 194, 193>, 0,
    <196, 193, 195>, 0,
    <196, 195, 189>, 0,
    <196, 189, 190>, 0,
    <200, 194, 159>, 0,
    <200, 159, 165>, 0,
    <200, 165, 163>, 0,
    <200, 163, 198>, 0,
    <200, 198, 197>, 0,
    <200, 197, 199>, 0,
    <200, 199, 193>, 0,
    <200, 193, 194>, 0,
    <204, 198, 163>, 0,
    <204, 163, 169>, 0,
    <204, 169, 167>, 0,
    <204, 167, 202>, 0,
    <204, 202, 201>, 0,
    <204, 201, 203>, 0,
    <204, 203, 197>, 0,
    <204, 197, 198>, 0,
    <210, 209, 172>, 0,
    <210, 172, 174>, 0,
    <210, 174, 171>, 0,
    <210, 171, 207>, 0,
    <210, 207, 205>, 0,
    <210, 205, 208>, 0,
    <210, 208, 206>, 0,
    <210, 206, 209>, 0,
    <214, 207, 171>, 0,
    <214, 171, 179>, 0,
    <214, 179, 177>, 0,
    <214, 177, 212>, 0,
    <214, 212, 211>, 0,
    <214, 211, 213>, 0,
    <214, 213, 205>, 0,
    <214, 205, 207>, 0,
    <218, 212, 177>, 0,
    <218, 177, 183>, 0,
    <218, 183, 181>, 0,
    <218, 181, 216>, 0,
    <218, 216, 215>, 0,
    <218, 215, 217>, 0,
    <218, 217, 211>, 0,
    <218, 211, 212>, 0,
    <222, 216, 181>, 0,
    <222, 181, 187>, 0,
    <222, 187, 185>, 0,
    <222, 185, 220>, 0,
    <222, 220, 219>, 0,
    <222, 219, 221>, 0,
    <222, 221, 215>, 0,
    <222, 215, 216>, 0,
    <226, 220, 185>, 0,
    <226, 185, 191>, 0,
    <226, 191, 189>, 0,
    <226, 189, 224>, 0,
    <226, 224, 223>, 0,
    <226, 223, 225>, 0,
    <226, 225, 219>, 0,
    <226, 219, 220>, 0,
    <230, 224, 189>, 0,
    <230, 189, 195>, 0,
    <230, 195, 193>, 0,
    <230, 193, 228>, 0,
    <230, 228, 227>, 0,
    <230, 227, 229>, 0,
    <230, 229, 223>, 0,
    <230, 223, 224>, 0,
    <234, 228, 193>, 0,
    <234, 193, 199>, 0,
    <234, 199, 197>, 0,
    <234, 197, 232>, 0,
    <234, 232, 231>, 0,
    <234, 231, 233>, 0,
    <234, 233, 227>, 0,
    <234, 227, 228>, 0,
    <238, 232, 197>, 0,
    <238, 197, 203>, 0,
    <238, 203, 201>, 0,
    <238, 201, 236>, 0,
    <238, 236, 235>, 0,
    <238, 235, 237>, 0,
    <238, 237, 231>, 0,
    <238, 231, 232>, 0,
    <244, 243, 206>, 0,
    <244, 206, 208>, 0,
    <244, 208, 205>, 0,
    <244, 205, 241>, 0,
    <244, 241, 239>, 0,
    <244, 239, 242>, 0,
    <244, 242, 240>, 0,
    <244, 240, 243>, 0,
    <248, 241, 205>, 0,
    <248, 205, 213>, 0,
    <248, 213, 211>, 0,
    <248, 211, 246>, 0,
    <248, 246, 245>, 0,
    <248, 245, 247>, 0,
    <248, 247, 239>, 0,
    <248, 239, 241>, 0,
    <252, 246, 211>, 0,
    <252, 211, 217>, 0,
    <252, 217, 215>, 0,
    <252, 215, 250>, 0,
    <252, 250, 249>, 0,
    <252, 249, 251>, 0,
    <252, 251, 245>, 0,
    <252, 245, 246>, 0,
    <256, 250, 215>, 0,
    <256, 215, 221>, 0,
    <256, 221, 219>, 0,
    <256, 219, 254>, 0,
    <256, 254, 253>, 0,
    <256, 253, 255>, 0,
    <256, 255, 249>, 0,
    <256, 249, 250>, 0,
    <260, 254, 219>, 0,
    <260, 219, 225>, 0,
    <260, 225, 223>, 0,
    <260, 223, 258>, 0,
    <260, 258, 257>, 0,
    <260, 257, 259>, 0,
    <260, 259, 253>, 0,
    <260, 253, 254>, 0,
    <264, 258, 223>, 0,
    <264, 223, 229>, 0,
    <264, 229, 227>, 0,
    <264, 227, 262>, 0,
    <264, 262, 261>, 0,
    <264, 261, 263>, 0,
    <264, 263, 257>, 0,
    <264, 257, 258>, 0,
    <268, 262, 227>, 0,
    <268, 227, 233>, 0,
    <268, 233, 231>, 0,
    <268, 231, 266>, 0,
    <268, 266, 265>, 0,
    <268, 265, 267>, 0,
    <268, 267, 261>, 0,
    <268, 261, 262>, 0,
    <272, 266, 231>, 0,
    <272, 231, 237>, 0,
    <272, 237, 235>, 0,
    <272, 235, 270>, 0,
    <272, 270, 269>, 0,
    <272, 269, 271>, 0,
    <272, 271, 265>, 0,
    <272, 265, 266>, 0,
    <276, 32, 0>, 0,
    <276, 0, 274>, 0,
    <276, 274, 273>, 0,
    <276, 273, 275>, 0,
    <276, 275, 31>, 0,
    <276, 31, 32>, 0,
    <280, 274, 0>, 0,
    <280, 0, 278>, 0,
    <280, 278, 277>, 0,
    <280, 277, 279>, 0,
    <280, 279, 273>, 0,
    <280, 273, 274>, 0,
    <284, 278, 0>, 0,
    <284, 0, 282>, 0,
    <284, 282, 281>, 0,
    <284, 281, 283>, 0,
    <284, 283, 277>, 0,
    <284, 277, 278>, 0,
    <288, 282, 0>, 0,
    <288, 0, 286>, 0,
    <288, 286, 285>, 0,
    <288, 285, 287>, 0,
    <288, 287, 281>, 0,
    <288, 281, 282>, 0,
    <292, 286, 0>, 0,
    <292, 0, 290>, 0,
    <292, 290, 289>, 0,
    <292, 289, 291>, 0,
    <292, 291, 285>, 0,
    <292, 285, 286>, 0,
    <296, 290, 0>, 0,
    <296, 0, 294>, 0,
    <296, 294, 293>, 0,
    <296, 293, 295>, 0,
    <296, 295, 289>, 0,
    <296, 289, 290>, 0,
    <300, 294, 0>, 0,
    <300, 0, 298>, 0,
    <300, 298, 297>, 0,
    <300, 297, 299>, 0,
    <300, 299, 293>, 0,
    <300, 293, 294>, 0,
    <302, 298, 0>, 0,
    <302, 0, 5>, 0,
    <302, 5, 2>, 0,
    <302, 2, 301>, 0,
    <302, 301, 297>, 0,
    <302, 297, 298>, 0,
    <306, 66, 31>, 0,
    <306, 31, 275>, 0,
    <306, 275, 273>, 0,
    <306, 273, 304>, 0,
    <306, 304, 303>, 0,
    <306, 303, 305>, 0,
    <306, 305, 65>, 0,
    <306, 65, 66>, 0,
    <310, 304, 273>, 0,
    <310, 273, 279>, 0,
    <310, 279, 277>, 0,
    <310, 277, 308>, 0,
    <310, 308, 307>, 0,
    <310, 307, 309>, 0,
    <310, 309, 303>, 0,
    <310, 303, 304>, 0,
    <314, 308, 277>, 0,
    <314, 277, 283>, 0,
    <314, 283, 281>, 0,
    <314, 281, 312>, 0,
    <314, 312, 311>, 0,
    <314, 311, 313>, 0,
    <314, 313, 307>, 0,
    <314, 307, 308>, 0,
    <318, 312, 281>, 0,
    <318, 281, 287>, 0,
    <318, 287, 285>, 0,
    <318, 285, 316>, 0,
    <318, 316, 315>, 0,
    <318, 315, 317>, 0,
    <318, 317, 311>, 0,
    <318, 311, 312>, 0,
    <322, 316, 285>, 0,
    <322, 285, 291>, 0,
    <322, 291, 289>, 0,
    <322, 289, 320>, 0,
    <322, 320, 319>, 0,
    <322, 319, 321>, 0,
    <322, 321, 315>, 0,
    <322, 315, 316>, 0,
    <326, 320, 289>, 0,
    <326, 289, 295>, 0,
    <326, 295, 293>, 0,
    <326, 293, 324>, 0,
    <326, 324, 323>, 0,
    <326, 323, 325>, 0,
    <326, 325, 319>, 0,
    <326, 319, 320>, 0,
    <330, 324, 293>, 0,
    <330, 293, 299>, 0,
    <330, 299, 297>, 0,
    <330, 297, 328>, 0,
    <330, 328, 327>, 0,
    <330, 327, 329>, 0,
    <330, 329, 323>, 0,
    <330, 323, 324>, 0,
    <332, 328, 297>, 0,
    <332, 297, 301>, 0,
    <332, 301, 2>, 0,
    <332, 2, 39>, 0,
    <332, 39, 36>, 0,
    <332, 36, 331>, 0,
    <332, 331, 327>, 0,
    <332, 327, 328>, 0,
    <336, 100, 65>, 0,
    <336, 65, 305>, 0,
    <336, 305, 303>, 0,
    <336, 303, 334>, 0,
    <336, 334, 333>, 0,
    <336, 333, 335>, 0,
    <336, 335, 99>, 0,
    <336, 99, 100>, 0,
    <340, 334, 303>, 0,
    <340, 303, 309>, 0,
    <340, 309, 307>, 0,
    <340, 307, 338>, 0,
    <340, 338, 337>, 0,
    <340, 337, 339>, 0,
    <340, 339, 333>, 0,
    <340, 333, 334>, 0,
    <344, 338, 307>, 0,
    <344, 307, 313>, 0,
    <344, 313, 311>, 0,
    <344, 311, 342>, 0,
    <344, 342, 341>, 0,
    <344, 341, 343>, 0,
    <344, 343, 337>, 0,
    <344, 337, 338>, 0,
    <348, 342, 311>, 0,
    <348, 311, 317>, 0,
    <348, 317, 315>, 0,
    <348, 315, 346>, 0,
    <348, 346, 345>, 0,
    <348, 345, 347>, 0,
    <348, 347, 341>, 0,
    <348, 341, 342>, 0,
    <352, 346, 315>, 0,
    <352, 315, 321>, 0,
    <352, 321, 319>, 0,
    <352, 319, 350>, 0,
    <352, 350, 349>, 0,
    <352, 349, 351>, 0,
    <352, 351, 345>, 0,
    <352, 345, 346>, 0,
    <356, 350, 319>, 0,
    <356, 319, 325>, 0,
    <356, 325, 323>, 0,
    <356, 323, 354>, 0,
    <356, 354, 353>, 0,
    <356, 353, 355>, 0,
    <356, 355, 349>, 0,
    <356, 349, 350>, 0,
    <360, 354, 323>, 0,
    <360, 323, 329>, 0,
    <360, 329, 327>, 0,
    <360, 327, 358>, 0,
    <360, 358, 357>, 0,
    <360, 357, 359>, 0,
    <360, 359, 353>, 0,
    <360, 353, 354>, 0,
    <362, 358, 327>, 0,
    <362, 327, 331>, 0,
    <362, 331, 36>, 0,
    <362, 36, 73>, 0,
    <362, 73, 70>, 0,
    <362, 70, 361>, 0,
    <362, 361, 357>, 0,
    <362, 357, 358>, 0,
    <366, 134, 99>, 0,
    <366, 99, 335>, 0,
    <366, 335, 333>, 0,
    <366, 333, 364>, 0,
    <366, 364, 363>, 0,
    <366, 363, 365>, 0,
    <366, 365, 133>, 0,
    <366, 133, 134>, 0,
    <370, 364, 333>, 0,
    <370, 333, 339>, 0,
    <370, 339, 337>, 0,
    <370, 337, 368>, 0,
    <370, 368, 367>, 0,
    <370, 367, 369>, 0,
    <370, 369, 363>, 0,
    <370, 363, 364>, 0,
    <374, 368, 337>, 0,
    <374, 337, 343>, 0,
    <374, 343, 341>, 0,
    <374, 341, 372>, 0,
    <374, 372, 371>, 0,
    <374, 371, 373>, 0,
    <374, 373, 367>, 0,
    <374, 367, 368>, 0,
    <378, 372, 341>, 0,
    <378, 341, 347>, 0,
    <378, 347, 345>, 0,
    <378, 345, 376>, 0,
    <378, 376, 375>, 0,
    <378, 375, 377>, 0,
    <378, 377, 371>, 0,
    <378, 371, 372>, 0,
    <382, 376, 345>, 0,
    <382, 345, 351>, 0,
    <382, 351, 349>, 0,
    <382, 349, 380>, 0,
    <382, 380, 379>, 0,
    <382, 379, 381>, 0,
    <382, 381, 375>, 0,
    <382, 375, 376>, 0,
    <386, 380, 349>, 0,
    <386, 349, 355>, 0,
    <386, 355, 353>, 0,
    <386, 353, 384>, 0,
    <386, 384, 383>, 0,
    <386, 383, 385>, 0,
    <386, 385, 379>, 0,
    <386, 379, 380>, 0,
    <390, 384, 353>, 0,
    <390, 353, 359>, 0,
    <390, 359, 357>, 0,
    <390, 357, 388>, 0,
    <390, 388, 387>, 0,
    <390, 387, 389>, 0,
    <390, 389, 383>, 0,
    <390, 383, 384>, 0,
    <392, 388, 357>, 0,
    <392, 357, 361>, 0,
    <392, 361, 70>, 0,
    <392, 70, 107>, 0,
    <392, 107, 104>, 0,
    <392, 104, 391>, 0,
    <392, 391, 387>, 0,
    <392, 387, 388>, 0,
    <396, 168, 133>, 0,
    <396, 133, 365>, 0,
    <396, 365, 363>, 0,
    <396, 363, 394>, 0,
    <396, 394, 393>, 0,
    <396, 393, 395>, 0,
    <396, 395, 167>, 0,
    <396, 167, 168>, 0,
    <400, 394, 363>, 0,
    <400, 363, 369>, 0,
    <400, 369, 367>, 0,
    <400, 367, 398>, 0,
    <400, 398, 397>, 0,
    <400, 397, 399>, 0,
    <400, 399, 393>, 0,
    <400, 393, 394>, 0,
    <404, 398, 367>, 0,
    <404, 367, 373>, 0,
    <404, 373, 371>, 0,
    <404, 371, 402>, 0,
    <404, 402, 401>, 0,
    <404, 401, 403>, 0,
    <404, 403, 397>, 0,
    <404, 397, 398>, 0,
    <408, 402, 371>, 0,
    <408, 371, 377>, 0,
    <408, 377, 375>, 0,
    <408, 375, 406>, 0,
    <408, 406, 405>, 0,
    <408, 405, 407>, 0,
    <408, 407, 401>, 0,
    <408, 401, 402>, 0,
    <412, 406, 375>, 0,
    <412, 375, 381>, 0,
    <412, 381, 379>, 0,
    <412, 379, 410>, 0,
    <412, 410, 409>, 0,
    <412, 409, 411>, 0,
    <412, 411, 405>, 0,
    <412, 405, 406>, 0,
    <416, 410, 379>, 0,
    <416, 379, 385>, 0,
    <416, 385, 383>, 0,
    <416, 383, 414>, 0,
    <416, 414, 413>, 0,
    <416, 413, 415>, 0,
    <416, 415, 409>, 0,
    <416, 409, 410>, 0,
    <420, 414, 383>, 0,
    <420, 383, 389>, 0,
    <420, 389, 387>, 0,
    <420, 387, 418>, 0,
    <420, 418, 417>, 0,
    <420, 417, 419>, 0,
    <420, 419, 413>, 0,
    <420, 413, 414>, 0,
    <422, 418, 387>, 0,
    <422, 387, 391>, 0,
    <422, 391, 104>, 0,
    <422, 104, 141>, 0,
    <422, 141, 138>, 0,
    <422, 138, 421>, 0,
    <422, 421, 417>, 0,
    <422, 417, 418>, 0,
    <426, 202, 167>, 0,
    <426, 167, 395>, 0,
    <426, 395, 393>, 0,
    <426, 393, 424>, 0,
    <426, 424, 423>, 0,
    <426, 423, 425>, 0,
    <426, 425, 201>, 0,
    <426, 201, 202>, 0,
    <430, 424, 393>, 0,
    <430, 393, 399>, 0,
    <430, 399, 397>, 0,
    <430, 397, 428>, 0,
    <430, 428, 427>, 0,
    <430, 427, 429>, 0,
    <430, 429, 423>, 0,
    <430, 423, 424>, 0,
    <434, 428, 397>, 0,
    <434, 397, 403>, 0,
    <434, 403, 401>, 0,
    <434, 401, 432>, 0,
    <434, 432, 431>, 0,
    <434, 431, 433>, 0,
    <434, 433, 427>, 0,
    <434, 427, 428>, 0,
    <438, 432, 401>, 0,
    <438, 401, 407>, 0,
    <438, 407, 405>, 0,
    <438, 405, 436>, 0,
    <438, 436, 435>, 0,
    <438, 435, 437>, 0,
    <438, 437, 431>, 0,
    <438, 431, 432>, 0,
    <442, 436, 405>, 0,
    <442, 405, 411>, 0,
    <442, 411, 409>, 0,
    <442, 409, 440>, 0,
    <442, 440, 439>, 0,
    <442, 439, 441>, 0,
    <442, 441, 435>, 0,
    <442, 435, 436>, 0,
    <446, 440, 409>, 0,
    <446, 409, 415>, 0,
    <446, 415, 413>, 0,
    <446, 413, 444>, 0,
    <446, 444, 443>, 0,
    <446, 443, 445>, 0,
    <446, 445, 439>, 0,
    <446, 439, 440>, 0,
    <450, 444, 413>, 0,
    <450, 413, 419>, 0,
    <450, 419, 417>, 0,
    <450, 417, 448>, 0,
    <450, 448, 447>, 0,
    <450, 447, 449>, 0,
    <450, 449, 443>, 0,
    <450, 443, 444>, 0,
    <452, 448, 417>, 0,
    <452, 417, 421>, 0,
    <452, 421, 138>, 0,
    <452, 138, 175>, 0,
    <452, 175, 172>, 0,
    <452, 172, 451>, 0,
    <452, 451, 447>, 0,
    <452, 447, 448>, 0,
    <456, 236, 201>, 0,
    <456, 201, 425>, 0,
    <456, 425, 423>, 0,
    <456, 423, 454>, 0,
    <456, 454, 453>, 0,
    <456, 453, 455>, 0,
    <456, 455, 235>, 0,
    <456, 235, 236>, 0,
    <460, 454, 423>, 0,
    <460, 423, 429>, 0,
    <460, 429, 427>, 0,
    <460, 427, 458>, 0,
    <460, 458, 457>, 0,
    <460, 457, 459>, 0,
    <460, 459, 453>, 0,
    <460, 453, 454>, 0,
    <464, 458, 427>, 0,
    <464, 427, 433>, 0,
    <464, 433, 431>, 0,
    <464, 431, 462>, 0,
    <464, 462, 461>, 0,
    <464, 461, 463>, 0,
    <464, 463, 457>, 0,
    <464, 457, 458>, 0,
    <468, 462, 431>, 0,
    <468, 431, 437>, 0,
    <468, 437, 435>, 0,
    <468, 435, 466>, 0,
    <468, 466, 465>, 0,
    <468, 465, 467>, 0,
    <468, 467, 461>, 0,
    <468, 461, 462>, 0,
    <472, 466, 435>, 0,
    <472, 435, 441>, 0,
    <472, 441, 439>, 0,
    <472, 439, 470>, 0,
    <472, 470, 469>, 0,
    <472, 469, 471>, 0,
    <472, 471, 465>, 0,
    <472, 465, 466>, 0,
    <476, 470, 439>, 0,
    <476, 439, 445>, 0,
    <476, 445, 443>, 0,
    <476, 443, 474>, 0,
    <476, 474, 473>, 0,
    <476, 473, 475>, 0,
    <476, 475, 469>, 0,
    <476, 469, 470>, 0,
    <480, 474, 443>, 0,
    <480, 443, 449>, 0,
    <480, 449, 447>, 0,
    <480, 447, 478>, 0,
    <480, 478, 477>, 0,
    <480, 477, 479>, 0,
    <480, 479, 473>, 0,
    <480, 473, 474>, 0,
    <482, 478, 447>, 0,
    <482, 447, 451>, 0,
    <482, 451, 172>, 0,
    <482, 172, 209>, 0,
    <482, 209, 206>, 0,
    <482, 206, 481>, 0,
    <482, 481, 477>, 0,
    <482, 477, 478>, 0,
    <486, 270, 235>, 0,
    <486, 235, 455>, 0,
    <486, 455, 453>, 0,
    <486, 453, 484>, 0,
    <486, 484, 483>, 0,
    <486, 483, 485>, 0,
    <486, 485, 269>, 0,
    <486, 269, 270>, 0,
    <490, 484, 453>, 0,
    <490, 453, 459>, 0,
    <490, 459, 457>, 0,
    <490, 457, 488>, 0,
    <490, 488, 487>, 0,
    <490, 487, 489>, 0,
    <490, 489, 483>, 0,
    <490, 483, 484>, 0,
    <494, 488, 457>, 0,
    <494, 457, 463>, 0,
    <494, 463, 461>, 0,
    <494, 461, 492>, 0,
    <494, 492, 491>, 0,
    <494, 491, 493>, 0,
    <494, 493, 487>, 0,
    <494, 487, 488>, 0,
    <498, 492, 461>, 0,
    <498, 461, 467>, 0,
    <498, 467, 465>, 0,
    <498, 465, 496>, 0,
    <498, 496, 495>, 0,
    <498, 495, 497>, 0,
    <498, 497, 491>, 0,
    <498, 491, 492>, 0,
    <502, 496, 465>, 0,
    <502, 465, 471>, 0,
    <502, 471, 469>, 0,
    <502, 469, 500>, 0,
    <502, 500, 499>, 0,
    <502, 499, 501>, 0,
    <502, 501, 495>, 0,
    <502, 495, 496>, 0,
    <506, 500, 469>, 0,
    <506, 469, 475>, 0,
    <506, 475, 473>, 0,
    <506, 473, 504>, 0,
    <506, 504, 503>, 0,
    <506, 503, 505>, 0,
    <506, 505, 499>, 0,
    <506, 499, 500>, 0,
    <510, 504, 473>, 0,
    <510, 473, 479>, 0,
    <510, 479, 477>, 0,
    <510, 477, 508>, 0,
    <510, 508, 507>, 0,
    <510, 507, 509>, 0,
    <510, 509, 503>, 0,
    <510, 503, 504>, 0,
    <512, 508, 477>, 0,
    <512, 477, 481>, 0,
    <512, 481, 206>, 0,
    <512, 206, 243>, 0,
    <512, 243, 240>, 0,
    <512, 240, 511>, 0,
    <512, 511, 507>, 0,
    <512, 507, 508>, 0,
    <518, 517, 240>, 0,
    <518, 240, 242>, 0,
    <518, 242, 239>, 0,
    <518, 239, 515>, 0,
    <518, 515, 513>, 0,
    <518, 513, 516>, 0,
    <518, 516, 514>, 0,
    <518, 514, 517>, 0,
    <522, 515, 239>, 0,
    <522, 239, 247>, 0,
    <522, 247, 245>, 0,
    <522, 245, 520>, 0,
    <522, 520, 519>, 0,
    <522, 519, 521>, 0,
    <522, 521, 513>, 0,
    <522, 513, 515>, 0,
    <526, 520, 245>, 0,
    <526, 245, 251>, 0,
    <526, 251, 249>, 0,
    <526, 249, 524>, 0,
    <526, 524, 523>, 0,
    <526, 523, 525>, 0,
    <526, 525, 519>, 0,
    <526, 519, 520>, 0,
    <530, 524, 249>, 0,
    <530, 249, 255>, 0,
    <530, 255, 253>, 0,
    <530, 253, 528>, 0,
    <530, 528, 527>, 0,
    <530, 527, 529>, 0,
    <530, 529, 523>, 0,
    <530, 523, 524>, 0,
    <534, 528, 253>, 0,
    <534, 253, 259>, 0,
    <534, 259, 257>, 0,
    <534, 257, 532>, 0,
    <534, 532, 531>, 0,
    <534, 531, 533>, 0,
    <534, 533, 527>, 0,
    <534, 527, 528>, 0,
    <538, 532, 257>, 0,
    <538, 257, 263>, 0,
    <538, 263, 261>, 0,
    <538, 261, 536>, 0,
    <538, 536, 535>, 0,
    <538, 535, 537>, 0,
    <538, 537, 531>, 0,
    <538, 531, 532>, 0,
    <542, 536, 261>, 0,
    <542, 261, 267>, 0,
    <542, 267, 265>, 0,
    <542, 265, 540>, 0,
    <542, 540, 539>, 0,
    <542, 539, 541>, 0,
    <542, 541, 535>, 0,
    <542, 535, 536>, 0,
    <546, 540, 265>, 0,
    <546, 265, 271>, 0,
    <546, 271, 269>, 0,
    <546, 269, 544>, 0,
    <546, 544, 543>, 0,
    <546, 543, 545>, 0,
    <546, 545, 539>, 0,
    <546, 539, 540>, 0,
    <552, 551, 514>, 0,
    <552, 514, 516>, 0,
    <552, 516, 513>, 0,
    <552, 513, 549>, 0,
    <552, 549, 547>, 0,
    <552, 547, 550>, 0,
    <552, 550, 548>, 0,
    <552, 548, 551>, 0,
    <556, 549, 513>, 0,
    <556, 513, 521>, 0,
    <556, 521, 519>, 0,
    <556, 519, 554>, 0,
    <556, 554, 553>, 0,
    <556, 553, 555>, 0,
    <556, 555, 547>, 0,
    <556, 547, 549>, 0,
    <560, 554, 519>, 0,
    <560, 519, 525>, 0,
    <560, 525, 523>, 0,
    <560, 523, 558>, 0,
    <560, 558, 557>, 0,
    <560, 557, 559>, 0,
    <560, 559, 553>, 0,
    <560, 553, 554>, 0,
    <564, 558, 523>, 0,
    <564, 523, 529>, 0,
    <564, 529, 527>, 0,
    <564, 527, 562>, 0,
    <564, 562, 561>, 0,
    <564, 561, 563>, 0,
    <564, 563, 557>, 0,
    <564, 557, 558>, 0,
    <568, 562, 527>, 0,
    <568, 527, 533>, 0,
    <568, 533, 531>, 0,
    <568, 531, 566>, 0,
    <568, 566, 565>, 0,
    <568, 565, 567>, 0,
    <568, 567, 561>, 0,
    <568, 561, 562>, 0,
    <572, 566, 531>, 0,
    <572, 531, 537>, 0,
    <572, 537, 535>, 0,
    <572, 535, 570>, 0,
    <572, 570, 569>, 0,
    <572, 569, 571>, 0,
    <572, 571, 565>, 0,
    <572, 565, 566>, 0,
    <576, 570, 535>, 0,
    <576, 535, 541>, 0,
    <576, 541, 539>, 0,
    <576, 539, 574>, 0,
    <576, 574, 573>, 0,
    <576, 573, 575>, 0,
    <576, 575, 569>, 0,
    <576, 569, 570>, 0,
    <580, 574, 539>, 0,
    <580, 539, 545>, 0,
    <580, 545, 543>, 0,
    <580, 543, 578>, 0,
    <580, 578, 577>, 0,
    <580, 577, 579>, 0,
    <580, 579, 573>, 0,
    <580, 573, 574>, 0,
    <586, 585, 548>, 0,
    <586, 548, 550>, 0,
    <586, 550, 547>, 0,
    <586, 547, 583>, 0,
    <586, 583, 581>, 0,
    <586, 581, 584>, 0,
    <586, 584, 582>, 0,
    <586, 582, 585>, 0,
    <590, 583, 547>, 0,
    <590, 547, 555>, 0,
    <590, 555, 553>, 0,
    <590, 553, 588>, 0,
    <590, 588, 587>, 0,
    <590, 587, 589>, 0,
    <590, 589, 581>, 0,
    <590, 581, 583>, 0,
    <594, 588, 553>, 0,
    <594, 553, 559>, 0,
    <594, 559, 557>, 0,
    <594, 557, 592>, 0,
    <594, 592, 591>, 0,
    <594, 591, 593>, 0,
    <594, 593, 587>, 0,
    <594, 587, 588>, 0,
    <598, 592, 557>, 0,
    <598, 557, 563>, 0,
    <598, 563, 561>, 0,
    <598, 561, 596>, 0,
    <598, 596, 595>, 0,
    <598, 595, 597>, 0,
    <598, 597, 591>, 0,
    <598, 591, 592>, 0,
    <602, 596, 561>, 0,
    <602, 561, 567>, 0,
    <602, 567, 565>, 0,
    <602, 565, 600>, 0,
    <602, 600, 599>, 0,
    <602, 599, 601>, 0,
    <602, 601, 595>, 0,
    <602, 595, 596>, 0,
    <606, 600, 565>, 0,
    <606, 565, 571>, 0,
    <606, 571, 569>, 0,
    <606, 569, 604>, 0,
    <606, 604, 603>, 0,
    <606, 603, 605>, 0,
    <606, 605, 599>, 0,
    <606, 599, 600>, 0,
    <610, 604, 569>, 0,
    <610, 569, 575>, 0,
    <610, 575, 573>, 0,
    <610, 573, 608>, 0,
    <610, 608, 607>, 0,
    <610, 607, 609>, 0,
    <610, 609, 603>, 0,
    <610, 603, 604>, 0,
    <614, 608, 573>, 0,
    <614, 573, 579>, 0,
    <614, 579, 577>, 0,
    <614, 577, 612>, 0,
    <614, 612, 611>, 0,
    <614, 611, 613>, 0,
    <614, 613, 607>, 0,
    <614, 607, 608>, 0,
    <620, 619, 582>, 0,
    <620, 582, 584>, 0,
    <620, 584, 581>, 0,
    <620, 581, 617>, 0,
    <620, 617, 615>, 0,
    <620, 615, 618>, 0,
    <620, 618, 616>, 0,
    <620, 616, 619>, 0,
    <624, 617, 581>, 0,
    <624, 581, 589>, 0,
    <624, 589, 587>, 0,
    <624, 587, 622>, 0,
    <624, 622, 621>, 0,
    <624, 621, 623>, 0,
    <624, 623, 615>, 0,
    <624, 615, 617>, 0,
    <628, 622, 587>, 0,
    <628, 587, 593>, 0,
    <628, 593, 591>, 0,
    <628, 591, 626>, 0,
    <628, 626, 625>, 0,
    <628, 625, 627>, 0,
    <628, 627, 621>, 0,
    <628, 621, 622>, 0,
    <632, 626, 591>, 0,
    <632, 591, 597>, 0,
    <632, 597, 595>, 0,
    <632, 595, 630>, 0,
    <632, 630, 629>, 0,
    <632, 629, 631>, 0,
    <632, 631, 625>, 0,
    <632, 625, 626>, 0,
    <636, 630, 595>, 0,
    <636, 595, 601>, 0,
    <636, 601, 599>, 0,
    <636, 599, 634>, 0,
    <636, 634, 633>, 0,
    <636, 633, 635>, 0,
    <636, 635, 629>, 0,
    <636, 629, 630>, 0,
    <640, 634, 599>, 0,
    <640, 599, 605>, 0,
    <640, 605, 603>, 0,
    <640, 603, 638>, 0,
    <640, 638, 637>, 0,
    <640, 637, 639>, 0,
    <640, 639, 633>, 0,
    <640, 633, 634>, 0,
    <644, 638, 603>, 0,
    <644, 603, 609>, 0,
    <644, 609, 607>, 0,
    <644, 607, 642>, 0,
    <644, 642, 641>, 0,
    <644, 641, 643>, 0,
    <644, 643, 637>, 0,
    <644, 637, 638>, 0,
    <648, 642, 607>, 0,
    <648, 607, 613>, 0,
    <648, 613, 611>, 0,
    <648, 611, 646>, 0,
    <648, 646, 645>, 0,
    <648, 645, 647>, 0,
    <648, 647, 641>, 0,
    <648, 641, 642>, 0,
    <654, 653, 616>, 0,
    <654, 616, 618>, 0,
    <654, 618, 615>, 0,
    <654, 615, 651>, 0,
    <654, 651, 649>, 0,
    <654, 649, 652>, 0,
    <654, 652, 650>, 0,
    <654, 650, 653>, 0,
    <658, 651, 615>, 0,
    <658, 615, 623>, 0,
    <658, 623, 621>, 0,
    <658, 621, 656>, 0,
    <658, 656, 655>, 0,
    <658, 655, 657>, 0,
    <658, 657, 649>, 0,
    <658, 649, 651>, 0,
    <662, 656, 621>, 0,
    <662, 621, 627>, 0,
    <662, 627, 625>, 0,
    <662, 625, 660>, 0,
    <662, 660, 659>, 0,
    <662, 659, 661>, 0,
    <662, 661, 655>, 0,
    <662, 655, 656>, 0,
    <666, 660, 625>, 0,
    <666, 625, 631>, 0,
    <666, 631, 629>, 0,
    <666, 629, 664>, 0,
    <666, 664, 663>, 0,
    <666, 663, 665>, 0,
    <666, 665, 659>, 0,
    <666, 659, 660>, 0,
    <670, 664, 629>, 0,
    <670, 629, 635>, 0,
    <670, 635, 633>, 0,
    <670, 633, 668>, 0,
    <670, 668, 667>, 0,
    <670, 667, 669>, 0,
    <670, 669, 663>, 0,
    <670, 663, 664>, 0,
    <674, 668, 633>, 0,
    <674, 633, 639>, 0,
    <674, 639, 637>, 0,
    <674, 637, 672>, 0,
    <674, 672, 671>, 0,
    <674, 671, 673>, 0,
    <674, 673, 667>, 0,
    <674, 667, 668>, 0,
    <678, 672, 637>, 0,
    <678, 637, 643>, 0,
    <678, 643, 641>, 0,
    <678, 641, 676>, 0,
    <678, 676, 675>, 0,
    <678, 675, 677>, 0,
    <678, 677, 671>, 0,
    <678, 671, 672>, 0,
    <682, 676, 641>, 0,
    <682, 641, 647>, 0,
    <682, 647, 645>, 0,
    <682, 645, 680>, 0,
    <682, 680, 679>, 0,
    <682, 679, 681>, 0,
    <682, 681, 675>, 0,
    <682, 675, 676>, 0,
    <688, 687, 650>, 0,
    <688, 650, 652>, 0,
    <688, 652, 649>, 0,
    <688, 649, 685>, 0,
    <688, 685, 683>, 0,
    <688, 683, 686>, 0,
    <688, 686, 684>, 0,
    <688, 684, 687>, 0,
    <692, 685, 649>, 0,
    <692, 649, 657>, 0,
    <692, 657, 655>, 0,
    <692, 655, 690>, 0,
    <692, 690, 689>, 0,
    <692, 689, 691>, 0,
    <692, 691, 683>, 0,
    <692, 683, 685>, 0,
    <696, 690, 655>, 0,
    <696, 655, 661>, 0,
    <696, 661, 659>, 0,
    <696, 659, 694>, 0,
    <696, 694, 693>, 0,
    <696, 693, 695>, 0,
    <696, 695, 689>, 0,
    <696, 689, 690>, 0,
    <700, 694, 659>, 0,
    <700, 659, 665>, 0,
    <700, 665, 663>, 0,
    <700, 663, 698>, 0,
    <700, 698, 697>, 0,
    <700, 697, 699>, 0,
    <700, 699, 693>, 0,
    <700, 693, 694>, 0,
    <704, 698, 663>, 0,
    <704, 663, 669>, 0,
    <704, 669, 667>, 0,
    <704, 667, 702>, 0,
    <704, 702, 701>, 0,
    <704, 701, 703>, 0,
    <704, 703, 697>, 0,
    <704, 697, 698>, 0,
    <708, 702, 667>, 0,
    <708, 667, 673>, 0,
    <708, 673, 671>, 0,
    <708, 671, 706>, 0,
    <708, 706, 705>, 0,
    <708, 705, 707>, 0,
    <708, 707, 701>, 0,
    <708, 701, 702>, 0,
    <712, 706, 671>, 0,
    <712, 671, 677>, 0,
    <712, 677, 675>, 0,
    <712, 675, 710>, 0,
    <712, 710, 709>, 0,
    <712, 709, 711>, 0,
    <712, 711, 705>, 0,
    <712, 705, 706>, 0,
    <716, 710, 675>, 0,
    <716, 675, 681>, 0,
    <716, 681, 679>, 0,
    <716, 679, 714>, 0,
    <716, 714, 713>, 0,
    <716, 713, 715>, 0,
    <716, 715, 709>, 0,
    <716, 709, 710>, 0,
    <722, 721, 684>, 0,
    <722, 684, 686>, 0,
    <722, 686, 683>, 0,
    <722, 683, 719>, 0,
    <722, 719, 717>, 0,
    <722, 717, 720>, 0,
    <722, 720, 718>, 0,
    <722, 718, 721>, 0,
    <726, 719, 683>, 0,
    <726, 683, 691>, 0,
    <726, 691, 689>, 0,
    <726, 689, 724>, 0,
    <726, 724, 723>, 0,
    <726, 723, 725>, 0,
    <726, 725, 717>, 0,
    <726, 717, 719>, 0,
    <730, 724, 689>, 0,
    <730, 689, 695>, 0,
    <730, 695, 693>, 0,
    <730, 693, 728>, 0,
    <730, 728, 727>, 0,
    <730, 727, 729>, 0,
    <730, 729, 723>, 0,
    <730, 723, 724>, 0,
    <734, 728, 693>, 0,
    <734, 693, 699>, 0,
    <734, 699, 697>, 0,
    <734, 697, 732>, 0,
    <734, 732, 731>, 0,
    <734, 731, 733>, 0,
    <734, 733, 727>, 0,
    <734, 727, 728>, 0,
    <738, 732, 697>, 0,
    <738, 697, 703>, 0,
    <738, 703, 701>, 0,
    <738, 701, 736>, 0,
    <738, 736, 735>, 0,
    <738, 735, 737>, 0,
    <738, 737, 731>, 0,
    <738, 731, 732>, 0,
    <742, 736, 701>, 0,
    <742, 701, 707>, 0,
    <742, 707, 705>, 0,
    <742, 705, 740>, 0,
    <742, 740, 739>, 0,
    <742, 739, 741>, 0,
    <742, 741, 735>, 0,
    <742, 735, 736>, 0,
    <746, 740, 705>, 0,
    <746, 705, 711>, 0,
    <746, 711, 709>, 0,
    <746, 709, 744>, 0,
    <746, 744, 743>, 0,
    <746, 743, 745>, 0,
    <746, 745, 739>, 0,
    <746, 739, 740>, 0,
    <750, 744, 709>, 0,
    <750, 709, 715>, 0,
    <750, 715, 713>, 0,
    <750, 713, 748>, 0,
    <750, 748, 747>, 0,
    <750, 747, 749>, 0,
    <750, 749, 743>, 0,
    <750, 743, 744>, 0,
    <756, 755, 718>, 0,
    <756, 718, 720>, 0,
    <756, 720, 717>, 0,
    <756, 717, 753>, 0,
    <756, 753, 751>, 0,
    <756, 751, 754>, 0,
    <756, 754, 752>, 0,
    <756, 752, 755>, 0,
    <760, 753, 717>, 0,
    <760, 717, 725>, 0,
    <760, 725, 723>, 0,
    <760, 723, 758>, 0,
    <760, 758, 757>, 0,
    <760, 757, 759>, 0,
    <760, 759, 751>, 0,
    <760, 751, 753>, 0,
    <764, 758, 723>, 0,
    <764, 723, 729>, 0,
    <764, 729, 727>, 0,
    <764, 727, 762>, 0,
    <764, 762, 761>, 0,
    <764, 761, 763>, 0,
    <764, 763, 757>, 0,
    <764, 757, 758>, 0,
    <768, 762, 727>, 0,
    <768, 727, 733>, 0,
    <768, 733, 731>, 0,
    <768, 731, 766>, 0,
    <768, 766, 765>, 0,
    <768, 765, 767>, 0,
    <768, 767, 761>, 0,
    <768, 761, 762>, 0,
    <772, 766, 731>, 0,
    <772, 731, 737>, 0,
    <772, 737, 735>, 0,
    <772, 735, 770>, 0,
    <772, 770, 769>, 0,
    <772, 769, 771>, 0,
    <772, 771, 765>, 0,
    <772, 765, 766>, 0,
    <776, 770, 735>, 0,
    <776, 735, 741>, 0,
    <776, 741, 739>, 0,
    <776, 739, 774>, 0,
    <776, 774, 773>, 0,
    <776, 773, 775>, 0,
    <776, 775, 769>, 0,
    <776, 769, 770>, 0,
    <780, 774, 739>, 0,
    <780, 739, 745>, 0,
    <780, 745, 743>, 0,
    <780, 743, 778>, 0,
    <780, 778, 777>, 0,
    <780, 777, 779>, 0,
    <780, 779, 773>, 0,
    <780, 773, 774>, 0,
    <784, 778, 743>, 0,
    <784, 743, 749>, 0,
    <784, 749, 747>, 0,
    <784, 747, 782>, 0,
    <784, 782, 781>, 0,
    <784, 781, 783>, 0,
    <784, 783, 777>, 0,
    <784, 777, 778>, 0,
    <788, 544, 269>, 0,
    <788, 269, 485>, 0,
    <788, 485, 483>, 0,
    <788, 483, 786>, 0,
    <788, 786, 785>, 0,
    <788, 785, 787>, 0,
    <788, 787, 543>, 0,
    <788, 543, 544>, 0,
    <792, 786, 483>, 0,
    <792, 483, 489>, 0,
    <792, 489, 487>, 0,
    <792, 487, 790>, 0,
    <792, 790, 789>, 0,
    <792, 789, 791>, 0,
    <792, 791, 785>, 0,
    <792, 785, 786>, 0,
    <796, 790, 487>, 0,
    <796, 487, 493>, 0,
    <796, 493, 491>, 0,
    <796, 491, 794>, 0,
    <796, 794, 793>, 0,
    <796, 793, 795>, 0,
    <796, 795, 789>, 0,
    <796, 789, 790>, 0,
    <800, 794, 491>, 0,
    <800, 491, 497>, 0,
    <800, 497, 495>, 0,
    <800, 495, 798>, 0,
    <800, 798, 797>, 0,
    <800, 797, 799>, 0,
    <800, 799, 793>, 0,
    <800, 793, 794>, 0,
    <804, 798, 495>, 0,
    <804, 495, 501>, 0,
    <804, 501, 499>, 0,
    <804, 499, 802>, 0,
    <804, 802, 801>, 0,
    <804, 801, 803>, 0,
    <804, 803, 797>, 0,
    <804, 797, 798>, 0,
    <808, 802, 499>, 0,
    <808, 499, 505>, 0,
    <808, 505, 503>, 0,
    <808, 503, 806>, 0,
    <808, 806, 805>, 0,
    <808, 805, 807>, 0,
    <808, 807, 801>, 0,
    <808, 801, 802>, 0,
    <812, 806, 503>, 0,
    <812, 503, 509>, 0,
    <812, 509, 507>, 0,
    <812, 507, 810>, 0,
    <812, 810, 809>, 0,
    <812, 809, 811>, 0,
    <812, 811, 805>, 0,
    <812, 805, 806>, 0,
    <814, 810, 507>, 0,
    <814, 507, 511>, 0,
    <814, 511, 240>, 0,
    <814, 240, 517>, 0,
    <814, 517, 514>, 0,
    <814, 514, 813>, 0,
    <814, 813, 809>, 0,
    <814, 809, 810>, 0,
    <818, 578, 543>, 0,
    <818, 543, 787>, 0,
    <818, 787, 785>, 0,
    <818, 785, 816>, 0,
    <818, 816, 815>, 0,
    <818, 815, 817>, 0,
    <818, 817, 577>, 0,
    <818, 577, 578>, 0,
    <822, 816, 785>, 0,
    <822, 785, 791>, 0,
    <822, 791, 789>, 0,
    <822, 789, 820>, 0,
    <822, 820, 819>, 0,
    <822, 819, 821>, 0,
    <822, 821, 815>, 0,
    <822, 815, 816>, 0,
    <826, 820, 789>, 0,
    <826, 789, 795>, 0,
    <826, 795, 793>, 0,
    <826, 793, 824>, 0,
    <826, 824, 823>, 0,
    <826, 823, 825>, 0,
    <826, 825, 819>, 0,
    <826, 819, 820>, 0,
    <830, 824, 793>, 0,
    <830, 793, 799>, 0,
    <830, 799, 797>, 0,
    <830, 797, 828>, 0,
    <830, 828, 827>, 0,
    <830, 827, 829>, 0,
    <830, 829, 823>, 0,
    <830, 823, 824>, 0,
    <834, 828, 797>, 0,
    <834, 797, 803>, 0,
    <834, 803, 801>, 0,
    <834, 801, 832>, 0,
    <834, 832, 831>, 0,
    <834, 831, 833>, 0,
    <834, 833, 827>, 0,
    <834, 827, 828>, 0,
    <838, 832, 801>, 0,
    <838, 801, 807>, 0,
    <838, 807, 805>, 0,
    <838, 805, 836>, 0,
    <838, 836, 835>, 0,
    <838, 835, 837>, 0,
    <838, 837, 831>, 0,
    <838, 831, 832>, 0,
    <842, 836, 805>, 0,
    <842, 805, 811>, 0,
    <842, 811, 809>, 0,
    <842, 809, 840>, 0,
    <842, 840, 839>, 0,
    <842, 839, 841>, 0,
    <842, 841, 835>, 0,
    <842, 835, 836>, 0,
    <844, 840, 809>, 0,
    <844, 809, 813>, 0,
    <844, 813, 514>, 0,
    <844, 514, 551>, 0,
    <844, 551, 548>, 0,
    <844, 548, 843>, 0,
    <844, 843, 839>, 0,
    <844, 839, 840>, 0,
    <848, 612, 577>, 0,
    <848, 577, 817>, 0,
    <848, 817, 815>, 0,
    <848, 815, 846>, 0,
    <848, 846, 845>, 0,
    <848, 845, 847>, 0,
    <848, 847, 611>, 0,
    <848, 611, 612>, 0,
    <852, 846, 815>, 0,
    <852, 815, 821>, 0,
    <852, 821, 819>, 0,
    <852, 819, 850>, 0,
    <852, 850, 849>, 0,
    <852, 849, 851>, 0,
    <852, 851, 845>, 0,
    <852, 845, 846>, 0,
    <856, 850, 819>, 0,
    <856, 819, 825>, 0,
    <856, 825, 823>, 0,
    <856, 823, 854>, 0,
    <856, 854, 853>, 0,
    <856, 853, 855>, 0,
    <856, 855, 849>, 0,
    <856, 849, 850>, 0,
    <860, 854, 823>, 0,
    <860, 823, 829>, 0,
    <860, 829, 827>, 0,
    <860, 827, 858>, 0,
    <860, 858, 857>, 0,
    <860, 857, 859>, 0,
    <860, 859, 853>, 0,
    <860, 853, 854>, 0,
    <864, 858, 827>, 0,
    <864, 827, 833>, 0,
    <864, 833, 831>, 0,
    <864, 831, 862>, 0,
    <864, 862, 861>, 0,
    <864, 861, 863>, 0,
    <864, 863, 857>, 0,
    <864, 857, 858>, 0,
    <868, 862, 831>, 0,
    <868, 831, 837>, 0,
    <868, 837, 835>, 0,
    <868, 835, 866>, 0,
    <868, 866, 865>, 0,
    <868, 865, 867>, 0,
    <868, 867, 861>, 0,
    <868, 861, 862>, 0,
    <872, 866, 835>, 0,
    <872, 835, 841>, 0,
    <872, 841, 839>, 0,
    <872, 839, 870>, 0,
    <872, 870, 869>, 0,
    <872, 869, 871>, 0,
    <872, 871, 865>, 0,
    <872, 865, 866>, 0,
    <874, 870, 839>, 0,
    <874, 839, 843>, 0,
    <874, 843, 548>, 0,
    <874, 548, 585>, 0,
    <874, 585, 582>, 0,
    <874, 582, 873>, 0,
    <874, 873, 869>, 0,
    <874, 869, 870>, 0,
    <878, 646, 611>, 0,
    <878, 611, 847>, 0,
    <878, 847, 845>, 0,
    <878, 845, 876>, 0,
    <878, 876, 875>, 0,
    <878, 875, 877>, 0,
    <878, 877, 645>, 0,
    <878, 645, 646>, 0,
    <882, 876, 845>, 0,
    <882, 845, 851>, 0,
    <882, 851, 849>, 0,
    <882, 849, 880>, 0,
    <882, 880, 879>, 0,
    <882, 879, 881>, 0,
    <882, 881, 875>, 0,
    <882, 875, 876>, 0,
    <886, 880, 849>, 0,
    <886, 849, 855>, 0,
    <886, 855, 853>, 0,
    <886, 853, 884>, 0,
    <886, 884, 883>, 0,
    <886, 883, 885>, 0,
    <886, 885, 879>, 0,
    <886, 879, 880>, 0,
    <890, 884, 853>, 0,
    <890, 853, 859>, 0,
    <890, 859, 857>, 0,
    <890, 857, 888>, 0,
    <890, 888, 887>, 0,
    <890, 887, 889>, 0,
    <890, 889, 883>, 0,
    <890, 883, 884>, 0,
    <894, 888, 857>, 0,
    <894, 857, 863>, 0,
    <894, 863, 861>, 0,
    <894, 861, 892>, 0,
    <894, 892, 891>, 0,
    <894, 891, 893>, 0,
    <894, 893, 887>, 0,
    <894, 887, 888>, 0,
    <898, 892, 861>, 0,
    <898, 861, 867>, 0,
    <898, 867, 865>, 0,
    <898, 865, 896>, 0,
    <898, 896, 895>, 0,
    <898, 895, 897>, 0,
    <898, 897, 891>, 0,
    <898, 891, 892>, 0,
    <902, 896, 865>, 0,
    <902, 865, 871>, 0,
    <902, 871, 869>, 0,
    <902, 869, 900>, 0,
    <902, 900, 899>, 0,
    <902, 899, 901>, 0,
    <902, 901, 895>, 0,
    <902, 895, 896>, 0,
    <904, 900, 869>, 0,
    <904, 869, 873>, 0,
    <904, 873, 582>, 0,
    <904, 582, 619>, 0,
    <904, 619, 616>, 0,
    <904, 616, 903>, 0,
    <904, 903, 899>, 0,
    <904, 899, 900>, 0,
    <908, 680, 645>, 0,
    <908, 645, 877>, 0,
    <908, 877, 875>, 0,
    <908, 875, 906>, 0,
    <908, 906, 905>, 0,
    <908, 905, 907>, 0,
    <908, 907, 679>, 0,
    <908, 679, 680>, 0,
    <912, 906, 875>, 0,
    <912, 875, 881>, 0,
    <912, 881, 879>, 0,
    <912, 879, 910>, 0,
    <912, 910, 909>, 0,
    <912, 909, 911>, 0,
    <912, 911, 905>, 0,
    <912, 905, 906>, 0,
    <916, 910, 879>, 0,
    <916, 879, 885>, 0,
    <916, 885, 883>, 0,
    <916, 883, 914>, 0,
    <916, 914, 913>, 0,
    <916, 913, 915>, 0,
    <916, 915, 909>, 0,
    <916, 909, 910>, 0,
    <920, 914, 883>, 0,
    <920, 883, 889>, 0,
    <920, 889, 887>, 0,
    <920, 887, 918>, 0,
    <920, 918, 917>, 0,
    <920, 917, 919>, 0,
    <920, 919, 913>, 0,
    <920, 913, 914>, 0,
    <924, 918, 887>, 0,
    <924, 887, 893>, 0,
    <924, 893, 891>, 0,
    <924, 891, 922>, 0,
    <924, 922, 921>, 0,
    <924, 921, 923>, 0,
    <924, 923, 917>, 0,
    <924, 917, 918>, 0,
    <928, 922, 891>, 0,
    <928, 891, 897>, 0,
    <928, 897, 895>, 0,
    <928, 895, 926>, 0,
    <928, 926, 925>, 0,
    <928, 925, 927>, 0,
    <928, 927, 921>, 0,
    <928, 921, 922>, 0,
    <932, 926, 895>, 0,
    <932, 895, 901>, 0,
    <932, 901, 899>, 0,
    <932, 899, 930>, 0,
    <932, 930, 929>, 0,
    <932, 929, 931>, 0,
    <932, 931, 925>, 0,
    <932, 925, 926>, 0,
    <934, 930, 899>, 0,
    <934, 899, 903>, 0,
    <934, 903, 616>, 0,
    <934, 616, 653>, 0,
    <934, 653, 650>, 0,
    <934, 650, 933>, 0,
    <934, 933, 929>, 0,
    <934, 929, 930>, 0,
    <938, 714, 679>, 0,
    <938, 679, 907>, 0,
    <938, 907, 905>, 0,
    <938, 905, 936>, 0,
    <938, 936, 935>, 0,
    <938, 935, 937>, 0,
    <938, 937, 713>, 0,
    <938, 713, 714>, 0,
    <942, 936, 905>, 0,
    <942, 905, 911>, 0,
    <942, 911, 909>, 0,
    <942, 909, 940>, 0,
    <942, 940, 939>, 0,
    <942, 939, 941>, 0,
    <942, 941, 935>, 0,
    <942, 935, 936>, 0,
    <946, 940, 909>, 0,
    <946, 909, 915>, 0,
    <946, 915, 913>, 0,
    <946, 913, 944>, 0,
    <946, 944, 943>, 0,
    <946, 943, 945>, 0,
    <946, 945, 939>, 0,
    <946, 939, 940>, 0,
    <950, 944, 913>, 0,
    <950, 913, 919>, 0,
    <950, 919, 917>, 0,
    <950, 917, 948>, 0,
    <950, 948, 947>, 0,
    <950, 947, 949>, 0,
    <950, 949, 943>, 0,
    <950, 943, 944>, 0,
    <954, 948, 917>, 0,
    <954, 917, 923>, 0,
    <954, 923, 921>, 0,
    <954, 921, 952>, 0,
    <954, 952, 951>, 0,
    <954, 951, 953>, 0,
    <954, 953, 947>, 0,
    <954, 947, 948>, 0,
    <958, 952, 921>, 0,
    <958, 921, 927>, 0,
    <958, 927, 925>, 0,
    <958, 925, 956>, 0,
    <958, 956, 955>, 0,
    <958, 955, 957>, 0,
    <958, 957, 951>, 0,
    <958, 951, 952>, 0,
    <962, 956, 925>, 0,
    <962, 925, 931>, 0,
    <962, 931, 929>, 0,
    <962, 929, 960>, 0,
    <962, 960, 959>, 0,
    <962, 959, 961>, 0,
    <962, 961, 955>, 0,
    <962, 955, 956>, 0,
    <964, 960, 929>, 0,
    <964, 929, 933>, 0,
    <964, 933, 650>, 0,
    <964, 650, 687>, 0,
    <964, 687, 684>, 0,
    <964, 684, 963>, 0,
    <964, 963, 959>, 0,
    <964, 959, 960>, 0,
    <968, 748, 713>, 0,
    <968, 713, 937>, 0,
    <968, 937, 935>, 0,
    <968, 935, 966>, 0,
    <968, 966, 965>, 0,
    <968, 965, 967>, 0,
    <968, 967, 747>, 0,
    <968, 747, 748>, 0,
    <972, 966, 935>, 0,
    <972, 935, 941>, 0,
    <972, 941, 939>, 0,
    <972, 939, 970>, 0,
    <972, 970, 969>, 0,
    <972, 969, 971>, 0,
    <972, 971, 965>, 0,
    <972, 965, 966>, 0,
    <976, 970, 939>, 0,
    <976, 939, 945>, 0,
    <976, 945, 943>, 0,
    <976, 943, 974>, 0,
    <976, 974, 973>, 0,
    <976, 973, 975>, 0,
    <976, 975, 969>, 0,
    <976, 969, 970>, 0,
    <980, 974, 943>, 0,
    <980, 943, 949>, 0,
    <980, 949, 947>, 0,
    <980, 947, 978>, 0,
    <980, 978, 977>, 0,
    <980, 977, 979>, 0,
    <980, 979, 973>, 0,
    <980, 973, 974>, 0,
    <984, 978, 947>, 0,
    <984, 947, 953>, 0,
    <984, 953, 951>, 0,
    <984, 951, 982>, 0,
    <984, 982, 981>, 0,
    <984, 981, 983>, 0,
    <984, 983, 977>, 0,
    <984, 977, 978>, 0,
    <988, 982, 951>, 0,
    <988, 951, 957>, 0,
    <988, 957, 955>, 0,
    <988, 955, 986>, 0,
    <988, 986, 985>, 0,
    <988, 985, 987>, 0,
    <988, 987, 981>, 0,
    <988, 981, 982>, 0,
    <992, 986, 955>, 0,
    <992, 955, 961>, 0,
    <992, 961, 959>, 0,
    <992, 959, 990>, 0,
    <992, 990, 989>, 0,
    <992, 989, 991>, 0,
    <992, 991, 985>, 0,
    <992, 985, 986>, 0,
    <994, 990, 959>, 0,
    <994, 959, 963>, 0,
    <994, 963, 684>, 0,
    <994, 684, 721>, 0,
    <994, 721, 718>, 0,
    <994, 718, 993>, 0,
    <994, 993, 989>, 0,
    <994, 989, 990>, 0,
    <998, 782, 747>, 0,
    <998, 747, 967>, 0,
    <998, 967, 965>, 0,
    <998, 965, 996>, 0,
    <998, 996, 995>, 0,
    <998, 995, 997>, 0,
    <998, 997, 781>, 0,
    <998, 781, 782>, 0,
    <1002, 996, 965>, 0,
    <1002, 965, 971>, 0,
    <1002, 971, 969>, 0,
    <1002, 969, 1000>, 0,
    <1002, 1000, 999>, 0,
    <1002, 999, 1001>, 0,
    <1002, 1001, 995>, 0,
    <1002, 995, 996>, 0,
    <1006, 1000, 969>, 0,
    <1006, 969, 975>, 0,
    <1006, 975, 973>, 0,
    <1006, 973, 1004>, 0,
    <1006, 1004, 1003>, 0,
    <1006, 1003, 1005>, 0,
    <1006, 1005, 999>, 0,
    <1006, 999, 1000>, 0,
    <1010, 1004, 973>, 0,
    <1010, 973, 979>, 0,
    <1010, 979, 977>, 0,
    <1010, 977, 1008>, 0,
    <1010, 1008, 1007>, 0,
    <1010, 1007, 1009>, 0,
    <1010, 1009, 1003>, 0,
    <1010, 1003, 1004>, 0,
    <1014, 1008, 977>, 0,
    <1014, 977, 983>, 0,
    <1014, 983, 981>, 0,
    <1014, 981, 1012>, 0,
    <1014, 1012, 1011>, 0,
    <1014, 1011, 1013>, 0,
    <1014, 1013, 1007>, 0,
    <1014, 1007, 1008>, 0,
    <1018, 1012, 981>, 0,
    <1018, 981, 987>, 0,
    <1018, 987, 985>, 0,
    <1018, 985, 1016>, 0,
    <1018, 1016, 1015>, 0,
    <1018, 1015, 1017>, 0,
    <1018, 1017, 1011>, 0,
    <1018, 1011, 1012>, 0,
    <1022, 1016, 985>, 0,
    <1022, 985, 991>, 0,
    <1022, 991, 989>, 0,
    <1022, 989, 1020>, 0,
    <1022, 1020, 1019>, 0,
    <1022, 1019, 1021>, 0,
    <1022, 1021, 1015>, 0,
    <1022, 1015, 1016>, 0,
    <1024, 1020, 989>, 0,
    <1024, 989, 993>, 0,
    <1024, 993, 718>, 0,
    <1024, 718, 755>, 0,
    <1024, 755, 752>, 0,
    <1024, 752, 1023>, 0,
    <1024, 1023, 1019>, 0,
    <1024, 1019, 1020>, 0,
    <1030, 1029, 752>, 0,
    <1030, 752, 754>, 0,
    <1030, 754, 751>, 0,
    <1030, 751, 1027>, 0,
    <1030, 1027, 1025>, 0,
    <1030, 1025, 1028>, 0,
    <1030, 1028, 1026>, 0,
    <1030, 1026, 1029>, 0,
    <1034, 1027, 751>, 0,
    <1034, 751, 759>, 0,
    <1034, 759, 757>, 0,
    <1034, 757, 1032>, 0,
    <1034, 1032, 1031>, 0,
    <1034, 1031, 1033>, 0,
    <1034, 1033, 1025>, 0,
    <1034, 1025, 1027>, 0,
    <1038, 1032, 757>, 0,
    <1038, 757, 763>, 0,
    <1038, 763, 761>, 0,
    <1038, 761, 1036>, 0,
    <1038, 1036, 1035>, 0,
    <1038, 1035, 1037>, 0,
    <1038, 1037, 1031>, 0,
    <1038, 1031, 1032>, 0,
    <1042, 1036, 761>, 0,
    <1042, 761, 767>, 0,
    <1042, 767, 765>, 0,
    <1042, 765, 1040>, 0,
    <1042, 1040, 1039>, 0,
    <1042, 1039, 1041>, 0,
    <1042, 1041, 1035>, 0,
    <1042, 1035, 1036>, 0,
    <1046, 1040, 765>, 0,
    <1046, 765, 771>, 0,
    <1046, 771, 769>, 0,
    <1046, 769, 1044>, 0,
    <1046, 1044, 1043>, 0,
    <1046, 1043, 1045>, 0,
    <1046, 1045, 1039>, 0,
    <1046, 1039, 1040>, 0,
    <1050, 1044, 769>, 0,
    <1050, 769, 775>, 0,
    <1050, 775, 773>, 0,
    <1050, 773, 1048>, 0,
    <1050, 1048, 1047>, 0,
    <1050, 1047, 1049>, 0,
    <1050, 1049, 1043>, 0,
    <1050, 1043, 1044>, 0,
    <1054, 1048, 773>, 0,
    <1054, 773, 779>, 0,
    <1054, 779, 777>, 0,
    <1054, 777, 1052>, 0,
    <1054, 1052, 1051>, 0,
    <1054, 1051, 1053>, 0,
    <1054, 1053, 1047>, 0,
    <1054, 1047, 1048>, 0,
    <1058, 1052, 777>, 0,
    <1058, 777, 783>, 0,
    <1058, 783, 781>, 0,
    <1058, 781, 1056>, 0,
    <1058, 1056, 1055>, 0,
    <1058, 1055, 1057>, 0,
    <1058, 1057, 1051>, 0,
    <1058, 1051, 1052>, 0,
    <1064, 1063, 1026>, 0,
    <1064, 1026, 1028>, 0,
    <1064, 1028, 1025>, 0,
    <1064, 1025, 1061>, 0,
    <1064, 1061, 1059>, 0,
    <1064, 1059, 1062>, 0,
    <1064, 1062, 1060>, 0,
    <1064, 1060, 1063>, 0,
    <1068, 1061, 1025>, 0,
    <1068, 1025, 1033>, 0,
    <1068, 1033, 1031>, 0,
    <1068, 1031, 1066>, 0,
    <1068, 1066, 1065>, 0,
    <1068, 1065, 1067>, 0,
    <1068, 1067, 1059>, 0,
    <1068, 1059, 1061>, 0,
    <1072, 1066, 1031>, 0,
    <1072, 1031, 1037>, 0,
    <1072, 1037, 1035>, 0,
    <1072, 1035, 1070>, 0,
    <1072, 1070, 1069>, 0,
    <1072, 1069, 1071>, 0,
    <1072, 1071, 1065>, 0,
    <1072, 1065, 1066>, 0,
    <1076, 1070, 1035>, 0,
    <1076, 1035, 1041>, 0,
    <1076, 1041, 1039>, 0,
    <1076, 1039, 1074>, 0,
    <1076, 1074, 1073>, 0,
    <1076, 1073, 1075>, 0,
    <1076, 1075, 1069>, 0,
    <1076, 1069, 1070>, 0,
    <1080, 1074, 1039>, 0,
    <1080, 1039, 1045>, 0,
    <1080, 1045, 1043>, 0,
    <1080, 1043, 1078>, 0,
    <1080, 1078, 1077>, 0,
    <1080, 1077, 1079>, 0,
    <1080, 1079, 1073>, 0,
    <1080, 1073, 1074>, 0,
    <1084, 1078, 1043>, 0,
    <1084, 1043, 1049>, 0,
    <1084, 1049, 1047>, 0,
    <1084, 1047, 1082>, 0,
    <1084, 1082, 1081>, 0,
    <1084, 1081, 1083>, 0,
    <1084, 1083, 1077>, 0,
    <1084, 1077, 1078>, 0,
    <1088, 1082, 1047>, 0,
    <1088, 1047, 1053>, 0,
    <1088, 1053, 1051>, 0,
    <1088, 1051, 1086>, 0,
    <1088, 1086, 1085>, 0,
    <1088, 1085, 1087>, 0,
    <1088, 1087, 1081>, 0,
    <1088, 1081, 1082>, 0,
    <1092, 1086, 1051>, 0,
    <1092, 1051, 1057>, 0,
    <1092, 1057, 1055>, 0,
    <1092, 1055, 1090>, 0,
    <1092, 1090, 1089>, 0,
    <1092, 1089, 1091>, 0,
    <1092, 1091, 1085>, 0,
    <1092, 1085, 1086>, 0,
    <1098, 1097, 1060>, 0,
    <1098, 1060, 1062>, 0,
    <1098, 1062, 1059>, 0,
    <1098, 1059, 1095>, 0,
    <1098, 1095, 1093>, 0,
    <1098, 1093, 1096>, 0,
    <1098, 1096, 1094>, 0,
    <1098, 1094, 1097>, 0,
    <1102, 1095, 1059>, 0,
    <1102, 1059, 1067>, 0,
    <1102, 1067, 1065>, 0,
    <1102, 1065, 1100>, 0,
    <1102, 1100, 1099>, 0,
    <1102, 1099, 1101>, 0,
    <1102, 1101, 1093>, 0,
    <1102, 1093, 1095>, 0,
    <1106, 1100, 1065>, 0,
    <1106, 1065, 1071>, 0,
    <1106, 1071, 1069>, 0,
    <1106, 1069, 1104>, 0,
    <1106, 1104, 1103>, 0,
    <1106, 1103, 1105>, 0,
    <1106, 1105, 1099>, 0,
    <1106, 1099, 1100>, 0,
    <1110, 1104, 1069>, 0,
    <1110, 1069, 1075>, 0,
    <1110, 1075, 1073>, 0,
    <1110, 1073, 1108>, 0,
    <1110, 1108, 1107>, 0,
    <1110, 1107, 1109>, 0,
    <1110, 1109, 1103>, 0,
    <1110, 1103, 1104>, 0,
    <1114, 1108, 1073>, 0,
    <1114, 1073, 1079>, 0,
    <1114, 1079, 1077>, 0,
    <1114, 1077, 1112>, 0,
    <1114, 1112, 1111>, 0,
    <1114, 1111, 1113>, 0,
    <1114, 1113, 1107>, 0,
    <1114, 1107, 1108>, 0,
    <1118, 1112, 1077>, 0,
    <1118, 1077, 1083>, 0,
    <1118, 1083, 1081>, 0,
    <1118, 1081, 1116>, 0,
    <1118, 1116, 1115>, 0,
    <1118, 1115, 1117>, 0,
    <1118, 1117, 1111>, 0,
    <1118, 1111, 1112>, 0,
    <1122, 1116, 1081>, 0,
    <1122, 1081, 1087>, 0,
    <1122, 1087, 1085>, 0,
    <1122, 1085, 1120>, 0,
    <1122, 1120, 1119>, 0,
    <1122, 1119, 1121>, 0,
    <1122, 1121, 1115>, 0,
    <1122, 1115, 1116>, 0,
    <1126, 1120, 1085>, 0,
    <1126, 1085, 1091>, 0,
    <1126, 1091, 1089>, 0,
    <1126, 1089, 1124>, 0,
    <1126, 1124, 1123>, 0,
    <1126, 1123, 1125>, 0,
    <1126, 1125, 1119>, 0,
    <1126, 1119, 1120>, 0,
    <1132, 1131, 1094>, 0,
    <1132, 1094, 1096>, 0,
    <1132, 1096, 1093>, 0,
    <1132, 1093, 1129>, 0,
    <1132, 1129, 1127>, 0,
    <1132, 1127, 1130>, 0,
    <1132, 1130, 1128>, 0,
    <1132, 1128, 1131>, 0,
    <1136, 1129, 1093>, 0,
    <1136, 1093, 1101>, 0,
    <1136, 1101, 1099>, 0,
    <1136, 1099, 1134>, 0,
    <1136, 1134, 1133>, 0,
    <1136, 1133, 1135>, 0,
    <1136, 1135, 1127>, 0,
    <1136, 1127, 1129>, 0,
    <1140, 1134, 1099>, 0,
    <1140, 1099, 1105>, 0,
    <1140, 1105, 1103>, 0,
    <1140, 1103, 1138>, 0,
    <1140, 1138, 1137>, 0,
    <1140, 1137, 1139>, 0,
    <1140, 1139, 1133>, 0,
    <1140, 1133, 1134>, 0,
    <1144, 1138, 1103>, 0,
    <1144, 1103, 1109>, 0,
    <1144, 1109, 1107>, 0,
    <1144, 1107, 1142>, 0,
    <1144, 1142, 1141>, 0,
    <1144, 1141, 1143>, 0,
    <1144, 1143, 1137>, 0,
    <1144, 1137, 1138>, 0,
    <1148, 1142, 1107>, 0,
    <1148, 1107, 1113>, 0,
    <1148, 1113, 1111>, 0,
    <1148, 1111, 1146>, 0,
    <1148, 1146, 1145>, 0,
    <1148, 1145, 1147>, 0,
    <1148, 1147, 1141>, 0,
    <1148, 1141, 1142>, 0,
    <1152, 1146, 1111>, 0,
    <1152, 1111, 1117>, 0,
    <1152, 1117, 1115>, 0,
    <1152, 1115, 1150>, 0,
    <1152, 1150, 1149>, 0,
    <1152, 1149, 1151>, 0,
    <1152, 1151, 1145>, 0,
    <1152, 1145, 1146>, 0,
    <1156, 1150, 1115>, 0,
    <1156, 1115, 1121>, 0,
    <1156, 1121, 1119>, 0,
    <1156, 1119, 1154>, 0,
    <1156, 1154, 1153>, 0,
    <1156, 1153, 1155>, 0,
    <1156, 1155, 1149>, 0,
    <1156, 1149, 1150>, 0,
    <1160, 1154, 1119>, 0,
    <1160, 1119, 1125>, 0,
    <1160, 1125, 1123>, 0,
    <1160, 1123, 1158>, 0,
    <1160, 1158, 1157>, 0,
    <1160, 1157, 1159>, 0,
    <1160, 1159, 1153>, 0,
    <1160, 1153, 1154>, 0,
    <1166, 1165, 1128>, 0,
    <1166, 1128, 1130>, 0,
    <1166, 1130, 1127>, 0,
    <1166, 1127, 1163>, 0,
    <1166, 1163, 1161>, 0,
    <1166, 1161, 1164>, 0,
    <1166, 1164, 1162>, 0,
    <1166, 1162, 1165>, 0,
    <1170, 1163, 1127>, 0,
    <1170, 1127, 1135>, 0,
    <1170, 1135, 1133>, 0,
    <1170, 1133, 1168>, 0,
    <1170, 1168, 1167>, 0,
    <1170, 1167, 1169>, 0,
    <1170, 1169, 1161>, 0,
    <1170, 1161, 1163>, 0,
    <1174, 1168, 1133>, 0,
    <1174, 1133, 1139>, 0,
    <1174, 1139, 1137>, 0,
    <1174, 1137, 1172>, 0,
    <1174, 1172, 1171>, 0,
    <1174, 1171, 1173>, 0,
    <1174, 1173, 1167>, 0,
    <1174, 1167, 1168>, 0,
    <1178, 1172, 1137>, 0,
    <1178, 1137, 1143>, 0,
    <1178, 1143, 1141>, 0,
    <1178, 1141, 1176>, 0,
    <1178, 1176, 1175>, 0,
    <1178, 1175, 1177>, 0,
    <1178, 1177, 1171>, 0,
    <1178, 1171, 1172>, 0,
    <1182, 1176, 1141>, 0,
    <1182, 1141, 1147>, 0,
    <1182, 1147, 1145>, 0,
    <1182, 1145, 1180>, 0,
    <1182, 1180, 1179>, 0,
    <1182, 1179, 1181>, 0,
    <1182, 1181, 1175>, 0,
    <1182, 1175, 1176>, 0,
    <1186, 1180, 1145>, 0,
    <1186, 1145, 1151>, 0,
    <1186, 1151, 1149>, 0,
    <1186, 1149, 1184>, 0,
    <1186, 1184, 1183>, 0,
    <1186, 1183, 1185>, 0,
    <1186, 1185, 1179>, 0,
    <1186, 1179, 1180>, 0,
    <1190, 1184, 1149>, 0,
    <1190, 1149, 1155>, 0,
    <1190, 1155, 1153>, 0,
    <1190, 1153, 1188>, 0,
    <1190, 1188, 1187>, 0,
    <1190, 1187, 1189>, 0,
    <1190, 1189, 1183>, 0,
    <1190, 1183, 1184>, 0,
    <1194, 1188, 1153>, 0,
    <1194, 1153, 1159>, 0,
    <1194, 1159, 1157>, 0,
    <1194, 1157, 1192>, 0,
    <1194, 1192, 1191>, 0,
    <1194, 1191, 1193>, 0,
    <1194, 1193, 1187>, 0,
    <1194, 1187, 1188>, 0,
    <1200, 1199, 1162>, 0,
    <1200, 1162, 1164>, 0,
    <1200, 1164, 1161>, 0,
    <1200, 1161, 1197>, 0,
    <1200, 1197, 1195>, 0,
    <1200, 1195, 1198>, 0,
    <1200, 1198, 1196>, 0,
    <1200, 1196, 1199>, 0,
    <1204, 1197, 1161>, 0,
    <1204, 1161, 1169>, 0,
    <1204, 1169, 1167>, 0,
    <1204, 1167, 1202>, 0,
    <1204, 1202, 1201>, 0,
    <1204, 1201, 1203>, 0,
    <1204, 1203, 1195>, 0,
    <1204, 1195, 1197>, 0,
    <1208, 1202, 1167>, 0,
    <1208, 1167, 1173>, 0,
    <1208, 1173, 1171>, 0,
    <1208, 1171, 1206>, 0,
    <1208, 1206, 1205>, 0,
    <1208, 1205, 1207>, 0,
    <1208, 1207, 1201>, 0,
    <1208, 1201, 1202>, 0,
    <1212, 1206, 1171>, 0,
    <1212, 1171, 1177>, 0,
    <1212, 1177, 1175>, 0,
    <1212, 1175, 1210>, 0,
    <1212, 1210, 1209>, 0,
    <1212, 1209, 1211>, 0,
    <1212, 1211, 1205>, 0,
    <1212, 1205, 1206>, 0,
    <1216, 1210, 1175>, 0,
    <1216, 1175, 1181>, 0,
    <1216, 1181, 1179>, 0,
    <1216, 1179, 1214>, 0,
    <1216, 1214, 1213>, 0,
    <1216, 1213, 1215>, 0,
    <1216, 1215, 1209>, 0,
    <1216, 1209, 1210>, 0,
    <1220, 1214, 1179>, 0,
    <1220, 1179, 1185>, 0,
    <1220, 1185, 1183>, 0,
    <1220, 1183, 1218>, 0,
    <1220, 1218, 1217>, 0,
    <1220, 1217, 1219>, 0,
    <1220, 1219, 1213>, 0,
    <1220, 1213, 1214>, 0,
    <1224, 1218, 1183>, 0,
    <1224, 1183, 1189>, 0,
    <1224, 1189, 1187>, 0,
    <1224, 1187, 1222>, 0,
    <1224, 1222, 1221>, 0,
    <1224, 1221, 1223>, 0,
    <1224, 1223, 1217>, 0,
    <1224, 1217, 1218>, 0,
    <1228, 1222, 1187>, 0,
    <1228, 1187, 1193>, 0,
    <1228, 1193, 1191>, 0,
    <1228, 1191, 1226>, 0,
    <1228, 1226, 1225>, 0,
    <1228, 1225, 1227>, 0,
    <1228, 1227, 1221>, 0,
    <1228, 1221, 1222>, 0,
    <1234, 1233, 1196>, 0,
    <1234, 1196, 1198>, 0,
    <1234, 1198, 1195>, 0,
    <1234, 1195, 1231>, 0,
    <1234, 1231, 1229>, 0,
    <1234, 1229, 1232>, 0,
    <1234, 1232, 1230>, 0,
    <1234, 1230, 1233>, 0,
    <1238, 1231, 1195>, 0,
    <1238, 1195, 1203>, 0,
    <1238, 1203, 1201>, 0,
    <1238, 1201, 1236>, 0,
    <1238, 1236, 1235>, 0,
    <1238, 1235, 1237>, 0,
    <1238, 1237, 1229>, 0,
    <1238, 1229, 1231>, 0,
    <1242, 1236, 1201>, 0,
    <1242, 1201, 1207>, 0,
    <1242, 1207, 1205>, 0,
    <1242, 1205, 1240>, 0,
    <1242, 1240, 1239>, 0,
    <1242, 1239, 1241>, 0,
    <1242, 1241, 1235>, 0,
    <1242, 1235, 1236>, 0,
    <1246, 1240, 1205>, 0,
    <1246, 1205, 1211>, 0,
    <1246, 1211, 1209>, 0,
    <1246, 1209, 1244>, 0,
    <1246, 1244, 1243>, 0,
    <1246, 1243, 1245>, 0,
    <1246, 1245, 1239>, 0,
    <1246, 1239, 1240>, 0,
    <1250, 1244, 1209>, 0,
    <1250, 1209, 1215>, 0,
    <1250, 1215, 1213>, 0,
    <1250, 1213, 1248>, 0,
    <1250, 1248, 1247>, 0,
    <1250, 1247, 1249>, 0,
    <1250, 1249, 1243>, 0,
    <1250, 1243, 1244>, 0,
    <1254, 1248, 1213>, 0,
    <1254, 1213, 1219>, 0,
    <1254, 1219, 1217>, 0,
    <1254, 1217, 1252>, 0,
    <1254, 1252, 1251>, 0,
    <1254, 1251, 1253>, 0,
    <1254, 1253, 1247>, 0,
    <1254, 1247, 1248>, 0,
    <1258, 1252, 1217>, 0,
    <1258, 1217, 1223>, 0,
    <1258, 1223, 1221>, 0,
    <1258, 1221, 1256>, 0,
    <1258, 1256, 1255>, 0,
    <1258, 1255, 1257>, 0,
    <1258, 1257, 1251>, 0,
    <1258, 1251, 1252>, 0,
    <1262, 1256, 1221>, 0,
    <1262, 1221, 1227>, 0,
    <1262, 1227, 1225>, 0,
    <1262, 1225, 1260>, 0,
    <1262, 1260, 1259>, 0,
    <1262, 1259, 1261>, 0,
    <1262, 1261, 1255>, 0,
    <1262, 1255, 1256>, 0,
    <1268, 1267, 1230>, 0,
    <1268, 1230, 1232>, 0,
    <1268, 1232, 1229>, 0,
    <1268, 1229, 1265>, 0,
    <1268, 1265, 1263>, 0,
    <1268, 1263, 1266>, 0,
    <1268, 1266, 1264>, 0,
    <1268, 1264, 1267>, 0,
    <1272, 1265, 1229>, 0,
    <1272, 1229, 1237>, 0,
    <1272, 1237, 1235>, 0,
    <1272, 1235, 1270>, 0,
    <1272, 1270, 1269>, 0,
    <1272, 1269, 1271>, 0,
    <1272, 1271, 1263>, 0,
    <1272, 1263, 1265>, 0,
    <1276, 1270, 1235>, 0,
    <1276, 1235, 1241>, 0,
    <1276, 1241, 1239>, 0,
    <1276, 1239, 1274>, 0,
    <1276, 1274, 1273>, 0,
    <1276, 1273, 1275>, 0,
    <1276, 1275, 1269>, 0,
    <1276, 1269, 1270>, 0,
    <1280, 1274, 1239>, 0,
    <1280, 1239, 1245>, 0,
    <1280, 1245, 1243>, 0,
    <1280, 1243, 1278>, 0,
    <1280, 1278, 1277>, 0,
    <1280, 1277, 1279>, 0,
    <1280, 1279, 1273>, 0,
    <1280, 1273, 1274>, 0,
    <1284, 1278, 1243>, 0,
    <1284, 1243, 1249>, 0,
    <1284, 1249, 1247>, 0,
    <1284, 1247, 1282>, 0,
    <1284, 1282, 1281>, 0,
    <1284, 1281, 1283>, 0,
    <1284, 1283, 1277>, 0,
    <1284, 1277, 1278>, 0,
    <1288, 1282, 1247>, 0,
    <1288, 1247, 1253>, 0,
    <1288, 1253, 1251>, 0,
    <1288, 1251, 1286>, 0,
    <1288, 1286, 1285>, 0,
    <1288, 1285, 1287>, 0,
    <1288, 1287, 1281>, 0,
    <1288, 1281, 1282>, 0,
    <1292, 1286, 1251>, 0,
    <1292, 1251, 1257>, 0,
    <1292, 1257, 1255>, 0,
    <1292, 1255, 1290>, 0,
    <1292, 1290, 1289>, 0,
    <1292, 1289, 1291>, 0,
    <1292, 1291, 1285>, 0,
    <1292, 1285, 1286>, 0,
    <1296, 1290, 1255>, 0,
    <1296, 1255, 1261>, 0,
    <1296, 1261, 1259>, 0,
    <1296, 1259, 1294>, 0,
    <1296, 1294, 1293>, 0,
    <1296, 1293, 1295>, 0,
    <1296, 1295, 1289>, 0,
    <1296, 1289, 1290>, 0,
    <1300, 1056, 781>, 0,
    <1300, 781, 997>, 0,
    <1300, 997, 995>, 0,
    <1300, 995, 1298>, 0,
    <1300, 1298, 1297>, 0,
    <1300, 1297, 1299>, 0,
    <1300, 1299, 1055>, 0,
    <1300, 1055, 1056>, 0,
    <1304, 1298, 995>, 0,
    <1304, 995, 1001>, 0,
    <1304, 1001, 999>, 0,
    <1304, 999, 1302>, 0,
    <1304, 1302, 1301>, 0,
    <1304, 1301, 1303>, 0,
    <1304, 1303, 1297>, 0,
    <1304, 1297, 1298>, 0,
    <1308, 1302, 999>, 0,
    <1308, 999, 1005>, 0,
    <1308, 1005, 1003>, 0,
    <1308, 1003, 1306>, 0,
    <1308, 1306, 1305>, 0,
    <1308, 1305, 1307>, 0,
    <1308, 1307, 1301>, 0,
    <1308, 1301, 1302>, 0,
    <1312, 1306, 1003>, 0,
    <1312, 1003, 1009>, 0,
    <1312, 1009, 1007>, 0,
    <1312, 1007, 1310>, 0,
    <1312, 1310, 1309>, 0,
    <1312, 1309, 1311>, 0,
    <1312, 1311, 1305>, 0,
    <1312, 1305, 1306>, 0,
    <1316, 1310, 1007>, 0,
    <1316, 1007, 1013>, 0,
    <1316, 1013, 1011>, 0,
    <1316, 1011, 1314>, 0,
    <1316, 1314, 1313>, 0,
    <1316, 1313, 1315>, 0,
    <1316, 1315, 1309>, 0,
    <1316, 1309, 1310>, 0,
    <1320, 1314, 1011>, 0,
    <1320, 1011, 1017>, 0,
    <1320, 1017, 1015>, 0,
    <1320, 1015, 1318>, 0,
    <1320, 1318, 1317>, 0,
    <1320, 1317, 1319>, 0,
    <1320, 1319, 1313>, 0,
    <1320, 1313, 1314>, 0,
    <1324, 1318, 1015>, 0,
    <1324, 1015, 1021>, 0,
    <1324, 1021, 1019>, 0,
    <1324, 1019, 1322>, 0,
    <1324, 1322, 1321>, 0,
    <1324, 1321, 1323>, 0,
    <1324, 1323, 1317>, 0,
    <1324, 1317, 1318>, 0,
    <1326, 1322, 1019>, 0,
    <1326, 1019, 1023>, 0,
    <1326, 1023, 752>, 0,
    <1326, 752, 1029>, 0,
    <1326, 1029, 1026>, 0,
    <1326, 1026, 1325>, 0,
    <1326, 1325, 1321>, 0,
    <1326, 1321, 1322>, 0,
    <1330, 1090, 1055>, 0,
    <1330, 1055, 1299>, 0,
    <1330, 1299, 1297>, 0,
    <1330, 1297, 1328>, 0,
    <1330, 1328, 1327>, 0,
    <1330, 1327, 1329>, 0,
    <1330, 1329, 1089>, 0,
    <1330, 1089, 1090>, 0,
    <1334, 1328, 1297>, 0,
    <1334, 1297, 1303>, 0,
    <1334, 1303, 1301>, 0,
    <1334, 1301, 1332>, 0,
    <1334, 1332, 1331>, 0,
    <1334, 1331, 1333>, 0,
    <1334, 1333, 1327>, 0,
    <1334, 1327, 1328>, 0,
    <1338, 1332, 1301>, 0,
    <1338, 1301, 1307>, 0,
    <1338, 1307, 1305>, 0,
    <1338, 1305, 1336>, 0,
    <1338, 1336, 1335>, 0,
    <1338, 1335, 1337>, 0,
    <1338, 1337, 1331>, 0,
    <1338, 1331, 1332>, 0,
    <1342, 1336, 1305>, 0,
    <1342, 1305, 1311>, 0,
    <1342, 1311, 1309>, 0,
    <1342, 1309, 1340>, 0,
    <1342, 1340, 1339>, 0,
    <1342, 1339, 1341>, 0,
    <1342, 1341, 1335>, 0,
    <1342, 1335, 1336>, 0,
    <1346, 1340, 1309>, 0,
    <1346, 1309, 1315>, 0,
    <1346, 1315, 1313>, 0,
    <1346, 1313, 1344>, 0,
    <1346, 1344, 1343>, 0,
    <1346, 1343, 1345>, 0,
    <1346, 1345, 1339>, 0,
    <1346, 1339, 1340>, 0,
    <1350, 1344, 1313>, 0,
    <1350, 1313, 1319>, 0,
    <1350, 1319, 1317>, 0,
    <1350, 1317, 1348>, 0,
    <1350, 1348, 1347>, 0,
    <1350, 1347, 1349>, 0,
    <1350, 1349, 1343>, 0,
    <1350, 1343, 1344>, 0,
    <1354, 1348, 1317>, 0,
    <1354, 1317, 1323>, 0,
    <1354, 1323, 1321>, 0,
    <1354, 1321, 1352>, 0,
    <1354, 1352, 1351>, 0,
    <1354, 1351, 1353>, 0,
    <1354, 1353, 1347>, 0,
    <1354, 1347, 1348>, 0,
    <1356, 1352, 1321>, 0,
    <1356, 1321, 1325>, 0,
    <1356, 1325, 1026>, 0,
    <1356, 1026, 1063>, 0,
    <1356, 1063, 1060>, 0,
    <1356, 1060, 1355>, 0,
    <1356, 1355, 1351>, 0,
    <1356, 1351, 1352>, 0,
    <1360, 1124, 1089>, 0,
    <1360, 1089, 1329>, 0,
    <1360, 1329, 1327>, 0,
    <1360, 1327, 1358>, 0,
    <1360, 1358, 1357>, 0,
    <1360, 1357, 1359>, 0,
    <1360, 1359, 1123>, 0,
    <1360, 1123, 1124>, 0,
    <1364, 1358, 1327>, 0,
    <1364, 1327, 1333>, 0,
    <1364, 1333, 1331>, 0,
    <1364, 1331, 1362>, 0,
    <1364, 1362, 1361>, 0,
    <1364, 1361, 1363>, 0,
    <1364, 1363, 1357>, 0,
    <1364, 1357, 1358>, 0,
    <1368, 1362, 1331>, 0,
    <1368, 1331, 1337>, 0,
    <1368, 1337, 1335>, 0,
    <1368, 1335, 1366>, 0,
    <1368, 1366, 1365>, 0,
    <1368, 1365, 1367>, 0,
    <1368, 1367, 1361>, 0,
    <1368, 1361, 1362>, 0,
    <1372, 1366, 1335>, 0,
    <1372, 1335, 1341>, 0,
    <1372, 1341, 1339>, 0,
    <1372, 1339, 1370>, 0,
    <1372, 1370, 1369>, 0,
    <1372, 1369, 1371>, 0,
    <1372, 1371, 1365>, 0,
    <1372, 1365, 1366>, 0,
    <1376, 1370, 1339>, 0,
    <1376, 1339, 1345>, 0,
    <1376, 1345, 1343>, 0,
    <1376, 1343, 1374>, 0,
    <1376, 1374, 1373>, 0,
    <1376, 1373, 1375>, 0,
    <1376, 1375, 1369>, 0,
    <1376, 1369, 1370>, 0,
    <1380, 1374, 1343>, 0,
    <1380, 1343, 1349>, 0,
    <1380, 1349, 1347>, 0,
    <1380, 1347, 1378>, 0,
    <1380, 1378, 1377>, 0,
    <1380, 1377, 1379>, 0,
    <1380, 1379, 1373>, 0,
    <1380, 1373, 1374>, 0,
    <1384, 1378, 1347>, 0,
    <1384, 1347, 1353>, 0,
    <1384, 1353, 1351>, 0,
    <1384, 1351, 1382>, 0,
    <1384, 1382, 1381>, 0,
    <1384, 1381, 1383>, 0,
    <1384, 1383, 1377>, 0,
    <1384, 1377, 1378>, 0,
    <1386, 1382, 1351>, 0,
    <1386, 1351, 1355>, 0,
    <1386, 1355, 1060>, 0,
    <1386, 1060, 1097>, 0,
    <1386, 1097, 1094>, 0,
    <1386, 1094, 1385>, 0,
    <1386, 1385, 1381>, 0,
    <1386, 1381, 1382>, 0,
    <1390, 1158, 1123>, 0,
    <1390, 1123, 1359>, 0,
    <1390, 1359, 1357>, 0,
    <1390, 1357, 1388>, 0,
    <1390, 1388, 1387>, 0,
    <1390, 1387, 1389>, 0,
    <1390, 1389, 1157>, 0,
    <1390, 1157, 1158>, 0,
    <1394, 1388, 1357>, 0,
    <1394, 1357, 1363>, 0,
    <1394, 1363, 1361>, 0,
    <1394, 1361, 1392>, 0,
    <1394, 1392, 1391>, 0,
    <1394, 1391, 1393>, 0,
    <1394, 1393, 1387>, 0,
    <1394, 1387, 1388>, 0,
    <1398, 1392, 1361>, 0,
    <1398, 1361, 1367>, 0,
    <1398, 1367, 1365>, 0,
    <1398, 1365, 1396>, 0,
    <1398, 1396, 1395>, 0,
    <1398, 1395, 1397>, 0,
    <1398, 1397, 1391>, 0,
    <1398, 1391, 1392>, 0,
    <1402, 1396, 1365>, 0,
    <1402, 1365, 1371>, 0,
    <1402, 1371, 1369>, 0,
    <1402, 1369, 1400>, 0,
    <1402, 1400, 1399>, 0,
    <1402, 1399, 1401>, 0,
    <1402, 1401, 1395>, 0,
    <1402, 1395, 1396>, 0,
    <1406, 1400, 1369>, 0,
    <1406, 1369, 1375>, 0,
    <1406, 1375, 1373>, 0,
    <1406, 1373, 1404>, 0,
    <1406, 1404, 1403>, 0,
    <1406, 1403, 1405>, 0,
    <1406, 1405, 1399>, 0,
    <1406, 1399, 1400>, 0,
    <1410, 1404, 1373>, 0,
    <1410, 1373, 1379>, 0,
    <1410, 1379, 1377>, 0,
    <1410, 1377, 1408>, 0,
    <1410, 1408, 1407>, 0,
    <1410, 1407, 1409>, 0,
    <1410, 1409, 1403>, 0,
    <1410, 1403, 1404>, 0,
    <1414, 1408, 1377>, 0,
    <1414, 1377, 1383>, 0,
    <1414, 1383, 1381>, 0,
    <1414, 1381, 1412>, 0,
    <1414, 1412, 1411>, 0,
    <1414, 1411, 1413>, 0,
    <1414, 1413, 1407>, 0,
    <1414, 1407, 1408>, 0,
    <1416, 1412, 1381>, 0,
    <1416, 1381, 1385>, 0,
    <1416, 1385, 1094>, 0,
    <1416, 1094, 1131>, 0,
    <1416, 1131, 1128>, 0,
    <1416, 1128, 1415>, 0,
    <1416, 1415, 1411>, 0,
    <1416, 1411, 1412>, 0,
    <1420, 1192, 1157>, 0,
    <1420, 1157, 1389>, 0,
    <1420, 1389, 1387>, 0,
    <1420, 1387, 1418>, 0,
    <1420, 1418, 1417>, 0,
    <1420, 1417, 1419>, 0,
    <1420, 1419, 1191>, 0,
    <1420, 1191, 1192>, 0,
    <1424, 1418, 1387>, 0,
    <1424, 1387, 1393>, 0,
    <1424, 1393, 1391>, 0,
    <1424, 1391, 1422>, 0,
    <1424, 1422, 1421>, 0,
    <1424, 1421, 1423>, 0,
    <1424, 1423, 1417>, 0,
    <1424, 1417, 1418>, 0,
    <1428, 1422, 1391>, 0,
    <1428, 1391, 1397>, 0,
    <1428, 1397, 1395>, 0,
    <1428, 1395, 1426>, 0,
    <1428, 1426, 1425>, 0,
    <1428, 1425, 1427>, 0,
    <1428, 1427, 1421>, 0,
    <1428, 1421, 1422>, 0,
    <1432, 1426, 1395>, 0,
    <1432, 1395, 1401>, 0,
    <1432, 1401, 1399>, 0,
    <1432, 1399, 1430>, 0,
    <1432, 1430, 1429>, 0,
    <1432, 1429, 1431>, 0,
    <1432, 1431, 1425>, 0,
    <1432, 1425, 1426>, 0,
    <1436, 1430, 1399>, 0,
    <1436, 1399, 1405>, 0,
    <1436, 1405, 1403>, 0,
    <1436, 1403, 1434>, 0,
    <1436, 1434, 1433>, 0,
    <1436, 1433, 1435>, 0,
    <1436, 1435, 1429>, 0,
    <1436, 1429, 1430>, 0,
    <1440, 1434, 1403>, 0,
    <1440, 1403, 1409>, 0,
    <1440, 1409, 1407>, 0,
    <1440, 1407, 1438>, 0,
    <1440, 1438, 1437>, 0,
    <1440, 1437, 1439>, 0,
    <1440, 1439, 1433>, 0,
    <1440, 1433, 1434>, 0,
    <1444, 1438, 1407>, 0,
    <1444, 1407, 1413>, 0,
    <1444, 1413, 1411>, 0,
    <1444, 1411, 1442>, 0,
    <1444, 1442, 1441>, 0,
    <1444, 1441, 1443>, 0,
    <1444, 1443, 1437>, 0,
    <1444, 1437, 1438>, 0,
    <1446, 1442, 1411>, 0,
    <1446, 1411, 1415>, 0,
    <1446, 1415, 1128>, 0,
    <1446, 1128, 1165>, 0,
    <1446, 1165, 1162>, 0,
    <1446, 1162, 1445>, 0,
    <1446, 1445, 1441>, 0,
    <1446, 1441, 1442>, 0,
    <1450, 1226, 1191>, 0,
    <1450, 1191, 1419>, 0,
    <1450, 1419, 1417>, 0,
    <1450, 1417, 1448>, 0,
    <1450, 1448, 1447>, 0,
    <1450, 1447, 1449>, 0,
    <1450, 1449, 1225>, 0,
    <1450, 1225, 1226>, 0,
    <1454, 1448, 1417>, 0,
    <1454, 1417, 1423>, 0,
    <1454, 1423, 1421>, 0,
    <1454, 1421, 1452>, 0,
    <1454, 1452, 1451>, 0,
    <1454, 1451, 1453>, 0,
    <1454, 1453, 1447>, 0,
    <1454, 1447, 1448>, 0,
    <1458, 1452, 1421>, 0,
    <1458, 1421, 1427>, 0,
    <1458, 1427, 1425>, 0,
    <1458, 1425, 1456>, 0,
    <1458, 1456, 1455>, 0,
    <1458, 1455, 1457>, 0,
    <1458, 1457, 1451>, 0,
    <1458, 1451, 1452>, 0,
    <1462, 1456, 1425>, 0,
    <1462, 1425, 1431>, 0,
    <1462, 1431, 1429>, 0,
    <1462, 1429, 1460>, 0,
    <1462, 1460, 1459>, 0,
    <1462, 1459, 1461>, 0,
    <1462, 1461, 1455>, 0,
    <1462, 1455, 1456>, 0,
    <1466, 1460, 1429>, 0,
    <1466, 1429, 1435>, 0,
    <1466, 1435, 1433>, 0,
    <1466, 1433, 1464>, 0,
    <1466, 1464, 1463>, 0,
    <1466, 1463, 1465>, 0,
    <1466, 1465, 1459>, 0,
    <1466, 1459, 1460>, 0,
    <1470, 1464, 1433>, 0,
    <1470, 1433, 1439>, 0,
    <1470, 1439, 1437>, 0,
    <1470, 1437, 1468>, 0,
    <1470, 1468, 1467>, 0,
    <1470, 1467, 1469>, 0,
    <1470, 1469, 1463>, 0,
    <1470, 1463, 1464>, 0,
    <1474, 1468, 1437>, 0,
    <1474, 1437, 1443>, 0,
    <1474, 1443, 1441>, 0,
    <1474, 1441, 1472>, 0,
    <1474, 1472, 1471>, 0,
    <1474, 1471, 1473>, 0,
    <1474, 1473, 1467>, 0,
    <1474, 1467, 1468>, 0,
    <1476, 1472, 1441>, 0,
    <1476, 1441, 1445>, 0,
    <1476, 1445, 1162>, 0,
    <1476, 1162, 1199>, 0,
    <1476, 1199, 1196>, 0,
    <1476, 1196, 1475>, 0,
    <1476, 1475, 1471>, 0,
    <1476, 1471, 1472>, 0,
    <1482, 1481, 1225>, 0,
    <1482, 1225, 1449>, 0,
    <1482, 1449, 1447>, 0,
    <1482, 1447, 1479>, 0,
    <1482, 1479, 1477>, 0,
    <1482, 1477, 1480>, 0,
    <1482, 1480, 1478>, 0,
    <1482, 1478, 1481>, 0,
    <1486, 1479, 1447>, 0,
    <1486, 1447, 1453>, 0,
    <1486, 1453, 1451>, 0,
    <1486, 1451, 1484>, 0,
    <1486, 1484, 1483>, 0,
    <1486, 1483, 1485>, 0,
    <1486, 1485, 1477>, 0,
    <1486, 1477, 1479>, 0,
    <1490, 1484, 1451>, 0,
    <1490, 1451, 1457>, 0,
    <1490, 1457, 1455>, 0,
    <1490, 1455, 1488>, 0,
    <1490, 1488, 1487>, 0,
    <1490, 1487, 1489>, 0,
    <1490, 1489, 1483>, 0,
    <1490, 1483, 1484>, 0,
    <1494, 1488, 1455>, 0,
    <1494, 1455, 1461>, 0,
    <1494, 1461, 1459>, 0,
    <1494, 1459, 1492>, 0,
    <1494, 1492, 1491>, 0,
    <1494, 1491, 1493>, 0,
    <1494, 1493, 1487>, 0,
    <1494, 1487, 1488>, 0,
    <1498, 1492, 1459>, 0,
    <1498, 1459, 1465>, 0,
    <1498, 1465, 1463>, 0,
    <1498, 1463, 1496>, 0,
    <1498, 1496, 1495>, 0,
    <1498, 1495, 1497>, 0,
    <1498, 1497, 1491>, 0,
    <1498, 1491, 1492>, 0,
    <1502, 1496, 1463>, 0,
    <1502, 1463, 1469>, 0,
    <1502, 1469, 1467>, 0,
    <1502, 1467, 1500>, 0,
    <1502, 1500, 1499>, 0,
    <1502, 1499, 1501>, 0,
    <1502, 1501, 1495>, 0,
    <1502, 1495, 1496>, 0,
    <1506, 1500, 1467>, 0,
    <1506, 1467, 1473>, 0,
    <1506, 1473, 1471>, 0,
    <1506, 1471, 1504>, 0,
    <1506, 1504, 1503>, 0,
    <1506, 1503, 1505>, 0,
    <1506, 1505, 1499>, 0,
    <1506, 1499, 1500>, 0,
    <1510, 1504, 1471>, 0,
    <1510, 1471, 1475>, 0,
    <1510, 1475, 1196>, 0,
    <1510, 1196, 1508>, 0,
    <1510, 1508, 1507>, 0,
    <1510, 1507, 1509>, 0,
    <1510, 1509, 1503>, 0,
    <1510, 1503, 1504>, 0,
    <1513, 1512, 1478>, 0,
    <1513, 1478, 1480>, 0,
    <1513, 1480, 1477>, 0,
    <1513, 1477, 1511>, 0,
    <1513, 1511, 1289>, 0,
    <1513, 1289, 1295>, 0,
    <1513, 1295, 1293>, 0,
    <1513, 1293, 1512>, 0,
    <1515, 1511, 1477>, 0,
    <1515, 1477, 1485>, 0,
    <1515, 1485, 1483>, 0,
    <1515, 1483, 1514>, 0,
    <1515, 1514, 1285>, 0,
    <1515, 1285, 1291>, 0,
    <1515, 1291, 1289>, 0,
    <1515, 1289, 1511>, 0,
    <1517, 1514, 1483>, 0,
    <1517, 1483, 1489>, 0,
    <1517, 1489, 1487>, 0,
    <1517, 1487, 1516>, 0,
    <1517, 1516, 1281>, 0,
    <1517, 1281, 1287>, 0,
    <1517, 1287, 1285>, 0,
    <1517, 1285, 1514>, 0,
    <1519, 1516, 1487>, 0,
    <1519, 1487, 1493>, 0,
    <1519, 1493, 1491>, 0,
    <1519, 1491, 1518>, 0,
    <1519, 1518, 1277>, 0,
    <1519, 1277, 1283>, 0,
    <1519, 1283, 1281>, 0,
    <1519, 1281, 1516>, 0,
    <1521, 1518, 1491>, 0,
    <1521, 1491, 1497>, 0,
    <1521, 1497, 1495>, 0,
    <1521, 1495, 1520>, 0,
    <1521, 1520, 1273>, 0,
    <1521, 1273, 1279>, 0,
    <1521, 1279, 1277>, 0,
    <1521, 1277, 1518>, 0,
    <1523, 1520, 1495>, 0,
    <1523, 1495, 1501>, 0,
    <1523, 1501, 1499>, 0,
    <1523, 1499, 1522>, 0,
    <1523, 1522, 1269>, 0,
    <1523, 1269, 1275>, 0,
    <1523, 1275, 1273>, 0,
    <1523, 1273, 1520>, 0,
    <1525, 1522, 1499>, 0,
    <1525, 1499, 1505>, 0,
    <1525, 1505, 1503>, 0,
    <1525, 1503, 1524>, 0,
    <1525, 1524, 1263>, 0,
    <1525, 1263, 1271>, 0,
    <1525, 1271, 1269>, 0,
    <1525, 1269, 1522>, 0,
    <1527, 1524, 1503>, 0,
    <1527, 1503, 1509>, 0,
    <1527, 1509, 1507>, 0,
    <1527, 1507, 1526>, 0,
    <1527, 1526, 1264>, 0,
    <1527, 1264, 1266>, 0,
    <1527, 1266, 1263>, 0,
    <1527, 1263, 1524>, 0
  }
  normal_indices {
    3040,   // from 0 triangles and 1520 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 5, 6>,
    <0, 6, 1>,
    <7, 3, 2>,
    <7, 2, 8>,
    <7, 8, 9>,
    <7, 9, 10>,
    <7, 10, 4>,
    <7, 4, 3>,
    <11, 8, 2>,
    <11, 2, 12>,
    <11, 12, 13>,
    <11, 13, 14>,
    <11, 14, 9>,
    <11, 9, 8>,
    <15, 12, 2>,
    <15, 2, 16>,
    <15, 16, 17>,
    <15, 17, 18>,
    <15, 18, 13>,
    <15, 13, 12>,
    <19, 16, 2>,
    <19, 2, 20>,
    <19, 20, 21>,
    <19, 21, 22>,
    <19, 22, 17>,
    <19, 17, 16>,
    <23, 20, 2>,
    <23, 2, 24>,
    <23, 24, 25>,
    <23, 25, 26>,
    <23, 26, 21>,
    <23, 21, 20>,
    <27, 24, 2>,
    <27, 2, 28>,
    <27, 28, 29>,
    <27, 29, 30>,
    <27, 30, 25>,
    <27, 25, 24>,
    <31, 28, 2>,
    <31, 2, 32>,
    <31, 32, 33>,
    <31, 33, 34>,
    <31, 34, 29>,
    <31, 29, 28>,
    <35, 36, 6>,
    <35, 6, 5>,
    <35, 5, 4>,
    <35, 4, 37>,
    <35, 37, 38>,
    <35, 38, 39>,
    <35, 39, 40>,
    <35, 40, 36>,
    <41, 37, 4>,
    <41, 4, 10>,
    <41, 10, 9>,
    <41, 9, 42>,
    <41, 42, 43>,
    <41, 43, 44>,
    <41, 44, 38>,
    <41, 38, 37>,
    <45, 42, 9>,
    <45, 9, 14>,
    <45, 14, 13>,
    <45, 13, 46>,
    <45, 46, 47>,
    <45, 47, 48>,
    <45, 48, 43>,
    <45, 43, 42>,
    <49, 46, 13>,
    <49, 13, 18>,
    <49, 18, 17>,
    <49, 17, 50>,
    <49, 50, 51>,
    <49, 51, 52>,
    <49, 52, 47>,
    <49, 47, 46>,
    <53, 50, 17>,
    <53, 17, 22>,
    <53, 22, 21>,
    <53, 21, 54>,
    <53, 54, 55>,
    <53, 55, 56>,
    <53, 56, 51>,
    <53, 51, 50>,
    <57, 54, 21>,
    <57, 21, 26>,
    <57, 26, 25>,
    <57, 25, 58>,
    <57, 58, 59>,
    <57, 59, 60>,
    <57, 60, 55>,
    <57, 55, 54>,
    <61, 58, 25>,
    <61, 25, 30>,
    <61, 30, 29>,
    <61, 29, 62>,
    <61, 62, 63>,
    <61, 63, 64>,
    <61, 64, 59>,
    <61, 59, 58>,
    <65, 62, 29>,
    <65, 29, 34>,
    <65, 34, 33>,
    <65, 33, 66>,
    <65, 66, 67>,
    <65, 67, 68>,
    <65, 68, 63>,
    <65, 63, 62>,
    <69, 70, 40>,
    <69, 40, 39>,
    <69, 39, 38>,
    <69, 38, 71>,
    <69, 71, 72>,
    <69, 72, 73>,
    <69, 73, 74>,
    <69, 74, 70>,
    <75, 71, 38>,
    <75, 38, 44>,
    <75, 44, 43>,
    <75, 43, 76>,
    <75, 76, 77>,
    <75, 77, 78>,
    <75, 78, 72>,
    <75, 72, 71>,
    <79, 76, 43>,
    <79, 43, 48>,
    <79, 48, 47>,
    <79, 47, 80>,
    <79, 80, 81>,
    <79, 81, 82>,
    <79, 82, 77>,
    <79, 77, 76>,
    <83, 80, 47>,
    <83, 47, 52>,
    <83, 52, 51>,
    <83, 51, 84>,
    <83, 84, 85>,
    <83, 85, 86>,
    <83, 86, 81>,
    <83, 81, 80>,
    <87, 84, 51>,
    <87, 51, 56>,
    <87, 56, 55>,
    <87, 55, 88>,
    <87, 88, 89>,
    <87, 89, 90>,
    <87, 90, 85>,
    <87, 85, 84>,
    <91, 88, 55>,
    <91, 55, 60>,
    <91, 60, 59>,
    <91, 59, 92>,
    <91, 92, 93>,
    <91, 93, 94>,
    <91, 94, 89>,
    <91, 89, 88>,
    <95, 92, 59>,
    <95, 59, 64>,
    <95, 64, 63>,
    <95, 63, 96>,
    <95, 96, 97>,
    <95, 97, 98>,
    <95, 98, 93>,
    <95, 93, 92>,
    <99, 96, 63>,
    <99, 63, 68>,
    <99, 68, 67>,
    <99, 67, 100>,
    <99, 100, 101>,
    <99, 101, 102>,
    <99, 102, 97>,
    <99, 97, 96>,
    <103, 104, 74>,
    <103, 74, 73>,
    <103, 73, 72>,
    <103, 72, 105>,
    <103, 105, 106>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 108, 104>,
    <109, 105, 72>,
    <109, 72, 78>,
    <109, 78, 77>,
    <109, 77, 110>,
    <109, 110, 111>,
    <109, 111, 112>,
    <109, 112, 106>,
    <109, 106, 105>,
    <113, 110, 77>,
    <113, 77, 82>,
    <113, 82, 81>,
    <113, 81, 114>,
    <113, 114, 115>,
    <113, 115, 116>,
    <113, 116, 111>,
    <113, 111, 110>,
    <117, 114, 81>,
    <117, 81, 86>,
    <117, 86, 85>,
    <117, 85, 118>,
    <117, 118, 119>,
    <117, 119, 120>,
    <117, 120, 115>,
    <117, 115, 114>,
    <121, 118, 85>,
    <121, 85, 90>,
    <121, 90, 89>,
    <121, 89, 122>,
    <121, 122, 123>,
    <121, 123, 124>,
    <121, 124, 119>,
    <121, 119, 118>,
    <125, 122, 89>,
    <125, 89, 94>,
    <125, 94, 93>,
    <125, 93, 126>,
    <125, 126, 127>,
    <125, 127, 128>,
    <125, 128, 123>,
    <125, 123, 122>,
    <129, 126, 93>,
    <129, 93, 98>,
    <129, 98, 97>,
    <129, 97, 130>,
    <129, 130, 131>,
    <129, 131, 132>,
    <129, 132, 127>,
    <129, 127, 126>,
    <133, 130, 97>,
    <133, 97, 102>,
    <133, 102, 101>,
    <133, 101, 134>,
    <133, 134, 135>,
    <133, 135, 136>,
    <133, 136, 131>,
    <133, 131, 130>,
    <137, 138, 108>,
    <137, 108, 107>,
    <137, 107, 106>,
    <137, 106, 139>,
    <137, 139, 140>,
    <137, 140, 141>,
    <137, 141, 142>,
    <137, 142, 138>,
    <143, 139, 106>,
    <143, 106, 112>,
    <143, 112, 111>,
    <143, 111, 144>,
    <143, 144, 145>,
    <143, 145, 146>,
    <143, 146, 140>,
    <143, 140, 139>,
    <147, 144, 111>,
    <147, 111, 116>,
    <147, 116, 115>,
    <147, 115, 148>,
    <147, 148, 149>,
    <147, 149, 150>,
    <147, 150, 145>,
    <147, 145, 144>,
    <151, 148, 115>,
    <151, 115, 120>,
    <151, 120, 119>,
    <151, 119, 152>,
    <151, 152, 153>,
    <151, 153, 154>,
    <151, 154, 149>,
    <151, 149, 148>,
    <155, 152, 119>,
    <155, 119, 124>,
    <155, 124, 123>,
    <155, 123, 156>,
    <155, 156, 157>,
    <155, 157, 158>,
    <155, 158, 153>,
    <155, 153, 152>,
    <159, 156, 123>,
    <159, 123, 128>,
    <159, 128, 127>,
    <159, 127, 160>,
    <159, 160, 161>,
    <159, 161, 162>,
    <159, 162, 157>,
    <159, 157, 156>,
    <163, 160, 127>,
    <163, 127, 132>,
    <163, 132, 131>,
    <163, 131, 164>,
    <163, 164, 165>,
    <163, 165, 166>,
    <163, 166, 161>,
    <163, 161, 160>,
    <167, 164, 131>,
    <167, 131, 136>,
    <167, 136, 135>,
    <167, 135, 168>,
    <167, 168, 169>,
    <167, 169, 170>,
    <167, 170, 165>,
    <167, 165, 164>,
    <171, 172, 142>,
    <171, 142, 141>,
    <171, 141, 140>,
    <171, 140, 173>,
    <171, 173, 174>,
    <171, 174, 175>,
    <171, 175, 176>,
    <171, 176, 172>,
    <177, 173, 140>,
    <177, 140, 146>,
    <177, 146, 145>,
    <177, 145, 178>,
    <177, 178, 179>,
    <177, 179, 180>,
    <177, 180, 174>,
    <177, 174, 173>,
    <181, 178, 145>,
    <181, 145, 150>,
    <181, 150, 149>,
    <181, 149, 182>,
    <181, 182, 183>,
    <181, 183, 184>,
    <181, 184, 179>,
    <181, 179, 178>,
    <185, 182, 149>,
    <185, 149, 154>,
    <185, 154, 153>,
    <185, 153, 186>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 183>,
    <185, 183, 182>,
    <189, 186, 153>,
    <189, 153, 158>,
    <189, 158, 157>,
    <189, 157, 190>,
    <189, 190, 191>,
    <189, 191, 192>,
    <189, 192, 187>,
    <189, 187, 186>,
    <193, 190, 157>,
    <193, 157, 162>,
    <193, 162, 161>,
    <193, 161, 194>,
    <193, 194, 195>,
    <193, 195, 196>,
    <193, 196, 191>,
    <193, 191, 190>,
    <197, 194, 161>,
    <197, 161, 166>,
    <197, 166, 165>,
    <197, 165, 198>,
    <197, 198, 199>,
    <197, 199, 200>,
    <197, 200, 195>,
    <197, 195, 194>,
    <201, 198, 165>,
    <201, 165, 170>,
    <201, 170, 169>,
    <201, 169, 202>,
    <201, 202, 203>,
    <201, 203, 204>,
    <201, 204, 199>,
    <201, 199, 198>,
    <205, 206, 176>,
    <205, 176, 175>,
    <205, 175, 174>,
    <205, 174, 207>,
    <205, 207, 208>,
    <205, 208, 209>,
    <205, 209, 210>,
    <205, 210, 206>,
    <211, 207, 174>,
    <211, 174, 180>,
    <211, 180, 179>,
    <211, 179, 212>,
    <211, 212, 213>,
    <211, 213, 214>,
    <211, 214, 208>,
    <211, 208, 207>,
    <215, 212, 179>,
    <215, 179, 184>,
    <215, 184, 183>,
    <215, 183, 216>,
    <215, 216, 217>,
    <215, 217, 218>,
    <215, 218, 213>,
    <215, 213, 212>,
    <219, 216, 183>,
    <219, 183, 188>,
    <219, 188, 187>,
    <219, 187, 220>,
    <219, 220, 221>,
    <219, 221, 222>,
    <219, 222, 217>,
    <219, 217, 216>,
    <223, 220, 187>,
    <223, 187, 192>,
    <223, 192, 191>,
    <223, 191, 224>,
    <223, 224, 225>,
    <223, 225, 226>,
    <223, 226, 221>,
    <223, 221, 220>,
    <227, 224, 191>,
    <227, 191, 196>,
    <227, 196, 195>,
    <227, 195, 228>,
    <227, 228, 229>,
    <227, 229, 230>,
    <227, 230, 225>,
    <227, 225, 224>,
    <231, 228, 195>,
    <231, 195, 200>,
    <231, 200, 199>,
    <231, 199, 232>,
    <231, 232, 233>,
    <231, 233, 234>,
    <231, 234, 229>,
    <231, 229, 228>,
    <235, 232, 199>,
    <235, 199, 204>,
    <235, 204, 203>,
    <235, 203, 236>,
    <235, 236, 237>,
    <235, 237, 238>,
    <235, 238, 233>,
    <235, 233, 232>,
    <239, 240, 210>,
    <239, 210, 209>,
    <239, 209, 208>,
    <239, 208, 241>,
    <239, 241, 242>,
    <239, 242, 243>,
    <239, 243, 244>,
    <239, 244, 240>,
    <245, 241, 208>,
    <245, 208, 214>,
    <245, 214, 213>,
    <245, 213, 246>,
    <245, 246, 247>,
    <245, 247, 248>,
    <245, 248, 242>,
    <245, 242, 241>,
    <249, 246, 213>,
    <249, 213, 218>,
    <249, 218, 217>,
    <249, 217, 250>,
    <249, 250, 251>,
    <249, 251, 252>,
    <249, 252, 247>,
    <249, 247, 246>,
    <253, 250, 217>,
    <253, 217, 222>,
    <253, 222, 221>,
    <253, 221, 254>,
    <253, 254, 255>,
    <253, 255, 256>,
    <253, 256, 251>,
    <253, 251, 250>,
    <257, 254, 221>,
    <257, 221, 226>,
    <257, 226, 225>,
    <257, 225, 258>,
    <257, 258, 259>,
    <257, 259, 260>,
    <257, 260, 255>,
    <257, 255, 254>,
    <261, 258, 225>,
    <261, 225, 230>,
    <261, 230, 229>,
    <261, 229, 262>,
    <261, 262, 263>,
    <261, 263, 264>,
    <261, 264, 259>,
    <261, 259, 258>,
    <265, 262, 229>,
    <265, 229, 234>,
    <265, 234, 233>,
    <265, 233, 266>,
    <265, 266, 267>,
    <265, 267, 268>,
    <265, 268, 263>,
    <265, 263, 262>,
    <269, 266, 233>,
    <269, 233, 238>,
    <269, 238, 237>,
    <269, 237, 270>,
    <269, 270, 271>,
    <269, 271, 272>,
    <269, 272, 267>,
    <269, 267, 266>,
    <273, 32, 2>,
    <273, 2, 274>,
    <273, 274, 275>,
    <273, 275, 276>,
    <273, 276, 33>,
    <273, 33, 32>,
    <277, 274, 2>,
    <277, 2, 278>,
    <277, 278, 279>,
    <277, 279, 280>,
    <277, 280, 275>,
    <277, 275, 274>,
    <281, 278, 2>,
    <281, 2, 282>,
    <281, 282, 283>,
    <281, 283, 284>,
    <281, 284, 279>,
    <281, 279, 278>,
    <285, 282, 2>,
    <285, 2, 286>,
    <285, 286, 287>,
    <285, 287, 288>,
    <285, 288, 283>,
    <285, 283, 282>,
    <289, 286, 2>,
    <289, 2, 290>,
    <289, 290, 291>,
    <289, 291, 292>,
    <289, 292, 287>,
    <289, 287, 286>,
    <293, 290, 2>,
    <293, 2, 294>,
    <293, 294, 295>,
    <293, 295, 296>,
    <293, 296, 291>,
    <293, 291, 290>,
    <297, 294, 2>,
    <297, 2, 298>,
    <297, 298, 299>,
    <297, 299, 300>,
    <297, 300, 295>,
    <297, 295, 294>,
    <301, 298, 2>,
    <301, 2, 1>,
    <301, 1, 6>,
    <301, 6, 302>,
    <301, 302, 299>,
    <301, 299, 298>,
    <303, 66, 33>,
    <303, 33, 276>,
    <303, 276, 275>,
    <303, 275, 304>,
    <303, 304, 305>,
    <303, 305, 306>,
    <303, 306, 67>,
    <303, 67, 66>,
    <307, 304, 275>,
    <307, 275, 280>,
    <307, 280, 279>,
    <307, 279, 308>,
    <307, 308, 309>,
    <307, 309, 310>,
    <307, 310, 305>,
    <307, 305, 304>,
    <311, 308, 279>,
    <311, 279, 284>,
    <311, 284, 283>,
    <311, 283, 312>,
    <311, 312, 313>,
    <311, 313, 314>,
    <311, 314, 309>,
    <311, 309, 308>,
    <315, 312, 283>,
    <315, 283, 288>,
    <315, 288, 287>,
    <315, 287, 316>,
    <315, 316, 317>,
    <315, 317, 318>,
    <315, 318, 313>,
    <315, 313, 312>,
    <319, 316, 287>,
    <319, 287, 292>,
    <319, 292, 291>,
    <319, 291, 320>,
    <319, 320, 321>,
    <319, 321, 322>,
    <319, 322, 317>,
    <319, 317, 316>,
    <323, 320, 291>,
    <323, 291, 296>,
    <323, 296, 295>,
    <323, 295, 324>,
    <323, 324, 325>,
    <323, 325, 326>,
    <323, 326, 321>,
    <323, 321, 320>,
    <327, 324, 295>,
    <327, 295, 300>,
    <327, 300, 299>,
    <327, 299, 328>,
    <327, 328, 329>,
    <327, 329, 330>,
    <327, 330, 325>,
    <327, 325, 324>,
    <331, 328, 299>,
    <331, 299, 302>,
    <331, 302, 6>,
    <331, 6, 36>,
    <331, 36, 40>,
    <331, 40, 332>,
    <331, 332, 329>,
    <331, 329, 328>,
    <333, 100, 67>,
    <333, 67, 306>,
    <333, 306, 305>,
    <333, 305, 334>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 101>,
    <333, 101, 100>,
    <337, 334, 305>,
    <337, 305, 310>,
    <337, 310, 309>,
    <337, 309, 338>,
    <337, 338, 339>,
    <337, 339, 340>,
    <337, 340, 335>,
    <337, 335, 334>,
    <341, 338, 309>,
    <341, 309, 314>,
    <341, 314, 313>,
    <341, 313, 342>,
    <341, 342, 343>,
    <341, 343, 344>,
    <341, 344, 339>,
    <341, 339, 338>,
    <345, 342, 313>,
    <345, 313, 318>,
    <345, 318, 317>,
    <345, 317, 346>,
    <345, 346, 347>,
    <345, 347, 348>,
    <345, 348, 343>,
    <345, 343, 342>,
    <349, 346, 317>,
    <349, 317, 322>,
    <349, 322, 321>,
    <349, 321, 350>,
    <349, 350, 351>,
    <349, 351, 352>,
    <349, 352, 347>,
    <349, 347, 346>,
    <353, 350, 321>,
    <353, 321, 326>,
    <353, 326, 325>,
    <353, 325, 354>,
    <353, 354, 355>,
    <353, 355, 356>,
    <353, 356, 351>,
    <353, 351, 350>,
    <357, 354, 325>,
    <357, 325, 330>,
    <357, 330, 329>,
    <357, 329, 358>,
    <357, 358, 359>,
    <357, 359, 360>,
    <357, 360, 355>,
    <357, 355, 354>,
    <361, 358, 329>,
    <361, 329, 332>,
    <361, 332, 40>,
    <361, 40, 70>,
    <361, 70, 74>,
    <361, 74, 362>,
    <361, 362, 359>,
    <361, 359, 358>,
    <363, 134, 101>,
    <363, 101, 336>,
    <363, 336, 335>,
    <363, 335, 364>,
    <363, 364, 365>,
    <363, 365, 366>,
    <363, 366, 135>,
    <363, 135, 134>,
    <367, 364, 335>,
    <367, 335, 340>,
    <367, 340, 339>,
    <367, 339, 368>,
    <367, 368, 369>,
    <367, 369, 370>,
    <367, 370, 365>,
    <367, 365, 364>,
    <371, 368, 339>,
    <371, 339, 344>,
    <371, 344, 343>,
    <371, 343, 372>,
    <371, 372, 373>,
    <371, 373, 374>,
    <371, 374, 369>,
    <371, 369, 368>,
    <375, 372, 343>,
    <375, 343, 348>,
    <375, 348, 347>,
    <375, 347, 376>,
    <375, 376, 377>,
    <375, 377, 378>,
    <375, 378, 373>,
    <375, 373, 372>,
    <379, 376, 347>,
    <379, 347, 352>,
    <379, 352, 351>,
    <379, 351, 380>,
    <379, 380, 381>,
    <379, 381, 382>,
    <379, 382, 377>,
    <379, 377, 376>,
    <383, 380, 351>,
    <383, 351, 356>,
    <383, 356, 355>,
    <383, 355, 384>,
    <383, 384, 385>,
    <383, 385, 386>,
    <383, 386, 381>,
    <383, 381, 380>,
    <387, 384, 355>,
    <387, 355, 360>,
    <387, 360, 359>,
    <387, 359, 388>,
    <387, 388, 389>,
    <387, 389, 390>,
    <387, 390, 385>,
    <387, 385, 384>,
    <391, 388, 359>,
    <391, 359, 362>,
    <391, 362, 74>,
    <391, 74, 104>,
    <391, 104, 108>,
    <391, 108, 392>,
    <391, 392, 389>,
    <391, 389, 388>,
    <393, 168, 135>,
    <393, 135, 366>,
    <393, 366, 365>,
    <393, 365, 394>,
    <393, 394, 395>,
    <393, 395, 396>,
    <393, 396, 169>,
    <393, 169, 168>,
    <397, 394, 365>,
    <397, 365, 370>,
    <397, 370, 369>,
    <397, 369, 398>,
    <397, 398, 399>,
    <397, 399, 400>,
    <397, 400, 395>,
    <397, 395, 394>,
    <401, 398, 369>,
    <401, 369, 374>,
    <401, 374, 373>,
    <401, 373, 402>,
    <401, 402, 403>,
    <401, 403, 404>,
    <401, 404, 399>,
    <401, 399, 398>,
    <405, 402, 373>,
    <405, 373, 378>,
    <405, 378, 377>,
    <405, 377, 406>,
    <405, 406, 407>,
    <405, 407, 408>,
    <405, 408, 403>,
    <405, 403, 402>,
    <409, 406, 377>,
    <409, 377, 382>,
    <409, 382, 381>,
    <409, 381, 410>,
    <409, 410, 411>,
    <409, 411, 412>,
    <409, 412, 407>,
    <409, 407, 406>,
    <413, 410, 381>,
    <413, 381, 386>,
    <413, 386, 385>,
    <413, 385, 414>,
    <413, 414, 415>,
    <413, 415, 416>,
    <413, 416, 411>,
    <413, 411, 410>,
    <417, 414, 385>,
    <417, 385, 390>,
    <417, 390, 389>,
    <417, 389, 418>,
    <417, 418, 419>,
    <417, 419, 420>,
    <417, 420, 415>,
    <417, 415, 414>,
    <421, 418, 389>,
    <421, 389, 392>,
    <421, 392, 108>,
    <421, 108, 138>,
    <421, 138, 142>,
    <421, 142, 422>,
    <421, 422, 419>,
    <421, 419, 418>,
    <423, 202, 169>,
    <423, 169, 396>,
    <423, 396, 395>,
    <423, 395, 424>,
    <423, 424, 425>,
    <423, 425, 426>,
    <423, 426, 203>,
    <423, 203, 202>,
    <427, 424, 395>,
    <427, 395, 400>,
    <427, 400, 399>,
    <427, 399, 428>,
    <427, 428, 429>,
    <427, 429, 430>,
    <427, 430, 425>,
    <427, 425, 424>,
    <431, 428, 399>,
    <431, 399, 404>,
    <431, 404, 403>,
    <431, 403, 432>,
    <431, 432, 433>,
    <431, 433, 434>,
    <431, 434, 429>,
    <431, 429, 428>,
    <435, 432, 403>,
    <435, 403, 408>,
    <435, 408, 407>,
    <435, 407, 436>,
    <435, 436, 437>,
    <435, 437, 438>,
    <435, 438, 433>,
    <435, 433, 432>,
    <439, 436, 407>,
    <439, 407, 412>,
    <439, 412, 411>,
    <439, 411, 440>,
    <439, 440, 441>,
    <439, 441, 442>,
    <439, 442, 437>,
    <439, 437, 436>,
    <443, 440, 411>,
    <443, 411, 416>,
    <443, 416, 415>,
    <443, 415, 444>,
    <443, 444, 445>,
    <443, 445, 446>,
    <443, 446, 441>,
    <443, 441, 440>,
    <447, 444, 415>,
    <447, 415, 420>,
    <447, 420, 419>,
    <447, 419, 448>,
    <447, 448, 449>,
    <447, 449, 450>,
    <447, 450, 445>,
    <447, 445, 444>,
    <451, 448, 419>,
    <451, 419, 422>,
    <451, 422, 142>,
    <451, 142, 172>,
    <451, 172, 176>,
    <451, 176, 452>,
    <451, 452, 449>,
    <451, 449, 448>,
    <453, 236, 203>,
    <453, 203, 426>,
    <453, 426, 425>,
    <453, 425, 454>,
    <453, 454, 455>,
    <453, 455, 456>,
    <453, 456, 237>,
    <453, 237, 236>,
    <457, 454, 425>,
    <457, 425, 430>,
    <457, 430, 429>,
    <457, 429, 458>,
    <457, 458, 459>,
    <457, 459, 460>,
    <457, 460, 455>,
    <457, 455, 454>,
    <461, 458, 429>,
    <461, 429, 434>,
    <461, 434, 433>,
    <461, 433, 462>,
    <461, 462, 463>,
    <461, 463, 464>,
    <461, 464, 459>,
    <461, 459, 458>,
    <465, 462, 433>,
    <465, 433, 438>,
    <465, 438, 437>,
    <465, 437, 466>,
    <465, 466, 467>,
    <465, 467, 468>,
    <465, 468, 463>,
    <465, 463, 462>,
    <469, 466, 437>,
    <469, 437, 442>,
    <469, 442, 441>,
    <469, 441, 470>,
    <469, 470, 471>,
    <469, 471, 472>,
    <469, 472, 467>,
    <469, 467, 466>,
    <473, 470, 441>,
    <473, 441, 446>,
    <473, 446, 445>,
    <473, 445, 474>,
    <473, 474, 475>,
    <473, 475, 476>,
    <473, 476, 471>,
    <473, 471, 470>,
    <477, 474, 445>,
    <477, 445, 450>,
    <477, 450, 449>,
    <477, 449, 478>,
    <477, 478, 479>,
    <477, 479, 480>,
    <477, 480, 475>,
    <477, 475, 474>,
    <481, 478, 449>,
    <481, 449, 452>,
    <481, 452, 176>,
    <481, 176, 206>,
    <481, 206, 210>,
    <481, 210, 482>,
    <481, 482, 479>,
    <481, 479, 478>,
    <483, 270, 237>,
    <483, 237, 456>,
    <483, 456, 455>,
    <483, 455, 484>,
    <483, 484, 485>,
    <483, 485, 486>,
    <483, 486, 271>,
    <483, 271, 270>,
    <487, 484, 455>,
    <487, 455, 460>,
    <487, 460, 459>,
    <487, 459, 488>,
    <487, 488, 489>,
    <487, 489, 490>,
    <487, 490, 485>,
    <487, 485, 484>,
    <491, 488, 459>,
    <491, 459, 464>,
    <491, 464, 463>,
    <491, 463, 492>,
    <491, 492, 493>,
    <491, 493, 494>,
    <491, 494, 489>,
    <491, 489, 488>,
    <495, 492, 463>,
    <495, 463, 468>,
    <495, 468, 467>,
    <495, 467, 496>,
    <495, 496, 497>,
    <495, 497, 498>,
    <495, 498, 493>,
    <495, 493, 492>,
    <499, 496, 467>,
    <499, 467, 472>,
    <499, 472, 471>,
    <499, 471, 500>,
    <499, 500, 501>,
    <499, 501, 502>,
    <499, 502, 497>,
    <499, 497, 496>,
    <503, 500, 471>,
    <503, 471, 476>,
    <503, 476, 475>,
    <503, 475, 504>,
    <503, 504, 505>,
    <503, 505, 506>,
    <503, 506, 501>,
    <503, 501, 500>,
    <507, 504, 475>,
    <507, 475, 480>,
    <507, 480, 479>,
    <507, 479, 508>,
    <507, 508, 509>,
    <507, 509, 510>,
    <507, 510, 505>,
    <507, 505, 504>,
    <511, 508, 479>,
    <511, 479, 482>,
    <511, 482, 210>,
    <511, 210, 240>,
    <511, 240, 244>,
    <511, 244, 512>,
    <511, 512, 509>,
    <511, 509, 508>,
    <513, 514, 244>,
    <513, 244, 243>,
    <513, 243, 242>,
    <513, 242, 515>,
    <513, 515, 516>,
    <513, 516, 517>,
    <513, 517, 518>,
    <513, 518, 514>,
    <519, 515, 242>,
    <519, 242, 248>,
    <519, 248, 247>,
    <519, 247, 520>,
    <519, 520, 521>,
    <519, 521, 522>,
    <519, 522, 516>,
    <519, 516, 515>,
    <523, 520, 247>,
    <523, 247, 252>,
    <523, 252, 251>,
    <523, 251, 524>,
    <523, 524, 525>,
    <523, 525, 526>,
    <523, 526, 521>,
    <523, 521, 520>,
    <527, 524, 251>,
    <527, 251, 256>,
    <527, 256, 255>,
    <527, 255, 528>,
    <527, 528, 529>,
    <527, 529, 530>,
    <527, 530, 525>,
    <527, 525, 524>,
    <531, 528, 255>,
    <531, 255, 260>,
    <531, 260, 259>,
    <531, 259, 532>,
    <531, 532, 533>,
    <531, 533, 534>,
    <531, 534, 529>,
    <531, 529, 528>,
    <535, 532, 259>,
    <535, 259, 264>,
    <535, 264, 263>,
    <535, 263, 536>,
    <535, 536, 537>,
    <535, 537, 538>,
    <535, 538, 533>,
    <535, 533, 532>,
    <539, 536, 263>,
    <539, 263, 268>,
    <539, 268, 267>,
    <539, 267, 540>,
    <539, 540, 541>,
    <539, 541, 542>,
    <539, 542, 537>,
    <539, 537, 536>,
    <543, 540, 267>,
    <543, 267, 272>,
    <543, 272, 271>,
    <543, 271, 544>,
    <543, 544, 545>,
    <543, 545, 546>,
    <543, 546, 541>,
    <543, 541, 540>,
    <547, 548, 518>,
    <547, 518, 517>,
    <547, 517, 516>,
    <547, 516, 549>,
    <547, 549, 550>,
    <547, 550, 551>,
    <547, 551, 552>,
    <547, 552, 548>,
    <553, 549, 516>,
    <553, 516, 522>,
    <553, 522, 521>,
    <553, 521, 554>,
    <553, 554, 555>,
    <553, 555, 556>,
    <553, 556, 550>,
    <553, 550, 549>,
    <557, 554, 521>,
    <557, 521, 526>,
    <557, 526, 525>,
    <557, 525, 558>,
    <557, 558, 559>,
    <557, 559, 560>,
    <557, 560, 555>,
    <557, 555, 554>,
    <561, 558, 525>,
    <561, 525, 530>,
    <561, 530, 529>,
    <561, 529, 562>,
    <561, 562, 563>,
    <561, 563, 564>,
    <561, 564, 559>,
    <561, 559, 558>,
    <565, 562, 529>,
    <565, 529, 534>,
    <565, 534, 533>,
    <565, 533, 566>,
    <565, 566, 567>,
    <565, 567, 568>,
    <565, 568, 563>,
    <565, 563, 562>,
    <569, 566, 533>,
    <569, 533, 538>,
    <569, 538, 537>,
    <569, 537, 570>,
    <569, 570, 571>,
    <569, 571, 572>,
    <569, 572, 567>,
    <569, 567, 566>,
    <573, 570, 537>,
    <573, 537, 542>,
    <573, 542, 541>,
    <573, 541, 574>,
    <573, 574, 575>,
    <573, 575, 576>,
    <573, 576, 571>,
    <573, 571, 570>,
    <577, 574, 541>,
    <577, 541, 546>,
    <577, 546, 545>,
    <577, 545, 578>,
    <577, 578, 579>,
    <577, 579, 580>,
    <577, 580, 575>,
    <577, 575, 574>,
    <581, 582, 552>,
    <581, 552, 551>,
    <581, 551, 550>,
    <581, 550, 583>,
    <581, 583, 584>,
    <581, 584, 585>,
    <581, 585, 586>,
    <581, 586, 582>,
    <587, 583, 550>,
    <587, 550, 556>,
    <587, 556, 555>,
    <587, 555, 588>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 584>,
    <587, 584, 583>,
    <591, 588, 555>,
    <591, 555, 560>,
    <591, 560, 559>,
    <591, 559, 592>,
    <591, 592, 593>,
    <591, 593, 594>,
    <591, 594, 589>,
    <591, 589, 588>,
    <595, 592, 559>,
    <595, 559, 564>,
    <595, 564, 563>,
    <595, 563, 596>,
    <595, 596, 597>,
    <595, 597, 598>,
    <595, 598, 593>,
    <595, 593, 592>,
    <599, 596, 563>,
    <599, 563, 568>,
    <599, 568, 567>,
    <599, 567, 600>,
    <599, 600, 601>,
    <599, 601, 602>,
    <599, 602, 597>,
    <599, 597, 596>,
    <603, 600, 567>,
    <603, 567, 572>,
    <603, 572, 571>,
    <603, 571, 604>,
    <603, 604, 605>,
    <603, 605, 606>,
    <603, 606, 601>,
    <603, 601, 600>,
    <607, 604, 571>,
    <607, 571, 576>,
    <607, 576, 575>,
    <607, 575, 608>,
    <607, 608, 609>,
    <607, 609, 610>,
    <607, 610, 605>,
    <607, 605, 604>,
    <611, 608, 575>,
    <611, 575, 580>,
    <611, 580, 579>,
    <611, 579, 612>,
    <611, 612, 613>,
    <611, 613, 614>,
    <611, 614, 609>,
    <611, 609, 608>,
    <615, 616, 586>,
    <615, 586, 585>,
    <615, 585, 584>,
    <615, 584, 617>,
    <615, 617, 618>,
    <615, 618, 619>,
    <615, 619, 620>,
    <615, 620, 616>,
    <621, 617, 584>,
    <621, 584, 590>,
    <621, 590, 589>,
    <621, 589, 622>,
    <621, 622, 623>,
    <621, 623, 624>,
    <621, 624, 618>,
    <621, 618, 617>,
    <625, 622, 589>,
    <625, 589, 594>,
    <625, 594, 593>,
    <625, 593, 626>,
    <625, 626, 627>,
    <625, 627, 628>,
    <625, 628, 623>,
    <625, 623, 622>,
    <629, 626, 593>,
    <629, 593, 598>,
    <629, 598, 597>,
    <629, 597, 630>,
    <629, 630, 631>,
    <629, 631, 632>,
    <629, 632, 627>,
    <629, 627, 626>,
    <633, 630, 597>,
    <633, 597, 602>,
    <633, 602, 601>,
    <633, 601, 634>,
    <633, 634, 635>,
    <633, 635, 636>,
    <633, 636, 631>,
    <633, 631, 630>,
    <637, 634, 601>,
    <637, 601, 606>,
    <637, 606, 605>,
    <637, 605, 638>,
    <637, 638, 639>,
    <637, 639, 640>,
    <637, 640, 635>,
    <637, 635, 634>,
    <641, 638, 605>,
    <641, 605, 610>,
    <641, 610, 609>,
    <641, 609, 642>,
    <641, 642, 643>,
    <641, 643, 644>,
    <641, 644, 639>,
    <641, 639, 638>,
    <645, 642, 609>,
    <645, 609, 614>,
    <645, 614, 613>,
    <645, 613, 646>,
    <645, 646, 647>,
    <645, 647, 648>,
    <645, 648, 643>,
    <645, 643, 642>,
    <649, 650, 620>,
    <649, 620, 619>,
    <649, 619, 618>,
    <649, 618, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 654, 650>,
    <655, 651, 618>,
    <655, 618, 624>,
    <655, 624, 623>,
    <655, 623, 656>,
    <655, 656, 657>,
    <655, 657, 658>,
    <655, 658, 652>,
    <655, 652, 651>,
    <659, 656, 623>,
    <659, 623, 628>,
    <659, 628, 627>,
    <659, 627, 660>,
    <659, 660, 661>,
    <659, 661, 662>,
    <659, 662, 657>,
    <659, 657, 656>,
    <663, 660, 627>,
    <663, 627, 632>,
    <663, 632, 631>,
    <663, 631, 664>,
    <663, 664, 665>,
    <663, 665, 666>,
    <663, 666, 661>,
    <663, 661, 660>,
    <667, 664, 631>,
    <667, 631, 636>,
    <667, 636, 635>,
    <667, 635, 668>,
    <667, 668, 669>,
    <667, 669, 670>,
    <667, 670, 665>,
    <667, 665, 664>,
    <671, 668, 635>,
    <671, 635, 640>,
    <671, 640, 639>,
    <671, 639, 672>,
    <671, 672, 673>,
    <671, 673, 674>,
    <671, 674, 669>,
    <671, 669, 668>,
    <675, 672, 639>,
    <675, 639, 644>,
    <675, 644, 643>,
    <675, 643, 676>,
    <675, 676, 677>,
    <675, 677, 678>,
    <675, 678, 673>,
    <675, 673, 672>,
    <679, 676, 643>,
    <679, 643, 648>,
    <679, 648, 647>,
    <679, 647, 680>,
    <679, 680, 681>,
    <679, 681, 682>,
    <679, 682, 677>,
    <679, 677, 676>,
    <683, 684, 654>,
    <683, 654, 653>,
    <683, 653, 652>,
    <683, 652, 685>,
    <683, 685, 686>,
    <683, 686, 687>,
    <683, 687, 688>,
    <683, 688, 684>,
    <689, 685, 652>,
    <689, 652, 658>,
    <689, 658, 657>,
    <689, 657, 690>,
    <689, 690, 691>,
    <689, 691, 692>,
    <689, 692, 686>,
    <689, 686, 685>,
    <693, 690, 657>,
    <693, 657, 662>,
    <693, 662, 661>,
    <693, 661, 694>,
    <693, 694, 695>,
    <693, 695, 696>,
    <693, 696, 691>,
    <693, 691, 690>,
    <697, 694, 661>,
    <697, 661, 666>,
    <697, 666, 665>,
    <697, 665, 698>,
    <697, 698, 699>,
    <697, 699, 700>,
    <697, 700, 695>,
    <697, 695, 694>,
    <701, 698, 665>,
    <701, 665, 670>,
    <701, 670, 669>,
    <701, 669, 702>,
    <701, 702, 703>,
    <701, 703, 704>,
    <701, 704, 699>,
    <701, 699, 698>,
    <705, 702, 669>,
    <705, 669, 674>,
    <705, 674, 673>,
    <705, 673, 706>,
    <705, 706, 707>,
    <705, 707, 708>,
    <705, 708, 703>,
    <705, 703, 702>,
    <709, 706, 673>,
    <709, 673, 678>,
    <709, 678, 677>,
    <709, 677, 710>,
    <709, 710, 711>,
    <709, 711, 712>,
    <709, 712, 707>,
    <709, 707, 706>,
    <713, 710, 677>,
    <713, 677, 682>,
    <713, 682, 681>,
    <713, 681, 714>,
    <713, 714, 715>,
    <713, 715, 716>,
    <713, 716, 711>,
    <713, 711, 710>,
    <717, 718, 688>,
    <717, 688, 687>,
    <717, 687, 686>,
    <717, 686, 719>,
    <717, 719, 720>,
    <717, 720, 721>,
    <717, 721, 722>,
    <717, 722, 718>,
    <723, 719, 686>,
    <723, 686, 692>,
    <723, 692, 691>,
    <723, 691, 724>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 720>,
    <723, 720, 719>,
    <727, 724, 691>,
    <727, 691, 696>,
    <727, 696, 695>,
    <727, 695, 728>,
    <727, 728, 729>,
    <727, 729, 730>,
    <727, 730, 725>,
    <727, 725, 724>,
    <731, 728, 695>,
    <731, 695, 700>,
    <731, 700, 699>,
    <731, 699, 732>,
    <731, 732, 733>,
    <731, 733, 734>,
    <731, 734, 729>,
    <731, 729, 728>,
    <735, 732, 699>,
    <735, 699, 704>,
    <735, 704, 703>,
    <735, 703, 736>,
    <735, 736, 737>,
    <735, 737, 738>,
    <735, 738, 733>,
    <735, 733, 732>,
    <739, 736, 703>,
    <739, 703, 708>,
    <739, 708, 707>,
    <739, 707, 740>,
    <739, 740, 741>,
    <739, 741, 742>,
    <739, 742, 737>,
    <739, 737, 736>,
    <743, 740, 707>,
    <743, 707, 712>,
    <743, 712, 711>,
    <743, 711, 744>,
    <743, 744, 745>,
    <743, 745, 746>,
    <743, 746, 741>,
    <743, 741, 740>,
    <747, 744, 711>,
    <747, 711, 716>,
    <747, 716, 715>,
    <747, 715, 748>,
    <747, 748, 749>,
    <747, 749, 750>,
    <747, 750, 745>,
    <747, 745, 744>,
    <751, 752, 722>,
    <751, 722, 721>,
    <751, 721, 720>,
    <751, 720, 753>,
    <751, 753, 754>,
    <751, 754, 755>,
    <751, 755, 756>,
    <751, 756, 752>,
    <757, 753, 720>,
    <757, 720, 726>,
    <757, 726, 725>,
    <757, 725, 758>,
    <757, 758, 759>,
    <757, 759, 760>,
    <757, 760, 754>,
    <757, 754, 753>,
    <761, 758, 725>,
    <761, 725, 730>,
    <761, 730, 729>,
    <761, 729, 762>,
    <761, 762, 763>,
    <761, 763, 764>,
    <761, 764, 759>,
    <761, 759, 758>,
    <765, 762, 729>,
    <765, 729, 734>,
    <765, 734, 733>,
    <765, 733, 766>,
    <765, 766, 767>,
    <765, 767, 768>,
    <765, 768, 763>,
    <765, 763, 762>,
    <769, 766, 733>,
    <769, 733, 738>,
    <769, 738, 737>,
    <769, 737, 770>,
    <769, 770, 771>,
    <769, 771, 772>,
    <769, 772, 767>,
    <769, 767, 766>,
    <773, 770, 737>,
    <773, 737, 742>,
    <773, 742, 741>,
    <773, 741, 774>,
    <773, 774, 775>,
    <773, 775, 776>,
    <773, 776, 771>,
    <773, 771, 770>,
    <777, 774, 741>,
    <777, 741, 746>,
    <777, 746, 745>,
    <777, 745, 778>,
    <777, 778, 779>,
    <777, 779, 780>,
    <777, 780, 775>,
    <777, 775, 774>,
    <781, 778, 745>,
    <781, 745, 750>,
    <781, 750, 749>,
    <781, 749, 782>,
    <781, 782, 783>,
    <781, 783, 784>,
    <781, 784, 779>,
    <781, 779, 778>,
    <785, 544, 271>,
    <785, 271, 486>,
    <785, 486, 485>,
    <785, 485, 786>,
    <785, 786, 787>,
    <785, 787, 788>,
    <785, 788, 545>,
    <785, 545, 544>,
    <789, 786, 485>,
    <789, 485, 490>,
    <789, 490, 489>,
    <789, 489, 790>,
    <789, 790, 791>,
    <789, 791, 792>,
    <789, 792, 787>,
    <789, 787, 786>,
    <793, 790, 489>,
    <793, 489, 494>,
    <793, 494, 493>,
    <793, 493, 794>,
    <793, 794, 795>,
    <793, 795, 796>,
    <793, 796, 791>,
    <793, 791, 790>,
    <797, 794, 493>,
    <797, 493, 498>,
    <797, 498, 497>,
    <797, 497, 798>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 795>,
    <797, 795, 794>,
    <801, 798, 497>,
    <801, 497, 502>,
    <801, 502, 501>,
    <801, 501, 802>,
    <801, 802, 803>,
    <801, 803, 804>,
    <801, 804, 799>,
    <801, 799, 798>,
    <805, 802, 501>,
    <805, 501, 506>,
    <805, 506, 505>,
    <805, 505, 806>,
    <805, 806, 807>,
    <805, 807, 808>,
    <805, 808, 803>,
    <805, 803, 802>,
    <809, 806, 505>,
    <809, 505, 510>,
    <809, 510, 509>,
    <809, 509, 810>,
    <809, 810, 811>,
    <809, 811, 812>,
    <809, 812, 807>,
    <809, 807, 806>,
    <813, 810, 509>,
    <813, 509, 512>,
    <813, 512, 244>,
    <813, 244, 514>,
    <813, 514, 518>,
    <813, 518, 814>,
    <813, 814, 811>,
    <813, 811, 810>,
    <815, 578, 545>,
    <815, 545, 788>,
    <815, 788, 787>,
    <815, 787, 816>,
    <815, 816, 817>,
    <815, 817, 818>,
    <815, 818, 579>,
    <815, 579, 578>,
    <819, 816, 787>,
    <819, 787, 792>,
    <819, 792, 791>,
    <819, 791, 820>,
    <819, 820, 821>,
    <819, 821, 822>,
    <819, 822, 817>,
    <819, 817, 816>,
    <823, 820, 791>,
    <823, 791, 796>,
    <823, 796, 795>,
    <823, 795, 824>,
    <823, 824, 825>,
    <823, 825, 826>,
    <823, 826, 821>,
    <823, 821, 820>,
    <827, 824, 795>,
    <827, 795, 800>,
    <827, 800, 799>,
    <827, 799, 828>,
    <827, 828, 829>,
    <827, 829, 830>,
    <827, 830, 825>,
    <827, 825, 824>,
    <831, 828, 799>,
    <831, 799, 804>,
    <831, 804, 803>,
    <831, 803, 832>,
    <831, 832, 833>,
    <831, 833, 834>,
    <831, 834, 829>,
    <831, 829, 828>,
    <835, 832, 803>,
    <835, 803, 808>,
    <835, 808, 807>,
    <835, 807, 836>,
    <835, 836, 837>,
    <835, 837, 838>,
    <835, 838, 833>,
    <835, 833, 832>,
    <839, 836, 807>,
    <839, 807, 812>,
    <839, 812, 811>,
    <839, 811, 840>,
    <839, 840, 841>,
    <839, 841, 842>,
    <839, 842, 837>,
    <839, 837, 836>,
    <843, 840, 811>,
    <843, 811, 814>,
    <843, 814, 518>,
    <843, 518, 548>,
    <843, 548, 552>,
    <843, 552, 844>,
    <843, 844, 841>,
    <843, 841, 840>,
    <845, 612, 579>,
    <845, 579, 818>,
    <845, 818, 817>,
    <845, 817, 846>,
    <845, 846, 847>,
    <845, 847, 848>,
    <845, 848, 613>,
    <845, 613, 612>,
    <849, 846, 817>,
    <849, 817, 822>,
    <849, 822, 821>,
    <849, 821, 850>,
    <849, 850, 851>,
    <849, 851, 852>,
    <849, 852, 847>,
    <849, 847, 846>,
    <853, 850, 821>,
    <853, 821, 826>,
    <853, 826, 825>,
    <853, 825, 854>,
    <853, 854, 855>,
    <853, 855, 856>,
    <853, 856, 851>,
    <853, 851, 850>,
    <857, 854, 825>,
    <857, 825, 830>,
    <857, 830, 829>,
    <857, 829, 858>,
    <857, 858, 859>,
    <857, 859, 860>,
    <857, 860, 855>,
    <857, 855, 854>,
    <861, 858, 829>,
    <861, 829, 834>,
    <861, 834, 833>,
    <861, 833, 862>,
    <861, 862, 863>,
    <861, 863, 864>,
    <861, 864, 859>,
    <861, 859, 858>,
    <865, 862, 833>,
    <865, 833, 838>,
    <865, 838, 837>,
    <865, 837, 866>,
    <865, 866, 867>,
    <865, 867, 868>,
    <865, 868, 863>,
    <865, 863, 862>,
    <869, 866, 837>,
    <869, 837, 842>,
    <869, 842, 841>,
    <869, 841, 870>,
    <869, 870, 871>,
    <869, 871, 872>,
    <869, 872, 867>,
    <869, 867, 866>,
    <873, 870, 841>,
    <873, 841, 844>,
    <873, 844, 552>,
    <873, 552, 582>,
    <873, 582, 586>,
    <873, 586, 874>,
    <873, 874, 871>,
    <873, 871, 870>,
    <875, 646, 613>,
    <875, 613, 848>,
    <875, 848, 847>,
    <875, 847, 876>,
    <875, 876, 877>,
    <875, 877, 878>,
    <875, 878, 647>,
    <875, 647, 646>,
    <879, 876, 847>,
    <879, 847, 852>,
    <879, 852, 851>,
    <879, 851, 880>,
    <879, 880, 881>,
    <879, 881, 882>,
    <879, 882, 877>,
    <879, 877, 876>,
    <883, 880, 851>,
    <883, 851, 856>,
    <883, 856, 855>,
    <883, 855, 884>,
    <883, 884, 885>,
    <883, 885, 886>,
    <883, 886, 881>,
    <883, 881, 880>,
    <887, 884, 855>,
    <887, 855, 860>,
    <887, 860, 859>,
    <887, 859, 888>,
    <887, 888, 889>,
    <887, 889, 890>,
    <887, 890, 885>,
    <887, 885, 884>,
    <891, 888, 859>,
    <891, 859, 864>,
    <891, 864, 863>,
    <891, 863, 892>,
    <891, 892, 893>,
    <891, 893, 894>,
    <891, 894, 889>,
    <891, 889, 888>,
    <895, 892, 863>,
    <895, 863, 868>,
    <895, 868, 867>,
    <895, 867, 896>,
    <895, 896, 897>,
    <895, 897, 898>,
    <895, 898, 893>,
    <895, 893, 892>,
    <899, 896, 867>,
    <899, 867, 872>,
    <899, 872, 871>,
    <899, 871, 900>,
    <899, 900, 901>,
    <899, 901, 902>,
    <899, 902, 897>,
    <899, 897, 896>,
    <903, 900, 871>,
    <903, 871, 874>,
    <903, 874, 586>,
    <903, 586, 616>,
    <903, 616, 620>,
    <903, 620, 904>,
    <903, 904, 901>,
    <903, 901, 900>,
    <905, 680, 647>,
    <905, 647, 878>,
    <905, 878, 877>,
    <905, 877, 906>,
    <905, 906, 907>,
    <905, 907, 908>,
    <905, 908, 681>,
    <905, 681, 680>,
    <909, 906, 877>,
    <909, 877, 882>,
    <909, 882, 881>,
    <909, 881, 910>,
    <909, 910, 911>,
    <909, 911, 912>,
    <909, 912, 907>,
    <909, 907, 906>,
    <913, 910, 881>,
    <913, 881, 886>,
    <913, 886, 885>,
    <913, 885, 914>,
    <913, 914, 915>,
    <913, 915, 916>,
    <913, 916, 911>,
    <913, 911, 910>,
    <917, 914, 885>,
    <917, 885, 890>,
    <917, 890, 889>,
    <917, 889, 918>,
    <917, 918, 919>,
    <917, 919, 920>,
    <917, 920, 915>,
    <917, 915, 914>,
    <921, 918, 889>,
    <921, 889, 894>,
    <921, 894, 893>,
    <921, 893, 922>,
    <921, 922, 923>,
    <921, 923, 924>,
    <921, 924, 919>,
    <921, 919, 918>,
    <925, 922, 893>,
    <925, 893, 898>,
    <925, 898, 897>,
    <925, 897, 926>,
    <925, 926, 927>,
    <925, 927, 928>,
    <925, 928, 923>,
    <925, 923, 922>,
    <929, 926, 897>,
    <929, 897, 902>,
    <929, 902, 901>,
    <929, 901, 930>,
    <929, 930, 931>,
    <929, 931, 932>,
    <929, 932, 927>,
    <929, 927, 926>,
    <933, 930, 901>,
    <933, 901, 904>,
    <933, 904, 620>,
    <933, 620, 650>,
    <933, 650, 654>,
    <933, 654, 934>,
    <933, 934, 931>,
    <933, 931, 930>,
    <935, 714, 681>,
    <935, 681, 908>,
    <935, 908, 907>,
    <935, 907, 936>,
    <935, 936, 937>,
    <935, 937, 938>,
    <935, 938, 715>,
    <935, 715, 714>,
    <939, 936, 907>,
    <939, 907, 912>,
    <939, 912, 911>,
    <939, 911, 940>,
    <939, 940, 941>,
    <939, 941, 942>,
    <939, 942, 937>,
    <939, 937, 936>,
    <943, 940, 911>,
    <943, 911, 916>,
    <943, 916, 915>,
    <943, 915, 944>,
    <943, 944, 945>,
    <943, 945, 946>,
    <943, 946, 941>,
    <943, 941, 940>,
    <947, 944, 915>,
    <947, 915, 920>,
    <947, 920, 919>,
    <947, 919, 948>,
    <947, 948, 949>,
    <947, 949, 950>,
    <947, 950, 945>,
    <947, 945, 944>,
    <951, 948, 919>,
    <951, 919, 924>,
    <951, 924, 923>,
    <951, 923, 952>,
    <951, 952, 953>,
    <951, 953, 954>,
    <951, 954, 949>,
    <951, 949, 948>,
    <955, 952, 923>,
    <955, 923, 928>,
    <955, 928, 927>,
    <955, 927, 956>,
    <955, 956, 957>,
    <955, 957, 958>,
    <955, 958, 953>,
    <955, 953, 952>,
    <959, 956, 927>,
    <959, 927, 932>,
    <959, 932, 931>,
    <959, 931, 960>,
    <959, 960, 961>,
    <959, 961, 962>,
    <959, 962, 957>,
    <959, 957, 956>,
    <963, 960, 931>,
    <963, 931, 934>,
    <963, 934, 654>,
    <963, 654, 684>,
    <963, 684, 688>,
    <963, 688, 964>,
    <963, 964, 961>,
    <963, 961, 960>,
    <965, 748, 715>,
    <965, 715, 938>,
    <965, 938, 937>,
    <965, 937, 966>,
    <965, 966, 967>,
    <965, 967, 968>,
    <965, 968, 749>,
    <965, 749, 748>,
    <969, 966, 937>,
    <969, 937, 942>,
    <969, 942, 941>,
    <969, 941, 970>,
    <969, 970, 971>,
    <969, 971, 972>,
    <969, 972, 967>,
    <969, 967, 966>,
    <973, 970, 941>,
    <973, 941, 946>,
    <973, 946, 945>,
    <973, 945, 974>,
    <973, 974, 975>,
    <973, 975, 976>,
    <973, 976, 971>,
    <973, 971, 970>,
    <977, 974, 945>,
    <977, 945, 950>,
    <977, 950, 949>,
    <977, 949, 978>,
    <977, 978, 979>,
    <977, 979, 980>,
    <977, 980, 975>,
    <977, 975, 974>,
    <981, 978, 949>,
    <981, 949, 954>,
    <981, 954, 953>,
    <981, 953, 982>,
    <981, 982, 983>,
    <981, 983, 984>,
    <981, 984, 979>,
    <981, 979, 978>,
    <985, 982, 953>,
    <985, 953, 958>,
    <985, 958, 957>,
    <985, 957, 986>,
    <985, 986, 987>,
    <985, 987, 988>,
    <985, 988, 983>,
    <985, 983, 982>,
    <989, 986, 957>,
    <989, 957, 962>,
    <989, 962, 961>,
    <989, 961, 990>,
    <989, 990, 991>,
    <989, 991, 992>,
    <989, 992, 987>,
    <989, 987, 986>,
    <993, 990, 961>,
    <993, 961, 964>,
    <993, 964, 688>,
    <993, 688, 718>,
    <993, 718, 722>,
    <993, 722, 994>,
    <993, 994, 991>,
    <993, 991, 990>,
    <995, 782, 749>,
    <995, 749, 968>,
    <995, 968, 967>,
    <995, 967, 996>,
    <995, 996, 997>,
    <995, 997, 998>,
    <995, 998, 783>,
    <995, 783, 782>,
    <999, 996, 967>,
    <999, 967, 972>,
    <999, 972, 971>,
    <999, 971, 1000>,
    <999, 1000, 1001>,
    <999, 1001, 1002>,
    <999, 1002, 997>,
    <999, 997, 996>,
    <1003, 1000, 971>,
    <1003, 971, 976>,
    <1003, 976, 975>,
    <1003, 975, 1004>,
    <1003, 1004, 1005>,
    <1003, 1005, 1006>,
    <1003, 1006, 1001>,
    <1003, 1001, 1000>,
    <1007, 1004, 975>,
    <1007, 975, 980>,
    <1007, 980, 979>,
    <1007, 979, 1008>,
    <1007, 1008, 1009>,
    <1007, 1009, 1010>,
    <1007, 1010, 1005>,
    <1007, 1005, 1004>,
    <1011, 1008, 979>,
    <1011, 979, 984>,
    <1011, 984, 983>,
    <1011, 983, 1012>,
    <1011, 1012, 1013>,
    <1011, 1013, 1014>,
    <1011, 1014, 1009>,
    <1011, 1009, 1008>,
    <1015, 1012, 983>,
    <1015, 983, 988>,
    <1015, 988, 987>,
    <1015, 987, 1016>,
    <1015, 1016, 1017>,
    <1015, 1017, 1018>,
    <1015, 1018, 1013>,
    <1015, 1013, 1012>,
    <1019, 1016, 987>,
    <1019, 987, 992>,
    <1019, 992, 991>,
    <1019, 991, 1020>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1017>,
    <1019, 1017, 1016>,
    <1023, 1020, 991>,
    <1023, 991, 994>,
    <1023, 994, 722>,
    <1023, 722, 752>,
    <1023, 752, 756>,
    <1023, 756, 1024>,
    <1023, 1024, 1021>,
    <1023, 1021, 1020>,
    <1025, 1026, 756>,
    <1025, 756, 755>,
    <1025, 755, 754>,
    <1025, 754, 1027>,
    <1025, 1027, 1028>,
    <1025, 1028, 1029>,
    <1025, 1029, 1030>,
    <1025, 1030, 1026>,
    <1031, 1027, 754>,
    <1031, 754, 760>,
    <1031, 760, 759>,
    <1031, 759, 1032>,
    <1031, 1032, 1033>,
    <1031, 1033, 1034>,
    <1031, 1034, 1028>,
    <1031, 1028, 1027>,
    <1035, 1032, 759>,
    <1035, 759, 764>,
    <1035, 764, 763>,
    <1035, 763, 1036>,
    <1035, 1036, 1037>,
    <1035, 1037, 1038>,
    <1035, 1038, 1033>,
    <1035, 1033, 1032>,
    <1039, 1036, 763>,
    <1039, 763, 768>,
    <1039, 768, 767>,
    <1039, 767, 1040>,
    <1039, 1040, 1041>,
    <1039, 1041, 1042>,
    <1039, 1042, 1037>,
    <1039, 1037, 1036>,
    <1043, 1040, 767>,
    <1043, 767, 772>,
    <1043, 772, 771>,
    <1043, 771, 1044>,
    <1043, 1044, 1045>,
    <1043, 1045, 1046>,
    <1043, 1046, 1041>,
    <1043, 1041, 1040>,
    <1047, 1044, 771>,
    <1047, 771, 776>,
    <1047, 776, 775>,
    <1047, 775, 1048>,
    <1047, 1048, 1049>,
    <1047, 1049, 1050>,
    <1047, 1050, 1045>,
    <1047, 1045, 1044>,
    <1051, 1048, 775>,
    <1051, 775, 780>,
    <1051, 780, 779>,
    <1051, 779, 1052>,
    <1051, 1052, 1053>,
    <1051, 1053, 1054>,
    <1051, 1054, 1049>,
    <1051, 1049, 1048>,
    <1055, 1052, 779>,
    <1055, 779, 784>,
    <1055, 784, 783>,
    <1055, 783, 1056>,
    <1055, 1056, 1057>,
    <1055, 1057, 1058>,
    <1055, 1058, 1053>,
    <1055, 1053, 1052>,
    <1059, 1060, 1030>,
    <1059, 1030, 1029>,
    <1059, 1029, 1028>,
    <1059, 1028, 1061>,
    <1059, 1061, 1062>,
    <1059, 1062, 1063>,
    <1059, 1063, 1064>,
    <1059, 1064, 1060>,
    <1065, 1061, 1028>,
    <1065, 1028, 1034>,
    <1065, 1034, 1033>,
    <1065, 1033, 1066>,
    <1065, 1066, 1067>,
    <1065, 1067, 1068>,
    <1065, 1068, 1062>,
    <1065, 1062, 1061>,
    <1069, 1066, 1033>,
    <1069, 1033, 1038>,
    <1069, 1038, 1037>,
    <1069, 1037, 1070>,
    <1069, 1070, 1071>,
    <1069, 1071, 1072>,
    <1069, 1072, 1067>,
    <1069, 1067, 1066>,
    <1073, 1070, 1037>,
    <1073, 1037, 1042>,
    <1073, 1042, 1041>,
    <1073, 1041, 1074>,
    <1073, 1074, 1075>,
    <1073, 1075, 1076>,
    <1073, 1076, 1071>,
    <1073, 1071, 1070>,
    <1077, 1074, 1041>,
    <1077, 1041, 1046>,
    <1077, 1046, 1045>,
    <1077, 1045, 1078>,
    <1077, 1078, 1079>,
    <1077, 1079, 1080>,
    <1077, 1080, 1075>,
    <1077, 1075, 1074>,
    <1081, 1078, 1045>,
    <1081, 1045, 1050>,
    <1081, 1050, 1049>,
    <1081, 1049, 1082>,
    <1081, 1082, 1083>,
    <1081, 1083, 1084>,
    <1081, 1084, 1079>,
    <1081, 1079, 1078>,
    <1085, 1082, 1049>,
    <1085, 1049, 1054>,
    <1085, 1054, 1053>,
    <1085, 1053, 1086>,
    <1085, 1086, 1087>,
    <1085, 1087, 1088>,
    <1085, 1088, 1083>,
    <1085, 1083, 1082>,
    <1089, 1086, 1053>,
    <1089, 1053, 1058>,
    <1089, 1058, 1057>,
    <1089, 1057, 1090>,
    <1089, 1090, 1091>,
    <1089, 1091, 1092>,
    <1089, 1092, 1087>,
    <1089, 1087, 1086>,
    <1093, 1094, 1064>,
    <1093, 1064, 1063>,
    <1093, 1063, 1062>,
    <1093, 1062, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1098, 1094>,
    <1099, 1095, 1062>,
    <1099, 1062, 1068>,
    <1099, 1068, 1067>,
    <1099, 1067, 1100>,
    <1099, 1100, 1101>,
    <1099, 1101, 1102>,
    <1099, 1102, 1096>,
    <1099, 1096, 1095>,
    <1103, 1100, 1067>,
    <1103, 1067, 1072>,
    <1103, 1072, 1071>,
    <1103, 1071, 1104>,
    <1103, 1104, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1101>,
    <1103, 1101, 1100>,
    <1107, 1104, 1071>,
    <1107, 1071, 1076>,
    <1107, 1076, 1075>,
    <1107, 1075, 1108>,
    <1107, 1108, 1109>,
    <1107, 1109, 1110>,
    <1107, 1110, 1105>,
    <1107, 1105, 1104>,
    <1111, 1108, 1075>,
    <1111, 1075, 1080>,
    <1111, 1080, 1079>,
    <1111, 1079, 1112>,
    <1111, 1112, 1113>,
    <1111, 1113, 1114>,
    <1111, 1114, 1109>,
    <1111, 1109, 1108>,
    <1115, 1112, 1079>,
    <1115, 1079, 1084>,
    <1115, 1084, 1083>,
    <1115, 1083, 1116>,
    <1115, 1116, 1117>,
    <1115, 1117, 1118>,
    <1115, 1118, 1113>,
    <1115, 1113, 1112>,
    <1119, 1116, 1083>,
    <1119, 1083, 1088>,
    <1119, 1088, 1087>,
    <1119, 1087, 1120>,
    <1119, 1120, 1121>,
    <1119, 1121, 1122>,
    <1119, 1122, 1117>,
    <1119, 1117, 1116>,
    <1123, 1120, 1087>,
    <1123, 1087, 1092>,
    <1123, 1092, 1091>,
    <1123, 1091, 1124>,
    <1123, 1124, 1125>,
    <1123, 1125, 1126>,
    <1123, 1126, 1121>,
    <1123, 1121, 1120>,
    <1127, 1128, 1098>,
    <1127, 1098, 1097>,
    <1127, 1097, 1096>,
    <1127, 1096, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1131>,
    <1127, 1131, 1132>,
    <1127, 1132, 1128>,
    <1133, 1129, 1096>,
    <1133, 1096, 1102>,
    <1133, 1102, 1101>,
    <1133, 1101, 1134>,
    <1133, 1134, 1135>,
    <1133, 1135, 1136>,
    <1133, 1136, 1130>,
    <1133, 1130, 1129>,
    <1137, 1134, 1101>,
    <1137, 1101, 1106>,
    <1137, 1106, 1105>,
    <1137, 1105, 1138>,
    <1137, 1138, 1139>,
    <1137, 1139, 1140>,
    <1137, 1140, 1135>,
    <1137, 1135, 1134>,
    <1141, 1138, 1105>,
    <1141, 1105, 1110>,
    <1141, 1110, 1109>,
    <1141, 1109, 1142>,
    <1141, 1142, 1143>,
    <1141, 1143, 1144>,
    <1141, 1144, 1139>,
    <1141, 1139, 1138>,
    <1145, 1142, 1109>,
    <1145, 1109, 1114>,
    <1145, 1114, 1113>,
    <1145, 1113, 1146>,
    <1145, 1146, 1147>,
    <1145, 1147, 1148>,
    <1145, 1148, 1143>,
    <1145, 1143, 1142>,
    <1149, 1146, 1113>,
    <1149, 1113, 1118>,
    <1149, 1118, 1117>,
    <1149, 1117, 1150>,
    <1149, 1150, 1151>,
    <1149, 1151, 1152>,
    <1149, 1152, 1147>,
    <1149, 1147, 1146>,
    <1153, 1150, 1117>,
    <1153, 1117, 1122>,
    <1153, 1122, 1121>,
    <1153, 1121, 1154>,
    <1153, 1154, 1155>,
    <1153, 1155, 1156>,
    <1153, 1156, 1151>,
    <1153, 1151, 1150>,
    <1157, 1154, 1121>,
    <1157, 1121, 1126>,
    <1157, 1126, 1125>,
    <1157, 1125, 1158>,
    <1157, 1158, 1159>,
    <1157, 1159, 1160>,
    <1157, 1160, 1155>,
    <1157, 1155, 1154>,
    <1161, 1162, 1132>,
    <1161, 1132, 1131>,
    <1161, 1131, 1130>,
    <1161, 1130, 1163>,
    <1161, 1163, 1164>,
    <1161, 1164, 1165>,
    <1161, 1165, 1166>,
    <1161, 1166, 1162>,
    <1167, 1163, 1130>,
    <1167, 1130, 1136>,
    <1167, 1136, 1135>,
    <1167, 1135, 1168>,
    <1167, 1168, 1169>,
    <1167, 1169, 1170>,
    <1167, 1170, 1164>,
    <1167, 1164, 1163>,
    <1171, 1168, 1135>,
    <1171, 1135, 1140>,
    <1171, 1140, 1139>,
    <1171, 1139, 1172>,
    <1171, 1172, 1173>,
    <1171, 1173, 1174>,
    <1171, 1174, 1169>,
    <1171, 1169, 1168>,
    <1175, 1172, 1139>,
    <1175, 1139, 1144>,
    <1175, 1144, 1143>,
    <1175, 1143, 1176>,
    <1175, 1176, 1177>,
    <1175, 1177, 1178>,
    <1175, 1178, 1173>,
    <1175, 1173, 1172>,
    <1179, 1176, 1143>,
    <1179, 1143, 1148>,
    <1179, 1148, 1147>,
    <1179, 1147, 1180>,
    <1179, 1180, 1181>,
    <1179, 1181, 1182>,
    <1179, 1182, 1177>,
    <1179, 1177, 1176>,
    <1183, 1180, 1147>,
    <1183, 1147, 1152>,
    <1183, 1152, 1151>,
    <1183, 1151, 1184>,
    <1183, 1184, 1185>,
    <1183, 1185, 1186>,
    <1183, 1186, 1181>,
    <1183, 1181, 1180>,
    <1187, 1184, 1151>,
    <1187, 1151, 1156>,
    <1187, 1156, 1155>,
    <1187, 1155, 1188>,
    <1187, 1188, 1189>,
    <1187, 1189, 1190>,
    <1187, 1190, 1185>,
    <1187, 1185, 1184>,
    <1191, 1188, 1155>,
    <1191, 1155, 1160>,
    <1191, 1160, 1159>,
    <1191, 1159, 1192>,
    <1191, 1192, 1193>,
    <1191, 1193, 1194>,
    <1191, 1194, 1189>,
    <1191, 1189, 1188>,
    <1195, 1196, 1166>,
    <1195, 1166, 1165>,
    <1195, 1165, 1164>,
    <1195, 1164, 1197>,
    <1195, 1197, 1198>,
    <1195, 1198, 1199>,
    <1195, 1199, 1200>,
    <1195, 1200, 1196>,
    <1201, 1197, 1164>,
    <1201, 1164, 1170>,
    <1201, 1170, 1169>,
    <1201, 1169, 1202>,
    <1201, 1202, 1203>,
    <1201, 1203, 1204>,
    <1201, 1204, 1198>,
    <1201, 1198, 1197>,
    <1205, 1202, 1169>,
    <1205, 1169, 1174>,
    <1205, 1174, 1173>,
    <1205, 1173, 1206>,
    <1205, 1206, 1207>,
    <1205, 1207, 1208>,
    <1205, 1208, 1203>,
    <1205, 1203, 1202>,
    <1209, 1206, 1173>,
    <1209, 1173, 1178>,
    <1209, 1178, 1177>,
    <1209, 1177, 1210>,
    <1209, 1210, 1211>,
    <1209, 1211, 1212>,
    <1209, 1212, 1207>,
    <1209, 1207, 1206>,
    <1213, 1210, 1177>,
    <1213, 1177, 1182>,
    <1213, 1182, 1181>,
    <1213, 1181, 1214>,
    <1213, 1214, 1215>,
    <1213, 1215, 1216>,
    <1213, 1216, 1211>,
    <1213, 1211, 1210>,
    <1217, 1214, 1181>,
    <1217, 1181, 1186>,
    <1217, 1186, 1185>,
    <1217, 1185, 1218>,
    <1217, 1218, 1219>,
    <1217, 1219, 1220>,
    <1217, 1220, 1215>,
    <1217, 1215, 1214>,
    <1221, 1218, 1185>,
    <1221, 1185, 1190>,
    <1221, 1190, 1189>,
    <1221, 1189, 1222>,
    <1221, 1222, 1223>,
    <1221, 1223, 1224>,
    <1221, 1224, 1219>,
    <1221, 1219, 1218>,
    <1225, 1222, 1189>,
    <1225, 1189, 1194>,
    <1225, 1194, 1193>,
    <1225, 1193, 1226>,
    <1225, 1226, 1227>,
    <1225, 1227, 1228>,
    <1225, 1228, 1223>,
    <1225, 1223, 1222>,
    <1229, 1230, 1231>,
    <1229, 1231, 1199>,
    <1229, 1199, 1198>,
    <1229, 1198, 1232>,
    <1229, 1232, 1233>,
    <1229, 1233, 1234>,
    <1229, 1234, 1235>,
    <1229, 1235, 1236>,
    <1237, 1232, 1198>,
    <1237, 1198, 1204>,
    <1237, 1204, 1203>,
    <1237, 1203, 1238>,
    <1237, 1238, 1239>,
    <1237, 1239, 1240>,
    <1237, 1240, 1233>,
    <1237, 1233, 1232>,
    <1241, 1238, 1203>,
    <1241, 1203, 1208>,
    <1241, 1208, 1207>,
    <1241, 1207, 1242>,
    <1241, 1242, 1243>,
    <1241, 1243, 1244>,
    <1241, 1244, 1239>,
    <1241, 1239, 1238>,
    <1245, 1242, 1207>,
    <1245, 1207, 1212>,
    <1245, 1212, 1211>,
    <1245, 1211, 1246>,
    <1245, 1246, 1247>,
    <1245, 1247, 1248>,
    <1245, 1248, 1243>,
    <1245, 1243, 1242>,
    <1249, 1246, 1211>,
    <1249, 1211, 1216>,
    <1249, 1216, 1215>,
    <1249, 1215, 1250>,
    <1249, 1250, 1251>,
    <1249, 1251, 1252>,
    <1249, 1252, 1247>,
    <1249, 1247, 1246>,
    <1253, 1250, 1215>,
    <1253, 1215, 1220>,
    <1253, 1220, 1219>,
    <1253, 1219, 1254>,
    <1253, 1254, 1255>,
    <1253, 1255, 1256>,
    <1253, 1256, 1251>,
    <1253, 1251, 1250>,
    <1257, 1254, 1219>,
    <1257, 1219, 1224>,
    <1257, 1224, 1223>,
    <1257, 1223, 1258>,
    <1257, 1258, 1259>,
    <1257, 1259, 1260>,
    <1257, 1260, 1255>,
    <1257, 1255, 1254>,
    <1261, 1258, 1223>,
    <1261, 1223, 1228>,
    <1261, 1228, 1262>,
    <1261, 1262, 1263>,
    <1261, 1264, 1265>,
    <1261, 1265, 1266>,
    <1261, 1266, 1259>,
    <1261, 1259, 1258>,
    <1267, 1268, 1269>,
    <1267, 1269, 1234>,
    <1267, 1234, 1233>,
    <1267, 1233, 1270>,
    <1267, 1270, 1271>,
    <1267, 1271, 1272>,
    <1267, 1272, 1273>,
    <1267, 1273, 1274>,
    <1275, 1270, 1233>,
    <1275, 1233, 1240>,
    <1275, 1240, 1239>,
    <1275, 1239, 1276>,
    <1275, 1276, 1277>,
    <1275, 1277, 1278>,
    <1275, 1278, 1271>,
    <1275, 1271, 1270>,
    <1279, 1276, 1239>,
    <1279, 1239, 1244>,
    <1279, 1244, 1243>,
    <1279, 1243, 1280>,
    <1279, 1280, 1281>,
    <1279, 1281, 1282>,
    <1279, 1282, 1277>,
    <1279, 1277, 1276>,
    <1283, 1280, 1243>,
    <1283, 1243, 1248>,
    <1283, 1248, 1247>,
    <1283, 1247, 1284>,
    <1283, 1284, 1285>,
    <1283, 1285, 1286>,
    <1283, 1286, 1281>,
    <1283, 1281, 1280>,
    <1287, 1284, 1247>,
    <1287, 1247, 1252>,
    <1287, 1252, 1251>,
    <1287, 1251, 1288>,
    <1287, 1288, 1289>,
    <1287, 1289, 1290>,
    <1287, 1290, 1285>,
    <1287, 1285, 1284>,
    <1291, 1288, 1251>,
    <1291, 1251, 1256>,
    <1291, 1256, 1255>,
    <1291, 1255, 1292>,
    <1291, 1292, 1293>,
    <1291, 1293, 1294>,
    <1291, 1294, 1289>,
    <1291, 1289, 1288>,
    <1295, 1292, 1255>,
    <1295, 1255, 1260>,
    <1295, 1260, 1259>,
    <1295, 1259, 1296>,
    <1295, 1296, 1297>,
    <1295, 1297, 1298>,
    <1295, 1298, 1293>,
    <1295, 1293, 1292>,
    <1299, 1296, 1259>,
    <1299, 1259, 1266>,
    <1299, 1266, 1300>,
    <1299, 1300, 1301>,
    <1299, 1302, 1303>,
    <1299, 1303, 1304>,
    <1299, 1304, 1297>,
    <1299, 1297, 1296>,
    <1305, 1056, 783>,
    <1305, 783, 998>,
    <1305, 998, 997>,
    <1305, 997, 1306>,
    <1305, 1306, 1307>,
    <1305, 1307, 1308>,
    <1305, 1308, 1057>,
    <1305, 1057, 1056>,
    <1309, 1306, 997>,
    <1309, 997, 1002>,
    <1309, 1002, 1001>,
    <1309, 1001, 1310>,
    <1309, 1310, 1311>,
    <1309, 1311, 1312>,
    <1309, 1312, 1307>,
    <1309, 1307, 1306>,
    <1313, 1310, 1001>,
    <1313, 1001, 1006>,
    <1313, 1006, 1005>,
    <1313, 1005, 1314>,
    <1313, 1314, 1315>,
    <1313, 1315, 1316>,
    <1313, 1316, 1311>,
    <1313, 1311, 1310>,
    <1317, 1314, 1005>,
    <1317, 1005, 1010>,
    <1317, 1010, 1009>,
    <1317, 1009, 1318>,
    <1317, 1318, 1319>,
    <1317, 1319, 1320>,
    <1317, 1320, 1315>,
    <1317, 1315, 1314>,
    <1321, 1318, 1009>,
    <1321, 1009, 1014>,
    <1321, 1014, 1013>,
    <1321, 1013, 1322>,
    <1321, 1322, 1323>,
    <1321, 1323, 1324>,
    <1321, 1324, 1319>,
    <1321, 1319, 1318>,
    <1325, 1322, 1013>,
    <1325, 1013, 1018>,
    <1325, 1018, 1017>,
    <1325, 1017, 1326>,
    <1325, 1326, 1327>,
    <1325, 1327, 1328>,
    <1325, 1328, 1323>,
    <1325, 1323, 1322>,
    <1329, 1326, 1017>,
    <1329, 1017, 1022>,
    <1329, 1022, 1021>,
    <1329, 1021, 1330>,
    <1329, 1330, 1331>,
    <1329, 1331, 1332>,
    <1329, 1332, 1327>,
    <1329, 1327, 1326>,
    <1333, 1330, 1021>,
    <1333, 1021, 1024>,
    <1333, 1024, 756>,
    <1333, 756, 1026>,
    <1333, 1026, 1030>,
    <1333, 1030, 1334>,
    <1333, 1334, 1331>,
    <1333, 1331, 1330>,
    <1335, 1090, 1057>,
    <1335, 1057, 1308>,
    <1335, 1308, 1307>,
    <1335, 1307, 1336>,
    <1335, 1336, 1337>,
    <1335, 1337, 1338>,
    <1335, 1338, 1091>,
    <1335, 1091, 1090>,
    <1339, 1336, 1307>,
    <1339, 1307, 1312>,
    <1339, 1312, 1311>,
    <1339, 1311, 1340>,
    <1339, 1340, 1341>,
    <1339, 1341, 1342>,
    <1339, 1342, 1337>,
    <1339, 1337, 1336>,
    <1343, 1340, 1311>,
    <1343, 1311, 1316>,
    <1343, 1316, 1315>,
    <1343, 1315, 1344>,
    <1343, 1344, 1345>,
    <1343, 1345, 1346>,
    <1343, 1346, 1341>,
    <1343, 1341, 1340>,
    <1347, 1344, 1315>,
    <1347, 1315, 1320>,
    <1347, 1320, 1319>,
    <1347, 1319, 1348>,
    <1347, 1348, 1349>,
    <1347, 1349, 1350>,
    <1347, 1350, 1345>,
    <1347, 1345, 1344>,
    <1351, 1348, 1319>,
    <1351, 1319, 1324>,
    <1351, 1324, 1323>,
    <1351, 1323, 1352>,
    <1351, 1352, 1353>,
    <1351, 1353, 1354>,
    <1351, 1354, 1349>,
    <1351, 1349, 1348>,
    <1355, 1352, 1323>,
    <1355, 1323, 1328>,
    <1355, 1328, 1327>,
    <1355, 1327, 1356>,
    <1355, 1356, 1357>,
    <1355, 1357, 1358>,
    <1355, 1358, 1353>,
    <1355, 1353, 1352>,
    <1359, 1356, 1327>,
    <1359, 1327, 1332>,
    <1359, 1332, 1331>,
    <1359, 1331, 1360>,
    <1359, 1360, 1361>,
    <1359, 1361, 1362>,
    <1359, 1362, 1357>,
    <1359, 1357, 1356>,
    <1363, 1360, 1331>,
    <1363, 1331, 1334>,
    <1363, 1334, 1030>,
    <1363, 1030, 1060>,
    <1363, 1060, 1064>,
    <1363, 1064, 1364>,
    <1363, 1364, 1361>,
    <1363, 1361, 1360>,
    <1365, 1124, 1091>,
    <1365, 1091, 1338>,
    <1365, 1338, 1337>,
    <1365, 1337, 1366>,
    <1365, 1366, 1367>,
    <1365, 1367, 1368>,
    <1365, 1368, 1125>,
    <1365, 1125, 1124>,
    <1369, 1366, 1337>,
    <1369, 1337, 1342>,
    <1369, 1342, 1341>,
    <1369, 1341, 1370>,
    <1369, 1370, 1371>,
    <1369, 1371, 1372>,
    <1369, 1372, 1367>,
    <1369, 1367, 1366>,
    <1373, 1370, 1341>,
    <1373, 1341, 1346>,
    <1373, 1346, 1345>,
    <1373, 1345, 1374>,
    <1373, 1374, 1375>,
    <1373, 1375, 1376>,
    <1373, 1376, 1371>,
    <1373, 1371, 1370>,
    <1377, 1374, 1345>,
    <1377, 1345, 1350>,
    <1377, 1350, 1349>,
    <1377, 1349, 1378>,
    <1377, 1378, 1379>,
    <1377, 1379, 1380>,
    <1377, 1380, 1375>,
    <1377, 1375, 1374>,
    <1381, 1378, 1349>,
    <1381, 1349, 1354>,
    <1381, 1354, 1353>,
    <1381, 1353, 1382>,
    <1381, 1382, 1383>,
    <1381, 1383, 1384>,
    <1381, 1384, 1379>,
    <1381, 1379, 1378>,
    <1385, 1382, 1353>,
    <1385, 1353, 1358>,
    <1385, 1358, 1357>,
    <1385, 1357, 1386>,
    <1385, 1386, 1387>,
    <1385, 1387, 1388>,
    <1385, 1388, 1383>,
    <1385, 1383, 1382>,
    <1389, 1386, 1357>,
    <1389, 1357, 1362>,
    <1389, 1362, 1361>,
    <1389, 1361, 1390>,
    <1389, 1390, 1391>,
    <1389, 1391, 1392>,
    <1389, 1392, 1387>,
    <1389, 1387, 1386>,
    <1393, 1390, 1361>,
    <1393, 1361, 1364>,
    <1393, 1364, 1064>,
    <1393, 1064, 1094>,
    <1393, 1094, 1098>,
    <1393, 1098, 1394>,
    <1393, 1394, 1391>,
    <1393, 1391, 1390>,
    <1395, 1158, 1125>,
    <1395, 1125, 1368>,
    <1395, 1368, 1367>,
    <1395, 1367, 1396>,
    <1395, 1396, 1397>,
    <1395, 1397, 1398>,
    <1395, 1398, 1159>,
    <1395, 1159, 1158>,
    <1399, 1396, 1367>,
    <1399, 1367, 1372>,
    <1399, 1372, 1371>,
    <1399, 1371, 1400>,
    <1399, 1400, 1401>,
    <1399, 1401, 1402>,
    <1399, 1402, 1397>,
    <1399, 1397, 1396>,
    <1403, 1400, 1371>,
    <1403, 1371, 1376>,
    <1403, 1376, 1375>,
    <1403, 1375, 1404>,
    <1403, 1404, 1405>,
    <1403, 1405, 1406>,
    <1403, 1406, 1401>,
    <1403, 1401, 1400>,
    <1407, 1404, 1375>,
    <1407, 1375, 1380>,
    <1407, 1380, 1379>,
    <1407, 1379, 1408>,
    <1407, 1408, 1409>,
    <1407, 1409, 1410>,
    <1407, 1410, 1405>,
    <1407, 1405, 1404>,
    <1411, 1408, 1379>,
    <1411, 1379, 1384>,
    <1411, 1384, 1383>,
    <1411, 1383, 1412>,
    <1411, 1412, 1413>,
    <1411, 1413, 1414>,
    <1411, 1414, 1409>,
    <1411, 1409, 1408>,
    <1415, 1412, 1383>,
    <1415, 1383, 1388>,
    <1415, 1388, 1387>,
    <1415, 1387, 1416>,
    <1415, 1416, 1417>,
    <1415, 1417, 1418>,
    <1415, 1418, 1413>,
    <1415, 1413, 1412>,
    <1419, 1416, 1387>,
    <1419, 1387, 1392>,
    <1419, 1392, 1391>,
    <1419, 1391, 1420>,
    <1419, 1420, 1421>,
    <1419, 1421, 1422>,
    <1419, 1422, 1417>,
    <1419, 1417, 1416>,
    <1423, 1420, 1391>,
    <1423, 1391, 1394>,
    <1423, 1394, 1098>,
    <1423, 1098, 1128>,
    <1423, 1128, 1132>,
    <1423, 1132, 1424>,
    <1423, 1424, 1421>,
    <1423, 1421, 1420>,
    <1425, 1192, 1159>,
    <1425, 1159, 1398>,
    <1425, 1398, 1397>,
    <1425, 1397, 1426>,
    <1425, 1426, 1427>,
    <1425, 1427, 1428>,
    <1425, 1428, 1193>,
    <1425, 1193, 1192>,
    <1429, 1426, 1397>,
    <1429, 1397, 1402>,
    <1429, 1402, 1401>,
    <1429, 1401, 1430>,
    <1429, 1430, 1431>,
    <1429, 1431, 1432>,
    <1429, 1432, 1427>,
    <1429, 1427, 1426>,
    <1433, 1430, 1401>,
    <1433, 1401, 1406>,
    <1433, 1406, 1405>,
    <1433, 1405, 1434>,
    <1433, 1434, 1435>,
    <1433, 1435, 1436>,
    <1433, 1436, 1431>,
    <1433, 1431, 1430>,
    <1437, 1434, 1405>,
    <1437, 1405, 1410>,
    <1437, 1410, 1409>,
    <1437, 1409, 1438>,
    <1437, 1438, 1439>,
    <1437, 1439, 1440>,
    <1437, 1440, 1435>,
    <1437, 1435, 1434>,
    <1441, 1438, 1409>,
    <1441, 1409, 1414>,
    <1441, 1414, 1413>,
    <1441, 1413, 1442>,
    <1441, 1442, 1443>,
    <1441, 1443, 1444>,
    <1441, 1444, 1439>,
    <1441, 1439, 1438>,
    <1445, 1442, 1413>,
    <1445, 1413, 1418>,
    <1445, 1418, 1417>,
    <1445, 1417, 1446>,
    <1445, 1446, 1447>,
    <1445, 1447, 1448>,
    <1445, 1448, 1443>,
    <1445, 1443, 1442>,
    <1449, 1446, 1417>,
    <1449, 1417, 1422>,
    <1449, 1422, 1421>,
    <1449, 1421, 1450>,
    <1449, 1450, 1451>,
    <1449, 1451, 1452>,
    <1449, 1452, 1447>,
    <1449, 1447, 1446>,
    <1453, 1450, 1421>,
    <1453, 1421, 1424>,
    <1453, 1424, 1132>,
    <1453, 1132, 1162>,
    <1453, 1162, 1166>,
    <1453, 1166, 1454>,
    <1453, 1454, 1451>,
    <1453, 1451, 1450>,
    <1455, 1226, 1193>,
    <1455, 1193, 1428>,
    <1455, 1428, 1427>,
    <1455, 1427, 1456>,
    <1455, 1456, 1457>,
    <1455, 1457, 1458>,
    <1455, 1458, 1459>,
    <1455, 1459, 1226>,
    <1460, 1456, 1427>,
    <1460, 1427, 1432>,
    <1460, 1432, 1431>,
    <1460, 1431, 1461>,
    <1460, 1461, 1462>,
    <1460, 1462, 1463>,
    <1460, 1463, 1457>,
    <1460, 1457, 1456>,
    <1464, 1461, 1431>,
    <1464, 1431, 1436>,
    <1464, 1436, 1435>,
    <1464, 1435, 1465>,
    <1464, 1465, 1466>,
    <1464, 1466, 1467>,
    <1464, 1467, 1462>,
    <1464, 1462, 1461>,
    <1468, 1465, 1435>,
    <1468, 1435, 1440>,
    <1468, 1440, 1439>,
    <1468, 1439, 1469>,
    <1468, 1469, 1470>,
    <1468, 1470, 1471>,
    <1468, 1471, 1466>,
    <1468, 1466, 1465>,
    <1472, 1469, 1439>,
    <1472, 1439, 1444>,
    <1472, 1444, 1443>,
    <1472, 1443, 1473>,
    <1472, 1473, 1474>,
    <1472, 1474, 1475>,
    <1472, 1475, 1470>,
    <1472, 1470, 1469>,
    <1476, 1473, 1443>,
    <1476, 1443, 1448>,
    <1476, 1448, 1447>,
    <1476, 1447, 1477>,
    <1476, 1477, 1478>,
    <1476, 1478, 1479>,
    <1476, 1479, 1474>,
    <1476, 1474, 1473>,
    <1480, 1477, 1447>,
    <1480, 1447, 1452>,
    <1480, 1452, 1451>,
    <1480, 1451, 1481>,
    <1480, 1481, 1482>,
    <1480, 1482, 1483>,
    <1480, 1483, 1478>,
    <1480, 1478, 1477>,
    <1484, 1481, 1451>,
    <1484, 1451, 1454>,
    <1484, 1454, 1166>,
    <1484, 1166, 1196>,
    <1484, 1196, 1485>,
    <1484, 1485, 1486>,
    <1484, 1486, 1482>,
    <1484, 1482, 1481>,
    <1487, 1488, 1489>,
    <1487, 1489, 1458>,
    <1487, 1458, 1457>,
    <1487, 1457, 1490>,
    <1487, 1490, 1491>,
    <1487, 1491, 1492>,
    <1487, 1492, 1493>,
    <1487, 1493, 1494>,
    <1495, 1490, 1457>,
    <1495, 1457, 1463>,
    <1495, 1463, 1462>,
    <1495, 1462, 1496>,
    <1495, 1496, 1497>,
    <1495, 1497, 1498>,
    <1495, 1498, 1491>,
    <1495, 1491, 1490>,
    <1499, 1496, 1462>,
    <1499, 1462, 1467>,
    <1499, 1467, 1466>,
    <1499, 1466, 1500>,
    <1499, 1500, 1501>,
    <1499, 1501, 1502>,
    <1499, 1502, 1497>,
    <1499, 1497, 1496>,
    <1503, 1500, 1466>,
    <1503, 1466, 1471>,
    <1503, 1471, 1470>,
    <1503, 1470, 1504>,
    <1503, 1504, 1505>,
    <1503, 1505, 1506>,
    <1503, 1506, 1501>,
    <1503, 1501, 1500>,
    <1507, 1504, 1470>,
    <1507, 1470, 1475>,
    <1507, 1475, 1474>,
    <1507, 1474, 1508>,
    <1507, 1508, 1509>,
    <1507, 1509, 1510>,
    <1507, 1510, 1505>,
    <1507, 1505, 1504>,
    <1511, 1508, 1474>,
    <1511, 1474, 1479>,
    <1511, 1479, 1478>,
    <1511, 1478, 1512>,
    <1511, 1512, 1513>,
    <1511, 1513, 1514>,
    <1511, 1514, 1509>,
    <1511, 1509, 1508>,
    <1515, 1512, 1478>,
    <1515, 1478, 1483>,
    <1515, 1483, 1482>,
    <1515, 1482, 1516>,
    <1515, 1516, 1517>,
    <1515, 1517, 1518>,
    <1515, 1518, 1513>,
    <1515, 1513, 1512>,
    <1519, 1516, 1482>,
    <1519, 1482, 1486>,
    <1519, 1486, 1520>,
    <1519, 1520, 1521>,
    <1519, 1522, 1523>,
    <1519, 1523, 1524>,
    <1519, 1524, 1517>,
    <1519, 1517, 1516>,
    <1525, 1526, 1527>,
    <1525, 1527, 1492>,
    <1525, 1492, 1491>,
    <1525, 1491, 1528>,
    <1525, 1528, 1297>,
    <1525, 1297, 1304>,
    <1525, 1304, 1529>,
    <1525, 1529, 1530>,
    <1531, 1528, 1491>,
    <1531, 1491, 1498>,
    <1531, 1498, 1497>,
    <1531, 1497, 1532>,
    <1531, 1532, 1293>,
    <1531, 1293, 1298>,
    <1531, 1298, 1297>,
    <1531, 1297, 1528>,
    <1533, 1532, 1497>,
    <1533, 1497, 1502>,
    <1533, 1502, 1501>,
    <1533, 1501, 1534>,
    <1533, 1534, 1289>,
    <1533, 1289, 1294>,
    <1533, 1294, 1293>,
    <1533, 1293, 1532>,
    <1535, 1534, 1501>,
    <1535, 1501, 1506>,
    <1535, 1506, 1505>,
    <1535, 1505, 1536>,
    <1535, 1536, 1285>,
    <1535, 1285, 1290>,
    <1535, 1290, 1289>,
    <1535, 1289, 1534>,
    <1537, 1536, 1505>,
    <1537, 1505, 1510>,
    <1537, 1510, 1509>,
    <1537, 1509, 1538>,
    <1537, 1538, 1281>,
    <1537, 1281, 1286>,
    <1537, 1286, 1285>,
    <1537, 1285, 1536>,
    <1539, 1538, 1509>,
    <1539, 1509, 1514>,
    <1539, 1514, 1513>,
    <1539, 1513, 1540>,
    <1539, 1540, 1277>,
    <1539, 1277, 1282>,
    <1539, 1282, 1281>,
    <1539, 1281, 1538>,
    <1541, 1540, 1513>,
    <1541, 1513, 1518>,
    <1541, 1518, 1517>,
    <1541, 1517, 1542>,
    <1541, 1542, 1271>,
    <1541, 1271, 1278>,
    <1541, 1278, 1277>,
    <1541, 1277, 1540>,
    <1543, 1542, 1517>,
    <1543, 1517, 1524>,
    <1543, 1524, 1544>,
    <1543, 1544, 1545>,
    <1543, 1546, 1547>,
    <1543, 1547, 1272>,
    <1543, 1272, 1271>,
    <1543, 1271, 1542>
  }
  uv_indices {
    3040,   // from 0 triangles and 1520 quads
    <486, 492, 487>,
    <486, 487, 490>    <486, 490, 488>,
    <486, 488, 491>    <486, 491, 489>,
    <486, 489, 492>    <493, 499, 494>,
    <493, 494, 497>    <493, 497, 495>,
    <493, 495, 498>    <493, 498, 496>,
    <493, 496, 499>    <500, 506, 501>,
    <500, 501, 504>    <500, 504, 502>,
    <500, 502, 505>    <500, 505, 503>,
    <500, 503, 506>    <507, 513, 508>,
    <507, 508, 511>    <507, 511, 509>,
    <507, 509, 512>    <507, 512, 510>,
    <507, 510, 513>    <514, 520, 515>,
    <514, 515, 518>    <514, 518, 516>,
    <514, 516, 519>    <514, 519, 517>,
    <514, 517, 520>    <521, 527, 522>,
    <521, 522, 525>    <521, 525, 523>,
    <521, 523, 526>    <521, 526, 524>,
    <521, 524, 527>    <528, 534, 529>,
    <528, 529, 532>    <528, 532, 530>,
    <528, 530, 533>    <528, 533, 531>,
    <528, 531, 534>    <535, 541, 536>,
    <535, 536, 539>    <535, 539, 537>,
    <535, 537, 540>    <535, 540, 538>,
    <535, 538, 541>    <542, 550, 543>,
    <542, 543, 547>    <542, 547, 544>,
    <542, 544, 548>    <542, 548, 545>,
    <542, 545, 549>    <542, 549, 546>,
    <542, 546, 550>    <551, 559, 552>,
    <551, 552, 556>    <551, 556, 553>,
    <551, 553, 557>    <551, 557, 554>,
    <551, 554, 558>    <551, 558, 555>,
    <551, 555, 559>    <560, 568, 561>,
    <560, 561, 565>    <560, 565, 562>,
    <560, 562, 566>    <560, 566, 563>,
    <560, 563, 567>    <560, 567, 564>,
    <560, 564, 568>    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1052, 1047>,
    <1046, 1047, 1050>    <1046, 1050, 1048>,
    <1046, 1048, 1051>    <1046, 1051, 1049>,
    <1046, 1049, 1052>    <1053, 1059, 1054>,
    <1053, 1054, 1057>    <1053, 1057, 1055>,
    <1053, 1055, 1058>    <1053, 1058, 1056>,
    <1053, 1056, 1059>    <1060, 1066, 1061>,
    <1060, 1061, 1064>    <1060, 1064, 1062>,
    <1060, 1062, 1065>    <1060, 1065, 1063>,
    <1060, 1063, 1066>    <1067, 1073, 1068>,
    <1067, 1068, 1071>    <1067, 1071, 1069>,
    <1067, 1069, 1072>    <1067, 1072, 1070>,
    <1067, 1070, 1073>    <1074, 1080, 1075>,
    <1074, 1075, 1078>    <1074, 1078, 1076>,
    <1074, 1076, 1079>    <1074, 1079, 1077>,
    <1074, 1077, 1080>    <1081, 1087, 1082>,
    <1081, 1082, 1085>    <1081, 1085, 1083>,
    <1081, 1083, 1086>    <1081, 1086, 1084>,
    <1081, 1084, 1087>    <1088, 1094, 1089>,
    <1088, 1089, 1092>    <1088, 1092, 1090>,
    <1088, 1090, 1093>    <1088, 1093, 1091>,
    <1088, 1091, 1094>    <1095, 1101, 1096>,
    <1095, 1096, 1099>    <1095, 1099, 1097>,
    <1095, 1097, 1100>    <1095, 1100, 1098>,
    <1095, 1098, 1101>    <1102, 1110, 1103>,
    <1102, 1103, 1107>    <1102, 1107, 1104>,
    <1102, 1104, 1108>    <1102, 1108, 1105>,
    <1102, 1105, 1109>    <1102, 1109, 1106>,
    <1102, 1106, 1110>    <1111, 1119, 1112>,
    <1111, 1112, 1116>    <1111, 1116, 1113>,
    <1111, 1113, 1117>    <1111, 1117, 1114>,
    <1111, 1114, 1118>    <1111, 1118, 1115>,
    <1111, 1115, 1119>    <1120, 1128, 1121>,
    <1120, 1121, 1125>    <1120, 1125, 1122>,
    <1120, 1122, 1126>    <1120, 1126, 1123>,
    <1120, 1123, 1127>    <1120, 1127, 1124>,
    <1120, 1124, 1128>    <1129, 1137, 1130>,
    <1129, 1130, 1134>    <1129, 1134, 1131>,
    <1129, 1131, 1135>    <1129, 1135, 1132>,
    <1129, 1132, 1136>    <1129, 1136, 1133>,
    <1129, 1133, 1137>    <1138, 1146, 1139>,
    <1138, 1139, 1143>    <1138, 1143, 1140>,
    <1138, 1140, 1144>    <1138, 1144, 1141>,
    <1138, 1141, 1145>    <1138, 1145, 1142>,
    <1138, 1142, 1146>    <1147, 1155, 1148>,
    <1147, 1148, 1152>    <1147, 1152, 1149>,
    <1147, 1149, 1153>    <1147, 1153, 1150>,
    <1147, 1150, 1154>    <1147, 1154, 1151>,
    <1147, 1151, 1155>    <1156, 1164, 1157>,
    <1156, 1157, 1161>    <1156, 1161, 1158>,
    <1156, 1158, 1162>    <1156, 1162, 1159>,
    <1156, 1159, 1163>    <1156, 1163, 1160>,
    <1156, 1160, 1164>    <1165, 1173, 1166>,
    <1165, 1166, 1170>    <1165, 1170, 1167>,
    <1165, 1167, 1171>    <1165, 1171, 1168>,
    <1165, 1168, 1172>    <1165, 1172, 1169>,
    <1165, 1169, 1173>    <1174, 1182, 1175>,
    <1174, 1175, 1179>    <1174, 1179, 1176>,
    <1174, 1176, 1180>    <1174, 1180, 1177>,
    <1174, 1177, 1181>    <1174, 1181, 1178>,
    <1174, 1178, 1182>    <1183, 1191, 1184>,
    <1183, 1184, 1188>    <1183, 1188, 1185>,
    <1183, 1185, 1189>    <1183, 1189, 1186>,
    <1183, 1186, 1190>    <1183, 1190, 1187>,
    <1183, 1187, 1191>    <1192, 1200, 1193>,
    <1192, 1193, 1197>    <1192, 1197, 1194>,
    <1192, 1194, 1198>    <1192, 1198, 1195>,
    <1192, 1195, 1199>    <1192, 1199, 1196>,
    <1192, 1196, 1200>    <1201, 1209, 1202>,
    <1201, 1202, 1206>    <1201, 1206, 1203>,
    <1201, 1203, 1207>    <1201, 1207, 1204>,
    <1201, 1204, 1208>    <1201, 1208, 1205>,
    <1201, 1205, 1209>    <1210, 1218, 1211>,
    <1210, 1211, 1215>    <1210, 1215, 1212>,
    <1210, 1212, 1216>    <1210, 1216, 1213>,
    <1210, 1213, 1217>    <1210, 1217, 1214>,
    <1210, 1214, 1218>    <1219, 1227, 1220>,
    <1219, 1220, 1224>    <1219, 1224, 1221>,
    <1219, 1221, 1225>    <1219, 1225, 1222>,
    <1219, 1222, 1226>    <1219, 1226, 1223>,
    <1219, 1223, 1227>    <1228, 1236, 1229>,
    <1228, 1229, 1233>    <1228, 1233, 1230>,
    <1228, 1230, 1234>    <1228, 1234, 1231>,
    <1228, 1231, 1235>    <1228, 1235, 1232>,
    <1228, 1232, 1236>    <1237, 1245, 1238>,
    <1237, 1238, 1242>    <1237, 1242, 1239>,
    <1237, 1239, 1243>    <1237, 1243, 1240>,
    <1237, 1240, 1244>    <1237, 1244, 1241>,
    <1237, 1241, 1245>    <1246, 1254, 1247>,
    <1246, 1247, 1251>    <1246, 1251, 1248>,
    <1246, 1248, 1252>    <1246, 1252, 1249>,
    <1246, 1249, 1253>    <1246, 1253, 1250>,
    <1246, 1250, 1254>    <1255, 1263, 1256>,
    <1255, 1256, 1260>    <1255, 1260, 1257>,
    <1255, 1257, 1261>    <1255, 1261, 1258>,
    <1255, 1258, 1262>    <1255, 1262, 1259>,
    <1255, 1259, 1263>    <1264, 1272, 1265>,
    <1264, 1265, 1269>    <1264, 1269, 1266>,
    <1264, 1266, 1270>    <1264, 1270, 1267>,
    <1264, 1267, 1271>    <1264, 1271, 1268>,
    <1264, 1268, 1272>    <1273, 1281, 1274>,
    <1273, 1274, 1278>    <1273, 1278, 1275>,
    <1273, 1275, 1279>    <1273, 1279, 1276>,
    <1273, 1276, 1280>    <1273, 1280, 1277>,
    <1273, 1277, 1281>    <1282, 1290, 1283>,
    <1282, 1283, 1287>    <1282, 1287, 1284>,
    <1282, 1284, 1288>    <1282, 1288, 1285>,
    <1282, 1285, 1289>    <1282, 1289, 1286>,
    <1282, 1286, 1290>    <1291, 1299, 1292>,
    <1291, 1292, 1296>    <1291, 1296, 1293>,
    <1291, 1293, 1297>    <1291, 1297, 1294>,
    <1291, 1294, 1298>    <1291, 1298, 1295>,
    <1291, 1295, 1299>    <1300, 1308, 1301>,
    <1300, 1301, 1305>    <1300, 1305, 1302>,
    <1300, 1302, 1306>    <1300, 1306, 1303>,
    <1300, 1303, 1307>    <1300, 1307, 1304>,
    <1300, 1304, 1308>    <1309, 1317, 1310>,
    <1309, 1310, 1314>    <1309, 1314, 1311>,
    <1309, 1311, 1315>    <1309, 1315, 1312>,
    <1309, 1312, 1316>    <1309, 1316, 1313>,
    <1309, 1313, 1317>    <1318, 1326, 1319>,
    <1318, 1319, 1323>    <1318, 1323, 1320>,
    <1318, 1320, 1324>    <1318, 1324, 1321>,
    <1318, 1321, 1325>    <1318, 1325, 1322>,
    <1318, 1322, 1326>    <1327, 1335, 1328>,
    <1327, 1328, 1332>    <1327, 1332, 1329>,
    <1327, 1329, 1333>    <1327, 1333, 1330>,
    <1327, 1330, 1334>    <1327, 1334, 1331>,
    <1327, 1331, 1335>    <1336, 1344, 1337>,
    <1336, 1337, 1341>    <1336, 1341, 1338>,
    <1336, 1338, 1342>    <1336, 1342, 1339>,
    <1336, 1339, 1343>    <1336, 1343, 1340>,
    <1336, 1340, 1344>    <1345, 1353, 1346>,
    <1345, 1346, 1350>    <1345, 1350, 1347>,
    <1345, 1347, 1351>    <1345, 1351, 1348>,
    <1345, 1348, 1352>    <1345, 1352, 1349>,
    <1345, 1349, 1353>    <1354, 1362, 1355>,
    <1354, 1355, 1359>    <1354, 1359, 1356>,
    <1354, 1356, 1360>    <1354, 1360, 1357>,
    <1354, 1357, 1361>    <1354, 1361, 1358>,
    <1354, 1358, 1362>    <1363, 1371, 1364>,
    <1363, 1364, 1368>    <1363, 1368, 1365>,
    <1363, 1365, 1369>    <1363, 1369, 1366>,
    <1363, 1366, 1370>    <1363, 1370, 1367>,
    <1363, 1367, 1371>    <1372, 1380, 1373>,
    <1372, 1373, 1377>    <1372, 1377, 1374>,
    <1372, 1374, 1378>    <1372, 1378, 1375>,
    <1372, 1375, 1379>    <1372, 1379, 1376>,
    <1372, 1376, 1380>    <1381, 1389, 1382>,
    <1381, 1382, 1386>    <1381, 1386, 1383>,
    <1381, 1383, 1387>    <1381, 1387, 1384>,
    <1381, 1384, 1388>    <1381, 1388, 1385>,
    <1381, 1385, 1389>    <1390, 1398, 1391>,
    <1390, 1391, 1395>    <1390, 1395, 1392>,
    <1390, 1392, 1396>    <1390, 1396, 1393>,
    <1390, 1393, 1397>    <1390, 1397, 1394>,
    <1390, 1394, 1398>    <1399, 1407, 1400>,
    <1399, 1400, 1404>    <1399, 1404, 1401>,
    <1399, 1401, 1405>    <1399, 1405, 1402>,
    <1399, 1402, 1406>    <1399, 1406, 1403>,
    <1399, 1403, 1407>    <1408, 1416, 1409>,
    <1408, 1409, 1413>    <1408, 1413, 1410>,
    <1408, 1410, 1414>    <1408, 1414, 1411>,
    <1408, 1411, 1415>    <1408, 1415, 1412>,
    <1408, 1412, 1416>    <1417, 1425, 1418>,
    <1417, 1418, 1422>    <1417, 1422, 1419>,
    <1417, 1419, 1423>    <1417, 1423, 1420>,
    <1417, 1420, 1424>    <1417, 1424, 1421>,
    <1417, 1421, 1425>    <1426, 1434, 1427>,
    <1426, 1427, 1431>    <1426, 1431, 1428>,
    <1426, 1428, 1432>    <1426, 1432, 1429>,
    <1426, 1429, 1433>    <1426, 1433, 1430>,
    <1426, 1430, 1434>    <1435, 1443, 1436>,
    <1435, 1436, 1440>    <1435, 1440, 1437>,
    <1435, 1437, 1441>    <1435, 1441, 1438>,
    <1435, 1438, 1442>    <1435, 1442, 1439>,
    <1435, 1439, 1443>    <1444, 1452, 1445>,
    <1444, 1445, 1449>    <1444, 1449, 1446>,
    <1444, 1446, 1450>    <1444, 1450, 1447>,
    <1444, 1447, 1451>    <1444, 1451, 1448>,
    <1444, 1448, 1452>    <1453, 1461, 1454>,
    <1453, 1454, 1458>    <1453, 1458, 1455>,
    <1453, 1455, 1459>    <1453, 1459, 1456>,
    <1453, 1456, 1460>    <1453, 1460, 1457>,
    <1453, 1457, 1461>    <1462, 1470, 1463>,
    <1462, 1463, 1467>    <1462, 1467, 1464>,
    <1462, 1464, 1468>    <1462, 1468, 1465>,
    <1462, 1465, 1469>    <1462, 1469, 1466>,
    <1462, 1466, 1470>    <1471, 1479, 1472>,
    <1471, 1472, 1476>    <1471, 1476, 1473>,
    <1471, 1473, 1477>    <1471, 1477, 1474>,
    <1471, 1474, 1478>    <1471, 1478, 1475>,
    <1471, 1475, 1479>    <1480, 1488, 1481>,
    <1480, 1481, 1485>    <1480, 1485, 1482>,
    <1480, 1482, 1486>    <1480, 1486, 1483>,
    <1480, 1483, 1487>    <1480, 1487, 1484>,
    <1480, 1484, 1488>    <1489, 1497, 1490>,
    <1489, 1490, 1494>    <1489, 1494, 1491>,
    <1489, 1491, 1495>    <1489, 1495, 1492>,
    <1489, 1492, 1496>    <1489, 1496, 1493>,
    <1489, 1493, 1497>    <1498, 1506, 1499>,
    <1498, 1499, 1503>    <1498, 1503, 1500>,
    <1498, 1500, 1504>    <1498, 1504, 1501>,
    <1498, 1501, 1505>    <1498, 1505, 1502>,
    <1498, 1502, 1506>    <1507, 1515, 1508>,
    <1507, 1508, 1512>    <1507, 1512, 1509>,
    <1507, 1509, 1513>    <1507, 1513, 1510>,
    <1507, 1510, 1514>    <1507, 1514, 1511>,
    <1507, 1511, 1515>    <1516, 1524, 1517>,
    <1516, 1517, 1521>    <1516, 1521, 1518>,
    <1516, 1518, 1522>    <1516, 1522, 1519>,
    <1516, 1519, 1523>    <1516, 1523, 1520>,
    <1516, 1520, 1524>    <1525, 1533, 1526>,
    <1525, 1526, 1530>    <1525, 1530, 1527>,
    <1525, 1527, 1531>    <1525, 1531, 1528>,
    <1525, 1528, 1532>    <1525, 1532, 1529>,
    <1525, 1529, 1533>    <1534, 1542, 1535>,
    <1534, 1535, 1539>    <1534, 1539, 1536>,
    <1534, 1536, 1540>    <1534, 1540, 1537>,
    <1534, 1537, 1541>    <1534, 1541, 1538>,
    <1534, 1538, 1542>    <1543, 1551, 1544>,
    <1543, 1544, 1548>    <1543, 1548, 1545>,
    <1543, 1545, 1549>    <1543, 1549, 1546>,
    <1543, 1546, 1550>    <1543, 1550, 1547>,
    <1543, 1547, 1551>    <1552, 1560, 1553>,
    <1552, 1553, 1557>    <1552, 1557, 1554>,
    <1552, 1554, 1558>    <1552, 1558, 1555>,
    <1552, 1555, 1559>    <1552, 1559, 1556>,
    <1552, 1556, 1560>    <1561, 1569, 1562>,
    <1561, 1562, 1566>    <1561, 1566, 1563>,
    <1561, 1563, 1567>    <1561, 1567, 1564>,
    <1561, 1564, 1568>    <1561, 1568, 1565>,
    <1561, 1565, 1569>    <1570, 1578, 1571>,
    <1570, 1571, 1575>    <1570, 1575, 1572>,
    <1570, 1572, 1576>    <1570, 1576, 1573>,
    <1570, 1573, 1577>    <1570, 1577, 1574>,
    <1570, 1574, 1578>    <1579, 1587, 1580>,
    <1579, 1580, 1584>    <1579, 1584, 1581>,
    <1579, 1581, 1585>    <1579, 1585, 1582>,
    <1579, 1582, 1586>    <1579, 1586, 1583>,
    <1579, 1583, 1587>    <1588, 1596, 1589>,
    <1588, 1589, 1593>    <1588, 1593, 1590>,
    <1588, 1590, 1594>    <1588, 1594, 1591>,
    <1588, 1591, 1595>    <1588, 1595, 1592>,
    <1588, 1592, 1596>    <1597, 1605, 1598>,
    <1597, 1598, 1602>    <1597, 1602, 1599>,
    <1597, 1599, 1603>    <1597, 1603, 1600>,
    <1597, 1600, 1604>    <1597, 1604, 1601>,
    <1597, 1601, 1605>    <1606, 1614, 1607>,
    <1606, 1607, 1611>    <1606, 1611, 1608>,
    <1606, 1608, 1612>    <1606, 1612, 1609>,
    <1606, 1609, 1613>    <1606, 1613, 1610>,
    <1606, 1610, 1614>    <1615, 1623, 1616>,
    <1615, 1616, 1620>    <1615, 1620, 1617>,
    <1615, 1617, 1621>    <1615, 1621, 1618>,
    <1615, 1618, 1622>    <1615, 1622, 1619>,
    <1615, 1619, 1623>    <1624, 1632, 1625>,
    <1624, 1625, 1629>    <1624, 1629, 1626>,
    <1624, 1626, 1630>    <1624, 1630, 1627>,
    <1624, 1627, 1631>    <1624, 1631, 1628>,
    <1624, 1628, 1632>    <1633, 1641, 1634>,
    <1633, 1634, 1638>    <1633, 1638, 1635>,
    <1633, 1635, 1639>    <1633, 1639, 1636>,
    <1633, 1636, 1640>    <1633, 1640, 1637>,
    <1633, 1637, 1641>    <1642, 1650, 1643>,
    <1642, 1643, 1647>    <1642, 1647, 1644>,
    <1642, 1644, 1648>    <1642, 1648, 1645>,
    <1642, 1645, 1649>    <1642, 1649, 1646>,
    <1642, 1646, 1650>    <1651, 1659, 1652>,
    <1651, 1652, 1656>    <1651, 1656, 1653>,
    <1651, 1653, 1657>    <1651, 1657, 1654>,
    <1651, 1654, 1658>    <1651, 1658, 1655>,
    <1651, 1655, 1659>    <1660, 1668, 1661>,
    <1660, 1661, 1665>    <1660, 1665, 1662>,
    <1660, 1662, 1666>    <1660, 1666, 1663>,
    <1660, 1663, 1667>    <1660, 1667, 1664>,
    <1660, 1664, 1668>    <1669, 1677, 1670>,
    <1669, 1670, 1674>    <1669, 1674, 1671>,
    <1669, 1671, 1675>    <1669, 1675, 1672>,
    <1669, 1672, 1676>    <1669, 1676, 1673>,
    <1669, 1673, 1677>    <1678, 1686, 1679>,
    <1678, 1679, 1683>    <1678, 1683, 1680>,
    <1678, 1680, 1684>    <1678, 1684, 1681>,
    <1678, 1681, 1685>    <1678, 1685, 1682>,
    <1678, 1682, 1686>    <1687, 1695, 1688>,
    <1687, 1688, 1692>    <1687, 1692, 1689>,
    <1687, 1689, 1693>    <1687, 1693, 1690>,
    <1687, 1690, 1694>    <1687, 1694, 1691>,
    <1687, 1691, 1695>    <1696, 1704, 1697>,
    <1696, 1697, 1701>    <1696, 1701, 1698>,
    <1696, 1698, 1702>    <1696, 1702, 1699>,
    <1696, 1699, 1703>    <1696, 1703, 1700>,
    <1696, 1700, 1704>    <1705, 1713, 1706>,
    <1705, 1706, 1710>    <1705, 1710, 1707>,
    <1705, 1707, 1711>    <1705, 1711, 1708>,
    <1705, 1708, 1712>    <1705, 1712, 1709>,
    <1705, 1709, 1713>    <1714, 1722, 1715>,
    <1714, 1715, 1719>    <1714, 1719, 1716>,
    <1714, 1716, 1720>    <1714, 1720, 1717>,
    <1714, 1717, 1721>    <1714, 1721, 1718>,
    <1714, 1718, 1722>    <1723, 1731, 1724>,
    <1723, 1724, 1728>    <1723, 1728, 1725>,
    <1723, 1725, 1729>    <1723, 1729, 1726>,
    <1723, 1726, 1730>    <1723, 1730, 1727>,
    <1723, 1727, 1731>    <1732, 1740, 1733>,
    <1732, 1733, 1737>    <1732, 1737, 1734>,
    <1732, 1734, 1738>    <1732, 1738, 1735>,
    <1732, 1735, 1739>    <1732, 1739, 1736>,
    <1732, 1736, 1740>    <1741, 1749, 1742>,
    <1741, 1742, 1746>    <1741, 1746, 1743>,
    <1741, 1743, 1747>    <1741, 1747, 1744>,
    <1741, 1744, 1748>    <1741, 1748, 1745>,
    <1741, 1745, 1749>    <1750, 1758, 1751>,
    <1750, 1751, 1755>    <1750, 1755, 1752>,
    <1750, 1752, 1756>    <1750, 1756, 1753>,
    <1750, 1753, 1757>    <1750, 1757, 1754>,
    <1750, 1754, 1758>    <1759, 1767, 1760>,
    <1759, 1760, 1764>    <1759, 1764, 1761>,
    <1759, 1761, 1765>    <1759, 1765, 1762>,
    <1759, 1762, 1766>    <1759, 1766, 1763>,
    <1759, 1763, 1767>    <1768, 1776, 1769>,
    <1768, 1769, 1773>    <1768, 1773, 1770>,
    <1768, 1770, 1774>    <1768, 1774, 1771>,
    <1768, 1771, 1775>    <1768, 1775, 1772>,
    <1768, 1772, 1776>    <1777, 1785, 1778>,
    <1777, 1778, 1782>    <1777, 1782, 1779>,
    <1777, 1779, 1783>    <1777, 1783, 1780>,
    <1777, 1780, 1784>    <1777, 1784, 1781>,
    <1777, 1781, 1785>    <1786, 1794, 1787>,
    <1786, 1787, 1791>    <1786, 1791, 1788>,
    <1786, 1788, 1792>    <1786, 1792, 1789>,
    <1786, 1789, 1793>    <1786, 1793, 1790>,
    <1786, 1790, 1794>    <1795, 1803, 1796>,
    <1795, 1796, 1800>    <1795, 1800, 1797>,
    <1795, 1797, 1801>    <1795, 1801, 1798>,
    <1795, 1798, 1802>    <1795, 1802, 1799>,
    <1795, 1799, 1803>    <1804, 1812, 1805>,
    <1804, 1805, 1809>    <1804, 1809, 1806>,
    <1804, 1806, 1810>    <1804, 1810, 1807>,
    <1804, 1807, 1811>    <1804, 1811, 1808>,
    <1804, 1808, 1812>    <1813, 1821, 1814>,
    <1813, 1814, 1818>    <1813, 1818, 1815>,
    <1813, 1815, 1819>    <1813, 1819, 1816>,
    <1813, 1816, 1820>    <1813, 1820, 1817>,
    <1813, 1817, 1821>    <1822, 1830, 1823>,
    <1822, 1823, 1827>    <1822, 1827, 1824>,
    <1822, 1824, 1828>    <1822, 1828, 1825>,
    <1822, 1825, 1829>    <1822, 1829, 1826>,
    <1822, 1826, 1830>    <1831, 1839, 1832>,
    <1831, 1832, 1836>    <1831, 1836, 1833>,
    <1831, 1833, 1837>    <1831, 1837, 1834>,
    <1831, 1834, 1838>    <1831, 1838, 1835>,
    <1831, 1835, 1839>    <1840, 1848, 1841>,
    <1840, 1841, 1845>    <1840, 1845, 1842>,
    <1840, 1842, 1846>    <1840, 1846, 1843>,
    <1840, 1843, 1847>    <1840, 1847, 1844>,
    <1840, 1844, 1848>    <1849, 1857, 1850>,
    <1849, 1850, 1854>    <1849, 1854, 1851>,
    <1849, 1851, 1855>    <1849, 1855, 1852>,
    <1849, 1852, 1856>    <1849, 1856, 1853>,
    <1849, 1853, 1857>    <1858, 1866, 1859>,
    <1858, 1859, 1863>    <1858, 1863, 1860>,
    <1858, 1860, 1864>    <1858, 1864, 1861>,
    <1858, 1861, 1865>    <1858, 1865, 1862>,
    <1858, 1862, 1866>    <1867, 1875, 1868>,
    <1867, 1868, 1872>    <1867, 1872, 1869>,
    <1867, 1869, 1873>    <1867, 1873, 1870>,
    <1867, 1870, 1874>    <1867, 1874, 1871>,
    <1867, 1871, 1875>    <1876, 1884, 1877>,
    <1876, 1877, 1881>    <1876, 1881, 1878>,
    <1876, 1878, 1882>    <1876, 1882, 1879>,
    <1876, 1879, 1883>    <1876, 1883, 1880>,
    <1876, 1880, 1884>    <1885, 1893, 1886>,
    <1885, 1886, 1890>    <1885, 1890, 1887>,
    <1885, 1887, 1891>    <1885, 1891, 1888>,
    <1885, 1888, 1892>    <1885, 1892, 1889>,
    <1885, 1889, 1893>    <1894, 1902, 1895>,
    <1894, 1895, 1899>    <1894, 1899, 1896>,
    <1894, 1896, 1900>    <1894, 1900, 1897>,
    <1894, 1897, 1901>    <1894, 1901, 1898>,
    <1894, 1898, 1902>    <1903, 1911, 1904>,
    <1903, 1904, 1908>    <1903, 1908, 1905>,
    <1903, 1905, 1909>    <1903, 1909, 1906>,
    <1903, 1906, 1910>    <1903, 1910, 1907>,
    <1903, 1907, 1911>    <1912, 1920, 1913>,
    <1912, 1913, 1917>    <1912, 1917, 1914>,
    <1912, 1914, 1918>    <1912, 1918, 1915>,
    <1912, 1915, 1919>    <1912, 1919, 1916>,
    <1912, 1916, 1920>    <1921, 1929, 1922>,
    <1921, 1922, 1926>    <1921, 1926, 1923>,
    <1921, 1923, 1927>    <1921, 1927, 1924>,
    <1921, 1924, 1928>    <1921, 1928, 1925>,
    <1921, 1925, 1929>    <1930, 1938, 1931>,
    <1930, 1931, 1935>    <1930, 1935, 1932>,
    <1930, 1932, 1936>    <1930, 1936, 1933>,
    <1930, 1933, 1937>    <1930, 1937, 1934>,
    <1930, 1934, 1938>    <1939, 1947, 1940>,
    <1939, 1940, 1944>    <1939, 1944, 1941>,
    <1939, 1941, 1945>    <1939, 1945, 1942>,
    <1939, 1942, 1946>    <1939, 1946, 1943>,
    <1939, 1943, 1947>    <1948, 1956, 1949>,
    <1948, 1949, 1953>    <1948, 1953, 1950>,
    <1948, 1950, 1954>    <1948, 1954, 1951>,
    <1948, 1951, 1955>    <1948, 1955, 1952>,
    <1948, 1952, 1956>    <1957, 1965, 1958>,
    <1957, 1958, 1962>    <1957, 1962, 1959>,
    <1957, 1959, 1963>    <1957, 1963, 1960>,
    <1957, 1960, 1964>    <1957, 1964, 1961>,
    <1957, 1961, 1965>    <1966, 1974, 1967>,
    <1966, 1967, 1971>    <1966, 1971, 1968>,
    <1966, 1968, 1972>    <1966, 1972, 1969>,
    <1966, 1969, 1973>    <1966, 1973, 1970>,
    <1966, 1970, 1974>    <1975, 1983, 1976>,
    <1975, 1976, 1980>    <1975, 1980, 1977>,
    <1975, 1977, 1981>    <1975, 1981, 1978>,
    <1975, 1978, 1982>    <1975, 1982, 1979>,
    <1975, 1979, 1983>    <1984, 1992, 1985>,
    <1984, 1985, 1989>    <1984, 1989, 1986>,
    <1984, 1986, 1990>    <1984, 1990, 1987>,
    <1984, 1987, 1991>    <1984, 1991, 1988>,
    <1984, 1988, 1992>    <1993, 2001, 1994>,
    <1993, 1994, 1998>    <1993, 1998, 1995>,
    <1993, 1995, 1999>    <1993, 1999, 1996>,
    <1993, 1996, 2000>    <1993, 2000, 1997>,
    <1993, 1997, 2001>    <2002, 2010, 2003>,
    <2002, 2003, 2007>    <2002, 2007, 2004>,
    <2002, 2004, 2008>    <2002, 2008, 2005>,
    <2002, 2005, 2009>    <2002, 2009, 2006>,
    <2002, 2006, 2010>    <2011, 2019, 2012>,
    <2011, 2012, 2016>    <2011, 2016, 2013>,
    <2011, 2013, 2017>    <2011, 2017, 2014>,
    <2011, 2014, 2018>    <2011, 2018, 2015>,
    <2011, 2015, 2019>    <2020, 2028, 2021>,
    <2020, 2021, 2025>    <2020, 2025, 2022>,
    <2020, 2022, 2026>    <2020, 2026, 2023>,
    <2020, 2023, 2027>    <2020, 2027, 2024>,
    <2020, 2024, 2028>    <2029, 2037, 2030>,
    <2029, 2030, 2034>    <2029, 2034, 2031>,
    <2029, 2031, 2035>    <2029, 2035, 2032>,
    <2029, 2032, 2036>    <2029, 2036, 2033>,
    <2029, 2033, 2037>    <2038, 2046, 2039>,
    <2038, 2039, 2043>    <2038, 2043, 2040>,
    <2038, 2040, 2044>    <2038, 2044, 2041>,
    <2038, 2041, 2045>    <2038, 2045, 2042>,
    <2038, 2042, 2046>    <2047, 2055, 2048>,
    <2047, 2048, 2052>    <2047, 2052, 2049>,
    <2047, 2049, 2053>    <2047, 2053, 2050>,
    <2047, 2050, 2054>    <2047, 2054, 2051>,
    <2047, 2051, 2055>    <2056, 2064, 2057>,
    <2056, 2057, 2061>    <2056, 2061, 2058>,
    <2056, 2058, 2062>    <2056, 2062, 2059>,
    <2056, 2059, 2063>    <2056, 2063, 2060>,
    <2056, 2060, 2064>    <2065, 2073, 2066>,
    <2065, 2066, 2070>    <2065, 2070, 2067>,
    <2065, 2067, 2071>    <2065, 2071, 2068>,
    <2065, 2068, 2072>    <2065, 2072, 2069>,
    <2065, 2069, 2073>    <2074, 2082, 2075>,
    <2074, 2075, 2079>    <2074, 2079, 2076>,
    <2074, 2076, 2080>    <2074, 2080, 2077>,
    <2074, 2077, 2081>    <2074, 2081, 2078>,
    <2074, 2078, 2082>    <2083, 2091, 2084>,
    <2083, 2084, 2088>    <2083, 2088, 2085>,
    <2083, 2085, 2089>    <2083, 2089, 2086>,
    <2083, 2086, 2090>    <2083, 2090, 2087>,
    <2083, 2087, 2091>    <2092, 2100, 2093>,
    <2092, 2093, 2097>    <2092, 2097, 2094>,
    <2092, 2094, 2098>    <2092, 2098, 2095>,
    <2092, 2095, 2099>    <2092, 2099, 2096>,
    <2092, 2096, 2100>    <2101, 2109, 2102>,
    <2101, 2102, 2106>    <2101, 2106, 2103>,
    <2101, 2103, 2107>    <2101, 2107, 2104>,
    <2101, 2104, 2108>    <2101, 2108, 2105>,
    <2101, 2105, 2109>    <2110, 2118, 2111>,
    <2110, 2111, 2115>    <2110, 2115, 2112>,
    <2110, 2112, 2116>    <2110, 2116, 2113>,
    <2110, 2113, 2117>    <2110, 2117, 2114>,
    <2110, 2114, 2118>    <2119, 2127, 2120>,
    <2119, 2120, 2124>    <2119, 2124, 2121>,
    <2119, 2121, 2125>    <2119, 2125, 2122>,
    <2119, 2122, 2126>    <2119, 2126, 2123>,
    <2119, 2123, 2127>    <2128, 2136, 2129>,
    <2128, 2129, 2133>    <2128, 2133, 2130>,
    <2128, 2130, 2134>    <2128, 2134, 2131>,
    <2128, 2131, 2135>    <2128, 2135, 2132>,
    <2128, 2132, 2136>    <2137, 2145, 2138>,
    <2137, 2138, 2142>    <2137, 2142, 2139>,
    <2137, 2139, 2143>    <2137, 2143, 2140>,
    <2137, 2140, 2144>    <2137, 2144, 2141>,
    <2137, 2141, 2145>    <2146, 2154, 2147>,
    <2146, 2147, 2151>    <2146, 2151, 2148>,
    <2146, 2148, 2152>    <2146, 2152, 2149>,
    <2146, 2149, 2153>    <2146, 2153, 2150>,
    <2146, 2150, 2154>    <2155, 2163, 2156>,
    <2155, 2156, 2160>    <2155, 2160, 2157>,
    <2155, 2157, 2161>    <2155, 2161, 2158>,
    <2155, 2158, 2162>    <2155, 2162, 2159>,
    <2155, 2159, 2163>    <2164, 2172, 2165>,
    <2164, 2165, 2169>    <2164, 2169, 2166>,
    <2164, 2166, 2170>    <2164, 2170, 2167>,
    <2164, 2167, 2171>    <2164, 2171, 2168>,
    <2164, 2168, 2172>    <2173, 2181, 2174>,
    <2173, 2174, 2178>    <2173, 2178, 2175>,
    <2173, 2175, 2179>    <2173, 2179, 2176>,
    <2173, 2176, 2180>    <2173, 2180, 2177>,
    <2173, 2177, 2181>    <2182, 2190, 2183>,
    <2182, 2183, 2187>    <2182, 2187, 2184>,
    <2182, 2184, 2188>    <2182, 2188, 2185>,
    <2182, 2185, 2189>    <2182, 2189, 2186>,
    <2182, 2186, 2190>    <2191, 2199, 2192>,
    <2191, 2192, 2196>    <2191, 2196, 2193>,
    <2191, 2193, 2197>    <2191, 2197, 2194>,
    <2191, 2194, 2198>    <2191, 2198, 2195>,
    <2191, 2195, 2199>    <2200, 2208, 2201>,
    <2200, 2201, 2205>    <2200, 2205, 2202>,
    <2200, 2202, 2206>    <2200, 2206, 2203>,
    <2200, 2203, 2207>    <2200, 2207, 2204>,
    <2200, 2204, 2208>    <2209, 2217, 2210>,
    <2209, 2210, 2214>    <2209, 2214, 2211>,
    <2209, 2211, 2215>    <2209, 2215, 2212>,
    <2209, 2212, 2216>    <2209, 2216, 2213>,
    <2209, 2213, 2217>    <2218, 2226, 2219>,
    <2218, 2219, 2223>    <2218, 2223, 2220>,
    <2218, 2220, 2224>    <2218, 2224, 2221>,
    <2218, 2221, 2225>    <2218, 2225, 2222>,
    <2218, 2222, 2226>    <2227, 2235, 2228>,
    <2227, 2228, 2232>    <2227, 2232, 2229>,
    <2227, 2229, 2233>    <2227, 2233, 2230>,
    <2227, 2230, 2234>    <2227, 2234, 2231>,
    <2227, 2231, 2235>    <2236, 2244, 2237>,
    <2236, 2237, 2241>    <2236, 2241, 2238>,
    <2236, 2238, 2242>    <2236, 2242, 2239>,
    <2236, 2239, 2243>    <2236, 2243, 2240>,
    <2236, 2240, 2244>    <2245, 2253, 2246>,
    <2245, 2246, 2250>    <2245, 2250, 2247>,
    <2245, 2247, 2251>    <2245, 2251, 2248>,
    <2245, 2248, 2252>    <2245, 2252, 2249>,
    <2245, 2249, 2253>    <2254, 2262, 2255>,
    <2254, 2255, 2259>    <2254, 2259, 2256>,
    <2254, 2256, 2260>    <2254, 2260, 2257>,
    <2254, 2257, 2261>    <2254, 2261, 2258>,
    <2254, 2258, 2262>    <2263, 2271, 2264>,
    <2263, 2264, 2268>    <2263, 2268, 2265>,
    <2263, 2265, 2269>    <2263, 2269, 2266>,
    <2263, 2266, 2270>    <2263, 2270, 2267>,
    <2263, 2267, 2271>    <2272, 2280, 2273>,
    <2272, 2273, 2277>    <2272, 2277, 2274>,
    <2272, 2274, 2278>    <2272, 2278, 2275>,
    <2272, 2275, 2279>    <2272, 2279, 2276>,
    <2272, 2276, 2280>    <2281, 2289, 2282>,
    <2281, 2282, 2286>    <2281, 2286, 2283>,
    <2281, 2283, 2287>    <2281, 2287, 2284>,
    <2281, 2284, 2288>    <2281, 2288, 2285>,
    <2281, 2285, 2289>    <2290, 2298, 2291>,
    <2290, 2291, 2295>    <2290, 2295, 2292>,
    <2290, 2292, 2296>    <2290, 2296, 2293>,
    <2290, 2293, 2297>    <2290, 2297, 2294>,
    <2290, 2294, 2298>    <2299, 2307, 2300>,
    <2299, 2300, 2304>    <2299, 2304, 2301>,
    <2299, 2301, 2305>    <2299, 2305, 2302>,
    <2299, 2302, 2306>    <2299, 2306, 2303>,
    <2299, 2303, 2307>    <2308, 2316, 2309>,
    <2308, 2309, 2313>    <2308, 2313, 2310>,
    <2308, 2310, 2314>    <2308, 2314, 2311>,
    <2308, 2311, 2315>    <2308, 2315, 2312>,
    <2308, 2312, 2316>    <2317, 2325, 2318>,
    <2317, 2318, 2322>    <2317, 2322, 2319>,
    <2317, 2319, 2323>    <2317, 2323, 2320>,
    <2317, 2320, 2324>    <2317, 2324, 2321>,
    <2317, 2321, 2325>    <2326, 2334, 2327>,
    <2326, 2327, 2331>    <2326, 2331, 2328>,
    <2326, 2328, 2332>    <2326, 2332, 2329>,
    <2326, 2329, 2333>    <2326, 2333, 2330>,
    <2326, 2330, 2334>    <2335, 2343, 2336>,
    <2335, 2336, 2340>    <2335, 2340, 2337>,
    <2335, 2337, 2341>    <2335, 2341, 2338>,
    <2335, 2338, 2342>    <2335, 2342, 2339>,
    <2335, 2339, 2343>    <2344, 2352, 2345>,
    <2344, 2345, 2349>    <2344, 2349, 2346>,
    <2344, 2346, 2350>    <2344, 2350, 2347>,
    <2344, 2347, 2351>    <2344, 2351, 2348>,
    <2344, 2348, 2352>    <2353, 2361, 2354>,
    <2353, 2354, 2358>    <2353, 2358, 2355>,
    <2353, 2355, 2359>    <2353, 2359, 2356>,
    <2353, 2356, 2360>    <2353, 2360, 2357>,
    <2353, 2357, 2361>    <2362, 2370, 2363>,
    <2362, 2363, 2367>    <2362, 2367, 2364>,
    <2362, 2364, 2368>    <2362, 2368, 2365>,
    <2362, 2365, 2369>    <2362, 2369, 2366>,
    <2362, 2366, 2370>    <2371, 2379, 2372>,
    <2371, 2372, 2376>    <2371, 2376, 2373>,
    <2371, 2373, 2377>    <2371, 2377, 2374>,
    <2371, 2374, 2378>    <2371, 2378, 2375>,
    <2371, 2375, 2379>    <2380, 2388, 2381>,
    <2380, 2381, 2385>    <2380, 2385, 2382>,
    <2380, 2382, 2386>    <2380, 2386, 2383>,
    <2380, 2383, 2387>    <2380, 2387, 2384>,
    <2380, 2384, 2388>    <2389, 2397, 2390>,
    <2389, 2390, 2394>    <2389, 2394, 2391>,
    <2389, 2391, 2395>    <2389, 2395, 2392>,
    <2389, 2392, 2396>    <2389, 2396, 2393>,
    <2389, 2393, 2397>    <2398, 2406, 2399>,
    <2398, 2399, 2403>    <2398, 2403, 2400>,
    <2398, 2400, 2404>    <2398, 2404, 2401>,
    <2398, 2401, 2405>    <2398, 2405, 2402>,
    <2398, 2402, 2406>    <2407, 2415, 2408>,
    <2407, 2408, 2412>    <2407, 2412, 2409>,
    <2407, 2409, 2413>    <2407, 2413, 2410>,
    <2407, 2410, 2414>    <2407, 2414, 2411>,
    <2407, 2411, 2415>    <2416, 2424, 2417>,
    <2416, 2417, 2421>    <2416, 2421, 2418>,
    <2416, 2418, 2422>    <2416, 2422, 2419>,
    <2416, 2419, 2423>    <2416, 2423, 2420>,
    <2416, 2420, 2424>    <2425, 2433, 2426>,
    <2425, 2426, 2430>    <2425, 2430, 2427>,
    <2425, 2427, 2431>    <2425, 2431, 2428>,
    <2425, 2428, 2432>    <2425, 2432, 2429>,
    <2425, 2429, 2433>    <2434, 2442, 2435>,
    <2434, 2435, 2439>    <2434, 2439, 2436>,
    <2434, 2436, 2440>    <2434, 2440, 2437>,
    <2434, 2437, 2441>    <2434, 2441, 2438>,
    <2434, 2438, 2442>    <2443, 2451, 2444>,
    <2443, 2444, 2448>    <2443, 2448, 2445>,
    <2443, 2445, 2449>    <2443, 2449, 2446>,
    <2443, 2446, 2450>    <2443, 2450, 2447>,
    <2443, 2447, 2451>    <2452, 2460, 2453>,
    <2452, 2453, 2457>    <2452, 2457, 2454>,
    <2452, 2454, 2458>    <2452, 2458, 2455>,
    <2452, 2455, 2459>    <2452, 2459, 2456>,
    <2452, 2456, 2460>    <2461, 2469, 2462>,
    <2461, 2462, 2466>    <2461, 2466, 2463>,
    <2461, 2463, 2467>    <2461, 2467, 2464>,
    <2461, 2464, 2468>    <2461, 2468, 2465>,
    <2461, 2465, 2469>    <2470, 2478, 2471>,
    <2470, 2471, 2475>    <2470, 2475, 2472>,
    <2470, 2472, 2476>    <2470, 2476, 2473>,
    <2470, 2473, 2477>    <2470, 2477, 2474>,
    <2470, 2474, 2478>    <2479, 2487, 2480>,
    <2479, 2480, 2484>    <2479, 2484, 2481>,
    <2479, 2481, 2485>    <2479, 2485, 2482>,
    <2479, 2482, 2486>    <2479, 2486, 2483>,
    <2479, 2483, 2487>    <2488, 2496, 2489>,
    <2488, 2489, 2493>    <2488, 2493, 2490>,
    <2488, 2490, 2494>    <2488, 2494, 2491>,
    <2488, 2491, 2495>    <2488, 2495, 2492>,
    <2488, 2492, 2496>    <2497, 2505, 2498>,
    <2497, 2498, 2502>    <2497, 2502, 2499>,
    <2497, 2499, 2503>    <2497, 2503, 2500>,
    <2497, 2500, 2504>    <2497, 2504, 2501>,
    <2497, 2501, 2505>    <2506, 2514, 2507>,
    <2506, 2507, 2511>    <2506, 2511, 2508>,
    <2506, 2508, 2512>    <2506, 2512, 2509>,
    <2506, 2509, 2513>    <2506, 2513, 2510>,
    <2506, 2510, 2514>    <2515, 2523, 2516>,
    <2515, 2516, 2520>    <2515, 2520, 2517>,
    <2515, 2517, 2521>    <2515, 2521, 2518>,
    <2515, 2518, 2522>    <2515, 2522, 2519>,
    <2515, 2519, 2523>    <2524, 2532, 2525>,
    <2524, 2525, 2529>    <2524, 2529, 2526>,
    <2524, 2526, 2530>    <2524, 2530, 2527>,
    <2524, 2527, 2531>    <2524, 2531, 2528>,
    <2524, 2528, 2532>    <2533, 2541, 2534>,
    <2533, 2534, 2538>    <2533, 2538, 2535>,
    <2533, 2535, 2539>    <2533, 2539, 2536>,
    <2533, 2536, 2540>    <2533, 2540, 2537>,
    <2533, 2537, 2541>    <2542, 2550, 2543>,
    <2542, 2543, 2547>    <2542, 2547, 2544>,
    <2542, 2544, 2548>    <2542, 2548, 2545>,
    <2542, 2545, 2549>    <2542, 2549, 2546>,
    <2542, 2546, 2550>    <2551, 2559, 2552>,
    <2551, 2552, 2556>    <2551, 2556, 2553>,
    <2551, 2553, 2557>    <2551, 2557, 2554>,
    <2551, 2554, 2558>    <2551, 2558, 2555>,
    <2551, 2555, 2559>    <2560, 2568, 2561>,
    <2560, 2561, 2565>    <2560, 2565, 2562>,
    <2560, 2562, 2566>    <2560, 2566, 2563>,
    <2560, 2563, 2567>    <2560, 2567, 2564>,
    <2560, 2564, 2568>    <2569, 2577, 2570>,
    <2569, 2570, 2574>    <2569, 2574, 2571>,
    <2569, 2571, 2575>    <2569, 2575, 2572>,
    <2569, 2572, 2576>    <2569, 2576, 2573>,
    <2569, 2573, 2577>    <2578, 2586, 2579>,
    <2578, 2579, 2583>    <2578, 2583, 2580>,
    <2578, 2580, 2584>    <2578, 2584, 2581>,
    <2578, 2581, 2585>    <2578, 2585, 2582>,
    <2578, 2582, 2586>    <2587, 2595, 2588>,
    <2587, 2588, 2592>    <2587, 2592, 2589>,
    <2587, 2589, 2593>    <2587, 2593, 2590>,
    <2587, 2590, 2594>    <2587, 2594, 2591>,
    <2587, 2591, 2595>    <2596, 2604, 2597>,
    <2596, 2597, 2601>    <2596, 2601, 2598>,
    <2596, 2598, 2602>    <2596, 2602, 2599>,
    <2596, 2599, 2603>    <2596, 2603, 2600>,
    <2596, 2600, 2604>    <2605, 2613, 2606>,
    <2605, 2606, 2610>    <2605, 2610, 2607>,
    <2605, 2607, 2611>    <2605, 2611, 2608>,
    <2605, 2608, 2612>    <2605, 2612, 2609>,
    <2605, 2609, 2613>    <2614, 2622, 2615>,
    <2614, 2615, 2619>    <2614, 2619, 2616>,
    <2614, 2616, 2620>    <2614, 2620, 2617>,
    <2614, 2617, 2621>    <2614, 2621, 2618>,
    <2614, 2618, 2622>    <2623, 2631, 2624>,
    <2623, 2624, 2628>    <2623, 2628, 2625>,
    <2623, 2625, 2629>    <2623, 2629, 2626>,
    <2623, 2626, 2630>    <2623, 2630, 2627>,
    <2623, 2627, 2631>    <2632, 2640, 2633>,
    <2632, 2633, 2637>    <2632, 2637, 2634>,
    <2632, 2634, 2638>    <2632, 2638, 2635>,
    <2632, 2635, 2639>    <2632, 2639, 2636>,
    <2632, 2636, 2640>    <2641, 2649, 2642>,
    <2641, 2642, 2646>    <2641, 2646, 2643>,
    <2641, 2643, 2647>    <2641, 2647, 2644>,
    <2641, 2644, 2648>    <2641, 2648, 2645>,
    <2641, 2645, 2649>    <2650, 2658, 2651>,
    <2650, 2651, 2655>    <2650, 2655, 2652>,
    <2650, 2652, 2656>    <2650, 2656, 2653>,
    <2650, 2653, 2657>    <2650, 2657, 2654>,
    <2650, 2654, 2658>    <2659, 2667, 2660>,
    <2659, 2660, 2664>    <2659, 2664, 2661>,
    <2659, 2661, 2665>    <2659, 2665, 2662>,
    <2659, 2662, 2666>    <2659, 2666, 2663>,
    <2659, 2663, 2667>    <2668, 2676, 2669>,
    <2668, 2669, 2673>    <2668, 2673, 2670>,
    <2668, 2670, 2674>    <2668, 2674, 2671>,
    <2668, 2671, 2675>    <2668, 2675, 2672>,
    <2668, 2672, 2676>    <2677, 2685, 2678>,
    <2677, 2678, 2682>    <2677, 2682, 2679>,
    <2677, 2679, 2683>    <2677, 2683, 2680>,
    <2677, 2680, 2684>    <2677, 2684, 2681>,
    <2677, 2681, 2685>    <2686, 2694, 2687>,
    <2686, 2687, 2691>    <2686, 2691, 2688>,
    <2686, 2688, 2692>    <2686, 2692, 2689>,
    <2686, 2689, 2693>    <2686, 2693, 2690>,
    <2686, 2690, 2694>    <2695, 2703, 2696>,
    <2695, 2696, 2700>    <2695, 2700, 2697>,
    <2695, 2697, 2701>    <2695, 2701, 2698>,
    <2695, 2698, 2702>    <2695, 2702, 2699>,
    <2695, 2699, 2703>    <2704, 2712, 2705>,
    <2704, 2705, 2709>    <2704, 2709, 2706>,
    <2704, 2706, 2710>    <2704, 2710, 2707>,
    <2704, 2707, 2711>    <2704, 2711, 2708>,
    <2704, 2708, 2712>    <2713, 2721, 2714>,
    <2713, 2714, 2718>    <2713, 2718, 2715>,
    <2713, 2715, 2719>    <2713, 2719, 2716>,
    <2713, 2716, 2720>    <2713, 2720, 2717>,
    <2713, 2717, 2721>    <2722, 2730, 2723>,
    <2722, 2723, 2727>    <2722, 2727, 2724>,
    <2722, 2724, 2728>    <2722, 2728, 2725>,
    <2722, 2725, 2729>    <2722, 2729, 2726>,
    <2722, 2726, 2730>    <2731, 2739, 2732>,
    <2731, 2732, 2736>    <2731, 2736, 2733>,
    <2731, 2733, 2737>    <2731, 2737, 2734>,
    <2731, 2734, 2738>    <2731, 2738, 2735>,
    <2731, 2735, 2739>    <2740, 2748, 2741>,
    <2740, 2741, 2745>    <2740, 2745, 2742>,
    <2740, 2742, 2746>    <2740, 2746, 2743>,
    <2740, 2743, 2747>    <2740, 2747, 2744>,
    <2740, 2744, 2748>    <2749, 2757, 2750>,
    <2749, 2750, 2754>    <2749, 2754, 2751>,
    <2749, 2751, 2755>    <2749, 2755, 2752>,
    <2749, 2752, 2756>    <2749, 2756, 2753>,
    <2749, 2753, 2757>    <2758, 2766, 2759>,
    <2758, 2759, 2763>    <2758, 2763, 2760>,
    <2758, 2760, 2764>    <2758, 2764, 2761>,
    <2758, 2761, 2765>    <2758, 2765, 2762>,
    <2758, 2762, 2766>    <2767, 2775, 2768>,
    <2767, 2768, 2772>    <2767, 2772, 2769>,
    <2767, 2769, 2773>    <2767, 2773, 2770>,
    <2767, 2770, 2774>    <2767, 2774, 2771>,
    <2767, 2771, 2775>    <2776, 2784, 2777>,
    <2776, 2777, 2781>    <2776, 2781, 2778>,
    <2776, 2778, 2782>    <2776, 2782, 2779>,
    <2776, 2779, 2783>    <2776, 2783, 2780>,
    <2776, 2780, 2784>    <2785, 2793, 2786>,
    <2785, 2786, 2790>    <2785, 2790, 2787>,
    <2785, 2787, 2791>    <2785, 2791, 2788>,
    <2785, 2788, 2792>    <2785, 2792, 2789>,
    <2785, 2789, 2793>    <2794, 2802, 2795>,
    <2794, 2795, 2799>    <2794, 2799, 2796>,
    <2794, 2796, 2800>    <2794, 2800, 2797>,
    <2794, 2797, 2801>    <2794, 2801, 2798>,
    <2794, 2798, 2802>    <2803, 2811, 2804>,
    <2803, 2804, 2808>    <2803, 2808, 2805>,
    <2803, 2805, 2809>    <2803, 2809, 2806>,
    <2803, 2806, 2810>    <2803, 2810, 2807>,
    <2803, 2807, 2811>    <2812, 2820, 2813>,
    <2812, 2813, 2817>    <2812, 2817, 2814>,
    <2812, 2814, 2818>    <2812, 2818, 2815>,
    <2812, 2815, 2819>    <2812, 2819, 2816>,
    <2812, 2816, 2820>    <2821, 2829, 2822>,
    <2821, 2822, 2826>    <2821, 2826, 2823>,
    <2821, 2823, 2827>    <2821, 2827, 2824>,
    <2821, 2824, 2828>    <2821, 2828, 2825>,
    <2821, 2825, 2829>    <2830, 2838, 2831>,
    <2830, 2831, 2835>    <2830, 2835, 2832>,
    <2830, 2832, 2836>    <2830, 2836, 2833>,
    <2830, 2833, 2837>    <2830, 2837, 2834>,
    <2830, 2834, 2838>    <2839, 2847, 2840>,
    <2839, 2840, 2844>    <2839, 2844, 2841>,
    <2839, 2841, 2845>    <2839, 2845, 2842>,
    <2839, 2842, 2846>    <2839, 2846, 2843>,
    <2839, 2843, 2847>    <2848, 2856, 2849>,
    <2848, 2849, 2853>    <2848, 2853, 2850>,
    <2848, 2850, 2854>    <2848, 2854, 2851>,
    <2848, 2851, 2855>    <2848, 2855, 2852>,
    <2848, 2852, 2856>    <2857, 2865, 2858>,
    <2857, 2858, 2862>    <2857, 2862, 2859>,
    <2857, 2859, 2863>    <2857, 2863, 2860>,
    <2857, 2860, 2864>    <2857, 2864, 2861>,
    <2857, 2861, 2865>    <2866, 2874, 2867>,
    <2866, 2867, 2871>    <2866, 2871, 2868>,
    <2866, 2868, 2872>    <2866, 2872, 2869>,
    <2866, 2869, 2873>    <2866, 2873, 2870>,
    <2866, 2870, 2874>    <2875, 2883, 2876>,
    <2875, 2876, 2880>    <2875, 2880, 2877>,
    <2875, 2877, 2881>    <2875, 2881, 2878>,
    <2875, 2878, 2882>    <2875, 2882, 2879>,
    <2875, 2879, 2883>    <2884, 2892, 2885>,
    <2884, 2885, 2889>    <2884, 2889, 2886>,
    <2884, 2886, 2890>    <2884, 2890, 2887>,
    <2884, 2887, 2891>    <2884, 2891, 2888>,
    <2884, 2888, 2892>    <2893, 2901, 2894>,
    <2893, 2894, 2898>    <2893, 2898, 2895>,
    <2893, 2895, 2899>    <2893, 2899, 2896>,
    <2893, 2896, 2900>    <2893, 2900, 2897>,
    <2893, 2897, 2901>    <2902, 2910, 2903>,
    <2902, 2903, 2907>    <2902, 2907, 2904>,
    <2902, 2904, 2908>    <2902, 2908, 2905>,
    <2902, 2905, 2909>    <2902, 2909, 2906>,
    <2902, 2906, 2910>    <2911, 2919, 2912>,
    <2911, 2912, 2916>    <2911, 2916, 2913>,
    <2911, 2913, 2917>    <2911, 2917, 2914>,
    <2911, 2914, 2918>    <2911, 2918, 2915>,
    <2911, 2915, 2919>    <2920, 2928, 2921>,
    <2920, 2921, 2925>    <2920, 2925, 2922>,
    <2920, 2922, 2926>    <2920, 2926, 2923>,
    <2920, 2923, 2927>    <2920, 2927, 2924>,
    <2920, 2924, 2928>    <2929, 2937, 2930>,
    <2929, 2930, 2934>    <2929, 2934, 2931>,
    <2929, 2931, 2935>    <2929, 2935, 2932>,
    <2929, 2932, 2936>    <2929, 2936, 2933>,
    <2929, 2933, 2937>    <2938, 2946, 2939>,
    <2938, 2939, 2943>    <2938, 2943, 2940>,
    <2938, 2940, 2944>    <2938, 2944, 2941>,
    <2938, 2941, 2945>    <2938, 2945, 2942>,
    <2938, 2942, 2946>    <2947, 2955, 2948>,
    <2947, 2948, 2952>    <2947, 2952, 2949>,
    <2947, 2949, 2953>    <2947, 2953, 2950>,
    <2947, 2950, 2954>    <2947, 2954, 2951>,
    <2947, 2951, 2955>    <2956, 2964, 2957>,
    <2956, 2957, 2961>    <2956, 2961, 2958>,
    <2956, 2958, 2962>    <2956, 2962, 2959>,
    <2956, 2959, 2963>    <2956, 2963, 2960>,
    <2956, 2960, 2964>    <2965, 2973, 2966>,
    <2965, 2966, 2970>    <2965, 2970, 2967>,
    <2965, 2967, 2971>    <2965, 2971, 2968>,
    <2965, 2968, 2972>    <2965, 2972, 2969>,
    <2965, 2969, 2973>    <2974, 2982, 2975>,
    <2974, 2975, 2979>    <2974, 2979, 2976>,
    <2974, 2976, 2980>    <2974, 2980, 2977>,
    <2974, 2977, 2981>    <2974, 2981, 2978>,
    <2974, 2978, 2982>    <2983, 2991, 2984>,
    <2983, 2984, 2988>    <2983, 2988, 2985>,
    <2983, 2985, 2989>    <2983, 2989, 2986>,
    <2983, 2986, 2990>    <2983, 2990, 2987>,
    <2983, 2987, 2991>    <2992, 3000, 2993>,
    <2992, 2993, 2997>    <2992, 2997, 2994>,
    <2992, 2994, 2998>    <2992, 2998, 2995>,
    <2992, 2995, 2999>    <2992, 2999, 2996>,
    <2992, 2996, 3000>    <3001, 3009, 3002>,
    <3001, 3002, 3006>    <3001, 3006, 3003>,
    <3001, 3003, 3007>    <3001, 3007, 3004>,
    <3001, 3004, 3008>    <3001, 3008, 3005>,
    <3001, 3005, 3009>    <3010, 3018, 3011>,
    <3010, 3011, 3015>    <3010, 3015, 3012>,
    <3010, 3012, 3016>    <3010, 3016, 3013>,
    <3010, 3013, 3017>    <3010, 3017, 3014>,
    <3010, 3014, 3018>    <3019, 3027, 3020>,
    <3019, 3020, 3024>    <3019, 3024, 3021>,
    <3019, 3021, 3025>    <3019, 3025, 3022>,
    <3019, 3022, 3026>    <3019, 3026, 3023>,
    <3019, 3023, 3027>    <3028, 3036, 3029>,
    <3028, 3029, 3033>    <3028, 3033, 3030>,
    <3028, 3030, 3034>    <3028, 3034, 3031>,
    <3028, 3031, 3035>    <3028, 3035, 3032>,
    <3028, 3032, 3036>    <3037, 3045, 3038>,
    <3037, 3038, 3042>    <3037, 3042, 3039>,
    <3037, 3039, 3043>    <3037, 3043, 3040>,
    <3037, 3040, 3044>    <3037, 3044, 3041>,
    <3037, 3041, 3045>    <3046, 3054, 3047>,
    <3046, 3047, 3051>    <3046, 3051, 3048>,
    <3046, 3048, 3052>    <3046, 3052, 3049>,
    <3046, 3049, 3053>    <3046, 3053, 3050>,
    <3046, 3050, 3054>    <3055, 3063, 3056>,
    <3055, 3056, 3060>    <3055, 3060, 3057>,
    <3055, 3057, 3061>    <3055, 3061, 3058>,
    <3055, 3058, 3062>    <3055, 3062, 3059>,
    <3055, 3059, 3063>    <3064, 3072, 3065>,
    <3064, 3065, 3069>    <3064, 3069, 3066>,
    <3064, 3066, 3070>    <3064, 3070, 3067>,
    <3064, 3067, 3071>    <3064, 3071, 3068>,
    <3064, 3068, 3072>    <3073, 3081, 3074>,
    <3073, 3074, 3078>    <3073, 3078, 3075>,
    <3073, 3075, 3079>    <3073, 3079, 3076>,
    <3073, 3076, 3080>    <3073, 3080, 3077>,
    <3073, 3077, 3081>    <3082, 3090, 3083>,
    <3082, 3083, 3087>    <3082, 3087, 3084>,
    <3082, 3084, 3088>    <3082, 3088, 3085>,
    <3082, 3085, 3089>    <3082, 3089, 3086>,
    <3082, 3086, 3090>    <3091, 3099, 3092>,
    <3091, 3092, 3096>    <3091, 3096, 3093>,
    <3091, 3093, 3097>    <3091, 3097, 3094>,
    <3091, 3094, 3098>    <3091, 3098, 3095>,
    <3091, 3095, 3099>    <3100, 3108, 3101>,
    <3100, 3101, 3105>    <3100, 3105, 3102>,
    <3100, 3102, 3106>    <3100, 3106, 3103>,
    <3100, 3103, 3107>    <3100, 3107, 3104>,
    <3100, 3104, 3108>    <3109, 3117, 3110>,
    <3109, 3110, 3114>    <3109, 3114, 3111>,
    <3109, 3111, 3115>    <3109, 3115, 3112>,
    <3109, 3112, 3116>    <3109, 3116, 3113>,
    <3109, 3113, 3117>    <3118, 3126, 3119>,
    <3118, 3119, 3123>    <3118, 3123, 3120>,
    <3118, 3120, 3124>    <3118, 3124, 3121>,
    <3118, 3121, 3125>    <3118, 3125, 3122>,
    <3118, 3122, 3126>    <3127, 3135, 3128>,
    <3127, 3128, 3132>    <3127, 3132, 3129>,
    <3127, 3129, 3133>    <3127, 3133, 3130>,
    <3127, 3130, 3134>    <3127, 3134, 3131>,
    <3127, 3131, 3135>    <3136, 3144, 3137>,
    <3136, 3137, 3141>    <3136, 3141, 3138>,
    <3136, 3138, 3142>    <3136, 3142, 3139>,
    <3136, 3139, 3143>    <3136, 3143, 3140>,
    <3136, 3140, 3144>    <3145, 3153, 3146>,
    <3145, 3146, 3150>    <3145, 3150, 3147>,
    <3145, 3147, 3151>    <3145, 3151, 3148>,
    <3145, 3148, 3152>    <3145, 3152, 3149>,
    <3145, 3149, 3153>    <3154, 3162, 3155>,
    <3154, 3155, 3159>    <3154, 3159, 3156>,
    <3154, 3156, 3160>    <3154, 3160, 3157>,
    <3154, 3157, 3161>    <3154, 3161, 3158>,
    <3154, 3158, 3162>    <3163, 3171, 3164>,
    <3163, 3164, 3168>    <3163, 3168, 3165>,
    <3163, 3165, 3169>    <3163, 3169, 3166>,
    <3163, 3166, 3170>    <3163, 3170, 3167>,
    <3163, 3167, 3171>    <3172, 3180, 3173>,
    <3172, 3173, 3177>    <3172, 3177, 3174>,
    <3172, 3174, 3178>    <3172, 3178, 3175>,
    <3172, 3175, 3179>    <3172, 3179, 3176>,
    <3172, 3176, 3180>    <3181, 3189, 3182>,
    <3181, 3182, 3186>    <3181, 3186, 3183>,
    <3181, 3183, 3187>    <3181, 3187, 3184>,
    <3181, 3184, 3188>    <3181, 3188, 3185>,
    <3181, 3185, 3189>    <3190, 3198, 3191>,
    <3190, 3191, 3195>    <3190, 3195, 3192>,
    <3190, 3192, 3196>    <3190, 3196, 3193>,
    <3190, 3193, 3197>    <3190, 3197, 3194>,
    <3190, 3194, 3198>    <3199, 3207, 3200>,
    <3199, 3200, 3204>    <3199, 3204, 3201>,
    <3199, 3201, 3205>    <3199, 3205, 3202>,
    <3199, 3202, 3206>    <3199, 3206, 3203>,
    <3199, 3203, 3207>    <3208, 3216, 3209>,
    <3208, 3209, 3213>    <3208, 3213, 3210>,
    <3208, 3210, 3214>    <3208, 3214, 3211>,
    <3208, 3211, 3215>    <3208, 3215, 3212>,
    <3208, 3212, 3216>    <3217, 3225, 3218>,
    <3217, 3218, 3222>    <3217, 3222, 3219>,
    <3217, 3219, 3223>    <3217, 3223, 3220>,
    <3217, 3220, 3224>    <3217, 3224, 3221>,
    <3217, 3221, 3225>    <3226, 3234, 3227>,
    <3226, 3227, 3231>    <3226, 3231, 3228>,
    <3226, 3228, 3232>    <3226, 3232, 3229>,
    <3226, 3229, 3233>    <3226, 3233, 3230>,
    <3226, 3230, 3234>    <3235, 3243, 3236>,
    <3235, 3236, 3240>    <3235, 3240, 3237>,
    <3235, 3237, 3241>    <3235, 3241, 3238>,
    <3235, 3238, 3242>    <3235, 3242, 3239>,
    <3235, 3239, 3243>    <3244, 3252, 3245>,
    <3244, 3245, 3249>    <3244, 3249, 3246>,
    <3244, 3246, 3250>    <3244, 3250, 3247>,
    <3244, 3247, 3251>    <3244, 3251, 3248>,
    <3244, 3248, 3252>    <3253, 3261, 3254>,
    <3253, 3254, 3258>    <3253, 3258, 3255>,
    <3253, 3255, 3259>    <3253, 3259, 3256>,
    <3253, 3256, 3260>    <3253, 3260, 3257>,
    <3253, 3257, 3261>    <3262, 3270, 3263>,
    <3262, 3263, 3267>    <3262, 3267, 3264>,
    <3262, 3264, 3268>    <3262, 3268, 3265>,
    <3262, 3265, 3269>    <3262, 3269, 3266>,
    <3262, 3266, 3270>    <3271, 3279, 3272>,
    <3271, 3272, 3276>    <3271, 3276, 3273>,
    <3271, 3273, 3277>    <3271, 3277, 3274>,
    <3271, 3274, 3278>    <3271, 3278, 3275>,
    <3271, 3275, 3279>    <3280, 3288, 3281>,
    <3280, 3281, 3285>    <3280, 3285, 3282>,
    <3280, 3282, 3286>    <3280, 3286, 3283>,
    <3280, 3283, 3287>    <3280, 3287, 3284>,
    <3280, 3284, 3288>    <3289, 3297, 3290>,
    <3289, 3290, 3294>    <3289, 3294, 3291>,
    <3289, 3291, 3295>    <3289, 3295, 3292>,
    <3289, 3292, 3296>    <3289, 3296, 3293>,
    <3289, 3293, 3297>    <3298, 3306, 3299>,
    <3298, 3299, 3303>    <3298, 3303, 3300>,
    <3298, 3300, 3304>    <3298, 3304, 3301>,
    <3298, 3301, 3305>    <3298, 3305, 3302>,
    <3298, 3302, 3306>    <3307, 3315, 3308>,
    <3307, 3308, 3312>    <3307, 3312, 3309>,
    <3307, 3309, 3313>    <3307, 3313, 3310>,
    <3307, 3310, 3314>    <3307, 3314, 3311>,
    <3307, 3311, 3315>    <3316, 3324, 3317>,
    <3316, 3317, 3321>    <3316, 3321, 3318>,
    <3316, 3318, 3322>    <3316, 3322, 3319>,
    <3316, 3319, 3323>    <3316, 3323, 3320>,
    <3316, 3320, 3324>    <3325, 3333, 3326>,
    <3325, 3326, 3330>    <3325, 3330, 3327>,
    <3325, 3327, 3331>    <3325, 3331, 3328>,
    <3325, 3328, 3332>    <3325, 3332, 3329>,
    <3325, 3329, 3333>    <3334, 3342, 3335>,
    <3334, 3335, 3339>    <3334, 3339, 3336>,
    <3334, 3336, 3340>    <3334, 3340, 3337>,
    <3334, 3337, 3341>    <3334, 3341, 3338>,
    <3334, 3338, 3342>    <3343, 3351, 3344>,
    <3343, 3344, 3348>    <3343, 3348, 3345>,
    <3343, 3345, 3349>    <3343, 3349, 3346>,
    <3343, 3346, 3350>    <3343, 3350, 3347>,
    <3343, 3347, 3351>    <3352, 3360, 3353>,
    <3352, 3353, 3357>    <3352, 3357, 3354>,
    <3352, 3354, 3358>    <3352, 3358, 3355>,
    <3352, 3355, 3359>    <3352, 3359, 3356>,
    <3352, 3356, 3360>    <3361, 3369, 3362>,
    <3361, 3362, 3366>    <3361, 3366, 3363>,
    <3361, 3363, 3367>    <3361, 3367, 3364>,
    <3361, 3364, 3368>    <3361, 3368, 3365>,
    <3361, 3365, 3369>    <3370, 3378, 3371>,
    <3370, 3371, 3375>    <3370, 3375, 3372>,
    <3370, 3372, 3376>    <3370, 3376, 3373>,
    <3370, 3373, 3377>    <3370, 3377, 3374>,
    <3370, 3374, 3378>    <3379, 3387, 3380>,
    <3379, 3380, 3384>    <3379, 3384, 3381>,
    <3379, 3381, 3385>    <3379, 3385, 3382>,
    <3379, 3382, 3386>    <3379, 3386, 3383>,
    <3379, 3383, 3387>    <3388, 3396, 3389>,
    <3388, 3389, 3393>    <3388, 3393, 3390>,
    <3388, 3390, 3394>    <3388, 3394, 3391>,
    <3388, 3391, 3395>    <3388, 3395, 3392>,
    <3388, 3392, 3396>    <3397, 3405, 3398>,
    <3397, 3398, 3402>    <3397, 3402, 3399>,
    <3397, 3399, 3403>    <3397, 3403, 3400>,
    <3397, 3400, 3404>    <3397, 3404, 3401>,
    <3397, 3401, 3405>    <3406, 3414, 3407>,
    <3406, 3407, 3411>    <3406, 3411, 3408>,
    <3406, 3408, 3412>    <3406, 3412, 3409>,
    <3406, 3409, 3413>    <3406, 3413, 3410>,
    <3406, 3410, 3414>    <3415, 3423, 3416>,
    <3415, 3416, 3420>    <3415, 3420, 3417>,
    <3415, 3417, 3421>    <3415, 3421, 3418>,
    <3415, 3418, 3422>    <3415, 3422, 3419>,
    <3415, 3419, 3423>    <3424, 3432, 3425>,
    <3424, 3425, 3429>    <3424, 3429, 3426>,
    <3424, 3426, 3430>    <3424, 3430, 3427>,
    <3424, 3427, 3431>    <3424, 3431, 3428>,
    <3424, 3428, 3432>    <3433, 3441, 3434>,
    <3433, 3434, 3438>    <3433, 3438, 3435>,
    <3433, 3435, 3439>    <3433, 3439, 3436>,
    <3433, 3436, 3440>    <3433, 3440, 3437>,
    <3433, 3437, 3441>    <3442, 3450, 3443>,
    <3442, 3443, 3447>    <3442, 3447, 3444>,
    <3442, 3444, 3448>    <3442, 3448, 3445>,
    <3442, 3445, 3449>    <3442, 3449, 3446>,
    <3442, 3446, 3450>    <3451, 3459, 3452>,
    <3451, 3452, 3456>    <3451, 3456, 3453>,
    <3451, 3453, 3457>    <3451, 3457, 3454>,
    <3451, 3454, 3458>    <3451, 3458, 3455>,
    <3451, 3455, 3459>    <3460, 3468, 3461>,
    <3460, 3461, 3465>    <3460, 3465, 3462>,
    <3460, 3462, 3466>    <3460, 3466, 3463>,
    <3460, 3463, 3467>    <3460, 3467, 3464>,
    <3460, 3464, 3468>    <3469, 3477, 3470>,
    <3469, 3470, 3474>    <3469, 3474, 3471>,
    <3469, 3471, 3475>    <3469, 3475, 3472>,
    <3469, 3472, 3476>    <3469, 3476, 3473>,
    <3469, 3473, 3477>    <3478, 3486, 3479>,
    <3478, 3479, 3483>    <3478, 3483, 3480>,
    <3478, 3480, 3484>    <3478, 3484, 3481>,
    <3478, 3481, 3485>    <3478, 3485, 3482>,
    <3478, 3482, 3486>    <3487, 3495, 3488>,
    <3487, 3488, 3492>    <3487, 3492, 3489>,
    <3487, 3489, 3493>    <3487, 3493, 3490>,
    <3487, 3490, 3494>    <3487, 3494, 3491>,
    <3487, 3491, 3495>    <3496, 3504, 3497>,
    <3496, 3497, 3501>    <3496, 3501, 3498>,
    <3496, 3498, 3502>    <3496, 3502, 3499>,
    <3496, 3499, 3503>    <3496, 3503, 3500>,
    <3496, 3500, 3504>    <3505, 3513, 3506>,
    <3505, 3506, 3510>    <3505, 3510, 3507>,
    <3505, 3507, 3511>    <3505, 3511, 3508>,
    <3505, 3508, 3512>    <3505, 3512, 3509>,
    <3505, 3509, 3513>    <3514, 3522, 3515>,
    <3514, 3515, 3519>    <3514, 3519, 3516>,
    <3514, 3516, 3520>    <3514, 3520, 3517>,
    <3514, 3517, 3521>    <3514, 3521, 3518>,
    <3514, 3518, 3522>    <3523, 3531, 3524>,
    <3523, 3524, 3528>    <3523, 3528, 3525>,
    <3523, 3525, 3529>    <3523, 3529, 3526>,
    <3523, 3526, 3530>    <3523, 3530, 3527>,
    <3523, 3527, 3531>    <3532, 3540, 3533>,
    <3532, 3533, 3537>    <3532, 3537, 3534>,
    <3532, 3534, 3538>    <3532, 3538, 3535>,
    <3532, 3535, 3539>    <3532, 3539, 3536>,
    <3532, 3536, 3540>    <3541, 3549, 3542>,
    <3541, 3542, 3546>    <3541, 3546, 3543>,
    <3541, 3543, 3547>    <3541, 3547, 3544>,
    <3541, 3544, 3548>    <3541, 3548, 3545>,
    <3541, 3545, 3549>    <3550, 3558, 3551>,
    <3550, 3551, 3555>    <3550, 3555, 3552>,
    <3550, 3552, 3556>    <3550, 3556, 3553>,
    <3550, 3553, 3557>    <3550, 3557, 3554>,
    <3550, 3554, 3558>    <3559, 3567, 3560>,
    <3559, 3560, 3564>    <3559, 3564, 3561>,
    <3559, 3561, 3565>    <3559, 3565, 3562>,
    <3559, 3562, 3566>    <3559, 3566, 3563>,
    <3559, 3563, 3567>    <3568, 3576, 3569>,
    <3568, 3569, 3573>    <3568, 3573, 3570>,
    <3568, 3570, 3574>    <3568, 3574, 3571>,
    <3568, 3571, 3575>    <3568, 3575, 3572>,
    <3568, 3572, 3576>    <3577, 3585, 3578>,
    <3577, 3578, 3582>    <3577, 3582, 3579>,
    <3577, 3579, 3583>    <3577, 3583, 3580>,
    <3577, 3580, 3584>    <3577, 3584, 3581>,
    <3577, 3581, 3585>    <3586, 3594, 3587>,
    <3586, 3587, 3591>    <3586, 3591, 3588>,
    <3586, 3588, 3592>    <3586, 3592, 3589>,
    <3586, 3589, 3593>    <3586, 3593, 3590>,
    <3586, 3590, 3594>    <3595, 3603, 3596>,
    <3595, 3596, 3600>    <3595, 3600, 3597>,
    <3595, 3597, 3601>    <3595, 3601, 3598>,
    <3595, 3598, 3602>    <3595, 3602, 3599>,
    <3595, 3599, 3603>    <3604, 3612, 3605>,
    <3604, 3605, 3609>    <3604, 3609, 3606>,
    <3604, 3606, 3610>    <3604, 3610, 3607>,
    <3604, 3607, 3611>    <3604, 3611, 3608>,
    <3604, 3608, 3612>    <3613, 3621, 3614>,
    <3613, 3614, 3618>    <3613, 3618, 3615>,
    <3613, 3615, 3619>    <3613, 3619, 3616>,
    <3613, 3616, 3620>    <3613, 3620, 3617>,
    <3613, 3617, 3621>    <3622, 3630, 3623>,
    <3622, 3623, 3627>    <3622, 3627, 3624>,
    <3622, 3624, 3628>    <3622, 3628, 3625>,
    <3622, 3625, 3629>    <3622, 3629, 3626>,
    <3622, 3626, 3630>    <3631, 3639, 3632>,
    <3631, 3632, 3636>    <3631, 3636, 3633>,
    <3631, 3633, 3637>    <3631, 3637, 3634>,
    <3631, 3634, 3638>    <3631, 3638, 3635>,
    <3631, 3635, 3639>    <3640, 3648, 3641>,
    <3640, 3641, 3645>    <3640, 3645, 3642>,
    <3640, 3642, 3646>    <3640, 3646, 3643>,
    <3640, 3643, 3647>    <3640, 3647, 3644>,
    <3640, 3644, 3648>    <3649, 3657, 3650>,
    <3649, 3650, 3654>    <3649, 3654, 3651>,
    <3649, 3651, 3655>    <3649, 3655, 3652>,
    <3649, 3652, 3656>    <3649, 3656, 3653>,
    <3649, 3653, 3657>    <3658, 3666, 3659>,
    <3658, 3659, 3663>    <3658, 3663, 3660>,
    <3658, 3660, 3664>    <3658, 3664, 3661>,
    <3658, 3661, 3665>    <3658, 3665, 3662>,
    <3658, 3662, 3666>    <3667, 3675, 3668>,
    <3667, 3668, 3672>    <3667, 3672, 3669>,
    <3667, 3669, 3673>    <3667, 3673, 3670>,
    <3667, 3670, 3674>    <3667, 3674, 3671>,
    <3667, 3671, 3675>    <3676, 3684, 3677>,
    <3676, 3677, 3681>    <3676, 3681, 3678>,
    <3676, 3678, 3682>    <3676, 3682, 3679>,
    <3676, 3679, 3683>    <3676, 3683, 3680>,
    <3676, 3680, 3684>    <3685, 3693, 3686>,
    <3685, 3686, 3690>    <3685, 3690, 3687>,
    <3685, 3687, 3691>    <3685, 3691, 3688>,
    <3685, 3688, 3692>    <3685, 3692, 3689>,
    <3685, 3689, 3693>    <3694, 3702, 3695>,
    <3694, 3695, 3699>    <3694, 3699, 3696>,
    <3694, 3696, 3700>    <3694, 3700, 3697>,
    <3694, 3697, 3701>    <3694, 3701, 3698>,
    <3694, 3698, 3702>    <3703, 3711, 3704>,
    <3703, 3704, 3708>    <3703, 3708, 3705>,
    <3703, 3705, 3709>    <3703, 3709, 3706>,
    <3703, 3706, 3710>    <3703, 3710, 3707>,
    <3703, 3707, 3711>    <3712, 3720, 3713>,
    <3712, 3713, 3717>    <3712, 3717, 3714>,
    <3712, 3714, 3718>    <3712, 3718, 3715>,
    <3712, 3715, 3719>    <3712, 3719, 3716>,
    <3712, 3716, 3720>    <3721, 3729, 3722>,
    <3721, 3722, 3726>    <3721, 3726, 3723>,
    <3721, 3723, 3727>    <3721, 3727, 3724>,
    <3721, 3724, 3728>    <3721, 3728, 3725>,
    <3721, 3725, 3729>    <3730, 3738, 3731>,
    <3730, 3731, 3735>    <3730, 3735, 3732>,
    <3730, 3732, 3736>    <3730, 3736, 3733>,
    <3730, 3733, 3737>    <3730, 3737, 3734>,
    <3730, 3734, 3738>    <3739, 3747, 3740>,
    <3739, 3740, 3744>    <3739, 3744, 3741>,
    <3739, 3741, 3745>    <3739, 3745, 3742>,
    <3739, 3742, 3746>    <3739, 3746, 3743>,
    <3739, 3743, 3747>    <3748, 3756, 3749>,
    <3748, 3749, 3753>    <3748, 3753, 3750>,
    <3748, 3750, 3754>    <3748, 3754, 3751>,
    <3748, 3751, 3755>    <3748, 3755, 3752>,
    <3748, 3752, 3756>    <3757, 3765, 3758>,
    <3757, 3758, 3762>    <3757, 3762, 3759>,
    <3757, 3759, 3763>    <3757, 3763, 3760>,
    <3757, 3760, 3764>    <3757, 3764, 3761>,
    <3757, 3761, 3765>    <3766, 3774, 3767>,
    <3766, 3767, 3771>    <3766, 3771, 3768>,
    <3766, 3768, 3772>    <3766, 3772, 3769>,
    <3766, 3769, 3773>    <3766, 3773, 3770>,
    <3766, 3770, 3774>    <3775, 3783, 3776>,
    <3775, 3776, 3780>    <3775, 3780, 3777>,
    <3775, 3777, 3781>    <3775, 3781, 3778>,
    <3775, 3778, 3782>    <3775, 3782, 3779>,
    <3775, 3779, 3783>    <3784, 3792, 3785>,
    <3784, 3785, 3789>    <3784, 3789, 3786>,
    <3784, 3786, 3790>    <3784, 3790, 3787>,
    <3784, 3787, 3791>    <3784, 3791, 3788>,
    <3784, 3788, 3792>    <3793, 3801, 3794>,
    <3793, 3794, 3798>    <3793, 3798, 3795>,
    <3793, 3795, 3799>    <3793, 3799, 3796>,
    <3793, 3796, 3800>    <3793, 3800, 3797>,
    <3793, 3797, 3801>    <3802, 3810, 3803>,
    <3802, 3803, 3807>    <3802, 3807, 3804>,
    <3802, 3804, 3808>    <3802, 3808, 3805>,
    <3802, 3805, 3809>    <3802, 3809, 3806>,
    <3802, 3806, 3810>    <3811, 3819, 3812>,
    <3811, 3812, 3816>    <3811, 3816, 3813>,
    <3811, 3813, 3817>    <3811, 3817, 3814>,
    <3811, 3814, 3818>    <3811, 3818, 3815>,
    <3811, 3815, 3819>    <3820, 3828, 3821>,
    <3820, 3821, 3825>    <3820, 3825, 3822>,
    <3820, 3822, 3826>    <3820, 3826, 3823>,
    <3820, 3823, 3827>    <3820, 3827, 3824>,
    <3820, 3824, 3828>    <3829, 3837, 3830>,
    <3829, 3830, 3834>    <3829, 3834, 3831>,
    <3829, 3831, 3835>    <3829, 3835, 3832>,
    <3829, 3832, 3836>    <3829, 3836, 3833>,
    <3829, 3833, 3837>    <3838, 3846, 3839>,
    <3838, 3839, 3843>    <3838, 3843, 3840>,
    <3838, 3840, 3844>    <3838, 3844, 3841>,
    <3838, 3841, 3845>    <3838, 3845, 3842>,
    <3838, 3842, 3846>    <3847, 3855, 3848>,
    <3847, 3848, 3852>    <3847, 3852, 3849>,
    <3847, 3849, 3853>    <3847, 3853, 3850>,
    <3847, 3850, 3854>    <3847, 3854, 3851>,
    <3847, 3851, 3855>    <3856, 3864, 3857>,
    <3856, 3857, 3861>    <3856, 3861, 3858>,
    <3856, 3858, 3862>    <3856, 3862, 3859>,
    <3856, 3859, 3863>    <3856, 3863, 3860>,
    <3856, 3860, 3864>    <3865, 3873, 3866>,
    <3865, 3866, 3870>    <3865, 3870, 3867>,
    <3865, 3867, 3871>    <3865, 3871, 3868>,
    <3865, 3868, 3872>    <3865, 3872, 3869>,
    <3865, 3869, 3873>    <3874, 3882, 3875>,
    <3874, 3875, 3879>    <3874, 3879, 3876>,
    <3874, 3876, 3880>    <3874, 3880, 3877>,
    <3874, 3877, 3881>    <3874, 3881, 3878>,
    <3874, 3878, 3882>    <3883, 3891, 3884>,
    <3883, 3884, 3888>    <3883, 3888, 3885>,
    <3883, 3885, 3889>    <3883, 3889, 3886>,
    <3883, 3886, 3890>    <3883, 3890, 3887>,
    <3883, 3887, 3891>    <3892, 3900, 3893>,
    <3892, 3893, 3897>    <3892, 3897, 3894>,
    <3892, 3894, 3898>    <3892, 3898, 3895>,
    <3892, 3895, 3899>    <3892, 3899, 3896>,
    <3892, 3896, 3900>    <3901, 3909, 3902>,
    <3901, 3902, 3906>    <3901, 3906, 3903>,
    <3901, 3903, 3907>    <3901, 3907, 3904>,
    <3901, 3904, 3908>    <3901, 3908, 3905>,
    <3901, 3905, 3909>
  }
  photons {
    collect off
  }
  scale <1.0, 1.192135, 1.0>
}

#declare Corps = mesh2 {
  vertex_vectors {
    1528,
    <-0.3046617, 7.3865883, -0.6163216>,
    <-0.5738331, 7.0975547, -0.5915940>,
    <-0.5907857, 7.0975547, -0.4097140>,
    <-0.4799848, 7.2298823, -0.6082298>,
    <-0.5847389, 7.1023033, -0.5035710>,
    <-0.4932803, 7.2298823, -0.4927931>,
    <-0.5046936, 7.2172192, -0.5481085>,
    <-0.4866937, 7.0975547, -0.7260122>,
    <-0.4267258, 7.2298823, -0.6956818>,
    <-0.5360492, 7.1023033, -0.6632987>,
    <-0.4711183, 7.2172192, -0.6600471>,
    <-0.3582349, 7.0975547, -0.8063134>,
    <-0.3450011, 7.2298823, -0.7481530>,
    <-0.4264034, 7.1023033, -0.7697839>,
    <-0.3944446, 7.2172192, -0.7346728>,
    <-0.2110323, 7.0975547, -0.8324974>,
    <-0.2509727, 7.2298823, -0.7656434>,
    <-0.2886420, 7.1023033, -0.8230265>,
    <-0.2980848, 7.2172192, -0.7719857>,
    <-0.0641373, 7.0975547, -0.8045643>,
    <-0.1569443, 7.2298823, -0.7481530>,
    <-0.1415087, 7.1023033, -0.8230265>,
    <-0.1951629, 7.2172192, -0.7719857>,
    <0.0633987, 7.0975547, -0.7225142>,
    <-0.0752196, 7.2298823, -0.6956818>,
    <-0.0037472, 7.1023033, -0.7697839>,
    <-0.0988031, 7.2172192, -0.7346728>,
    <0.1507342, 7.0975547, -0.5863469>,
    <-0.0196190, 7.2298823, -0.6082298>,
    <0.1058985, 7.1023033, -0.6632987>,
    <-0.0221294, 7.2172192, -0.6600471>,
    <0.1754423, 7.0975547, -0.4035924>,
    <-0.0016402, 7.2298823, -0.4927931>,
    <0.1622828, 7.1023033, -0.5035710>,
    <0.0176902, 7.2172192, -0.5481085>,
    <-0.7313106, 6.6917661, -0.5265790>,
    <-0.7624424, 6.6917661, -0.2293011>,
    <-0.6631941, 6.9095129, -0.5594720>,
    <-0.7574236, 6.6917661, -0.3834452>,
    <-0.6867442, 6.9095129, -0.3129381>,
    <-0.6835088, 6.9095129, -0.4407705>,
    <-0.5881082, 6.6917661, -0.7467849>,
    <-0.5455691, 6.9095129, -0.7420897>,
    <-0.6719187, 6.6917661, -0.6476923>,
    <-0.6146572, 6.9095129, -0.6599117>,
    <-0.3777016, 6.6917661, -0.8789084>,
    <-0.3719726, 6.9095129, -0.8516603>,
    <-0.4887393, 6.6917661, -0.8238570>,
    <-0.4636009, 6.9095129, -0.8060059>,
    <-0.1361784, 6.6917661, -0.9229496>,
    <-0.1726161, 6.9095129, -0.8881838>,
    <-0.2588848, 6.6917661, -0.9119393>,
    <-0.2739044, 6.9095129, -0.8790529>,
    <0.1053449, 6.6917661, -0.8789084>,
    <0.0267404, 6.9095129, -0.8516603>,
    <-0.0134719, 6.6917661, -0.9119393>,
    <-0.0713278, 6.9095129, -0.8790529>,
    <0.3157515, 6.6917661, -0.7467849>,
    <0.2003368, 6.9095129, -0.7420897>,
    <0.2163826, 6.6917661, -0.8238570>,
    <0.1183687, 6.9095129, -0.8060059>,
    <0.4603289, 6.6917661, -0.5265790>,
    <0.3198025, 6.9095129, -0.5594720>,
    <0.3995620, 6.6917661, -0.6476923>,
    <0.2694250, 6.9095129, -0.6599117>,
    <0.4983357, 6.6917661, -0.2293011>,
    <0.3525553, 6.9095129, -0.3129381>,
    <0.4905669, 6.6917661, -0.3834452>,
    <0.3456388, 6.9095129, -0.4407705>,
    <-0.8112555, 6.1904657, -0.4589531>,
    <-0.8540254, 6.1904657, -0.0992385>,
    <-0.7792650, 6.4513285, -0.4926574>,
    <-0.8457756, 6.1904657, -0.2857572>,
    <-0.8166837, 6.4513285, -0.1584223>,
    <-0.8100255, 6.4513285, -0.3317294>,
    <-0.6339918, 6.1904657, -0.7254084>,
    <-0.6165693, 6.4513285, -0.7402390>,
    <-0.7372209, 6.1904657, -0.6055035>,
    <-0.7115385, 6.4513285, -0.6288273>,
    <-0.3756280, 6.1904657, -0.8852816>,
    <-0.3784532, 6.4513285, -0.8887879>,
    <-0.5118879, 6.1904657, -0.8186678>,
    <-0.5040809, 6.4513285, -0.8268925>,
    <-0.0795146, 6.1904657, -0.9385727>,
    <-0.1052989, 6.4513285, -0.9383042>,
    <-0.2299306, 6.1904657, -0.9252499>,
    <-0.2440660, 6.4513285, -0.9259251>,
    <0.2165988, 6.1904657, -0.8852816>,
    <0.1678554, 6.4513285, -0.8887879>,
    <0.0709015, 6.1904657, -0.9252499>,
    <0.0334681, 6.4513285, -0.9259251>,
    <0.4749627, 6.1904657, -0.7254084>,
    <0.4059714, 6.4513285, -0.7402390>,
    <0.3528588, 6.1904657, -0.8186678>,
    <0.2934831, 6.4513285, -0.8268925>,
    <0.6528774, 6.1904657, -0.4589531>,
    <0.5696477, 6.4513285, -0.4926574>,
    <0.5781918, 6.1904657, -0.6055035>,
    <0.5009406, 6.4513285, -0.6288273>,
    <0.6989026, 6.1904657, -0.0992385>,
    <0.6119688, 6.4513285, -0.1584223>,
    <0.6893507, 6.1904657, -0.2857572>,
    <0.6033496, 6.4513285, -0.3317294>,
    <-0.8506778, 5.6165272, -0.4002256>,
    <-0.9032562, 5.6165272, -0.0117031>,
    <-0.8314800, 5.9114434, -0.4267122>,
    <-0.8914597, 5.6165272, -0.2131592>,
    <-0.8790246, 5.9114434, -0.0506865>,
    <-0.8691349, 5.9114434, -0.2456628>,
    <-0.6528014, 5.6165272, -0.6880201>,
    <-0.6434155, 5.9114434, -0.7052499>,
    <-0.7674466, 5.6165272, -0.5585126>,
    <-0.7526708, 5.9114434, -0.5799079>,
    <-0.3674686, 5.6165272, -0.8606967>,
    <-0.3706264, 5.9114434, -0.8723724>,
    <-0.5177771, 5.6165272, -0.7887481>,
    <-0.5144226, 5.9114434, -0.8027380>,
    <-0.0413779, 5.6165272, -0.9182556>,
    <-0.0583622, 5.9114434, -0.9280800>,
    <-0.2069706, 5.6165272, -0.9038659>,
    <-0.2169615, 5.9114434, -0.9141531>,
    <0.2847129, 5.6165272, -0.8606967>,
    <0.2539021, 5.9114434, -0.8723724>,
    <0.1242149, 5.6165272, -0.9038659>,
    <0.1002372, 5.9114434, -0.9141531>,
    <0.5700456, 5.6165272, -0.6880201>,
    <0.5266912, 5.9114434, -0.7052499>,
    <0.4350214, 5.6165272, -0.7887481>,
    <0.3976983, 5.9114434, -0.8027380>,
    <0.7680847, 5.6165272, -0.4002256>,
    <0.7151365, 5.9114434, -0.4267122>,
    <0.6846909, 5.6165272, -0.5585126>,
    <0.6359465, 5.9114434, -0.5799079>,
    <0.8214763, 5.6165272, -0.0117031>,
    <0.7645851, 5.9114434, -0.0506865>,
    <0.8093545, 5.6165272, -0.2131592>,
    <0.7539338, 5.9114434, -0.2456628>,
    <-0.9196461, 5.0077259, -0.3770981>,
    <-0.9859139, 5.0077259, 0.0417369>,
    <-0.8795877, 5.3079827, -0.3837840>,
    <-0.9687055, 5.0077259, -0.1754368>,
    <-0.9382953, 5.3079827, 0.0187748>,
    <-0.9241062, 5.3079827, -0.1899594>,
    <-0.6962396, 5.0077259, -0.6873462>,
    <-0.6701107, 5.3079827, -0.6819757>,
    <-0.8248384, 5.0077259, -0.5477346>,
    <-0.7911072, 5.3079827, -0.5477894>,
    <-0.3789987, 5.0077259, -0.8734951>,
    <-0.3701745, 5.3079827, -0.8608907>,
    <-0.5458068, 5.0077259, -0.7959331>,
    <-0.5280439, 5.3079827, -0.7863428>,
    <-0.0180899, 5.0077259, -0.9355447>,
    <-0.0280979, 5.3079827, -0.9205290>,
    <-0.2012735, 5.0077259, -0.9200323>,
    <-0.2017700, 5.3079827, -0.9056195>,
    <0.3428188, 5.0077259, -0.8734951>,
    <0.3139786, 5.3079827, -0.8608907>,
    <0.1650937, 5.0077259, -0.9200323>,
    <0.1455741, 5.3079827, -0.9056195>,
    <0.6600597, 5.0077259, -0.6873462>,
    <0.6139148, 5.3079827, -0.6819757>,
    <0.5096270, 5.0077259, -0.7959331>,
    <0.4718480, 5.3079827, -0.7863428>,
    <0.8833194, 5.0077259, -0.3770981>,
    <0.8233813, 5.3079827, -0.3837840>,
    <0.7886585, 5.0077259, -0.5477346>,
    <0.7349114, 5.3079827, -0.5477894>,
    <0.9488531, 5.0077259, 0.0417369>,
    <0.8820362, 5.3079827, 0.0187748>,
    <0.9319384, 5.0077259, -0.1754368>,
    <0.8678681, 5.3079827, -0.1899594>,
    <-1.0381736, 4.4643781, -0.3914643>,
    <-1.1250426, 4.4643781, 0.0693907>,
    <-0.9722893, 4.7376724, -0.3798786>,
    <-1.0994219, 4.4643781, -0.1695712>,
    <-1.0478837, 4.7376724, 0.0581727>,
    <-1.0268889, 4.7376724, -0.1689650>,
    <-0.7779612, 4.4643781, -0.7328385>,
    <-0.7320843, 4.7376724, -0.7043611>,
    <-0.9265721, 4.4643781, -0.5792201>,
    <-0.8698259, 4.7376724, -0.5583440>,
    <-0.4156583, 4.4643781, -0.9376630>,
    <-0.3941957, 4.7376724, -0.8990506>,
    <-0.6056844, 4.4643781, -0.8523194>,
    <-0.5716498, 4.7376724, -0.8179300>,
    <-0.0060238, 4.4643781, -1.0059378>,
    <-0.0109214, 4.7376724, -0.9639471>,
    <-0.2137992, 4.4643781, -0.9888691>,
    <-0.2053951, 4.7376724, -0.9477230>,
    <0.4036107, 4.4643781, -0.9376630>,
    <0.3723529, 4.7376724, -0.8990506>,
    <0.2017517, 4.4643781, -0.9888691>,
    <0.1835523, 4.7376724, -0.9477230>,
    <0.7659136, 4.4643781, -0.7328385>,
    <0.7102415, 4.7376724, -0.7043611>,
    <0.5936368, 4.4643781, -0.8523194>,
    <0.5498070, 4.7376724, -0.8179300>,
    <1.0257909, 4.4643781, -0.3914643>,
    <0.9501922, 4.7376724, -0.3798786>,
    <0.9145246, 4.4643781, -0.5792201>,
    <0.8479831, 4.7376724, -0.5583440>,
    <1.1109839, 4.4643781, 0.0693907>,
    <1.0245153, 4.7376724, 0.0581727>,
    <1.0860335, 4.4643781, -0.1695712>,
    <1.0040290, 4.7376724, -0.1689650>,
    <-1.2029088, 3.8008799, -0.4353003>,
    <-1.3176425, 3.8008799, 0.0809225>,
    <-1.1179555, 4.1543989, -0.4111941>,
    <-1.2804432, 3.8008799, -0.1867486>,
    <-1.2182283, 4.1543989, 0.0766992>,
    <-1.1870700, 4.1543989, -0.1762825>,
    <-0.8942989, 3.8008799, -0.8176876>,
    <-0.8341866, 4.1543989, -0.7725965>,
    <-1.0691310, 3.8008799, -0.6456133>,
    <-0.9955794, 4.1543989, -0.6099654>,
    <-0.4735051, 3.8008799, -1.0471200>,
    <-0.4432792, 4.1543989, -0.9894379>,
    <-0.6936015, 3.8008799, -0.9515232>,
    <-0.6480223, 4.1543989, -0.8990873>,
    <-0.0009808, 3.8008799, -1.1235974>,
    <-0.0028285, 4.1543989, -1.0617184>,
    <-0.2404761, 3.8008799, -1.1044781>,
    <-0.2261503, 4.1543989, -1.0436483>,
    <0.4715435, 3.8008799, -1.0471200>,
    <0.4376222, 4.1543989, -0.9894379>,
    <0.2385145, 3.8008799, -1.1044781>,
    <0.2204933, 4.1543989, -1.0436483>,
    <0.8923373, 3.8008799, -0.8176876>,
    <0.8285297, 4.1543989, -0.7725965>,
    <0.6916399, 3.8008799, -0.9515232>,
    <0.6423653, 4.1543989, -0.8990873>,
    <1.2005228, 3.8008799, -0.4353003>,
    <1.1119066, 4.1543989, -0.4111941>,
    <1.0671694, 3.8008799, -0.6456133>,
    <0.9899224, 4.1543989, -0.6099654>,
    <1.3131347, 3.8008799, 0.0809225>,
    <1.2102198, 4.1543989, 0.0766992>,
    <1.2767841, 3.8008799, -0.1867486>,
    <1.1798453, 4.1543989, -0.1762825>,
    <-1.3586827, 2.9911822, -0.4835026>,
    <-1.5014612, 2.9911822, 0.0831721>,
    <-1.2843073, 3.3969664, -0.4600157>,
    <-1.4523019, 2.9911822, -0.2106592>,
    <-1.4134868, 3.3969664, 0.0828852>,
    <-1.3701518, 3.3969664, -0.1986189>,
    <-1.0043670, 2.9911822, -0.9032616>,
    <-0.9518360, 3.3969664, -0.8621645>,
    <-1.2037472, 2.9911822, -0.7143700>,
    <-1.1395102, 3.3969664, -0.6811975>,
    <-0.5297804, 2.9911822, -1.1551170>,
    <-0.5027828, 3.3969664, -1.1034538>,
    <-0.7774135, 2.9911822, -1.0501772>,
    <-0.7373601, 3.3969664, -1.0029166>,
    <-0.0000498, 2.9911822, -1.2390688>,
    <-0.0001260, 3.3969664, -1.1838835>,
    <-0.2683613, 2.9911822, -1.2180808>,
    <-0.2548046, 3.3969664, -1.1637761>,
    <0.5296761, 2.9911822, -1.1551170>,
    <0.5025307, 3.3969664, -1.1034538>,
    <0.2682605, 2.9911822, -1.2180808>,
    <0.2545525, 3.3969664, -1.1637761>,
    <1.0042484, 2.9911822, -0.9032616>,
    <0.9515839, 3.3969664, -0.8621645>,
    <0.7773032, 2.9911822, -1.0501772>,
    <0.7371080, 3.3969664, -1.0029166>,
    <1.3581182, 2.9911822, -0.4835026>,
    <1.2836227, 3.3969664, -0.4600157>,
    <1.2036181, 2.9911822, -0.7143700>,
    <1.1392581, 3.3969664, -0.6811975>,
    <1.4987527, 2.9911822, 0.0831721>,
    <1.4106398, 3.3969664, 0.0828852>,
    <1.4504547, 2.9911822, -0.2106592>,
    <1.3681697, 3.3969664, -0.1986189>,
    <0.1492430, 7.0975547, -0.2217123>,
    <-0.0194960, 7.2298823, -0.3773564>,
    <0.1624906, 7.1023033, -0.3172219>,
    <0.0177693, 7.2172192, -0.4175135>,
    <0.0602526, 7.0975547, -0.0872941>,
    <-0.0750669, 7.2298823, -0.2899044>,
    <0.1063438, 7.1023033, -0.1574942>,
    <-0.0219598, 7.2172192, -0.3055749>,
    <-0.0683721, 7.0975547, -0.0069930>,
    <-0.1568467, 7.2298823, -0.2374332>,
    <-0.0033613, 7.1023033, -0.0510090>,
    <-0.0986561, 7.2172192, -0.2309491>,
    <-0.2158594, 7.0975547, 0.0191911>,
    <-0.2509727, 7.2298823, -0.2199428>,
    <-0.1413602, 7.1023033, 0.0022335>,
    <-0.1951064, 7.2172192, -0.1936363>,
    <-0.3630380, 7.0975547, -0.0087420>,
    <-0.3450987, 7.2298823, -0.2374332>,
    <-0.2887905, 7.1023033, 0.0022335>,
    <-0.2981413, 7.2172192, -0.1936363>,
    <-0.4907368, 7.0975547, -0.0907922>,
    <-0.4268785, 7.2298823, -0.2899044>,
    <-0.4267894, 7.1023033, -0.0510090>,
    <-0.3945916, 7.2172192, -0.2309491>,
    <-0.5757780, 7.0975547, -0.2269595>,
    <-0.4801078, 7.2298823, -0.3773564>,
    <-0.5364945, 7.1023033, -0.1574942>,
    <-0.4712879, 7.2172192, -0.3055749>,
    <-0.5849467, 7.1023033, -0.3172219>,
    <-0.5047727, 7.2172192, -0.4175135>,
    <0.4623434, 6.6917661, 0.0679769>,
    <0.3207567, 6.9095129, -0.0664042>,
    <0.4916950, 6.6917661, -0.0751570>,
    <0.3461732, 6.9095129, -0.1851057>,
    <0.3181688, 6.6917661, 0.2881827>,
    <0.2014819, 6.9095129, 0.1162135>,
    <0.4019794, 6.6917661, 0.1890901>,
    <0.2705700, 6.9095129, 0.0340355>,
    <0.1068759, 6.6917661, 0.4203063>,
    <0.0274656, 6.9095129, 0.2257841>,
    <0.2184776, 6.6917661, 0.3652548>,
    <0.1193611, 6.9095129, 0.1801297>,
    <-0.1361784, 6.6917661, 0.4643475>,
    <-0.1726161, 6.9095129, 0.2623076>,
    <-0.0126661, 6.6917661, 0.4533372>,
    <-0.0709461, 6.9095129, 0.2531768>,
    <-0.3792326, 6.6917661, 0.4203063>,
    <-0.3726979, 6.9095129, 0.2257841>,
    <-0.2596906, 6.6917661, 0.4533372>,
    <-0.2742861, 6.9095129, 0.2531768>,
    <-0.5905256, 6.6917661, 0.2881827>,
    <-0.5467141, 6.9095129, 0.1162135>,
    <-0.4908343, 6.6917661, 0.3652548>,
    <-0.4645933, 6.9095129, 0.1801297>,
    <-0.7333251, 6.6917661, 0.0679769>,
    <-0.6641483, 6.9095129, -0.0664042>,
    <-0.6743361, 6.6917661, 0.1890901>,
    <-0.6158022, 6.9095129, 0.0340355>,
    <-0.7585517, 6.6917661, -0.0751570>,
    <-0.6840432, 6.9095129, -0.1851057>,
    <0.6590798, 6.1904657, 0.2604762>,
    <0.5733586, 6.4513285, 0.1758129>,
    <0.6928240, 6.1904657, 0.0872803>,
    <0.6054277, 6.4513285, 0.0148848>,
    <0.4824056, 6.1904657, 0.5269315>,
    <0.4104245, 6.4513285, 0.4233944>,
    <0.5856347, 6.1904657, 0.4070266>,
    <0.5053937, 6.4513285, 0.3119827>,
    <0.2213127, 6.1904657, 0.6868047>,
    <0.1706756, 6.4513285, 0.5719434>,
    <0.3593093, 6.1904657, 0.6201909>,
    <0.2973424, 6.4513285, 0.5100480>,
    <-0.0795146, 6.1904657, 0.7400958>,
    <-0.1052989, 6.4513285, 0.6214597>,
    <0.0733824, 6.1904657, 0.7267730>,
    <0.0349525, 6.4513285, 0.6090806>,
    <-0.3803418, 6.1904657, 0.6868047>,
    <-0.3812735, 6.4513285, 0.5719434>,
    <-0.2324116, 6.1904657, 0.7267730>,
    <-0.2455503, 6.4513285, 0.6090806>,
    <-0.6414347, 6.1904657, 0.5269315>,
    <-0.6210223, 6.4513285, 0.4233944>,
    <-0.5183385, 6.1904657, 0.6201909>,
    <-0.5079402, 6.4513285, 0.5100480>,
    <-0.8174579, 6.1904657, 0.2604762>,
    <-0.7829759, 6.4513285, 0.1758129>,
    <-0.7446639, 6.1904657, 0.4070266>,
    <-0.7159915, 6.4513285, 0.3119827>,
    <-0.8492490, 6.1904657, 0.0872803>,
    <-0.8121036, 6.4513285, 0.0148848>,
    <0.7824973, 5.6165272, 0.3768194>,
    <0.7247848, 5.9114434, 0.3253393>,
    <0.8174256, 5.6165272, 0.1897530>,
    <0.7593369, 5.9114434, 0.1442899>,
    <0.5873408, 5.6165272, 0.6646138>,
    <0.5382690, 5.9114434, 0.6038769>,
    <0.7019861, 5.6165272, 0.5351063>,
    <0.6475243, 5.9114434, 0.4785350>,
    <0.2956665, 5.6165272, 0.8372905>,
    <0.2612348, 5.9114434, 0.7709995>,
    <0.4500105, 5.6165272, 0.7653419>,
    <0.4077324, 5.9114434, 0.7013651>,
    <-0.0413779, 5.6165272, 0.8948494>,
    <-0.0583622, 5.9114434, 0.8267070>,
    <0.1299799, 5.6165272, 0.8804597>,
    <0.1040965, 5.9114434, 0.8127802>,
    <-0.3784222, 5.6165272, 0.8372905>,
    <-0.3779591, 5.9114434, 0.7709995>,
    <-0.2127357, 5.6165272, 0.8804597>,
    <-0.2208208, 5.9114434, 0.8127802>,
    <-0.6700965, 5.6165272, 0.6646138>,
    <-0.6549934, 5.9114434, 0.6038769>,
    <-0.5327663, 5.6165272, 0.7653419>,
    <-0.5244567, 5.9114434, 0.7013651>,
    <-0.8650904, 5.6165272, 0.3768194>,
    <-0.8411283, 5.9114434, 0.3253393>,
    <-0.7847418, 5.6165272, 0.5351063>,
    <-0.7642486, 5.9114434, 0.4785350>,
    <-0.8995308, 5.6165272, 0.1897530>,
    <-0.8745380, 5.9114434, 0.1442899>,
    <0.9127177, 5.0077259, 0.4605718>,
    <0.8442413, 5.3079827, 0.4213336>,
    <0.9484014, 5.0077259, 0.2589105>,
    <0.8795498, 5.3079827, 0.2275090>,
    <0.6953376, 5.0077259, 0.7708199>,
    <0.6389468, 5.3079827, 0.7195253>,
    <0.8239365, 5.0077259, 0.6312083>,
    <0.7599434, 5.3079827, 0.5853390>,
    <0.3651615, 5.0077259, 0.9569688>,
    <0.3298323, 5.3079827, 0.8984403>,
    <0.5402012, 5.0077259, 0.8794068>,
    <0.4935425, 5.3079827, 0.8238923>,
    <-0.0180899, 5.0077259, 1.0190184>,
    <-0.0280979, 5.3079827, 0.9580786>,
    <0.1768530, 5.0077259, 1.0035060>,
    <0.1539181, 5.3079827, 0.9431690>,
    <-0.4013414, 5.0077259, 0.9569688>,
    <-0.3860281, 5.3079827, 0.8984403>,
    <-0.2130329, 5.0077259, 1.0035060>,
    <-0.2101140, 5.3079827, 0.9431690>,
    <-0.7315175, 5.0077259, 0.7708199>,
    <-0.6951427, 5.3079827, 0.7195253>,
    <-0.5763811, 5.0077259, 0.8794068>,
    <-0.5497384, 5.3079827, 0.8238923>,
    <-0.9490444, 5.0077259, 0.4605718>,
    <-0.9004477, 5.3079827, 0.4213336>,
    <-0.8601163, 5.0077259, 0.6312083>,
    <-0.8161393, 5.3079827, 0.5853390>,
    <-0.9851685, 5.0077259, 0.2589105>,
    <-0.9357878, 5.3079827, 0.2275090>,
    <1.0799686, 4.4643781, 0.5302458>,
    <0.9906274, 4.7376724, 0.4962241>,
    <1.1163731, 4.4643781, 0.3083526>,
    <1.0266728, 4.7376724, 0.2853105>,
    <0.8309269, 4.4643781, 0.8716199>,
    <0.7587637, 4.7376724, 0.8207066>,
    <0.9795378, 4.4643781, 0.7180016>,
    <0.8965054, 4.7376724, 0.6746895>,
    <0.4447858, 4.4643781, 1.0764444>,
    <0.4030836, 4.7376724, 1.0153961>,
    <0.6499816, 4.4643781, 0.9911009>,
    <0.5918596, 4.7376724, 0.9342754>,
    <-0.0060238, 4.4643781, 1.1447193>,
    <-0.0109214, 4.7376724, 1.0802926>,
    <0.2234228, 4.4643781, 1.1276505>,
    <0.1997264, 4.7376724, 1.0640684>,
    <-0.4568333, 4.4643781, 1.0764444>,
    <-0.4249264, 4.7376724, 1.0153961>,
    <-0.2354703, 4.4643781, 1.1276505>,
    <-0.2215692, 4.7376724, 1.0640684>,
    <-0.8429744, 4.4643781, 0.8716199>,
    <-0.7806065, 4.7376724, 0.8207066>,
    <-0.6620292, 4.4643781, 0.9911009>,
    <-0.6137024, 4.7376724, 0.9342754>,
    <-1.0923514, 4.4643781, 0.5302458>,
    <-1.0127245, 4.7376724, 0.4962241>,
    <-0.9915854, 4.4643781, 0.7180016>,
    <-0.9183482, 4.7376724, 0.6746895>,
    <-1.1297615, 4.4643781, 0.3083526>,
    <-1.0495327, 4.7376724, 0.2853105>,
    <1.2897582, 3.8008799, 0.5971454>,
    <1.1827392, 4.1543989, 0.5645924>,
    <1.3267559, 3.8008799, 0.3485936>,
    <1.2195116, 4.1543989, 0.3296809>,
    <0.9994197, 3.8008799, 0.9795327>,
    <0.9135288, 4.1543989, 0.9259948>,
    <1.1742518, 3.8008799, 0.8074584>,
    <1.0749216, 4.1543989, 0.7633637>,
    <0.5393624, 3.8008799, 1.2089650>,
    <0.4914550, 4.1543989, 1.1428363>,
    <0.7844446, 3.8008799, 1.1133682>,
    <0.7160312, 4.1543989, 1.0524857>,
    <-0.0009808, 3.8008799, 1.2854425>,
    <-0.0028285, 4.1543989, 1.2151167>,
    <0.2742087, 3.8008799, 1.2663231>,
    <0.2488264, 4.1543989, 1.1970466>,
    <-0.5413240, 3.8008799, 1.2089650>,
    <-0.4971120, 4.1543989, 1.1428363>,
    <-0.2761703, 3.8008799, 1.2663231>,
    <-0.2544833, 4.1543989, 1.1970466>,
    <-1.0013813, 3.8008799, 0.9795327>,
    <-0.9191858, 4.1543989, 0.9259948>,
    <-0.7864063, 3.8008799, 1.1133682>,
    <-0.7216882, 4.1543989, 1.0524857>,
    <-1.2921441, 3.8008799, 0.5971454>,
    <-1.1887881, 4.1543989, 0.5645924>,
    <-1.1762134, 3.8008799, 0.8074584>,
    <-1.0805785, 4.1543989, 0.7633637>,
    <-1.3304150, 3.8008799, 0.3485936>,
    <-1.2267362, 4.1543989, 0.3296809>,
    <1.4843341, 2.9911822, 0.6498467>,
    <1.3918441, 3.3969664, 0.6257861>,
    <1.5211369, 2.9911822, 0.3770034>,
    <1.4287736, 3.3969664, 0.3643894>,
    <1.1556902, 2.9911822, 1.0696057>,
    <1.0814496, 3.3969664, 1.0279349>,
    <1.3550705, 2.9911822, 0.8807142>,
    <1.2691238, 3.3969664, 0.8469679>,
    <0.6255546, 2.9911822, 1.3214611>,
    <0.5847790, 3.3969664, 1.2692242>,
    <0.9085371, 2.9911822, 1.2165213>,
    <0.8496582, 3.3969664, 1.1686870>,
    <-0.0001244, 2.9911822, 1.4054129>,
    <-0.0001260, 3.3969664, 1.3496539>,
    <0.3186863, 2.9911822, 1.3844249>,
    <0.2978411, 3.3969664, 1.3295465>,
    <-0.6257986, 2.9911822, 1.3214611>,
    <-0.5850311, 3.3969664, 1.2692242>,
    <-0.3189338, 2.9911822, 1.3844249>,
    <-0.2980932, 3.3969664, 1.3295465>,
    <-1.1559200, 2.9911822, 1.0696057>,
    <-1.0817017, 3.3969664, 1.0279349>,
    <-0.9087752, 2.9911822, 1.2165213>,
    <-0.8499103, 3.3969664, 1.1686870>,
    <-1.4849626, 2.9911822, 0.6498467>,
    <-1.3925287, 3.3969664, 0.6257861>,
    <-1.3552896, 2.9911822, 0.8807142>,
    <-1.2693759, 3.3969664, 0.8469679>,
    <-1.5230172, 2.9911822, 0.3770034>,
    <-1.4307557, 3.3969664, 0.3643894>,
    <-1.4791761, 2.2907830, -0.5223726>,
    <-1.6442707, 2.2907830, 0.0806367>,
    <-1.4225670, 2.6320514, -0.5039236>,
    <-1.5855752, 2.2907830, -0.2320348>,
    <-1.5772653, 2.6320514, 0.0823678>,
    <-1.5229998, 2.6320514, -0.2216351>,
    <-1.0895857, 2.2907830, -0.9690462>,
    <-1.0494606, 2.6320514, -0.9382135>,
    <-1.3077992, 2.2907830, -0.7680431>,
    <-1.2588722, 2.6320514, -0.7427830>,
    <-0.5742483, 2.2907830, -1.2370503>,
    <-0.5531661, 2.6320514, -1.1987875>,
    <-0.8426765, 2.2907830, -1.1253819>,
    <-0.8118772, 2.6320514, -1.0902150>,
    <-0.0015419, 2.2907830, -1.3263850>,
    <-0.0005376, 2.6320514, -1.2856455>,
    <-0.2914779, 2.2907830, -1.3040514>,
    <-0.2803716, 2.6320514, -1.2639310>,
    <0.5711201, 2.2907830, -1.2370503>,
    <0.5520719, 2.6320514, -1.1987875>,
    <0.2883830, 2.2907830, -1.3040514>,
    <0.2792916, 2.6320514, -1.2639310>,
    <1.0863242, 2.2907830, -0.9690462>,
    <1.0483095, 2.6320514, -0.9382135>,
    <0.8394927, 2.2907830, -1.1253819>,
    <0.8107593, 2.6320514, -1.0902150>,
    <1.4753225, 2.2907830, -0.5223726>,
    <1.4209211, 2.6320514, -0.5039236>,
    <1.3044378, 2.2907830, -0.7680431>,
    <1.2576786, 2.6320514, -0.7427830>,
    <1.6382668, 2.2907830, 0.0806367>,
    <1.5734910, 2.6320514, 0.0823678>,
    <1.5804670, 2.2907830, -0.2320348>,
    <1.5200920, 2.6320514, -0.2216351>,
    <-1.5771572, 1.5788248, -0.5553385>,
    <-1.7586847, 1.5788248, 0.0750428>,
    <-1.5317263, 1.9385866, -0.5399437>,
    <-1.6931117, 1.5788248, -0.2518215>,
    <-1.7058488, 1.9385866, 0.0781428>,
    <-1.6433581, 1.9385866, -0.2423465>,
    <-1.1600257, 1.5788248, -1.0222875>,
    <-1.1272111, 1.9385866, -0.9977856>,
    <-1.3930629, 1.5788248, -0.8121605>,
    <-1.3534424, 1.9385866, -0.7917568>,
    <-0.6121563, 1.5788248, -1.3024570>,
    <-0.5943352, 1.9385866, -1.2724907>,
    <-0.8972418, 1.5788248, -1.1857197>,
    <-0.8717367, 1.9385866, -1.1580302>,
    <-0.0048595, 1.5788248, -1.3958468>,
    <-0.0030149, 1.9385866, -1.3640591>,
    <-0.3122139, 1.5788248, -1.3724994>,
    <-0.3023227, 1.9385866, -1.3411670>,
    <0.6023063, 1.5788248, -1.3024570>,
    <0.5882225, 1.9385866, -1.2724907>,
    <0.3024622, 1.5788248, -1.3724994>,
    <0.2962721, 1.9385866, -1.3411670>,
    <1.1497824, 1.5788248, -1.0222875>,
    <1.1208494, 1.9385866, -0.9977856>,
    <0.8872279, 1.5788248, -1.1857197>,
    <0.8655202, 1.9385866, -1.1580302>,
    <1.5659582, 1.5788248, -0.5553385>,
    <1.5246131, 1.9385866, -0.5399437>,
    <1.3825248, 1.5788248, -0.8121605>,
    <1.3468941, 1.9385866, -0.7917568>,
    <1.7450986, 1.5788248, 0.0750428>,
    <1.6964922, 1.9385866, 0.0781428>,
    <1.6805853, 1.5788248, -0.2518215>,
    <1.6349652, 1.9385866, -0.2423465>,
    <-1.6426798, 0.8475771, -0.5777141>,
    <-1.8340240, 0.8475771, 0.0676745>,
    <-1.6124084, 1.2148607, -0.5672583>,
    <-1.7644272, 0.8475771, -0.2669715>,
    <-1.7994633, 1.2148607, 0.0714935>,
    <-1.7315997, 1.2148607, -0.2597112>,
    <-1.2080683, 0.8475771, -1.0557797>,
    <-1.1857183, 1.2148607, -1.0404079>,
    <-1.4505892, 0.8475771, -0.8406502>,
    <-1.4239218, 1.2148607, -0.8274906>,
    <-0.6391195, 0.8475771, -1.3426191>,
    <-0.6264410, 1.2148607, -1.3242976>,
    <-0.9350302, 0.8475771, -1.2231027>,
    <-0.9173760, 1.2148607, -1.2060102>,
    <-0.0092578, 0.8475771, -1.4382323>,
    <-0.0069786, 1.2148607, -1.4189275>,
    <-0.3279805, 0.8475771, -1.4143290>,
    <-0.3204598, 1.2148607, -1.3952700>,
    <0.6203604, 0.8475771, -1.3426191>,
    <0.6122986, 1.2148607, -1.3242976>,
    <0.3094040, 0.8475771, -1.4143290>,
    <0.3064563, 1.2148607, -1.3952700>,
    <1.1885792, 0.8475771, -1.0557797>,
    <1.1710205, 1.2148607, -1.0404079>,
    <0.9159670, 0.8475771, -1.2231027>,
    <0.9030021, 1.2148607, -1.2060102>,
    <1.6217506, 0.8475771, -0.5777141>,
    <1.5965227, 1.2148607, -0.5672583>,
    <1.4305526, 0.8475771, -0.8406502>,
    <1.4088074, 1.2148607, -0.8274906>,
    <1.8103354, 0.8475771, 0.0676745>,
    <1.7810176, 1.2148607, 0.0714935>,
    <1.7420371, 0.8475771, -0.2669715>,
    <1.7143262, 1.2148607, -0.2597112>,
    <-1.6976149, 0.1065190, -0.5977554>,
    <-1.8950050, 0.1065190, 0.0599683>,
    <-1.6731716, 0.4778570, -0.5887165>,
    <-1.8231827, 0.1065190, -0.2810736>,
    <-1.8682064, 0.4778570, 0.0637653>,
    <-1.7971994, 0.4778570, -0.2745586>,
    <-1.2494538, 0.1065190, -1.0849581>,
    <-1.2308549, 0.4778570, -1.0720364>,
    <-1.4995191, 0.1065190, -0.8657169>,
    <-1.4776351, 0.4778570, -0.8545425>,
    <-0.6629656, 0.1065190, -1.3772797>,
    <-0.6521216, 0.4778570, -1.3620283>,
    <-0.9679775, 0.1065190, -1.2554791>,
    <-0.9530958, 0.4778570, -1.2411984>,
    <-0.0138370, 0.1065190, -1.4747203>,
    <-0.0115827, 0.4778570, -1.4586923>,
    <-0.3422937, 0.1065190, -1.4503602>,
    <-0.3356960, 0.4778570, -1.4345263>,
    <0.6349287, 0.1065190, -1.3772797>,
    <0.6286525, 0.4778570, -1.3620283>,
    <0.3145289, 0.1065190, -1.4503602>,
    <0.3124547, 0.4778570, -1.4345263>,
    <1.2203280, 0.1065190, -1.0849581>,
    <1.2064743, 0.4778570, -1.0720364>,
    <0.9394868, 0.1065190, -1.2554791>,
    <0.9292469, 0.4778570, -1.2411984>,
    <1.6665229, 0.1065190, -0.5977554>,
    <1.6470857, 0.4778570, -0.5887165>,
    <1.4695767, 0.1065190, -0.8657169>,
    <1.4525710, 0.4778570, -0.8545425>,
    <1.8607054, 0.1065190, 0.0599683>,
    <1.8391383, 0.4778570, 0.0637653>,
    <1.7904565, 0.1065190, -0.2810736>,
    <1.7695672, 0.4778570, -0.2745586>,
    <-1.7095710, -0.6384540, -0.6024296>,
    <-1.9054463, -0.6384540, 0.0535132>,
    <-1.7097409, -0.2656179, -0.6023207>,
    <-1.8346021, -0.6384540, -0.2866053>,
    <-1.9074141, -0.2656179, 0.0564854>,
    <-1.8356432, -0.2656179, -0.2851177>,
    <-1.2602122, -0.6384540, -1.0883132>,
    <-1.2592407, -0.2656179, -1.0903252>,
    <-1.5111923, -0.6384540, -0.8696656>,
    <-1.5107005, -0.2656179, -0.8707232>,
    <-0.6706799, -0.6384540, -1.3798434>,
    <-0.6691694, -0.2656179, -1.3831279>,
    <-0.9773772, -0.6384540, -1.2583725>,
    <-0.9760799, -0.2656179, -1.2611268>,
    <-0.0176694, -0.6384540, -1.4770201>,
    <-0.0159048, -0.2656179, -1.4807288>,
    <-0.3481131, -0.6384540, -1.4527259>,
    <-0.3464606, -0.2656179, -1.4563286>,
    <0.6348777, -0.6384540, -1.3798434>,
    <0.6369427, -0.2656179, -1.3831279>,
    <0.3126584, -0.6384540, -1.4527259>,
    <0.3145467, -0.2656179, -1.4563286>,
    <1.2230196, -0.6384540, -1.0883132>,
    <1.2257624, -0.2656179, -1.0903252>,
    <0.9409956, -0.6384540, -1.2583725>,
    <0.9433317, -0.2656179, -1.2611268>,
    <1.6699686, -0.6384540, -0.6024296>,
    <1.6740570, -0.2656179, -0.6023207>,
    <1.4729569, -0.6384540, -0.8696656>,
    <1.4762836, -0.2656179, -0.8707232>,
    <1.8622532, -0.6384540, 0.0535132>,
    <1.8683160, -0.2656179, 0.0564854>,
    <1.7932161, -0.6384540, -0.2866053>,
    <1.7982445, -0.2656179, -0.2851177>,
    <-1.6724300, -1.3858239, -0.5893478>,
    <-1.8584290, -1.3858239, 0.0498863>,
    <-1.6971269, -1.0118893, -0.5980996>,
    <-1.7920999, -1.3858239, -0.2815684>,
    <-1.8891138, -1.0118893, 0.0512480>,
    <-1.8200807, -1.0118893, -0.2854507>,
    <-1.2356951, -1.3858239, -1.0628546>,
    <-1.2523648, -1.0118893, -1.0790978>,
    <-1.4801579, -1.3858239, -0.8497766>,
    <-1.5010071, -1.0118893, -0.8626486>,
    <-0.6594084, -1.3858239, -1.3469587>,
    <-0.6674439, -1.0118893, -1.3676968>,
    <-0.9594529, -1.3858239, -1.2285820>,
    <-0.9718435, -1.0118893, -1.2474472>,
    <-0.0198227, -1.3858239, -1.4416601>,
    <-0.0190142, -1.0118893, -1.4638964>,
    <-0.3435392, -1.3858239, -1.4179847>,
    <-0.3471672, -1.0118893, -1.4398465>,
    <0.6192431, -1.3858239, -1.3469587>,
    <0.6289168, -1.0118893, -1.3676968>,
    <0.3037639, -1.3858239, -1.4179847>,
    <0.3090141, -1.0118893, -1.4398465>,
    <1.1939700, -1.3858239, -1.0628546>,
    <1.2123415, -1.0118893, -1.0790978>,
    <0.9186376, -1.3858239, -1.2285820>,
    <0.9326929, -1.0118893, -1.2474472>,
    <1.6280459, -1.3858239, -0.5893478>,
    <1.6545381, -1.0118893, -0.5980996>,
    <1.4372630, -1.3858239, -0.8497766>,
    <1.4598616, -1.0118893, -0.8626486>,
    <1.8102389, -1.3858239, 0.0498863>,
    <1.8427998, -1.0118893, 0.0512480>,
    <1.7458482, -1.3858239, -0.2815684>,
    <1.7756558, -1.0118893, -0.2854507>,
    <-1.5863639, -2.0752537, -0.5586485>,
    <-1.7540523, -2.0752537, 0.0506588>,
    <-1.6355018, -1.7601581, -0.5761917>,
    <-1.6958453, -2.0752537, -0.2652783>,
    <-1.8134044, -1.7601581, 0.0496245>,
    <-1.7506811, -1.7601581, -0.2748728>,
    <-1.1758749, -2.0752537, -1.0099873>,
    <-1.2101997, -1.7601581, -1.0397592>,
    <-1.4065188, -2.0752537, -0.8068848>,
    <-1.4486576, -1.7601581, -0.8311538>,
    <-0.6287262, -2.0752537, -1.2807905>,
    <-0.6465202, -1.7601581, -1.3178997>,
    <-0.9139974, -2.0752537, -1.1679558>,
    <-0.9401794, -1.7601581, -1.2020079>,
    <-0.0193640, -2.0752537, -1.3710583>,
    <-0.0199781, -1.7601581, -1.4106133>,
    <-0.3279017, -2.0752537, -1.3484913>,
    <-0.3371454, -1.7601581, -1.3874349>,
    <0.5894903, -2.0752537, -1.2807905>,
    <0.6060399, -1.7601581, -1.3178997>,
    <0.2890467, -2.0752537, -1.3484913>,
    <0.2970581, -1.7601581, -1.3874349>,
    <1.1351152, -2.0752537, -1.0099873>,
    <1.1681473, -1.7601581, -1.0397592>,
    <0.8741265, -2.0752537, -1.1679558>,
    <0.8990441, -1.7601581, -1.2020079>,
    <1.5429983, -2.0752537, -0.5586485>,
    <1.5907725, -1.7601581, -0.5761917>,
    <1.3646163, -2.0752537, -0.8068848>,
    <1.4054262, -1.7601581, -0.8311538>,
    <1.7069266, -2.0752537, 0.0506588>,
    <1.7648535, -1.7601581, 0.0496245>,
    <1.6506299, -2.0752537, -0.2652783>,
    <1.7040780, -1.7601581, -0.2748728>,
    <-1.4580580, -2.4293115, -0.5108007>,
    <-1.5999935, -2.4293115, 0.0566488>,
    <-1.5250378, -2.2714726, -0.5367355>,
    <-1.5531346, -2.4293115, -0.2375842>,
    <-1.6803852, -2.2714726, 0.0531859>,
    <-1.6276136, -2.2714726, -0.2526993>,
    <-1.0854567, -2.4293115, -0.9311336>,
    <-1.1327175, -2.2714726, -0.9737143>,
    <-1.2960692, -2.4293115, -0.7419838>,
    <-1.3537545, -2.2714726, -0.7770739>,
    <-0.5808351, -2.4293115, -1.1833334>,
    <-0.6059733, -2.2714726, -1.2359016>,
    <-0.8445088, -2.4293115, -1.0782502>,
    <-0.8808807, -2.2714726, -1.1266569>,
    <-0.0157493, -2.4293115, -1.2674000>,
    <-0.0178637, -2.2714726, -1.3232974>,
    <-0.3020454, -2.4293115, -1.2463833>,
    <-0.3157246, -2.2714726, -1.3014484>,
    <0.5489234, -2.4293115, -1.1833334>,
    <0.5697773, -2.2714726, -1.2359016>,
    <0.2704435, -2.4293115, -1.2463833>,
    <0.2798800, -2.2714726, -1.3014484>,
    <1.0523057, -2.4293115, -0.9311336>,
    <1.0951158, -2.2714726, -0.9737143>,
    <0.8120807, -2.4293115, -1.0782502>,
    <0.8440990, -2.2714726, -1.1266569>,
    <1.4227194, -2.4293115, -0.5108007>,
    <1.4850038, -2.2714726, -0.5367355>,
    <1.2619888, -2.4293115, -0.7419838>,
    <1.3150985, -2.2714726, -0.7770739>,
    <1.5612562, -2.4293115, 0.0566488>,
    <1.6367411, -2.2714726, 0.0531859>,
    <1.5160873, -2.4293115, -0.2375842>,
    <1.5857884, -2.2714726, -0.2526993>,
    <1.6300331, 2.2907830, 0.6836460>,
    <1.5625651, 2.6320514, 0.6686592>,
    <1.6671174, 2.2907830, 0.3933082>,
    <1.5994179, 2.6320514, 0.3863708>,
    <1.2718148, 2.2907830, 1.1303196>,
    <1.2182132, 2.6320514, 1.1029492>,
    <1.4900284, 2.2907830, 0.9293165>,
    <1.4276248, 2.6320514, 0.9075187>,
    <0.6882729, 2.2907830, 1.3983237>,
    <0.6595392, 2.6320514, 1.3635231>,
    <1.0001040, 2.2907830, 1.2866553>,
    <0.9579463, 2.6320514, 1.2549506>,
    <-0.0022414, 2.2907830, 1.4876584>,
    <-0.0008359, 2.6320514, 1.4503811>,
    <0.3496987, 2.2907830, 1.4653247>,
    <0.3357068, 2.6320514, 1.4286666>,
    <-0.6927113, 2.2907830, 1.3983237>,
    <-0.6611920, 2.6320514, 1.3635231>,
    <-0.3541705, 2.2907830, 1.4653247>,
    <-0.3373738, 2.6320514, 1.4286666>,
    <-1.2761200, 2.2907830, 1.1303196>,
    <-1.2198092, 2.6320514, 1.1029492>,
    <-1.0044868, 2.2907830, 1.2866553>,
    <-0.9595755, 2.6320514, 1.2549506>,
    <-1.6344862, 2.2907830, 0.6836460>,
    <-1.5644666, 2.6320514, 0.6686592>,
    <-1.4942336, 2.2907830, 0.9293165>,
    <-1.4291782, 2.6320514, 0.9075187>,
    <-1.6725365, 2.2907830, 0.3933082>,
    <-1.6024582, 2.6320514, 0.3863708>,
    <1.7401874, 1.5788248, 0.7054241>,
    <1.6902339, 1.9385866, 0.6962293>,
    <1.7781904, 1.5788248, 0.4019072>,
    <1.7277360, 1.9385866, 0.3986321>,
    <1.3583792, 1.5788248, 1.1723732>,
    <1.3192915, 1.9385866, 1.1540711>,
    <1.5914165, 1.5788248, 0.9622461>,
    <1.5455229, 1.9385866, 0.9480423>,
    <0.7334598, 1.5788248, 1.4525426>,
    <0.7132961, 1.9385866, 1.4287763>,
    <1.0675771, 1.5788248, 1.3358054>,
    <1.0372282, 1.9385866, 1.3143158>,
    <-0.0069236, 1.5788248, 1.5459324>,
    <-0.0043216, 1.9385866, 1.5203446>,
    <0.3704764, 1.5788248, 1.5225850>,
    <0.3614585, 1.9385866, 1.4974525>,
    <-0.7471759, 1.5788248, 1.4525426>,
    <-0.7218564, 1.9385866, 1.4287763>,
    <-0.3842908, 1.5788248, 1.5225850>,
    <-0.3700809, 1.9385866, 1.4974525>,
    <-1.3717022, 1.5788248, 1.1723732>,
    <-1.3276028, 1.9385866, 1.1540711>,
    <-1.0811295, 1.5788248, 1.3358054>,
    <-1.0456847, 1.9385866, 1.3143158>,
    <-1.7531557, 1.5788248, 0.7054241>,
    <-1.6984671, 1.9385866, 0.6962293>,
    <-1.6044446, 1.5788248, 0.9622461>,
    <-1.5536475, 1.9385866, 0.9480423>,
    <-1.7916342, 1.5788248, 0.4019072>,
    <-1.7367097, 1.9385866, 0.3986321>,
    <1.8065082, 0.8475771, 0.7130631>,
    <1.7769136, 1.2148607, 0.7102454>,
    <1.8455694, 0.8475771, 0.4023204>,
    <1.8153969, 1.2148607, 0.4026982>,
    <1.4094000, 0.8475771, 1.1911287>,
    <1.3868138, 1.2148607, 1.1833949>,
    <1.6519209, 0.8475771, 0.9759992>,
    <1.6250173, 1.2148607, 0.9704776>,
    <0.7584351, 0.8475771, 1.4779681>,
    <0.7476146, 1.2148607, 1.4672846>,
    <1.1065379, 0.8475771, 1.3584517>,
    <1.0894089, 1.2148607, 1.3489972>,
    <-0.0130906, 0.8475771, 1.5735812>,
    <-0.0098946, 1.2148607, 1.5619145>,
    <0.3801921, 0.8475771, 1.5496779>,
    <0.3762428, 1.2148607, 1.5382570>,
    <-0.7843730, 0.8475771, 1.4779681>,
    <-0.7672188, 1.2148607, 1.4672846>,
    <-0.4063125, 0.8475771, 1.5496779>,
    <-0.3959858, 1.2148607, 1.5382570>,
    <-1.4346079, 0.8475771, 1.1911287>,
    <-1.4058625, 1.2148607, 1.1833949>,
    <-1.1321717, 0.8475771, 1.3584517>,
    <-1.1087816, 1.2148607, 1.3489972>,
    <-1.8307226, 0.8475771, 0.7130631>,
    <-1.7952987, 1.2148607, 0.7102454>,
    <-1.6765813, 0.8475771, 0.9759992>,
    <-1.6436494, 1.2148607, 0.9704776>,
    <-1.8696630, 0.8475771, 0.4023204>,
    <-1.8339664, 1.2148607, 0.4026982>,
    <1.8558794, 0.1065190, 0.7176919>,
    <1.8350668, 0.4778570, 0.7162472>,
    <1.8965977, 0.1065190, 0.4010101>,
    <1.8749217, 0.4778570, 0.4020893>,
    <1.4462310, 0.1065190, 1.2048946>,
    <1.4309427, 0.4778570, 1.1995671>,
    <1.6962964, 0.1065190, 0.9856534>,
    <1.6777230, 0.4778570, 0.9820731>,
    <0.7753481, 0.1065190, 1.4972162>,
    <0.7685955, 0.4778570, 1.4895590>,
    <1.1340657, 0.1065190, 1.3754156>,
    <1.1227786, 0.4778570, 1.3687290>,
    <-0.0195533, 0.1065190, 1.5946568>,
    <-0.0163676, 0.4778570, 1.5862230>,
    <0.3856259, 0.1065190, 1.5702967>,
    <0.3837584, 0.4778570, 1.5620570>,
    <-0.8140917, 0.1065190, 1.4972162>,
    <-0.8010269, 0.4778570, 1.4895590>,
    <-0.4246417, 0.1065190, 1.5702967>,
    <-0.4164177, 0.4778570, 1.5620570>,
    <-1.4838858, 0.1065190, 1.2048946>,
    <-1.4624627, 0.4778570, 1.1995671>,
    <-1.1723557, 0.1065190, 1.3754156>,
    <-1.1548303, 0.4778570, 1.3687290>,
    <-1.8918710, 0.1065190, 0.7176919>,
    <-1.8652541, 0.4778570, 0.7162472>,
    <-1.7331346, 0.1065190, 0.9856534>,
    <-1.7085594, 0.4778570, 0.9820731>,
    <-1.9318645, 0.1065190, 0.4010101>,
    <-1.9046805, 0.4778570, 0.4020893>,
    <1.8544112, -0.6384540, 0.7094560>,
    <1.8622358, -0.2656179, 0.7152915>,
    <1.8966337, -0.6384540, 0.3936317>,
    <1.9037414, -0.2656179, 0.3980886>,
    <1.4426591, -0.6384540, 1.1953396>,
    <1.4500542, -0.2656179, 1.2032960>,
    <1.6936391, -0.6384540, 0.9766920>,
    <1.7015141, -0.2656179, 0.9836940>,
    <0.7705955, -0.6384540, 1.4868698>,
    <0.7759453, -0.2656179, 1.4960987>,
    <1.1298127, -0.6384540, 1.3653989>,
    <1.1363343, -0.2656179, 1.3740976>,
    <-0.0249689, -0.6384540, 1.5840465>,
    <-0.0224753, -0.2656179, 1.5936996>,
    <0.3805032, -0.6384540, 1.5597523>,
    <0.3844784, -0.2656179, 1.5692994>,
    <-0.8200698, -0.6384540, 1.4868698>,
    <-0.8204787, -0.2656179, 1.4960987>,
    <-0.4303251, -0.6384540, 1.5597523>,
    <-0.4293247, -0.2656179, 1.5692994>,
    <-1.4907430, -0.6384540, 1.1953396>,
    <-1.4933361, -0.2656179, 1.2032960>,
    <-1.1787077, -0.6384540, 1.3653989>,
    <-1.1803462, -0.2656179, 1.3740976>,
    <-1.9002703, -0.6384540, 0.7094560>,
    <-1.9035515, -0.2656179, 0.7152915>,
    <-1.7406802, -0.6384540, 0.9766920>,
    <-1.7438573, -0.2656179, 0.9836940>,
    <-1.9412640, -0.6384540, 0.3936317>,
    <-1.9440603, -0.2656179, 0.3980886>,
    <1.7973194, -1.3858239, 0.6891205>,
    <1.8326807, -1.0118893, 0.7005957>,
    <1.8407870, -1.3858239, 0.3813411>,
    <1.8755553, -1.0118893, 0.3879468>,
    <1.3952005, -1.3858239, 1.1626273>,
    <1.4242922, -1.0118893, 1.1815939>,
    <1.6396633, -1.3858239, 0.9495492>,
    <1.6729345, -1.0118893, 0.9651447>,
    <0.7428892, -1.3858239, 1.4467314>,
    <0.7595073, -1.0118893, 1.4701929>,
    <1.0913129, -1.3858239, 1.3283547>,
    <1.1147294, -1.0118893, 1.3499433>,
    <-0.0280117, -1.3858239, 1.5414327>,
    <-0.0268693, -1.0118893, 1.5663925>,
    <0.3648181, -1.3858239, 1.5177574>,
    <0.3738873, -1.0118893, 1.5423426>,
    <-0.7983927, -1.3858239, 1.4467314>,
    <-0.8127472, -1.0118893, 1.4701929>,
    <-0.4207116, -1.3858239, 1.5177574>,
    <-0.4275012, -1.0118893, 1.5423426>,
    <-1.4491442, -1.3858239, 1.1626273>,
    <-1.4760359, -1.0118893, 1.1815939>,
    <-1.1461665, -1.3858239, 1.3283547>,
    <-1.1673458, -1.0118893, 1.3499433>,
    <-1.8487227, -1.3858239, 0.6891205>,
    <-1.8820024, -1.0118893, 0.7005957>,
    <-1.6924371, -1.3858239, 0.9495492>,
    <-1.7235560, -1.0118893, 0.9651447>,
    <-1.8906783, -1.3858239, 0.3813411>,
    <-1.9234713, -1.0118893, 0.3879468>,
    <1.6868050, -2.0752537, 0.6599662>,
    <1.7486025, -1.7601581, 0.6754406>,
    <1.7313039, -2.0752537, 0.3665960>,
    <1.7926096, -1.7601581, 0.3741217>,
    <1.3058294, -2.0752537, 1.1113049>,
    <1.3556307, -1.7601581, 1.1390082>,
    <1.5364733, -2.0752537, 0.9082025>,
    <1.5940886, -1.7601581, 0.9304028>,
    <0.6938973, -2.0752537, 1.3821082>,
    <0.7209497, -1.7601581, 1.4171487>,
    <1.0203942, -2.0752537, 1.2692735>,
    <1.0597917, -1.7601581, 1.3012568>,
    <-0.0273636, -2.0752537, 1.4723760>,
    <-0.0282314, -1.7601581, 1.5098622>,
    <0.3400681, -2.0752537, 1.4498090>,
    <0.3534826, -1.7601581, 1.4866838>,
    <-0.7481166, -2.0752537, 1.3821082>,
    <-0.7768885, -1.7601581, 1.4171487>,
    <-0.3946684, -2.0752537, 1.4498090>,
    <-0.4098145, -1.7601581, 1.4866838>,
    <-1.3585250, -2.0752537, 1.1113049>,
    <-1.4099974, -1.7601581, 1.1390082>,
    <-1.0739786, -2.0752537, 1.2692735>,
    <-1.1150755, -1.7601581, 1.3012568>,
    <-1.7370274, -2.0752537, 0.6599662>,
    <-1.8004061, -1.7601581, 0.6754406>,
    <-1.5880260, -2.0752537, 0.9082025>,
    <-1.6472763, -1.7601581, 0.9304028>,
    <-1.7800746, -2.0752537, 0.3665960>,
    <-1.8428807, -1.7601581, 0.3741217>,
    <1.5319824, -2.4293115, 0.6240983>,
    <1.6122021, -2.2714726, 0.6431073>,
    <1.5773902, -2.4293115, 0.3508819>,
    <1.6571507, -2.2714726, 0.3590710>,
    <1.1819134, -2.4293115, 1.0444313>,
    <1.2460435, -2.2714726, 1.0800861>,
    <1.3925260, -2.4293115, 0.8552815>,
    <1.4670805, -2.2714726, 0.8834456>,
    <0.6279893, -2.4293115, 1.2966311>,
    <0.6619405, -2.2714726, 1.3422734>,
    <0.9230373, -2.4293115, 1.1915478>,
    <0.9733489, -2.2714726, 1.2330287>,
    <-0.0222556, -2.4293115, 1.3806977>,
    <-0.0252435, -2.2714726, 1.4296691>,
    <0.3088611, -2.4293115, 1.3596810>,
    <0.3247618, -2.2714726, 1.4078202>,
    <-0.6720873, -2.4293115, 1.2966311>,
    <-0.7119589, -2.2714726, 1.3422734>,
    <-0.3532690, -2.4293115, 1.3596810>,
    <-0.3751316, -2.2714726, 1.4078202>,
    <-1.2247722, -2.4293115, 1.0444313>,
    <-1.2946563, -2.2714726, 1.0800861>,
    <-0.9666190, -2.4293115, 1.1915478>,
    <-1.0227817, -2.2714726, 1.2330287>,
    <-1.5728977, -2.4293115, 0.6240983>,
    <-1.6585616, -2.2714726, 0.6431073>,
    <-1.4344553, -2.4293115, 0.8552815>,
    <-1.5146390, -2.2714726, 0.8834456>,
    <-1.6173292, -2.4293115, 0.3508819>,
    <-1.7022558, -2.2714726, 0.3590710>,
    <-1.3406401, -2.8468913, -0.4489504>,
    <-1.4572610, -2.8468913, 0.0636572>,
    <-1.3919592, -2.6292672, -0.4811918>,
    <-1.4217721, -2.8468913, -0.2021394>,
    <-1.5204677, -2.6292672, 0.0604910>,
    <-1.4795566, -2.6292672, -0.2203816>,
    <-1.0031119, -2.8468913, -0.8286598>,
    <-1.0388220, -2.6292672, -0.8824383>,
    <-1.1953615, -2.8468913, -0.6577906>,
    <-1.2391678, -2.6292672, -0.7018774>,
    <-0.5366935, -2.8468913, -1.0564854>,
    <-0.5558854, -2.6292672, -1.1231863>,
    <-0.7810671, -2.8468913, -0.9615581>,
    <-0.8085609, -2.6292672, -1.0228746>,
    <-0.0108269, -2.8468913, -1.1324273>,
    <-0.0132929, -2.6292672, -1.2034356>,
    <-0.2774579, -2.8468913, -1.1134418>,
    <-0.2882958, -2.6292672, -1.1833732>,
    <0.5147547, -2.8468913, -1.0564854>,
    <0.5289510, -2.6292672, -1.1231863>,
    <0.2557328, -2.8468913, -1.1134418>,
    <0.2616229, -2.6292672, -1.1833732>,
    <0.9803183, -2.8468913, -0.8286598>,
    <1.0108416, -2.6292672, -0.8824383>,
    <0.7587721, -2.8468913, -0.9615581>,
    <0.7811907, -2.6292672, -1.0228746>,
    <1.3162225, -2.8468913, -0.4489504>,
    <1.3620755, -2.6292672, -0.4811918>,
    <1.1719268, -2.8468913, -0.6577906>,
    <1.2104030, -2.6292672, -0.7018774>,
    <1.4299237, -2.8468913, 0.0636572>,
    <1.4874309, -2.6292672, 0.0604910>,
    <1.3958306, -2.8468913, -0.2021394>,
    <1.4480600, -2.6292672, -0.2203816>,
    <-1.3106888, -3.2653112, -0.3807525>,
    <-1.4116302, -3.2653112, 0.0642445>,
    <-1.3179997, -3.0577354, -0.4151181>,
    <-1.3840907, -3.2653112, -0.1664947>,
    <-1.4258266, -3.0577354, 0.0650921>,
    <-1.3946734, -3.0577354, -0.1839057>,
    <-0.9854011, -3.2653112, -0.7103798>,
    <-0.9886254, -3.0577354, -0.7708294>,
    <-1.1720792, -3.2653112, -0.5620475>,
    <-1.1769617, -3.0577354, -0.6107593>,
    <-0.5270016, -3.2653112, -0.9081563>,
    <-0.5288290, -3.0577354, -0.9842561>,
    <-0.7677939, -3.2653112, -0.8257494>,
    <-0.7700570, -3.0577354, -0.8953283>,
    <-0.0068367, -3.2653112, -0.9740817>,
    <-0.0086842, -3.0577354, -1.0553984>,
    <-0.2707679, -3.2653112, -0.9576004>,
    <-0.2725139, -3.0577354, -1.0376128>,
    <0.5131426, -3.2653112, -0.9081563>,
    <0.5112290, -3.0577354, -0.9842561>,
    <0.2570481, -3.2653112, -0.9576004>,
    <0.2550876, -3.0577354, -1.0376128>,
    <0.9709852, -3.2653112, -0.7103798>,
    <0.9703307, -3.0577354, -0.7708294>,
    <0.7537029, -3.2653112, -0.8257494>,
    <0.7521676, -3.0577354, -0.8953283>,
    <1.2950763, -3.2653112, -0.3807525>,
    <1.2983108, -3.0577354, -0.4151181>,
    <1.1572455, -3.2653112, -0.5620475>,
    <1.1581459, -3.0577354, -0.6107593>,
    <1.3934229, -3.2653112, 0.0642445>,
    <1.4033933, -3.0577354, 0.0650921>,
    <1.3670698, -3.2653112, -0.1664947>,
    <1.3735231, -3.0577354, -0.1839057>,
    <-1.3090774, -3.6847051, -0.3146525>,
    <-1.3989627, -3.6847051, 0.0534958>,
    <-1.3053583, -3.4731305, -0.3469114>,
    <-1.3774297, -3.6847051, -0.1373959>,
    <-1.4001373, -3.4731305, 0.0605628>,
    <-1.3758540, -3.4731305, -0.1507201>,
    <-0.9881617, -3.6847051, -0.5873549>,
    <-0.9834778, -3.4731305, -0.6487441>,
    <-1.1735171, -3.6847051, -0.4646388>,
    <-1.1688249, -3.4731305, -0.5129194>,
    <-0.5284077, -3.6847051, -0.7509764>,
    <-0.5259209, -3.4731305, -0.8298437>,
    <-0.7704245, -3.6847051, -0.6828008>,
    <-0.7665410, -3.4731305, -0.7543855>,
    <-0.0039442, -3.6847051, -0.8055169>,
    <-0.0052565, -3.4731305, -0.8902103>,
    <-0.2702135, -3.6847051, -0.7918817>,
    <-0.2695239, -3.4731305, -0.8751186>,
    <0.5204113, -3.6847051, -0.7509764>,
    <0.5152636, -3.4731305, -0.8298437>,
    <0.2622982, -3.6847051, -0.7918817>,
    <0.2589748, -3.4731305, -0.8751186>,
    <0.9798409, -3.6847051, -0.5873549>,
    <0.9723881, -3.4731305, -0.6487441>,
    <0.7622929, -3.6847051, -0.6828008>,
    <0.7557036, -3.4731305, -0.7543855>,
    <1.2999048, -3.6847051, -0.3146525>,
    <1.2932549, -3.4731305, -0.3469114>,
    <1.1649529, -3.6847051, -0.4646388>,
    <1.1574109, -3.4731305, -0.5129194>,
    <1.3875047, -3.6847051, 0.0534958>,
    <1.3855962, -3.4731305, 0.0605628>,
    <1.3669723, -3.6847051, -0.1373959>,
    <1.3624033, -3.4731305, -0.1507201>,
    <-1.3590146, -4.1331673, -0.2591125>,
    <-1.4441364, -4.1331673, 0.0270001>,
    <-1.3289154, -3.9035468, -0.2850336>,
    <-1.4262466, -4.1331673, -0.1213546>,
    <-1.4157211, -3.9035468, 0.0424920>,
    <-1.3962839, -3.9035468, -0.1273361>,
    <-1.0288473, -4.1331673, -0.4710478>,
    <-1.0047589, -3.9035468, -0.5276452>,
    <-1.2204458, -4.1331673, -0.3756769>,
    <-1.1924737, -3.9035468, -0.4184700>,
    <-0.5501678, -4.1331673, -0.5982089>,
    <-0.5372830, -3.9035468, -0.6732121>,
    <-0.8025267, -4.1331673, -0.5452251>,
    <-0.7835710, -3.9035468, -0.6125593>,
    <-0.0020711, -4.1331673, -0.6405960>,
    <-0.0029000, -3.9035468, -0.7217345>,
    <-0.2804546, -4.1331673, -0.6299992>,
    <-0.2742683, -3.9035468, -0.7096039>,
    <0.5459707, -4.1331673, -0.5982089>,
    <0.5314044, -3.9035468, -0.6732121>,
    <0.2762986, -4.1331673, -0.6299992>,
    <0.2684486, -3.9035468, -0.7096039>,
    <1.0244858, -4.1331673, -0.4710478>,
    <0.9986446, -3.9035468, -0.5276452>,
    <0.7982611, -4.1331673, -0.5452251>,
    <0.7775941, -3.9035468, -0.6125593>,
    <1.3540485, -4.1331673, -0.2591125>,
    <1.3220844, -3.9035468, -0.2850336>,
    <1.2159609, -4.1331673, -0.3756769>,
    <1.1861827, -3.9035468, -0.4184700>,
    <1.4371476, -4.1331673, 0.0270001>,
    <1.4067400, -3.9035468, 0.0424920>,
    <1.4201107, -4.1331673, -0.1213546>,
    <1.3882257, -3.9035468, -0.1273361>,
    <-1.4297406, -4.6387918, -0.2225944>,
    <-1.5142019, -4.6387918, -0.0196535>,
    <-1.3935176, -4.3770783, -0.2379468>,
    <-1.4981456, -4.6387918, -0.1248821>,
    <-1.4779324, -4.3770783, 0.0064687>,
    <-1.4611477, -4.3770783, -0.1202653>,
    <-1.0842242, -4.6387918, -0.3729210>,
    <-1.0560048, -4.3770783, -0.4189954>,
    <-1.2852946, -4.6387918, -0.3052740>,
    <-1.2521840, -4.3770783, -0.3375236>,
    <-0.5797633, -4.6387918, -0.4631170>,
    <-0.5646831, -4.3770783, -0.5276246>,
    <-0.8459460, -4.6387918, -0.4255353>,
    <-0.8238381, -4.3770783, -0.4823624>,
    <-0.0008980, -4.6387918, -0.4931823>,
    <-0.0014044, -4.3770783, -0.5638343>,
    <-0.2949795, -4.6387918, -0.4856660>,
    <-0.2875388, -4.3770783, -0.5547818>,
    <0.5779447, -4.6387918, -0.4631170>,
    <0.5618379, -4.3770783, -0.5276246>,
    <0.2931778, -4.6387918, -0.4856660>,
    <0.2847209, -4.3770783, -0.5547818>,
    <1.0823382, -4.6387918, -0.3729210>,
    <1.0530508, -4.3770783, -0.4189954>,
    <0.8440993, -4.6387918, -0.4255353>,
    <0.8209476, -4.3770783, -0.4823624>,
    <1.4274197, -4.6387918, -0.2225944>,
    <1.3900523, -4.3770783, -0.2379468>,
    <1.2833581, -4.6387918, -0.3052740>,
    <1.2491483, -4.3770783, -0.3375236>,
    <1.5101163, -4.6387918, -0.0196535>,
    <1.4725730, -4.3770783, 0.0064687>,
    <1.4947838, -4.6387918, -0.1248821>,
    <1.4565749, -4.3770783, -0.1202653>,
    <-1.5027036, -5.2296729, -0.2135603>,
    <-1.6251994, -5.3906840, -0.1121665>,
    <-1.4649998, -4.9218194, -0.2141130>,
    <-1.5841536, -5.2296729, -0.1321588>,
    <-1.5627429, -5.0256526, -0.0644110>,
    <-1.5343986, -4.9218194, -0.1360191>,
    <-1.1404550, -5.2296729, -0.3044374>,
    <-1.1114982, -4.9218194, -0.3342574>,
    <-1.3515469, -5.2296729, -0.2635427>,
    <-1.3173837, -4.9218194, -0.2801924>,
    <-0.6098255, -5.2296729, -0.3589637>,
    <-0.5943428, -4.9218194, -0.4063441>,
    <-0.8899281, -5.2296729, -0.3362444>,
    <-0.8672908, -4.9218194, -0.3763080>,
    <-0.0003293, -5.2296729, -0.3771391>,
    <-0.0005501, -4.9218194, -0.4303729>,
    <-0.3100061, -5.2296729, -0.3725953>,
    <-0.3022355, -4.9218194, -0.4243657>,
    <0.6091603, -5.2296729, -0.3589637>,
    <0.5932298, -4.9218194, -0.4063441>,
    <0.3093459, -5.2296729, -0.3725953>,
    <0.3011321, -4.9218194, -0.4243657>,
    <1.1397700, -5.2296729, -0.3044374>,
    <1.1103466, -4.9218194, -0.3342574>,
    <0.8892547, -5.2296729, -0.3362444>,
    <0.8661617, -4.9218194, -0.3763080>,
    <1.5016926, -5.2296729, -0.2135603>,
    <1.4634744, -4.9218194, -0.2141130>,
    <1.3508470, -5.2296729, -0.2635427>,
    <1.3162033, -4.9218194, -0.2801924>,
    <1.6223736, -5.3906840, -0.1121665>,
    <1.5598600, -5.0256526, -0.0644110>,
    <1.5818203, -5.2296729, -0.1321588>,
    <1.5319028, -4.9218194, -0.1360191>,
    <-1.5948577, -5.9443936, -0.2423176>,
    <-1.7116714, -5.9339047, -0.1910788>,
    <-1.5462604, -5.5658640, -0.2219940>,
    <-1.6738893, -5.9383999, -0.2176471>,
    <-1.6497739, -5.5658640, -0.1370793>,
    <-1.6187419, -5.5658640, -0.1811092>,
    <-1.2095822, -5.9634983, -0.2802722>,
    <-1.1737226, -5.5658640, -0.2848939>,
    <-1.4333268, -5.9533840, -0.2631926>,
    <-1.3908794, -5.5658640, -0.2565889>,
    <-0.6467908, -5.9805257, -0.3030450>,
    <-0.6276151, -5.5658640, -0.3226338>,
    <-0.9439095, -5.9728634, -0.2935563>,
    <-0.9159134, -5.5658640, -0.3069088>,
    <-0.0001438, -5.9873706, -0.3106359>,
    <-0.0002043, -5.5658640, -0.3352137>,
    <-0.3287082, -5.9855317, -0.3087382>,
    <-0.3189910, -5.5658640, -0.3320687>,
    <0.6465022, -5.9805257, -0.3030450>,
    <0.6272035, -5.5658640, -0.3226338>,
    <0.3284204, -5.9855317, -0.3087382>,
    <0.3185816, -5.5658640, -0.3320687>,
    <1.2092903, -5.9634983, -0.2802722>,
    <1.1733022, -5.5658640, -0.2848939>,
    <0.9436195, -5.9728634, -0.2935563>,
    <0.9154981, -5.5658640, -0.3069088>,
    <1.5943311, -5.9443936, -0.2423176>,
    <1.5455501, -5.5658640, -0.2219940>,
    <1.4330324, -5.9533840, -0.2631926>,
    <1.3904524, -5.5658640, -0.2565889>,
    <1.7095331, -5.9339047, -0.1910788>,
    <1.6471177, -5.5658640, -0.1370793>,
    <1.6726716, -5.9383999, -0.2176471>,
    <1.6171967, -5.5658640, -0.1811092>,
    <-1.6751726, -6.6107811, -0.2866866>,
    <-1.8491379, -6.5478478, -0.2866866>,
    <-1.6476831, -6.3792621, -0.2774341>,
    <-1.7800178, -6.5748192, -0.2866866>,
    <-1.7990662, -6.3373066, -0.2534261>,
    <-1.7424061, -6.3552875, -0.2658747>,
    <-1.2649237, -6.7254096, -0.2866866>,
    <-1.2463150, -6.4556811, -0.2952179>,
    <-1.4988773, -6.6647239, -0.2866866>,
    <-1.4768345, -6.4152240, -0.2872152>,
    <-0.6763841, -6.8275739, -0.2866866>,
    <-0.6664317, -6.5237906, -0.3058881>,
    <-0.9871037, -6.7816000, -0.2866866>,
    <-0.9725794, -6.4931414, -0.3014422>,
    <-0.0001120, -6.8686430, -0.2866866>,
    <-0.0001163, -6.5511701, -0.3094449>,
    <-0.3437313, -6.8576097, -0.2866866>,
    <-0.3386760, -6.5438145, -0.3085557>,
    <0.6761602, -6.8275739, -0.2866866>,
    <0.6661988, -6.5237906, -0.3058881>,
    <0.3435074, -6.8576097, -0.2866866>,
    <0.3384433, -6.5438145, -0.3085557>,
    <1.2646997, -6.7254096, -0.2866866>,
    <1.2460812, -6.4556811, -0.2952179>,
    <0.9868798, -6.7816000, -0.2866866>,
    <0.9723461, -6.4931414, -0.3014422>,
    <1.6748846, -6.6107811, -0.2866866>,
    <1.6473196, -6.3792621, -0.2774341>,
    <1.4986534, -6.6647239, -0.2866866>,
    <1.4766001, -6.4152240, -0.2872152>,
    <1.8484007, -6.5478478, -0.2866866>,
    <1.7978025, -6.3373066, -0.2534261>,
    <1.7795372, -6.5748192, -0.2866866>,
    <1.7416567, -6.3552875, -0.2658747>,
    <1.3908011, -2.8468913, 0.5762648>,
    <1.4533345, -2.6292672, 0.6021738>,
    <1.4376744, -2.8468913, 0.3294538>,
    <1.4992626, -2.6292672, 0.3413636>,
    <1.0687726, -2.8468913, 0.9559742>,
    <1.1190797, -2.6292672, 1.0034204>,
    <1.2610222, -2.8468913, 0.7851050>,
    <1.3194256, -2.6292672, 0.8228594>,
    <0.5686933, -2.8468913, 1.1837998>,
    <0.5949536, -2.6292672, 1.2441683>,
    <0.8344874, -2.8468913, 1.0888725>,
    <0.8738407, -2.6292672, 1.1438567>,
    <-0.0153147, -2.8468913, 1.2597417>,
    <-0.0187843, -2.6292672, 1.3244176>,
    <0.2819171, -2.8468913, 1.2407562>,
    <0.2936636, -2.6292672, 1.3043553>,
    <-0.5990378, -2.8468913, 1.1837998>,
    <-0.6321736, -2.6292672, 1.2441683>,
    <-0.3124752, -2.8468913, 1.2407562>,
    <-0.3311451, -2.6292672, 1.3043553>,
    <-1.0982622, -2.8468913, 0.9559742>,
    <-1.1552537, -2.6292672, 1.0034204>,
    <-0.8644757, -2.8468913, 1.0888725>,
    <-0.9106249, -2.6292672, 1.1438567>,
    <-1.4190653, -2.8468913, 0.5762648>,
    <-1.4879251, -2.6292672, 0.6021738>,
    <-1.2898707, -2.8468913, 0.7851050>,
    <-1.3548151, -2.6292672, 0.8228594>,
    <-1.4656104, -2.8468913, 0.3294538>,
    <-1.5331999, -2.6292672, 0.3413636>,
    <1.3436667, -3.2653112, 0.5092414>,
    <1.3589250, -3.0577354, 0.5453024>,
    <1.3943324, -3.2653112, 0.2949836>,
    <1.4075319, -3.0577354, 0.3140900>,
    <1.0286161, -3.2653112, 0.8388688>,
    <1.0422224, -3.0577354, 0.9010136>,
    <1.2152941, -3.2653112, 0.6905365>,
    <1.2305587, -3.0577354, 0.7409436>,
    <0.5482854, -3.2653112, 1.0366452>,
    <0.5550680, -3.0577354, 1.1144404>,
    <0.8030339, -3.2653112, 0.9542384>,
    <0.8137057, -3.0577354, 1.0255126>,
    <-0.0097606, -3.2653112, 1.1025707>,
    <-0.0123316, -3.0577354, 1.1855827>,
    <0.2741080, -3.2653112, 1.0860893>,
    <0.2763690, -3.0577354, 1.1677971>,
    <-0.5676209, -3.2653112, 1.0366452>,
    <-0.5794997, -3.0577354, 1.1144404>,
    <-0.2935828, -3.2653112, 1.0860893>,
    <-0.3009744, -3.0577354, 1.1677971>,
    <-1.0473946, -3.2653112, 0.8388688>,
    <-1.0659593, -3.0577354, 0.9010136>,
    <-0.8221374, -3.2653112, 0.9542384>,
    <-0.8378478, -3.0577354, 1.0255126>,
    <-1.3617854, -3.2653112, 0.5092414>,
    <-1.3817403, -3.0577354, 0.5453024>,
    <-1.2336550, -3.2653112, 0.6905365>,
    <-1.2537745, -3.0577354, 0.7409436>,
    <-1.4126528, -3.2653112, 0.2949836>,
    <-1.4303033, -3.0577354, 0.3140900>,
    <1.3282057, -3.6847051, 0.4216441>,
    <1.3309869, -3.4731305, 0.4680370>,
    <1.3828511, -3.6847051, 0.2443875>,
    <1.3835736, -3.4731305, 0.2718457>,
    <1.0134073, -3.6847051, 0.6943465>,
    <1.0171403, -3.4731305, 0.7698697>,
    <1.1987626, -3.6847051, 0.5716304>,
    <1.2024874, -3.4731305, 0.6340450>,
    <0.5408798, -3.6847051, 0.8579680>,
    <0.5425531, -3.4731305, 0.9509693>,
    <0.7910252, -3.6847051, 0.7897924>,
    <0.7940107, -3.4731305, 0.8755112>,
    <-0.0056472, -3.6847051, 0.9125084>,
    <-0.0075270, -3.4731305, 1.0113359>,
    <0.2722345, -3.6847051, 0.8988733>,
    <0.2722224, -3.4731305, 0.9962442>,
    <-0.5520660, -3.6847051, 0.8579680>,
    <-0.5574631, -3.4731305, 0.9509693>,
    <-0.2835018, -3.6847051, 0.8988733>,
    <-0.2872404, -3.4731305, 0.9962442>,
    <-1.0242691, -3.6847051, 0.6943465>,
    <-1.0316178, -3.4731305, 0.7698697>,
    <-0.8020762, -3.6847051, 0.7897924>,
    <-0.8087404, -3.4731305, 0.8755112>,
    <-1.3388380, -3.6847051, 0.4216441>,
    <-1.3450365, -3.4731305, 0.4680370>,
    <-1.2093812, -3.6847051, 0.5716304>,
    <-1.2166405, -3.4731305, 0.6340450>,
    <-1.3940653, -3.6847051, 0.2443875>,
    <-1.3980334, -3.4731305, 0.2718457>,
    <1.3683936, -4.1331673, 0.3131127>,
    <1.3426436, -3.9035468, 0.3700177>,
    <1.4281593, -4.1331673, 0.1753548>,
    <1.3997608, -3.9035468, 0.2123201>,
    <1.0414999, -4.1331673, 0.5250480>,
    <1.0230290, -3.9035468, 0.6126292>,
    <1.2330983, -4.1331673, 0.4296771>,
    <1.2107438, -3.9035468, 0.5034540>,
    <0.5563457, -4.1331673, 0.6522092>,
    <0.5462737, -3.9035468, 0.7581962>,
    <0.8128248, -4.1331673, 0.5992254>,
    <0.7984667, -3.9035468, 0.6975433>,
    <-0.0029344, -4.1331673, 0.6945962>,
    <-0.0041372, -3.9035468, 0.8067185>,
    <0.2813351, -4.1331673, 0.6839995>,
    <0.2756668, -3.9035468, 0.7945879>,
    <-0.5621596, -4.1331673, 0.6522092>,
    <-0.5544696, -3.9035468, 0.7581962>,
    <-0.2871901, -4.1331673, 0.6839995>,
    <-0.2839216, -3.9035468, 0.7945879>,
    <-1.0471494, -4.1331673, 0.5250480>,
    <-1.0309892, -3.9035468, 0.6126292>,
    <-0.8185702, -4.1331673, 0.5992254>,
    <-0.8065643, -3.9035468, 0.6975433>,
    <-1.3740996, -4.1331673, 0.3131127>,
    <-1.3505350, -3.9035468, 0.3700177>,
    <-1.2386245, -4.1331673, 0.4296771>,
    <-1.2185272, -3.9035468, 0.5034540>,
    <-1.4346788, -4.1331673, 0.1753548>,
    <-1.4083689, -3.9035468, 0.2123201>,
    <1.4332997, -4.6387918, 0.1832874>,
    <1.3995492, -4.3770783, 0.2508843>,
    <1.4980829, -4.6387918, 0.0855751>,
    <1.4619033, -4.3770783, 0.1332028>,
    <1.0893123, -4.6387918, 0.3336140>,
    <1.0643146, -4.3770783, 0.4319329>,
    <1.2903827, -4.6387918, 0.2659670>,
    <1.2604938, -4.3770783, 0.3504610>,
    <0.5821975, -4.6387918, 0.4238100>,
    <0.5687065, -4.3770783, 0.5405621>,
    <0.8500690, -4.6387918, 0.3862283>,
    <0.8305892, -4.3770783, 0.4952999>,
    <-0.0012519, -4.6387918, 0.4538753>,
    <-0.0019759, -4.3770783, 0.5767718>,
    <0.2952423, -4.6387918, 0.4463589>,
    <0.2880552, -4.3770783, 0.5677193>,
    <-0.5846787, -4.6387918, 0.4238100>,
    <-0.5726220, -4.3770783, 0.5405621>,
    <-0.2977404, -4.6387918, 0.4463589>,
    <-0.2919979, -4.3770783, 0.5677193>,
    <-1.0917262, -4.6387918, 0.3336140>,
    <-1.0681213, -4.3770783, 0.4319329>,
    <-0.8525222, -4.6387918, 0.3862283>,
    <-0.8344594, -4.3770783, 0.4952999>,
    <-1.4359239, -4.6387918, 0.1832874>,
    <-1.4035043, -4.3770783, 0.2508843>,
    <-1.2927460, -4.6387918, 0.2659670>,
    <-1.2642188, -4.3770783, 0.3504610>,
    <-1.5016019, -4.6387918, 0.0855751>,
    <-1.4667301, -4.3770783, 0.1332028>,
    <1.5034196, -5.2296729, 0.0318080>,
    <1.4668347, -4.9218194, 0.1102770>,
    <1.5825137, -5.2296729, -0.0495935>,
    <1.5337881, -4.9218194, 0.0321831>,
    <1.1418183, -5.2296729, 0.1226851>,
    <1.1143321, -4.9218194, 0.2304214>,
    <1.3529102, -5.2296729, 0.0817904>,
    <1.3202177, -4.9218194, 0.1763564>,
    <0.6104093, -5.2296729, 0.1772114>,
    <0.5956601, -4.9218194, 0.3025080>,
    <0.8910080, -5.2296729, 0.1544921>,
    <0.8695732, -4.9218194, 0.2724719>,
    <-0.0004332, -5.2296729, 0.1953868>,
    <-0.0007523, -4.9218194, 0.3265369>,
    <0.3099522, -5.2296729, 0.1908430>,
    <0.3023118, -4.9218194, 0.3205297>,
    <-0.6112692, -5.2296729, 0.1772114>,
    <-0.5971519, -4.9218194, 0.3025080>,
    <-0.3108170, -5.2296729, 0.1908430>,
    <-0.3038133, -4.9218194, 0.3205297>,
    <-1.1426584, -5.2296729, 0.1226851>,
    <-1.1157854, -4.9218194, 0.2304214>,
    <-0.8918596, -5.2296729, 0.1544921>,
    <-0.8710490, -4.9218194, 0.2724719>,
    <-1.5045197, -5.2296729, 0.0318080>,
    <-1.4685334, -4.9218194, 0.1102770>,
    <-1.3537355, -5.2296729, 0.0817904>,
    <-1.3216421, -4.9218194, 0.1763564>,
    <-1.5848801, -5.2296729, -0.0495935>,
    <-1.5363738, -4.9218194, 0.0321831>,
    <1.5946175, -5.9443936, -0.1398400>,
    <1.7095331, -5.9339047, -0.1910788>,
    <1.5463198, -5.5658640, -0.0521645>,
    <1.6728323, -5.9383999, -0.1645105>,
    <1.6471177, -5.5658640, -0.1370793>,
    <1.6176285, -5.5658640, -0.0930494>,
    <1.2096299, -5.9634983, -0.1018854>,
    <1.1742151, -5.5658640, 0.0107353>,
    <1.4333745, -5.9533840, -0.1189650>,
    <1.3913719, -5.5658640, -0.0175696>,
    <0.6467093, -5.9805257, -0.0791126>,
    <0.6277602, -5.5658640, 0.0484752>,
    <0.9439102, -5.9728634, -0.0886012>,
    <0.9162796, -5.5658640, 0.0327502>,
    <-0.0001610, -5.9873706, -0.0715217>,
    <-0.0002506, -5.5658640, 0.0610552>,
    <0.3285209, -5.9855317, -0.0734194>,
    <0.3188518, -5.5658640, 0.0579102>,
    <-0.6470302, -5.9805257, -0.0791126>,
    <-0.6282585, -5.5658640, 0.0484752>,
    <-0.3288427, -5.9855317, -0.0734194>,
    <-0.3193524, -5.5658640, 0.0579102>,
    <-1.2099476, -5.9634983, -0.1018854>,
    <-1.1747046, -5.5658640, 0.0107353>,
    <-0.9442298, -5.9728634, -0.0886012>,
    <-0.9167742, -5.5658640, 0.0327502>,
    <-1.5951589, -5.9443936, -0.1398400>,
    <-1.5470698, -5.5658640, -0.0521645>,
    <-1.4336897, -5.9533840, -0.1189650>,
    <-1.3918548, -5.5658640, -0.0175696>,
    <-1.7116714, -5.9339047, -0.1910788>,
    <-1.6497739, -5.5658640, -0.1370793>,
    <-1.6740577, -5.9383999, -0.1645105>,
    <-1.6191944, -5.5658640, -0.0930494>,
    <1.6473948, -6.3792621, -0.2294180>,
    <1.7978025, -6.3373066, -0.2534261>,
    <1.7416988, -6.3552875, -0.2409774>,
    <1.2461704, -6.4556811, -0.2116342>,
    <1.4766899, -6.4152240, -0.2196369>,
    <0.6662532, -6.5237906, -0.2009640>,
    <0.9724224, -6.4931414, -0.2054099>,
    <-0.0001208, -6.5511701, -0.1974072>,
    <0.3384697, -6.5438145, -0.1982964>,
    <-0.6664945, -6.5237906, -0.2009640>,
    <-0.3387113, -6.5438145, -0.1982964>,
    <-1.2464109, -6.4556811, -0.2116342>,
    <-0.9726634, -6.4931414, -0.2054099>,
    <-1.6477622, -6.3792621, -0.2294180>,
    <-1.4769298, -6.4152240, -0.2196369>,
    <-1.7990662, -6.3373066, -0.2534261>,
    <-1.7424503, -6.3552875, -0.2409774>
  }
  normal_vectors {
    1548,
    <-0.7713928, 0.6310028, -0.0823924>,
    <-0.7217537, 0.6921498, -0.0004973>,
    <-0.0000000, 1.0000000, -0.0000000>,
    <-0.7318096, 0.6431724, -0.2253533>,
    <-0.8602366, 0.4364968, -0.2635594>,
    <-0.8732518, 0.4799945, -0.0838844>,
    <-0.8589962, 0.5119809, -0.0010967>,
    <-0.7067985, 0.5532492, -0.4408529>,
    <-0.5783422, 0.5684377, -0.5851486>,
    <-0.6573893, 0.3301701, -0.6773677>,
    <-0.7828277, 0.3657178, -0.5034195>,
    <-0.4667437, 0.4928644, -0.7343262>,
    <-0.3040554, 0.5469188, -0.7800193>,
    <-0.3431274, 0.3050993, -0.8883569>,
    <-0.5071254, 0.3021781, -0.8071631>,
    <-0.1555114, 0.5030828, -0.8501317>,
    <-0.0000000, 0.5836678, -0.8119925>,
    <-0.0000000, 0.3480722, -0.9374677>,
    <-0.1681799, 0.3134355, -0.9345982>,
    <0.1516792, 0.5684690, -0.8086015>,
    <0.2729124, 0.6598054, -0.7001254>,
    <0.3228249, 0.4441091, -0.8357937>,
    <0.1705693, 0.3859818, -0.9066003>,
    <0.4041437, 0.6641201, -0.6289772>,
    <0.4663604, 0.7469748, -0.4738530>,
    <0.5735989, 0.5671568, -0.5910308>,
    <0.4668343, 0.5007475, -0.7289154>,
    <0.5504885, 0.7573976, -0.3511571>,
    <0.5442784, 0.8161013, -0.1942669>,
    <0.6906344, 0.6810863, -0.2431987>,
    <0.6567930, 0.6244266, -0.4227462>,
    <0.5735024, 0.8148010, -0.0848194>,
    <0.5257168, 0.8506596, -0.0003623>,
    <0.6752902, 0.7375516, -0.0008621>,
    <0.6957051, 0.7119912, -0.0951998>,
    <-0.9288243, 0.3593758, -0.0901918>,
    <-0.9214598, 0.3884679, -0.0021094>,
    <-0.9090726, 0.3026775, -0.2863098>,
    <-0.9342543, 0.1888774, -0.3024801>,
    <-0.9655014, 0.2399321, -0.1011912>,
    <-0.9628675, 0.2699484, -0.0037377>,
    <-0.8147286, 0.2435412, -0.5262177>,
    <-0.6804823, 0.2031317, -0.7040464>,
    <-0.6894079, 0.1010749, -0.7172870>,
    <-0.8304165, 0.1356291, -0.5403825>,
    <-0.5237981, 0.1839968, -0.8317335>,
    <-0.3533961, 0.1787730, -0.9182328>,
    <-0.3565947, 0.0779835, -0.9309988>,
    <-0.5297731, 0.0826188, -0.8441058>,
    <-0.1760879, 0.1915929, -0.9655492>,
    <-0.0000000, 0.2155874, -0.9764846>,
    <-0.0000000, 0.1064183, -0.9943215>,
    <-0.1786412, 0.0862417, -0.9801274>,
    <0.1748533, 0.2555858, -0.9508429>,
    <0.3422004, 0.3038485, -0.8891428>,
    <0.3518208, 0.1803197, -0.9185352>,
    <0.1775956, 0.1379222, -0.9743907>,
    <0.4974007, 0.3650052, -0.7869966>,
    <0.6282453, 0.4275596, -0.6500005>,
    <0.6627731, 0.2919213, -0.6895751>,
    <0.5170165, 0.2325511, -0.8237802>,
    <0.7271671, 0.4956941, -0.4748845>,
    <0.7852180, 0.5557672, -0.2730487>,
    <0.8576699, 0.4205793, -0.2958302>,
    <0.7808521, 0.3563897, -0.5130852>,
    <0.7938882, 0.5989474, -0.1048973>,
    <0.7822310, 0.6229859, -0.0017907>,
    <0.8709406, 0.4913766, -0.0033808>,
    <0.8781167, 0.4649896, -0.1126750>,
    <-0.9825402, 0.1499240, -0.1101706>,
    <-0.9842158, 0.1768655, -0.0061467>,
    <-0.9437996, 0.1058347, -0.3131156>,
    <-0.9456079, 0.0506745, -0.3213375>,
    <-0.9890963, 0.0883311, -0.1178395>,
    <-0.9936765, 0.1118761, -0.0095299>,
    <-0.8340133, 0.0603200, -0.5484371>,
    <-0.6900137, 0.0304468, -0.7231556>,
    <-0.6869401, -0.0140945, -0.7265773>,
    <-0.8323485, 0.0118519, -0.5541259>,
    <-0.5290548, 0.0139052, -0.8484737>,
    <-0.3557743, 0.0087761, -0.9345307>,
    <-0.3532405, -0.0345612, -0.9348939>,
    <-0.5257869, -0.0290453, -0.8501203>,
    <-0.1782758, 0.0142651, -0.9838771>,
    <-0.0000000, 0.0296144, -0.9995614>,
    <0.0000000, -0.0198895, -0.9998022>,
    <-0.1769645, -0.0313045, -0.9837193>,
    <0.1780291, 0.0544919, -0.9825153>,
    <0.3543807, 0.0888556, -0.9308700>,
    <0.3533241, 0.0268655, -0.9351151>,
    <0.1770512, -0.0005347, -0.9842015>,
    <0.5244518, 0.1323455, -0.8410915>,
    <0.6786297, 0.1833604, -0.7112248>,
    <0.6832267, 0.1047790, -0.7226497>,
    <0.5249876, 0.0622821, -0.8488280>,
    <0.8093987, 0.2410441, -0.5355104>,
    <0.9013007, 0.3014373, -0.3111150>,
    <0.9237904, 0.2078187, -0.3215940>,
    <0.8215060, 0.1541990, -0.5489540>,
    <0.9312145, 0.3447369, -0.1183048>,
    <0.9290791, 0.3698356, -0.0058023>,
    <0.9627876, 0.2701013, -0.0092336>,
    <0.9610245, 0.2474144, -0.1233614>,
    <-0.9901446, 0.0621165, -0.1255194>,
    <-0.9964827, 0.0825959, -0.0141452>,
    <-0.9437680, 0.0301283, -0.3292329>,
    <-0.9398476, 0.0499736, -0.3379189>,
    <-0.9879835, 0.0768863, -0.1340786>,
    <-0.9952910, 0.0947797, -0.0203121>,
    <-0.8285618, -0.0030866, -0.5598891>,
    <-0.6826143, -0.0259550, -0.7303178>,
    <-0.6776760, 0.0009684, -0.7353599>,
    <-0.8236039, 0.0215146, -0.5667572>,
    <-0.5217825, -0.0397680, -0.8521511>,
    <-0.3502420, -0.0457098, -0.9355432>,
    <-0.3471194, -0.0186727, -0.9376350>,
    <-0.5175046, -0.0121715, -0.8555938>,
    <-0.1753768, -0.0442882, -0.9835047>,
    <-0.0000000, -0.0359957, -0.9993519>,
    <0.0000000, -0.0130544, -0.9999148>,
    <-0.1737193, -0.0188472, -0.9846148>,
    <0.1755104, -0.0209975, -0.9842536>,
    <0.3506083, 0.0008364, -0.9365218>,
    <0.3471347, 0.0161449, -0.9376763>,
    <0.1737499, -0.0014231, -0.9847888>,
    <0.5219670, 0.0295846, -0.8524525>,
    <0.6814159, 0.0646471, -0.7290357>,
    <0.6760716, 0.0687776, -0.7336190>,
    <0.5171348, 0.0397069, -0.8549824>,
    <0.8233500, 0.1061398, -0.5575206>,
    <0.9318526, 0.1520810, -0.3294270>,
    <0.9309114, 0.1419346, -0.3365391>,
    <0.8191489, 0.1034461, -0.5641755>,
    <0.9739702, 0.1867194, -0.1285217>,
    <0.9783137, 0.2066624, -0.0138873>,
    <0.9818522, 0.1885860, -0.0200379>,
    <0.9759962, 0.1712241, -0.1345874>,
    <-0.9829047, 0.1149878, -0.1437920>,
    <-0.9909282, 0.1314075, -0.0281653>,
    <-0.9332560, 0.0914718, -0.3473704>,
    <-0.9225732, 0.1461891, -0.3570538>,
    <-0.9734689, 0.1687614, -0.1545251>,
    <-0.9819541, 0.1853233, -0.0377021>,
    <-0.8162448, 0.0659028, -0.5739349>,
    <-0.6707749, 0.0463186, -0.7402132>,
    <-0.6610102, 0.1001346, -0.7436656>,
    <-0.8052906, 0.1207986, -0.5804436>,
    <-0.5117947, 0.0330144, -0.8584732>,
    <-0.3430851, 0.0255911, -0.9389556>,
    <-0.3377461, 0.0761970, -0.9381479>,
    <-0.5040197, 0.0853002, -0.8594696>,
    <-0.1716258, 0.0239243, -0.9848717>,
    <0.0000000, 0.0277732, -0.9996142>,
    <0.0000000, 0.0751492, -0.9971723>,
    <-0.1689141, 0.0728642, -0.9829338>,
    <0.1715571, 0.0370395, -0.9844776>,
    <0.3427370, 0.0517860, -0.9380030>,
    <0.3371542, 0.0963722, -0.9365038>,
    <0.1687802, 0.0829730, -0.9821551>,
    <0.5107441, 0.0720207, -0.8567108>,
    <0.6683110, 0.0972771, -0.7374941>,
    <0.6578733, 0.1392869, -0.7401364>,
    <0.5024891, 0.1153090, -0.8568597>,
    <0.8113513, 0.1275110, -0.5704822>,
    <0.9250035, 0.1608045, -0.3442534>,
    <0.9143236, 0.1994465, -0.3524676>,
    <0.7998606, 0.1681008, -0.5761641>,
    <0.9721686, 0.1862159, -0.1421684>,
    <0.9789768, 0.2020646, -0.0278256>,
    <0.9702210, 0.2393396, -0.0372516>,
    <0.9629209, 0.2234182, -0.1512202>,
    <-0.9594361, 0.2278340, -0.1660541>,
    <-0.9683958, 0.2446094, -0.0487422>,
    <-0.9073319, 0.2059868, -0.3664946>,
    <-0.8938530, 0.2417269, -0.3776174>,
    <-0.9484337, 0.2614377, -0.1792311>,
    <-0.9588589, 0.2771809, -0.0613217>,
    <-0.7902866, 0.1805600, -0.5855298>,
    <-0.6480550, 0.1587589, -0.7448626>,
    <-0.6351799, 0.1973798, -0.7467180>,
    <-0.7759213, 0.2182184, -0.5918842>,
    <-0.4939767, 0.1424214, -0.8577314>,
    <-0.3309941, 0.1316967, -0.9343976>,
    <-0.3241353, 0.1703999, -0.9305376>,
    <-0.4838321, 0.1813605, -0.8561629>,
    <-0.1655385, 0.1267648, -0.9780223>,
    <0.0000000, 0.1275492, -0.9918322>,
    <0.0000000, 0.1643063, -0.9864094>,
    <-0.1621144, 0.1647257, -0.9729257>,
    <0.1653800, 0.1339886, -0.9770857>,
    <0.3303196, 0.1460992, -0.9324934>,
    <0.3236266, 0.1791131, -0.9290771>,
    <0.1619928, 0.1690974, -0.9721957>,
    <0.4923227, 0.1638106, -0.8548593>,
    <0.6448492, 0.1866139, -0.7411780>,
    <0.6328839, 0.2142288, -0.7440188>,
    <0.4826149, 0.1942969, -0.8540091>,
    <0.7851368, 0.2141748, -0.5811105>,
    <0.9000303, 0.2438283, -0.3612384>,
    <0.8893267, 0.2647507, -0.3728338>,
    <0.7724815, 0.2385916, -0.5885120>,
    <0.9501410, 0.2665940, -0.1617395>,
    <0.9579796, 0.2827546, -0.0482180>,
    <0.9518755, 0.3003786, -0.0608751>,
    <0.9424541, 0.2850492, -0.1747201>,
    <-0.9453306, 0.2617317, -0.1945418>,
    <-0.9581997, 0.2759868, -0.0753961>,
    <-0.8869685, 0.2443927, -0.3918662>,
    <-0.8861498, 0.2194532, -0.4081407>,
    <-0.9489267, 0.2345459, -0.2110127>,
    <-0.9647466, 0.2472402, -0.0902010>,
    <-0.7665246, 0.2235408, -0.6020545>,
    <-0.6258888, 0.2048565, -0.7525271>,
    <-0.6206371, 0.1855294, -0.7618323>,
    <-0.7622193, 0.2014937, -0.6151601>,
    <-0.4761703, 0.1903729, -0.8584987>,
    <-0.3188353, 0.1802569, -0.9305114>,
    <-0.3155049, 0.1645544, -0.9345472>,
    <-0.4715096, 0.1732117, -0.8646828>,
    <-0.1594443, 0.1746858, -0.9716287>,
    <0.0000000, 0.1736244, -0.9848119>,
    <0.0000000, 0.1583678, -0.9873802>,
    <-0.1577442, 0.1596295, -0.9744923>,
    <0.1593764, 0.1770341, -0.9712148>,
    <0.3185533, 0.1849399, -0.9296887>,
    <0.3153872, 0.1667436, -0.9341988>,
    <0.1577158, 0.1607261, -0.9743166>,
    <0.4755030, 0.1973343, -0.8572958>,
    <0.6246443, 0.2139445, -0.7510308>,
    <0.6201217, 0.1898004, -0.7611996>,
    <0.4712324, 0.1764724, -0.8641745>,
    <0.7648783, 0.2345893, -0.5999409>,
    <0.8851522, 0.2569831, -0.3878985>,
    <0.8861265, 0.2255009, -0.4048816>,
    <0.7617793, 0.2067284, -0.6139672>,
    <0.9425260, 0.2747021, -0.1902197>,
    <0.9544591, 0.2887342, -0.0751018>,
    <0.9631532, 0.2534295, -0.0900520>,
    <0.9482358, 0.2408346, -0.2069967>,
    <-0.9516198, 0.2077720, -0.2263859>,
    <-0.9700596, 0.2193001, -0.1043638>,
    <-0.8850915, 0.1942084, -0.4229610>,
    <-0.8816496, 0.1831913, -0.4348965>,
    <-0.9508567, 0.1963653, -0.2393995>,
    <-0.9712762, 0.2074057, -0.1166425>,
    <-0.7584010, 0.1783125, -0.6269231>,
    <-0.6162425, 0.1643623, -0.7702144>,
    <-0.6113993, 0.1544667, -0.7760998>,
    <-0.7533889, 0.1678416, -0.6357943>,
    <-0.4677475, 0.1536739, -0.8704003>,
    <-0.3128803, 0.1461430, -0.9384818>,
    <-0.3103125, 0.1369788, -0.9407141>,
    <-0.4639074, 0.1442328, -0.8740634>,
    <-0.1564225, 0.1417622, -0.9774638>,
    <0.0000000, 0.1404355, -0.9900898>,
    <-0.0000000, 0.1311928, -0.9913569>,
    <-0.1551569, 0.1326676, -0.9789411>,
    <0.1564148, 0.1421144, -0.9774139>,
    <0.3128484, 0.1468451, -0.9383829>,
    <0.3103340, 0.1366431, -0.9407558>,
    <0.1551622, 0.1325023, -0.9789626>,
    <0.4676723, 0.1547178, -0.8702557>,
    <0.6161028, 0.1657266, -0.7700338>,
    <0.6114894, 0.1537650, -0.7761681>,
    <0.4639570, 0.1437181, -0.8741219>,
    <0.7585659, 0.1799991, -0.6262412>,
    <0.8859604, 0.1962063, -0.4202110>,
    <0.8830081, 0.1822035, -0.4325489>,
    <0.7539027, 0.1669670, -0.6354154>,
    <0.9520258, 0.2098803, -0.2227042>,
    <0.9696004, 0.2213494, -0.1043048>,
    <0.9715265, 0.2062541, -0.1165995>,
    <0.9519079, 0.1953155, -0.2360575>,
    <0.5221752, 0.8492034, 0.0786557>,
    <0.4404170, 0.8839970, 0.1567873>,
    <0.5746718, 0.7932189, 0.2013856>,
    <0.6436572, 0.7598547, 0.0912480>,
    <0.3914146, 0.8848585, 0.2526263>,
    <0.2971131, 0.9058314, 0.3019821>,
    <0.3875868, 0.8307141, 0.3996131>,
    <0.4841532, 0.8150885, 0.3181609>,
    <0.2359881, 0.8978922, 0.3716169>,
    <0.1499576, 0.9106046, 0.3851129>,
    <0.1960594, 0.8383840, 0.5085991>,
    <0.2925928, 0.8347856, 0.4663930>,
    <0.0793064, 0.8973476, 0.4341402>,
    <0.0000000, 0.9060322, 0.4232088>,
    <0.0000000, 0.8299901, 0.5577781>,
    <0.0976298, 0.8335504, 0.5437482>,
    <-0.0848962, 0.8873549, 0.4532040>,
    <-0.1636531, 0.8925123, 0.4202849>,
    <-0.2127620, 0.8062931, 0.5519273>,
    <-0.1061998, 0.8177294, 0.5657210>,
    <-0.2718284, 0.8641835, 0.4234339>,
    <-0.3557712, 0.8624237, 0.3600726>,
    <-0.4560594, 0.7555872, 0.4702104>,
    <-0.3358183, 0.7819698, 0.5251183>,
    <-0.4991853, 0.8103504, 0.3068327>,
    <-0.5946124, 0.7830137, 0.1825530>,
    <-0.7420499, 0.6310682, 0.2260862>,
    <-0.6025938, 0.7029474, 0.3778169>,
    <-0.7193185, 0.6908033, 0.0732922>,
    <-0.8356669, 0.5443308, 0.0732453>,
    <0.7504039, 0.6538251, 0.0969882>,
    <0.6823256, 0.6921842, 0.2351867>,
    <0.7802504, 0.5665136, 0.2650880>,
    <0.8468597, 0.5218302, 0.1025766>,
    <0.5753506, 0.7260449, 0.3766038>,
    <0.4656398, 0.7420034, 0.4822971>,
    <0.5415039, 0.6230301, 0.5644528>,
    <0.6668096, 0.6037567, 0.4368555>,
    <0.3511082, 0.7511641, 0.5589950>,
    <0.2363336, 0.7512686, 0.6162320>,
    <0.2758685, 0.6316363, 0.7245221>,
    <0.4110043, 0.6311773, 0.6577923>,
    <0.1184762, 0.7487069, 0.6522280>,
    <0.0000000, 0.7392142, 0.6734704>,
    <0.0000000, 0.6157644, 0.7879303>,
    <0.1389008, 0.6261733, 0.7672115>,
    <-0.1235986, 0.7275815, 0.6747952>,
    <-0.2530101, 0.7076449, 0.6597155>,
    <-0.2901200, 0.5790171, 0.7619512>,
    <-0.1424679, 0.6003907, 0.7869142>,
    <-0.3898046, 0.6823862, 0.6183862>,
    <-0.5314429, 0.6438701, 0.5504542>,
    <-0.5954373, 0.5101183, 0.6206720>,
    <-0.4426495, 0.5497051, 0.7084389>,
    <-0.6794333, 0.5900842, 0.4360861>,
    <-0.8246510, 0.5037823, 0.2572044>,
    <-0.8835626, 0.3742697, 0.2814947>,
    <-0.7472908, 0.4544090, 0.4848391>,
    <-0.9015250, 0.4247496, 0.0827072>,
    <-0.9485213, 0.3028760, 0.0925930>,
    <0.9112722, 0.3981322, 0.1052322>,
    <0.8505757, 0.4409374, 0.2865228>,
    <0.8944129, 0.3317645, 0.2999298>,
    <0.9497731, 0.2947809, 0.1050489>,
    <0.7341283, 0.4768258, 0.4834179>,
    <0.5991091, 0.4944453, 0.6297556>,
    <0.6353858, 0.3748754, 0.6750951>,
    <0.7768365, 0.3618138, 0.5153794>,
    <0.4556583, 0.5007073, 0.7359808>,
    <0.3057210, 0.4993153, 0.8106904>,
    <0.3237225, 0.3737825, 0.8691895>,
    <0.4832605, 0.3776019, 0.7898583>,
    <0.1535910, 0.4923169, 0.8567578>,
    <0.0000000, 0.4809278, 0.8767602>,
    <0.0000000, 0.3545746, 0.9350277>,
    <0.1622143, 0.3656583, 0.9165045>,
    <-0.1561883, 0.4653333, 0.8712463>,
    <-0.3160411, 0.4447239, 0.8380565>,
    <-0.3302106, 0.3238579, 0.8866098>,
    <-0.1638471, 0.3408496, 0.9257298>,
    <-0.4783288, 0.4174848, 0.7725983>,
    <-0.6370584, 0.3817469, 0.6696461>,
    <-0.6590862, 0.2742588, 0.7002767>,
    <-0.4974927, 0.3022200, 0.8131200>,
    <-0.7890029, 0.3329133, 0.5163751>,
    <-0.9173920, 0.2652392, 0.2967155>,
    <-0.9343501, 0.1833590, 0.3055640>,
    <-0.8106545, 0.2361396, 0.5357960>,
    <-0.9736476, 0.2059696, 0.0979130>,
    <-0.9855819, 0.1365465, 0.0999166>,
    <0.9683709, 0.2275674, 0.1023270>,
    <0.9163590, 0.2574472, 0.3066059>,
    <0.9229760, 0.2300196, 0.3085553>,
    <0.9735987, 0.2064144, 0.0974615>,
    <0.7976163, 0.2796216, 0.5344342>,
    <0.6518803, 0.2866352, 0.7020629>,
    <0.6536402, 0.2453020, 0.7159480>,
    <0.8023779, 0.2444952, 0.5444372>,
    <0.4947917, 0.2850016, 0.8209478>,
    <0.3305596, 0.2785645, 0.9017384>,
    <0.3290956, 0.2301748, 0.9158142>,
    <0.4943041, 0.2392022, 0.8357307>,
    <0.1651927, 0.2696989, 0.9486695>,
    <0.0000000, 0.2597790, 0.9656681>,
    <0.0000000, 0.2122084, 0.9772244>,
    <0.1640209, 0.2207225, 0.9614462>,
    <-0.1661390, 0.2491649, 0.9541041>,
    <-0.3343500, 0.2373253, 0.9120783>,
    <-0.3314416, 0.1985713, 0.9223426>,
    <-0.1645973, 0.2049887, 0.9648250>,
    <-0.5032044, 0.2229741, 0.8349059>,
    <-0.6660717, 0.2043578, 0.7173467>,
    <-0.6629423, 0.1822984, 0.7261369>,
    <-0.4996441, 0.1916709, 0.8447592>,
    <-0.8180286, 0.1779268, 0.5469655>,
    <-0.9403778, 0.1394036, 0.3102518>,
    <-0.9395630, 0.1404322, 0.3122502>,
    <-0.8161195, 0.1668271, 0.5532791>,
    <-0.9896602, 0.1033631, 0.0994425>,
    <-0.9889076, 0.1126310, 0.0968302>,
    <0.9716600, 0.2181856, 0.0909503>,
    <0.9213160, 0.2373481, 0.3079654>,
    <0.9127332, 0.2716883, 0.3051288>,
    <0.9632988, 0.2553463, 0.0827873>,
    <0.7983661, 0.2451631, 0.5500060>,
    <0.6472937, 0.2399131, 0.7235002>,
    <0.6352482, 0.2609771, 0.7268774>,
    <0.7876667, 0.2731134, 0.5522592>,
    <0.4872352, 0.2291598, 0.8426670>,
    <0.3231326, 0.2172168, 0.9210875>,
    <0.3143441, 0.2284079, 0.9214215>,
    <0.4758307, 0.2444132, 0.8448949>,
    <0.1606240, 0.2067920, 0.9651098>,
    <0.0000000, 0.1992640, 0.9799458>,
    <0.0000000, 0.2088182, 0.9779545>,
    <0.1558664, 0.2160524, 0.9638605>,
    <-0.1610215, 0.1949849, 0.9674983>,
    <-0.3247816, 0.1934781, 0.9257879>,
    <-0.3156554, 0.2103470, 0.9252653>,
    <-0.1561767, 0.2070750, 0.9657789>,
    <-0.4911043, 0.1934080, 0.8493585>,
    <-0.6543025, 0.1924540, 0.7313342>,
    <-0.6412097, 0.2248025, 0.7336988>,
    <-0.4790000, 0.2171882, 0.8505224>,
    <-0.8090262, 0.1866131, 0.5573618>,
    <-0.9346129, 0.1699115, 0.3124560>,
    <-0.9246911, 0.2202592, 0.3105355>,
    <-0.7969725, 0.2284474, 0.5591482>,
    <-0.9847216, 0.1477080, 0.0922265>,
    <-0.9757220, 0.2016313, 0.0855072>,
    <0.9514791, 0.2988603, 0.0732806>,
    <0.9008873, 0.3126129, 0.3011233>,
    <0.8964526, 0.3267171, 0.2993804>,
    <0.9467487, 0.3156712, 0.0633919>,
    <0.7740407, 0.3075541, 0.5534180>,
    <0.6207273, 0.2883544, 0.7290743>,
    <0.6098577, 0.2927707, 0.7364502>,
    <0.7661829, 0.3166129, 0.5592137>,
    <0.4625235, 0.2658936, 0.8457970>,
    <0.3043028, 0.2458103, 0.9203136>,
    <0.2953287, 0.2452300, 0.9233868>,
    <0.4512840, 0.2670696, 0.8514791>,
    <0.1504975, 0.2315120, 0.9611205>,
    <0.0000000, 0.2245089, 0.9744720>,
    <0.0000000, 0.2242365, 0.9745348>,
    <0.1455763, 0.2305167, 0.9621173>,
    <-0.1507275, 0.2251715, 0.9625897>,
    <-0.3052907, 0.2330492, 0.9233015>,
    <-0.2959140, 0.2375044, 0.9252170>,
    <-0.1457108, 0.2266863, 0.9630066>,
    <-0.4649716, 0.2466496, 0.8502737>,
    <-0.6254801, 0.2627821, 0.7346566>,
    <-0.6128134, 0.2771841, 0.7400194>,
    <-0.4527652, 0.2553819, 0.8542738>,
    <-0.7815919, 0.2759814, 0.5594179>,
    <-0.9107922, 0.2763161, 0.3067685>,
    <-0.9025754, 0.3045246, 0.3043394>,
    <-0.7708596, 0.2972971, 0.5633737>,
    <-0.9622648, 0.2610370, 0.0768517>,
    <-0.9538377, 0.2926873, 0.0672884>,
    <0.9515513, 0.3028200, 0.0533875>,
    <0.9014185, 0.3117226, 0.3004558>,
    <0.9128663, 0.2732855, 0.3032988>,
    <0.9629611, 0.2661113, 0.0434815>,
    <0.7652960, 0.2987305, 0.5701598>,
    <0.6033897, 0.2731269, 0.7492146>,
    <0.6001883, 0.2342465, 0.7647893>,
    <0.7692339, 0.2592411, 0.5840148>,
    <0.4426827, 0.2470172, 0.8619829>,
    <0.2878569, 0.2256800, 0.9307024>,
    <0.2818718, 0.1905467, 0.9403405>,
    <0.4363353, 0.2098507, 0.8749709>,
    <0.1413497, 0.2118637, 0.9670233>,
    <0.0000000, 0.2065129, 0.9784439>,
    <0.0000000, 0.1740294, 0.9847405>,
    <0.1378802, 0.1784160, 0.9742468>,
    <-0.1414138, 0.2098101, 0.9674616>,
    <-0.2881389, 0.2215210, 0.9316139>,
    <-0.2819793, 0.1886073, 0.9406992>,
    <-0.1379043, 0.1774632, 0.9744174>,
    <-0.4434103, 0.2406828, 0.8633997>,
    <-0.6048815, 0.2646072, 0.7510668>,
    <-0.6007858, 0.2301926, 0.7655507>,
    <-0.4366186, 0.2068714, 0.8755389>,
    <-0.7675271, 0.2880614, 0.5726454>,
    <-0.9041893, 0.2994208, 0.3046127>,
    <-0.9134599, 0.2672778, 0.3068447>,
    <-0.7699181, 0.2540773, 0.5853810>,
    <-0.9552451, 0.2901950, 0.0573902>,
    <-0.9644371, 0.2600135, 0.0474765>,
    <0.9719422, 0.2327872, 0.0337403>,
    <0.9219787, 0.2385307, 0.3050549>,
    <0.9261569, 0.2211364, 0.3055031>,
    <0.9758964, 0.2167841, 0.0251155>,
    <0.7715322, 0.2239963, 0.5954525>,
    <0.5963360, 0.2000388, 0.7774110>,
    <0.5911637, 0.1813514, 0.7858989>,
    <0.7706086, 0.2054172, 0.6032961>,
    <0.4300951, 0.1774951, 0.8851631>,
    <0.2762949, 0.1601268, 0.9476394>,
    <0.2710592, 0.1429756, 0.9518849>,
    <0.4237365, 0.1594521, 0.8916403>,
    <0.1347217, 0.1494697, 0.9795452>,
    <0.0000000, 0.1458221, 0.9893108>,
    <0.0000000, 0.1298744, 0.9915305>,
    <0.1318539, 0.1330799, 0.9822954>,
    <-0.1347276, 0.1491908, 0.9795869>,
    <-0.2763215, 0.1595556, 0.9477280>,
    <-0.2710454, 0.1434616, 0.9518157>,
    <-0.1318509, 0.1333193, 0.9822634>,
    <-0.4301665, 0.1766082, 0.8853058>,
    <-0.5964905, 0.1988139, 0.7776066>,
    <-0.5910733, 0.1823566, 0.7857343>,
    <-0.4236972, 0.1601956, 0.8915257>,
    <-0.7714300, 0.2223791, 0.5961906>,
    <-0.9214454, 0.2366020, 0.3081524>,
    <-0.9249646, 0.2224755, 0.3081316>,
    <-0.7700607, 0.2066303, 0.6035814>,
    <-0.9722604, 0.2308608, 0.0375908>,
    <-0.9754943, 0.2181510, 0.0286543>,
    <-0.9497987, 0.1875585, -0.2504080>,
    <-0.9719689, 0.1979871, -0.1267977>,
    <-0.8783265, 0.1747478, -0.4449785>,
    <-0.8764225, 0.1605689, -0.4539838>,
    <-0.9502040, 0.1719281, -0.2599096>,
    <-0.9741665, 0.1808570, -0.1352418>,
    <-0.7488461, 0.1597020, -0.6432145>,
    <-0.6071056, 0.1465591, -0.7809887>,
    <-0.6037259, 0.1345886, -0.7857487>,
    <-0.7455227, 0.1468137, -0.6501089>,
    <-0.4605396, 0.1364360, -0.8770909>,
    <-0.3080741, 0.1291756, -0.9425519>,
    <-0.3061960, 0.1180019, -0.9446267>,
    <-0.4577842, 0.1250090, -0.8802308>,
    <-0.1540573, 0.1247560, -0.9801542>,
    <-0.0000000, 0.1230829, -0.9923964>,
    <-0.0000000, 0.1118037, -0.9937303>,
    <-0.1531211, 0.1136156, -0.9816544>,
    <0.1540756, 0.1241069, -0.9802337>,
    <0.3081487, 0.1278664, -0.9427060>,
    <0.3063222, 0.1158145, -0.9448564>,
    <0.1531522, 0.1125310, -0.9817745>,
    <0.4607113, 0.1344512, -0.8773072>,
    <0.6074164, 0.1438920, -0.7812429>,
    <0.6042408, 0.1301316, -0.7861036>,
    <0.4580723, 0.1216930, -0.8805456>,
    <0.7496811, 0.1563602, -0.6430628>,
    <0.8801090, 0.1708278, -0.4429741>,
    <0.8785392, 0.1539021, -0.4521980>,
    <0.7466370, 0.1412030, -0.6500730>,
    <0.9514195, 0.1833299, -0.2473684>,
    <0.9728780, 0.1935456, -0.1266830>,
    <0.9755987, 0.1732068, -0.1349315>,
    <0.9522666, 0.1646499, -0.2570578>,
    <-0.9516248, 0.1505210, -0.2678689>,
    <-0.9772140, 0.1576563, -0.1421174>,
    <-0.8756562, 0.1410288, -0.4618843>,
    <-0.8758245, 0.1146339, -0.4688182>,
    <-0.9537814, 0.1223483, -0.2744667>,
    <-0.9807479, 0.1278259, -0.1476285>,
    <-0.7432046, 0.1290091, -0.6565086>,
    <-0.6010756, 0.1180556, -0.7904246>,
    <-0.5990706, 0.0948493, -0.7950585>,
    <-0.7417535, 0.1044098, -0.6624956>,
    <-0.4554835, 0.1092828, -0.8835112>,
    <-0.3045605, 0.1027240, -0.9469375>,
    <-0.3031475, 0.0810510, -0.9494906>,
    <-0.4535928, 0.0870231, -0.8869501>,
    <-0.1522848, 0.0985058, -0.9834154>,
    <-0.0000000, 0.0966354, -0.9953199>,
    <-0.0000000, 0.0752473, -0.9971649>,
    <-0.1515415, 0.0771109, -0.9854385>,
    <0.1523274, 0.0970940, -0.9835492>,
    <0.3047313, 0.0998757, -0.9471872>,
    <0.3033529, 0.0777061, -0.9497046>,
    <0.1515930, 0.0754535, -0.9855589>,
    <0.4558684, 0.1049616, -0.8838365>,
    <0.6017515, 0.1122399, -0.7907574>,
    <0.5998566, 0.0880076, -0.7952526>,
    <0.4540494, 0.0819452, -0.8872002>,
    <0.7445130, 0.1216599, -0.6564292>,
    <0.8779495, 0.1322242, -0.4601319>,
    <0.8781349, 0.1041952, -0.4669287>,
    <0.7431635, 0.0957411, -0.6622248>,
    <0.9539006, 0.1408257, -0.2650316>,
    <0.9789040, 0.1474329, -0.1414586>,
    <0.9824310, 0.1156270, -0.1464912>,
    <0.9560434, 0.1107986, -0.2714861>,
    <-0.9550764, 0.0985148, -0.2795067>,
    <-0.9830881, 0.1025161, -0.1517509>,
    <-0.8755140, 0.0924021, -0.4742753>,
    <-0.8741639, 0.0854429, -0.4780555>,
    <-0.9548833, 0.0902944, -0.2829218>,
    <-0.9835986, 0.0931031, -0.1544847>,
    <-0.7400762, 0.0837985, -0.6672818>,
    <-0.5969267, 0.0754939, -0.7987360>,
    <-0.5943552, 0.0704827, -0.8011080>,
    <-0.7377495, 0.0779716, -0.6705566>,
    <-0.4515869, 0.0685302, -0.8895914>,
    <-0.3016426, 0.0631055, -0.9513303>,
    <-0.2999480, 0.0589493, -0.9521324>,
    <-0.4492864, 0.0640520, -0.8910887>,
    <-0.1507459, 0.0594414, -0.9867839>,
    <-0.0000000, 0.0576139, -0.9983389>,
    <-0.0000000, 0.0536474, -0.9985599>,
    <-0.1498565, 0.0554450, -0.9871519>,
    <0.1508062, 0.0576264, -0.9868823>,
    <0.3018815, 0.0594413, -0.9514906>,
    <0.3002323, 0.0551628, -0.9522697>,
    <0.1499286, 0.0535702, -0.9872445>,
    <0.4521114, 0.0629638, -0.8897364>,
    <0.5978130, 0.0679861, -0.7987475>,
    <0.5953902, 0.0627105, -0.8009856>,
    <0.4499062, 0.0582958, -0.8911712>,
    <0.7415657, 0.0742658, -0.6667570>,
    <0.8777924, 0.0808805, -0.4721640>,
    <0.8765135, 0.0734557, -0.4757399>,
    <0.7393943, 0.0680849, -0.6698212>,
    <0.9572419, 0.0857239, -0.2762956>,
    <0.9846640, 0.0889882, -0.1500597>,
    <0.9851870, 0.0789600, -0.1522231>,
    <0.9570660, 0.0769442, -0.2794713>,
    <-0.9550340, 0.0807777, -0.2852805>,
    <-0.9842876, 0.0823977, -0.1561683>,
    <-0.8733114, 0.0772195, -0.4810035>,
    <-0.8738020, 0.0514578, -0.4835515>,
    <-0.9564916, 0.0532793, -0.2868537>,
    <-0.9861619, 0.0534120, -0.1569453>,
    <-0.7359225, 0.0709736, -0.6733356>,
    <-0.5921790, 0.0644132, -0.8032279>,
    <-0.5908702, 0.0421976, -0.8056623>,
    <-0.7352459, 0.0471503, -0.6761586>,
    <-0.4472556, 0.0586268, -0.8924827>,
    <-0.2984128, 0.0539470, -0.9529111>,
    <-0.2972367, 0.0337723, -0.9542064>,
    <-0.4458186, 0.0376069, -0.8943330>,
    <-0.1490392, 0.0506840, -0.9875315>,
    <-0.0000000, 0.0489734, -0.9988001>,
    <-0.0000000, 0.0295219, -0.9995641>,
    <-0.1483881, 0.0310252, -0.9884424>,
    <0.1491221, 0.0488385, -0.9876120>,
    <0.2987386, 0.0502181, -0.9530128>,
    <0.2975844, 0.0302714, -0.9542155>,
    <0.1484770, 0.0292938, -0.9884819>,
    <0.4479613, 0.0529533, -0.8924834>,
    <0.5933453, 0.0567433, -0.8029455>,
    <0.5920850, 0.0349777, -0.8051161>,
    <0.4465650, 0.0322745, -0.8941689>,
    <0.7376952, 0.0611983, -0.6723545>,
    <0.8756898, 0.0653330, -0.4784339>,
    <0.8760146, 0.0402183, -0.4806048>,
    <0.7370139, 0.0379294, -0.6748124>,
    <0.9571717, 0.0675034, -0.2815415>,
    <0.9858136, 0.0683138, -0.1533129>,
    <0.9873425, 0.0400610, -0.1534600>,
    <0.9583347, 0.0407065, -0.2827325>,
    <-0.9577396, 0.0167227, -0.2871500>,
    <-0.9875594, 0.0151834, -0.1565117>,
    <-0.8743729, 0.0169297, -0.4849593>,
    <-0.8744524, -0.0174523, -0.4847972>,
    <-0.9580680, -0.0197843, -0.2858570>,
    <-0.9877004, -0.0230364, -0.1546522>,
    <-0.7347926, 0.0150242, -0.6781255>,
    <-0.5897788, 0.0121190, -0.8074739>,
    <-0.5886521, -0.0174796, -0.8081975>,
    <-0.7341718, -0.0167910, -0.6787561>,
    <-0.4445407, 0.0090818, -0.8957126>,
    <-0.2961574, 0.0063678, -0.9551179>,
    <-0.2950892, -0.0202904, -0.9552542>,
    <-0.4432669, -0.0188165, -0.8961922>,
    <-0.1477810, 0.0043213, -0.9890107>,
    <-0.0000000, 0.0031166, -0.9999951>,
    <-0.0000000, -0.0223932, -0.9997492>,
    <-0.1471808, -0.0215470, -0.9888749>,
    <0.1478740, 0.0027939, -0.9890023>,
    <0.2965196, 0.0032771, -0.9550212>,
    <0.2954695, -0.0227849, -0.9550804>,
    <0.1472788, -0.0227787, -0.9888327>,
    <0.4453109, 0.0043682, -0.8953653>,
    <0.5910123, 0.0057266, -0.8066422>,
    <0.5899250, -0.0226549, -0.8071402>,
    <0.4440708, -0.0226261, -0.8957060>,
    <0.7365124, 0.0068442, -0.6763895>,
    <0.8763620, 0.0069420, -0.4816031>,
    <0.8762981, -0.0255604, -0.4810908>,
    <0.7358860, -0.0234252, -0.6767001>,
    <0.9592149, 0.0055432, -0.2826235>,
    <0.9883109, 0.0033077, -0.1524156>,
    <0.9881424, -0.0326765, -0.1500229>,
    <0.9592817, -0.0288585, -0.2809731>,
    <-0.9575223, -0.0561399, -0.2828416>,
    <-0.9866054, -0.0611254, -0.1512395>,
    <-0.8741275, -0.0516151, -0.4829461>,
    <-0.8735062, -0.0854926, -0.4792472>,
    <-0.9561621, -0.0922441, -0.2779299>,
    <-0.9843061, -0.0989612, -0.1461101>,
    <-0.7334966, -0.0482463, -0.6779787>,
    <-0.5876001, -0.0465605, -0.8078108>,
    <-0.5867554, -0.0750975, -0.8062744>,
    <-0.7329055, -0.0793040, -0.6756926>,
    <-0.4420881, -0.0460560, -0.8957885>,
    <-0.2940958, -0.0461745, -0.9546599>,
    <-0.2932514, -0.0712662, -0.9533754>,
    <-0.4411119, -0.0726154, -0.8945095>,
    <-0.1466202, -0.0465549, -0.9880967>,
    <-0.0000000, -0.0469847, -0.9988956>,
    <-0.0000000, -0.0706434, -0.9975016>,
    <-0.1461368, -0.0706862, -0.9867358>,
    <0.1467244, -0.0474021, -0.9880410>,
    <0.2944999, -0.0478926, -0.9544507>,
    <0.2936862, -0.0720331, -0.9531840>,
    <0.1462487, -0.0710631, -0.9866921>,
    <0.4429405, -0.0486847, -0.8952282>,
    <0.5889441, -0.0501396, -0.8066169>,
    <0.5882113, -0.0767127, -0.8050606>,
    <0.4420316, -0.0737948, -0.8939588>,
    <0.7352713, -0.0528434, -0.6757098>,
    <0.8759541, -0.0572343, -0.4789870>,
    <0.8754791, -0.0880377, -0.4751692>,
    <0.7348270, -0.0813886, -0.6733537>,
    <0.9586432, -0.0624206, -0.2776814>,
    <0.9869302, -0.0677982, -0.1461922>,
    <0.9847724, -0.1019768, -0.1407976>,
    <0.9574166, -0.0950773, -0.2726055>,
    <-0.9526549, -0.1388479, -0.2704994>,
    <-0.9792024, -0.1479540, -0.1388248>,
    <-0.8716073, -0.1291405, -0.4728883>,
    <-0.8605537, -0.2201310, -0.4593361>,
    <-0.9370565, -0.2357858, -0.2575464>,
    <-0.9598334, -0.2498571, -0.1276376>,
    <-0.7317700, -0.1193027, -0.6710287>,
    <-0.5857180, -0.1118715, -0.8027572>,
    <-0.5807139, -0.1894374, -0.7917606>,
    <-0.7245579, -0.2031302, -0.6586000>,
    <-0.4400832, -0.1068962, -0.8915716>,
    <-0.2924038, -0.1037236, -0.9506532>,
    <-0.2900309, -0.1730913, -0.9412340>,
    <-0.4364963, -0.1796927, -0.8815790>,
    <-0.1456591, -0.1019640, -0.9840664>,
    <-0.0000000, -0.1013456, -0.9948513>,
    <-0.0000000, -0.1675004, -0.9858720>,
    <-0.1444704, -0.1691528, -0.9749439>,
    <0.1457807, -0.1017721, -0.9840683>,
    <0.2928781, -0.1033395, -0.9505490>,
    <0.2906087, -0.1707395, -0.9414853>,
    <0.1446168, -0.1679877, -0.9751236>,
    <0.4410942, -0.1063202, -0.8911408>,
    <0.5873393, -0.1111065, -0.8016782>,
    <0.5828079, -0.1846244, -0.7913588>,
    <0.4377553, -0.1761214, -0.8816754>,
    <0.7339524, -0.1183419, -0.6688116>,
    <0.8739457, -0.1279652, -0.4688750>,
    <0.8641793, -0.2127313, -0.4560038>,
    <0.7275558, -0.1970232, -0.6571487>,
    <0.9543451, -0.1375215, -0.2651664>,
    <0.9801568, -0.1465721, -0.1334513>,
    <0.9626755, -0.2412804, -0.1226360>,
    <0.9404043, -0.2275782, -0.2526813>,
    <-0.8953520, -0.3778680, -0.2357129>,
    <-0.9110157, -0.3971414, -0.1110363>,
    <-0.8281190, -0.3565740, -0.4325203>,
    <-0.8271602, -0.3711097, -0.4219995>,
    <-0.8938203, -0.3885956, -0.2237829>,
    <-0.9081368, -0.4067673, -0.0991361>,
    <-0.7016407, -0.3327368, -0.6300686>,
    <-0.5645069, -0.3129208, -0.7638145>,
    <-0.5616075, -0.3384982, -0.7549940>,
    <-0.6998380, -0.3528997, -0.6210383>,
    <-0.4251674, -0.2985533, -0.8544581>,
    <-0.2828034, -0.2886426, -0.9147173>,
    <-0.2799468, -0.3224870, -0.9042300>,
    <-0.4218216, -0.3288143, -0.8449542>,
    <-0.1409505, -0.2825356, -0.9488449>,
    <0.0000000, -0.2796868, -0.9600913>,
    <0.0000000, -0.3162311, -0.9486822>,
    <-0.1393305, -0.3185291, -0.9376173>,
    <0.1411746, -0.2798734, -0.9496002>,
    <0.2837039, -0.2832721, -0.9161163>,
    <0.2809850, -0.3159703, -0.9062065>,
    <0.1395880, -0.3153111, -0.9386661>,
    <0.4271938, -0.2904124, -0.8562512>,
    <0.5680526, -0.3019956, -0.7655814>,
    <0.5657542, -0.3250655, -0.7577959>,
    <0.4241714, -0.3188772, -0.8475824>,
    <0.7071096, -0.3189984, -0.6310595>,
    <0.8355745, -0.3401920, -0.4313753>,
    <0.8361734, -0.3507089, -0.4216838>,
    <0.7063252, -0.3358835, -0.6231267>,
    <0.9035473, -0.3600207, -0.2323518>,
    <0.9192651, -0.3787787, -0.1071373>,
    <0.9183881, -0.3839198, -0.0957542>,
    <0.9038780, -0.3663492, -0.2208910>,
    <0.9790240, 0.2029050, 0.0184828>,
    <0.9293989, 0.2056172, 0.3064950>,
    <0.9336465, 0.1819326, 0.3085527>,
    <0.9834256, 0.1807992, 0.0136291>,
    <0.7695094, 0.1887388, 0.6101089>,
    <0.5866561, 0.1646926, 0.7929130>,
    <0.5833119, 0.1428181, 0.7995938>,
    <0.7694219, 0.1652145, 0.6170042>,
    <0.4184163, 0.1435052, 0.8968467>,
    <0.2667631, 0.1279231, 0.9552346>,
    <0.2633520, 0.1099000, 0.9584194>,
    <0.4142360, 0.1236707, 0.9017284>,
    <0.1295236, 0.1187684, 0.9844377>,
    <0.0000000, 0.1159978, 0.9932495>,
    <0.0000000, 0.0998227, 0.9950052>,
    <0.1276707, 0.1020031, 0.9865574>,
    <-0.1295156, 0.1195380, 0.9843457>,
    <-0.2667248, 0.1294938, 0.9550336>,
    <-0.2633103, 0.1124905, 0.9581302>,
    <-0.1276624, 0.1032693, 0.9864268>,
    <-0.4183047, 0.1459305, 0.8965074>,
    <-0.5863899, 0.1680151, 0.7924126>,
    <-0.5829765, 0.1483546, 0.7988300>,
    <-0.4141055, 0.1276872, 0.9012284>,
    <-0.7686186, 0.1929174, 0.6099248>,
    <-0.9276522, 0.2103936, 0.3085385>,
    <-0.9315596, 0.1900777, 0.3099470>,
    <-0.7683656, 0.1722646, 0.6163921>,
    <-0.9779539, 0.2077053, 0.0215570>,
    <-0.9818517, 0.1889652, 0.0161048>,
    <0.9881598, 0.1530903, 0.0101805>,
    <0.9379969, 0.1527744, 0.3111620>,
    <0.9421015, 0.1174603, 0.3140825>,
    <0.9928202, 0.1193565, 0.0078848>,
    <0.7696819, 0.1370612, 0.6235416>,
    <0.5806580, 0.1172262, 0.8056639>,
    <0.5785151, 0.0861041, 0.8111143>,
    <0.7700598, 0.1030303, 0.6295972>,
    <0.4108461, 0.1007531, 0.9061205>,
    <0.2605871, 0.0891626, 0.9613243>,
    <0.2583464, 0.0631037, 0.9639891>,
    <0.4080888, 0.0724763, 0.9100608>,
    <0.1261727, 0.0826880, 0.9885561>,
    <0.0000000, 0.0811076, 0.9967053>,
    <0.0000000, 0.0569934, 0.9983746>,
    <0.1249632, 0.0580234, 0.9904633>,
    <-0.1261699, 0.0843312, 0.9884176>,
    <-0.2605675, 0.0925306, 0.9610113>,
    <-0.2583716, 0.0670301, 0.9637173>,
    <-0.1249710, 0.0599359, 0.9903484>,
    <-0.4107640, 0.1059931, 0.9055597>,
    <-0.5803955, 0.1244873, 0.8047633>,
    <-0.5784525, 0.0946371, 0.8102077>,
    <-0.4081145, 0.0786043, 0.9095405>,
    <-0.7687154, 0.1463883, 0.6226132>,
    <-0.9359181, 0.1636325, 0.3119002>,
    <-0.9403620, 0.1304037, 0.3141882>,
    <-0.7694172, 0.1140747, 0.6284777>,
    <-0.9863937, 0.1639667, 0.0119357>,
    <-0.9911682, 0.1323162, 0.0088306>,
    <0.9958263, 0.0910344, 0.0065390>,
    <0.9444392, 0.0878605, 0.3167257>,
    <0.9447099, 0.0761953, 0.3189318>,
    <0.9967866, 0.0798750, 0.0060445>,
    <0.7694410, 0.0747909, 0.6343239>,
    <0.5761394, 0.0605601, 0.8151048>,
    <0.5734511, 0.0518057, 0.8176002>,
    <0.7676802, 0.0642412, 0.6376051>,
    <0.4054731, 0.0494623, 0.9127678>,
    <0.2563278, 0.0420122, 0.9656765>,
    <0.2544852, 0.0361679, 0.9664001>,
    <0.4029380, 0.0423624, 0.9142463>,
    <0.1238972, 0.0381150, 0.9915628>,
    <0.0000000, 0.0375306, 0.9992955>,
    <0.0000000, 0.0327353, 0.9994641>,
    <0.1229488, 0.0330412, 0.9918628>,
    <-0.1239170, 0.0401960, 0.9914781>,
    <-0.2564043, 0.0462895, 0.9654606>,
    <-0.2546018, 0.0405928, 0.9661937>,
    <-0.1229780, 0.0351926, 0.9917852>,
    <-0.4056251, 0.0561527, 0.9123131>,
    <-0.5763202, 0.0699098, 0.8142283>,
    <-0.5738222, 0.0615098, 0.8166668>,
    <-0.4031890, 0.0492923, 0.9137882>,
    <-0.7692114, 0.0869612, 0.6330495>,
    <-0.9431746, 0.1022020, 0.3161904>,
    <-0.9438000, 0.0911834, 0.3176904>,
    <-0.7677751, 0.0769148, 0.6360861>,
    <-0.9944081, 0.1053983, 0.0066165>,
    <-0.9954736, 0.0948944, 0.0052237>,
    <0.9976538, 0.0681657, 0.0063584>,
    <0.9448096, 0.0641769, 0.3212725>,
    <0.9454734, 0.0337342, 0.3239476>,
    <0.9992344, 0.0384038, 0.0074662>,
    <0.7661006, 0.0536482, 0.6404777>,
    <0.5712165, 0.0432214, 0.8196607>,
    <0.5697202, 0.0185678, 0.8216289>,
    <0.7651977, 0.0255978, 0.6432863>,
    <0.4008969, 0.0355412, 0.9154335>,
    <0.2530268, 0.0306429, 0.9669739>,
    <0.2520330, 0.0108776, 0.9676575>,
    <0.3995053, 0.0137485, 0.9166278>,
    <0.1222050, 0.0282843, 0.9921018>,
    <0.0000000, 0.0282231, 0.9996016>,
    <0.0000000, 0.0099508, 0.9999505>,
    <0.1217005, 0.0096766, 0.9925197>,
    <-0.1222440, 0.0304083, 0.9920341>,
    <-0.2531853, 0.0350133, 0.9667840>,
    <-0.2522486, 0.0149815, 0.9675465>,
    <-0.1217527, 0.0116706, 0.9924919>,
    <-0.4012530, 0.0423916, 0.9149858>,
    <-0.5717948, 0.0528284, 0.8186940>,
    <-0.5705949, 0.0276054, 0.8207676>,
    <-0.4000066, 0.0201850, 0.9162900>,
    <-0.7665596, 0.0662275, 0.6387491>,
    <-0.9443273, 0.0790981, 0.3193578>,
    <-0.9457018, 0.0478609, 0.3214924>,
    <-0.7661958, 0.0374630, 0.6415143>,
    <-0.9965282, 0.0831264, 0.0046463>,
    <-0.9986044, 0.0525858, 0.0049018>,
    <0.9999561, -0.0000426, 0.0093665>,
    <0.9452083, -0.0053952, 0.3264233>,
    <0.9435143, -0.0432900, 0.3284917>,
    <0.9992193, -0.0376128, 0.0120882>,
    <0.7639835, -0.0104198, 0.6451517>,
    <0.5684034, -0.0132226, 0.8226438>,
    <0.5671862, -0.0431990, 0.8224559>,
    <0.7622156, -0.0448267, 0.6457693>,
    <0.3984565, -0.0145622, 0.9170716>,
    <0.2513433, -0.0150085, 0.9677816>,
    <0.2509653, -0.0389141, 0.9672136>,
    <0.3977385, -0.0409483, 0.9165846>,
    <0.1213657, -0.0148510, 0.9924968>,
    <0.0000000, -0.0142116, 0.9998990>,
    <0.0000000, -0.0364107, 0.9993369>,
    <0.1212074, -0.0373857, 0.9919229>,
    <-0.1214310, -0.0130916, 0.9925135>,
    <-0.2516164, -0.0113885, 0.9677600>,
    <-0.2512833, -0.0359928, 0.9672441>,
    <-0.1212832, -0.0359645, 0.9919662>,
    <-0.3991051, -0.0088861, 0.9168621>,
    <-0.5695808, -0.0052515, 0.8219186>,
    <-0.5685948, -0.0367861, 0.8217948>,
    <-0.3985008, -0.0363747, 0.9164464>,
    <-0.7655390, 0.0000618, 0.6433894>,
    <-0.9461982, 0.0071321, 0.3235089>,
    <-0.9450802, -0.0331759, 0.3251503>,
    <-0.7641939, -0.0363951, 0.6439590>,
    <-0.9999029, 0.0125658, 0.0060164>,
    <-0.9995924, -0.0273901, 0.0080533>,
    <0.9971208, -0.0741896, 0.0156867>,
    <0.9405425, -0.0798260, 0.3301631>,
    <0.9364495, -0.1149092, 0.3314487>,
    <0.9937617, -0.1096727, 0.0202399>,
    <0.7600922, -0.0775711, 0.6451687>,
    <0.5662542, -0.0713636, 0.8211355>,
    <0.5658131, -0.0977506, 0.8187187>,
    <0.7578206, -0.1086376, 0.6433551>,
    <0.3974983, -0.0654276, 0.9152674>,
    <0.2509980, -0.0608537, 0.9660729>,
    <0.2515617, -0.0808586, 0.9644577>,
    <0.3979078, -0.0880416, 0.9131911>,
    <0.1212750, -0.0579354, 0.9909268>,
    <0.0000000, -0.0566512, 0.9983940>,
    <-0.0000000, -0.0749485, 0.9971874>,
    <0.1216296, -0.0765199, 0.9896216>,
    <-0.1213574, -0.0569546, 0.9909735>,
    <-0.2513442, -0.0588422, 0.9661075>,
    <-0.2519161, -0.0799675, 0.9644395>,
    <-0.1217142, -0.0760821, 0.9896450>,
    <-0.3983298, -0.0622898, 0.9151248>,
    <-0.5677963, -0.0669822, 0.8204393>,
    <-0.5673671, -0.0958565, 0.8178668>,
    <-0.3987538, -0.0866675, 0.9129535>,
    <-0.7623024, -0.0718221, 0.6432237>,
    <-0.9424069, -0.0728949, 0.3264284>,
    <-0.9382530, -0.1118703, 0.3273626>,
    <-0.7600215, -0.1061645, 0.6411681>,
    <-0.9976825, -0.0671293, 0.0111051>,
    <-0.9941953, -0.1064989, 0.0152900>,
    <0.9874010, -0.1561198, 0.0258036>,
    <0.9295492, -0.1609766, 0.3317000>,
    <0.9086898, -0.2597298, 0.3268385>,
    <0.9664242, -0.2549408, 0.0320847>,
    <0.7543245, -0.1497108, 0.6392035>,
    <0.5653334, -0.1328179, 0.8140993>,
    <0.5606029, -0.2106960, 0.8008318>,
    <0.7420865, -0.2393462, 0.6261158>,
    <0.3987492, -0.1181287, 0.9094200>,
    <0.2525843, -0.1074265, 0.9615928>,
    <0.2530054, -0.1676662, 0.9528254>,
    <0.3978337, -0.1858085, 0.8984451>,
    <0.1222536, -0.1011344, 0.9873327>,
    <-0.0000000, -0.0991383, 0.9950737>,
    <-0.0000000, -0.1541072, 0.9880541>,
    <0.1227182, -0.1571277, 0.9799240>,
    <-0.1223346, -0.1013633, 0.9872992>,
    <-0.2529203, -0.1079077, 0.9614506>,
    <-0.2532299, -0.1705388, 0.9522558>,
    <-0.1227750, -0.1585257, 0.9796917>,
    <-0.3995376, -0.1189060, 0.9089726>,
    <-0.5667387, -0.1339378, 0.8129378>,
    <-0.5612958, -0.2169091, 0.7986849>,
    <-0.3983101, -0.1902902, 0.8972952>,
    <-0.7561998, -0.1511730, 0.6366386>,
    <-0.9308221, -0.1625849, 0.3273170>,
    <-0.9078038, -0.2688270, 0.3219073>,
    <-0.7425494, -0.2472886, 0.6224699>,
    <-0.9872857, -0.1575999, 0.0207163>,
    <-0.9641541, -0.2639487, 0.0271649>,
    <0.9169678, -0.3971226, 0.0382588>,
    <0.8605097, -0.4026686, 0.3120594>,
    <0.8560005, -0.4106286, 0.3140817>,
    <0.9142073, -0.4024849, 0.0472318>,
    <0.7107503, -0.3740775, 0.5957349>,
    <0.5447517, -0.3332114, 0.7695555>,
    <0.5443639, -0.3532177, 0.7608582>,
    <0.7079013, -0.3879717, 0.5902150>,
    <0.3910135, -0.2966174, 0.8712787>,
    <0.2505491, -0.2693892, 0.9298681>,
    <0.2518136, -0.2977078, 0.9208474>,
    <0.3920201, -0.3214891, 0.8619542>,
    <0.1220198, -0.2535348, 0.9595995>,
    <-0.0000000, -0.2493440, 0.9684150>,
    <-0.0000000, -0.2807396, 0.9597840>,
    <0.1228083, -0.2839808, 0.9509327>,
    <-0.1219918, -0.2568211, 0.9587288>,
    <-0.2503932, -0.2760532, 0.9279536>,
    <-0.2514414, -0.3059191, 0.9182542>,
    <-0.1227294, -0.2880429, 0.9497204>,
    <-0.3904751, -0.3067776, 0.8679958>,
    <-0.5432699, -0.3468433, 0.7645636>,
    <-0.5418658, -0.3698551, 0.7547110>,
    <-0.3909526, -0.3339492, 0.8576911>,
    <-0.7072065, -0.3908636, 0.5891389>,
    <-0.8537665, -0.4214965, 0.3056525>,
    <-0.8469796, -0.4337067, 0.3074475>,
    <-0.7026732, -0.4084195, 0.5826181>,
    <-0.9087153, -0.4160484, 0.0337682>,
    <-0.9037238, -0.4259266, 0.0432411>,
    <-0.9253376, -0.3086539, -0.2201890>,
    <-0.9421967, -0.3226699, -0.0902747>,
    <-0.8526129, -0.3013410, -0.4269015>,
    <-0.8733460, -0.2169506, -0.4361184>,
    <-0.9537281, -0.2068892, -0.2181731>,
    <-0.9732051, -0.2152631, -0.0808307>,
    <-0.7155834, -0.2984203, -0.6315740>,
    <-0.5693200, -0.2988480, -0.7658750>,
    <-0.5679529, -0.2679444, -0.7782257>,
    <-0.7237838, -0.2413372, -0.6464468>,
    <-0.4244155, -0.3016102, -0.8537580>,
    <-0.2800584, -0.3046406, -0.9103633>,
    <-0.2732913, -0.3108352, -0.9103259>,
    <-0.4181908, -0.2921318, -0.8601020>,
    <-0.1388895, -0.3064466, -0.9417007>,
    <0.0000000, -0.3061612, -0.9519797>,
    <0.0000000, -0.3250646, -0.9456918>,
    <-0.1347097, -0.3220907, -0.9370757>,
    <0.1391163, -0.3034614, -0.9426335>,
    <0.2809689, -0.2985442, -0.9121008>,
    <0.2740807, -0.3054218, -0.9119196>,
    <0.1349075, -0.3194766, -0.9379417>,
    <0.4264590, -0.2921875, -0.8560135>,
    <0.5728773, -0.2858838, -0.7681680>,
    <0.5709124, -0.2558638, -0.7801235>,
    <0.4199385, -0.2835815, -0.8621097>,
    <0.7210905, -0.2816522, -0.6330091>,
    <0.8601435, -0.2808222, -0.4257841>,
    <0.8790996, -0.1967546, -0.4341330>,
    <0.7282172, -0.2252503, -0.6472728>,
    <0.9334061, -0.2860222, -0.2166665>,
    <0.9501983, -0.2992830, -0.0869073>,
    <0.9783200, -0.1920278, -0.0775586>,
    <0.9592759, -0.1844271, -0.2139543>,
    <-0.9700404, -0.1058533, -0.2186702>,
    <-0.9915850, -0.1079917, -0.0713928>,
    <-0.8819282, -0.1361582, -0.4512910>,
    <-0.8763681, -0.1034788, -0.4703946>,
    <-0.9732626, -0.0617982, -0.2212261>,
    <-0.9962240, -0.0608184, -0.0619590>,
    <-0.7191128, -0.1918235, -0.6678926>,
    <-0.5542803, -0.2468275, -0.7948897>,
    <-0.5294071, -0.2439024, -0.8125514>,
    <-0.7002950, -0.1756172, -0.6919144>,
    <-0.4016288, -0.2927922, -0.8677367>,
    <-0.2592058, -0.3264785, -0.9089687>,
    <-0.2410898, -0.3379659, -0.9097553>,
    <-0.3777116, -0.2988124, -0.8763818>,
    <-0.1267725, -0.3463785, -0.9294895>,
    <0.0000000, -0.3523064, -0.9358847>,
    <0.0000000, -0.3677831, -0.9299116>,
    <-0.1171471, -0.3608013, -0.9252562>,
    <0.1269346, -0.3442365, -0.9302628>,
    <0.2598539, -0.3219717, -0.9103901>,
    <0.2415879, -0.3343695, -0.9109513>,
    <0.1172705, -0.3591087, -0.9258988>,
    <0.4030576, -0.2854971, -0.8695033>,
    <0.5566465, -0.2362131, -0.7964597>,
    <0.5312796, -0.2351021, -0.8139220>,
    <0.3788266, -0.2928952, -0.8778968>,
    <0.7225359, -0.1772442, -0.6682263>,
    <0.8860253, -0.1173945, -0.4485283>,
    <0.8797736, -0.0870513, -0.4673548>,
    <0.7030923, -0.1631969, -0.6921185>,
    <0.9731772, -0.0849418, -0.2138013>,
    <0.9939124, -0.0864438, -0.0683045>,
    <0.9973668, -0.0418788, -0.0592079>,
    <0.9754233, -0.0433761, -0.2160273>,
    <-0.9733721, -0.0313284, -0.2270801>,
    <-0.9981928, -0.0287632, -0.0527618>,
    <-0.8648543, -0.0809765, -0.4954491>,
    <-0.8476184, -0.0295534, -0.5297827>,
    <-0.9707256, 0.0327753, -0.2379444>,
    <-0.9983166, 0.0378355, -0.0439588>,
    <-0.6740659, -0.1638142, -0.7202778>,
    <-0.4989776, -0.2394367, -0.8328814>,
    <-0.4636719, -0.2171227, -0.8589913>,
    <-0.6410454, -0.1296525, -0.7564728>,
    <-0.3506817, -0.2984966, -0.8876498>,
    <-0.2216253, -0.3398055, -0.9140101>,
    <-0.2007481, -0.3285147, -0.9229184>,
    <-0.3208221, -0.2832212, -0.9038025>,
    <-0.1070929, -0.3637013, -0.9253391>,
    <0.0000000, -0.3711207, -0.9285847>,
    <0.0000000, -0.3626431, -0.9319281>,
    <-0.0964767, -0.3544778, -0.9300741>,
    <0.1071801, -0.3624112, -0.9258350>,
    <0.2219814, -0.3370462, -0.9149449>,
    <0.2009792, -0.3265133, -0.9235780>,
    <0.0965328, -0.3535482, -0.9304220>,
    <0.3514941, -0.2939018, -0.8888609>,
    <0.5003764, -0.2324779, -0.8340129>,
    <0.4646034, -0.2119227, -0.8597863>,
    <0.3213561, -0.2798489, -0.9046629>,
    <0.6763115, -0.1537263, -0.7203964>,
    <0.8678429, -0.0671875, -0.4922749>,
    <0.8500506, -0.0185379, -0.5263747>,
    <0.6426766, -0.1218941, -0.7563786>,
    <0.9750062, -0.0156995, -0.2216222>,
    <0.9986492, -0.0126988, -0.0503843>,
    <0.9978345, 0.0506710, -0.0419385>,
    <0.9716301, 0.0453182, -0.2321234>,
    <-0.9620632, 0.0949625, -0.2557664>,
    <-0.9941475, 0.1019185, -0.0358243>,
    <-0.8184756, 0.0200689, -0.5741907>,
    <-0.7762858, 0.0434691, -0.6288806>,
    <-0.9507615, 0.1253337, -0.2834504>,
    <-0.9908456, 0.1319336, -0.0286106>,
    <-0.5958052, -0.0947724, -0.7975176>,
    <-0.4203820, -0.1903073, -0.8871652>,
    <-0.3703692, -0.1678852, -0.9135870>,
    <-0.5383694, -0.0744630, -0.8394127>,
    <-0.2866203, -0.2604228, -0.9219701>,
    <-0.1778170, -0.3077440, -0.9347057>,
    <-0.1537552, -0.2804226, -0.9474822>,
    <-0.2493866, -0.2352115, -0.9394050>,
    <-0.0850787, -0.3347184, -0.9384696>,
    <0.0000000, -0.3432797, -0.9392332>,
    <0.0000000, -0.3144777, -0.9492649>,
    <-0.0733560, -0.3062236, -0.9491291>,
    <0.0851116, -0.3340834, -0.9386929>,
    <0.1779534, -0.3063718, -0.9351304>,
    <0.1538298, -0.2795103, -0.9477396>,
    <0.0733739, -0.3058013, -0.9492639>,
    <0.2869393, -0.2580930, -0.9225258>,
    <0.4209483, -0.1866657, -0.8876702>,
    <0.3706937, -0.1654449, -0.9139005>,
    <0.2495639, -0.2336609, -0.9397449>,
    <0.5969646, -0.0891773, -0.7972958>,
    <0.8206480, 0.0284224, -0.5707268>,
    <0.7785300, 0.0496228, -0.6256426>,
    <0.5392233, -0.0706101, -0.8391975>,
    <0.9626888, 0.1045318, -0.2496066>,
    <0.9931606, 0.1116473, -0.0341604>,
    <0.9898765, 0.1392845, -0.0272822>,
    <0.9516832, 0.1325588, -0.2769968>,
    <-0.9364503, 0.1348220, -0.3238578>,
    <-0.9900666, 0.1388237, -0.0222731>,
    <-0.7196480, 0.0509410, -0.6924679>,
    <-0.6458125, 0.0519450, -0.7617269>,
    <-0.9140974, 0.1342747, -0.3826177>,
    <-0.9911679, 0.1315477, -0.0167742>,
    <-0.4717681, -0.0607449, -0.8796277>,
    <-0.3168877, -0.1455389, -0.9372303>,
    <-0.2622563, -0.1206213, -0.9574300>,
    <-0.3987094, -0.0473784, -0.9158527>,
    <-0.2112387, -0.2062171, -0.9554333>,
    <-0.1296737, -0.2470790, -0.9602795>,
    <-0.1061802, -0.2088855, -0.9721587>,
    <-0.1734709, -0.1731970, -0.9694899>,
    <-0.0617612, -0.2705324, -0.9607277>,
    <0.0000000, -0.2780964, -0.9605532>,
    <0.0000000, -0.2362534, -0.9716915>,
    <-0.0505233, -0.2295378, -0.9719876>,
    <0.0617701, -0.2702654, -0.9608023>,
    <0.1297109, -0.2465038, -0.9604223>,
    <0.1061966, -0.2085616, -0.9722265>,
    <0.0505271, -0.2293869, -0.9720230>,
    <0.2113285, -0.2052419, -0.9556234>,
    <0.3170583, -0.1440009, -0.9374102>,
    <0.2623354, -0.1197577, -0.9575167>,
    <0.1735109, -0.1726496, -0.9695804>,
    <0.4723967, -0.0582572, -0.8794586>,
    <0.7220304, 0.0552532, -0.6896515>,
    <0.6482402, 0.0546736, -0.7594705>,
    <0.3991609, -0.0459488, -0.9157288>,
    <0.9379764, 0.1401298, -0.3171181>,
    <0.9893069, 0.1442937, -0.0212434>,
    <0.9906855, 0.1352261, -0.0160033>,
    <0.9165109, 0.1378227, -0.3755165>,
    <-0.8640779, 0.1378013, -0.4841283>,
    <-0.9891603, 0.1463171, -0.0123756>,
    <-0.5594660, 0.0536144, -0.8271174>,
    <-0.4751817, 0.0714097, -0.8769852>,
    <-0.7525117, 0.1457511, -0.6422482>,
    <0.9828493, -0.1844106, 0.0000000>,
    <-0.3219147, -0.0294530, -0.9463104>,
    <-0.2081551, -0.0915533, -0.9738015>,
    <-0.1555613, -0.0591806, -0.9860519>,
    <-0.2437030, -0.0065171, -0.9698280>,
    <-0.1369004, -0.1364934, -0.9811360>,
    <-0.0836358, -0.1672815, -0.9823553>,
    <-0.0621846, -0.1240575, -0.9903246>,
    <-0.1019065, -0.0975635, -0.9899982>,
    <-0.0397756, -0.1852418, -0.9818877>,
    <0.0000000, -0.1911239, -0.9815659>,
    <0.0000000, -0.1447310, -0.9894710>,
    <-0.0295671, -0.1396106, -0.9897650>,
    <0.0397771, -0.1851675, -0.9819016>,
    <0.0836421, -0.1671224, -0.9823819>,
    <0.0621866, -0.1239907, -0.9903328>,
    <0.0295676, -0.1395793, -0.9897694>,
    <0.1369159, -0.1362253, -0.9811711>,
    <0.2081869, -0.0911304, -0.9738344>,
    <0.1555722, -0.0590034, -0.9860608>,
    <0.1019116, -0.0974511, -0.9900087>,
    <0.3222285, -0.0287345, -0.9462257>,
    <0.5618589, 0.0551379, -0.8253935>,
    <0.4775564, 0.0723012, -0.8756211>,
    <0.2439110, -0.0062040, -0.9697778>,
    <0.8678575, 0.1396813, -0.4767730>,
    <0.9889290, 0.1479185, -0.0118098>,
    <0.9829497, 0.1838744, 0.0000000>,
    <0.7585710, 0.1470253, -0.6347862>,
    <-0.6175160, 0.1655783, -0.7689329>,
    <-0.7914867, 0.2094037, -0.5741941>,
    <0.9828493, -0.1844106, 0.0000000>,
    <-0.3248427, 0.0848240, -0.9419565>,
    <-0.1803033, 0.0901755, -0.9794688>,
    <-0.3781618, 0.1576947, -0.9122094>,
    <-0.5252500, 0.2254017, -0.8205526>,
    <-0.7914867, 0.2094037, -0.5741941>,
    <-0.1674125, 0.0195494, -0.9856931>,
    <-0.1062719, -0.0215943, -0.9941026>,
    <-0.0622727, 0.0174816, -0.9979061>,
    <-0.0967804, 0.0465228, -0.9942179>,
    <-0.0696417, -0.0510323, -0.9962659>,
    <-0.0425781, -0.0710047, -0.9965668>,
    <-0.0256116, -0.0156855, -0.9995489>,
    <-0.0413754, -0.0025690, -0.9991404>,
    <-0.0202815, -0.0825728, -0.9963786>,
    <0.0000000, -0.0863523, -0.9962647>,
    <0.0000000, -0.0254451, -0.9996762>,
    <-0.0123051, -0.0230698, -0.9996581>,
    <0.0202816, -0.0825628, -0.9963795>,
    <0.0425786, -0.0709834, -0.9965683>,
    <0.0256116, -0.0156807, -0.9995490>,
    <0.0123051, -0.0230676, -0.9996582>,
    <0.0696429, -0.0509964, -0.9962677>,
    <0.1062745, -0.0215370, -0.9941036>,
    <0.0622726, 0.0174947, -0.9979058>,
    <0.0413754, -0.0025609, -0.9991404>,
    <0.1675364, 0.0196597, -0.9856698>,
    <0.3263066, 0.0852458, -0.9414123>,
    <0.1809276, 0.0903329, -0.9793392>,
    <0.0968345, 0.0465528, -0.9942112>,
    <0.6242119, 0.1666944, -0.7632644>,
    <0.9829497, 0.1838744, 0.0000000>,
    <0.8006703, 0.2099773, -0.5611030>,
    <0.8006703, 0.2099773, -0.5611030>,
    <0.5330846, 0.2270468, -0.8150280>,
    <0.3821899, 0.1585279, -0.9103844>,
    <-0.1270720, 0.1283091, -0.9835596>,
    <-0.1636326, 0.1874678, -0.9685454>,
    <-0.5252500, 0.2254017, -0.8205526>,
    <-0.0659049, 0.0750371, -0.9950005>,
    <-0.2781777, -0.9605295, -0.0004455>,
    <-0.3186145, -0.9478842, -0.0005522>,
    <0.3462417, 0.9381453, 0.0000000>,
    <-0.1636326, 0.1874678, -0.9685454>,
    <-0.0385232, 0.0374100, -0.9985572>,
    <-0.0272368, 0.0112211, -0.9995660>,
    <-0.1998813, -0.9798201, -0.0002260>,
    <-0.2426937, -0.9701029, -0.0003358>,
    <-0.0196078, -0.0066809, -0.9997854>,
    <-0.0128925, -0.0181603, -0.9997520>,
    <-0.1049491, -0.9944776, -0.0000622>,
    <-0.1532293, -0.9881906, -0.0001325>,
    <-0.0064367, -0.0245169, -0.9996787>,
    <0.0000000, -0.0265410, -0.9996477>,
    <-0.0000000, -1.0000000, 0.0000000>,
    <-0.0541669, -0.9985319, -0.0000172>,
    <0.0064367, -0.0245164, -0.9996787>,
    <0.0128924, -0.0181593, -0.9997520>,
    <0.1049491, -0.9944776, -0.0000537>,
    <0.0541669, -0.9985319, -0.0000128>,
    <0.0196077, -0.0066793, -0.9997854>,
    <0.0272366, 0.0112235, -0.9995660>,
    <0.1998813, -0.9798201, -0.0002099>,
    <0.1532293, -0.9881906, -0.0001201>,
    <0.0385351, 0.0374164, -0.9985565>,
    <0.0660296, 0.0750806, -0.9949889>,
    <0.2784963, -0.9604372, -0.0004235>,
    <0.2427417, -0.9700909, -0.0003162>,
    <0.1277884, 0.1285688, -0.9834329>,
    <0.5330846, 0.2270468, -0.8150280>,
    <0.1649609, 0.1880878, -0.9681998>,
    <0.1649609, 0.1880878, -0.9681998>,
    <0.3478539, -0.9375487, 0.0000000>,
    <0.3196477, -0.9475363, -0.0005282>,
    <0.9465144, -0.3170907, 0.0596987>,
    <0.8833341, -0.3320805, 0.3308224>,
    <0.9040516, -0.2424118, 0.3520330>,
    <0.9745473, -0.2114199, 0.0745600>,
    <0.7253232, -0.3267495, 0.6059217>,
    <0.5544733, -0.3111073, 0.7718624>,
    <0.5544630, -0.2840173, 0.7822435>,
    <0.7332093, -0.2685578, 0.6247246>,
    <0.3977953, -0.2957539, 0.8684978>,
    <0.2549579, -0.2841291, 0.9242657>,
    <0.2516903, -0.3001472, 0.9200890>,
    <0.3947223, -0.2937694, 0.8705710>,
    <0.1242028, -0.2776917, 0.9526075>,
    <-0.0000000, -0.2767850, 0.9609319>,
    <-0.0000000, -0.3067220, 0.9517991>,
    <0.1222543, -0.3042942, 0.9447004>,
    <-0.1241291, -0.2814878, 0.9515023>,
    <-0.2546252, -0.2918408, 0.9219517>,
    <-0.2513591, -0.3069628, 0.9179283>,
    <-0.1221758, -0.3076214, 0.9436324>,
    <-0.3968920, -0.3075704, 0.8647989>,
    <-0.5524606, -0.3271460, 0.7666569>,
    <-0.5528560, -0.2987335, 0.7778872>,
    <-0.3939101, -0.3043697, 0.8672911>,
    <-0.7211747, -0.3469567, 0.5996067>,
    <-0.8761519, -0.3555496, 0.3254878>,
    <-0.8990286, -0.2654595, 0.3482511>,
    <-0.7301622, -0.2876987, 0.6197520>,
    <-0.9382960, -0.3411890, 0.0564869>,
    <-0.9691950, -0.2354220, 0.0723702>,
    <0.9898230, -0.1087940, 0.0917291>,
    <0.9113953, -0.1607101, 0.3788548>,
    <0.9026166, -0.1344867, 0.4088967>,
    <0.9915497, -0.0674691, 0.1108020>,
    <0.7270123, -0.2236735, 0.6491712>,
    <0.5413890, -0.2723224, 0.7954486>,
    <0.5162168, -0.2840174, 0.8079940>,
    <0.7050069, -0.2188970, 0.6745734>,
    <0.3809082, -0.3071537, 0.8721041>,
    <0.2408754, -0.3306909, 0.9124816>,
    <0.2253113, -0.3608670, 0.9049916>,
    <0.3590129, -0.3301214, 0.8730003>,
    <0.1164320, -0.3446038, 0.9314998>,
    <-0.0000000, -0.3500022, 0.9367489>,
    <-0.0000000, -0.3851217, 0.9228658>,
    <0.1084468, -0.3786700, 0.9191563>,
    <-0.1163549, -0.3473152, 0.9305018>,
    <-0.2405625, -0.3363103, 0.9105081>,
    <-0.2250397, -0.3653373, 0.9032640>,
    <-0.1083796, -0.3808089, 0.9182802>,
    <-0.3801955, -0.3160636, 0.8692268>,
    <-0.5401389, -0.2850182, 0.7918425>,
    <-0.5151786, -0.2944638, 0.8049112>,
    <-0.3584017, -0.3373101, 0.8704999>,
    <-0.7249137, -0.2407391, 0.6454029>,
    <-0.9083239, -0.1819715, 0.3766086>,
    <-0.9002034, -0.1530456, 0.4076897>,
    <-0.7032968, -0.2333194, 0.6715174>,
    <-0.9872077, -0.1311448, 0.0906753>,
    <-0.9900092, -0.0872044, 0.1108020>,
    <0.9902453, -0.0423500, 0.1327434>,
    <0.8873075, -0.1234870, 0.4443382>,
    <0.8678108, -0.0864294, 0.4893202>,
    <0.9871345, 0.0154606, 0.1591428>,
    <0.6749459, -0.2237236, 0.7031329>,
    <0.4849447, -0.2986182, 0.8219829>,
    <0.4491845, -0.2992956, 0.8418167>,
    <0.6391655, -0.2102396, 0.7397748>,
    <0.3333031, -0.3505570, 0.8752250>,
    <0.2076707, -0.3847198, 0.8993684>,
    <0.1882193, -0.3983464, 0.8977158>,
    <0.3045744, -0.3594541, 0.8820585>,
    <0.0995719, -0.4042410, 0.9092165>,
    <-0.0000000, -0.4110627, 0.9116071>,
    <-0.0000000, -0.4276557, 0.9039417>,
    <0.0898529, -0.4202478, 0.9029497>,
    <-0.0995194, -0.4058675, 0.9084974>,
    <-0.2074575, -0.3881415, 0.8979463>,
    <-0.1880751, -0.4008047, 0.8966512>,
    <-0.0898173, -0.4214078, 0.9024125>,
    <-0.3328211, -0.3561231, 0.8731589>,
    <-0.4841260, -0.3068468, 0.8194309>,
    <-0.4486465, -0.3053984, 0.8399096>,
    <-0.3042499, -0.3635046, 0.8805091>,
    <-0.6735235, -0.2353918, 0.7006831>,
    <-0.8851680, -0.1390963, 0.4439931>,
    <-0.8661293, -0.0989718, 0.4899231>,
    <-0.6381552, -0.2191692, 0.7380534>,
    <-0.9892409, -0.0592172, 0.1337751>,
    <-0.9869056, 0.0017345, 0.1612893>,
    <0.9790200, 0.0693476, 0.1916006>,
    <0.8370871, -0.0556923, 0.5442275>,
    <0.7920729, -0.0569369, 0.6077654>,
    <0.9685910, 0.0879763, 0.2325760>,
    <0.5917436, -0.2001893, 0.7808737>,
    <0.4058914, -0.2986974, 0.8637314>,
    <0.3561387, -0.3042637, 0.8835094>,
    <0.5318611, -0.2078231, 0.8209344>,
    <0.2715854, -0.3634666, 0.8911416>,
    <0.1665841, -0.4047534, 0.8991242>,
    <0.1438172, -0.4060249, 0.9024746>,
    <0.2357046, -0.3665163, 0.9000606>,
    <0.0792252, -0.4277756, 0.9004063>,
    <-0.0000000, -0.4354009, 0.9002367>,
    <-0.0000000, -0.4352413, 0.9003139>,
    <0.0682369, -0.4280246, 0.9011873>,
    <-0.0792041, -0.4285552, 0.9000373>,
    <-0.1664987, -0.4064143, 0.8983906>,
    <-0.1437709, -0.4071061, 0.9019948>,
    <-0.0682255, -0.4285313, 0.9009474>,
    <-0.2713938, -0.3662302, 0.8900679>,
    <-0.4055798, -0.3029285, 0.8624033>,
    <-0.3559655, -0.3070579, 0.8826121>,
    <-0.2355997, -0.3683232, 0.8993502>,
    <-0.5910280, -0.2065912, 0.7797474>,
    <-0.8355282, -0.0653072, 0.5455526>,
    <-0.7902487, -0.0641279, 0.6094215>,
    <-0.5312927, -0.2121905, 0.8201849>,
    <-0.9790832, 0.0586078, 0.1948363>,
    <-0.9682981, 0.0795050, 0.2368074>,
    <0.9550877, 0.0811444, 0.2849967>,
    <0.7311017, -0.0793921, 0.6776335>,
    <0.6519338, -0.1122363, 0.7499236>,
    <0.9334346, 0.0577440, 0.3540699>,
    <0.4631278, -0.2237386, 0.8575859>,
    <0.3034404, -0.3106354, 0.9007939>,
    <0.2502803, -0.3141810, 0.9157784>,
    <0.3889515, -0.2402123, 0.8893901>,
    <0.1991725, -0.3664105, 0.9088859>,
    <0.1211227, -0.4019678, 0.9076074>,
    <0.0991348, -0.3929254, 0.9142111>,
    <0.1633246, -0.3620547, 0.9177371>,
    <0.0573980, -0.4218596, 0.9048425>,
    <-0.0000000, -0.4283604, 0.9036080>,
    <-0.0000000, -0.4160294, 0.9093511>,
    <0.0469552, -0.4103415, 0.9107223>,
    <-0.0573925, -0.4221724, 0.9046970>,
    <-0.1211002, -0.4026349, 0.9073147>,
    <-0.0991259, -0.3932974, 0.9140521>,
    <-0.0469531, -0.4105163, 0.9106436>,
    <-0.1991210, -0.3675256, 0.9084469>,
    <-0.3033529, -0.3123686, 0.9002238>,
    <-0.2502450, -0.3151459, 0.9154564>,
    <-0.1633041, -0.3626751, 0.9174958>,
    <-0.4626684, -0.2265275, 0.8571017>,
    <-0.7289613, -0.0845363, 0.6793152>,
    <-0.6496335, -0.1155954, 0.7514080>,
    <-0.3885978, -0.2418050, 0.8891131>,
    <-0.9540854, 0.0744423, 0.2901368>,
    <-0.9314246, 0.0525941, 0.3601140>,
    <0.8842923, 0.0253825, 0.4662433>,
    <0.5607459, -0.1451393, 0.8151678>,
    <0.4748923, -0.1589138, 0.8655771>,
    <0.7704981, -0.0218159, 0.6370688>,
    <0.9829497, 0.1838744, 0.0000000>,
    <0.3125467, -0.2511506, 0.9160993>,
    <0.1983198, -0.3125258, 0.9289763>,
    <0.1482796, -0.3057042, 0.9405095>,
    <0.2360588, -0.2550494, 0.9376706>,
    <0.1289104, -0.3529974, 0.9267011>,
    <0.0781695, -0.3794814, 0.9218912>,
    <0.0582829, -0.3626021, 0.9301198>,
    <0.0961499, -0.3398951, 0.9355354>,
    <0.0370220, -0.3945678, 0.9181207>,
    <-0.0000000, -0.3994995, 0.9167334>,
    <-0.0000000, -0.3799303, 0.9250151>,
    <0.0276078, -0.3756554, 0.9263481>,
    <-0.0370213, -0.3946541, 0.9180836>,
    <-0.0781668, -0.3796646, 0.9218160>,
    <-0.0582824, -0.3626800, 0.9300895>,
    <-0.0276077, -0.3756922, 0.9263332>,
    <-0.1289044, -0.3533019, 0.9265859>,
    <-0.1983099, -0.3129986, 0.9288192>,
    <-0.1482784, -0.3059040, 0.9404447>,
    <-0.0961489, -0.3400242, 0.9354886>,
    <-0.3122875, -0.2519519, 0.9159677>,
    <-0.5584229, -0.1471265, 0.8164054>,
    <-0.4725445, -0.1601691, 0.8666300>,
    <-0.2358782, -0.2554008, 0.9376204>,
    <-0.8807734, 0.0216923, 0.4730408>,
    <0.9828493, -0.1844106, 0.0000000>,
    <-0.7643912, -0.0251078, 0.6442637>,
    <0.6352529, -0.0499799, 0.7706853>,
    <0.8188503, 0.0482952, 0.5719718>,
    <0.9829497, 0.1838744, 0.0000000>,
    <0.3256341, -0.1763125, 0.9289114>,
    <0.2004544, -0.1831831, 0.9624251>,
    <0.4119775, -0.1040042, 0.9052390>,
    <0.5747586, -0.0111390, 0.8182472>,
    <0.8188503, 0.0482952, 0.5719718>,
    <0.1647040, -0.2455287, 0.9552949>,
    <0.1037342, -0.2813159, 0.9539919>,
    <0.0738630, -0.2355451, 0.9690525>,
    <0.1118600, -0.2182977, 0.9694501>,
    <0.0676891, -0.3049254, 0.9499677>,
    <0.0412922, -0.3201886, 0.9464535>,
    <0.0312407, -0.2504213, 0.9676328>,
    <0.0498697, -0.2451812, 0.9681938>,
    <0.0196542, -0.3287604, 0.9442088>,
    <-0.0000000, -0.3315123, 0.9434509>,
    <-0.0000000, -0.2536323, 0.9673007>,
    <0.0151559, -0.2529332, 0.9673650>,
    <-0.0196543, -0.3287730, 0.9442044>,
    <-0.0412924, -0.3202152, 0.9464445>,
    <-0.0312410, -0.2504292, 0.9676307>,
    <-0.0151560, -0.2529370, 0.9673640>,
    <-0.0676896, -0.3049692, 0.9499536>,
    <-0.1037353, -0.2813834, 0.9539719>,
    <-0.0738645, -0.2355645, 0.9690477>,
    <-0.0498704, -0.2451939, 0.9681905>,
    <-0.1645905, -0.2456559, 0.9552817>,
    <-0.3241796, -0.1768811, 0.9293119>,
    <-0.1997699, -0.1833966, 0.9625267>,
    <-0.1118005, -0.2183384, 0.9694478>,
    <-0.6283728, -0.0527227, 0.7761236>,
    <0.9828493, -0.1844106, 0.0000000>,
    <-0.8096144, 0.0438493, 0.5853219>,
    <-0.8096144, 0.0438493, 0.5853219>,
    <-0.5664820, -0.0146373, 0.8239441>,
    <-0.4076652, -0.1054498, 0.9070223>,
    <0.2010754, -0.1510133, 0.9678655>,
    <0.2520463, -0.0929922, 0.9632368>,
    <0.5747586, -0.0111390, 0.8182472>,
    <0.1236019, -0.1973974, 0.9725003>,
    <0.3478539, -0.9375487, 0.0000000>,
    <0.2520463, -0.0929922, 0.9632368>,
    <0.0844737, -0.2201342, 0.9718051>,
    <0.0622844, -0.2304441, 0.9710902>,
    <0.0448335, -0.2350976, 0.9709372>,
    <0.0293542, -0.2368528, 0.9711020>,
    <0.0146795, -0.2373009, 0.9713253>,
    <-0.0000000, -0.2373064, 0.9714349>,
    <-0.0146795, -0.2373025, 0.9713249>,
    <-0.0293545, -0.2368559, 0.9711012>,
    <-0.0448341, -0.2351025, 0.9709360>,
    <-0.0622856, -0.2304512, 0.9710884>,
    <-0.0844486, -0.2201503, 0.9718036>,
    <-0.1233712, -0.1974852, 0.9725118>,
    <-0.1999614, -0.1514739, 0.9680243>,
    <-0.5664820, -0.0146373, 0.8239441>,
    <-0.2500445, -0.0940804, 0.9636527>,
    <-0.2500445, -0.0940804, 0.9636527>,
    <0.3462417, 0.9381453, 0.0000000>
  }
  uv_vectors {
    3910,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0000000, 0.0000000>,
    <0.0000000, 0.1250000>,
    <0.0000000, 0.2500000>,
    <0.0000000, 0.3750000>,
    <0.0000000, 0.5000000>,
    <0.0000000, 0.6250000>,
    <0.0000000, 0.7500000>,
    <0.0000000, 0.8750000>,
    <0.0000000, 1.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.0416667, 0.0833333>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0511712, 0.0511712>,
    <0.0606733, 0.1250000>,
    <0.0000000, 0.0501834>,
    <0.1666667, 0.0833333>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1762031, 0.0512031>,
    <0.1870180, 0.1250000>,
    <0.1250000, 0.0511712>,
    <0.2916667, 0.0833333>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.3012724, 0.0512724>,
    <0.3136624, 0.1250000>,
    <0.2500000, 0.0512031>,
    <0.4166667, 0.0833333>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4259690, 0.0509690>,
    <0.4402492, 0.1250000>,
    <0.3750000, 0.0512724>,
    <0.5416667, 0.0833333>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5505055, 0.0505055>,
    <0.5663993, 0.1250000>,
    <0.5000000, 0.0509690>,
    <0.6666667, 0.0833333>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6751349, 0.0501349>,
    <0.6925959, 0.1250000>,
    <0.6250000, 0.0505055>,
    <0.7916667, 0.0833333>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7999859, 0.0499859>,
    <0.8187198, 0.1250000>,
    <0.7500000, 0.0501349>,
    <0.9166667, 0.0833333>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9245636, 0.0495636>,
    <0.9433350, 0.1250000>,
    <0.8750000, 0.0499859>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0606733, 0.1250000>,
    <0.1250000, 0.1903126>,
    <0.0606797, 0.2500000>,
    <0.0000000, 0.1892013>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1870180, 0.1250000>,
    <0.2500000, 0.1911067>,
    <0.1862935, 0.2500000>,
    <0.1250000, 0.1903126>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3136624, 0.1250000>,
    <0.3750000, 0.1913700>,
    <0.3120446, 0.2500000>,
    <0.2500000, 0.1911067>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4402492, 0.1250000>,
    <0.5000000, 0.1909922>,
    <0.4374688, 0.2500000>,
    <0.3750000, 0.1913700>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5663993, 0.1250000>,
    <0.6250000, 0.1901560>,
    <0.5625312, 0.2500000>,
    <0.5000000, 0.1909922>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6925959, 0.1250000>,
    <0.7500000, 0.1891990>,
    <0.6879554, 0.2500000>,
    <0.6250000, 0.1901560>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8187198, 0.1250000>,
    <0.8750000, 0.1883413>,
    <0.8138476, 0.2500000>,
    <0.7500000, 0.1891990>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9433350, 0.1250000>,
    <1.0000000, 0.1876481>,
    <0.9391729, 0.2500000>,
    <0.8750000, 0.1883413>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0606797, 0.2500000>,
    <0.1250000, 0.3146294>,
    <0.0607627, 0.3750000>,
    <0.0000000, 0.3141163>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1862935, 0.2500000>,
    <0.2500000, 0.3149376>,
    <0.1863427, 0.3750000>,
    <0.1250000, 0.3146294>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3120446, 0.2500000>,
    <0.3750000, 0.3150247>,
    <0.3120960, 0.3750000>,
    <0.2500000, 0.3149376>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4374688, 0.2500000>,
    <0.5000000, 0.3148805>,
    <0.4374845, 0.3750000>,
    <0.3750000, 0.3150247>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5625312, 0.2500000>,
    <0.6250000, 0.3145395>,
    <0.5625155, 0.3750000>,
    <0.5000000, 0.3148805>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6879554, 0.2500000>,
    <0.7500000, 0.3140827>,
    <0.6879040, 0.3750000>,
    <0.6250000, 0.3145395>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8138476, 0.2500000>,
    <0.8750000, 0.3136058>,
    <0.8137133, 0.3750000>,
    <0.7500000, 0.3140827>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9391729, 0.2500000>,
    <1.0000000, 0.3131787>,
    <0.9391784, 0.3750000>,
    <0.8750000, 0.3136058>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0607627, 0.3750000>,
    <0.1250000, 0.4391339>,
    <0.0608565, 0.5000000>,
    <0.0000000, 0.4390176>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1863427, 0.3750000>,
    <0.2500000, 0.4392008>,
    <0.1864564, 0.5000000>,
    <0.1250000, 0.4391339>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3120960, 0.3750000>,
    <0.3750000, 0.4392186>,
    <0.3121613, 0.5000000>,
    <0.2500000, 0.4392008>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4374845, 0.3750000>,
    <0.5000000, 0.4391883>,
    <0.4375027, 0.5000000>,
    <0.3750000, 0.4392186>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5625155, 0.3750000>,
    <0.6250000, 0.4391151>,
    <0.5624973, 0.5000000>,
    <0.5000000, 0.4391883>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6879040, 0.3750000>,
    <0.7500000, 0.4390105>,
    <0.6878387, 0.5000000>,
    <0.6250000, 0.4391151>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8137133, 0.3750000>,
    <0.8750000, 0.4388917>,
    <0.8135568, 0.5000000>,
    <0.7500000, 0.4390105>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9391784, 0.3750000>,
    <1.0000000, 0.4387783>,
    <0.9391294, 0.5000000>,
    <0.8750000, 0.4388917>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0608565, 0.5000000>,
    <0.1250000, 0.5617520>,
    <0.0609850, 0.6250000>,
    <0.0000000, 0.5617762>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1864564, 0.5000000>,
    <0.2500000, 0.5617169>,
    <0.1866246, 0.6250000>,
    <0.1250000, 0.5617520>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3121613, 0.5000000>,
    <0.3750000, 0.5616890>,
    <0.3122343, 0.6250000>,
    <0.2500000, 0.5617169>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4375027, 0.5000000>,
    <0.5000000, 0.5616758>,
    <0.4375208, 0.6250000>,
    <0.3750000, 0.5616890>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5624973, 0.5000000>,
    <0.6250000, 0.5616800>,
    <0.5624792, 0.6250000>,
    <0.5000000, 0.5616758>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6878387, 0.5000000>,
    <0.7500000, 0.5617002>,
    <0.6877657, 0.6250000>,
    <0.6250000, 0.5616800>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8135568, 0.5000000>,
    <0.8750000, 0.5617303>,
    <0.8133640, 0.6250000>,
    <0.7500000, 0.5617002>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9391294, 0.5000000>,
    <1.0000000, 0.5617545>,
    <0.9390273, 0.6250000>,
    <0.8750000, 0.5617303>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0609850, 0.6250000>,
    <0.1250000, 0.6881976>,
    <0.0611530, 0.7500000>,
    <0.0000000, 0.6882387>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1866246, 0.6250000>,
    <0.2500000, 0.6881374>,
    <0.1868229, 0.7500000>,
    <0.1250000, 0.6881976>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3122343, 0.6250000>,
    <0.3750000, 0.6880875>,
    <0.3122991, 0.7500000>,
    <0.2500000, 0.6881374>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4375208, 0.6250000>,
    <0.5000000, 0.6880595>,
    <0.4375334, 0.7500000>,
    <0.3750000, 0.6880875>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5624792, 0.6250000>,
    <0.6250000, 0.6880573>,
    <0.5624666, 0.7500000>,
    <0.5000000, 0.6880595>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6877657, 0.6250000>,
    <0.7500000, 0.6880799>,
    <0.6877009, 0.7500000>,
    <0.6250000, 0.6880573>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8133640, 0.6250000>,
    <0.8750000, 0.6881194>,
    <0.8131526, 0.7500000>,
    <0.7500000, 0.6880799>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9390273, 0.6250000>,
    <1.0000000, 0.6881530>,
    <0.9388738, 0.7500000>,
    <0.8750000, 0.6881194>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0611530, 0.7500000>,
    <0.1250000, 0.8164861>,
    <0.0613363, 0.8750000>,
    <0.0000000, 0.8164335>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1868229, 0.7500000>,
    <0.2500000, 0.8165394>,
    <0.1870012, 0.8750000>,
    <0.1250000, 0.8164861>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3122991, 0.7500000>,
    <0.3750000, 0.8165727>,
    <0.3123353, 0.8750000>,
    <0.2500000, 0.8165394>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4375334, 0.7500000>,
    <0.5000000, 0.8165739>,
    <0.4375355, 0.8750000>,
    <0.3750000, 0.8165727>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5624666, 0.7500000>,
    <0.6250000, 0.8165398>,
    <0.5624645, 0.8750000>,
    <0.5000000, 0.8165739>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6877009, 0.7500000>,
    <0.7500000, 0.8164771>,
    <0.6876647, 0.8750000>,
    <0.6250000, 0.8165398>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8131526, 0.7500000>,
    <0.8750000, 0.8164022>,
    <0.8129703, 0.8750000>,
    <0.7500000, 0.8164771>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9388738, 0.7500000>,
    <1.0000000, 0.8163431>,
    <0.9386955, 0.8750000>,
    <0.8750000, 0.8164022>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0613363, 0.8750000>,
    <0.1250000, 0.9375331>,
    <0.0614920, 1.0000000>,
    <0.0000000, 0.9375058>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1870012, 0.8750000>,
    <0.2500000, 0.9375624>,
    <0.1871169, 1.0000000>,
    <0.1250000, 0.9375331>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3123353, 0.8750000>,
    <0.3750000, 0.9375822>,
    <0.3123372, 1.0000000>,
    <0.2500000, 0.9375624>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4375355, 0.8750000>,
    <0.5000000, 0.9375864>,
    <0.4375275, 1.0000000>,
    <0.3750000, 0.9375822>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5624645, 0.8750000>,
    <0.6250000, 0.9375733>,
    <0.5624723, 1.0000000>,
    <0.5000000, 0.9375864>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6876647, 0.8750000>,
    <0.7500000, 0.9375452>,
    <0.6876626, 1.0000000>,
    <0.6250000, 0.9375733>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8129703, 0.8750000>,
    <0.8750000, 0.9375091>,
    <0.8128567, 1.0000000>,
    <0.7500000, 0.9375452>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9386955, 0.8750000>,
    <1.0000000, 0.9374789>,
    <0.9385381, 1.0000000>,
    <0.8750000, 0.9375091>,
    <0.0416667, 0.0833333>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0495323, 0.0495323>,
    <0.0655827, 0.1250000>,
    <0.0000000, 0.0495636>,
    <0.1666667, 0.0833333>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1740898, 0.0490898>,
    <0.1901079, 0.1250000>,
    <0.1250000, 0.0495323>,
    <0.2916667, 0.0833333>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2989009, 0.0489009>,
    <0.3146643, 0.1250000>,
    <0.2500000, 0.0490898>,
    <0.4166667, 0.0833333>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4238462, 0.0488462>,
    <0.4386771, 0.1250000>,
    <0.3750000, 0.0489009>,
    <0.5416667, 0.0833333>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5489090, 0.0489090>,
    <0.5625739, 0.1250000>,
    <0.5000000, 0.0488462>,
    <0.6666667, 0.0833333>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6741287, 0.0491287>,
    <0.6870170, 0.1250000>,
    <0.6250000, 0.0489090>,
    <0.7916667, 0.0833333>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7997911, 0.0497911>,
    <0.8120796, 0.1250000>,
    <0.7500000, 0.0491287>,
    <0.9166667, 0.0833333>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9251834, 0.0501834>,
    <0.9381625, 0.1250000>,
    <0.8750000, 0.0497911>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0655827, 0.1250000>,
    <0.1250000, 0.1868946>,
    <0.0607992, 0.2500000>,
    <0.0000000, 0.1876481>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1901079, 0.1250000>,
    <0.2500000, 0.1864791>,
    <0.1861939, 0.2500000>,
    <0.1250000, 0.1868946>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3146643, 0.1250000>,
    <0.3750000, 0.1863219>,
    <0.3121086, 0.2500000>,
    <0.2500000, 0.1864791>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4386771, 0.1250000>,
    <0.5000000, 0.1863609>,
    <0.4374951, 0.2500000>,
    <0.3750000, 0.1863219>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5625739, 0.1250000>,
    <0.6250000, 0.1865823>,
    <0.5625049, 0.2500000>,
    <0.5000000, 0.1863609>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6870170, 0.1250000>,
    <0.7500000, 0.1870246>,
    <0.6878914, 0.2500000>,
    <0.6250000, 0.1865823>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8120796, 0.1250000>,
    <0.8750000, 0.1877942>,
    <0.8136655, 0.2500000>,
    <0.7500000, 0.1870246>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9381625, 0.1250000>,
    <1.0000000, 0.1892013>,
    <0.9393473, 0.2500000>,
    <0.8750000, 0.1877942>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0607992, 0.2500000>,
    <0.1250000, 0.3126526>,
    <0.0607501, 0.3750000>,
    <0.0000000, 0.3131787>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1861939, 0.2500000>,
    <0.2500000, 0.3123789>,
    <0.1863932, 0.3750000>,
    <0.1250000, 0.3126526>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3121086, 0.2500000>,
    <0.3750000, 0.3123022>,
    <0.3122560, 0.3750000>,
    <0.2500000, 0.3123789>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4374951, 0.2500000>,
    <0.5000000, 0.3123761>,
    <0.4375493, 0.3750000>,
    <0.3750000, 0.3123022>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5625049, 0.2500000>,
    <0.6250000, 0.3125839>,
    <0.5624507, 0.3750000>,
    <0.5000000, 0.3123761>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6878914, 0.2500000>,
    <0.7500000, 0.3129328>,
    <0.6877440, 0.3750000>,
    <0.6250000, 0.3125839>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8136655, 0.2500000>,
    <0.8750000, 0.3134489>,
    <0.8135514, 0.3750000>,
    <0.7500000, 0.3129328>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9393473, 0.2500000>,
    <1.0000000, 0.3141163>,
    <0.9393078, 0.3750000>,
    <0.8750000, 0.3134489>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0607501, 0.3750000>,
    <0.1250000, 0.4386468>,
    <0.0607137, 0.5000000>,
    <0.0000000, 0.4387783>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1863932, 0.3750000>,
    <0.2500000, 0.4385730>,
    <0.1866755, 0.5000000>,
    <0.1250000, 0.4386468>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3122560, 0.3750000>,
    <0.3750000, 0.4385507>,
    <0.3124962, 0.5000000>,
    <0.2500000, 0.4385730>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4375493, 0.3750000>,
    <0.5000000, 0.4385739>,
    <0.4376353, 0.5000000>,
    <0.3750000, 0.4385507>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5624507, 0.3750000>,
    <0.6250000, 0.4386387>,
    <0.5623647, 0.5000000>,
    <0.5000000, 0.4385739>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6877440, 0.3750000>,
    <0.7500000, 0.4387399>,
    <0.6875038, 0.5000000>,
    <0.6250000, 0.4386387>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8135514, 0.3750000>,
    <0.8750000, 0.4388711>,
    <0.8133115, 0.5000000>,
    <0.7500000, 0.4387399>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9393078, 0.3750000>,
    <1.0000000, 0.4390176>,
    <0.9392999, 0.5000000>,
    <0.8750000, 0.4388711>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0607137, 0.5000000>,
    <0.1250000, 0.5617699>,
    <0.0606663, 0.6250000>,
    <0.0000000, 0.5617545>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1866755, 0.5000000>,
    <0.2500000, 0.5617199>,
    <0.1870850, 0.6250000>,
    <0.1250000, 0.5617699>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3124962, 0.5000000>,
    <0.3750000, 0.5616537>,
    <0.3128432, 0.6250000>,
    <0.2500000, 0.5617199>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4376353, 0.5000000>,
    <0.5000000, 0.5616261>,
    <0.4377544, 0.6250000>,
    <0.3750000, 0.5616537>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5623647, 0.5000000>,
    <0.6250000, 0.5616599>,
    <0.5622456, 0.6250000>,
    <0.5000000, 0.5616261>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6875038, 0.5000000>,
    <0.7500000, 0.5617332>,
    <0.6871568, 0.6250000>,
    <0.6250000, 0.5616599>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8133115, 0.5000000>,
    <0.8750000, 0.5617895>,
    <0.8129260, 0.6250000>,
    <0.7500000, 0.5617332>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9392999, 0.5000000>,
    <1.0000000, 0.5617762>,
    <0.9393220, 0.6250000>,
    <0.8750000, 0.5617895>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0606663, 0.6250000>,
    <0.1250000, 0.6881779>,
    <0.0605918, 0.7500000>,
    <0.0000000, 0.6881530>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1870850, 0.6250000>,
    <0.2500000, 0.6880885>,
    <0.1876185, 0.7500000>,
    <0.1250000, 0.6881779>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3128432, 0.6250000>,
    <0.3750000, 0.6879700>,
    <0.3132690, 0.7500000>,
    <0.2500000, 0.6880885>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4377544, 0.6250000>,
    <0.5000000, 0.6879278>,
    <0.4378926, 0.7500000>,
    <0.3750000, 0.6879700>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5622456, 0.6250000>,
    <0.6250000, 0.6880069>,
    <0.5621074, 0.7500000>,
    <0.5000000, 0.6879278>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6871568, 0.6250000>,
    <0.7500000, 0.6881574>,
    <0.6867310, 0.7500000>,
    <0.6250000, 0.6880069>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8129260, 0.6250000>,
    <0.8750000, 0.6882661>,
    <0.8124047, 0.7500000>,
    <0.7500000, 0.6881574>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9393220, 0.6250000>,
    <1.0000000, 0.6882387>,
    <0.9393835, 0.7500000>,
    <0.8750000, 0.6882661>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0605918, 0.7500000>,
    <0.1250000, 0.8162922>,
    <0.0604868, 0.8750000>,
    <0.0000000, 0.8163431>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1876185, 0.7500000>,
    <0.2500000, 0.8163189>,
    <0.1881908, 0.8750000>,
    <0.1250000, 0.8162922>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3132690, 0.7500000>,
    <0.3750000, 0.8163786>,
    <0.3136906, 0.8750000>,
    <0.2500000, 0.8163189>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4378926, 0.7500000>,
    <0.5000000, 0.8164215>,
    <0.4380216, 0.8750000>,
    <0.3750000, 0.8163786>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5621074, 0.7500000>,
    <0.6250000, 0.8164228>,
    <0.5619784, 0.8750000>,
    <0.5000000, 0.8164215>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6867310, 0.7500000>,
    <0.7500000, 0.8163972>,
    <0.6863094, 0.8750000>,
    <0.6250000, 0.8164228>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8124047, 0.7500000>,
    <0.8750000, 0.8163879>,
    <0.8118358, 0.8750000>,
    <0.7500000, 0.8163972>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9393835, 0.7500000>,
    <1.0000000, 0.8164335>,
    <0.9394846, 0.8750000>,
    <0.8750000, 0.8163879>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0604868, 0.8750000>,
    <0.1250000, 0.9374467>,
    <0.0603763, 1.0000000>,
    <0.0000000, 0.9374789>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1881908, 0.8750000>,
    <0.2500000, 0.9374719>,
    <0.1886658, 1.0000000>,
    <0.1250000, 0.9374467>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3136906, 0.8750000>,
    <0.3750000, 0.9375196>,
    <0.3140156, 1.0000000>,
    <0.2500000, 0.9374719>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4380216, 0.8750000>,
    <0.5000000, 0.9375466>,
    <0.4381163, 1.0000000>,
    <0.3750000, 0.9375196>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5619784, 0.8750000>,
    <0.6250000, 0.9375337>,
    <0.5618835, 1.0000000>,
    <0.5000000, 0.9375466>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6863094, 0.8750000>,
    <0.7500000, 0.9374968>,
    <0.6859842, 1.0000000>,
    <0.6250000, 0.9375337>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8118358, 0.8750000>,
    <0.8750000, 0.9374767>,
    <0.8113588, 1.0000000>,
    <0.7500000, 0.9374968>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9394846, 0.8750000>,
    <1.0000000, 0.9375058>,
    <0.9395979, 1.0000000>,
    <0.8750000, 0.9374767>,
    <0.0625000, 0.0625000>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0614920, 0.0000000>,
    <0.1250000, 0.0608389>,
    <0.0616120, 0.1250000>,
    <0.0000000, 0.0608164>,
    <0.1875000, 0.0625000>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1871169, 0.0000000>,
    <0.2500000, 0.0608564>,
    <0.1872003, 0.1250000>,
    <0.1250000, 0.0608389>,
    <0.3125000, 0.0625000>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.3123372, 0.0000000>,
    <0.3750000, 0.0608655>,
    <0.3123379, 0.1250000>,
    <0.2500000, 0.0608564>,
    <0.4375000, 0.0625000>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4375275, 0.0000000>,
    <0.5000000, 0.0608666>,
    <0.4375210, 0.1250000>,
    <0.3750000, 0.0608655>,
    <0.5625000, 0.0625000>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5624723, 0.0000000>,
    <0.6250000, 0.0608601>,
    <0.5624767, 0.1250000>,
    <0.5000000, 0.0608666>,
    <0.6875000, 0.0625000>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6876626, 0.0000000>,
    <0.7500000, 0.0608457>,
    <0.6876606, 0.1250000>,
    <0.6250000, 0.0608601>,
    <0.8125000, 0.0625000>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.8128567, 0.0000000>,
    <0.8750000, 0.0608230>,
    <0.8127781, 0.1250000>,
    <0.7500000, 0.0608457>,
    <0.9375000, 0.0625000>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9385381, 0.0000000>,
    <1.0000000, 0.0607970>,
    <0.9384153, 0.1250000>,
    <0.8750000, 0.0608230>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0616120, 0.1250000>,
    <0.1250000, 0.1880574>,
    <0.0616963, 0.2500000>,
    <0.0000000, 0.1880275>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1872003, 0.1250000>,
    <0.2500000, 0.1880855>,
    <0.1872812, 0.2500000>,
    <0.1250000, 0.1880574>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3123379, 0.1250000>,
    <0.3750000, 0.1881025>,
    <0.3123584, 0.2500000>,
    <0.2500000, 0.1880855>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4375210, 0.1250000>,
    <0.5000000, 0.1881080>,
    <0.4375231, 0.2500000>,
    <0.3750000, 0.1881025>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5624767, 0.1250000>,
    <0.6250000, 0.1881021>,
    <0.5624705, 0.2500000>,
    <0.5000000, 0.1881080>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6876606, 0.1250000>,
    <0.7500000, 0.1880846>,
    <0.6876373, 0.2500000>,
    <0.6250000, 0.1881021>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8127781, 0.1250000>,
    <0.8750000, 0.1880562>,
    <0.8127026, 0.2500000>,
    <0.7500000, 0.1880846>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9384153, 0.1250000>,
    <1.0000000, 0.1880258>,
    <0.9383296, 0.2500000>,
    <0.8750000, 0.1880562>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0616963, 0.2500000>,
    <0.1250000, 0.3127396>,
    <0.0617539, 0.3750000>,
    <0.0000000, 0.3127267>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1872812, 0.2500000>,
    <0.2500000, 0.3127526>,
    <0.1873613, 0.3750000>,
    <0.1250000, 0.3127396>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3123584, 0.2500000>,
    <0.3750000, 0.3127610>,
    <0.3123931, 0.3750000>,
    <0.2500000, 0.3127526>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4375231, 0.2500000>,
    <0.5000000, 0.3127642>,
    <0.4375315, 0.3750000>,
    <0.3750000, 0.3127610>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5624705, 0.2500000>,
    <0.6250000, 0.3127622>,
    <0.5624570, 0.3750000>,
    <0.5000000, 0.3127642>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6876373, 0.2500000>,
    <0.7500000, 0.3127550>,
    <0.6875991, 0.3750000>,
    <0.6250000, 0.3127622>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8127026, 0.2500000>,
    <0.8750000, 0.3127434>,
    <0.8126277, 0.3750000>,
    <0.7500000, 0.3127550>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9383296, 0.2500000>,
    <1.0000000, 0.3127317>,
    <0.9382719, 0.3750000>,
    <0.8750000, 0.3127434>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0617539, 0.3750000>,
    <0.1250000, 0.4375936>,
    <0.0617877, 0.5000000>,
    <0.0000000, 0.4375845>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1873613, 0.3750000>,
    <0.2500000, 0.4376051>,
    <0.1874371, 0.5000000>,
    <0.1250000, 0.4375936>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3123931, 0.3750000>,
    <0.3750000, 0.4376138>,
    <0.3124366, 0.5000000>,
    <0.2500000, 0.4376051>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4375315, 0.3750000>,
    <0.5000000, 0.4376177>,
    <0.4375441, 0.5000000>,
    <0.3750000, 0.4376138>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5624570, 0.3750000>,
    <0.6250000, 0.4376164>,
    <0.5624392, 0.5000000>,
    <0.5000000, 0.4376177>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6875991, 0.3750000>,
    <0.7500000, 0.4376104>,
    <0.6875519, 0.5000000>,
    <0.6250000, 0.4376164>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8126277, 0.3750000>,
    <0.8750000, 0.4376015>,
    <0.8125565, 0.5000000>,
    <0.7500000, 0.4376104>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9382719, 0.3750000>,
    <1.0000000, 0.4375944>,
    <0.9382385, 0.5000000>,
    <0.8750000, 0.4376015>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0617877, 0.5000000>,
    <0.1250000, 0.5625397>,
    <0.0617955, 0.6250000>,
    <0.0000000, 0.5625413>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1874371, 0.5000000>,
    <0.2500000, 0.5625452>,
    <0.1875040, 0.6250000>,
    <0.1250000, 0.5625397>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3124366, 0.5000000>,
    <0.3750000, 0.5625519>,
    <0.3124860, 0.6250000>,
    <0.2500000, 0.5625452>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4375441, 0.5000000>,
    <0.5000000, 0.5625560>,
    <0.4375602, 0.6250000>,
    <0.3750000, 0.5625519>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5624392, 0.5000000>,
    <0.6250000, 0.5625560>,
    <0.5624187, 0.6250000>,
    <0.5000000, 0.5625560>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6875519, 0.5000000>,
    <0.7500000, 0.5625534>,
    <0.6874992, 0.6250000>,
    <0.6250000, 0.5625560>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8125565, 0.5000000>,
    <0.8750000, 0.5625518>,
    <0.8124934, 0.6250000>,
    <0.7500000, 0.5625534>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9382385, 0.5000000>,
    <1.0000000, 0.5625559>,
    <0.9382319, 0.6250000>,
    <0.8750000, 0.5625518>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0617955, 0.6250000>,
    <0.1250000, 0.6875988>,
    <0.0617704, 0.7500000>,
    <0.0000000, 0.6876164>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1875040, 0.6250000>,
    <0.2500000, 0.6875858>,
    <0.1875555, 0.7500000>,
    <0.1250000, 0.6875988>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3124860, 0.6250000>,
    <0.3750000, 0.6875792>,
    <0.3125397, 0.7500000>,
    <0.2500000, 0.6875858>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4375602, 0.6250000>,
    <0.5000000, 0.6875775>,
    <0.4375795, 0.7500000>,
    <0.3750000, 0.6875792>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5624187, 0.6250000>,
    <0.6250000, 0.6875797>,
    <0.5623962, 0.7500000>,
    <0.5000000, 0.6875775>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6874992, 0.6250000>,
    <0.7500000, 0.6875865>,
    <0.6874431, 0.7500000>,
    <0.6250000, 0.6875797>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8124934, 0.6250000>,
    <0.8750000, 0.6875998>,
    <0.8124443, 0.7500000>,
    <0.7500000, 0.6875865>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9382319, 0.6250000>,
    <1.0000000, 0.6876171>,
    <0.9382586, 0.7500000>,
    <0.8750000, 0.6875998>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0617704, 0.7500000>,
    <0.1250000, 0.8073802>,
    <0.0616999, 0.8750000>,
    <0.0000000, 0.8074480>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1875555, 0.7500000>,
    <0.2500000, 0.8073186>,
    <0.1875799, 0.8750000>,
    <0.1250000, 0.8073802>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3125397, 0.7500000>,
    <0.3750000, 0.8072807>,
    <0.3125962, 0.8750000>,
    <0.2500000, 0.8073186>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4375795, 0.7500000>,
    <0.5000000, 0.8072660>,
    <0.4376025, 0.8750000>,
    <0.3750000, 0.8072807>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5623962, 0.7500000>,
    <0.6250000, 0.8072732>,
    <0.5623726, 0.8750000>,
    <0.5000000, 0.8072660>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6874431, 0.7500000>,
    <0.7500000, 0.8073034>,
    <0.6873862, 0.8750000>,
    <0.6250000, 0.8072732>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8124443, 0.7500000>,
    <0.8750000, 0.8073573>,
    <0.8124200, 0.8750000>,
    <0.7500000, 0.8073034>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9382586, 0.7500000>,
    <1.0000000, 0.8074192>,
    <0.9383311, 0.8750000>,
    <0.8750000, 0.8073573>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0616999, 0.8750000>,
    <0.1250000, 0.9320202>,
    <0.0615789, 1.0000000>,
    <0.0000000, 0.9322578>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1875799, 0.8750000>,
    <0.2500000, 0.9318264>,
    <0.1875879, 1.0000000>,
    <0.1250000, 0.9320202>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3125962, 0.8750000>,
    <0.3750000, 0.9317158>,
    <0.3126691, 1.0000000>,
    <0.2500000, 0.9318264>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4376025, 0.8750000>,
    <0.5000000, 0.9316637>,
    <0.4376349, 1.0000000>,
    <0.3750000, 0.9317158>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5623726, 0.8750000>,
    <0.6250000, 0.9316564>,
    <0.5623433, 1.0000000>,
    <0.5000000, 0.9316637>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6873862, 0.8750000>,
    <0.7500000, 0.9317083>,
    <0.6873154, 1.0000000>,
    <0.6250000, 0.9316564>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8124200, 0.8750000>,
    <0.8750000, 0.9318490>,
    <0.8124087, 1.0000000>,
    <0.7500000, 0.9317083>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9383311, 0.8750000>,
    <1.0000000, 0.9320530>,
    <0.9384539, 1.0000000>,
    <0.8750000, 0.9318490>,
    <0.0625000, 0.0625000>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0603763, 0.0000000>,
    <0.1250000, 0.0607689>,
    <0.0603054, 0.1250000>,
    <0.0000000, 0.0607970>,
    <0.1875000, 0.0625000>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1886658, 0.0000000>,
    <0.2500000, 0.0607880>,
    <0.1890011, 0.1250000>,
    <0.1250000, 0.0607689>,
    <0.3125000, 0.0625000>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.3140156, 0.0000000>,
    <0.3750000, 0.0608267>,
    <0.3142204, 0.1250000>,
    <0.2500000, 0.0607880>,
    <0.4375000, 0.0625000>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4381163, 0.0000000>,
    <0.5000000, 0.0608485>,
    <0.4381725, 0.1250000>,
    <0.3750000, 0.0608267>,
    <0.5625000, 0.0625000>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5618835, 0.0000000>,
    <0.6250000, 0.0608372>,
    <0.5618255, 0.1250000>,
    <0.5000000, 0.0608485>,
    <0.6875000, 0.0625000>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6859842, 0.0000000>,
    <0.7500000, 0.0608065>,
    <0.6857778, 0.1250000>,
    <0.6250000, 0.0608372>,
    <0.8125000, 0.0625000>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.8113588, 0.0000000>,
    <0.8750000, 0.0607909>,
    <0.8110202, 0.1250000>,
    <0.7500000, 0.0608065>,
    <0.9375000, 0.0625000>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9395979, 0.0000000>,
    <1.0000000, 0.0608164>,
    <0.9396761, 0.1250000>,
    <0.8750000, 0.0607909>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0603054, 0.1250000>,
    <0.1250000, 0.1880032>,
    <0.0602688, 0.2500000>,
    <0.0000000, 0.1880258>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1890011, 0.1250000>,
    <0.2500000, 0.1880364>,
    <0.1892384, 0.2500000>,
    <0.1250000, 0.1880032>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3142204, 0.1250000>,
    <0.3750000, 0.1880865>,
    <0.3143494, 0.2500000>,
    <0.2500000, 0.1880364>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4381725, 0.1250000>,
    <0.5000000, 0.1881092>,
    <0.4382056, 0.2500000>,
    <0.3750000, 0.1880865>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5618255, 0.1250000>,
    <0.6250000, 0.1880868>,
    <0.5617890, 0.2500000>,
    <0.5000000, 0.1881092>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6857778, 0.1250000>,
    <0.7500000, 0.1880372>,
    <0.6856455, 0.2500000>,
    <0.6250000, 0.1880868>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8110202, 0.1250000>,
    <0.8750000, 0.1880045>,
    <0.8107803, 0.2500000>,
    <0.7500000, 0.1880372>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9396761, 0.1250000>,
    <1.0000000, 0.1880275>,
    <0.9397238, 0.2500000>,
    <0.8750000, 0.1880045>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0602688, 0.2500000>,
    <0.1250000, 0.3127247>,
    <0.0602578, 0.3750000>,
    <0.0000000, 0.3127317>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1892384, 0.2500000>,
    <0.2500000, 0.3127403>,
    <0.1894046, 0.3750000>,
    <0.1250000, 0.3127247>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3143494, 0.2500000>,
    <0.3750000, 0.3127613>,
    <0.3144291, 0.3750000>,
    <0.2500000, 0.3127403>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4382056, 0.2500000>,
    <0.5000000, 0.3127695>,
    <0.4382243, 0.3750000>,
    <0.3750000, 0.3127613>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5617890, 0.2500000>,
    <0.6250000, 0.3127581>,
    <0.5617659, 0.3750000>,
    <0.5000000, 0.3127695>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6856455, 0.2500000>,
    <0.7500000, 0.3127348>,
    <0.6855617, 0.3750000>,
    <0.6250000, 0.3127581>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8107803, 0.2500000>,
    <0.8750000, 0.3127185>,
    <0.8106117, 0.3750000>,
    <0.7500000, 0.3127348>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9397238, 0.2500000>,
    <1.0000000, 0.3127267>,
    <0.9397477, 0.3750000>,
    <0.8750000, 0.3127185>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0602578, 0.3750000>,
    <0.1250000, 0.4375916>,
    <0.0602692, 0.5000000>,
    <0.0000000, 0.4375944>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1894046, 0.3750000>,
    <0.2500000, 0.4376050>,
    <0.1895059, 0.5000000>,
    <0.1250000, 0.4375916>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3144291, 0.3750000>,
    <0.3750000, 0.4376211>,
    <0.3144680, 0.5000000>,
    <0.2500000, 0.4376050>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4382243, 0.3750000>,
    <0.5000000, 0.4376262>,
    <0.4382318, 0.5000000>,
    <0.3750000, 0.4376211>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5617659, 0.3750000>,
    <0.6250000, 0.4376154>,
    <0.5617541, 0.5000000>,
    <0.5000000, 0.4376262>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6855617, 0.3750000>,
    <0.7500000, 0.4375950>,
    <0.6855185, 0.5000000>,
    <0.6250000, 0.4376154>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8106117, 0.3750000>,
    <0.8750000, 0.4375799>,
    <0.8105084, 0.5000000>,
    <0.7500000, 0.4375950>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9397477, 0.3750000>,
    <1.0000000, 0.4375845>,
    <0.9397491, 0.5000000>,
    <0.8750000, 0.4375799>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0602692, 0.5000000>,
    <0.1250000, 0.5625642>,
    <0.0603030, 0.6250000>,
    <0.0000000, 0.5625559>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1895059, 0.5000000>,
    <0.2500000, 0.5625700>,
    <0.1895351, 0.6250000>,
    <0.1250000, 0.5625642>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3144680, 0.5000000>,
    <0.3750000, 0.5625713>,
    <0.3144652, 0.6250000>,
    <0.2500000, 0.5625700>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4382318, 0.5000000>,
    <0.5000000, 0.5625688>,
    <0.4382282, 0.6250000>,
    <0.3750000, 0.5625713>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5617541, 0.5000000>,
    <0.6250000, 0.5625635>,
    <0.5617538, 0.6250000>,
    <0.5000000, 0.5625688>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6855185, 0.5000000>,
    <0.7500000, 0.5625562>,
    <0.6855175, 0.6250000>,
    <0.6250000, 0.5625635>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8105084, 0.5000000>,
    <0.8750000, 0.5625477>,
    <0.8104778, 0.6250000>,
    <0.7500000, 0.5625562>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9397491, 0.5000000>,
    <1.0000000, 0.5625413>,
    <0.9397262, 0.6250000>,
    <0.8750000, 0.5625477>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0603030, 0.6250000>,
    <0.1250000, 0.6876339>,
    <0.0603614, 0.7500000>,
    <0.0000000, 0.6876171>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1895351, 0.6250000>,
    <0.2500000, 0.6876171>,
    <0.1894741, 0.7500000>,
    <0.1250000, 0.6876339>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3144652, 0.6250000>,
    <0.3750000, 0.6875890>,
    <0.3144117, 0.7500000>,
    <0.2500000, 0.6876171>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4382282, 0.6250000>,
    <0.5000000, 0.6875761>,
    <0.4382114, 0.7500000>,
    <0.3750000, 0.6875890>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5617538, 0.6250000>,
    <0.6250000, 0.6875889>,
    <0.5617678, 0.7500000>,
    <0.5000000, 0.6875761>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6855175, 0.6250000>,
    <0.7500000, 0.6876170>,
    <0.6855684, 0.7500000>,
    <0.6250000, 0.6875889>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8104778, 0.6250000>,
    <0.8750000, 0.6876335>,
    <0.8105382, 0.7500000>,
    <0.7500000, 0.6876170>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9397262, 0.6250000>,
    <1.0000000, 0.6876164>,
    <0.9396745, 0.7500000>,
    <0.8750000, 0.6876335>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0603614, 0.7500000>,
    <0.1250000, 0.8074704>,
    <0.0604475, 0.8750000>,
    <0.0000000, 0.8074192>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1894741, 0.7500000>,
    <0.2500000, 0.8073958>,
    <0.1892901, 0.8750000>,
    <0.1250000, 0.8074704>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3144117, 0.7500000>,
    <0.3750000, 0.8072835>,
    <0.3142877, 0.8750000>,
    <0.2500000, 0.8073958>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4382114, 0.7500000>,
    <0.5000000, 0.8072379>,
    <0.4381759, 0.8750000>,
    <0.3750000, 0.8072835>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5617678, 0.7500000>,
    <0.6250000, 0.8073003>,
    <0.5618024, 0.8750000>,
    <0.5000000, 0.8072379>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6855684, 0.7500000>,
    <0.7500000, 0.8074250>,
    <0.6856920, 0.8750000>,
    <0.6250000, 0.8073003>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8105382, 0.7500000>,
    <0.8750000, 0.8075043>,
    <0.8107231, 0.8750000>,
    <0.7500000, 0.8074250>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9396745, 0.7500000>,
    <1.0000000, 0.8074480>,
    <0.9395879, 0.8750000>,
    <0.8750000, 0.8075043>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0604475, 0.8750000>,
    <0.1250000, 0.9322696>,
    <0.0605636, 1.0000000>,
    <0.0000000, 0.9320530>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1892901, 0.8750000>,
    <0.2500000, 0.9320245>,
    <0.1889796, 1.0000000>,
    <0.1250000, 0.9322696>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3142877, 0.8750000>,
    <0.3750000, 0.9315999>,
    <0.3140799, 1.0000000>,
    <0.2500000, 0.9320245>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4381759, 0.8750000>,
    <0.5000000, 0.9314337>,
    <0.4381169, 1.0000000>,
    <0.3750000, 0.9315999>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5618024, 0.8750000>,
    <0.6250000, 0.9317311>,
    <0.5618636, 1.0000000>,
    <0.5000000, 0.9314337>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6856920, 0.8750000>,
    <0.7500000, 0.9322335>,
    <0.6859027, 1.0000000>,
    <0.6250000, 0.9317311>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8107231, 0.8750000>,
    <0.8750000, 0.9324999>,
    <0.8110362, 1.0000000>,
    <0.7500000, 0.9322335>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9395879, 0.8750000>,
    <1.0000000, 0.9322578>,
    <0.9394615, 1.0000000>,
    <0.8750000, 0.9324999>,
    <0.0625000, 0.0625000>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0615789, 0.0000000>,
    <0.1250000, 0.0643864>,
    <0.0615114, 0.1250000>,
    <0.0000000, 0.0641146>,
    <0.1875000, 0.0625000>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1875879, 0.0000000>,
    <0.2500000, 0.0647801>,
    <0.1878429, 0.1250000>,
    <0.1250000, 0.0643864>,
    <0.3125000, 0.0625000>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.3126691, 0.0000000>,
    <0.3750000, 0.0650832>,
    <0.3129062, 0.1250000>,
    <0.2500000, 0.0647801>,
    <0.4375000, 0.0625000>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4376349, 0.0000000>,
    <0.5000000, 0.0652025>,
    <0.4377214, 0.1250000>,
    <0.3750000, 0.0650832>,
    <0.5625000, 0.0625000>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5623433, 0.0000000>,
    <0.6250000, 0.0651123>,
    <0.5622623, 0.1250000>,
    <0.5000000, 0.0652025>,
    <0.6875000, 0.0625000>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6873154, 0.0000000>,
    <0.7500000, 0.0648362>,
    <0.6870817, 0.1250000>,
    <0.6250000, 0.0651123>,
    <0.8125000, 0.0625000>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.8124087, 0.0000000>,
    <0.8750000, 0.0644635>,
    <0.8121465, 0.1250000>,
    <0.7500000, 0.0648362>,
    <0.9375000, 0.0625000>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9384539, 0.0000000>,
    <1.0000000, 0.0642016>,
    <0.9385243, 0.1250000>,
    <0.8750000, 0.0644635>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0615114, 0.1250000>,
    <0.1250000, 0.1868813>,
    <0.0616971, 0.2500000>,
    <0.0000000, 0.1867408>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1878429, 0.1250000>,
    <0.2500000, 0.1870854>,
    <0.1888692, 0.2500000>,
    <0.1250000, 0.1868813>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3129062, 0.1250000>,
    <0.3750000, 0.1872300>,
    <0.3135239, 0.2500000>,
    <0.2500000, 0.1870854>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4377214, 0.1250000>,
    <0.5000000, 0.1872847>,
    <0.4379145, 0.2500000>,
    <0.3750000, 0.1872300>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5622623, 0.1250000>,
    <0.6250000, 0.1872457>,
    <0.5620746, 0.2500000>,
    <0.5000000, 0.1872847>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6870817, 0.1250000>,
    <0.7500000, 0.1871179>,
    <0.6864666, 0.2500000>,
    <0.6250000, 0.1872457>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8121465, 0.1250000>,
    <0.8750000, 0.1869312>,
    <0.8111089, 0.2500000>,
    <0.7500000, 0.1871179>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9385243, 0.1250000>,
    <1.0000000, 0.1868019>,
    <0.9383469, 0.2500000>,
    <0.8750000, 0.1869312>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0616971, 0.2500000>,
    <0.1250000, 0.3130045>,
    <0.0621526, 0.3750000>,
    <0.0000000, 0.3130249>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1888692, 0.2500000>,
    <0.2500000, 0.3130112>,
    <0.1904636, 0.3750000>,
    <0.1250000, 0.3130045>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3135239, 0.2500000>,
    <0.3750000, 0.3130194>,
    <0.3142501, 0.3750000>,
    <0.2500000, 0.3130112>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4379145, 0.2500000>,
    <0.5000000, 0.3130239>,
    <0.4381159, 0.3750000>,
    <0.3750000, 0.3130194>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5620746, 0.2500000>,
    <0.6250000, 0.3130246>,
    <0.5618776, 0.3750000>,
    <0.5000000, 0.3130239>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6864666, 0.2500000>,
    <0.7500000, 0.3130226>,
    <0.6857433, 0.3750000>,
    <0.6250000, 0.3130246>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8111089, 0.2500000>,
    <0.8750000, 0.3130237>,
    <0.8095019, 0.3750000>,
    <0.7500000, 0.3130226>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9383469, 0.2500000>,
    <1.0000000, 0.3130513>,
    <0.9379050, 0.3750000>,
    <0.8750000, 0.3130237>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0621526, 0.3750000>,
    <0.1250000, 0.4390537>,
    <0.0632968, 0.5000000>,
    <0.0000000, 0.4391789>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1904636, 0.3750000>,
    <0.2500000, 0.4388797>,
    <0.1927117, 0.5000000>,
    <0.1250000, 0.4390537>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3142501, 0.3750000>,
    <0.3750000, 0.4387499>,
    <0.3149815, 0.5000000>,
    <0.2500000, 0.4388797>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4381159, 0.3750000>,
    <0.5000000, 0.4387035>,
    <0.4382958, 0.5000000>,
    <0.3750000, 0.4387499>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5618776, 0.3750000>,
    <0.6250000, 0.4387501>,
    <0.5617011, 0.5000000>,
    <0.5000000, 0.4387035>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6857433, 0.3750000>,
    <0.7500000, 0.4388803>,
    <0.6850147, 0.5000000>,
    <0.6250000, 0.4387501>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8095019, 0.3750000>,
    <0.8750000, 0.4390557>,
    <0.8072412, 0.5000000>,
    <0.7500000, 0.4388803>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9379050, 0.3750000>,
    <1.0000000, 0.4391840>,
    <0.9367864, 0.5000000>,
    <0.8750000, 0.4390557>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0632968, 0.5000000>,
    <0.1250000, 0.5646253>,
    <0.0660525, 0.6250000>,
    <0.0000000, 0.5647443>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1927117, 0.5000000>,
    <0.2500000, 0.5644729>,
    <0.1950463, 0.6250000>,
    <0.1250000, 0.5646253>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3149815, 0.5000000>,
    <0.3750000, 0.5643637>,
    <0.3155229, 0.6250000>,
    <0.2500000, 0.5644729>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4382958, 0.5000000>,
    <0.5000000, 0.5643244>,
    <0.4384164, 0.6250000>,
    <0.3750000, 0.5643637>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5617011, 0.5000000>,
    <0.6250000, 0.5643607>,
    <0.5615823, 0.6250000>,
    <0.5000000, 0.5643244>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6850147, 0.5000000>,
    <0.7500000, 0.5644669>,
    <0.6844754, 0.6250000>,
    <0.6250000, 0.5643607>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8072412, 0.5000000>,
    <0.8750000, 0.5646171>,
    <0.8048989, 0.6250000>,
    <0.7500000, 0.5644669>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9367864, 0.5000000>,
    <1.0000000, 0.5647363>,
    <0.9340717, 0.6250000>,
    <0.8750000, 0.5646171>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0660525, 0.6250000>,
    <0.1250000, 0.6901042>,
    <0.0509506, 0.7500000>,
    <0.0000000, 0.6859452>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1950463, 0.6250000>,
    <0.2500000, 0.6899778>,
    <0.1968211, 0.7500000>,
    <0.1250000, 0.6901042>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3155229, 0.6250000>,
    <0.3750000, 0.6898745>,
    <0.3158366, 0.7500000>,
    <0.2500000, 0.6899778>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4384164, 0.6250000>,
    <0.5000000, 0.6898356>,
    <0.4384819, 0.7500000>,
    <0.3750000, 0.6898745>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5615823, 0.6250000>,
    <0.6250000, 0.6898728>,
    <0.5615177, 0.7500000>,
    <0.5000000, 0.6898356>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6844754, 0.6250000>,
    <0.7500000, 0.6899745>,
    <0.6841629, 0.7500000>,
    <0.6250000, 0.6898728>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8048989, 0.6250000>,
    <0.8750000, 0.6900997>,
    <0.8031243, 0.7500000>,
    <0.7500000, 0.6899745>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9340717, 0.6250000>,
    <1.0000000, 0.6859340>,
    <0.9492727, 0.7500000>,
    <0.8750000, 0.6900997>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0509506, 0.7500000>,
    <0.1250000, 0.8162322>,
    <0.0801770, 0.8750000>,
    <0.0000000, 0.8348189>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1968211, 0.7500000>,
    <0.2500000, 0.8176578>,
    <0.1974133, 0.8750000>,
    <0.1250000, 0.8162322>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3158366, 0.7500000>,
    <0.3750000, 0.8188770>,
    <0.3159602, 0.8750000>,
    <0.2500000, 0.8176578>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4384819, 0.7500000>,
    <0.5000000, 0.8193516>,
    <0.4385052, 0.8750000>,
    <0.3750000, 0.8188770>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5615177, 0.7500000>,
    <0.6250000, 0.8188762>,
    <0.5614947, 0.8750000>,
    <0.5000000, 0.8193516>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6841629, 0.7500000>,
    <0.7500000, 0.8176563>,
    <0.6840397, 0.8750000>,
    <0.6250000, 0.8188762>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8031243, 0.7500000>,
    <0.8750000, 0.8162305>,
    <0.8025441, 0.8750000>,
    <0.7500000, 0.8176563>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9492727, 0.7500000>,
    <1.0000000, 0.8348215>,
    <0.9195858, 0.8750000>,
    <0.8750000, 0.8162305>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0801770, 0.8750000>,
    <0.1250000, 0.9183504>,
    <0.0748777, 1.0000000>,
    <0.0000000, 0.9180067>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1974133, 0.8750000>,
    <0.2500000, 0.9192416>,
    <0.1959103, 1.0000000>,
    <0.1250000, 0.9183504>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3159602, 0.8750000>,
    <0.3750000, 0.9198832>,
    <0.3157065, 1.0000000>,
    <0.2500000, 0.9192416>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4385052, 0.8750000>,
    <0.5000000, 0.9201043>,
    <0.4384028, 1.0000000>,
    <0.3750000, 0.9198832>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5614947, 0.8750000>,
    <0.6250000, 0.9198831>,
    <0.5615972, 1.0000000>,
    <0.5000000, 0.9201043>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6840397, 0.8750000>,
    <0.7500000, 0.9192414>,
    <0.6842935, 1.0000000>,
    <0.6250000, 0.9198831>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8025441, 0.8750000>,
    <0.8750000, 0.9183502>,
    <0.8040795, 1.0000000>,
    <0.7500000, 0.9192414>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9195858, 0.8750000>,
    <1.0000000, 0.9180098>,
    <0.9250748, 1.0000000>,
    <0.8750000, 0.9183502>,
    <0.0625000, 0.0625000>,
    <0.0000000, 0.0000000>,
    <0.1250000, 0.0000000>,
    <0.1250000, 0.1250000>,
    <0.0000000, 0.1250000>,
    <0.0605636, 0.0000000>,
    <0.1250000, 0.0641791>,
    <0.0607250, 0.1250000>,
    <0.0000000, 0.0642016>,
    <0.1875000, 0.0625000>,
    <0.1250000, 0.0000000>,
    <0.2500000, 0.0000000>,
    <0.2500000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1889796, 0.0000000>,
    <0.2500000, 0.0645898>,
    <0.1889074, 0.1250000>,
    <0.1250000, 0.0641791>,
    <0.3125000, 0.0625000>,
    <0.2500000, 0.0000000>,
    <0.3750000, 0.0000000>,
    <0.3750000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.3140799, 0.0000000>,
    <0.3750000, 0.0650785>,
    <0.3139598, 0.1250000>,
    <0.2500000, 0.0645898>,
    <0.4375000, 0.0625000>,
    <0.3750000, 0.0000000>,
    <0.5000000, 0.0000000>,
    <0.5000000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.4381169, 0.0000000>,
    <0.5000000, 0.0652747>,
    <0.4380782, 0.1250000>,
    <0.3750000, 0.0650785>,
    <0.5625000, 0.0625000>,
    <0.5000000, 0.0000000>,
    <0.6250000, 0.0000000>,
    <0.6250000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5618636, 0.0000000>,
    <0.6250000, 0.0650237>,
    <0.5619069, 0.1250000>,
    <0.5000000, 0.0652747>,
    <0.6875000, 0.0625000>,
    <0.6250000, 0.0000000>,
    <0.7500000, 0.0000000>,
    <0.7500000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6859027, 0.0000000>,
    <0.7500000, 0.0645032>,
    <0.6860271, 0.1250000>,
    <0.6250000, 0.0650237>,
    <0.8125000, 0.0625000>,
    <0.7500000, 0.0000000>,
    <0.8750000, 0.0000000>,
    <0.8750000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.8110362, 0.0000000>,
    <0.8750000, 0.0640844>,
    <0.8111117, 0.1250000>,
    <0.7500000, 0.0645032>,
    <0.9375000, 0.0625000>,
    <0.8750000, 0.0000000>,
    <1.0000000, 0.0000000>,
    <1.0000000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.9394615, 0.0000000>,
    <1.0000000, 0.0641146>,
    <0.9392848, 0.1250000>,
    <0.8750000, 0.0640844>,
    <0.0625000, 0.1875000>,
    <0.0000000, 0.1250000>,
    <0.1250000, 0.1250000>,
    <0.1250000, 0.2500000>,
    <0.0000000, 0.2500000>,
    <0.0607250, 0.1250000>,
    <0.1250000, 0.1868790>,
    <0.0610343, 0.2500000>,
    <0.0000000, 0.1868019>,
    <0.1875000, 0.1875000>,
    <0.1250000, 0.1250000>,
    <0.2500000, 0.1250000>,
    <0.2500000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1889074, 0.1250000>,
    <0.2500000, 0.1871571>,
    <0.1897108, 0.2500000>,
    <0.1250000, 0.1868790>,
    <0.3125000, 0.1875000>,
    <0.2500000, 0.1250000>,
    <0.3750000, 0.1250000>,
    <0.3750000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.3139598, 0.1250000>,
    <0.3750000, 0.1874158>,
    <0.3142239, 0.2500000>,
    <0.2500000, 0.1871571>,
    <0.4375000, 0.1875000>,
    <0.3750000, 0.1250000>,
    <0.5000000, 0.1250000>,
    <0.5000000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.4380782, 0.1250000>,
    <0.5000000, 0.1875068>,
    <0.4381380, 0.2500000>,
    <0.3750000, 0.1874158>,
    <0.5625000, 0.1875000>,
    <0.5000000, 0.1250000>,
    <0.6250000, 0.1250000>,
    <0.6250000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5619069, 0.1250000>,
    <0.6250000, 0.1873841>,
    <0.5618517, 0.2500000>,
    <0.5000000, 0.1875068>,
    <0.6875000, 0.1875000>,
    <0.6250000, 0.1250000>,
    <0.7500000, 0.1250000>,
    <0.7500000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6860271, 0.1250000>,
    <0.7500000, 0.1871004>,
    <0.6857662, 0.2500000>,
    <0.6250000, 0.1873841>,
    <0.8125000, 0.1875000>,
    <0.7500000, 0.1250000>,
    <0.8750000, 0.1250000>,
    <0.8750000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.8111117, 0.1250000>,
    <0.8750000, 0.1868105>,
    <0.8103123, 0.2500000>,
    <0.7500000, 0.1871004>,
    <0.9375000, 0.1875000>,
    <0.8750000, 0.1250000>,
    <1.0000000, 0.1250000>,
    <1.0000000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.9392848, 0.1250000>,
    <1.0000000, 0.1867408>,
    <0.9389591, 0.2500000>,
    <0.8750000, 0.1868105>,
    <0.0625000, 0.3125000>,
    <0.0000000, 0.2500000>,
    <0.1250000, 0.2500000>,
    <0.1250000, 0.3750000>,
    <0.0000000, 0.3750000>,
    <0.0610343, 0.2500000>,
    <0.1250000, 0.3131376>,
    <0.0615935, 0.3750000>,
    <0.0000000, 0.3130513>,
    <0.1875000, 0.3125000>,
    <0.1250000, 0.2500000>,
    <0.2500000, 0.2500000>,
    <0.2500000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1897108, 0.2500000>,
    <0.2500000, 0.3132611>,
    <0.1910942, 0.3750000>,
    <0.1250000, 0.3131376>,
    <0.3125000, 0.3125000>,
    <0.2500000, 0.2500000>,
    <0.3750000, 0.2500000>,
    <0.3750000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.3142239, 0.2500000>,
    <0.3750000, 0.3133579>,
    <0.3146533, 0.3750000>,
    <0.2500000, 0.3132611>,
    <0.4375000, 0.3125000>,
    <0.3750000, 0.2500000>,
    <0.5000000, 0.2500000>,
    <0.5000000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.4381380, 0.2500000>,
    <0.5000000, 0.3133891>,
    <0.4382358, 0.3750000>,
    <0.3750000, 0.3133579>,
    <0.5625000, 0.3125000>,
    <0.5000000, 0.2500000>,
    <0.6250000, 0.2500000>,
    <0.6250000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5618517, 0.2500000>,
    <0.6250000, 0.3133438>,
    <0.5617580, 0.3750000>,
    <0.5000000, 0.3133891>,
    <0.6875000, 0.3125000>,
    <0.6250000, 0.2500000>,
    <0.7500000, 0.2500000>,
    <0.7500000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6857662, 0.2500000>,
    <0.7500000, 0.3132354>,
    <0.6853400, 0.3750000>,
    <0.6250000, 0.3133438>,
    <0.8125000, 0.3125000>,
    <0.7500000, 0.2500000>,
    <0.8750000, 0.2500000>,
    <0.8750000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.8103123, 0.2500000>,
    <0.8750000, 0.3131064>,
    <0.8089356, 0.3750000>,
    <0.7500000, 0.3132354>,
    <0.9375000, 0.3125000>,
    <0.8750000, 0.2500000>,
    <1.0000000, 0.2500000>,
    <1.0000000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.9389591, 0.2500000>,
    <1.0000000, 0.3130249>,
    <0.9383785, 0.3750000>,
    <0.8750000, 0.3131064>,
    <0.0625000, 0.4375000>,
    <0.0000000, 0.3750000>,
    <0.1250000, 0.3750000>,
    <0.1250000, 0.5000000>,
    <0.0000000, 0.5000000>,
    <0.0615935, 0.3750000>,
    <0.1250000, 0.4392069>,
    <0.0628215, 0.5000000>,
    <0.0000000, 0.4391840>,
    <0.1875000, 0.4375000>,
    <0.1250000, 0.3750000>,
    <0.2500000, 0.3750000>,
    <0.2500000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1910942, 0.3750000>,
    <0.2500000, 0.4391463>,
    <0.1931416, 0.5000000>,
    <0.1250000, 0.4392069>,
    <0.3125000, 0.4375000>,
    <0.2500000, 0.3750000>,
    <0.3750000, 0.3750000>,
    <0.3750000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.3146533, 0.3750000>,
    <0.3750000, 0.4390862>,
    <0.3151739, 0.5000000>,
    <0.2500000, 0.4391463>,
    <0.4375000, 0.4375000>,
    <0.3750000, 0.3750000>,
    <0.5000000, 0.3750000>,
    <0.5000000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.4382358, 0.3750000>,
    <0.5000000, 0.4390619>,
    <0.4383490, 0.5000000>,
    <0.3750000, 0.4390862>,
    <0.5625000, 0.4375000>,
    <0.5000000, 0.3750000>,
    <0.6250000, 0.3750000>,
    <0.6250000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5617580, 0.3750000>,
    <0.6250000, 0.4390821>,
    <0.5616479, 0.5000000>,
    <0.5000000, 0.4390619>,
    <0.6875000, 0.4375000>,
    <0.6250000, 0.3750000>,
    <0.7500000, 0.3750000>,
    <0.7500000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6853400, 0.3750000>,
    <0.7500000, 0.4391393>,
    <0.6848222, 0.5000000>,
    <0.6250000, 0.4390821>,
    <0.8125000, 0.4375000>,
    <0.7500000, 0.3750000>,
    <0.8750000, 0.3750000>,
    <0.8750000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.8089356, 0.3750000>,
    <0.8750000, 0.4391992>,
    <0.8068980, 0.5000000>,
    <0.7500000, 0.4391393>,
    <0.9375000, 0.4375000>,
    <0.8750000, 0.3750000>,
    <1.0000000, 0.3750000>,
    <1.0000000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.9383785, 0.3750000>,
    <1.0000000, 0.4391789>,
    <0.9371169, 0.5000000>,
    <0.8750000, 0.4391992>,
    <0.0625000, 0.5625000>,
    <0.0000000, 0.5000000>,
    <0.1250000, 0.5000000>,
    <0.1250000, 0.6250000>,
    <0.0000000, 0.6250000>,
    <0.0628215, 0.5000000>,
    <0.1250000, 0.5647285>,
    <0.0656713, 0.6250000>,
    <0.0000000, 0.5647363>,
    <0.1875000, 0.5625000>,
    <0.1250000, 0.5000000>,
    <0.2500000, 0.5000000>,
    <0.2500000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1931416, 0.5000000>,
    <0.2500000, 0.5646432>,
    <0.1952923, 0.6250000>,
    <0.1250000, 0.5647285>,
    <0.3125000, 0.5625000>,
    <0.2500000, 0.5000000>,
    <0.3750000, 0.5000000>,
    <0.3750000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.3151739, 0.5000000>,
    <0.3750000, 0.5645658>,
    <0.3155961, 0.6250000>,
    <0.2500000, 0.5646432>,
    <0.4375000, 0.5625000>,
    <0.3750000, 0.5000000>,
    <0.5000000, 0.5000000>,
    <0.5000000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.4383490, 0.5000000>,
    <0.5000000, 0.5645371>,
    <0.4384357, 0.6250000>,
    <0.3750000, 0.5645658>,
    <0.5625000, 0.5625000>,
    <0.5000000, 0.5000000>,
    <0.6250000, 0.5000000>,
    <0.6250000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5616479, 0.5000000>,
    <0.6250000, 0.5645682>,
    <0.5615631, 0.6250000>,
    <0.5000000, 0.5645371>,
    <0.6875000, 0.5625000>,
    <0.6250000, 0.5000000>,
    <0.7500000, 0.5000000>,
    <0.7500000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6848222, 0.5000000>,
    <0.7500000, 0.5646481>,
    <0.6844022, 0.6250000>,
    <0.6250000, 0.5645682>,
    <0.8125000, 0.5625000>,
    <0.7500000, 0.5000000>,
    <0.8750000, 0.5000000>,
    <0.8750000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.8068980, 0.5000000>,
    <0.8750000, 0.5647357>,
    <0.8047567, 0.6250000>,
    <0.7500000, 0.5646481>,
    <0.9375000, 0.5625000>,
    <0.8750000, 0.5000000>,
    <1.0000000, 0.5000000>,
    <1.0000000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.9371169, 0.5000000>,
    <1.0000000, 0.5647443>,
    <0.9342163, 0.6250000>,
    <0.8750000, 0.5647357>,
    <0.0625000, 0.6875000>,
    <0.0000000, 0.6250000>,
    <0.1250000, 0.6250000>,
    <0.1250000, 0.7500000>,
    <0.0000000, 0.7500000>,
    <0.0656713, 0.6250000>,
    <0.1250000, 0.6901044>,
    <0.0487907, 0.7500000>,
    <0.0000000, 0.6859340>,
    <0.1875000, 0.6875000>,
    <0.1250000, 0.6250000>,
    <0.2500000, 0.6250000>,
    <0.2500000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1952923, 0.6250000>,
    <0.2500000, 0.6899844>,
    <0.1969392, 0.7500000>,
    <0.1250000, 0.6901044>,
    <0.3125000, 0.6875000>,
    <0.2500000, 0.6250000>,
    <0.3750000, 0.6250000>,
    <0.3750000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.3155961, 0.6250000>,
    <0.3750000, 0.6898873>,
    <0.3158567, 0.7500000>,
    <0.2500000, 0.6899844>,
    <0.4375000, 0.6875000>,
    <0.3750000, 0.6250000>,
    <0.5000000, 0.6250000>,
    <0.5000000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.4384357, 0.6250000>,
    <0.5000000, 0.6898519>,
    <0.4384871, 0.7500000>,
    <0.3750000, 0.6898873>,
    <0.5625000, 0.6875000>,
    <0.5000000, 0.6250000>,
    <0.6250000, 0.6250000>,
    <0.6250000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5615631, 0.6250000>,
    <0.6250000, 0.6898889>,
    <0.5615126, 0.7500000>,
    <0.5000000, 0.6898519>,
    <0.6875000, 0.6875000>,
    <0.6250000, 0.6250000>,
    <0.7500000, 0.6250000>,
    <0.7500000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6844022, 0.6250000>,
    <0.7500000, 0.6899876>,
    <0.6841428, 0.7500000>,
    <0.6250000, 0.6898889>,
    <0.8125000, 0.6875000>,
    <0.7500000, 0.6250000>,
    <0.8750000, 0.6250000>,
    <0.8750000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.8047567, 0.6250000>,
    <0.8750000, 0.6901088>,
    <0.8031131, 0.7500000>,
    <0.7500000, 0.6899876>,
    <0.9375000, 0.6875000>,
    <0.8750000, 0.6250000>,
    <1.0000000, 0.6250000>,
    <1.0000000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.9342163, 0.6250000>,
    <1.0000000, 0.6859452>,
    <0.9509952, 0.7500000>,
    <0.8750000, 0.6901088>,
    <0.0625000, 0.8125000>,
    <0.0000000, 0.7500000>,
    <0.1250000, 0.7500000>,
    <0.1250000, 0.8750000>,
    <0.0000000, 0.8750000>,
    <0.0487907, 0.7500000>,
    <0.1250000, 0.8160756>,
    <0.0804540, 0.8750000>,
    <0.0000000, 0.8348215>,
    <0.1875000, 0.8125000>,
    <0.1250000, 0.7500000>,
    <0.2500000, 0.7500000>,
    <0.2500000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1969392, 0.7500000>,
    <0.2500000, 0.8172829>,
    <0.1974666, 0.8750000>,
    <0.1250000, 0.8160756>,
    <0.3125000, 0.8125000>,
    <0.2500000, 0.7500000>,
    <0.3750000, 0.7500000>,
    <0.3750000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.3158567, 0.7500000>,
    <0.3750000, 0.8183079>,
    <0.3159633, 0.8750000>,
    <0.2500000, 0.8172829>,
    <0.4375000, 0.8125000>,
    <0.3750000, 0.7500000>,
    <0.5000000, 0.7500000>,
    <0.5000000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.4384871, 0.7500000>,
    <0.5000000, 0.8187064>,
    <0.4385060, 0.8750000>,
    <0.3750000, 0.8183079>,
    <0.5625000, 0.8125000>,
    <0.5000000, 0.7500000>,
    <0.6250000, 0.7500000>,
    <0.6250000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5615126, 0.7500000>,
    <0.6250000, 0.8183088>,
    <0.5614939, 0.8750000>,
    <0.5000000, 0.8187064>,
    <0.6875000, 0.8125000>,
    <0.6250000, 0.7500000>,
    <0.7500000, 0.7500000>,
    <0.7500000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6841428, 0.7500000>,
    <0.7500000, 0.8172845>,
    <0.6840366, 0.8750000>,
    <0.6250000, 0.8183088>,
    <0.8125000, 0.8125000>,
    <0.7500000, 0.7500000>,
    <0.8750000, 0.7500000>,
    <0.8750000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.8031131, 0.7500000>,
    <0.8750000, 0.8160774>,
    <0.8025756, 0.8750000>,
    <0.7500000, 0.8172845>,
    <0.9375000, 0.8125000>,
    <0.8750000, 0.7500000>,
    <1.0000000, 0.7500000>,
    <1.0000000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.9509952, 0.7500000>,
    <1.0000000, 0.8348189>,
    <0.9197819, 0.8750000>,
    <0.8750000, 0.8160774>,
    <0.0625000, 0.9375000>,
    <0.0000000, 0.8750000>,
    <0.1250000, 0.8750000>,
    <0.1250000, 1.0000000>,
    <0.0000000, 1.0000000>,
    <0.0804540, 0.8750000>,
    <0.1250000, 0.9186692>,
    <0.0749252, 1.0000000>,
    <0.0000000, 0.9180098>,
    <0.1875000, 0.9375000>,
    <0.1250000, 0.8750000>,
    <0.2500000, 0.8750000>,
    <0.2500000, 1.0000000>,
    <0.1250000, 1.0000000>,
    <0.1974666, 0.8750000>,
    <0.2500000, 0.9196125>,
    <0.1959205, 1.0000000>,
    <0.1250000, 0.9186692>,
    <0.3125000, 0.9375000>,
    <0.2500000, 0.8750000>,
    <0.3750000, 0.8750000>,
    <0.3750000, 1.0000000>,
    <0.2500000, 1.0000000>,
    <0.3159633, 0.8750000>,
    <0.3750000, 0.9202227>,
    <0.3157065, 1.0000000>,
    <0.2500000, 0.9196125>,
    <0.4375000, 0.9375000>,
    <0.3750000, 0.8750000>,
    <0.5000000, 0.8750000>,
    <0.5000000, 1.0000000>,
    <0.3750000, 1.0000000>,
    <0.4385060, 0.8750000>,
    <0.5000000, 0.9204268>,
    <0.4384028, 1.0000000>,
    <0.3750000, 0.9202227>,
    <0.5625000, 0.9375000>,
    <0.5000000, 0.8750000>,
    <0.6250000, 0.8750000>,
    <0.6250000, 1.0000000>,
    <0.5000000, 1.0000000>,
    <0.5614939, 0.8750000>,
    <0.6250000, 0.9202228>,
    <0.5615972, 1.0000000>,
    <0.5000000, 0.9204268>,
    <0.6875000, 0.9375000>,
    <0.6250000, 0.8750000>,
    <0.7500000, 0.8750000>,
    <0.7500000, 1.0000000>,
    <0.6250000, 1.0000000>,
    <0.6840366, 0.8750000>,
    <0.7500000, 0.9196127>,
    <0.6842935, 1.0000000>,
    <0.6250000, 0.9202228>,
    <0.8125000, 0.9375000>,
    <0.7500000, 0.8750000>,
    <0.8750000, 0.8750000>,
    <0.8750000, 1.0000000>,
    <0.7500000, 1.0000000>,
    <0.8025756, 0.8750000>,
    <0.8750000, 0.9186694>,
    <0.8040897, 1.0000000>,
    <0.7500000, 0.9196127>,
    <0.9375000, 0.9375000>,
    <0.8750000, 0.8750000>,
    <1.0000000, 0.8750000>,
    <1.0000000, 1.0000000>,
    <0.8750000, 1.0000000>,
    <0.9197819, 0.8750000>,
    <1.0000000, 0.9180067>,
    <0.9251223, 1.0000000>,
    <0.8750000, 0.9186694>
  }
  texture_list {
    1,
    texture { T_Corps }
  }
  face_indices {
    3040,   // 0 triangles and 1520 quads
    <6, 5, 0>, 0,
    <6, 0, 3>, 0,
    <6, 3, 1>, 0,
    <6, 1, 4>, 0,
    <6, 4, 2>, 0,
    <6, 2, 5>, 0,
    <10, 3, 0>, 0,
    <10, 0, 8>, 0,
    <10, 8, 7>, 0,
    <10, 7, 9>, 0,
    <10, 9, 1>, 0,
    <10, 1, 3>, 0,
    <14, 8, 0>, 0,
    <14, 0, 12>, 0,
    <14, 12, 11>, 0,
    <14, 11, 13>, 0,
    <14, 13, 7>, 0,
    <14, 7, 8>, 0,
    <18, 12, 0>, 0,
    <18, 0, 16>, 0,
    <18, 16, 15>, 0,
    <18, 15, 17>, 0,
    <18, 17, 11>, 0,
    <18, 11, 12>, 0,
    <22, 16, 0>, 0,
    <22, 0, 20>, 0,
    <22, 20, 19>, 0,
    <22, 19, 21>, 0,
    <22, 21, 15>, 0,
    <22, 15, 16>, 0,
    <26, 20, 0>, 0,
    <26, 0, 24>, 0,
    <26, 24, 23>, 0,
    <26, 23, 25>, 0,
    <26, 25, 19>, 0,
    <26, 19, 20>, 0,
    <30, 24, 0>, 0,
    <30, 0, 28>, 0,
    <30, 28, 27>, 0,
    <30, 27, 29>, 0,
    <30, 29, 23>, 0,
    <30, 23, 24>, 0,
    <34, 28, 0>, 0,
    <34, 0, 32>, 0,
    <34, 32, 31>, 0,
    <34, 31, 33>, 0,
    <34, 33, 27>, 0,
    <34, 27, 28>, 0,
    <40, 39, 2>, 0,
    <40, 2, 4>, 0,
    <40, 4, 1>, 0,
    <40, 1, 37>, 0,
    <40, 37, 35>, 0,
    <40, 35, 38>, 0,
    <40, 38, 36>, 0,
    <40, 36, 39>, 0,
    <44, 37, 1>, 0,
    <44, 1, 9>, 0,
    <44, 9, 7>, 0,
    <44, 7, 42>, 0,
    <44, 42, 41>, 0,
    <44, 41, 43>, 0,
    <44, 43, 35>, 0,
    <44, 35, 37>, 0,
    <48, 42, 7>, 0,
    <48, 7, 13>, 0,
    <48, 13, 11>, 0,
    <48, 11, 46>, 0,
    <48, 46, 45>, 0,
    <48, 45, 47>, 0,
    <48, 47, 41>, 0,
    <48, 41, 42>, 0,
    <52, 46, 11>, 0,
    <52, 11, 17>, 0,
    <52, 17, 15>, 0,
    <52, 15, 50>, 0,
    <52, 50, 49>, 0,
    <52, 49, 51>, 0,
    <52, 51, 45>, 0,
    <52, 45, 46>, 0,
    <56, 50, 15>, 0,
    <56, 15, 21>, 0,
    <56, 21, 19>, 0,
    <56, 19, 54>, 0,
    <56, 54, 53>, 0,
    <56, 53, 55>, 0,
    <56, 55, 49>, 0,
    <56, 49, 50>, 0,
    <60, 54, 19>, 0,
    <60, 19, 25>, 0,
    <60, 25, 23>, 0,
    <60, 23, 58>, 0,
    <60, 58, 57>, 0,
    <60, 57, 59>, 0,
    <60, 59, 53>, 0,
    <60, 53, 54>, 0,
    <64, 58, 23>, 0,
    <64, 23, 29>, 0,
    <64, 29, 27>, 0,
    <64, 27, 62>, 0,
    <64, 62, 61>, 0,
    <64, 61, 63>, 0,
    <64, 63, 57>, 0,
    <64, 57, 58>, 0,
    <68, 62, 27>, 0,
    <68, 27, 33>, 0,
    <68, 33, 31>, 0,
    <68, 31, 66>, 0,
    <68, 66, 65>, 0,
    <68, 65, 67>, 0,
    <68, 67, 61>, 0,
    <68, 61, 62>, 0,
    <74, 73, 36>, 0,
    <74, 36, 38>, 0,
    <74, 38, 35>, 0,
    <74, 35, 71>, 0,
    <74, 71, 69>, 0,
    <74, 69, 72>, 0,
    <74, 72, 70>, 0,
    <74, 70, 73>, 0,
    <78, 71, 35>, 0,
    <78, 35, 43>, 0,
    <78, 43, 41>, 0,
    <78, 41, 76>, 0,
    <78, 76, 75>, 0,
    <78, 75, 77>, 0,
    <78, 77, 69>, 0,
    <78, 69, 71>, 0,
    <82, 76, 41>, 0,
    <82, 41, 47>, 0,
    <82, 47, 45>, 0,
    <82, 45, 80>, 0,
    <82, 80, 79>, 0,
    <82, 79, 81>, 0,
    <82, 81, 75>, 0,
    <82, 75, 76>, 0,
    <86, 80, 45>, 0,
    <86, 45, 51>, 0,
    <86, 51, 49>, 0,
    <86, 49, 84>, 0,
    <86, 84, 83>, 0,
    <86, 83, 85>, 0,
    <86, 85, 79>, 0,
    <86, 79, 80>, 0,
    <90, 84, 49>, 0,
    <90, 49, 55>, 0,
    <90, 55, 53>, 0,
    <90, 53, 88>, 0,
    <90, 88, 87>, 0,
    <90, 87, 89>, 0,
    <90, 89, 83>, 0,
    <90, 83, 84>, 0,
    <94, 88, 53>, 0,
    <94, 53, 59>, 0,
    <94, 59, 57>, 0,
    <94, 57, 92>, 0,
    <94, 92, 91>, 0,
    <94, 91, 93>, 0,
    <94, 93, 87>, 0,
    <94, 87, 88>, 0,
    <98, 92, 57>, 0,
    <98, 57, 63>, 0,
    <98, 63, 61>, 0,
    <98, 61, 96>, 0,
    <98, 96, 95>, 0,
    <98, 95, 97>, 0,
    <98, 97, 91>, 0,
    <98, 91, 92>, 0,
    <102, 96, 61>, 0,
    <102, 61, 67>, 0,
    <102, 67, 65>, 0,
    <102, 65, 100>, 0,
    <102, 100, 99>, 0,
    <102, 99, 101>, 0,
    <102, 101, 95>, 0,
    <102, 95, 96>, 0,
    <108, 107, 70>, 0,
    <108, 70, 72>, 0,
    <108, 72, 69>, 0,
    <108, 69, 105>, 0,
    <108, 105, 103>, 0,
    <108, 103, 106>, 0,
    <108, 106, 104>, 0,
    <108, 104, 107>, 0,
    <112, 105, 69>, 0,
    <112, 69, 77>, 0,
    <112, 77, 75>, 0,
    <112, 75, 110>, 0,
    <112, 110, 109>, 0,
    <112, 109, 111>, 0,
    <112, 111, 103>, 0,
    <112, 103, 105>, 0,
    <116, 110, 75>, 0,
    <116, 75, 81>, 0,
    <116, 81, 79>, 0,
    <116, 79, 114>, 0,
    <116, 114, 113>, 0,
    <116, 113, 115>, 0,
    <116, 115, 109>, 0,
    <116, 109, 110>, 0,
    <120, 114, 79>, 0,
    <120, 79, 85>, 0,
    <120, 85, 83>, 0,
    <120, 83, 118>, 0,
    <120, 118, 117>, 0,
    <120, 117, 119>, 0,
    <120, 119, 113>, 0,
    <120, 113, 114>, 0,
    <124, 118, 83>, 0,
    <124, 83, 89>, 0,
    <124, 89, 87>, 0,
    <124, 87, 122>, 0,
    <124, 122, 121>, 0,
    <124, 121, 123>, 0,
    <124, 123, 117>, 0,
    <124, 117, 118>, 0,
    <128, 122, 87>, 0,
    <128, 87, 93>, 0,
    <128, 93, 91>, 0,
    <128, 91, 126>, 0,
    <128, 126, 125>, 0,
    <128, 125, 127>, 0,
    <128, 127, 121>, 0,
    <128, 121, 122>, 0,
    <132, 126, 91>, 0,
    <132, 91, 97>, 0,
    <132, 97, 95>, 0,
    <132, 95, 130>, 0,
    <132, 130, 129>, 0,
    <132, 129, 131>, 0,
    <132, 131, 125>, 0,
    <132, 125, 126>, 0,
    <136, 130, 95>, 0,
    <136, 95, 101>, 0,
    <136, 101, 99>, 0,
    <136, 99, 134>, 0,
    <136, 134, 133>, 0,
    <136, 133, 135>, 0,
    <136, 135, 129>, 0,
    <136, 129, 130>, 0,
    <142, 141, 104>, 0,
    <142, 104, 106>, 0,
    <142, 106, 103>, 0,
    <142, 103, 139>, 0,
    <142, 139, 137>, 0,
    <142, 137, 140>, 0,
    <142, 140, 138>, 0,
    <142, 138, 141>, 0,
    <146, 139, 103>, 0,
    <146, 103, 111>, 0,
    <146, 111, 109>, 0,
    <146, 109, 144>, 0,
    <146, 144, 143>, 0,
    <146, 143, 145>, 0,
    <146, 145, 137>, 0,
    <146, 137, 139>, 0,
    <150, 144, 109>, 0,
    <150, 109, 115>, 0,
    <150, 115, 113>, 0,
    <150, 113, 148>, 0,
    <150, 148, 147>, 0,
    <150, 147, 149>, 0,
    <150, 149, 143>, 0,
    <150, 143, 144>, 0,
    <154, 148, 113>, 0,
    <154, 113, 119>, 0,
    <154, 119, 117>, 0,
    <154, 117, 152>, 0,
    <154, 152, 151>, 0,
    <154, 151, 153>, 0,
    <154, 153, 147>, 0,
    <154, 147, 148>, 0,
    <158, 152, 117>, 0,
    <158, 117, 123>, 0,
    <158, 123, 121>, 0,
    <158, 121, 156>, 0,
    <158, 156, 155>, 0,
    <158, 155, 157>, 0,
    <158, 157, 151>, 0,
    <158, 151, 152>, 0,
    <162, 156, 121>, 0,
    <162, 121, 127>, 0,
    <162, 127, 125>, 0,
    <162, 125, 160>, 0,
    <162, 160, 159>, 0,
    <162, 159, 161>, 0,
    <162, 161, 155>, 0,
    <162, 155, 156>, 0,
    <166, 160, 125>, 0,
    <166, 125, 131>, 0,
    <166, 131, 129>, 0,
    <166, 129, 164>, 0,
    <166, 164, 163>, 0,
    <166, 163, 165>, 0,
    <166, 165, 159>, 0,
    <166, 159, 160>, 0,
    <170, 164, 129>, 0,
    <170, 129, 135>, 0,
    <170, 135, 133>, 0,
    <170, 133, 168>, 0,
    <170, 168, 167>, 0,
    <170, 167, 169>, 0,
    <170, 169, 163>, 0,
    <170, 163, 164>, 0,
    <176, 175, 138>, 0,
    <176, 138, 140>, 0,
    <176, 140, 137>, 0,
    <176, 137, 173>, 0,
    <176, 173, 171>, 0,
    <176, 171, 174>, 0,
    <176, 174, 172>, 0,
    <176, 172, 175>, 0,
    <180, 173, 137>, 0,
    <180, 137, 145>, 0,
    <180, 145, 143>, 0,
    <180, 143, 178>, 0,
    <180, 178, 177>, 0,
    <180, 177, 179>, 0,
    <180, 179, 171>, 0,
    <180, 171, 173>, 0,
    <184, 178, 143>, 0,
    <184, 143, 149>, 0,
    <184, 149, 147>, 0,
    <184, 147, 182>, 0,
    <184, 182, 181>, 0,
    <184, 181, 183>, 0,
    <184, 183, 177>, 0,
    <184, 177, 178>, 0,
    <188, 182, 147>, 0,
    <188, 147, 153>, 0,
    <188, 153, 151>, 0,
    <188, 151, 186>, 0,
    <188, 186, 185>, 0,
    <188, 185, 187>, 0,
    <188, 187, 181>, 0,
    <188, 181, 182>, 0,
    <192, 186, 151>, 0,
    <192, 151, 157>, 0,
    <192, 157, 155>, 0,
    <192, 155, 190>, 0,
    <192, 190, 189>, 0,
    <192, 189, 191>, 0,
    <192, 191, 185>, 0,
    <192, 185, 186>, 0,
    <196, 190, 155>, 0,
    <196, 155, 161>, 0,
    <196, 161, 159>, 0,
    <196, 159, 194>, 0,
    <196, 194, 193>, 0,
    <196, 193, 195>, 0,
    <196, 195, 189>, 0,
    <196, 189, 190>, 0,
    <200, 194, 159>, 0,
    <200, 159, 165>, 0,
    <200, 165, 163>, 0,
    <200, 163, 198>, 0,
    <200, 198, 197>, 0,
    <200, 197, 199>, 0,
    <200, 199, 193>, 0,
    <200, 193, 194>, 0,
    <204, 198, 163>, 0,
    <204, 163, 169>, 0,
    <204, 169, 167>, 0,
    <204, 167, 202>, 0,
    <204, 202, 201>, 0,
    <204, 201, 203>, 0,
    <204, 203, 197>, 0,
    <204, 197, 198>, 0,
    <210, 209, 172>, 0,
    <210, 172, 174>, 0,
    <210, 174, 171>, 0,
    <210, 171, 207>, 0,
    <210, 207, 205>, 0,
    <210, 205, 208>, 0,
    <210, 208, 206>, 0,
    <210, 206, 209>, 0,
    <214, 207, 171>, 0,
    <214, 171, 179>, 0,
    <214, 179, 177>, 0,
    <214, 177, 212>, 0,
    <214, 212, 211>, 0,
    <214, 211, 213>, 0,
    <214, 213, 205>, 0,
    <214, 205, 207>, 0,
    <218, 212, 177>, 0,
    <218, 177, 183>, 0,
    <218, 183, 181>, 0,
    <218, 181, 216>, 0,
    <218, 216, 215>, 0,
    <218, 215, 217>, 0,
    <218, 217, 211>, 0,
    <218, 211, 212>, 0,
    <222, 216, 181>, 0,
    <222, 181, 187>, 0,
    <222, 187, 185>, 0,
    <222, 185, 220>, 0,
    <222, 220, 219>, 0,
    <222, 219, 221>, 0,
    <222, 221, 215>, 0,
    <222, 215, 216>, 0,
    <226, 220, 185>, 0,
    <226, 185, 191>, 0,
    <226, 191, 189>, 0,
    <226, 189, 224>, 0,
    <226, 224, 223>, 0,
    <226, 223, 225>, 0,
    <226, 225, 219>, 0,
    <226, 219, 220>, 0,
    <230, 224, 189>, 0,
    <230, 189, 195>, 0,
    <230, 195, 193>, 0,
    <230, 193, 228>, 0,
    <230, 228, 227>, 0,
    <230, 227, 229>, 0,
    <230, 229, 223>, 0,
    <230, 223, 224>, 0,
    <234, 228, 193>, 0,
    <234, 193, 199>, 0,
    <234, 199, 197>, 0,
    <234, 197, 232>, 0,
    <234, 232, 231>, 0,
    <234, 231, 233>, 0,
    <234, 233, 227>, 0,
    <234, 227, 228>, 0,
    <238, 232, 197>, 0,
    <238, 197, 203>, 0,
    <238, 203, 201>, 0,
    <238, 201, 236>, 0,
    <238, 236, 235>, 0,
    <238, 235, 237>, 0,
    <238, 237, 231>, 0,
    <238, 231, 232>, 0,
    <244, 243, 206>, 0,
    <244, 206, 208>, 0,
    <244, 208, 205>, 0,
    <244, 205, 241>, 0,
    <244, 241, 239>, 0,
    <244, 239, 242>, 0,
    <244, 242, 240>, 0,
    <244, 240, 243>, 0,
    <248, 241, 205>, 0,
    <248, 205, 213>, 0,
    <248, 213, 211>, 0,
    <248, 211, 246>, 0,
    <248, 246, 245>, 0,
    <248, 245, 247>, 0,
    <248, 247, 239>, 0,
    <248, 239, 241>, 0,
    <252, 246, 211>, 0,
    <252, 211, 217>, 0,
    <252, 217, 215>, 0,
    <252, 215, 250>, 0,
    <252, 250, 249>, 0,
    <252, 249, 251>, 0,
    <252, 251, 245>, 0,
    <252, 245, 246>, 0,
    <256, 250, 215>, 0,
    <256, 215, 221>, 0,
    <256, 221, 219>, 0,
    <256, 219, 254>, 0,
    <256, 254, 253>, 0,
    <256, 253, 255>, 0,
    <256, 255, 249>, 0,
    <256, 249, 250>, 0,
    <260, 254, 219>, 0,
    <260, 219, 225>, 0,
    <260, 225, 223>, 0,
    <260, 223, 258>, 0,
    <260, 258, 257>, 0,
    <260, 257, 259>, 0,
    <260, 259, 253>, 0,
    <260, 253, 254>, 0,
    <264, 258, 223>, 0,
    <264, 223, 229>, 0,
    <264, 229, 227>, 0,
    <264, 227, 262>, 0,
    <264, 262, 261>, 0,
    <264, 261, 263>, 0,
    <264, 263, 257>, 0,
    <264, 257, 258>, 0,
    <268, 262, 227>, 0,
    <268, 227, 233>, 0,
    <268, 233, 231>, 0,
    <268, 231, 266>, 0,
    <268, 266, 265>, 0,
    <268, 265, 267>, 0,
    <268, 267, 261>, 0,
    <268, 261, 262>, 0,
    <272, 266, 231>, 0,
    <272, 231, 237>, 0,
    <272, 237, 235>, 0,
    <272, 235, 270>, 0,
    <272, 270, 269>, 0,
    <272, 269, 271>, 0,
    <272, 271, 265>, 0,
    <272, 265, 266>, 0,
    <276, 32, 0>, 0,
    <276, 0, 274>, 0,
    <276, 274, 273>, 0,
    <276, 273, 275>, 0,
    <276, 275, 31>, 0,
    <276, 31, 32>, 0,
    <280, 274, 0>, 0,
    <280, 0, 278>, 0,
    <280, 278, 277>, 0,
    <280, 277, 279>, 0,
    <280, 279, 273>, 0,
    <280, 273, 274>, 0,
    <284, 278, 0>, 0,
    <284, 0, 282>, 0,
    <284, 282, 281>, 0,
    <284, 281, 283>, 0,
    <284, 283, 277>, 0,
    <284, 277, 278>, 0,
    <288, 282, 0>, 0,
    <288, 0, 286>, 0,
    <288, 286, 285>, 0,
    <288, 285, 287>, 0,
    <288, 287, 281>, 0,
    <288, 281, 282>, 0,
    <292, 286, 0>, 0,
    <292, 0, 290>, 0,
    <292, 290, 289>, 0,
    <292, 289, 291>, 0,
    <292, 291, 285>, 0,
    <292, 285, 286>, 0,
    <296, 290, 0>, 0,
    <296, 0, 294>, 0,
    <296, 294, 293>, 0,
    <296, 293, 295>, 0,
    <296, 295, 289>, 0,
    <296, 289, 290>, 0,
    <300, 294, 0>, 0,
    <300, 0, 298>, 0,
    <300, 298, 297>, 0,
    <300, 297, 299>, 0,
    <300, 299, 293>, 0,
    <300, 293, 294>, 0,
    <302, 298, 0>, 0,
    <302, 0, 5>, 0,
    <302, 5, 2>, 0,
    <302, 2, 301>, 0,
    <302, 301, 297>, 0,
    <302, 297, 298>, 0,
    <306, 66, 31>, 0,
    <306, 31, 275>, 0,
    <306, 275, 273>, 0,
    <306, 273, 304>, 0,
    <306, 304, 303>, 0,
    <306, 303, 305>, 0,
    <306, 305, 65>, 0,
    <306, 65, 66>, 0,
    <310, 304, 273>, 0,
    <310, 273, 279>, 0,
    <310, 279, 277>, 0,
    <310, 277, 308>, 0,
    <310, 308, 307>, 0,
    <310, 307, 309>, 0,
    <310, 309, 303>, 0,
    <310, 303, 304>, 0,
    <314, 308, 277>, 0,
    <314, 277, 283>, 0,
    <314, 283, 281>, 0,
    <314, 281, 312>, 0,
    <314, 312, 311>, 0,
    <314, 311, 313>, 0,
    <314, 313, 307>, 0,
    <314, 307, 308>, 0,
    <318, 312, 281>, 0,
    <318, 281, 287>, 0,
    <318, 287, 285>, 0,
    <318, 285, 316>, 0,
    <318, 316, 315>, 0,
    <318, 315, 317>, 0,
    <318, 317, 311>, 0,
    <318, 311, 312>, 0,
    <322, 316, 285>, 0,
    <322, 285, 291>, 0,
    <322, 291, 289>, 0,
    <322, 289, 320>, 0,
    <322, 320, 319>, 0,
    <322, 319, 321>, 0,
    <322, 321, 315>, 0,
    <322, 315, 316>, 0,
    <326, 320, 289>, 0,
    <326, 289, 295>, 0,
    <326, 295, 293>, 0,
    <326, 293, 324>, 0,
    <326, 324, 323>, 0,
    <326, 323, 325>, 0,
    <326, 325, 319>, 0,
    <326, 319, 320>, 0,
    <330, 324, 293>, 0,
    <330, 293, 299>, 0,
    <330, 299, 297>, 0,
    <330, 297, 328>, 0,
    <330, 328, 327>, 0,
    <330, 327, 329>, 0,
    <330, 329, 323>, 0,
    <330, 323, 324>, 0,
    <332, 328, 297>, 0,
    <332, 297, 301>, 0,
    <332, 301, 2>, 0,
    <332, 2, 39>, 0,
    <332, 39, 36>, 0,
    <332, 36, 331>, 0,
    <332, 331, 327>, 0,
    <332, 327, 328>, 0,
    <336, 100, 65>, 0,
    <336, 65, 305>, 0,
    <336, 305, 303>, 0,
    <336, 303, 334>, 0,
    <336, 334, 333>, 0,
    <336, 333, 335>, 0,
    <336, 335, 99>, 0,
    <336, 99, 100>, 0,
    <340, 334, 303>, 0,
    <340, 303, 309>, 0,
    <340, 309, 307>, 0,
    <340, 307, 338>, 0,
    <340, 338, 337>, 0,
    <340, 337, 339>, 0,
    <340, 339, 333>, 0,
    <340, 333, 334>, 0,
    <344, 338, 307>, 0,
    <344, 307, 313>, 0,
    <344, 313, 311>, 0,
    <344, 311, 342>, 0,
    <344, 342, 341>, 0,
    <344, 341, 343>, 0,
    <344, 343, 337>, 0,
    <344, 337, 338>, 0,
    <348, 342, 311>, 0,
    <348, 311, 317>, 0,
    <348, 317, 315>, 0,
    <348, 315, 346>, 0,
    <348, 346, 345>, 0,
    <348, 345, 347>, 0,
    <348, 347, 341>, 0,
    <348, 341, 342>, 0,
    <352, 346, 315>, 0,
    <352, 315, 321>, 0,
    <352, 321, 319>, 0,
    <352, 319, 350>, 0,
    <352, 350, 349>, 0,
    <352, 349, 351>, 0,
    <352, 351, 345>, 0,
    <352, 345, 346>, 0,
    <356, 350, 319>, 0,
    <356, 319, 325>, 0,
    <356, 325, 323>, 0,
    <356, 323, 354>, 0,
    <356, 354, 353>, 0,
    <356, 353, 355>, 0,
    <356, 355, 349>, 0,
    <356, 349, 350>, 0,
    <360, 354, 323>, 0,
    <360, 323, 329>, 0,
    <360, 329, 327>, 0,
    <360, 327, 358>, 0,
    <360, 358, 357>, 0,
    <360, 357, 359>, 0,
    <360, 359, 353>, 0,
    <360, 353, 354>, 0,
    <362, 358, 327>, 0,
    <362, 327, 331>, 0,
    <362, 331, 36>, 0,
    <362, 36, 73>, 0,
    <362, 73, 70>, 0,
    <362, 70, 361>, 0,
    <362, 361, 357>, 0,
    <362, 357, 358>, 0,
    <366, 134, 99>, 0,
    <366, 99, 335>, 0,
    <366, 335, 333>, 0,
    <366, 333, 364>, 0,
    <366, 364, 363>, 0,
    <366, 363, 365>, 0,
    <366, 365, 133>, 0,
    <366, 133, 134>, 0,
    <370, 364, 333>, 0,
    <370, 333, 339>, 0,
    <370, 339, 337>, 0,
    <370, 337, 368>, 0,
    <370, 368, 367>, 0,
    <370, 367, 369>, 0,
    <370, 369, 363>, 0,
    <370, 363, 364>, 0,
    <374, 368, 337>, 0,
    <374, 337, 343>, 0,
    <374, 343, 341>, 0,
    <374, 341, 372>, 0,
    <374, 372, 371>, 0,
    <374, 371, 373>, 0,
    <374, 373, 367>, 0,
    <374, 367, 368>, 0,
    <378, 372, 341>, 0,
    <378, 341, 347>, 0,
    <378, 347, 345>, 0,
    <378, 345, 376>, 0,
    <378, 376, 375>, 0,
    <378, 375, 377>, 0,
    <378, 377, 371>, 0,
    <378, 371, 372>, 0,
    <382, 376, 345>, 0,
    <382, 345, 351>, 0,
    <382, 351, 349>, 0,
    <382, 349, 380>, 0,
    <382, 380, 379>, 0,
    <382, 379, 381>, 0,
    <382, 381, 375>, 0,
    <382, 375, 376>, 0,
    <386, 380, 349>, 0,
    <386, 349, 355>, 0,
    <386, 355, 353>, 0,
    <386, 353, 384>, 0,
    <386, 384, 383>, 0,
    <386, 383, 385>, 0,
    <386, 385, 379>, 0,
    <386, 379, 380>, 0,
    <390, 384, 353>, 0,
    <390, 353, 359>, 0,
    <390, 359, 357>, 0,
    <390, 357, 388>, 0,
    <390, 388, 387>, 0,
    <390, 387, 389>, 0,
    <390, 389, 383>, 0,
    <390, 383, 384>, 0,
    <392, 388, 357>, 0,
    <392, 357, 361>, 0,
    <392, 361, 70>, 0,
    <392, 70, 107>, 0,
    <392, 107, 104>, 0,
    <392, 104, 391>, 0,
    <392, 391, 387>, 0,
    <392, 387, 388>, 0,
    <396, 168, 133>, 0,
    <396, 133, 365>, 0,
    <396, 365, 363>, 0,
    <396, 363, 394>, 0,
    <396, 394, 393>, 0,
    <396, 393, 395>, 0,
    <396, 395, 167>, 0,
    <396, 167, 168>, 0,
    <400, 394, 363>, 0,
    <400, 363, 369>, 0,
    <400, 369, 367>, 0,
    <400, 367, 398>, 0,
    <400, 398, 397>, 0,
    <400, 397, 399>, 0,
    <400, 399, 393>, 0,
    <400, 393, 394>, 0,
    <404, 398, 367>, 0,
    <404, 367, 373>, 0,
    <404, 373, 371>, 0,
    <404, 371, 402>, 0,
    <404, 402, 401>, 0,
    <404, 401, 403>, 0,
    <404, 403, 397>, 0,
    <404, 397, 398>, 0,
    <408, 402, 371>, 0,
    <408, 371, 377>, 0,
    <408, 377, 375>, 0,
    <408, 375, 406>, 0,
    <408, 406, 405>, 0,
    <408, 405, 407>, 0,
    <408, 407, 401>, 0,
    <408, 401, 402>, 0,
    <412, 406, 375>, 0,
    <412, 375, 381>, 0,
    <412, 381, 379>, 0,
    <412, 379, 410>, 0,
    <412, 410, 409>, 0,
    <412, 409, 411>, 0,
    <412, 411, 405>, 0,
    <412, 405, 406>, 0,
    <416, 410, 379>, 0,
    <416, 379, 385>, 0,
    <416, 385, 383>, 0,
    <416, 383, 414>, 0,
    <416, 414, 413>, 0,
    <416, 413, 415>, 0,
    <416, 415, 409>, 0,
    <416, 409, 410>, 0,
    <420, 414, 383>, 0,
    <420, 383, 389>, 0,
    <420, 389, 387>, 0,
    <420, 387, 418>, 0,
    <420, 418, 417>, 0,
    <420, 417, 419>, 0,
    <420, 419, 413>, 0,
    <420, 413, 414>, 0,
    <422, 418, 387>, 0,
    <422, 387, 391>, 0,
    <422, 391, 104>, 0,
    <422, 104, 141>, 0,
    <422, 141, 138>, 0,
    <422, 138, 421>, 0,
    <422, 421, 417>, 0,
    <422, 417, 418>, 0,
    <426, 202, 167>, 0,
    <426, 167, 395>, 0,
    <426, 395, 393>, 0,
    <426, 393, 424>, 0,
    <426, 424, 423>, 0,
    <426, 423, 425>, 0,
    <426, 425, 201>, 0,
    <426, 201, 202>, 0,
    <430, 424, 393>, 0,
    <430, 393, 399>, 0,
    <430, 399, 397>, 0,
    <430, 397, 428>, 0,
    <430, 428, 427>, 0,
    <430, 427, 429>, 0,
    <430, 429, 423>, 0,
    <430, 423, 424>, 0,
    <434, 428, 397>, 0,
    <434, 397, 403>, 0,
    <434, 403, 401>, 0,
    <434, 401, 432>, 0,
    <434, 432, 431>, 0,
    <434, 431, 433>, 0,
    <434, 433, 427>, 0,
    <434, 427, 428>, 0,
    <438, 432, 401>, 0,
    <438, 401, 407>, 0,
    <438, 407, 405>, 0,
    <438, 405, 436>, 0,
    <438, 436, 435>, 0,
    <438, 435, 437>, 0,
    <438, 437, 431>, 0,
    <438, 431, 432>, 0,
    <442, 436, 405>, 0,
    <442, 405, 411>, 0,
    <442, 411, 409>, 0,
    <442, 409, 440>, 0,
    <442, 440, 439>, 0,
    <442, 439, 441>, 0,
    <442, 441, 435>, 0,
    <442, 435, 436>, 0,
    <446, 440, 409>, 0,
    <446, 409, 415>, 0,
    <446, 415, 413>, 0,
    <446, 413, 444>, 0,
    <446, 444, 443>, 0,
    <446, 443, 445>, 0,
    <446, 445, 439>, 0,
    <446, 439, 440>, 0,
    <450, 444, 413>, 0,
    <450, 413, 419>, 0,
    <450, 419, 417>, 0,
    <450, 417, 448>, 0,
    <450, 448, 447>, 0,
    <450, 447, 449>, 0,
    <450, 449, 443>, 0,
    <450, 443, 444>, 0,
    <452, 448, 417>, 0,
    <452, 417, 421>, 0,
    <452, 421, 138>, 0,
    <452, 138, 175>, 0,
    <452, 175, 172>, 0,
    <452, 172, 451>, 0,
    <452, 451, 447>, 0,
    <452, 447, 448>, 0,
    <456, 236, 201>, 0,
    <456, 201, 425>, 0,
    <456, 425, 423>, 0,
    <456, 423, 454>, 0,
    <456, 454, 453>, 0,
    <456, 453, 455>, 0,
    <456, 455, 235>, 0,
    <456, 235, 236>, 0,
    <460, 454, 423>, 0,
    <460, 423, 429>, 0,
    <460, 429, 427>, 0,
    <460, 427, 458>, 0,
    <460, 458, 457>, 0,
    <460, 457, 459>, 0,
    <460, 459, 453>, 0,
    <460, 453, 454>, 0,
    <464, 458, 427>, 0,
    <464, 427, 433>, 0,
    <464, 433, 431>, 0,
    <464, 431, 462>, 0,
    <464, 462, 461>, 0,
    <464, 461, 463>, 0,
    <464, 463, 457>, 0,
    <464, 457, 458>, 0,
    <468, 462, 431>, 0,
    <468, 431, 437>, 0,
    <468, 437, 435>, 0,
    <468, 435, 466>, 0,
    <468, 466, 465>, 0,
    <468, 465, 467>, 0,
    <468, 467, 461>, 0,
    <468, 461, 462>, 0,
    <472, 466, 435>, 0,
    <472, 435, 441>, 0,
    <472, 441, 439>, 0,
    <472, 439, 470>, 0,
    <472, 470, 469>, 0,
    <472, 469, 471>, 0,
    <472, 471, 465>, 0,
    <472, 465, 466>, 0,
    <476, 470, 439>, 0,
    <476, 439, 445>, 0,
    <476, 445, 443>, 0,
    <476, 443, 474>, 0,
    <476, 474, 473>, 0,
    <476, 473, 475>, 0,
    <476, 475, 469>, 0,
    <476, 469, 470>, 0,
    <480, 474, 443>, 0,
    <480, 443, 449>, 0,
    <480, 449, 447>, 0,
    <480, 447, 478>, 0,
    <480, 478, 477>, 0,
    <480, 477, 479>, 0,
    <480, 479, 473>, 0,
    <480, 473, 474>, 0,
    <482, 478, 447>, 0,
    <482, 447, 451>, 0,
    <482, 451, 172>, 0,
    <482, 172, 209>, 0,
    <482, 209, 206>, 0,
    <482, 206, 481>, 0,
    <482, 481, 477>, 0,
    <482, 477, 478>, 0,
    <486, 270, 235>, 0,
    <486, 235, 455>, 0,
    <486, 455, 453>, 0,
    <486, 453, 484>, 0,
    <486, 484, 483>, 0,
    <486, 483, 485>, 0,
    <486, 485, 269>, 0,
    <486, 269, 270>, 0,
    <490, 484, 453>, 0,
    <490, 453, 459>, 0,
    <490, 459, 457>, 0,
    <490, 457, 488>, 0,
    <490, 488, 487>, 0,
    <490, 487, 489>, 0,
    <490, 489, 483>, 0,
    <490, 483, 484>, 0,
    <494, 488, 457>, 0,
    <494, 457, 463>, 0,
    <494, 463, 461>, 0,
    <494, 461, 492>, 0,
    <494, 492, 491>, 0,
    <494, 491, 493>, 0,
    <494, 493, 487>, 0,
    <494, 487, 488>, 0,
    <498, 492, 461>, 0,
    <498, 461, 467>, 0,
    <498, 467, 465>, 0,
    <498, 465, 496>, 0,
    <498, 496, 495>, 0,
    <498, 495, 497>, 0,
    <498, 497, 491>, 0,
    <498, 491, 492>, 0,
    <502, 496, 465>, 0,
    <502, 465, 471>, 0,
    <502, 471, 469>, 0,
    <502, 469, 500>, 0,
    <502, 500, 499>, 0,
    <502, 499, 501>, 0,
    <502, 501, 495>, 0,
    <502, 495, 496>, 0,
    <506, 500, 469>, 0,
    <506, 469, 475>, 0,
    <506, 475, 473>, 0,
    <506, 473, 504>, 0,
    <506, 504, 503>, 0,
    <506, 503, 505>, 0,
    <506, 505, 499>, 0,
    <506, 499, 500>, 0,
    <510, 504, 473>, 0,
    <510, 473, 479>, 0,
    <510, 479, 477>, 0,
    <510, 477, 508>, 0,
    <510, 508, 507>, 0,
    <510, 507, 509>, 0,
    <510, 509, 503>, 0,
    <510, 503, 504>, 0,
    <512, 508, 477>, 0,
    <512, 477, 481>, 0,
    <512, 481, 206>, 0,
    <512, 206, 243>, 0,
    <512, 243, 240>, 0,
    <512, 240, 511>, 0,
    <512, 511, 507>, 0,
    <512, 507, 508>, 0,
    <518, 517, 240>, 0,
    <518, 240, 242>, 0,
    <518, 242, 239>, 0,
    <518, 239, 515>, 0,
    <518, 515, 513>, 0,
    <518, 513, 516>, 0,
    <518, 516, 514>, 0,
    <518, 514, 517>, 0,
    <522, 515, 239>, 0,
    <522, 239, 247>, 0,
    <522, 247, 245>, 0,
    <522, 245, 520>, 0,
    <522, 520, 519>, 0,
    <522, 519, 521>, 0,
    <522, 521, 513>, 0,
    <522, 513, 515>, 0,
    <526, 520, 245>, 0,
    <526, 245, 251>, 0,
    <526, 251, 249>, 0,
    <526, 249, 524>, 0,
    <526, 524, 523>, 0,
    <526, 523, 525>, 0,
    <526, 525, 519>, 0,
    <526, 519, 520>, 0,
    <530, 524, 249>, 0,
    <530, 249, 255>, 0,
    <530, 255, 253>, 0,
    <530, 253, 528>, 0,
    <530, 528, 527>, 0,
    <530, 527, 529>, 0,
    <530, 529, 523>, 0,
    <530, 523, 524>, 0,
    <534, 528, 253>, 0,
    <534, 253, 259>, 0,
    <534, 259, 257>, 0,
    <534, 257, 532>, 0,
    <534, 532, 531>, 0,
    <534, 531, 533>, 0,
    <534, 533, 527>, 0,
    <534, 527, 528>, 0,
    <538, 532, 257>, 0,
    <538, 257, 263>, 0,
    <538, 263, 261>, 0,
    <538, 261, 536>, 0,
    <538, 536, 535>, 0,
    <538, 535, 537>, 0,
    <538, 537, 531>, 0,
    <538, 531, 532>, 0,
    <542, 536, 261>, 0,
    <542, 261, 267>, 0,
    <542, 267, 265>, 0,
    <542, 265, 540>, 0,
    <542, 540, 539>, 0,
    <542, 539, 541>, 0,
    <542, 541, 535>, 0,
    <542, 535, 536>, 0,
    <546, 540, 265>, 0,
    <546, 265, 271>, 0,
    <546, 271, 269>, 0,
    <546, 269, 544>, 0,
    <546, 544, 543>, 0,
    <546, 543, 545>, 0,
    <546, 545, 539>, 0,
    <546, 539, 540>, 0,
    <552, 551, 514>, 0,
    <552, 514, 516>, 0,
    <552, 516, 513>, 0,
    <552, 513, 549>, 0,
    <552, 549, 547>, 0,
    <552, 547, 550>, 0,
    <552, 550, 548>, 0,
    <552, 548, 551>, 0,
    <556, 549, 513>, 0,
    <556, 513, 521>, 0,
    <556, 521, 519>, 0,
    <556, 519, 554>, 0,
    <556, 554, 553>, 0,
    <556, 553, 555>, 0,
    <556, 555, 547>, 0,
    <556, 547, 549>, 0,
    <560, 554, 519>, 0,
    <560, 519, 525>, 0,
    <560, 525, 523>, 0,
    <560, 523, 558>, 0,
    <560, 558, 557>, 0,
    <560, 557, 559>, 0,
    <560, 559, 553>, 0,
    <560, 553, 554>, 0,
    <564, 558, 523>, 0,
    <564, 523, 529>, 0,
    <564, 529, 527>, 0,
    <564, 527, 562>, 0,
    <564, 562, 561>, 0,
    <564, 561, 563>, 0,
    <564, 563, 557>, 0,
    <564, 557, 558>, 0,
    <568, 562, 527>, 0,
    <568, 527, 533>, 0,
    <568, 533, 531>, 0,
    <568, 531, 566>, 0,
    <568, 566, 565>, 0,
    <568, 565, 567>, 0,
    <568, 567, 561>, 0,
    <568, 561, 562>, 0,
    <572, 566, 531>, 0,
    <572, 531, 537>, 0,
    <572, 537, 535>, 0,
    <572, 535, 570>, 0,
    <572, 570, 569>, 0,
    <572, 569, 571>, 0,
    <572, 571, 565>, 0,
    <572, 565, 566>, 0,
    <576, 570, 535>, 0,
    <576, 535, 541>, 0,
    <576, 541, 539>, 0,
    <576, 539, 574>, 0,
    <576, 574, 573>, 0,
    <576, 573, 575>, 0,
    <576, 575, 569>, 0,
    <576, 569, 570>, 0,
    <580, 574, 539>, 0,
    <580, 539, 545>, 0,
    <580, 545, 543>, 0,
    <580, 543, 578>, 0,
    <580, 578, 577>, 0,
    <580, 577, 579>, 0,
    <580, 579, 573>, 0,
    <580, 573, 574>, 0,
    <586, 585, 548>, 0,
    <586, 548, 550>, 0,
    <586, 550, 547>, 0,
    <586, 547, 583>, 0,
    <586, 583, 581>, 0,
    <586, 581, 584>, 0,
    <586, 584, 582>, 0,
    <586, 582, 585>, 0,
    <590, 583, 547>, 0,
    <590, 547, 555>, 0,
    <590, 555, 553>, 0,
    <590, 553, 588>, 0,
    <590, 588, 587>, 0,
    <590, 587, 589>, 0,
    <590, 589, 581>, 0,
    <590, 581, 583>, 0,
    <594, 588, 553>, 0,
    <594, 553, 559>, 0,
    <594, 559, 557>, 0,
    <594, 557, 592>, 0,
    <594, 592, 591>, 0,
    <594, 591, 593>, 0,
    <594, 593, 587>, 0,
    <594, 587, 588>, 0,
    <598, 592, 557>, 0,
    <598, 557, 563>, 0,
    <598, 563, 561>, 0,
    <598, 561, 596>, 0,
    <598, 596, 595>, 0,
    <598, 595, 597>, 0,
    <598, 597, 591>, 0,
    <598, 591, 592>, 0,
    <602, 596, 561>, 0,
    <602, 561, 567>, 0,
    <602, 567, 565>, 0,
    <602, 565, 600>, 0,
    <602, 600, 599>, 0,
    <602, 599, 601>, 0,
    <602, 601, 595>, 0,
    <602, 595, 596>, 0,
    <606, 600, 565>, 0,
    <606, 565, 571>, 0,
    <606, 571, 569>, 0,
    <606, 569, 604>, 0,
    <606, 604, 603>, 0,
    <606, 603, 605>, 0,
    <606, 605, 599>, 0,
    <606, 599, 600>, 0,
    <610, 604, 569>, 0,
    <610, 569, 575>, 0,
    <610, 575, 573>, 0,
    <610, 573, 608>, 0,
    <610, 608, 607>, 0,
    <610, 607, 609>, 0,
    <610, 609, 603>, 0,
    <610, 603, 604>, 0,
    <614, 608, 573>, 0,
    <614, 573, 579>, 0,
    <614, 579, 577>, 0,
    <614, 577, 612>, 0,
    <614, 612, 611>, 0,
    <614, 611, 613>, 0,
    <614, 613, 607>, 0,
    <614, 607, 608>, 0,
    <620, 619, 582>, 0,
    <620, 582, 584>, 0,
    <620, 584, 581>, 0,
    <620, 581, 617>, 0,
    <620, 617, 615>, 0,
    <620, 615, 618>, 0,
    <620, 618, 616>, 0,
    <620, 616, 619>, 0,
    <624, 617, 581>, 0,
    <624, 581, 589>, 0,
    <624, 589, 587>, 0,
    <624, 587, 622>, 0,
    <624, 622, 621>, 0,
    <624, 621, 623>, 0,
    <624, 623, 615>, 0,
    <624, 615, 617>, 0,
    <628, 622, 587>, 0,
    <628, 587, 593>, 0,
    <628, 593, 591>, 0,
    <628, 591, 626>, 0,
    <628, 626, 625>, 0,
    <628, 625, 627>, 0,
    <628, 627, 621>, 0,
    <628, 621, 622>, 0,
    <632, 626, 591>, 0,
    <632, 591, 597>, 0,
    <632, 597, 595>, 0,
    <632, 595, 630>, 0,
    <632, 630, 629>, 0,
    <632, 629, 631>, 0,
    <632, 631, 625>, 0,
    <632, 625, 626>, 0,
    <636, 630, 595>, 0,
    <636, 595, 601>, 0,
    <636, 601, 599>, 0,
    <636, 599, 634>, 0,
    <636, 634, 633>, 0,
    <636, 633, 635>, 0,
    <636, 635, 629>, 0,
    <636, 629, 630>, 0,
    <640, 634, 599>, 0,
    <640, 599, 605>, 0,
    <640, 605, 603>, 0,
    <640, 603, 638>, 0,
    <640, 638, 637>, 0,
    <640, 637, 639>, 0,
    <640, 639, 633>, 0,
    <640, 633, 634>, 0,
    <644, 638, 603>, 0,
    <644, 603, 609>, 0,
    <644, 609, 607>, 0,
    <644, 607, 642>, 0,
    <644, 642, 641>, 0,
    <644, 641, 643>, 0,
    <644, 643, 637>, 0,
    <644, 637, 638>, 0,
    <648, 642, 607>, 0,
    <648, 607, 613>, 0,
    <648, 613, 611>, 0,
    <648, 611, 646>, 0,
    <648, 646, 645>, 0,
    <648, 645, 647>, 0,
    <648, 647, 641>, 0,
    <648, 641, 642>, 0,
    <654, 653, 616>, 0,
    <654, 616, 618>, 0,
    <654, 618, 615>, 0,
    <654, 615, 651>, 0,
    <654, 651, 649>, 0,
    <654, 649, 652>, 0,
    <654, 652, 650>, 0,
    <654, 650, 653>, 0,
    <658, 651, 615>, 0,
    <658, 615, 623>, 0,
    <658, 623, 621>, 0,
    <658, 621, 656>, 0,
    <658, 656, 655>, 0,
    <658, 655, 657>, 0,
    <658, 657, 649>, 0,
    <658, 649, 651>, 0,
    <662, 656, 621>, 0,
    <662, 621, 627>, 0,
    <662, 627, 625>, 0,
    <662, 625, 660>, 0,
    <662, 660, 659>, 0,
    <662, 659, 661>, 0,
    <662, 661, 655>, 0,
    <662, 655, 656>, 0,
    <666, 660, 625>, 0,
    <666, 625, 631>, 0,
    <666, 631, 629>, 0,
    <666, 629, 664>, 0,
    <666, 664, 663>, 0,
    <666, 663, 665>, 0,
    <666, 665, 659>, 0,
    <666, 659, 660>, 0,
    <670, 664, 629>, 0,
    <670, 629, 635>, 0,
    <670, 635, 633>, 0,
    <670, 633, 668>, 0,
    <670, 668, 667>, 0,
    <670, 667, 669>, 0,
    <670, 669, 663>, 0,
    <670, 663, 664>, 0,
    <674, 668, 633>, 0,
    <674, 633, 639>, 0,
    <674, 639, 637>, 0,
    <674, 637, 672>, 0,
    <674, 672, 671>, 0,
    <674, 671, 673>, 0,
    <674, 673, 667>, 0,
    <674, 667, 668>, 0,
    <678, 672, 637>, 0,
    <678, 637, 643>, 0,
    <678, 643, 641>, 0,
    <678, 641, 676>, 0,
    <678, 676, 675>, 0,
    <678, 675, 677>, 0,
    <678, 677, 671>, 0,
    <678, 671, 672>, 0,
    <682, 676, 641>, 0,
    <682, 641, 647>, 0,
    <682, 647, 645>, 0,
    <682, 645, 680>, 0,
    <682, 680, 679>, 0,
    <682, 679, 681>, 0,
    <682, 681, 675>, 0,
    <682, 675, 676>, 0,
    <688, 687, 650>, 0,
    <688, 650, 652>, 0,
    <688, 652, 649>, 0,
    <688, 649, 685>, 0,
    <688, 685, 683>, 0,
    <688, 683, 686>, 0,
    <688, 686, 684>, 0,
    <688, 684, 687>, 0,
    <692, 685, 649>, 0,
    <692, 649, 657>, 0,
    <692, 657, 655>, 0,
    <692, 655, 690>, 0,
    <692, 690, 689>, 0,
    <692, 689, 691>, 0,
    <692, 691, 683>, 0,
    <692, 683, 685>, 0,
    <696, 690, 655>, 0,
    <696, 655, 661>, 0,
    <696, 661, 659>, 0,
    <696, 659, 694>, 0,
    <696, 694, 693>, 0,
    <696, 693, 695>, 0,
    <696, 695, 689>, 0,
    <696, 689, 690>, 0,
    <700, 694, 659>, 0,
    <700, 659, 665>, 0,
    <700, 665, 663>, 0,
    <700, 663, 698>, 0,
    <700, 698, 697>, 0,
    <700, 697, 699>, 0,
    <700, 699, 693>, 0,
    <700, 693, 694>, 0,
    <704, 698, 663>, 0,
    <704, 663, 669>, 0,
    <704, 669, 667>, 0,
    <704, 667, 702>, 0,
    <704, 702, 701>, 0,
    <704, 701, 703>, 0,
    <704, 703, 697>, 0,
    <704, 697, 698>, 0,
    <708, 702, 667>, 0,
    <708, 667, 673>, 0,
    <708, 673, 671>, 0,
    <708, 671, 706>, 0,
    <708, 706, 705>, 0,
    <708, 705, 707>, 0,
    <708, 707, 701>, 0,
    <708, 701, 702>, 0,
    <712, 706, 671>, 0,
    <712, 671, 677>, 0,
    <712, 677, 675>, 0,
    <712, 675, 710>, 0,
    <712, 710, 709>, 0,
    <712, 709, 711>, 0,
    <712, 711, 705>, 0,
    <712, 705, 706>, 0,
    <716, 710, 675>, 0,
    <716, 675, 681>, 0,
    <716, 681, 679>, 0,
    <716, 679, 714>, 0,
    <716, 714, 713>, 0,
    <716, 713, 715>, 0,
    <716, 715, 709>, 0,
    <716, 709, 710>, 0,
    <722, 721, 684>, 0,
    <722, 684, 686>, 0,
    <722, 686, 683>, 0,
    <722, 683, 719>, 0,
    <722, 719, 717>, 0,
    <722, 717, 720>, 0,
    <722, 720, 718>, 0,
    <722, 718, 721>, 0,
    <726, 719, 683>, 0,
    <726, 683, 691>, 0,
    <726, 691, 689>, 0,
    <726, 689, 724>, 0,
    <726, 724, 723>, 0,
    <726, 723, 725>, 0,
    <726, 725, 717>, 0,
    <726, 717, 719>, 0,
    <730, 724, 689>, 0,
    <730, 689, 695>, 0,
    <730, 695, 693>, 0,
    <730, 693, 728>, 0,
    <730, 728, 727>, 0,
    <730, 727, 729>, 0,
    <730, 729, 723>, 0,
    <730, 723, 724>, 0,
    <734, 728, 693>, 0,
    <734, 693, 699>, 0,
    <734, 699, 697>, 0,
    <734, 697, 732>, 0,
    <734, 732, 731>, 0,
    <734, 731, 733>, 0,
    <734, 733, 727>, 0,
    <734, 727, 728>, 0,
    <738, 732, 697>, 0,
    <738, 697, 703>, 0,
    <738, 703, 701>, 0,
    <738, 701, 736>, 0,
    <738, 736, 735>, 0,
    <738, 735, 737>, 0,
    <738, 737, 731>, 0,
    <738, 731, 732>, 0,
    <742, 736, 701>, 0,
    <742, 701, 707>, 0,
    <742, 707, 705>, 0,
    <742, 705, 740>, 0,
    <742, 740, 739>, 0,
    <742, 739, 741>, 0,
    <742, 741, 735>, 0,
    <742, 735, 736>, 0,
    <746, 740, 705>, 0,
    <746, 705, 711>, 0,
    <746, 711, 709>, 0,
    <746, 709, 744>, 0,
    <746, 744, 743>, 0,
    <746, 743, 745>, 0,
    <746, 745, 739>, 0,
    <746, 739, 740>, 0,
    <750, 744, 709>, 0,
    <750, 709, 715>, 0,
    <750, 715, 713>, 0,
    <750, 713, 748>, 0,
    <750, 748, 747>, 0,
    <750, 747, 749>, 0,
    <750, 749, 743>, 0,
    <750, 743, 744>, 0,
    <756, 755, 718>, 0,
    <756, 718, 720>, 0,
    <756, 720, 717>, 0,
    <756, 717, 753>, 0,
    <756, 753, 751>, 0,
    <756, 751, 754>, 0,
    <756, 754, 752>, 0,
    <756, 752, 755>, 0,
    <760, 753, 717>, 0,
    <760, 717, 725>, 0,
    <760, 725, 723>, 0,
    <760, 723, 758>, 0,
    <760, 758, 757>, 0,
    <760, 757, 759>, 0,
    <760, 759, 751>, 0,
    <760, 751, 753>, 0,
    <764, 758, 723>, 0,
    <764, 723, 729>, 0,
    <764, 729, 727>, 0,
    <764, 727, 762>, 0,
    <764, 762, 761>, 0,
    <764, 761, 763>, 0,
    <764, 763, 757>, 0,
    <764, 757, 758>, 0,
    <768, 762, 727>, 0,
    <768, 727, 733>, 0,
    <768, 733, 731>, 0,
    <768, 731, 766>, 0,
    <768, 766, 765>, 0,
    <768, 765, 767>, 0,
    <768, 767, 761>, 0,
    <768, 761, 762>, 0,
    <772, 766, 731>, 0,
    <772, 731, 737>, 0,
    <772, 737, 735>, 0,
    <772, 735, 770>, 0,
    <772, 770, 769>, 0,
    <772, 769, 771>, 0,
    <772, 771, 765>, 0,
    <772, 765, 766>, 0,
    <776, 770, 735>, 0,
    <776, 735, 741>, 0,
    <776, 741, 739>, 0,
    <776, 739, 774>, 0,
    <776, 774, 773>, 0,
    <776, 773, 775>, 0,
    <776, 775, 769>, 0,
    <776, 769, 770>, 0,
    <780, 774, 739>, 0,
    <780, 739, 745>, 0,
    <780, 745, 743>, 0,
    <780, 743, 778>, 0,
    <780, 778, 777>, 0,
    <780, 777, 779>, 0,
    <780, 779, 773>, 0,
    <780, 773, 774>, 0,
    <784, 778, 743>, 0,
    <784, 743, 749>, 0,
    <784, 749, 747>, 0,
    <784, 747, 782>, 0,
    <784, 782, 781>, 0,
    <784, 781, 783>, 0,
    <784, 783, 777>, 0,
    <784, 777, 778>, 0,
    <788, 544, 269>, 0,
    <788, 269, 485>, 0,
    <788, 485, 483>, 0,
    <788, 483, 786>, 0,
    <788, 786, 785>, 0,
    <788, 785, 787>, 0,
    <788, 787, 543>, 0,
    <788, 543, 544>, 0,
    <792, 786, 483>, 0,
    <792, 483, 489>, 0,
    <792, 489, 487>, 0,
    <792, 487, 790>, 0,
    <792, 790, 789>, 0,
    <792, 789, 791>, 0,
    <792, 791, 785>, 0,
    <792, 785, 786>, 0,
    <796, 790, 487>, 0,
    <796, 487, 493>, 0,
    <796, 493, 491>, 0,
    <796, 491, 794>, 0,
    <796, 794, 793>, 0,
    <796, 793, 795>, 0,
    <796, 795, 789>, 0,
    <796, 789, 790>, 0,
    <800, 794, 491>, 0,
    <800, 491, 497>, 0,
    <800, 497, 495>, 0,
    <800, 495, 798>, 0,
    <800, 798, 797>, 0,
    <800, 797, 799>, 0,
    <800, 799, 793>, 0,
    <800, 793, 794>, 0,
    <804, 798, 495>, 0,
    <804, 495, 501>, 0,
    <804, 501, 499>, 0,
    <804, 499, 802>, 0,
    <804, 802, 801>, 0,
    <804, 801, 803>, 0,
    <804, 803, 797>, 0,
    <804, 797, 798>, 0,
    <808, 802, 499>, 0,
    <808, 499, 505>, 0,
    <808, 505, 503>, 0,
    <808, 503, 806>, 0,
    <808, 806, 805>, 0,
    <808, 805, 807>, 0,
    <808, 807, 801>, 0,
    <808, 801, 802>, 0,
    <812, 806, 503>, 0,
    <812, 503, 509>, 0,
    <812, 509, 507>, 0,
    <812, 507, 810>, 0,
    <812, 810, 809>, 0,
    <812, 809, 811>, 0,
    <812, 811, 805>, 0,
    <812, 805, 806>, 0,
    <814, 810, 507>, 0,
    <814, 507, 511>, 0,
    <814, 511, 240>, 0,
    <814, 240, 517>, 0,
    <814, 517, 514>, 0,
    <814, 514, 813>, 0,
    <814, 813, 809>, 0,
    <814, 809, 810>, 0,
    <818, 578, 543>, 0,
    <818, 543, 787>, 0,
    <818, 787, 785>, 0,
    <818, 785, 816>, 0,
    <818, 816, 815>, 0,
    <818, 815, 817>, 0,
    <818, 817, 577>, 0,
    <818, 577, 578>, 0,
    <822, 816, 785>, 0,
    <822, 785, 791>, 0,
    <822, 791, 789>, 0,
    <822, 789, 820>, 0,
    <822, 820, 819>, 0,
    <822, 819, 821>, 0,
    <822, 821, 815>, 0,
    <822, 815, 816>, 0,
    <826, 820, 789>, 0,
    <826, 789, 795>, 0,
    <826, 795, 793>, 0,
    <826, 793, 824>, 0,
    <826, 824, 823>, 0,
    <826, 823, 825>, 0,
    <826, 825, 819>, 0,
    <826, 819, 820>, 0,
    <830, 824, 793>, 0,
    <830, 793, 799>, 0,
    <830, 799, 797>, 0,
    <830, 797, 828>, 0,
    <830, 828, 827>, 0,
    <830, 827, 829>, 0,
    <830, 829, 823>, 0,
    <830, 823, 824>, 0,
    <834, 828, 797>, 0,
    <834, 797, 803>, 0,
    <834, 803, 801>, 0,
    <834, 801, 832>, 0,
    <834, 832, 831>, 0,
    <834, 831, 833>, 0,
    <834, 833, 827>, 0,
    <834, 827, 828>, 0,
    <838, 832, 801>, 0,
    <838, 801, 807>, 0,
    <838, 807, 805>, 0,
    <838, 805, 836>, 0,
    <838, 836, 835>, 0,
    <838, 835, 837>, 0,
    <838, 837, 831>, 0,
    <838, 831, 832>, 0,
    <842, 836, 805>, 0,
    <842, 805, 811>, 0,
    <842, 811, 809>, 0,
    <842, 809, 840>, 0,
    <842, 840, 839>, 0,
    <842, 839, 841>, 0,
    <842, 841, 835>, 0,
    <842, 835, 836>, 0,
    <844, 840, 809>, 0,
    <844, 809, 813>, 0,
    <844, 813, 514>, 0,
    <844, 514, 551>, 0,
    <844, 551, 548>, 0,
    <844, 548, 843>, 0,
    <844, 843, 839>, 0,
    <844, 839, 840>, 0,
    <848, 612, 577>, 0,
    <848, 577, 817>, 0,
    <848, 817, 815>, 0,
    <848, 815, 846>, 0,
    <848, 846, 845>, 0,
    <848, 845, 847>, 0,
    <848, 847, 611>, 0,
    <848, 611, 612>, 0,
    <852, 846, 815>, 0,
    <852, 815, 821>, 0,
    <852, 821, 819>, 0,
    <852, 819, 850>, 0,
    <852, 850, 849>, 0,
    <852, 849, 851>, 0,
    <852, 851, 845>, 0,
    <852, 845, 846>, 0,
    <856, 850, 819>, 0,
    <856, 819, 825>, 0,
    <856, 825, 823>, 0,
    <856, 823, 854>, 0,
    <856, 854, 853>, 0,
    <856, 853, 855>, 0,
    <856, 855, 849>, 0,
    <856, 849, 850>, 0,
    <860, 854, 823>, 0,
    <860, 823, 829>, 0,
    <860, 829, 827>, 0,
    <860, 827, 858>, 0,
    <860, 858, 857>, 0,
    <860, 857, 859>, 0,
    <860, 859, 853>, 0,
    <860, 853, 854>, 0,
    <864, 858, 827>, 0,
    <864, 827, 833>, 0,
    <864, 833, 831>, 0,
    <864, 831, 862>, 0,
    <864, 862, 861>, 0,
    <864, 861, 863>, 0,
    <864, 863, 857>, 0,
    <864, 857, 858>, 0,
    <868, 862, 831>, 0,
    <868, 831, 837>, 0,
    <868, 837, 835>, 0,
    <868, 835, 866>, 0,
    <868, 866, 865>, 0,
    <868, 865, 867>, 0,
    <868, 867, 861>, 0,
    <868, 861, 862>, 0,
    <872, 866, 835>, 0,
    <872, 835, 841>, 0,
    <872, 841, 839>, 0,
    <872, 839, 870>, 0,
    <872, 870, 869>, 0,
    <872, 869, 871>, 0,
    <872, 871, 865>, 0,
    <872, 865, 866>, 0,
    <874, 870, 839>, 0,
    <874, 839, 843>, 0,
    <874, 843, 548>, 0,
    <874, 548, 585>, 0,
    <874, 585, 582>, 0,
    <874, 582, 873>, 0,
    <874, 873, 869>, 0,
    <874, 869, 870>, 0,
    <878, 646, 611>, 0,
    <878, 611, 847>, 0,
    <878, 847, 845>, 0,
    <878, 845, 876>, 0,
    <878, 876, 875>, 0,
    <878, 875, 877>, 0,
    <878, 877, 645>, 0,
    <878, 645, 646>, 0,
    <882, 876, 845>, 0,
    <882, 845, 851>, 0,
    <882, 851, 849>, 0,
    <882, 849, 880>, 0,
    <882, 880, 879>, 0,
    <882, 879, 881>, 0,
    <882, 881, 875>, 0,
    <882, 875, 876>, 0,
    <886, 880, 849>, 0,
    <886, 849, 855>, 0,
    <886, 855, 853>, 0,
    <886, 853, 884>, 0,
    <886, 884, 883>, 0,
    <886, 883, 885>, 0,
    <886, 885, 879>, 0,
    <886, 879, 880>, 0,
    <890, 884, 853>, 0,
    <890, 853, 859>, 0,
    <890, 859, 857>, 0,
    <890, 857, 888>, 0,
    <890, 888, 887>, 0,
    <890, 887, 889>, 0,
    <890, 889, 883>, 0,
    <890, 883, 884>, 0,
    <894, 888, 857>, 0,
    <894, 857, 863>, 0,
    <894, 863, 861>, 0,
    <894, 861, 892>, 0,
    <894, 892, 891>, 0,
    <894, 891, 893>, 0,
    <894, 893, 887>, 0,
    <894, 887, 888>, 0,
    <898, 892, 861>, 0,
    <898, 861, 867>, 0,
    <898, 867, 865>, 0,
    <898, 865, 896>, 0,
    <898, 896, 895>, 0,
    <898, 895, 897>, 0,
    <898, 897, 891>, 0,
    <898, 891, 892>, 0,
    <902, 896, 865>, 0,
    <902, 865, 871>, 0,
    <902, 871, 869>, 0,
    <902, 869, 900>, 0,
    <902, 900, 899>, 0,
    <902, 899, 901>, 0,
    <902, 901, 895>, 0,
    <902, 895, 896>, 0,
    <904, 900, 869>, 0,
    <904, 869, 873>, 0,
    <904, 873, 582>, 0,
    <904, 582, 619>, 0,
    <904, 619, 616>, 0,
    <904, 616, 903>, 0,
    <904, 903, 899>, 0,
    <904, 899, 900>, 0,
    <908, 680, 645>, 0,
    <908, 645, 877>, 0,
    <908, 877, 875>, 0,
    <908, 875, 906>, 0,
    <908, 906, 905>, 0,
    <908, 905, 907>, 0,
    <908, 907, 679>, 0,
    <908, 679, 680>, 0,
    <912, 906, 875>, 0,
    <912, 875, 881>, 0,
    <912, 881, 879>, 0,
    <912, 879, 910>, 0,
    <912, 910, 909>, 0,
    <912, 909, 911>, 0,
    <912, 911, 905>, 0,
    <912, 905, 906>, 0,
    <916, 910, 879>, 0,
    <916, 879, 885>, 0,
    <916, 885, 883>, 0,
    <916, 883, 914>, 0,
    <916, 914, 913>, 0,
    <916, 913, 915>, 0,
    <916, 915, 909>, 0,
    <916, 909, 910>, 0,
    <920, 914, 883>, 0,
    <920, 883, 889>, 0,
    <920, 889, 887>, 0,
    <920, 887, 918>, 0,
    <920, 918, 917>, 0,
    <920, 917, 919>, 0,
    <920, 919, 913>, 0,
    <920, 913, 914>, 0,
    <924, 918, 887>, 0,
    <924, 887, 893>, 0,
    <924, 893, 891>, 0,
    <924, 891, 922>, 0,
    <924, 922, 921>, 0,
    <924, 921, 923>, 0,
    <924, 923, 917>, 0,
    <924, 917, 918>, 0,
    <928, 922, 891>, 0,
    <928, 891, 897>, 0,
    <928, 897, 895>, 0,
    <928, 895, 926>, 0,
    <928, 926, 925>, 0,
    <928, 925, 927>, 0,
    <928, 927, 921>, 0,
    <928, 921, 922>, 0,
    <932, 926, 895>, 0,
    <932, 895, 901>, 0,
    <932, 901, 899>, 0,
    <932, 899, 930>, 0,
    <932, 930, 929>, 0,
    <932, 929, 931>, 0,
    <932, 931, 925>, 0,
    <932, 925, 926>, 0,
    <934, 930, 899>, 0,
    <934, 899, 903>, 0,
    <934, 903, 616>, 0,
    <934, 616, 653>, 0,
    <934, 653, 650>, 0,
    <934, 650, 933>, 0,
    <934, 933, 929>, 0,
    <934, 929, 930>, 0,
    <938, 714, 679>, 0,
    <938, 679, 907>, 0,
    <938, 907, 905>, 0,
    <938, 905, 936>, 0,
    <938, 936, 935>, 0,
    <938, 935, 937>, 0,
    <938, 937, 713>, 0,
    <938, 713, 714>, 0,
    <942, 936, 905>, 0,
    <942, 905, 911>, 0,
    <942, 911, 909>, 0,
    <942, 909, 940>, 0,
    <942, 940, 939>, 0,
    <942, 939, 941>, 0,
    <942, 941, 935>, 0,
    <942, 935, 936>, 0,
    <946, 940, 909>, 0,
    <946, 909, 915>, 0,
    <946, 915, 913>, 0,
    <946, 913, 944>, 0,
    <946, 944, 943>, 0,
    <946, 943, 945>, 0,
    <946, 945, 939>, 0,
    <946, 939, 940>, 0,
    <950, 944, 913>, 0,
    <950, 913, 919>, 0,
    <950, 919, 917>, 0,
    <950, 917, 948>, 0,
    <950, 948, 947>, 0,
    <950, 947, 949>, 0,
    <950, 949, 943>, 0,
    <950, 943, 944>, 0,
    <954, 948, 917>, 0,
    <954, 917, 923>, 0,
    <954, 923, 921>, 0,
    <954, 921, 952>, 0,
    <954, 952, 951>, 0,
    <954, 951, 953>, 0,
    <954, 953, 947>, 0,
    <954, 947, 948>, 0,
    <958, 952, 921>, 0,
    <958, 921, 927>, 0,
    <958, 927, 925>, 0,
    <958, 925, 956>, 0,
    <958, 956, 955>, 0,
    <958, 955, 957>, 0,
    <958, 957, 951>, 0,
    <958, 951, 952>, 0,
    <962, 956, 925>, 0,
    <962, 925, 931>, 0,
    <962, 931, 929>, 0,
    <962, 929, 960>, 0,
    <962, 960, 959>, 0,
    <962, 959, 961>, 0,
    <962, 961, 955>, 0,
    <962, 955, 956>, 0,
    <964, 960, 929>, 0,
    <964, 929, 933>, 0,
    <964, 933, 650>, 0,
    <964, 650, 687>, 0,
    <964, 687, 684>, 0,
    <964, 684, 963>, 0,
    <964, 963, 959>, 0,
    <964, 959, 960>, 0,
    <968, 748, 713>, 0,
    <968, 713, 937>, 0,
    <968, 937, 935>, 0,
    <968, 935, 966>, 0,
    <968, 966, 965>, 0,
    <968, 965, 967>, 0,
    <968, 967, 747>, 0,
    <968, 747, 748>, 0,
    <972, 966, 935>, 0,
    <972, 935, 941>, 0,
    <972, 941, 939>, 0,
    <972, 939, 970>, 0,
    <972, 970, 969>, 0,
    <972, 969, 971>, 0,
    <972, 971, 965>, 0,
    <972, 965, 966>, 0,
    <976, 970, 939>, 0,
    <976, 939, 945>, 0,
    <976, 945, 943>, 0,
    <976, 943, 974>, 0,
    <976, 974, 973>, 0,
    <976, 973, 975>, 0,
    <976, 975, 969>, 0,
    <976, 969, 970>, 0,
    <980, 974, 943>, 0,
    <980, 943, 949>, 0,
    <980, 949, 947>, 0,
    <980, 947, 978>, 0,
    <980, 978, 977>, 0,
    <980, 977, 979>, 0,
    <980, 979, 973>, 0,
    <980, 973, 974>, 0,
    <984, 978, 947>, 0,
    <984, 947, 953>, 0,
    <984, 953, 951>, 0,
    <984, 951, 982>, 0,
    <984, 982, 981>, 0,
    <984, 981, 983>, 0,
    <984, 983, 977>, 0,
    <984, 977, 978>, 0,
    <988, 982, 951>, 0,
    <988, 951, 957>, 0,
    <988, 957, 955>, 0,
    <988, 955, 986>, 0,
    <988, 986, 985>, 0,
    <988, 985, 987>, 0,
    <988, 987, 981>, 0,
    <988, 981, 982>, 0,
    <992, 986, 955>, 0,
    <992, 955, 961>, 0,
    <992, 961, 959>, 0,
    <992, 959, 990>, 0,
    <992, 990, 989>, 0,
    <992, 989, 991>, 0,
    <992, 991, 985>, 0,
    <992, 985, 986>, 0,
    <994, 990, 959>, 0,
    <994, 959, 963>, 0,
    <994, 963, 684>, 0,
    <994, 684, 721>, 0,
    <994, 721, 718>, 0,
    <994, 718, 993>, 0,
    <994, 993, 989>, 0,
    <994, 989, 990>, 0,
    <998, 782, 747>, 0,
    <998, 747, 967>, 0,
    <998, 967, 965>, 0,
    <998, 965, 996>, 0,
    <998, 996, 995>, 0,
    <998, 995, 997>, 0,
    <998, 997, 781>, 0,
    <998, 781, 782>, 0,
    <1002, 996, 965>, 0,
    <1002, 965, 971>, 0,
    <1002, 971, 969>, 0,
    <1002, 969, 1000>, 0,
    <1002, 1000, 999>, 0,
    <1002, 999, 1001>, 0,
    <1002, 1001, 995>, 0,
    <1002, 995, 996>, 0,
    <1006, 1000, 969>, 0,
    <1006, 969, 975>, 0,
    <1006, 975, 973>, 0,
    <1006, 973, 1004>, 0,
    <1006, 1004, 1003>, 0,
    <1006, 1003, 1005>, 0,
    <1006, 1005, 999>, 0,
    <1006, 999, 1000>, 0,
    <1010, 1004, 973>, 0,
    <1010, 973, 979>, 0,
    <1010, 979, 977>, 0,
    <1010, 977, 1008>, 0,
    <1010, 1008, 1007>, 0,
    <1010, 1007, 1009>, 0,
    <1010, 1009, 1003>, 0,
    <1010, 1003, 1004>, 0,
    <1014, 1008, 977>, 0,
    <1014, 977, 983>, 0,
    <1014, 983, 981>, 0,
    <1014, 981, 1012>, 0,
    <1014, 1012, 1011>, 0,
    <1014, 1011, 1013>, 0,
    <1014, 1013, 1007>, 0,
    <1014, 1007, 1008>, 0,
    <1018, 1012, 981>, 0,
    <1018, 981, 987>, 0,
    <1018, 987, 985>, 0,
    <1018, 985, 1016>, 0,
    <1018, 1016, 1015>, 0,
    <1018, 1015, 1017>, 0,
    <1018, 1017, 1011>, 0,
    <1018, 1011, 1012>, 0,
    <1022, 1016, 985>, 0,
    <1022, 985, 991>, 0,
    <1022, 991, 989>, 0,
    <1022, 989, 1020>, 0,
    <1022, 1020, 1019>, 0,
    <1022, 1019, 1021>, 0,
    <1022, 1021, 1015>, 0,
    <1022, 1015, 1016>, 0,
    <1024, 1020, 989>, 0,
    <1024, 989, 993>, 0,
    <1024, 993, 718>, 0,
    <1024, 718, 755>, 0,
    <1024, 755, 752>, 0,
    <1024, 752, 1023>, 0,
    <1024, 1023, 1019>, 0,
    <1024, 1019, 1020>, 0,
    <1030, 1029, 752>, 0,
    <1030, 752, 754>, 0,
    <1030, 754, 751>, 0,
    <1030, 751, 1027>, 0,
    <1030, 1027, 1025>, 0,
    <1030, 1025, 1028>, 0,
    <1030, 1028, 1026>, 0,
    <1030, 1026, 1029>, 0,
    <1034, 1027, 751>, 0,
    <1034, 751, 759>, 0,
    <1034, 759, 757>, 0,
    <1034, 757, 1032>, 0,
    <1034, 1032, 1031>, 0,
    <1034, 1031, 1033>, 0,
    <1034, 1033, 1025>, 0,
    <1034, 1025, 1027>, 0,
    <1038, 1032, 757>, 0,
    <1038, 757, 763>, 0,
    <1038, 763, 761>, 0,
    <1038, 761, 1036>, 0,
    <1038, 1036, 1035>, 0,
    <1038, 1035, 1037>, 0,
    <1038, 1037, 1031>, 0,
    <1038, 1031, 1032>, 0,
    <1042, 1036, 761>, 0,
    <1042, 761, 767>, 0,
    <1042, 767, 765>, 0,
    <1042, 765, 1040>, 0,
    <1042, 1040, 1039>, 0,
    <1042, 1039, 1041>, 0,
    <1042, 1041, 1035>, 0,
    <1042, 1035, 1036>, 0,
    <1046, 1040, 765>, 0,
    <1046, 765, 771>, 0,
    <1046, 771, 769>, 0,
    <1046, 769, 1044>, 0,
    <1046, 1044, 1043>, 0,
    <1046, 1043, 1045>, 0,
    <1046, 1045, 1039>, 0,
    <1046, 1039, 1040>, 0,
    <1050, 1044, 769>, 0,
    <1050, 769, 775>, 0,
    <1050, 775, 773>, 0,
    <1050, 773, 1048>, 0,
    <1050, 1048, 1047>, 0,
    <1050, 1047, 1049>, 0,
    <1050, 1049, 1043>, 0,
    <1050, 1043, 1044>, 0,
    <1054, 1048, 773>, 0,
    <1054, 773, 779>, 0,
    <1054, 779, 777>, 0,
    <1054, 777, 1052>, 0,
    <1054, 1052, 1051>, 0,
    <1054, 1051, 1053>, 0,
    <1054, 1053, 1047>, 0,
    <1054, 1047, 1048>, 0,
    <1058, 1052, 777>, 0,
    <1058, 777, 783>, 0,
    <1058, 783, 781>, 0,
    <1058, 781, 1056>, 0,
    <1058, 1056, 1055>, 0,
    <1058, 1055, 1057>, 0,
    <1058, 1057, 1051>, 0,
    <1058, 1051, 1052>, 0,
    <1064, 1063, 1026>, 0,
    <1064, 1026, 1028>, 0,
    <1064, 1028, 1025>, 0,
    <1064, 1025, 1061>, 0,
    <1064, 1061, 1059>, 0,
    <1064, 1059, 1062>, 0,
    <1064, 1062, 1060>, 0,
    <1064, 1060, 1063>, 0,
    <1068, 1061, 1025>, 0,
    <1068, 1025, 1033>, 0,
    <1068, 1033, 1031>, 0,
    <1068, 1031, 1066>, 0,
    <1068, 1066, 1065>, 0,
    <1068, 1065, 1067>, 0,
    <1068, 1067, 1059>, 0,
    <1068, 1059, 1061>, 0,
    <1072, 1066, 1031>, 0,
    <1072, 1031, 1037>, 0,
    <1072, 1037, 1035>, 0,
    <1072, 1035, 1070>, 0,
    <1072, 1070, 1069>, 0,
    <1072, 1069, 1071>, 0,
    <1072, 1071, 1065>, 0,
    <1072, 1065, 1066>, 0,
    <1076, 1070, 1035>, 0,
    <1076, 1035, 1041>, 0,
    <1076, 1041, 1039>, 0,
    <1076, 1039, 1074>, 0,
    <1076, 1074, 1073>, 0,
    <1076, 1073, 1075>, 0,
    <1076, 1075, 1069>, 0,
    <1076, 1069, 1070>, 0,
    <1080, 1074, 1039>, 0,
    <1080, 1039, 1045>, 0,
    <1080, 1045, 1043>, 0,
    <1080, 1043, 1078>, 0,
    <1080, 1078, 1077>, 0,
    <1080, 1077, 1079>, 0,
    <1080, 1079, 1073>, 0,
    <1080, 1073, 1074>, 0,
    <1084, 1078, 1043>, 0,
    <1084, 1043, 1049>, 0,
    <1084, 1049, 1047>, 0,
    <1084, 1047, 1082>, 0,
    <1084, 1082, 1081>, 0,
    <1084, 1081, 1083>, 0,
    <1084, 1083, 1077>, 0,
    <1084, 1077, 1078>, 0,
    <1088, 1082, 1047>, 0,
    <1088, 1047, 1053>, 0,
    <1088, 1053, 1051>, 0,
    <1088, 1051, 1086>, 0,
    <1088, 1086, 1085>, 0,
    <1088, 1085, 1087>, 0,
    <1088, 1087, 1081>, 0,
    <1088, 1081, 1082>, 0,
    <1092, 1086, 1051>, 0,
    <1092, 1051, 1057>, 0,
    <1092, 1057, 1055>, 0,
    <1092, 1055, 1090>, 0,
    <1092, 1090, 1089>, 0,
    <1092, 1089, 1091>, 0,
    <1092, 1091, 1085>, 0,
    <1092, 1085, 1086>, 0,
    <1098, 1097, 1060>, 0,
    <1098, 1060, 1062>, 0,
    <1098, 1062, 1059>, 0,
    <1098, 1059, 1095>, 0,
    <1098, 1095, 1093>, 0,
    <1098, 1093, 1096>, 0,
    <1098, 1096, 1094>, 0,
    <1098, 1094, 1097>, 0,
    <1102, 1095, 1059>, 0,
    <1102, 1059, 1067>, 0,
    <1102, 1067, 1065>, 0,
    <1102, 1065, 1100>, 0,
    <1102, 1100, 1099>, 0,
    <1102, 1099, 1101>, 0,
    <1102, 1101, 1093>, 0,
    <1102, 1093, 1095>, 0,
    <1106, 1100, 1065>, 0,
    <1106, 1065, 1071>, 0,
    <1106, 1071, 1069>, 0,
    <1106, 1069, 1104>, 0,
    <1106, 1104, 1103>, 0,
    <1106, 1103, 1105>, 0,
    <1106, 1105, 1099>, 0,
    <1106, 1099, 1100>, 0,
    <1110, 1104, 1069>, 0,
    <1110, 1069, 1075>, 0,
    <1110, 1075, 1073>, 0,
    <1110, 1073, 1108>, 0,
    <1110, 1108, 1107>, 0,
    <1110, 1107, 1109>, 0,
    <1110, 1109, 1103>, 0,
    <1110, 1103, 1104>, 0,
    <1114, 1108, 1073>, 0,
    <1114, 1073, 1079>, 0,
    <1114, 1079, 1077>, 0,
    <1114, 1077, 1112>, 0,
    <1114, 1112, 1111>, 0,
    <1114, 1111, 1113>, 0,
    <1114, 1113, 1107>, 0,
    <1114, 1107, 1108>, 0,
    <1118, 1112, 1077>, 0,
    <1118, 1077, 1083>, 0,
    <1118, 1083, 1081>, 0,
    <1118, 1081, 1116>, 0,
    <1118, 1116, 1115>, 0,
    <1118, 1115, 1117>, 0,
    <1118, 1117, 1111>, 0,
    <1118, 1111, 1112>, 0,
    <1122, 1116, 1081>, 0,
    <1122, 1081, 1087>, 0,
    <1122, 1087, 1085>, 0,
    <1122, 1085, 1120>, 0,
    <1122, 1120, 1119>, 0,
    <1122, 1119, 1121>, 0,
    <1122, 1121, 1115>, 0,
    <1122, 1115, 1116>, 0,
    <1126, 1120, 1085>, 0,
    <1126, 1085, 1091>, 0,
    <1126, 1091, 1089>, 0,
    <1126, 1089, 1124>, 0,
    <1126, 1124, 1123>, 0,
    <1126, 1123, 1125>, 0,
    <1126, 1125, 1119>, 0,
    <1126, 1119, 1120>, 0,
    <1132, 1131, 1094>, 0,
    <1132, 1094, 1096>, 0,
    <1132, 1096, 1093>, 0,
    <1132, 1093, 1129>, 0,
    <1132, 1129, 1127>, 0,
    <1132, 1127, 1130>, 0,
    <1132, 1130, 1128>, 0,
    <1132, 1128, 1131>, 0,
    <1136, 1129, 1093>, 0,
    <1136, 1093, 1101>, 0,
    <1136, 1101, 1099>, 0,
    <1136, 1099, 1134>, 0,
    <1136, 1134, 1133>, 0,
    <1136, 1133, 1135>, 0,
    <1136, 1135, 1127>, 0,
    <1136, 1127, 1129>, 0,
    <1140, 1134, 1099>, 0,
    <1140, 1099, 1105>, 0,
    <1140, 1105, 1103>, 0,
    <1140, 1103, 1138>, 0,
    <1140, 1138, 1137>, 0,
    <1140, 1137, 1139>, 0,
    <1140, 1139, 1133>, 0,
    <1140, 1133, 1134>, 0,
    <1144, 1138, 1103>, 0,
    <1144, 1103, 1109>, 0,
    <1144, 1109, 1107>, 0,
    <1144, 1107, 1142>, 0,
    <1144, 1142, 1141>, 0,
    <1144, 1141, 1143>, 0,
    <1144, 1143, 1137>, 0,
    <1144, 1137, 1138>, 0,
    <1148, 1142, 1107>, 0,
    <1148, 1107, 1113>, 0,
    <1148, 1113, 1111>, 0,
    <1148, 1111, 1146>, 0,
    <1148, 1146, 1145>, 0,
    <1148, 1145, 1147>, 0,
    <1148, 1147, 1141>, 0,
    <1148, 1141, 1142>, 0,
    <1152, 1146, 1111>, 0,
    <1152, 1111, 1117>, 0,
    <1152, 1117, 1115>, 0,
    <1152, 1115, 1150>, 0,
    <1152, 1150, 1149>, 0,
    <1152, 1149, 1151>, 0,
    <1152, 1151, 1145>, 0,
    <1152, 1145, 1146>, 0,
    <1156, 1150, 1115>, 0,
    <1156, 1115, 1121>, 0,
    <1156, 1121, 1119>, 0,
    <1156, 1119, 1154>, 0,
    <1156, 1154, 1153>, 0,
    <1156, 1153, 1155>, 0,
    <1156, 1155, 1149>, 0,
    <1156, 1149, 1150>, 0,
    <1160, 1154, 1119>, 0,
    <1160, 1119, 1125>, 0,
    <1160, 1125, 1123>, 0,
    <1160, 1123, 1158>, 0,
    <1160, 1158, 1157>, 0,
    <1160, 1157, 1159>, 0,
    <1160, 1159, 1153>, 0,
    <1160, 1153, 1154>, 0,
    <1166, 1165, 1128>, 0,
    <1166, 1128, 1130>, 0,
    <1166, 1130, 1127>, 0,
    <1166, 1127, 1163>, 0,
    <1166, 1163, 1161>, 0,
    <1166, 1161, 1164>, 0,
    <1166, 1164, 1162>, 0,
    <1166, 1162, 1165>, 0,
    <1170, 1163, 1127>, 0,
    <1170, 1127, 1135>, 0,
    <1170, 1135, 1133>, 0,
    <1170, 1133, 1168>, 0,
    <1170, 1168, 1167>, 0,
    <1170, 1167, 1169>, 0,
    <1170, 1169, 1161>, 0,
    <1170, 1161, 1163>, 0,
    <1174, 1168, 1133>, 0,
    <1174, 1133, 1139>, 0,
    <1174, 1139, 1137>, 0,
    <1174, 1137, 1172>, 0,
    <1174, 1172, 1171>, 0,
    <1174, 1171, 1173>, 0,
    <1174, 1173, 1167>, 0,
    <1174, 1167, 1168>, 0,
    <1178, 1172, 1137>, 0,
    <1178, 1137, 1143>, 0,
    <1178, 1143, 1141>, 0,
    <1178, 1141, 1176>, 0,
    <1178, 1176, 1175>, 0,
    <1178, 1175, 1177>, 0,
    <1178, 1177, 1171>, 0,
    <1178, 1171, 1172>, 0,
    <1182, 1176, 1141>, 0,
    <1182, 1141, 1147>, 0,
    <1182, 1147, 1145>, 0,
    <1182, 1145, 1180>, 0,
    <1182, 1180, 1179>, 0,
    <1182, 1179, 1181>, 0,
    <1182, 1181, 1175>, 0,
    <1182, 1175, 1176>, 0,
    <1186, 1180, 1145>, 0,
    <1186, 1145, 1151>, 0,
    <1186, 1151, 1149>, 0,
    <1186, 1149, 1184>, 0,
    <1186, 1184, 1183>, 0,
    <1186, 1183, 1185>, 0,
    <1186, 1185, 1179>, 0,
    <1186, 1179, 1180>, 0,
    <1190, 1184, 1149>, 0,
    <1190, 1149, 1155>, 0,
    <1190, 1155, 1153>, 0,
    <1190, 1153, 1188>, 0,
    <1190, 1188, 1187>, 0,
    <1190, 1187, 1189>, 0,
    <1190, 1189, 1183>, 0,
    <1190, 1183, 1184>, 0,
    <1194, 1188, 1153>, 0,
    <1194, 1153, 1159>, 0,
    <1194, 1159, 1157>, 0,
    <1194, 1157, 1192>, 0,
    <1194, 1192, 1191>, 0,
    <1194, 1191, 1193>, 0,
    <1194, 1193, 1187>, 0,
    <1194, 1187, 1188>, 0,
    <1200, 1199, 1162>, 0,
    <1200, 1162, 1164>, 0,
    <1200, 1164, 1161>, 0,
    <1200, 1161, 1197>, 0,
    <1200, 1197, 1195>, 0,
    <1200, 1195, 1198>, 0,
    <1200, 1198, 1196>, 0,
    <1200, 1196, 1199>, 0,
    <1204, 1197, 1161>, 0,
    <1204, 1161, 1169>, 0,
    <1204, 1169, 1167>, 0,
    <1204, 1167, 1202>, 0,
    <1204, 1202, 1201>, 0,
    <1204, 1201, 1203>, 0,
    <1204, 1203, 1195>, 0,
    <1204, 1195, 1197>, 0,
    <1208, 1202, 1167>, 0,
    <1208, 1167, 1173>, 0,
    <1208, 1173, 1171>, 0,
    <1208, 1171, 1206>, 0,
    <1208, 1206, 1205>, 0,
    <1208, 1205, 1207>, 0,
    <1208, 1207, 1201>, 0,
    <1208, 1201, 1202>, 0,
    <1212, 1206, 1171>, 0,
    <1212, 1171, 1177>, 0,
    <1212, 1177, 1175>, 0,
    <1212, 1175, 1210>, 0,
    <1212, 1210, 1209>, 0,
    <1212, 1209, 1211>, 0,
    <1212, 1211, 1205>, 0,
    <1212, 1205, 1206>, 0,
    <1216, 1210, 1175>, 0,
    <1216, 1175, 1181>, 0,
    <1216, 1181, 1179>, 0,
    <1216, 1179, 1214>, 0,
    <1216, 1214, 1213>, 0,
    <1216, 1213, 1215>, 0,
    <1216, 1215, 1209>, 0,
    <1216, 1209, 1210>, 0,
    <1220, 1214, 1179>, 0,
    <1220, 1179, 1185>, 0,
    <1220, 1185, 1183>, 0,
    <1220, 1183, 1218>, 0,
    <1220, 1218, 1217>, 0,
    <1220, 1217, 1219>, 0,
    <1220, 1219, 1213>, 0,
    <1220, 1213, 1214>, 0,
    <1224, 1218, 1183>, 0,
    <1224, 1183, 1189>, 0,
    <1224, 1189, 1187>, 0,
    <1224, 1187, 1222>, 0,
    <1224, 1222, 1221>, 0,
    <1224, 1221, 1223>, 0,
    <1224, 1223, 1217>, 0,
    <1224, 1217, 1218>, 0,
    <1228, 1222, 1187>, 0,
    <1228, 1187, 1193>, 0,
    <1228, 1193, 1191>, 0,
    <1228, 1191, 1226>, 0,
    <1228, 1226, 1225>, 0,
    <1228, 1225, 1227>, 0,
    <1228, 1227, 1221>, 0,
    <1228, 1221, 1222>, 0,
    <1234, 1233, 1196>, 0,
    <1234, 1196, 1198>, 0,
    <1234, 1198, 1195>, 0,
    <1234, 1195, 1231>, 0,
    <1234, 1231, 1229>, 0,
    <1234, 1229, 1232>, 0,
    <1234, 1232, 1230>, 0,
    <1234, 1230, 1233>, 0,
    <1238, 1231, 1195>, 0,
    <1238, 1195, 1203>, 0,
    <1238, 1203, 1201>, 0,
    <1238, 1201, 1236>, 0,
    <1238, 1236, 1235>, 0,
    <1238, 1235, 1237>, 0,
    <1238, 1237, 1229>, 0,
    <1238, 1229, 1231>, 0,
    <1242, 1236, 1201>, 0,
    <1242, 1201, 1207>, 0,
    <1242, 1207, 1205>, 0,
    <1242, 1205, 1240>, 0,
    <1242, 1240, 1239>, 0,
    <1242, 1239, 1241>, 0,
    <1242, 1241, 1235>, 0,
    <1242, 1235, 1236>, 0,
    <1246, 1240, 1205>, 0,
    <1246, 1205, 1211>, 0,
    <1246, 1211, 1209>, 0,
    <1246, 1209, 1244>, 0,
    <1246, 1244, 1243>, 0,
    <1246, 1243, 1245>, 0,
    <1246, 1245, 1239>, 0,
    <1246, 1239, 1240>, 0,
    <1250, 1244, 1209>, 0,
    <1250, 1209, 1215>, 0,
    <1250, 1215, 1213>, 0,
    <1250, 1213, 1248>, 0,
    <1250, 1248, 1247>, 0,
    <1250, 1247, 1249>, 0,
    <1250, 1249, 1243>, 0,
    <1250, 1243, 1244>, 0,
    <1254, 1248, 1213>, 0,
    <1254, 1213, 1219>, 0,
    <1254, 1219, 1217>, 0,
    <1254, 1217, 1252>, 0,
    <1254, 1252, 1251>, 0,
    <1254, 1251, 1253>, 0,
    <1254, 1253, 1247>, 0,
    <1254, 1247, 1248>, 0,
    <1258, 1252, 1217>, 0,
    <1258, 1217, 1223>, 0,
    <1258, 1223, 1221>, 0,
    <1258, 1221, 1256>, 0,
    <1258, 1256, 1255>, 0,
    <1258, 1255, 1257>, 0,
    <1258, 1257, 1251>, 0,
    <1258, 1251, 1252>, 0,
    <1262, 1256, 1221>, 0,
    <1262, 1221, 1227>, 0,
    <1262, 1227, 1225>, 0,
    <1262, 1225, 1260>, 0,
    <1262, 1260, 1259>, 0,
    <1262, 1259, 1261>, 0,
    <1262, 1261, 1255>, 0,
    <1262, 1255, 1256>, 0,
    <1268, 1267, 1230>, 0,
    <1268, 1230, 1232>, 0,
    <1268, 1232, 1229>, 0,
    <1268, 1229, 1265>, 0,
    <1268, 1265, 1263>, 0,
    <1268, 1263, 1266>, 0,
    <1268, 1266, 1264>, 0,
    <1268, 1264, 1267>, 0,
    <1272, 1265, 1229>, 0,
    <1272, 1229, 1237>, 0,
    <1272, 1237, 1235>, 0,
    <1272, 1235, 1270>, 0,
    <1272, 1270, 1269>, 0,
    <1272, 1269, 1271>, 0,
    <1272, 1271, 1263>, 0,
    <1272, 1263, 1265>, 0,
    <1276, 1270, 1235>, 0,
    <1276, 1235, 1241>, 0,
    <1276, 1241, 1239>, 0,
    <1276, 1239, 1274>, 0,
    <1276, 1274, 1273>, 0,
    <1276, 1273, 1275>, 0,
    <1276, 1275, 1269>, 0,
    <1276, 1269, 1270>, 0,
    <1280, 1274, 1239>, 0,
    <1280, 1239, 1245>, 0,
    <1280, 1245, 1243>, 0,
    <1280, 1243, 1278>, 0,
    <1280, 1278, 1277>, 0,
    <1280, 1277, 1279>, 0,
    <1280, 1279, 1273>, 0,
    <1280, 1273, 1274>, 0,
    <1284, 1278, 1243>, 0,
    <1284, 1243, 1249>, 0,
    <1284, 1249, 1247>, 0,
    <1284, 1247, 1282>, 0,
    <1284, 1282, 1281>, 0,
    <1284, 1281, 1283>, 0,
    <1284, 1283, 1277>, 0,
    <1284, 1277, 1278>, 0,
    <1288, 1282, 1247>, 0,
    <1288, 1247, 1253>, 0,
    <1288, 1253, 1251>, 0,
    <1288, 1251, 1286>, 0,
    <1288, 1286, 1285>, 0,
    <1288, 1285, 1287>, 0,
    <1288, 1287, 1281>, 0,
    <1288, 1281, 1282>, 0,
    <1292, 1286, 1251>, 0,
    <1292, 1251, 1257>, 0,
    <1292, 1257, 1255>, 0,
    <1292, 1255, 1290>, 0,
    <1292, 1290, 1289>, 0,
    <1292, 1289, 1291>, 0,
    <1292, 1291, 1285>, 0,
    <1292, 1285, 1286>, 0,
    <1296, 1290, 1255>, 0,
    <1296, 1255, 1261>, 0,
    <1296, 1261, 1259>, 0,
    <1296, 1259, 1294>, 0,
    <1296, 1294, 1293>, 0,
    <1296, 1293, 1295>, 0,
    <1296, 1295, 1289>, 0,
    <1296, 1289, 1290>, 0,
    <1300, 1056, 781>, 0,
    <1300, 781, 997>, 0,
    <1300, 997, 995>, 0,
    <1300, 995, 1298>, 0,
    <1300, 1298, 1297>, 0,
    <1300, 1297, 1299>, 0,
    <1300, 1299, 1055>, 0,
    <1300, 1055, 1056>, 0,
    <1304, 1298, 995>, 0,
    <1304, 995, 1001>, 0,
    <1304, 1001, 999>, 0,
    <1304, 999, 1302>, 0,
    <1304, 1302, 1301>, 0,
    <1304, 1301, 1303>, 0,
    <1304, 1303, 1297>, 0,
    <1304, 1297, 1298>, 0,
    <1308, 1302, 999>, 0,
    <1308, 999, 1005>, 0,
    <1308, 1005, 1003>, 0,
    <1308, 1003, 1306>, 0,
    <1308, 1306, 1305>, 0,
    <1308, 1305, 1307>, 0,
    <1308, 1307, 1301>, 0,
    <1308, 1301, 1302>, 0,
    <1312, 1306, 1003>, 0,
    <1312, 1003, 1009>, 0,
    <1312, 1009, 1007>, 0,
    <1312, 1007, 1310>, 0,
    <1312, 1310, 1309>, 0,
    <1312, 1309, 1311>, 0,
    <1312, 1311, 1305>, 0,
    <1312, 1305, 1306>, 0,
    <1316, 1310, 1007>, 0,
    <1316, 1007, 1013>, 0,
    <1316, 1013, 1011>, 0,
    <1316, 1011, 1314>, 0,
    <1316, 1314, 1313>, 0,
    <1316, 1313, 1315>, 0,
    <1316, 1315, 1309>, 0,
    <1316, 1309, 1310>, 0,
    <1320, 1314, 1011>, 0,
    <1320, 1011, 1017>, 0,
    <1320, 1017, 1015>, 0,
    <1320, 1015, 1318>, 0,
    <1320, 1318, 1317>, 0,
    <1320, 1317, 1319>, 0,
    <1320, 1319, 1313>, 0,
    <1320, 1313, 1314>, 0,
    <1324, 1318, 1015>, 0,
    <1324, 1015, 1021>, 0,
    <1324, 1021, 1019>, 0,
    <1324, 1019, 1322>, 0,
    <1324, 1322, 1321>, 0,
    <1324, 1321, 1323>, 0,
    <1324, 1323, 1317>, 0,
    <1324, 1317, 1318>, 0,
    <1326, 1322, 1019>, 0,
    <1326, 1019, 1023>, 0,
    <1326, 1023, 752>, 0,
    <1326, 752, 1029>, 0,
    <1326, 1029, 1026>, 0,
    <1326, 1026, 1325>, 0,
    <1326, 1325, 1321>, 0,
    <1326, 1321, 1322>, 0,
    <1330, 1090, 1055>, 0,
    <1330, 1055, 1299>, 0,
    <1330, 1299, 1297>, 0,
    <1330, 1297, 1328>, 0,
    <1330, 1328, 1327>, 0,
    <1330, 1327, 1329>, 0,
    <1330, 1329, 1089>, 0,
    <1330, 1089, 1090>, 0,
    <1334, 1328, 1297>, 0,
    <1334, 1297, 1303>, 0,
    <1334, 1303, 1301>, 0,
    <1334, 1301, 1332>, 0,
    <1334, 1332, 1331>, 0,
    <1334, 1331, 1333>, 0,
    <1334, 1333, 1327>, 0,
    <1334, 1327, 1328>, 0,
    <1338, 1332, 1301>, 0,
    <1338, 1301, 1307>, 0,
    <1338, 1307, 1305>, 0,
    <1338, 1305, 1336>, 0,
    <1338, 1336, 1335>, 0,
    <1338, 1335, 1337>, 0,
    <1338, 1337, 1331>, 0,
    <1338, 1331, 1332>, 0,
    <1342, 1336, 1305>, 0,
    <1342, 1305, 1311>, 0,
    <1342, 1311, 1309>, 0,
    <1342, 1309, 1340>, 0,
    <1342, 1340, 1339>, 0,
    <1342, 1339, 1341>, 0,
    <1342, 1341, 1335>, 0,
    <1342, 1335, 1336>, 0,
    <1346, 1340, 1309>, 0,
    <1346, 1309, 1315>, 0,
    <1346, 1315, 1313>, 0,
    <1346, 1313, 1344>, 0,
    <1346, 1344, 1343>, 0,
    <1346, 1343, 1345>, 0,
    <1346, 1345, 1339>, 0,
    <1346, 1339, 1340>, 0,
    <1350, 1344, 1313>, 0,
    <1350, 1313, 1319>, 0,
    <1350, 1319, 1317>, 0,
    <1350, 1317, 1348>, 0,
    <1350, 1348, 1347>, 0,
    <1350, 1347, 1349>, 0,
    <1350, 1349, 1343>, 0,
    <1350, 1343, 1344>, 0,
    <1354, 1348, 1317>, 0,
    <1354, 1317, 1323>, 0,
    <1354, 1323, 1321>, 0,
    <1354, 1321, 1352>, 0,
    <1354, 1352, 1351>, 0,
    <1354, 1351, 1353>, 0,
    <1354, 1353, 1347>, 0,
    <1354, 1347, 1348>, 0,
    <1356, 1352, 1321>, 0,
    <1356, 1321, 1325>, 0,
    <1356, 1325, 1026>, 0,
    <1356, 1026, 1063>, 0,
    <1356, 1063, 1060>, 0,
    <1356, 1060, 1355>, 0,
    <1356, 1355, 1351>, 0,
    <1356, 1351, 1352>, 0,
    <1360, 1124, 1089>, 0,
    <1360, 1089, 1329>, 0,
    <1360, 1329, 1327>, 0,
    <1360, 1327, 1358>, 0,
    <1360, 1358, 1357>, 0,
    <1360, 1357, 1359>, 0,
    <1360, 1359, 1123>, 0,
    <1360, 1123, 1124>, 0,
    <1364, 1358, 1327>, 0,
    <1364, 1327, 1333>, 0,
    <1364, 1333, 1331>, 0,
    <1364, 1331, 1362>, 0,
    <1364, 1362, 1361>, 0,
    <1364, 1361, 1363>, 0,
    <1364, 1363, 1357>, 0,
    <1364, 1357, 1358>, 0,
    <1368, 1362, 1331>, 0,
    <1368, 1331, 1337>, 0,
    <1368, 1337, 1335>, 0,
    <1368, 1335, 1366>, 0,
    <1368, 1366, 1365>, 0,
    <1368, 1365, 1367>, 0,
    <1368, 1367, 1361>, 0,
    <1368, 1361, 1362>, 0,
    <1372, 1366, 1335>, 0,
    <1372, 1335, 1341>, 0,
    <1372, 1341, 1339>, 0,
    <1372, 1339, 1370>, 0,
    <1372, 1370, 1369>, 0,
    <1372, 1369, 1371>, 0,
    <1372, 1371, 1365>, 0,
    <1372, 1365, 1366>, 0,
    <1376, 1370, 1339>, 0,
    <1376, 1339, 1345>, 0,
    <1376, 1345, 1343>, 0,
    <1376, 1343, 1374>, 0,
    <1376, 1374, 1373>, 0,
    <1376, 1373, 1375>, 0,
    <1376, 1375, 1369>, 0,
    <1376, 1369, 1370>, 0,
    <1380, 1374, 1343>, 0,
    <1380, 1343, 1349>, 0,
    <1380, 1349, 1347>, 0,
    <1380, 1347, 1378>, 0,
    <1380, 1378, 1377>, 0,
    <1380, 1377, 1379>, 0,
    <1380, 1379, 1373>, 0,
    <1380, 1373, 1374>, 0,
    <1384, 1378, 1347>, 0,
    <1384, 1347, 1353>, 0,
    <1384, 1353, 1351>, 0,
    <1384, 1351, 1382>, 0,
    <1384, 1382, 1381>, 0,
    <1384, 1381, 1383>, 0,
    <1384, 1383, 1377>, 0,
    <1384, 1377, 1378>, 0,
    <1386, 1382, 1351>, 0,
    <1386, 1351, 1355>, 0,
    <1386, 1355, 1060>, 0,
    <1386, 1060, 1097>, 0,
    <1386, 1097, 1094>, 0,
    <1386, 1094, 1385>, 0,
    <1386, 1385, 1381>, 0,
    <1386, 1381, 1382>, 0,
    <1390, 1158, 1123>, 0,
    <1390, 1123, 1359>, 0,
    <1390, 1359, 1357>, 0,
    <1390, 1357, 1388>, 0,
    <1390, 1388, 1387>, 0,
    <1390, 1387, 1389>, 0,
    <1390, 1389, 1157>, 0,
    <1390, 1157, 1158>, 0,
    <1394, 1388, 1357>, 0,
    <1394, 1357, 1363>, 0,
    <1394, 1363, 1361>, 0,
    <1394, 1361, 1392>, 0,
    <1394, 1392, 1391>, 0,
    <1394, 1391, 1393>, 0,
    <1394, 1393, 1387>, 0,
    <1394, 1387, 1388>, 0,
    <1398, 1392, 1361>, 0,
    <1398, 1361, 1367>, 0,
    <1398, 1367, 1365>, 0,
    <1398, 1365, 1396>, 0,
    <1398, 1396, 1395>, 0,
    <1398, 1395, 1397>, 0,
    <1398, 1397, 1391>, 0,
    <1398, 1391, 1392>, 0,
    <1402, 1396, 1365>, 0,
    <1402, 1365, 1371>, 0,
    <1402, 1371, 1369>, 0,
    <1402, 1369, 1400>, 0,
    <1402, 1400, 1399>, 0,
    <1402, 1399, 1401>, 0,
    <1402, 1401, 1395>, 0,
    <1402, 1395, 1396>, 0,
    <1406, 1400, 1369>, 0,
    <1406, 1369, 1375>, 0,
    <1406, 1375, 1373>, 0,
    <1406, 1373, 1404>, 0,
    <1406, 1404, 1403>, 0,
    <1406, 1403, 1405>, 0,
    <1406, 1405, 1399>, 0,
    <1406, 1399, 1400>, 0,
    <1410, 1404, 1373>, 0,
    <1410, 1373, 1379>, 0,
    <1410, 1379, 1377>, 0,
    <1410, 1377, 1408>, 0,
    <1410, 1408, 1407>, 0,
    <1410, 1407, 1409>, 0,
    <1410, 1409, 1403>, 0,
    <1410, 1403, 1404>, 0,
    <1414, 1408, 1377>, 0,
    <1414, 1377, 1383>, 0,
    <1414, 1383, 1381>, 0,
    <1414, 1381, 1412>, 0,
    <1414, 1412, 1411>, 0,
    <1414, 1411, 1413>, 0,
    <1414, 1413, 1407>, 0,
    <1414, 1407, 1408>, 0,
    <1416, 1412, 1381>, 0,
    <1416, 1381, 1385>, 0,
    <1416, 1385, 1094>, 0,
    <1416, 1094, 1131>, 0,
    <1416, 1131, 1128>, 0,
    <1416, 1128, 1415>, 0,
    <1416, 1415, 1411>, 0,
    <1416, 1411, 1412>, 0,
    <1420, 1192, 1157>, 0,
    <1420, 1157, 1389>, 0,
    <1420, 1389, 1387>, 0,
    <1420, 1387, 1418>, 0,
    <1420, 1418, 1417>, 0,
    <1420, 1417, 1419>, 0,
    <1420, 1419, 1191>, 0,
    <1420, 1191, 1192>, 0,
    <1424, 1418, 1387>, 0,
    <1424, 1387, 1393>, 0,
    <1424, 1393, 1391>, 0,
    <1424, 1391, 1422>, 0,
    <1424, 1422, 1421>, 0,
    <1424, 1421, 1423>, 0,
    <1424, 1423, 1417>, 0,
    <1424, 1417, 1418>, 0,
    <1428, 1422, 1391>, 0,
    <1428, 1391, 1397>, 0,
    <1428, 1397, 1395>, 0,
    <1428, 1395, 1426>, 0,
    <1428, 1426, 1425>, 0,
    <1428, 1425, 1427>, 0,
    <1428, 1427, 1421>, 0,
    <1428, 1421, 1422>, 0,
    <1432, 1426, 1395>, 0,
    <1432, 1395, 1401>, 0,
    <1432, 1401, 1399>, 0,
    <1432, 1399, 1430>, 0,
    <1432, 1430, 1429>, 0,
    <1432, 1429, 1431>, 0,
    <1432, 1431, 1425>, 0,
    <1432, 1425, 1426>, 0,
    <1436, 1430, 1399>, 0,
    <1436, 1399, 1405>, 0,
    <1436, 1405, 1403>, 0,
    <1436, 1403, 1434>, 0,
    <1436, 1434, 1433>, 0,
    <1436, 1433, 1435>, 0,
    <1436, 1435, 1429>, 0,
    <1436, 1429, 1430>, 0,
    <1440, 1434, 1403>, 0,
    <1440, 1403, 1409>, 0,
    <1440, 1409, 1407>, 0,
    <1440, 1407, 1438>, 0,
    <1440, 1438, 1437>, 0,
    <1440, 1437, 1439>, 0,
    <1440, 1439, 1433>, 0,
    <1440, 1433, 1434>, 0,
    <1444, 1438, 1407>, 0,
    <1444, 1407, 1413>, 0,
    <1444, 1413, 1411>, 0,
    <1444, 1411, 1442>, 0,
    <1444, 1442, 1441>, 0,
    <1444, 1441, 1443>, 0,
    <1444, 1443, 1437>, 0,
    <1444, 1437, 1438>, 0,
    <1446, 1442, 1411>, 0,
    <1446, 1411, 1415>, 0,
    <1446, 1415, 1128>, 0,
    <1446, 1128, 1165>, 0,
    <1446, 1165, 1162>, 0,
    <1446, 1162, 1445>, 0,
    <1446, 1445, 1441>, 0,
    <1446, 1441, 1442>, 0,
    <1450, 1226, 1191>, 0,
    <1450, 1191, 1419>, 0,
    <1450, 1419, 1417>, 0,
    <1450, 1417, 1448>, 0,
    <1450, 1448, 1447>, 0,
    <1450, 1447, 1449>, 0,
    <1450, 1449, 1225>, 0,
    <1450, 1225, 1226>, 0,
    <1454, 1448, 1417>, 0,
    <1454, 1417, 1423>, 0,
    <1454, 1423, 1421>, 0,
    <1454, 1421, 1452>, 0,
    <1454, 1452, 1451>, 0,
    <1454, 1451, 1453>, 0,
    <1454, 1453, 1447>, 0,
    <1454, 1447, 1448>, 0,
    <1458, 1452, 1421>, 0,
    <1458, 1421, 1427>, 0,
    <1458, 1427, 1425>, 0,
    <1458, 1425, 1456>, 0,
    <1458, 1456, 1455>, 0,
    <1458, 1455, 1457>, 0,
    <1458, 1457, 1451>, 0,
    <1458, 1451, 1452>, 0,
    <1462, 1456, 1425>, 0,
    <1462, 1425, 1431>, 0,
    <1462, 1431, 1429>, 0,
    <1462, 1429, 1460>, 0,
    <1462, 1460, 1459>, 0,
    <1462, 1459, 1461>, 0,
    <1462, 1461, 1455>, 0,
    <1462, 1455, 1456>, 0,
    <1466, 1460, 1429>, 0,
    <1466, 1429, 1435>, 0,
    <1466, 1435, 1433>, 0,
    <1466, 1433, 1464>, 0,
    <1466, 1464, 1463>, 0,
    <1466, 1463, 1465>, 0,
    <1466, 1465, 1459>, 0,
    <1466, 1459, 1460>, 0,
    <1470, 1464, 1433>, 0,
    <1470, 1433, 1439>, 0,
    <1470, 1439, 1437>, 0,
    <1470, 1437, 1468>, 0,
    <1470, 1468, 1467>, 0,
    <1470, 1467, 1469>, 0,
    <1470, 1469, 1463>, 0,
    <1470, 1463, 1464>, 0,
    <1474, 1468, 1437>, 0,
    <1474, 1437, 1443>, 0,
    <1474, 1443, 1441>, 0,
    <1474, 1441, 1472>, 0,
    <1474, 1472, 1471>, 0,
    <1474, 1471, 1473>, 0,
    <1474, 1473, 1467>, 0,
    <1474, 1467, 1468>, 0,
    <1476, 1472, 1441>, 0,
    <1476, 1441, 1445>, 0,
    <1476, 1445, 1162>, 0,
    <1476, 1162, 1199>, 0,
    <1476, 1199, 1196>, 0,
    <1476, 1196, 1475>, 0,
    <1476, 1475, 1471>, 0,
    <1476, 1471, 1472>, 0,
    <1482, 1481, 1225>, 0,
    <1482, 1225, 1449>, 0,
    <1482, 1449, 1447>, 0,
    <1482, 1447, 1479>, 0,
    <1482, 1479, 1477>, 0,
    <1482, 1477, 1480>, 0,
    <1482, 1480, 1478>, 0,
    <1482, 1478, 1481>, 0,
    <1486, 1479, 1447>, 0,
    <1486, 1447, 1453>, 0,
    <1486, 1453, 1451>, 0,
    <1486, 1451, 1484>, 0,
    <1486, 1484, 1483>, 0,
    <1486, 1483, 1485>, 0,
    <1486, 1485, 1477>, 0,
    <1486, 1477, 1479>, 0,
    <1490, 1484, 1451>, 0,
    <1490, 1451, 1457>, 0,
    <1490, 1457, 1455>, 0,
    <1490, 1455, 1488>, 0,
    <1490, 1488, 1487>, 0,
    <1490, 1487, 1489>, 0,
    <1490, 1489, 1483>, 0,
    <1490, 1483, 1484>, 0,
    <1494, 1488, 1455>, 0,
    <1494, 1455, 1461>, 0,
    <1494, 1461, 1459>, 0,
    <1494, 1459, 1492>, 0,
    <1494, 1492, 1491>, 0,
    <1494, 1491, 1493>, 0,
    <1494, 1493, 1487>, 0,
    <1494, 1487, 1488>, 0,
    <1498, 1492, 1459>, 0,
    <1498, 1459, 1465>, 0,
    <1498, 1465, 1463>, 0,
    <1498, 1463, 1496>, 0,
    <1498, 1496, 1495>, 0,
    <1498, 1495, 1497>, 0,
    <1498, 1497, 1491>, 0,
    <1498, 1491, 1492>, 0,
    <1502, 1496, 1463>, 0,
    <1502, 1463, 1469>, 0,
    <1502, 1469, 1467>, 0,
    <1502, 1467, 1500>, 0,
    <1502, 1500, 1499>, 0,
    <1502, 1499, 1501>, 0,
    <1502, 1501, 1495>, 0,
    <1502, 1495, 1496>, 0,
    <1506, 1500, 1467>, 0,
    <1506, 1467, 1473>, 0,
    <1506, 1473, 1471>, 0,
    <1506, 1471, 1504>, 0,
    <1506, 1504, 1503>, 0,
    <1506, 1503, 1505>, 0,
    <1506, 1505, 1499>, 0,
    <1506, 1499, 1500>, 0,
    <1510, 1504, 1471>, 0,
    <1510, 1471, 1475>, 0,
    <1510, 1475, 1196>, 0,
    <1510, 1196, 1508>, 0,
    <1510, 1508, 1507>, 0,
    <1510, 1507, 1509>, 0,
    <1510, 1509, 1503>, 0,
    <1510, 1503, 1504>, 0,
    <1513, 1512, 1478>, 0,
    <1513, 1478, 1480>, 0,
    <1513, 1480, 1477>, 0,
    <1513, 1477, 1511>, 0,
    <1513, 1511, 1289>, 0,
    <1513, 1289, 1295>, 0,
    <1513, 1295, 1293>, 0,
    <1513, 1293, 1512>, 0,
    <1515, 1511, 1477>, 0,
    <1515, 1477, 1485>, 0,
    <1515, 1485, 1483>, 0,
    <1515, 1483, 1514>, 0,
    <1515, 1514, 1285>, 0,
    <1515, 1285, 1291>, 0,
    <1515, 1291, 1289>, 0,
    <1515, 1289, 1511>, 0,
    <1517, 1514, 1483>, 0,
    <1517, 1483, 1489>, 0,
    <1517, 1489, 1487>, 0,
    <1517, 1487, 1516>, 0,
    <1517, 1516, 1281>, 0,
    <1517, 1281, 1287>, 0,
    <1517, 1287, 1285>, 0,
    <1517, 1285, 1514>, 0,
    <1519, 1516, 1487>, 0,
    <1519, 1487, 1493>, 0,
    <1519, 1493, 1491>, 0,
    <1519, 1491, 1518>, 0,
    <1519, 1518, 1277>, 0,
    <1519, 1277, 1283>, 0,
    <1519, 1283, 1281>, 0,
    <1519, 1281, 1516>, 0,
    <1521, 1518, 1491>, 0,
    <1521, 1491, 1497>, 0,
    <1521, 1497, 1495>, 0,
    <1521, 1495, 1520>, 0,
    <1521, 1520, 1273>, 0,
    <1521, 1273, 1279>, 0,
    <1521, 1279, 1277>, 0,
    <1521, 1277, 1518>, 0,
    <1523, 1520, 1495>, 0,
    <1523, 1495, 1501>, 0,
    <1523, 1501, 1499>, 0,
    <1523, 1499, 1522>, 0,
    <1523, 1522, 1269>, 0,
    <1523, 1269, 1275>, 0,
    <1523, 1275, 1273>, 0,
    <1523, 1273, 1520>, 0,
    <1525, 1522, 1499>, 0,
    <1525, 1499, 1505>, 0,
    <1525, 1505, 1503>, 0,
    <1525, 1503, 1524>, 0,
    <1525, 1524, 1263>, 0,
    <1525, 1263, 1271>, 0,
    <1525, 1271, 1269>, 0,
    <1525, 1269, 1522>, 0,
    <1527, 1524, 1503>, 0,
    <1527, 1503, 1509>, 0,
    <1527, 1509, 1507>, 0,
    <1527, 1507, 1526>, 0,
    <1527, 1526, 1264>, 0,
    <1527, 1264, 1266>, 0,
    <1527, 1266, 1263>, 0,
    <1527, 1263, 1524>, 0
  }
  normal_indices {
    3040,   // from 0 triangles and 1520 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 5, 6>,
    <0, 6, 1>,
    <7, 3, 2>,
    <7, 2, 8>,
    <7, 8, 9>,
    <7, 9, 10>,
    <7, 10, 4>,
    <7, 4, 3>,
    <11, 8, 2>,
    <11, 2, 12>,
    <11, 12, 13>,
    <11, 13, 14>,
    <11, 14, 9>,
    <11, 9, 8>,
    <15, 12, 2>,
    <15, 2, 16>,
    <15, 16, 17>,
    <15, 17, 18>,
    <15, 18, 13>,
    <15, 13, 12>,
    <19, 16, 2>,
    <19, 2, 20>,
    <19, 20, 21>,
    <19, 21, 22>,
    <19, 22, 17>,
    <19, 17, 16>,
    <23, 20, 2>,
    <23, 2, 24>,
    <23, 24, 25>,
    <23, 25, 26>,
    <23, 26, 21>,
    <23, 21, 20>,
    <27, 24, 2>,
    <27, 2, 28>,
    <27, 28, 29>,
    <27, 29, 30>,
    <27, 30, 25>,
    <27, 25, 24>,
    <31, 28, 2>,
    <31, 2, 32>,
    <31, 32, 33>,
    <31, 33, 34>,
    <31, 34, 29>,
    <31, 29, 28>,
    <35, 36, 6>,
    <35, 6, 5>,
    <35, 5, 4>,
    <35, 4, 37>,
    <35, 37, 38>,
    <35, 38, 39>,
    <35, 39, 40>,
    <35, 40, 36>,
    <41, 37, 4>,
    <41, 4, 10>,
    <41, 10, 9>,
    <41, 9, 42>,
    <41, 42, 43>,
    <41, 43, 44>,
    <41, 44, 38>,
    <41, 38, 37>,
    <45, 42, 9>,
    <45, 9, 14>,
    <45, 14, 13>,
    <45, 13, 46>,
    <45, 46, 47>,
    <45, 47, 48>,
    <45, 48, 43>,
    <45, 43, 42>,
    <49, 46, 13>,
    <49, 13, 18>,
    <49, 18, 17>,
    <49, 17, 50>,
    <49, 50, 51>,
    <49, 51, 52>,
    <49, 52, 47>,
    <49, 47, 46>,
    <53, 50, 17>,
    <53, 17, 22>,
    <53, 22, 21>,
    <53, 21, 54>,
    <53, 54, 55>,
    <53, 55, 56>,
    <53, 56, 51>,
    <53, 51, 50>,
    <57, 54, 21>,
    <57, 21, 26>,
    <57, 26, 25>,
    <57, 25, 58>,
    <57, 58, 59>,
    <57, 59, 60>,
    <57, 60, 55>,
    <57, 55, 54>,
    <61, 58, 25>,
    <61, 25, 30>,
    <61, 30, 29>,
    <61, 29, 62>,
    <61, 62, 63>,
    <61, 63, 64>,
    <61, 64, 59>,
    <61, 59, 58>,
    <65, 62, 29>,
    <65, 29, 34>,
    <65, 34, 33>,
    <65, 33, 66>,
    <65, 66, 67>,
    <65, 67, 68>,
    <65, 68, 63>,
    <65, 63, 62>,
    <69, 70, 40>,
    <69, 40, 39>,
    <69, 39, 38>,
    <69, 38, 71>,
    <69, 71, 72>,
    <69, 72, 73>,
    <69, 73, 74>,
    <69, 74, 70>,
    <75, 71, 38>,
    <75, 38, 44>,
    <75, 44, 43>,
    <75, 43, 76>,
    <75, 76, 77>,
    <75, 77, 78>,
    <75, 78, 72>,
    <75, 72, 71>,
    <79, 76, 43>,
    <79, 43, 48>,
    <79, 48, 47>,
    <79, 47, 80>,
    <79, 80, 81>,
    <79, 81, 82>,
    <79, 82, 77>,
    <79, 77, 76>,
    <83, 80, 47>,
    <83, 47, 52>,
    <83, 52, 51>,
    <83, 51, 84>,
    <83, 84, 85>,
    <83, 85, 86>,
    <83, 86, 81>,
    <83, 81, 80>,
    <87, 84, 51>,
    <87, 51, 56>,
    <87, 56, 55>,
    <87, 55, 88>,
    <87, 88, 89>,
    <87, 89, 90>,
    <87, 90, 85>,
    <87, 85, 84>,
    <91, 88, 55>,
    <91, 55, 60>,
    <91, 60, 59>,
    <91, 59, 92>,
    <91, 92, 93>,
    <91, 93, 94>,
    <91, 94, 89>,
    <91, 89, 88>,
    <95, 92, 59>,
    <95, 59, 64>,
    <95, 64, 63>,
    <95, 63, 96>,
    <95, 96, 97>,
    <95, 97, 98>,
    <95, 98, 93>,
    <95, 93, 92>,
    <99, 96, 63>,
    <99, 63, 68>,
    <99, 68, 67>,
    <99, 67, 100>,
    <99, 100, 101>,
    <99, 101, 102>,
    <99, 102, 97>,
    <99, 97, 96>,
    <103, 104, 74>,
    <103, 74, 73>,
    <103, 73, 72>,
    <103, 72, 105>,
    <103, 105, 106>,
    <103, 106, 107>,
    <103, 107, 108>,
    <103, 108, 104>,
    <109, 105, 72>,
    <109, 72, 78>,
    <109, 78, 77>,
    <109, 77, 110>,
    <109, 110, 111>,
    <109, 111, 112>,
    <109, 112, 106>,
    <109, 106, 105>,
    <113, 110, 77>,
    <113, 77, 82>,
    <113, 82, 81>,
    <113, 81, 114>,
    <113, 114, 115>,
    <113, 115, 116>,
    <113, 116, 111>,
    <113, 111, 110>,
    <117, 114, 81>,
    <117, 81, 86>,
    <117, 86, 85>,
    <117, 85, 118>,
    <117, 118, 119>,
    <117, 119, 120>,
    <117, 120, 115>,
    <117, 115, 114>,
    <121, 118, 85>,
    <121, 85, 90>,
    <121, 90, 89>,
    <121, 89, 122>,
    <121, 122, 123>,
    <121, 123, 124>,
    <121, 124, 119>,
    <121, 119, 118>,
    <125, 122, 89>,
    <125, 89, 94>,
    <125, 94, 93>,
    <125, 93, 126>,
    <125, 126, 127>,
    <125, 127, 128>,
    <125, 128, 123>,
    <125, 123, 122>,
    <129, 126, 93>,
    <129, 93, 98>,
    <129, 98, 97>,
    <129, 97, 130>,
    <129, 130, 131>,
    <129, 131, 132>,
    <129, 132, 127>,
    <129, 127, 126>,
    <133, 130, 97>,
    <133, 97, 102>,
    <133, 102, 101>,
    <133, 101, 134>,
    <133, 134, 135>,
    <133, 135, 136>,
    <133, 136, 131>,
    <133, 131, 130>,
    <137, 138, 108>,
    <137, 108, 107>,
    <137, 107, 106>,
    <137, 106, 139>,
    <137, 139, 140>,
    <137, 140, 141>,
    <137, 141, 142>,
    <137, 142, 138>,
    <143, 139, 106>,
    <143, 106, 112>,
    <143, 112, 111>,
    <143, 111, 144>,
    <143, 144, 145>,
    <143, 145, 146>,
    <143, 146, 140>,
    <143, 140, 139>,
    <147, 144, 111>,
    <147, 111, 116>,
    <147, 116, 115>,
    <147, 115, 148>,
    <147, 148, 149>,
    <147, 149, 150>,
    <147, 150, 145>,
    <147, 145, 144>,
    <151, 148, 115>,
    <151, 115, 120>,
    <151, 120, 119>,
    <151, 119, 152>,
    <151, 152, 153>,
    <151, 153, 154>,
    <151, 154, 149>,
    <151, 149, 148>,
    <155, 152, 119>,
    <155, 119, 124>,
    <155, 124, 123>,
    <155, 123, 156>,
    <155, 156, 157>,
    <155, 157, 158>,
    <155, 158, 153>,
    <155, 153, 152>,
    <159, 156, 123>,
    <159, 123, 128>,
    <159, 128, 127>,
    <159, 127, 160>,
    <159, 160, 161>,
    <159, 161, 162>,
    <159, 162, 157>,
    <159, 157, 156>,
    <163, 160, 127>,
    <163, 127, 132>,
    <163, 132, 131>,
    <163, 131, 164>,
    <163, 164, 165>,
    <163, 165, 166>,
    <163, 166, 161>,
    <163, 161, 160>,
    <167, 164, 131>,
    <167, 131, 136>,
    <167, 136, 135>,
    <167, 135, 168>,
    <167, 168, 169>,
    <167, 169, 170>,
    <167, 170, 165>,
    <167, 165, 164>,
    <171, 172, 142>,
    <171, 142, 141>,
    <171, 141, 140>,
    <171, 140, 173>,
    <171, 173, 174>,
    <171, 174, 175>,
    <171, 175, 176>,
    <171, 176, 172>,
    <177, 173, 140>,
    <177, 140, 146>,
    <177, 146, 145>,
    <177, 145, 178>,
    <177, 178, 179>,
    <177, 179, 180>,
    <177, 180, 174>,
    <177, 174, 173>,
    <181, 178, 145>,
    <181, 145, 150>,
    <181, 150, 149>,
    <181, 149, 182>,
    <181, 182, 183>,
    <181, 183, 184>,
    <181, 184, 179>,
    <181, 179, 178>,
    <185, 182, 149>,
    <185, 149, 154>,
    <185, 154, 153>,
    <185, 153, 186>,
    <185, 186, 187>,
    <185, 187, 188>,
    <185, 188, 183>,
    <185, 183, 182>,
    <189, 186, 153>,
    <189, 153, 158>,
    <189, 158, 157>,
    <189, 157, 190>,
    <189, 190, 191>,
    <189, 191, 192>,
    <189, 192, 187>,
    <189, 187, 186>,
    <193, 190, 157>,
    <193, 157, 162>,
    <193, 162, 161>,
    <193, 161, 194>,
    <193, 194, 195>,
    <193, 195, 196>,
    <193, 196, 191>,
    <193, 191, 190>,
    <197, 194, 161>,
    <197, 161, 166>,
    <197, 166, 165>,
    <197, 165, 198>,
    <197, 198, 199>,
    <197, 199, 200>,
    <197, 200, 195>,
    <197, 195, 194>,
    <201, 198, 165>,
    <201, 165, 170>,
    <201, 170, 169>,
    <201, 169, 202>,
    <201, 202, 203>,
    <201, 203, 204>,
    <201, 204, 199>,
    <201, 199, 198>,
    <205, 206, 176>,
    <205, 176, 175>,
    <205, 175, 174>,
    <205, 174, 207>,
    <205, 207, 208>,
    <205, 208, 209>,
    <205, 209, 210>,
    <205, 210, 206>,
    <211, 207, 174>,
    <211, 174, 180>,
    <211, 180, 179>,
    <211, 179, 212>,
    <211, 212, 213>,
    <211, 213, 214>,
    <211, 214, 208>,
    <211, 208, 207>,
    <215, 212, 179>,
    <215, 179, 184>,
    <215, 184, 183>,
    <215, 183, 216>,
    <215, 216, 217>,
    <215, 217, 218>,
    <215, 218, 213>,
    <215, 213, 212>,
    <219, 216, 183>,
    <219, 183, 188>,
    <219, 188, 187>,
    <219, 187, 220>,
    <219, 220, 221>,
    <219, 221, 222>,
    <219, 222, 217>,
    <219, 217, 216>,
    <223, 220, 187>,
    <223, 187, 192>,
    <223, 192, 191>,
    <223, 191, 224>,
    <223, 224, 225>,
    <223, 225, 226>,
    <223, 226, 221>,
    <223, 221, 220>,
    <227, 224, 191>,
    <227, 191, 196>,
    <227, 196, 195>,
    <227, 195, 228>,
    <227, 228, 229>,
    <227, 229, 230>,
    <227, 230, 225>,
    <227, 225, 224>,
    <231, 228, 195>,
    <231, 195, 200>,
    <231, 200, 199>,
    <231, 199, 232>,
    <231, 232, 233>,
    <231, 233, 234>,
    <231, 234, 229>,
    <231, 229, 228>,
    <235, 232, 199>,
    <235, 199, 204>,
    <235, 204, 203>,
    <235, 203, 236>,
    <235, 236, 237>,
    <235, 237, 238>,
    <235, 238, 233>,
    <235, 233, 232>,
    <239, 240, 210>,
    <239, 210, 209>,
    <239, 209, 208>,
    <239, 208, 241>,
    <239, 241, 242>,
    <239, 242, 243>,
    <239, 243, 244>,
    <239, 244, 240>,
    <245, 241, 208>,
    <245, 208, 214>,
    <245, 214, 213>,
    <245, 213, 246>,
    <245, 246, 247>,
    <245, 247, 248>,
    <245, 248, 242>,
    <245, 242, 241>,
    <249, 246, 213>,
    <249, 213, 218>,
    <249, 218, 217>,
    <249, 217, 250>,
    <249, 250, 251>,
    <249, 251, 252>,
    <249, 252, 247>,
    <249, 247, 246>,
    <253, 250, 217>,
    <253, 217, 222>,
    <253, 222, 221>,
    <253, 221, 254>,
    <253, 254, 255>,
    <253, 255, 256>,
    <253, 256, 251>,
    <253, 251, 250>,
    <257, 254, 221>,
    <257, 221, 226>,
    <257, 226, 225>,
    <257, 225, 258>,
    <257, 258, 259>,
    <257, 259, 260>,
    <257, 260, 255>,
    <257, 255, 254>,
    <261, 258, 225>,
    <261, 225, 230>,
    <261, 230, 229>,
    <261, 229, 262>,
    <261, 262, 263>,
    <261, 263, 264>,
    <261, 264, 259>,
    <261, 259, 258>,
    <265, 262, 229>,
    <265, 229, 234>,
    <265, 234, 233>,
    <265, 233, 266>,
    <265, 266, 267>,
    <265, 267, 268>,
    <265, 268, 263>,
    <265, 263, 262>,
    <269, 266, 233>,
    <269, 233, 238>,
    <269, 238, 237>,
    <269, 237, 270>,
    <269, 270, 271>,
    <269, 271, 272>,
    <269, 272, 267>,
    <269, 267, 266>,
    <273, 32, 2>,
    <273, 2, 274>,
    <273, 274, 275>,
    <273, 275, 276>,
    <273, 276, 33>,
    <273, 33, 32>,
    <277, 274, 2>,
    <277, 2, 278>,
    <277, 278, 279>,
    <277, 279, 280>,
    <277, 280, 275>,
    <277, 275, 274>,
    <281, 278, 2>,
    <281, 2, 282>,
    <281, 282, 283>,
    <281, 283, 284>,
    <281, 284, 279>,
    <281, 279, 278>,
    <285, 282, 2>,
    <285, 2, 286>,
    <285, 286, 287>,
    <285, 287, 288>,
    <285, 288, 283>,
    <285, 283, 282>,
    <289, 286, 2>,
    <289, 2, 290>,
    <289, 290, 291>,
    <289, 291, 292>,
    <289, 292, 287>,
    <289, 287, 286>,
    <293, 290, 2>,
    <293, 2, 294>,
    <293, 294, 295>,
    <293, 295, 296>,
    <293, 296, 291>,
    <293, 291, 290>,
    <297, 294, 2>,
    <297, 2, 298>,
    <297, 298, 299>,
    <297, 299, 300>,
    <297, 300, 295>,
    <297, 295, 294>,
    <301, 298, 2>,
    <301, 2, 1>,
    <301, 1, 6>,
    <301, 6, 302>,
    <301, 302, 299>,
    <301, 299, 298>,
    <303, 66, 33>,
    <303, 33, 276>,
    <303, 276, 275>,
    <303, 275, 304>,
    <303, 304, 305>,
    <303, 305, 306>,
    <303, 306, 67>,
    <303, 67, 66>,
    <307, 304, 275>,
    <307, 275, 280>,
    <307, 280, 279>,
    <307, 279, 308>,
    <307, 308, 309>,
    <307, 309, 310>,
    <307, 310, 305>,
    <307, 305, 304>,
    <311, 308, 279>,
    <311, 279, 284>,
    <311, 284, 283>,
    <311, 283, 312>,
    <311, 312, 313>,
    <311, 313, 314>,
    <311, 314, 309>,
    <311, 309, 308>,
    <315, 312, 283>,
    <315, 283, 288>,
    <315, 288, 287>,
    <315, 287, 316>,
    <315, 316, 317>,
    <315, 317, 318>,
    <315, 318, 313>,
    <315, 313, 312>,
    <319, 316, 287>,
    <319, 287, 292>,
    <319, 292, 291>,
    <319, 291, 320>,
    <319, 320, 321>,
    <319, 321, 322>,
    <319, 322, 317>,
    <319, 317, 316>,
    <323, 320, 291>,
    <323, 291, 296>,
    <323, 296, 295>,
    <323, 295, 324>,
    <323, 324, 325>,
    <323, 325, 326>,
    <323, 326, 321>,
    <323, 321, 320>,
    <327, 324, 295>,
    <327, 295, 300>,
    <327, 300, 299>,
    <327, 299, 328>,
    <327, 328, 329>,
    <327, 329, 330>,
    <327, 330, 325>,
    <327, 325, 324>,
    <331, 328, 299>,
    <331, 299, 302>,
    <331, 302, 6>,
    <331, 6, 36>,
    <331, 36, 40>,
    <331, 40, 332>,
    <331, 332, 329>,
    <331, 329, 328>,
    <333, 100, 67>,
    <333, 67, 306>,
    <333, 306, 305>,
    <333, 305, 334>,
    <333, 334, 335>,
    <333, 335, 336>,
    <333, 336, 101>,
    <333, 101, 100>,
    <337, 334, 305>,
    <337, 305, 310>,
    <337, 310, 309>,
    <337, 309, 338>,
    <337, 338, 339>,
    <337, 339, 340>,
    <337, 340, 335>,
    <337, 335, 334>,
    <341, 338, 309>,
    <341, 309, 314>,
    <341, 314, 313>,
    <341, 313, 342>,
    <341, 342, 343>,
    <341, 343, 344>,
    <341, 344, 339>,
    <341, 339, 338>,
    <345, 342, 313>,
    <345, 313, 318>,
    <345, 318, 317>,
    <345, 317, 346>,
    <345, 346, 347>,
    <345, 347, 348>,
    <345, 348, 343>,
    <345, 343, 342>,
    <349, 346, 317>,
    <349, 317, 322>,
    <349, 322, 321>,
    <349, 321, 350>,
    <349, 350, 351>,
    <349, 351, 352>,
    <349, 352, 347>,
    <349, 347, 346>,
    <353, 350, 321>,
    <353, 321, 326>,
    <353, 326, 325>,
    <353, 325, 354>,
    <353, 354, 355>,
    <353, 355, 356>,
    <353, 356, 351>,
    <353, 351, 350>,
    <357, 354, 325>,
    <357, 325, 330>,
    <357, 330, 329>,
    <357, 329, 358>,
    <357, 358, 359>,
    <357, 359, 360>,
    <357, 360, 355>,
    <357, 355, 354>,
    <361, 358, 329>,
    <361, 329, 332>,
    <361, 332, 40>,
    <361, 40, 70>,
    <361, 70, 74>,
    <361, 74, 362>,
    <361, 362, 359>,
    <361, 359, 358>,
    <363, 134, 101>,
    <363, 101, 336>,
    <363, 336, 335>,
    <363, 335, 364>,
    <363, 364, 365>,
    <363, 365, 366>,
    <363, 366, 135>,
    <363, 135, 134>,
    <367, 364, 335>,
    <367, 335, 340>,
    <367, 340, 339>,
    <367, 339, 368>,
    <367, 368, 369>,
    <367, 369, 370>,
    <367, 370, 365>,
    <367, 365, 364>,
    <371, 368, 339>,
    <371, 339, 344>,
    <371, 344, 343>,
    <371, 343, 372>,
    <371, 372, 373>,
    <371, 373, 374>,
    <371, 374, 369>,
    <371, 369, 368>,
    <375, 372, 343>,
    <375, 343, 348>,
    <375, 348, 347>,
    <375, 347, 376>,
    <375, 376, 377>,
    <375, 377, 378>,
    <375, 378, 373>,
    <375, 373, 372>,
    <379, 376, 347>,
    <379, 347, 352>,
    <379, 352, 351>,
    <379, 351, 380>,
    <379, 380, 381>,
    <379, 381, 382>,
    <379, 382, 377>,
    <379, 377, 376>,
    <383, 380, 351>,
    <383, 351, 356>,
    <383, 356, 355>,
    <383, 355, 384>,
    <383, 384, 385>,
    <383, 385, 386>,
    <383, 386, 381>,
    <383, 381, 380>,
    <387, 384, 355>,
    <387, 355, 360>,
    <387, 360, 359>,
    <387, 359, 388>,
    <387, 388, 389>,
    <387, 389, 390>,
    <387, 390, 385>,
    <387, 385, 384>,
    <391, 388, 359>,
    <391, 359, 362>,
    <391, 362, 74>,
    <391, 74, 104>,
    <391, 104, 108>,
    <391, 108, 392>,
    <391, 392, 389>,
    <391, 389, 388>,
    <393, 168, 135>,
    <393, 135, 366>,
    <393, 366, 365>,
    <393, 365, 394>,
    <393, 394, 395>,
    <393, 395, 396>,
    <393, 396, 169>,
    <393, 169, 168>,
    <397, 394, 365>,
    <397, 365, 370>,
    <397, 370, 369>,
    <397, 369, 398>,
    <397, 398, 399>,
    <397, 399, 400>,
    <397, 400, 395>,
    <397, 395, 394>,
    <401, 398, 369>,
    <401, 369, 374>,
    <401, 374, 373>,
    <401, 373, 402>,
    <401, 402, 403>,
    <401, 403, 404>,
    <401, 404, 399>,
    <401, 399, 398>,
    <405, 402, 373>,
    <405, 373, 378>,
    <405, 378, 377>,
    <405, 377, 406>,
    <405, 406, 407>,
    <405, 407, 408>,
    <405, 408, 403>,
    <405, 403, 402>,
    <409, 406, 377>,
    <409, 377, 382>,
    <409, 382, 381>,
    <409, 381, 410>,
    <409, 410, 411>,
    <409, 411, 412>,
    <409, 412, 407>,
    <409, 407, 406>,
    <413, 410, 381>,
    <413, 381, 386>,
    <413, 386, 385>,
    <413, 385, 414>,
    <413, 414, 415>,
    <413, 415, 416>,
    <413, 416, 411>,
    <413, 411, 410>,
    <417, 414, 385>,
    <417, 385, 390>,
    <417, 390, 389>,
    <417, 389, 418>,
    <417, 418, 419>,
    <417, 419, 420>,
    <417, 420, 415>,
    <417, 415, 414>,
    <421, 418, 389>,
    <421, 389, 392>,
    <421, 392, 108>,
    <421, 108, 138>,
    <421, 138, 142>,
    <421, 142, 422>,
    <421, 422, 419>,
    <421, 419, 418>,
    <423, 202, 169>,
    <423, 169, 396>,
    <423, 396, 395>,
    <423, 395, 424>,
    <423, 424, 425>,
    <423, 425, 426>,
    <423, 426, 203>,
    <423, 203, 202>,
    <427, 424, 395>,
    <427, 395, 400>,
    <427, 400, 399>,
    <427, 399, 428>,
    <427, 428, 429>,
    <427, 429, 430>,
    <427, 430, 425>,
    <427, 425, 424>,
    <431, 428, 399>,
    <431, 399, 404>,
    <431, 404, 403>,
    <431, 403, 432>,
    <431, 432, 433>,
    <431, 433, 434>,
    <431, 434, 429>,
    <431, 429, 428>,
    <435, 432, 403>,
    <435, 403, 408>,
    <435, 408, 407>,
    <435, 407, 436>,
    <435, 436, 437>,
    <435, 437, 438>,
    <435, 438, 433>,
    <435, 433, 432>,
    <439, 436, 407>,
    <439, 407, 412>,
    <439, 412, 411>,
    <439, 411, 440>,
    <439, 440, 441>,
    <439, 441, 442>,
    <439, 442, 437>,
    <439, 437, 436>,
    <443, 440, 411>,
    <443, 411, 416>,
    <443, 416, 415>,
    <443, 415, 444>,
    <443, 444, 445>,
    <443, 445, 446>,
    <443, 446, 441>,
    <443, 441, 440>,
    <447, 444, 415>,
    <447, 415, 420>,
    <447, 420, 419>,
    <447, 419, 448>,
    <447, 448, 449>,
    <447, 449, 450>,
    <447, 450, 445>,
    <447, 445, 444>,
    <451, 448, 419>,
    <451, 419, 422>,
    <451, 422, 142>,
    <451, 142, 172>,
    <451, 172, 176>,
    <451, 176, 452>,
    <451, 452, 449>,
    <451, 449, 448>,
    <453, 236, 203>,
    <453, 203, 426>,
    <453, 426, 425>,
    <453, 425, 454>,
    <453, 454, 455>,
    <453, 455, 456>,
    <453, 456, 237>,
    <453, 237, 236>,
    <457, 454, 425>,
    <457, 425, 430>,
    <457, 430, 429>,
    <457, 429, 458>,
    <457, 458, 459>,
    <457, 459, 460>,
    <457, 460, 455>,
    <457, 455, 454>,
    <461, 458, 429>,
    <461, 429, 434>,
    <461, 434, 433>,
    <461, 433, 462>,
    <461, 462, 463>,
    <461, 463, 464>,
    <461, 464, 459>,
    <461, 459, 458>,
    <465, 462, 433>,
    <465, 433, 438>,
    <465, 438, 437>,
    <465, 437, 466>,
    <465, 466, 467>,
    <465, 467, 468>,
    <465, 468, 463>,
    <465, 463, 462>,
    <469, 466, 437>,
    <469, 437, 442>,
    <469, 442, 441>,
    <469, 441, 470>,
    <469, 470, 471>,
    <469, 471, 472>,
    <469, 472, 467>,
    <469, 467, 466>,
    <473, 470, 441>,
    <473, 441, 446>,
    <473, 446, 445>,
    <473, 445, 474>,
    <473, 474, 475>,
    <473, 475, 476>,
    <473, 476, 471>,
    <473, 471, 470>,
    <477, 474, 445>,
    <477, 445, 450>,
    <477, 450, 449>,
    <477, 449, 478>,
    <477, 478, 479>,
    <477, 479, 480>,
    <477, 480, 475>,
    <477, 475, 474>,
    <481, 478, 449>,
    <481, 449, 452>,
    <481, 452, 176>,
    <481, 176, 206>,
    <481, 206, 210>,
    <481, 210, 482>,
    <481, 482, 479>,
    <481, 479, 478>,
    <483, 270, 237>,
    <483, 237, 456>,
    <483, 456, 455>,
    <483, 455, 484>,
    <483, 484, 485>,
    <483, 485, 486>,
    <483, 486, 271>,
    <483, 271, 270>,
    <487, 484, 455>,
    <487, 455, 460>,
    <487, 460, 459>,
    <487, 459, 488>,
    <487, 488, 489>,
    <487, 489, 490>,
    <487, 490, 485>,
    <487, 485, 484>,
    <491, 488, 459>,
    <491, 459, 464>,
    <491, 464, 463>,
    <491, 463, 492>,
    <491, 492, 493>,
    <491, 493, 494>,
    <491, 494, 489>,
    <491, 489, 488>,
    <495, 492, 463>,
    <495, 463, 468>,
    <495, 468, 467>,
    <495, 467, 496>,
    <495, 496, 497>,
    <495, 497, 498>,
    <495, 498, 493>,
    <495, 493, 492>,
    <499, 496, 467>,
    <499, 467, 472>,
    <499, 472, 471>,
    <499, 471, 500>,
    <499, 500, 501>,
    <499, 501, 502>,
    <499, 502, 497>,
    <499, 497, 496>,
    <503, 500, 471>,
    <503, 471, 476>,
    <503, 476, 475>,
    <503, 475, 504>,
    <503, 504, 505>,
    <503, 505, 506>,
    <503, 506, 501>,
    <503, 501, 500>,
    <507, 504, 475>,
    <507, 475, 480>,
    <507, 480, 479>,
    <507, 479, 508>,
    <507, 508, 509>,
    <507, 509, 510>,
    <507, 510, 505>,
    <507, 505, 504>,
    <511, 508, 479>,
    <511, 479, 482>,
    <511, 482, 210>,
    <511, 210, 240>,
    <511, 240, 244>,
    <511, 244, 512>,
    <511, 512, 509>,
    <511, 509, 508>,
    <513, 514, 244>,
    <513, 244, 243>,
    <513, 243, 242>,
    <513, 242, 515>,
    <513, 515, 516>,
    <513, 516, 517>,
    <513, 517, 518>,
    <513, 518, 514>,
    <519, 515, 242>,
    <519, 242, 248>,
    <519, 248, 247>,
    <519, 247, 520>,
    <519, 520, 521>,
    <519, 521, 522>,
    <519, 522, 516>,
    <519, 516, 515>,
    <523, 520, 247>,
    <523, 247, 252>,
    <523, 252, 251>,
    <523, 251, 524>,
    <523, 524, 525>,
    <523, 525, 526>,
    <523, 526, 521>,
    <523, 521, 520>,
    <527, 524, 251>,
    <527, 251, 256>,
    <527, 256, 255>,
    <527, 255, 528>,
    <527, 528, 529>,
    <527, 529, 530>,
    <527, 530, 525>,
    <527, 525, 524>,
    <531, 528, 255>,
    <531, 255, 260>,
    <531, 260, 259>,
    <531, 259, 532>,
    <531, 532, 533>,
    <531, 533, 534>,
    <531, 534, 529>,
    <531, 529, 528>,
    <535, 532, 259>,
    <535, 259, 264>,
    <535, 264, 263>,
    <535, 263, 536>,
    <535, 536, 537>,
    <535, 537, 538>,
    <535, 538, 533>,
    <535, 533, 532>,
    <539, 536, 263>,
    <539, 263, 268>,
    <539, 268, 267>,
    <539, 267, 540>,
    <539, 540, 541>,
    <539, 541, 542>,
    <539, 542, 537>,
    <539, 537, 536>,
    <543, 540, 267>,
    <543, 267, 272>,
    <543, 272, 271>,
    <543, 271, 544>,
    <543, 544, 545>,
    <543, 545, 546>,
    <543, 546, 541>,
    <543, 541, 540>,
    <547, 548, 518>,
    <547, 518, 517>,
    <547, 517, 516>,
    <547, 516, 549>,
    <547, 549, 550>,
    <547, 550, 551>,
    <547, 551, 552>,
    <547, 552, 548>,
    <553, 549, 516>,
    <553, 516, 522>,
    <553, 522, 521>,
    <553, 521, 554>,
    <553, 554, 555>,
    <553, 555, 556>,
    <553, 556, 550>,
    <553, 550, 549>,
    <557, 554, 521>,
    <557, 521, 526>,
    <557, 526, 525>,
    <557, 525, 558>,
    <557, 558, 559>,
    <557, 559, 560>,
    <557, 560, 555>,
    <557, 555, 554>,
    <561, 558, 525>,
    <561, 525, 530>,
    <561, 530, 529>,
    <561, 529, 562>,
    <561, 562, 563>,
    <561, 563, 564>,
    <561, 564, 559>,
    <561, 559, 558>,
    <565, 562, 529>,
    <565, 529, 534>,
    <565, 534, 533>,
    <565, 533, 566>,
    <565, 566, 567>,
    <565, 567, 568>,
    <565, 568, 563>,
    <565, 563, 562>,
    <569, 566, 533>,
    <569, 533, 538>,
    <569, 538, 537>,
    <569, 537, 570>,
    <569, 570, 571>,
    <569, 571, 572>,
    <569, 572, 567>,
    <569, 567, 566>,
    <573, 570, 537>,
    <573, 537, 542>,
    <573, 542, 541>,
    <573, 541, 574>,
    <573, 574, 575>,
    <573, 575, 576>,
    <573, 576, 571>,
    <573, 571, 570>,
    <577, 574, 541>,
    <577, 541, 546>,
    <577, 546, 545>,
    <577, 545, 578>,
    <577, 578, 579>,
    <577, 579, 580>,
    <577, 580, 575>,
    <577, 575, 574>,
    <581, 582, 552>,
    <581, 552, 551>,
    <581, 551, 550>,
    <581, 550, 583>,
    <581, 583, 584>,
    <581, 584, 585>,
    <581, 585, 586>,
    <581, 586, 582>,
    <587, 583, 550>,
    <587, 550, 556>,
    <587, 556, 555>,
    <587, 555, 588>,
    <587, 588, 589>,
    <587, 589, 590>,
    <587, 590, 584>,
    <587, 584, 583>,
    <591, 588, 555>,
    <591, 555, 560>,
    <591, 560, 559>,
    <591, 559, 592>,
    <591, 592, 593>,
    <591, 593, 594>,
    <591, 594, 589>,
    <591, 589, 588>,
    <595, 592, 559>,
    <595, 559, 564>,
    <595, 564, 563>,
    <595, 563, 596>,
    <595, 596, 597>,
    <595, 597, 598>,
    <595, 598, 593>,
    <595, 593, 592>,
    <599, 596, 563>,
    <599, 563, 568>,
    <599, 568, 567>,
    <599, 567, 600>,
    <599, 600, 601>,
    <599, 601, 602>,
    <599, 602, 597>,
    <599, 597, 596>,
    <603, 600, 567>,
    <603, 567, 572>,
    <603, 572, 571>,
    <603, 571, 604>,
    <603, 604, 605>,
    <603, 605, 606>,
    <603, 606, 601>,
    <603, 601, 600>,
    <607, 604, 571>,
    <607, 571, 576>,
    <607, 576, 575>,
    <607, 575, 608>,
    <607, 608, 609>,
    <607, 609, 610>,
    <607, 610, 605>,
    <607, 605, 604>,
    <611, 608, 575>,
    <611, 575, 580>,
    <611, 580, 579>,
    <611, 579, 612>,
    <611, 612, 613>,
    <611, 613, 614>,
    <611, 614, 609>,
    <611, 609, 608>,
    <615, 616, 586>,
    <615, 586, 585>,
    <615, 585, 584>,
    <615, 584, 617>,
    <615, 617, 618>,
    <615, 618, 619>,
    <615, 619, 620>,
    <615, 620, 616>,
    <621, 617, 584>,
    <621, 584, 590>,
    <621, 590, 589>,
    <621, 589, 622>,
    <621, 622, 623>,
    <621, 623, 624>,
    <621, 624, 618>,
    <621, 618, 617>,
    <625, 622, 589>,
    <625, 589, 594>,
    <625, 594, 593>,
    <625, 593, 626>,
    <625, 626, 627>,
    <625, 627, 628>,
    <625, 628, 623>,
    <625, 623, 622>,
    <629, 626, 593>,
    <629, 593, 598>,
    <629, 598, 597>,
    <629, 597, 630>,
    <629, 630, 631>,
    <629, 631, 632>,
    <629, 632, 627>,
    <629, 627, 626>,
    <633, 630, 597>,
    <633, 597, 602>,
    <633, 602, 601>,
    <633, 601, 634>,
    <633, 634, 635>,
    <633, 635, 636>,
    <633, 636, 631>,
    <633, 631, 630>,
    <637, 634, 601>,
    <637, 601, 606>,
    <637, 606, 605>,
    <637, 605, 638>,
    <637, 638, 639>,
    <637, 639, 640>,
    <637, 640, 635>,
    <637, 635, 634>,
    <641, 638, 605>,
    <641, 605, 610>,
    <641, 610, 609>,
    <641, 609, 642>,
    <641, 642, 643>,
    <641, 643, 644>,
    <641, 644, 639>,
    <641, 639, 638>,
    <645, 642, 609>,
    <645, 609, 614>,
    <645, 614, 613>,
    <645, 613, 646>,
    <645, 646, 647>,
    <645, 647, 648>,
    <645, 648, 643>,
    <645, 643, 642>,
    <649, 650, 620>,
    <649, 620, 619>,
    <649, 619, 618>,
    <649, 618, 651>,
    <649, 651, 652>,
    <649, 652, 653>,
    <649, 653, 654>,
    <649, 654, 650>,
    <655, 651, 618>,
    <655, 618, 624>,
    <655, 624, 623>,
    <655, 623, 656>,
    <655, 656, 657>,
    <655, 657, 658>,
    <655, 658, 652>,
    <655, 652, 651>,
    <659, 656, 623>,
    <659, 623, 628>,
    <659, 628, 627>,
    <659, 627, 660>,
    <659, 660, 661>,
    <659, 661, 662>,
    <659, 662, 657>,
    <659, 657, 656>,
    <663, 660, 627>,
    <663, 627, 632>,
    <663, 632, 631>,
    <663, 631, 664>,
    <663, 664, 665>,
    <663, 665, 666>,
    <663, 666, 661>,
    <663, 661, 660>,
    <667, 664, 631>,
    <667, 631, 636>,
    <667, 636, 635>,
    <667, 635, 668>,
    <667, 668, 669>,
    <667, 669, 670>,
    <667, 670, 665>,
    <667, 665, 664>,
    <671, 668, 635>,
    <671, 635, 640>,
    <671, 640, 639>,
    <671, 639, 672>,
    <671, 672, 673>,
    <671, 673, 674>,
    <671, 674, 669>,
    <671, 669, 668>,
    <675, 672, 639>,
    <675, 639, 644>,
    <675, 644, 643>,
    <675, 643, 676>,
    <675, 676, 677>,
    <675, 677, 678>,
    <675, 678, 673>,
    <675, 673, 672>,
    <679, 676, 643>,
    <679, 643, 648>,
    <679, 648, 647>,
    <679, 647, 680>,
    <679, 680, 681>,
    <679, 681, 682>,
    <679, 682, 677>,
    <679, 677, 676>,
    <683, 684, 654>,
    <683, 654, 653>,
    <683, 653, 652>,
    <683, 652, 685>,
    <683, 685, 686>,
    <683, 686, 687>,
    <683, 687, 688>,
    <683, 688, 684>,
    <689, 685, 652>,
    <689, 652, 658>,
    <689, 658, 657>,
    <689, 657, 690>,
    <689, 690, 691>,
    <689, 691, 692>,
    <689, 692, 686>,
    <689, 686, 685>,
    <693, 690, 657>,
    <693, 657, 662>,
    <693, 662, 661>,
    <693, 661, 694>,
    <693, 694, 695>,
    <693, 695, 696>,
    <693, 696, 691>,
    <693, 691, 690>,
    <697, 694, 661>,
    <697, 661, 666>,
    <697, 666, 665>,
    <697, 665, 698>,
    <697, 698, 699>,
    <697, 699, 700>,
    <697, 700, 695>,
    <697, 695, 694>,
    <701, 698, 665>,
    <701, 665, 670>,
    <701, 670, 669>,
    <701, 669, 702>,
    <701, 702, 703>,
    <701, 703, 704>,
    <701, 704, 699>,
    <701, 699, 698>,
    <705, 702, 669>,
    <705, 669, 674>,
    <705, 674, 673>,
    <705, 673, 706>,
    <705, 706, 707>,
    <705, 707, 708>,
    <705, 708, 703>,
    <705, 703, 702>,
    <709, 706, 673>,
    <709, 673, 678>,
    <709, 678, 677>,
    <709, 677, 710>,
    <709, 710, 711>,
    <709, 711, 712>,
    <709, 712, 707>,
    <709, 707, 706>,
    <713, 710, 677>,
    <713, 677, 682>,
    <713, 682, 681>,
    <713, 681, 714>,
    <713, 714, 715>,
    <713, 715, 716>,
    <713, 716, 711>,
    <713, 711, 710>,
    <717, 718, 688>,
    <717, 688, 687>,
    <717, 687, 686>,
    <717, 686, 719>,
    <717, 719, 720>,
    <717, 720, 721>,
    <717, 721, 722>,
    <717, 722, 718>,
    <723, 719, 686>,
    <723, 686, 692>,
    <723, 692, 691>,
    <723, 691, 724>,
    <723, 724, 725>,
    <723, 725, 726>,
    <723, 726, 720>,
    <723, 720, 719>,
    <727, 724, 691>,
    <727, 691, 696>,
    <727, 696, 695>,
    <727, 695, 728>,
    <727, 728, 729>,
    <727, 729, 730>,
    <727, 730, 725>,
    <727, 725, 724>,
    <731, 728, 695>,
    <731, 695, 700>,
    <731, 700, 699>,
    <731, 699, 732>,
    <731, 732, 733>,
    <731, 733, 734>,
    <731, 734, 729>,
    <731, 729, 728>,
    <735, 732, 699>,
    <735, 699, 704>,
    <735, 704, 703>,
    <735, 703, 736>,
    <735, 736, 737>,
    <735, 737, 738>,
    <735, 738, 733>,
    <735, 733, 732>,
    <739, 736, 703>,
    <739, 703, 708>,
    <739, 708, 707>,
    <739, 707, 740>,
    <739, 740, 741>,
    <739, 741, 742>,
    <739, 742, 737>,
    <739, 737, 736>,
    <743, 740, 707>,
    <743, 707, 712>,
    <743, 712, 711>,
    <743, 711, 744>,
    <743, 744, 745>,
    <743, 745, 746>,
    <743, 746, 741>,
    <743, 741, 740>,
    <747, 744, 711>,
    <747, 711, 716>,
    <747, 716, 715>,
    <747, 715, 748>,
    <747, 748, 749>,
    <747, 749, 750>,
    <747, 750, 745>,
    <747, 745, 744>,
    <751, 752, 722>,
    <751, 722, 721>,
    <751, 721, 720>,
    <751, 720, 753>,
    <751, 753, 754>,
    <751, 754, 755>,
    <751, 755, 756>,
    <751, 756, 752>,
    <757, 753, 720>,
    <757, 720, 726>,
    <757, 726, 725>,
    <757, 725, 758>,
    <757, 758, 759>,
    <757, 759, 760>,
    <757, 760, 754>,
    <757, 754, 753>,
    <761, 758, 725>,
    <761, 725, 730>,
    <761, 730, 729>,
    <761, 729, 762>,
    <761, 762, 763>,
    <761, 763, 764>,
    <761, 764, 759>,
    <761, 759, 758>,
    <765, 762, 729>,
    <765, 729, 734>,
    <765, 734, 733>,
    <765, 733, 766>,
    <765, 766, 767>,
    <765, 767, 768>,
    <765, 768, 763>,
    <765, 763, 762>,
    <769, 766, 733>,
    <769, 733, 738>,
    <769, 738, 737>,
    <769, 737, 770>,
    <769, 770, 771>,
    <769, 771, 772>,
    <769, 772, 767>,
    <769, 767, 766>,
    <773, 770, 737>,
    <773, 737, 742>,
    <773, 742, 741>,
    <773, 741, 774>,
    <773, 774, 775>,
    <773, 775, 776>,
    <773, 776, 771>,
    <773, 771, 770>,
    <777, 774, 741>,
    <777, 741, 746>,
    <777, 746, 745>,
    <777, 745, 778>,
    <777, 778, 779>,
    <777, 779, 780>,
    <777, 780, 775>,
    <777, 775, 774>,
    <781, 778, 745>,
    <781, 745, 750>,
    <781, 750, 749>,
    <781, 749, 782>,
    <781, 782, 783>,
    <781, 783, 784>,
    <781, 784, 779>,
    <781, 779, 778>,
    <785, 544, 271>,
    <785, 271, 486>,
    <785, 486, 485>,
    <785, 485, 786>,
    <785, 786, 787>,
    <785, 787, 788>,
    <785, 788, 545>,
    <785, 545, 544>,
    <789, 786, 485>,
    <789, 485, 490>,
    <789, 490, 489>,
    <789, 489, 790>,
    <789, 790, 791>,
    <789, 791, 792>,
    <789, 792, 787>,
    <789, 787, 786>,
    <793, 790, 489>,
    <793, 489, 494>,
    <793, 494, 493>,
    <793, 493, 794>,
    <793, 794, 795>,
    <793, 795, 796>,
    <793, 796, 791>,
    <793, 791, 790>,
    <797, 794, 493>,
    <797, 493, 498>,
    <797, 498, 497>,
    <797, 497, 798>,
    <797, 798, 799>,
    <797, 799, 800>,
    <797, 800, 795>,
    <797, 795, 794>,
    <801, 798, 497>,
    <801, 497, 502>,
    <801, 502, 501>,
    <801, 501, 802>,
    <801, 802, 803>,
    <801, 803, 804>,
    <801, 804, 799>,
    <801, 799, 798>,
    <805, 802, 501>,
    <805, 501, 506>,
    <805, 506, 505>,
    <805, 505, 806>,
    <805, 806, 807>,
    <805, 807, 808>,
    <805, 808, 803>,
    <805, 803, 802>,
    <809, 806, 505>,
    <809, 505, 510>,
    <809, 510, 509>,
    <809, 509, 810>,
    <809, 810, 811>,
    <809, 811, 812>,
    <809, 812, 807>,
    <809, 807, 806>,
    <813, 810, 509>,
    <813, 509, 512>,
    <813, 512, 244>,
    <813, 244, 514>,
    <813, 514, 518>,
    <813, 518, 814>,
    <813, 814, 811>,
    <813, 811, 810>,
    <815, 578, 545>,
    <815, 545, 788>,
    <815, 788, 787>,
    <815, 787, 816>,
    <815, 816, 817>,
    <815, 817, 818>,
    <815, 818, 579>,
    <815, 579, 578>,
    <819, 816, 787>,
    <819, 787, 792>,
    <819, 792, 791>,
    <819, 791, 820>,
    <819, 820, 821>,
    <819, 821, 822>,
    <819, 822, 817>,
    <819, 817, 816>,
    <823, 820, 791>,
    <823, 791, 796>,
    <823, 796, 795>,
    <823, 795, 824>,
    <823, 824, 825>,
    <823, 825, 826>,
    <823, 826, 821>,
    <823, 821, 820>,
    <827, 824, 795>,
    <827, 795, 800>,
    <827, 800, 799>,
    <827, 799, 828>,
    <827, 828, 829>,
    <827, 829, 830>,
    <827, 830, 825>,
    <827, 825, 824>,
    <831, 828, 799>,
    <831, 799, 804>,
    <831, 804, 803>,
    <831, 803, 832>,
    <831, 832, 833>,
    <831, 833, 834>,
    <831, 834, 829>,
    <831, 829, 828>,
    <835, 832, 803>,
    <835, 803, 808>,
    <835, 808, 807>,
    <835, 807, 836>,
    <835, 836, 837>,
    <835, 837, 838>,
    <835, 838, 833>,
    <835, 833, 832>,
    <839, 836, 807>,
    <839, 807, 812>,
    <839, 812, 811>,
    <839, 811, 840>,
    <839, 840, 841>,
    <839, 841, 842>,
    <839, 842, 837>,
    <839, 837, 836>,
    <843, 840, 811>,
    <843, 811, 814>,
    <843, 814, 518>,
    <843, 518, 548>,
    <843, 548, 552>,
    <843, 552, 844>,
    <843, 844, 841>,
    <843, 841, 840>,
    <845, 612, 579>,
    <845, 579, 818>,
    <845, 818, 817>,
    <845, 817, 846>,
    <845, 846, 847>,
    <845, 847, 848>,
    <845, 848, 613>,
    <845, 613, 612>,
    <849, 846, 817>,
    <849, 817, 822>,
    <849, 822, 821>,
    <849, 821, 850>,
    <849, 850, 851>,
    <849, 851, 852>,
    <849, 852, 847>,
    <849, 847, 846>,
    <853, 850, 821>,
    <853, 821, 826>,
    <853, 826, 825>,
    <853, 825, 854>,
    <853, 854, 855>,
    <853, 855, 856>,
    <853, 856, 851>,
    <853, 851, 850>,
    <857, 854, 825>,
    <857, 825, 830>,
    <857, 830, 829>,
    <857, 829, 858>,
    <857, 858, 859>,
    <857, 859, 860>,
    <857, 860, 855>,
    <857, 855, 854>,
    <861, 858, 829>,
    <861, 829, 834>,
    <861, 834, 833>,
    <861, 833, 862>,
    <861, 862, 863>,
    <861, 863, 864>,
    <861, 864, 859>,
    <861, 859, 858>,
    <865, 862, 833>,
    <865, 833, 838>,
    <865, 838, 837>,
    <865, 837, 866>,
    <865, 866, 867>,
    <865, 867, 868>,
    <865, 868, 863>,
    <865, 863, 862>,
    <869, 866, 837>,
    <869, 837, 842>,
    <869, 842, 841>,
    <869, 841, 870>,
    <869, 870, 871>,
    <869, 871, 872>,
    <869, 872, 867>,
    <869, 867, 866>,
    <873, 870, 841>,
    <873, 841, 844>,
    <873, 844, 552>,
    <873, 552, 582>,
    <873, 582, 586>,
    <873, 586, 874>,
    <873, 874, 871>,
    <873, 871, 870>,
    <875, 646, 613>,
    <875, 613, 848>,
    <875, 848, 847>,
    <875, 847, 876>,
    <875, 876, 877>,
    <875, 877, 878>,
    <875, 878, 647>,
    <875, 647, 646>,
    <879, 876, 847>,
    <879, 847, 852>,
    <879, 852, 851>,
    <879, 851, 880>,
    <879, 880, 881>,
    <879, 881, 882>,
    <879, 882, 877>,
    <879, 877, 876>,
    <883, 880, 851>,
    <883, 851, 856>,
    <883, 856, 855>,
    <883, 855, 884>,
    <883, 884, 885>,
    <883, 885, 886>,
    <883, 886, 881>,
    <883, 881, 880>,
    <887, 884, 855>,
    <887, 855, 860>,
    <887, 860, 859>,
    <887, 859, 888>,
    <887, 888, 889>,
    <887, 889, 890>,
    <887, 890, 885>,
    <887, 885, 884>,
    <891, 888, 859>,
    <891, 859, 864>,
    <891, 864, 863>,
    <891, 863, 892>,
    <891, 892, 893>,
    <891, 893, 894>,
    <891, 894, 889>,
    <891, 889, 888>,
    <895, 892, 863>,
    <895, 863, 868>,
    <895, 868, 867>,
    <895, 867, 896>,
    <895, 896, 897>,
    <895, 897, 898>,
    <895, 898, 893>,
    <895, 893, 892>,
    <899, 896, 867>,
    <899, 867, 872>,
    <899, 872, 871>,
    <899, 871, 900>,
    <899, 900, 901>,
    <899, 901, 902>,
    <899, 902, 897>,
    <899, 897, 896>,
    <903, 900, 871>,
    <903, 871, 874>,
    <903, 874, 586>,
    <903, 586, 616>,
    <903, 616, 620>,
    <903, 620, 904>,
    <903, 904, 901>,
    <903, 901, 900>,
    <905, 680, 647>,
    <905, 647, 878>,
    <905, 878, 877>,
    <905, 877, 906>,
    <905, 906, 907>,
    <905, 907, 908>,
    <905, 908, 681>,
    <905, 681, 680>,
    <909, 906, 877>,
    <909, 877, 882>,
    <909, 882, 881>,
    <909, 881, 910>,
    <909, 910, 911>,
    <909, 911, 912>,
    <909, 912, 907>,
    <909, 907, 906>,
    <913, 910, 881>,
    <913, 881, 886>,
    <913, 886, 885>,
    <913, 885, 914>,
    <913, 914, 915>,
    <913, 915, 916>,
    <913, 916, 911>,
    <913, 911, 910>,
    <917, 914, 885>,
    <917, 885, 890>,
    <917, 890, 889>,
    <917, 889, 918>,
    <917, 918, 919>,
    <917, 919, 920>,
    <917, 920, 915>,
    <917, 915, 914>,
    <921, 918, 889>,
    <921, 889, 894>,
    <921, 894, 893>,
    <921, 893, 922>,
    <921, 922, 923>,
    <921, 923, 924>,
    <921, 924, 919>,
    <921, 919, 918>,
    <925, 922, 893>,
    <925, 893, 898>,
    <925, 898, 897>,
    <925, 897, 926>,
    <925, 926, 927>,
    <925, 927, 928>,
    <925, 928, 923>,
    <925, 923, 922>,
    <929, 926, 897>,
    <929, 897, 902>,
    <929, 902, 901>,
    <929, 901, 930>,
    <929, 930, 931>,
    <929, 931, 932>,
    <929, 932, 927>,
    <929, 927, 926>,
    <933, 930, 901>,
    <933, 901, 904>,
    <933, 904, 620>,
    <933, 620, 650>,
    <933, 650, 654>,
    <933, 654, 934>,
    <933, 934, 931>,
    <933, 931, 930>,
    <935, 714, 681>,
    <935, 681, 908>,
    <935, 908, 907>,
    <935, 907, 936>,
    <935, 936, 937>,
    <935, 937, 938>,
    <935, 938, 715>,
    <935, 715, 714>,
    <939, 936, 907>,
    <939, 907, 912>,
    <939, 912, 911>,
    <939, 911, 940>,
    <939, 940, 941>,
    <939, 941, 942>,
    <939, 942, 937>,
    <939, 937, 936>,
    <943, 940, 911>,
    <943, 911, 916>,
    <943, 916, 915>,
    <943, 915, 944>,
    <943, 944, 945>,
    <943, 945, 946>,
    <943, 946, 941>,
    <943, 941, 940>,
    <947, 944, 915>,
    <947, 915, 920>,
    <947, 920, 919>,
    <947, 919, 948>,
    <947, 948, 949>,
    <947, 949, 950>,
    <947, 950, 945>,
    <947, 945, 944>,
    <951, 948, 919>,
    <951, 919, 924>,
    <951, 924, 923>,
    <951, 923, 952>,
    <951, 952, 953>,
    <951, 953, 954>,
    <951, 954, 949>,
    <951, 949, 948>,
    <955, 952, 923>,
    <955, 923, 928>,
    <955, 928, 927>,
    <955, 927, 956>,
    <955, 956, 957>,
    <955, 957, 958>,
    <955, 958, 953>,
    <955, 953, 952>,
    <959, 956, 927>,
    <959, 927, 932>,
    <959, 932, 931>,
    <959, 931, 960>,
    <959, 960, 961>,
    <959, 961, 962>,
    <959, 962, 957>,
    <959, 957, 956>,
    <963, 960, 931>,
    <963, 931, 934>,
    <963, 934, 654>,
    <963, 654, 684>,
    <963, 684, 688>,
    <963, 688, 964>,
    <963, 964, 961>,
    <963, 961, 960>,
    <965, 748, 715>,
    <965, 715, 938>,
    <965, 938, 937>,
    <965, 937, 966>,
    <965, 966, 967>,
    <965, 967, 968>,
    <965, 968, 749>,
    <965, 749, 748>,
    <969, 966, 937>,
    <969, 937, 942>,
    <969, 942, 941>,
    <969, 941, 970>,
    <969, 970, 971>,
    <969, 971, 972>,
    <969, 972, 967>,
    <969, 967, 966>,
    <973, 970, 941>,
    <973, 941, 946>,
    <973, 946, 945>,
    <973, 945, 974>,
    <973, 974, 975>,
    <973, 975, 976>,
    <973, 976, 971>,
    <973, 971, 970>,
    <977, 974, 945>,
    <977, 945, 950>,
    <977, 950, 949>,
    <977, 949, 978>,
    <977, 978, 979>,
    <977, 979, 980>,
    <977, 980, 975>,
    <977, 975, 974>,
    <981, 978, 949>,
    <981, 949, 954>,
    <981, 954, 953>,
    <981, 953, 982>,
    <981, 982, 983>,
    <981, 983, 984>,
    <981, 984, 979>,
    <981, 979, 978>,
    <985, 982, 953>,
    <985, 953, 958>,
    <985, 958, 957>,
    <985, 957, 986>,
    <985, 986, 987>,
    <985, 987, 988>,
    <985, 988, 983>,
    <985, 983, 982>,
    <989, 986, 957>,
    <989, 957, 962>,
    <989, 962, 961>,
    <989, 961, 990>,
    <989, 990, 991>,
    <989, 991, 992>,
    <989, 992, 987>,
    <989, 987, 986>,
    <993, 990, 961>,
    <993, 961, 964>,
    <993, 964, 688>,
    <993, 688, 718>,
    <993, 718, 722>,
    <993, 722, 994>,
    <993, 994, 991>,
    <993, 991, 990>,
    <995, 782, 749>,
    <995, 749, 968>,
    <995, 968, 967>,
    <995, 967, 996>,
    <995, 996, 997>,
    <995, 997, 998>,
    <995, 998, 783>,
    <995, 783, 782>,
    <999, 996, 967>,
    <999, 967, 972>,
    <999, 972, 971>,
    <999, 971, 1000>,
    <999, 1000, 1001>,
    <999, 1001, 1002>,
    <999, 1002, 997>,
    <999, 997, 996>,
    <1003, 1000, 971>,
    <1003, 971, 976>,
    <1003, 976, 975>,
    <1003, 975, 1004>,
    <1003, 1004, 1005>,
    <1003, 1005, 1006>,
    <1003, 1006, 1001>,
    <1003, 1001, 1000>,
    <1007, 1004, 975>,
    <1007, 975, 980>,
    <1007, 980, 979>,
    <1007, 979, 1008>,
    <1007, 1008, 1009>,
    <1007, 1009, 1010>,
    <1007, 1010, 1005>,
    <1007, 1005, 1004>,
    <1011, 1008, 979>,
    <1011, 979, 984>,
    <1011, 984, 983>,
    <1011, 983, 1012>,
    <1011, 1012, 1013>,
    <1011, 1013, 1014>,
    <1011, 1014, 1009>,
    <1011, 1009, 1008>,
    <1015, 1012, 983>,
    <1015, 983, 988>,
    <1015, 988, 987>,
    <1015, 987, 1016>,
    <1015, 1016, 1017>,
    <1015, 1017, 1018>,
    <1015, 1018, 1013>,
    <1015, 1013, 1012>,
    <1019, 1016, 987>,
    <1019, 987, 992>,
    <1019, 992, 991>,
    <1019, 991, 1020>,
    <1019, 1020, 1021>,
    <1019, 1021, 1022>,
    <1019, 1022, 1017>,
    <1019, 1017, 1016>,
    <1023, 1020, 991>,
    <1023, 991, 994>,
    <1023, 994, 722>,
    <1023, 722, 752>,
    <1023, 752, 756>,
    <1023, 756, 1024>,
    <1023, 1024, 1021>,
    <1023, 1021, 1020>,
    <1025, 1026, 756>,
    <1025, 756, 755>,
    <1025, 755, 754>,
    <1025, 754, 1027>,
    <1025, 1027, 1028>,
    <1025, 1028, 1029>,
    <1025, 1029, 1030>,
    <1025, 1030, 1026>,
    <1031, 1027, 754>,
    <1031, 754, 760>,
    <1031, 760, 759>,
    <1031, 759, 1032>,
    <1031, 1032, 1033>,
    <1031, 1033, 1034>,
    <1031, 1034, 1028>,
    <1031, 1028, 1027>,
    <1035, 1032, 759>,
    <1035, 759, 764>,
    <1035, 764, 763>,
    <1035, 763, 1036>,
    <1035, 1036, 1037>,
    <1035, 1037, 1038>,
    <1035, 1038, 1033>,
    <1035, 1033, 1032>,
    <1039, 1036, 763>,
    <1039, 763, 768>,
    <1039, 768, 767>,
    <1039, 767, 1040>,
    <1039, 1040, 1041>,
    <1039, 1041, 1042>,
    <1039, 1042, 1037>,
    <1039, 1037, 1036>,
    <1043, 1040, 767>,
    <1043, 767, 772>,
    <1043, 772, 771>,
    <1043, 771, 1044>,
    <1043, 1044, 1045>,
    <1043, 1045, 1046>,
    <1043, 1046, 1041>,
    <1043, 1041, 1040>,
    <1047, 1044, 771>,
    <1047, 771, 776>,
    <1047, 776, 775>,
    <1047, 775, 1048>,
    <1047, 1048, 1049>,
    <1047, 1049, 1050>,
    <1047, 1050, 1045>,
    <1047, 1045, 1044>,
    <1051, 1048, 775>,
    <1051, 775, 780>,
    <1051, 780, 779>,
    <1051, 779, 1052>,
    <1051, 1052, 1053>,
    <1051, 1053, 1054>,
    <1051, 1054, 1049>,
    <1051, 1049, 1048>,
    <1055, 1052, 779>,
    <1055, 779, 784>,
    <1055, 784, 783>,
    <1055, 783, 1056>,
    <1055, 1056, 1057>,
    <1055, 1057, 1058>,
    <1055, 1058, 1053>,
    <1055, 1053, 1052>,
    <1059, 1060, 1030>,
    <1059, 1030, 1029>,
    <1059, 1029, 1028>,
    <1059, 1028, 1061>,
    <1059, 1061, 1062>,
    <1059, 1062, 1063>,
    <1059, 1063, 1064>,
    <1059, 1064, 1060>,
    <1065, 1061, 1028>,
    <1065, 1028, 1034>,
    <1065, 1034, 1033>,
    <1065, 1033, 1066>,
    <1065, 1066, 1067>,
    <1065, 1067, 1068>,
    <1065, 1068, 1062>,
    <1065, 1062, 1061>,
    <1069, 1066, 1033>,
    <1069, 1033, 1038>,
    <1069, 1038, 1037>,
    <1069, 1037, 1070>,
    <1069, 1070, 1071>,
    <1069, 1071, 1072>,
    <1069, 1072, 1067>,
    <1069, 1067, 1066>,
    <1073, 1070, 1037>,
    <1073, 1037, 1042>,
    <1073, 1042, 1041>,
    <1073, 1041, 1074>,
    <1073, 1074, 1075>,
    <1073, 1075, 1076>,
    <1073, 1076, 1071>,
    <1073, 1071, 1070>,
    <1077, 1074, 1041>,
    <1077, 1041, 1046>,
    <1077, 1046, 1045>,
    <1077, 1045, 1078>,
    <1077, 1078, 1079>,
    <1077, 1079, 1080>,
    <1077, 1080, 1075>,
    <1077, 1075, 1074>,
    <1081, 1078, 1045>,
    <1081, 1045, 1050>,
    <1081, 1050, 1049>,
    <1081, 1049, 1082>,
    <1081, 1082, 1083>,
    <1081, 1083, 1084>,
    <1081, 1084, 1079>,
    <1081, 1079, 1078>,
    <1085, 1082, 1049>,
    <1085, 1049, 1054>,
    <1085, 1054, 1053>,
    <1085, 1053, 1086>,
    <1085, 1086, 1087>,
    <1085, 1087, 1088>,
    <1085, 1088, 1083>,
    <1085, 1083, 1082>,
    <1089, 1086, 1053>,
    <1089, 1053, 1058>,
    <1089, 1058, 1057>,
    <1089, 1057, 1090>,
    <1089, 1090, 1091>,
    <1089, 1091, 1092>,
    <1089, 1092, 1087>,
    <1089, 1087, 1086>,
    <1093, 1094, 1064>,
    <1093, 1064, 1063>,
    <1093, 1063, 1062>,
    <1093, 1062, 1095>,
    <1093, 1095, 1096>,
    <1093, 1096, 1097>,
    <1093, 1097, 1098>,
    <1093, 1098, 1094>,
    <1099, 1095, 1062>,
    <1099, 1062, 1068>,
    <1099, 1068, 1067>,
    <1099, 1067, 1100>,
    <1099, 1100, 1101>,
    <1099, 1101, 1102>,
    <1099, 1102, 1096>,
    <1099, 1096, 1095>,
    <1103, 1100, 1067>,
    <1103, 1067, 1072>,
    <1103, 1072, 1071>,
    <1103, 1071, 1104>,
    <1103, 1104, 1105>,
    <1103, 1105, 1106>,
    <1103, 1106, 1101>,
    <1103, 1101, 1100>,
    <1107, 1104, 1071>,
    <1107, 1071, 1076>,
    <1107, 1076, 1075>,
    <1107, 1075, 1108>,
    <1107, 1108, 1109>,
    <1107, 1109, 1110>,
    <1107, 1110, 1105>,
    <1107, 1105, 1104>,
    <1111, 1108, 1075>,
    <1111, 1075, 1080>,
    <1111, 1080, 1079>,
    <1111, 1079, 1112>,
    <1111, 1112, 1113>,
    <1111, 1113, 1114>,
    <1111, 1114, 1109>,
    <1111, 1109, 1108>,
    <1115, 1112, 1079>,
    <1115, 1079, 1084>,
    <1115, 1084, 1083>,
    <1115, 1083, 1116>,
    <1115, 1116, 1117>,
    <1115, 1117, 1118>,
    <1115, 1118, 1113>,
    <1115, 1113, 1112>,
    <1119, 1116, 1083>,
    <1119, 1083, 1088>,
    <1119, 1088, 1087>,
    <1119, 1087, 1120>,
    <1119, 1120, 1121>,
    <1119, 1121, 1122>,
    <1119, 1122, 1117>,
    <1119, 1117, 1116>,
    <1123, 1120, 1087>,
    <1123, 1087, 1092>,
    <1123, 1092, 1091>,
    <1123, 1091, 1124>,
    <1123, 1124, 1125>,
    <1123, 1125, 1126>,
    <1123, 1126, 1121>,
    <1123, 1121, 1120>,
    <1127, 1128, 1098>,
    <1127, 1098, 1097>,
    <1127, 1097, 1096>,
    <1127, 1096, 1129>,
    <1127, 1129, 1130>,
    <1127, 1130, 1131>,
    <1127, 1131, 1132>,
    <1127, 1132, 1128>,
    <1133, 1129, 1096>,
    <1133, 1096, 1102>,
    <1133, 1102, 1101>,
    <1133, 1101, 1134>,
    <1133, 1134, 1135>,
    <1133, 1135, 1136>,
    <1133, 1136, 1130>,
    <1133, 1130, 1129>,
    <1137, 1134, 1101>,
    <1137, 1101, 1106>,
    <1137, 1106, 1105>,
    <1137, 1105, 1138>,
    <1137, 1138, 1139>,
    <1137, 1139, 1140>,
    <1137, 1140, 1135>,
    <1137, 1135, 1134>,
    <1141, 1138, 1105>,
    <1141, 1105, 1110>,
    <1141, 1110, 1109>,
    <1141, 1109, 1142>,
    <1141, 1142, 1143>,
    <1141, 1143, 1144>,
    <1141, 1144, 1139>,
    <1141, 1139, 1138>,
    <1145, 1142, 1109>,
    <1145, 1109, 1114>,
    <1145, 1114, 1113>,
    <1145, 1113, 1146>,
    <1145, 1146, 1147>,
    <1145, 1147, 1148>,
    <1145, 1148, 1143>,
    <1145, 1143, 1142>,
    <1149, 1146, 1113>,
    <1149, 1113, 1118>,
    <1149, 1118, 1117>,
    <1149, 1117, 1150>,
    <1149, 1150, 1151>,
    <1149, 1151, 1152>,
    <1149, 1152, 1147>,
    <1149, 1147, 1146>,
    <1153, 1150, 1117>,
    <1153, 1117, 1122>,
    <1153, 1122, 1121>,
    <1153, 1121, 1154>,
    <1153, 1154, 1155>,
    <1153, 1155, 1156>,
    <1153, 1156, 1151>,
    <1153, 1151, 1150>,
    <1157, 1154, 1121>,
    <1157, 1121, 1126>,
    <1157, 1126, 1125>,
    <1157, 1125, 1158>,
    <1157, 1158, 1159>,
    <1157, 1159, 1160>,
    <1157, 1160, 1155>,
    <1157, 1155, 1154>,
    <1161, 1162, 1132>,
    <1161, 1132, 1131>,
    <1161, 1131, 1130>,
    <1161, 1130, 1163>,
    <1161, 1163, 1164>,
    <1161, 1164, 1165>,
    <1161, 1165, 1166>,
    <1161, 1166, 1162>,
    <1167, 1163, 1130>,
    <1167, 1130, 1136>,
    <1167, 1136, 1135>,
    <1167, 1135, 1168>,
    <1167, 1168, 1169>,
    <1167, 1169, 1170>,
    <1167, 1170, 1164>,
    <1167, 1164, 1163>,
    <1171, 1168, 1135>,
    <1171, 1135, 1140>,
    <1171, 1140, 1139>,
    <1171, 1139, 1172>,
    <1171, 1172, 1173>,
    <1171, 1173, 1174>,
    <1171, 1174, 1169>,
    <1171, 1169, 1168>,
    <1175, 1172, 1139>,
    <1175, 1139, 1144>,
    <1175, 1144, 1143>,
    <1175, 1143, 1176>,
    <1175, 1176, 1177>,
    <1175, 1177, 1178>,
    <1175, 1178, 1173>,
    <1175, 1173, 1172>,
    <1179, 1176, 1143>,
    <1179, 1143, 1148>,
    <1179, 1148, 1147>,
    <1179, 1147, 1180>,
    <1179, 1180, 1181>,
    <1179, 1181, 1182>,
    <1179, 1182, 1177>,
    <1179, 1177, 1176>,
    <1183, 1180, 1147>,
    <1183, 1147, 1152>,
    <1183, 1152, 1151>,
    <1183, 1151, 1184>,
    <1183, 1184, 1185>,
    <1183, 1185, 1186>,
    <1183, 1186, 1181>,
    <1183, 1181, 1180>,
    <1187, 1184, 1151>,
    <1187, 1151, 1156>,
    <1187, 1156, 1155>,
    <1187, 1155, 1188>,
    <1187, 1188, 1189>,
    <1187, 1189, 1190>,
    <1187, 1190, 1185>,
    <1187, 1185, 1184>,
    <1191, 1188, 1155>,
    <1191, 1155, 1160>,
    <1191, 1160, 1159>,
    <1191, 1159, 1192>,
    <1191, 1192, 1193>,
    <1191, 1193, 1194>,
    <1191, 1194, 1189>,
    <1191, 1189, 1188>,
    <1195, 1196, 1166>,
    <1195, 1166, 1165>,
    <1195, 1165, 1164>,
    <1195, 1164, 1197>,
    <1195, 1197, 1198>,
    <1195, 1198, 1199>,
    <1195, 1199, 1200>,
    <1195, 1200, 1196>,
    <1201, 1197, 1164>,
    <1201, 1164, 1170>,
    <1201, 1170, 1169>,
    <1201, 1169, 1202>,
    <1201, 1202, 1203>,
    <1201, 1203, 1204>,
    <1201, 1204, 1198>,
    <1201, 1198, 1197>,
    <1205, 1202, 1169>,
    <1205, 1169, 1174>,
    <1205, 1174, 1173>,
    <1205, 1173, 1206>,
    <1205, 1206, 1207>,
    <1205, 1207, 1208>,
    <1205, 1208, 1203>,
    <1205, 1203, 1202>,
    <1209, 1206, 1173>,
    <1209, 1173, 1178>,
    <1209, 1178, 1177>,
    <1209, 1177, 1210>,
    <1209, 1210, 1211>,
    <1209, 1211, 1212>,
    <1209, 1212, 1207>,
    <1209, 1207, 1206>,
    <1213, 1210, 1177>,
    <1213, 1177, 1182>,
    <1213, 1182, 1181>,
    <1213, 1181, 1214>,
    <1213, 1214, 1215>,
    <1213, 1215, 1216>,
    <1213, 1216, 1211>,
    <1213, 1211, 1210>,
    <1217, 1214, 1181>,
    <1217, 1181, 1186>,
    <1217, 1186, 1185>,
    <1217, 1185, 1218>,
    <1217, 1218, 1219>,
    <1217, 1219, 1220>,
    <1217, 1220, 1215>,
    <1217, 1215, 1214>,
    <1221, 1218, 1185>,
    <1221, 1185, 1190>,
    <1221, 1190, 1189>,
    <1221, 1189, 1222>,
    <1221, 1222, 1223>,
    <1221, 1223, 1224>,
    <1221, 1224, 1219>,
    <1221, 1219, 1218>,
    <1225, 1222, 1189>,
    <1225, 1189, 1194>,
    <1225, 1194, 1193>,
    <1225, 1193, 1226>,
    <1225, 1226, 1227>,
    <1225, 1227, 1228>,
    <1225, 1228, 1223>,
    <1225, 1223, 1222>,
    <1229, 1230, 1231>,
    <1229, 1231, 1199>,
    <1229, 1199, 1198>,
    <1229, 1198, 1232>,
    <1229, 1232, 1233>,
    <1229, 1233, 1234>,
    <1229, 1234, 1235>,
    <1229, 1235, 1236>,
    <1237, 1232, 1198>,
    <1237, 1198, 1204>,
    <1237, 1204, 1203>,
    <1237, 1203, 1238>,
    <1237, 1238, 1239>,
    <1237, 1239, 1240>,
    <1237, 1240, 1233>,
    <1237, 1233, 1232>,
    <1241, 1238, 1203>,
    <1241, 1203, 1208>,
    <1241, 1208, 1207>,
    <1241, 1207, 1242>,
    <1241, 1242, 1243>,
    <1241, 1243, 1244>,
    <1241, 1244, 1239>,
    <1241, 1239, 1238>,
    <1245, 1242, 1207>,
    <1245, 1207, 1212>,
    <1245, 1212, 1211>,
    <1245, 1211, 1246>,
    <1245, 1246, 1247>,
    <1245, 1247, 1248>,
    <1245, 1248, 1243>,
    <1245, 1243, 1242>,
    <1249, 1246, 1211>,
    <1249, 1211, 1216>,
    <1249, 1216, 1215>,
    <1249, 1215, 1250>,
    <1249, 1250, 1251>,
    <1249, 1251, 1252>,
    <1249, 1252, 1247>,
    <1249, 1247, 1246>,
    <1253, 1250, 1215>,
    <1253, 1215, 1220>,
    <1253, 1220, 1219>,
    <1253, 1219, 1254>,
    <1253, 1254, 1255>,
    <1253, 1255, 1256>,
    <1253, 1256, 1251>,
    <1253, 1251, 1250>,
    <1257, 1254, 1219>,
    <1257, 1219, 1224>,
    <1257, 1224, 1223>,
    <1257, 1223, 1258>,
    <1257, 1258, 1259>,
    <1257, 1259, 1260>,
    <1257, 1260, 1255>,
    <1257, 1255, 1254>,
    <1261, 1258, 1223>,
    <1261, 1223, 1228>,
    <1261, 1228, 1262>,
    <1261, 1262, 1263>,
    <1261, 1264, 1265>,
    <1261, 1265, 1266>,
    <1261, 1266, 1259>,
    <1261, 1259, 1258>,
    <1267, 1268, 1269>,
    <1267, 1269, 1234>,
    <1267, 1234, 1233>,
    <1267, 1233, 1270>,
    <1267, 1270, 1271>,
    <1267, 1271, 1272>,
    <1267, 1272, 1273>,
    <1267, 1273, 1274>,
    <1275, 1270, 1233>,
    <1275, 1233, 1240>,
    <1275, 1240, 1239>,
    <1275, 1239, 1276>,
    <1275, 1276, 1277>,
    <1275, 1277, 1278>,
    <1275, 1278, 1271>,
    <1275, 1271, 1270>,
    <1279, 1276, 1239>,
    <1279, 1239, 1244>,
    <1279, 1244, 1243>,
    <1279, 1243, 1280>,
    <1279, 1280, 1281>,
    <1279, 1281, 1282>,
    <1279, 1282, 1277>,
    <1279, 1277, 1276>,
    <1283, 1280, 1243>,
    <1283, 1243, 1248>,
    <1283, 1248, 1247>,
    <1283, 1247, 1284>,
    <1283, 1284, 1285>,
    <1283, 1285, 1286>,
    <1283, 1286, 1281>,
    <1283, 1281, 1280>,
    <1287, 1284, 1247>,
    <1287, 1247, 1252>,
    <1287, 1252, 1251>,
    <1287, 1251, 1288>,
    <1287, 1288, 1289>,
    <1287, 1289, 1290>,
    <1287, 1290, 1285>,
    <1287, 1285, 1284>,
    <1291, 1288, 1251>,
    <1291, 1251, 1256>,
    <1291, 1256, 1255>,
    <1291, 1255, 1292>,
    <1291, 1292, 1293>,
    <1291, 1293, 1294>,
    <1291, 1294, 1289>,
    <1291, 1289, 1288>,
    <1295, 1292, 1255>,
    <1295, 1255, 1260>,
    <1295, 1260, 1259>,
    <1295, 1259, 1296>,
    <1295, 1296, 1297>,
    <1295, 1297, 1298>,
    <1295, 1298, 1293>,
    <1295, 1293, 1292>,
    <1299, 1296, 1259>,
    <1299, 1259, 1266>,
    <1299, 1266, 1300>,
    <1299, 1300, 1301>,
    <1299, 1302, 1303>,
    <1299, 1303, 1304>,
    <1299, 1304, 1297>,
    <1299, 1297, 1296>,
    <1305, 1056, 783>,
    <1305, 783, 998>,
    <1305, 998, 997>,
    <1305, 997, 1306>,
    <1305, 1306, 1307>,
    <1305, 1307, 1308>,
    <1305, 1308, 1057>,
    <1305, 1057, 1056>,
    <1309, 1306, 997>,
    <1309, 997, 1002>,
    <1309, 1002, 1001>,
    <1309, 1001, 1310>,
    <1309, 1310, 1311>,
    <1309, 1311, 1312>,
    <1309, 1312, 1307>,
    <1309, 1307, 1306>,
    <1313, 1310, 1001>,
    <1313, 1001, 1006>,
    <1313, 1006, 1005>,
    <1313, 1005, 1314>,
    <1313, 1314, 1315>,
    <1313, 1315, 1316>,
    <1313, 1316, 1311>,
    <1313, 1311, 1310>,
    <1317, 1314, 1005>,
    <1317, 1005, 1010>,
    <1317, 1010, 1009>,
    <1317, 1009, 1318>,
    <1317, 1318, 1319>,
    <1317, 1319, 1320>,
    <1317, 1320, 1315>,
    <1317, 1315, 1314>,
    <1321, 1318, 1009>,
    <1321, 1009, 1014>,
    <1321, 1014, 1013>,
    <1321, 1013, 1322>,
    <1321, 1322, 1323>,
    <1321, 1323, 1324>,
    <1321, 1324, 1319>,
    <1321, 1319, 1318>,
    <1325, 1322, 1013>,
    <1325, 1013, 1018>,
    <1325, 1018, 1017>,
    <1325, 1017, 1326>,
    <1325, 1326, 1327>,
    <1325, 1327, 1328>,
    <1325, 1328, 1323>,
    <1325, 1323, 1322>,
    <1329, 1326, 1017>,
    <1329, 1017, 1022>,
    <1329, 1022, 1021>,
    <1329, 1021, 1330>,
    <1329, 1330, 1331>,
    <1329, 1331, 1332>,
    <1329, 1332, 1327>,
    <1329, 1327, 1326>,
    <1333, 1330, 1021>,
    <1333, 1021, 1024>,
    <1333, 1024, 756>,
    <1333, 756, 1026>,
    <1333, 1026, 1030>,
    <1333, 1030, 1334>,
    <1333, 1334, 1331>,
    <1333, 1331, 1330>,
    <1335, 1090, 1057>,
    <1335, 1057, 1308>,
    <1335, 1308, 1307>,
    <1335, 1307, 1336>,
    <1335, 1336, 1337>,
    <1335, 1337, 1338>,
    <1335, 1338, 1091>,
    <1335, 1091, 1090>,
    <1339, 1336, 1307>,
    <1339, 1307, 1312>,
    <1339, 1312, 1311>,
    <1339, 1311, 1340>,
    <1339, 1340, 1341>,
    <1339, 1341, 1342>,
    <1339, 1342, 1337>,
    <1339, 1337, 1336>,
    <1343, 1340, 1311>,
    <1343, 1311, 1316>,
    <1343, 1316, 1315>,
    <1343, 1315, 1344>,
    <1343, 1344, 1345>,
    <1343, 1345, 1346>,
    <1343, 1346, 1341>,
    <1343, 1341, 1340>,
    <1347, 1344, 1315>,
    <1347, 1315, 1320>,
    <1347, 1320, 1319>,
    <1347, 1319, 1348>,
    <1347, 1348, 1349>,
    <1347, 1349, 1350>,
    <1347, 1350, 1345>,
    <1347, 1345, 1344>,
    <1351, 1348, 1319>,
    <1351, 1319, 1324>,
    <1351, 1324, 1323>,
    <1351, 1323, 1352>,
    <1351, 1352, 1353>,
    <1351, 1353, 1354>,
    <1351, 1354, 1349>,
    <1351, 1349, 1348>,
    <1355, 1352, 1323>,
    <1355, 1323, 1328>,
    <1355, 1328, 1327>,
    <1355, 1327, 1356>,
    <1355, 1356, 1357>,
    <1355, 1357, 1358>,
    <1355, 1358, 1353>,
    <1355, 1353, 1352>,
    <1359, 1356, 1327>,
    <1359, 1327, 1332>,
    <1359, 1332, 1331>,
    <1359, 1331, 1360>,
    <1359, 1360, 1361>,
    <1359, 1361, 1362>,
    <1359, 1362, 1357>,
    <1359, 1357, 1356>,
    <1363, 1360, 1331>,
    <1363, 1331, 1334>,
    <1363, 1334, 1030>,
    <1363, 1030, 1060>,
    <1363, 1060, 1064>,
    <1363, 1064, 1364>,
    <1363, 1364, 1361>,
    <1363, 1361, 1360>,
    <1365, 1124, 1091>,
    <1365, 1091, 1338>,
    <1365, 1338, 1337>,
    <1365, 1337, 1366>,
    <1365, 1366, 1367>,
    <1365, 1367, 1368>,
    <1365, 1368, 1125>,
    <1365, 1125, 1124>,
    <1369, 1366, 1337>,
    <1369, 1337, 1342>,
    <1369, 1342, 1341>,
    <1369, 1341, 1370>,
    <1369, 1370, 1371>,
    <1369, 1371, 1372>,
    <1369, 1372, 1367>,
    <1369, 1367, 1366>,
    <1373, 1370, 1341>,
    <1373, 1341, 1346>,
    <1373, 1346, 1345>,
    <1373, 1345, 1374>,
    <1373, 1374, 1375>,
    <1373, 1375, 1376>,
    <1373, 1376, 1371>,
    <1373, 1371, 1370>,
    <1377, 1374, 1345>,
    <1377, 1345, 1350>,
    <1377, 1350, 1349>,
    <1377, 1349, 1378>,
    <1377, 1378, 1379>,
    <1377, 1379, 1380>,
    <1377, 1380, 1375>,
    <1377, 1375, 1374>,
    <1381, 1378, 1349>,
    <1381, 1349, 1354>,
    <1381, 1354, 1353>,
    <1381, 1353, 1382>,
    <1381, 1382, 1383>,
    <1381, 1383, 1384>,
    <1381, 1384, 1379>,
    <1381, 1379, 1378>,
    <1385, 1382, 1353>,
    <1385, 1353, 1358>,
    <1385, 1358, 1357>,
    <1385, 1357, 1386>,
    <1385, 1386, 1387>,
    <1385, 1387, 1388>,
    <1385, 1388, 1383>,
    <1385, 1383, 1382>,
    <1389, 1386, 1357>,
    <1389, 1357, 1362>,
    <1389, 1362, 1361>,
    <1389, 1361, 1390>,
    <1389, 1390, 1391>,
    <1389, 1391, 1392>,
    <1389, 1392, 1387>,
    <1389, 1387, 1386>,
    <1393, 1390, 1361>,
    <1393, 1361, 1364>,
    <1393, 1364, 1064>,
    <1393, 1064, 1094>,
    <1393, 1094, 1098>,
    <1393, 1098, 1394>,
    <1393, 1394, 1391>,
    <1393, 1391, 1390>,
    <1395, 1158, 1125>,
    <1395, 1125, 1368>,
    <1395, 1368, 1367>,
    <1395, 1367, 1396>,
    <1395, 1396, 1397>,
    <1395, 1397, 1398>,
    <1395, 1398, 1159>,
    <1395, 1159, 1158>,
    <1399, 1396, 1367>,
    <1399, 1367, 1372>,
    <1399, 1372, 1371>,
    <1399, 1371, 1400>,
    <1399, 1400, 1401>,
    <1399, 1401, 1402>,
    <1399, 1402, 1397>,
    <1399, 1397, 1396>,
    <1403, 1400, 1371>,
    <1403, 1371, 1376>,
    <1403, 1376, 1375>,
    <1403, 1375, 1404>,
    <1403, 1404, 1405>,
    <1403, 1405, 1406>,
    <1403, 1406, 1401>,
    <1403, 1401, 1400>,
    <1407, 1404, 1375>,
    <1407, 1375, 1380>,
    <1407, 1380, 1379>,
    <1407, 1379, 1408>,
    <1407, 1408, 1409>,
    <1407, 1409, 1410>,
    <1407, 1410, 1405>,
    <1407, 1405, 1404>,
    <1411, 1408, 1379>,
    <1411, 1379, 1384>,
    <1411, 1384, 1383>,
    <1411, 1383, 1412>,
    <1411, 1412, 1413>,
    <1411, 1413, 1414>,
    <1411, 1414, 1409>,
    <1411, 1409, 1408>,
    <1415, 1412, 1383>,
    <1415, 1383, 1388>,
    <1415, 1388, 1387>,
    <1415, 1387, 1416>,
    <1415, 1416, 1417>,
    <1415, 1417, 1418>,
    <1415, 1418, 1413>,
    <1415, 1413, 1412>,
    <1419, 1416, 1387>,
    <1419, 1387, 1392>,
    <1419, 1392, 1391>,
    <1419, 1391, 1420>,
    <1419, 1420, 1421>,
    <1419, 1421, 1422>,
    <1419, 1422, 1417>,
    <1419, 1417, 1416>,
    <1423, 1420, 1391>,
    <1423, 1391, 1394>,
    <1423, 1394, 1098>,
    <1423, 1098, 1128>,
    <1423, 1128, 1132>,
    <1423, 1132, 1424>,
    <1423, 1424, 1421>,
    <1423, 1421, 1420>,
    <1425, 1192, 1159>,
    <1425, 1159, 1398>,
    <1425, 1398, 1397>,
    <1425, 1397, 1426>,
    <1425, 1426, 1427>,
    <1425, 1427, 1428>,
    <1425, 1428, 1193>,
    <1425, 1193, 1192>,
    <1429, 1426, 1397>,
    <1429, 1397, 1402>,
    <1429, 1402, 1401>,
    <1429, 1401, 1430>,
    <1429, 1430, 1431>,
    <1429, 1431, 1432>,
    <1429, 1432, 1427>,
    <1429, 1427, 1426>,
    <1433, 1430, 1401>,
    <1433, 1401, 1406>,
    <1433, 1406, 1405>,
    <1433, 1405, 1434>,
    <1433, 1434, 1435>,
    <1433, 1435, 1436>,
    <1433, 1436, 1431>,
    <1433, 1431, 1430>,
    <1437, 1434, 1405>,
    <1437, 1405, 1410>,
    <1437, 1410, 1409>,
    <1437, 1409, 1438>,
    <1437, 1438, 1439>,
    <1437, 1439, 1440>,
    <1437, 1440, 1435>,
    <1437, 1435, 1434>,
    <1441, 1438, 1409>,
    <1441, 1409, 1414>,
    <1441, 1414, 1413>,
    <1441, 1413, 1442>,
    <1441, 1442, 1443>,
    <1441, 1443, 1444>,
    <1441, 1444, 1439>,
    <1441, 1439, 1438>,
    <1445, 1442, 1413>,
    <1445, 1413, 1418>,
    <1445, 1418, 1417>,
    <1445, 1417, 1446>,
    <1445, 1446, 1447>,
    <1445, 1447, 1448>,
    <1445, 1448, 1443>,
    <1445, 1443, 1442>,
    <1449, 1446, 1417>,
    <1449, 1417, 1422>,
    <1449, 1422, 1421>,
    <1449, 1421, 1450>,
    <1449, 1450, 1451>,
    <1449, 1451, 1452>,
    <1449, 1452, 1447>,
    <1449, 1447, 1446>,
    <1453, 1450, 1421>,
    <1453, 1421, 1424>,
    <1453, 1424, 1132>,
    <1453, 1132, 1162>,
    <1453, 1162, 1166>,
    <1453, 1166, 1454>,
    <1453, 1454, 1451>,
    <1453, 1451, 1450>,
    <1455, 1226, 1193>,
    <1455, 1193, 1428>,
    <1455, 1428, 1427>,
    <1455, 1427, 1456>,
    <1455, 1456, 1457>,
    <1455, 1457, 1458>,
    <1455, 1458, 1459>,
    <1455, 1459, 1226>,
    <1460, 1456, 1427>,
    <1460, 1427, 1432>,
    <1460, 1432, 1431>,
    <1460, 1431, 1461>,
    <1460, 1461, 1462>,
    <1460, 1462, 1463>,
    <1460, 1463, 1457>,
    <1460, 1457, 1456>,
    <1464, 1461, 1431>,
    <1464, 1431, 1436>,
    <1464, 1436, 1435>,
    <1464, 1435, 1465>,
    <1464, 1465, 1466>,
    <1464, 1466, 1467>,
    <1464, 1467, 1462>,
    <1464, 1462, 1461>,
    <1468, 1465, 1435>,
    <1468, 1435, 1440>,
    <1468, 1440, 1439>,
    <1468, 1439, 1469>,
    <1468, 1469, 1470>,
    <1468, 1470, 1471>,
    <1468, 1471, 1466>,
    <1468, 1466, 1465>,
    <1472, 1469, 1439>,
    <1472, 1439, 1444>,
    <1472, 1444, 1443>,
    <1472, 1443, 1473>,
    <1472, 1473, 1474>,
    <1472, 1474, 1475>,
    <1472, 1475, 1470>,
    <1472, 1470, 1469>,
    <1476, 1473, 1443>,
    <1476, 1443, 1448>,
    <1476, 1448, 1447>,
    <1476, 1447, 1477>,
    <1476, 1477, 1478>,
    <1476, 1478, 1479>,
    <1476, 1479, 1474>,
    <1476, 1474, 1473>,
    <1480, 1477, 1447>,
    <1480, 1447, 1452>,
    <1480, 1452, 1451>,
    <1480, 1451, 1481>,
    <1480, 1481, 1482>,
    <1480, 1482, 1483>,
    <1480, 1483, 1478>,
    <1480, 1478, 1477>,
    <1484, 1481, 1451>,
    <1484, 1451, 1454>,
    <1484, 1454, 1166>,
    <1484, 1166, 1196>,
    <1484, 1196, 1485>,
    <1484, 1485, 1486>,
    <1484, 1486, 1482>,
    <1484, 1482, 1481>,
    <1487, 1488, 1489>,
    <1487, 1489, 1458>,
    <1487, 1458, 1457>,
    <1487, 1457, 1490>,
    <1487, 1490, 1491>,
    <1487, 1491, 1492>,
    <1487, 1492, 1493>,
    <1487, 1493, 1494>,
    <1495, 1490, 1457>,
    <1495, 1457, 1463>,
    <1495, 1463, 1462>,
    <1495, 1462, 1496>,
    <1495, 1496, 1497>,
    <1495, 1497, 1498>,
    <1495, 1498, 1491>,
    <1495, 1491, 1490>,
    <1499, 1496, 1462>,
    <1499, 1462, 1467>,
    <1499, 1467, 1466>,
    <1499, 1466, 1500>,
    <1499, 1500, 1501>,
    <1499, 1501, 1502>,
    <1499, 1502, 1497>,
    <1499, 1497, 1496>,
    <1503, 1500, 1466>,
    <1503, 1466, 1471>,
    <1503, 1471, 1470>,
    <1503, 1470, 1504>,
    <1503, 1504, 1505>,
    <1503, 1505, 1506>,
    <1503, 1506, 1501>,
    <1503, 1501, 1500>,
    <1507, 1504, 1470>,
    <1507, 1470, 1475>,
    <1507, 1475, 1474>,
    <1507, 1474, 1508>,
    <1507, 1508, 1509>,
    <1507, 1509, 1510>,
    <1507, 1510, 1505>,
    <1507, 1505, 1504>,
    <1511, 1508, 1474>,
    <1511, 1474, 1479>,
    <1511, 1479, 1478>,
    <1511, 1478, 1512>,
    <1511, 1512, 1513>,
    <1511, 1513, 1514>,
    <1511, 1514, 1509>,
    <1511, 1509, 1508>,
    <1515, 1512, 1478>,
    <1515, 1478, 1483>,
    <1515, 1483, 1482>,
    <1515, 1482, 1516>,
    <1515, 1516, 1517>,
    <1515, 1517, 1518>,
    <1515, 1518, 1513>,
    <1515, 1513, 1512>,
    <1519, 1516, 1482>,
    <1519, 1482, 1486>,
    <1519, 1486, 1520>,
    <1519, 1520, 1521>,
    <1519, 1522, 1523>,
    <1519, 1523, 1524>,
    <1519, 1524, 1517>,
    <1519, 1517, 1516>,
    <1525, 1526, 1527>,
    <1525, 1527, 1492>,
    <1525, 1492, 1491>,
    <1525, 1491, 1528>,
    <1525, 1528, 1297>,
    <1525, 1297, 1304>,
    <1525, 1304, 1529>,
    <1525, 1529, 1530>,
    <1531, 1528, 1491>,
    <1531, 1491, 1498>,
    <1531, 1498, 1497>,
    <1531, 1497, 1532>,
    <1531, 1532, 1293>,
    <1531, 1293, 1298>,
    <1531, 1298, 1297>,
    <1531, 1297, 1528>,
    <1533, 1532, 1497>,
    <1533, 1497, 1502>,
    <1533, 1502, 1501>,
    <1533, 1501, 1534>,
    <1533, 1534, 1289>,
    <1533, 1289, 1294>,
    <1533, 1294, 1293>,
    <1533, 1293, 1532>,
    <1535, 1534, 1501>,
    <1535, 1501, 1506>,
    <1535, 1506, 1505>,
    <1535, 1505, 1536>,
    <1535, 1536, 1285>,
    <1535, 1285, 1290>,
    <1535, 1290, 1289>,
    <1535, 1289, 1534>,
    <1537, 1536, 1505>,
    <1537, 1505, 1510>,
    <1537, 1510, 1509>,
    <1537, 1509, 1538>,
    <1537, 1538, 1281>,
    <1537, 1281, 1286>,
    <1537, 1286, 1285>,
    <1537, 1285, 1536>,
    <1539, 1538, 1509>,
    <1539, 1509, 1514>,
    <1539, 1514, 1513>,
    <1539, 1513, 1540>,
    <1539, 1540, 1277>,
    <1539, 1277, 1282>,
    <1539, 1282, 1281>,
    <1539, 1281, 1538>,
    <1541, 1540, 1513>,
    <1541, 1513, 1518>,
    <1541, 1518, 1517>,
    <1541, 1517, 1542>,
    <1541, 1542, 1271>,
    <1541, 1271, 1278>,
    <1541, 1278, 1277>,
    <1541, 1277, 1540>,
    <1543, 1542, 1517>,
    <1543, 1517, 1524>,
    <1543, 1524, 1544>,
    <1543, 1544, 1545>,
    <1543, 1546, 1547>,
    <1543, 1547, 1272>,
    <1543, 1272, 1271>,
    <1543, 1271, 1542>
  }
  uv_indices {
    3040,   // from 0 triangles and 1520 quads
    <486, 492, 487>,
    <486, 487, 490>    <486, 490, 488>,
    <486, 488, 491>    <486, 491, 489>,
    <486, 489, 492>    <493, 499, 494>,
    <493, 494, 497>    <493, 497, 495>,
    <493, 495, 498>    <493, 498, 496>,
    <493, 496, 499>    <500, 506, 501>,
    <500, 501, 504>    <500, 504, 502>,
    <500, 502, 505>    <500, 505, 503>,
    <500, 503, 506>    <507, 513, 508>,
    <507, 508, 511>    <507, 511, 509>,
    <507, 509, 512>    <507, 512, 510>,
    <507, 510, 513>    <514, 520, 515>,
    <514, 515, 518>    <514, 518, 516>,
    <514, 516, 519>    <514, 519, 517>,
    <514, 517, 520>    <521, 527, 522>,
    <521, 522, 525>    <521, 525, 523>,
    <521, 523, 526>    <521, 526, 524>,
    <521, 524, 527>    <528, 534, 529>,
    <528, 529, 532>    <528, 532, 530>,
    <528, 530, 533>    <528, 533, 531>,
    <528, 531, 534>    <535, 541, 536>,
    <535, 536, 539>    <535, 539, 537>,
    <535, 537, 540>    <535, 540, 538>,
    <535, 538, 541>    <542, 550, 543>,
    <542, 543, 547>    <542, 547, 544>,
    <542, 544, 548>    <542, 548, 545>,
    <542, 545, 549>    <542, 549, 546>,
    <542, 546, 550>    <551, 559, 552>,
    <551, 552, 556>    <551, 556, 553>,
    <551, 553, 557>    <551, 557, 554>,
    <551, 554, 558>    <551, 558, 555>,
    <551, 555, 559>    <560, 568, 561>,
    <560, 561, 565>    <560, 565, 562>,
    <560, 562, 566>    <560, 566, 563>,
    <560, 563, 567>    <560, 567, 564>,
    <560, 564, 568>    <569, 577, 570>,
    <569, 570, 574>    <569, 574, 571>,
    <569, 571, 575>    <569, 575, 572>,
    <569, 572, 576>    <569, 576, 573>,
    <569, 573, 577>    <578, 586, 579>,
    <578, 579, 583>    <578, 583, 580>,
    <578, 580, 584>    <578, 584, 581>,
    <578, 581, 585>    <578, 585, 582>,
    <578, 582, 586>    <587, 595, 588>,
    <587, 588, 592>    <587, 592, 589>,
    <587, 589, 593>    <587, 593, 590>,
    <587, 590, 594>    <587, 594, 591>,
    <587, 591, 595>    <596, 604, 597>,
    <596, 597, 601>    <596, 601, 598>,
    <596, 598, 602>    <596, 602, 599>,
    <596, 599, 603>    <596, 603, 600>,
    <596, 600, 604>    <605, 613, 606>,
    <605, 606, 610>    <605, 610, 607>,
    <605, 607, 611>    <605, 611, 608>,
    <605, 608, 612>    <605, 612, 609>,
    <605, 609, 613>    <614, 622, 615>,
    <614, 615, 619>    <614, 619, 616>,
    <614, 616, 620>    <614, 620, 617>,
    <614, 617, 621>    <614, 621, 618>,
    <614, 618, 622>    <623, 631, 624>,
    <623, 624, 628>    <623, 628, 625>,
    <623, 625, 629>    <623, 629, 626>,
    <623, 626, 630>    <623, 630, 627>,
    <623, 627, 631>    <632, 640, 633>,
    <632, 633, 637>    <632, 637, 634>,
    <632, 634, 638>    <632, 638, 635>,
    <632, 635, 639>    <632, 639, 636>,
    <632, 636, 640>    <641, 649, 642>,
    <641, 642, 646>    <641, 646, 643>,
    <641, 643, 647>    <641, 647, 644>,
    <641, 644, 648>    <641, 648, 645>,
    <641, 645, 649>    <650, 658, 651>,
    <650, 651, 655>    <650, 655, 652>,
    <650, 652, 656>    <650, 656, 653>,
    <650, 653, 657>    <650, 657, 654>,
    <650, 654, 658>    <659, 667, 660>,
    <659, 660, 664>    <659, 664, 661>,
    <659, 661, 665>    <659, 665, 662>,
    <659, 662, 666>    <659, 666, 663>,
    <659, 663, 667>    <668, 676, 669>,
    <668, 669, 673>    <668, 673, 670>,
    <668, 670, 674>    <668, 674, 671>,
    <668, 671, 675>    <668, 675, 672>,
    <668, 672, 676>    <677, 685, 678>,
    <677, 678, 682>    <677, 682, 679>,
    <677, 679, 683>    <677, 683, 680>,
    <677, 680, 684>    <677, 684, 681>,
    <677, 681, 685>    <686, 694, 687>,
    <686, 687, 691>    <686, 691, 688>,
    <686, 688, 692>    <686, 692, 689>,
    <686, 689, 693>    <686, 693, 690>,
    <686, 690, 694>    <695, 703, 696>,
    <695, 696, 700>    <695, 700, 697>,
    <695, 697, 701>    <695, 701, 698>,
    <695, 698, 702>    <695, 702, 699>,
    <695, 699, 703>    <704, 712, 705>,
    <704, 705, 709>    <704, 709, 706>,
    <704, 706, 710>    <704, 710, 707>,
    <704, 707, 711>    <704, 711, 708>,
    <704, 708, 712>    <713, 721, 714>,
    <713, 714, 718>    <713, 718, 715>,
    <713, 715, 719>    <713, 719, 716>,
    <713, 716, 720>    <713, 720, 717>,
    <713, 717, 721>    <722, 730, 723>,
    <722, 723, 727>    <722, 727, 724>,
    <722, 724, 728>    <722, 728, 725>,
    <722, 725, 729>    <722, 729, 726>,
    <722, 726, 730>    <731, 739, 732>,
    <731, 732, 736>    <731, 736, 733>,
    <731, 733, 737>    <731, 737, 734>,
    <731, 734, 738>    <731, 738, 735>,
    <731, 735, 739>    <740, 748, 741>,
    <740, 741, 745>    <740, 745, 742>,
    <740, 742, 746>    <740, 746, 743>,
    <740, 743, 747>    <740, 747, 744>,
    <740, 744, 748>    <749, 757, 750>,
    <749, 750, 754>    <749, 754, 751>,
    <749, 751, 755>    <749, 755, 752>,
    <749, 752, 756>    <749, 756, 753>,
    <749, 753, 757>    <758, 766, 759>,
    <758, 759, 763>    <758, 763, 760>,
    <758, 760, 764>    <758, 764, 761>,
    <758, 761, 765>    <758, 765, 762>,
    <758, 762, 766>    <767, 775, 768>,
    <767, 768, 772>    <767, 772, 769>,
    <767, 769, 773>    <767, 773, 770>,
    <767, 770, 774>    <767, 774, 771>,
    <767, 771, 775>    <776, 784, 777>,
    <776, 777, 781>    <776, 781, 778>,
    <776, 778, 782>    <776, 782, 779>,
    <776, 779, 783>    <776, 783, 780>,
    <776, 780, 784>    <785, 793, 786>,
    <785, 786, 790>    <785, 790, 787>,
    <785, 787, 791>    <785, 791, 788>,
    <785, 788, 792>    <785, 792, 789>,
    <785, 789, 793>    <794, 802, 795>,
    <794, 795, 799>    <794, 799, 796>,
    <794, 796, 800>    <794, 800, 797>,
    <794, 797, 801>    <794, 801, 798>,
    <794, 798, 802>    <803, 811, 804>,
    <803, 804, 808>    <803, 808, 805>,
    <803, 805, 809>    <803, 809, 806>,
    <803, 806, 810>    <803, 810, 807>,
    <803, 807, 811>    <812, 820, 813>,
    <812, 813, 817>    <812, 817, 814>,
    <812, 814, 818>    <812, 818, 815>,
    <812, 815, 819>    <812, 819, 816>,
    <812, 816, 820>    <821, 829, 822>,
    <821, 822, 826>    <821, 826, 823>,
    <821, 823, 827>    <821, 827, 824>,
    <821, 824, 828>    <821, 828, 825>,
    <821, 825, 829>    <830, 838, 831>,
    <830, 831, 835>    <830, 835, 832>,
    <830, 832, 836>    <830, 836, 833>,
    <830, 833, 837>    <830, 837, 834>,
    <830, 834, 838>    <839, 847, 840>,
    <839, 840, 844>    <839, 844, 841>,
    <839, 841, 845>    <839, 845, 842>,
    <839, 842, 846>    <839, 846, 843>,
    <839, 843, 847>    <848, 856, 849>,
    <848, 849, 853>    <848, 853, 850>,
    <848, 850, 854>    <848, 854, 851>,
    <848, 851, 855>    <848, 855, 852>,
    <848, 852, 856>    <857, 865, 858>,
    <857, 858, 862>    <857, 862, 859>,
    <857, 859, 863>    <857, 863, 860>,
    <857, 860, 864>    <857, 864, 861>,
    <857, 861, 865>    <866, 874, 867>,
    <866, 867, 871>    <866, 871, 868>,
    <866, 868, 872>    <866, 872, 869>,
    <866, 869, 873>    <866, 873, 870>,
    <866, 870, 874>    <875, 883, 876>,
    <875, 876, 880>    <875, 880, 877>,
    <875, 877, 881>    <875, 881, 878>,
    <875, 878, 882>    <875, 882, 879>,
    <875, 879, 883>    <884, 892, 885>,
    <884, 885, 889>    <884, 889, 886>,
    <884, 886, 890>    <884, 890, 887>,
    <884, 887, 891>    <884, 891, 888>,
    <884, 888, 892>    <893, 901, 894>,
    <893, 894, 898>    <893, 898, 895>,
    <893, 895, 899>    <893, 899, 896>,
    <893, 896, 900>    <893, 900, 897>,
    <893, 897, 901>    <902, 910, 903>,
    <902, 903, 907>    <902, 907, 904>,
    <902, 904, 908>    <902, 908, 905>,
    <902, 905, 909>    <902, 909, 906>,
    <902, 906, 910>    <911, 919, 912>,
    <911, 912, 916>    <911, 916, 913>,
    <911, 913, 917>    <911, 917, 914>,
    <911, 914, 918>    <911, 918, 915>,
    <911, 915, 919>    <920, 928, 921>,
    <920, 921, 925>    <920, 925, 922>,
    <920, 922, 926>    <920, 926, 923>,
    <920, 923, 927>    <920, 927, 924>,
    <920, 924, 928>    <929, 937, 930>,
    <929, 930, 934>    <929, 934, 931>,
    <929, 931, 935>    <929, 935, 932>,
    <929, 932, 936>    <929, 936, 933>,
    <929, 933, 937>    <938, 946, 939>,
    <938, 939, 943>    <938, 943, 940>,
    <938, 940, 944>    <938, 944, 941>,
    <938, 941, 945>    <938, 945, 942>,
    <938, 942, 946>    <947, 955, 948>,
    <947, 948, 952>    <947, 952, 949>,
    <947, 949, 953>    <947, 953, 950>,
    <947, 950, 954>    <947, 954, 951>,
    <947, 951, 955>    <956, 964, 957>,
    <956, 957, 961>    <956, 961, 958>,
    <956, 958, 962>    <956, 962, 959>,
    <956, 959, 963>    <956, 963, 960>,
    <956, 960, 964>    <965, 973, 966>,
    <965, 966, 970>    <965, 970, 967>,
    <965, 967, 971>    <965, 971, 968>,
    <965, 968, 972>    <965, 972, 969>,
    <965, 969, 973>    <974, 982, 975>,
    <974, 975, 979>    <974, 979, 976>,
    <974, 976, 980>    <974, 980, 977>,
    <974, 977, 981>    <974, 981, 978>,
    <974, 978, 982>    <983, 991, 984>,
    <983, 984, 988>    <983, 988, 985>,
    <983, 985, 989>    <983, 989, 986>,
    <983, 986, 990>    <983, 990, 987>,
    <983, 987, 991>    <992, 1000, 993>,
    <992, 993, 997>    <992, 997, 994>,
    <992, 994, 998>    <992, 998, 995>,
    <992, 995, 999>    <992, 999, 996>,
    <992, 996, 1000>    <1001, 1009, 1002>,
    <1001, 1002, 1006>    <1001, 1006, 1003>,
    <1001, 1003, 1007>    <1001, 1007, 1004>,
    <1001, 1004, 1008>    <1001, 1008, 1005>,
    <1001, 1005, 1009>    <1010, 1018, 1011>,
    <1010, 1011, 1015>    <1010, 1015, 1012>,
    <1010, 1012, 1016>    <1010, 1016, 1013>,
    <1010, 1013, 1017>    <1010, 1017, 1014>,
    <1010, 1014, 1018>    <1019, 1027, 1020>,
    <1019, 1020, 1024>    <1019, 1024, 1021>,
    <1019, 1021, 1025>    <1019, 1025, 1022>,
    <1019, 1022, 1026>    <1019, 1026, 1023>,
    <1019, 1023, 1027>    <1028, 1036, 1029>,
    <1028, 1029, 1033>    <1028, 1033, 1030>,
    <1028, 1030, 1034>    <1028, 1034, 1031>,
    <1028, 1031, 1035>    <1028, 1035, 1032>,
    <1028, 1032, 1036>    <1037, 1045, 1038>,
    <1037, 1038, 1042>    <1037, 1042, 1039>,
    <1037, 1039, 1043>    <1037, 1043, 1040>,
    <1037, 1040, 1044>    <1037, 1044, 1041>,
    <1037, 1041, 1045>    <1046, 1052, 1047>,
    <1046, 1047, 1050>    <1046, 1050, 1048>,
    <1046, 1048, 1051>    <1046, 1051, 1049>,
    <1046, 1049, 1052>    <1053, 1059, 1054>,
    <1053, 1054, 1057>    <1053, 1057, 1055>,
    <1053, 1055, 1058>    <1053, 1058, 1056>,
    <1053, 1056, 1059>    <1060, 1066, 1061>,
    <1060, 1061, 1064>    <1060, 1064, 1062>,
    <1060, 1062, 1065>    <1060, 1065, 1063>,
    <1060, 1063, 1066>    <1067, 1073, 1068>,
    <1067, 1068, 1071>    <1067, 1071, 1069>,
    <1067, 1069, 1072>    <1067, 1072, 1070>,
    <1067, 1070, 1073>    <1074, 1080, 1075>,
    <1074, 1075, 1078>    <1074, 1078, 1076>,
    <1074, 1076, 1079>    <1074, 1079, 1077>,
    <1074, 1077, 1080>    <1081, 1087, 1082>,
    <1081, 1082, 1085>    <1081, 1085, 1083>,
    <1081, 1083, 1086>    <1081, 1086, 1084>,
    <1081, 1084, 1087>    <1088, 1094, 1089>,
    <1088, 1089, 1092>    <1088, 1092, 1090>,
    <1088, 1090, 1093>    <1088, 1093, 1091>,
    <1088, 1091, 1094>    <1095, 1101, 1096>,
    <1095, 1096, 1099>    <1095, 1099, 1097>,
    <1095, 1097, 1100>    <1095, 1100, 1098>,
    <1095, 1098, 1101>    <1102, 1110, 1103>,
    <1102, 1103, 1107>    <1102, 1107, 1104>,
    <1102, 1104, 1108>    <1102, 1108, 1105>,
    <1102, 1105, 1109>    <1102, 1109, 1106>,
    <1102, 1106, 1110>    <1111, 1119, 1112>,
    <1111, 1112, 1116>    <1111, 1116, 1113>,
    <1111, 1113, 1117>    <1111, 1117, 1114>,
    <1111, 1114, 1118>    <1111, 1118, 1115>,
    <1111, 1115, 1119>    <1120, 1128, 1121>,
    <1120, 1121, 1125>    <1120, 1125, 1122>,
    <1120, 1122, 1126>    <1120, 1126, 1123>,
    <1120, 1123, 1127>    <1120, 1127, 1124>,
    <1120, 1124, 1128>    <1129, 1137, 1130>,
    <1129, 1130, 1134>    <1129, 1134, 1131>,
    <1129, 1131, 1135>    <1129, 1135, 1132>,
    <1129, 1132, 1136>    <1129, 1136, 1133>,
    <1129, 1133, 1137>    <1138, 1146, 1139>,
    <1138, 1139, 1143>    <1138, 1143, 1140>,
    <1138, 1140, 1144>    <1138, 1144, 1141>,
    <1138, 1141, 1145>    <1138, 1145, 1142>,
    <1138, 1142, 1146>    <1147, 1155, 1148>,
    <1147, 1148, 1152>    <1147, 1152, 1149>,
    <1147, 1149, 1153>    <1147, 1153, 1150>,
    <1147, 1150, 1154>    <1147, 1154, 1151>,
    <1147, 1151, 1155>    <1156, 1164, 1157>,
    <1156, 1157, 1161>    <1156, 1161, 1158>,
    <1156, 1158, 1162>    <1156, 1162, 1159>,
    <1156, 1159, 1163>    <1156, 1163, 1160>,
    <1156, 1160, 1164>    <1165, 1173, 1166>,
    <1165, 1166, 1170>    <1165, 1170, 1167>,
    <1165, 1167, 1171>    <1165, 1171, 1168>,
    <1165, 1168, 1172>    <1165, 1172, 1169>,
    <1165, 1169, 1173>    <1174, 1182, 1175>,
    <1174, 1175, 1179>    <1174, 1179, 1176>,
    <1174, 1176, 1180>    <1174, 1180, 1177>,
    <1174, 1177, 1181>    <1174, 1181, 1178>,
    <1174, 1178, 1182>    <1183, 1191, 1184>,
    <1183, 1184, 1188>    <1183, 1188, 1185>,
    <1183, 1185, 1189>    <1183, 1189, 1186>,
    <1183, 1186, 1190>    <1183, 1190, 1187>,
    <1183, 1187, 1191>    <1192, 1200, 1193>,
    <1192, 1193, 1197>    <1192, 1197, 1194>,
    <1192, 1194, 1198>    <1192, 1198, 1195>,
    <1192, 1195, 1199>    <1192, 1199, 1196>,
    <1192, 1196, 1200>    <1201, 1209, 1202>,
    <1201, 1202, 1206>    <1201, 1206, 1203>,
    <1201, 1203, 1207>    <1201, 1207, 1204>,
    <1201, 1204, 1208>    <1201, 1208, 1205>,
    <1201, 1205, 1209>    <1210, 1218, 1211>,
    <1210, 1211, 1215>    <1210, 1215, 1212>,
    <1210, 1212, 1216>    <1210, 1216, 1213>,
    <1210, 1213, 1217>    <1210, 1217, 1214>,
    <1210, 1214, 1218>    <1219, 1227, 1220>,
    <1219, 1220, 1224>    <1219, 1224, 1221>,
    <1219, 1221, 1225>    <1219, 1225, 1222>,
    <1219, 1222, 1226>    <1219, 1226, 1223>,
    <1219, 1223, 1227>    <1228, 1236, 1229>,
    <1228, 1229, 1233>    <1228, 1233, 1230>,
    <1228, 1230, 1234>    <1228, 1234, 1231>,
    <1228, 1231, 1235>    <1228, 1235, 1232>,
    <1228, 1232, 1236>    <1237, 1245, 1238>,
    <1237, 1238, 1242>    <1237, 1242, 1239>,
    <1237, 1239, 1243>    <1237, 1243, 1240>,
    <1237, 1240, 1244>    <1237, 1244, 1241>,
    <1237, 1241, 1245>    <1246, 1254, 1247>,
    <1246, 1247, 1251>    <1246, 1251, 1248>,
    <1246, 1248, 1252>    <1246, 1252, 1249>,
    <1246, 1249, 1253>    <1246, 1253, 1250>,
    <1246, 1250, 1254>    <1255, 1263, 1256>,
    <1255, 1256, 1260>    <1255, 1260, 1257>,
    <1255, 1257, 1261>    <1255, 1261, 1258>,
    <1255, 1258, 1262>    <1255, 1262, 1259>,
    <1255, 1259, 1263>    <1264, 1272, 1265>,
    <1264, 1265, 1269>    <1264, 1269, 1266>,
    <1264, 1266, 1270>    <1264, 1270, 1267>,
    <1264, 1267, 1271>    <1264, 1271, 1268>,
    <1264, 1268, 1272>    <1273, 1281, 1274>,
    <1273, 1274, 1278>    <1273, 1278, 1275>,
    <1273, 1275, 1279>    <1273, 1279, 1276>,
    <1273, 1276, 1280>    <1273, 1280, 1277>,
    <1273, 1277, 1281>    <1282, 1290, 1283>,
    <1282, 1283, 1287>    <1282, 1287, 1284>,
    <1282, 1284, 1288>    <1282, 1288, 1285>,
    <1282, 1285, 1289>    <1282, 1289, 1286>,
    <1282, 1286, 1290>    <1291, 1299, 1292>,
    <1291, 1292, 1296>    <1291, 1296, 1293>,
    <1291, 1293, 1297>    <1291, 1297, 1294>,
    <1291, 1294, 1298>    <1291, 1298, 1295>,
    <1291, 1295, 1299>    <1300, 1308, 1301>,
    <1300, 1301, 1305>    <1300, 1305, 1302>,
    <1300, 1302, 1306>    <1300, 1306, 1303>,
    <1300, 1303, 1307>    <1300, 1307, 1304>,
    <1300, 1304, 1308>    <1309, 1317, 1310>,
    <1309, 1310, 1314>    <1309, 1314, 1311>,
    <1309, 1311, 1315>    <1309, 1315, 1312>,
    <1309, 1312, 1316>    <1309, 1316, 1313>,
    <1309, 1313, 1317>    <1318, 1326, 1319>,
    <1318, 1319, 1323>    <1318, 1323, 1320>,
    <1318, 1320, 1324>    <1318, 1324, 1321>,
    <1318, 1321, 1325>    <1318, 1325, 1322>,
    <1318, 1322, 1326>    <1327, 1335, 1328>,
    <1327, 1328, 1332>    <1327, 1332, 1329>,
    <1327, 1329, 1333>    <1327, 1333, 1330>,
    <1327, 1330, 1334>    <1327, 1334, 1331>,
    <1327, 1331, 1335>    <1336, 1344, 1337>,
    <1336, 1337, 1341>    <1336, 1341, 1338>,
    <1336, 1338, 1342>    <1336, 1342, 1339>,
    <1336, 1339, 1343>    <1336, 1343, 1340>,
    <1336, 1340, 1344>    <1345, 1353, 1346>,
    <1345, 1346, 1350>    <1345, 1350, 1347>,
    <1345, 1347, 1351>    <1345, 1351, 1348>,
    <1345, 1348, 1352>    <1345, 1352, 1349>,
    <1345, 1349, 1353>    <1354, 1362, 1355>,
    <1354, 1355, 1359>    <1354, 1359, 1356>,
    <1354, 1356, 1360>    <1354, 1360, 1357>,
    <1354, 1357, 1361>    <1354, 1361, 1358>,
    <1354, 1358, 1362>    <1363, 1371, 1364>,
    <1363, 1364, 1368>    <1363, 1368, 1365>,
    <1363, 1365, 1369>    <1363, 1369, 1366>,
    <1363, 1366, 1370>    <1363, 1370, 1367>,
    <1363, 1367, 1371>    <1372, 1380, 1373>,
    <1372, 1373, 1377>    <1372, 1377, 1374>,
    <1372, 1374, 1378>    <1372, 1378, 1375>,
    <1372, 1375, 1379>    <1372, 1379, 1376>,
    <1372, 1376, 1380>    <1381, 1389, 1382>,
    <1381, 1382, 1386>    <1381, 1386, 1383>,
    <1381, 1383, 1387>    <1381, 1387, 1384>,
    <1381, 1384, 1388>    <1381, 1388, 1385>,
    <1381, 1385, 1389>    <1390, 1398, 1391>,
    <1390, 1391, 1395>    <1390, 1395, 1392>,
    <1390, 1392, 1396>    <1390, 1396, 1393>,
    <1390, 1393, 1397>    <1390, 1397, 1394>,
    <1390, 1394, 1398>    <1399, 1407, 1400>,
    <1399, 1400, 1404>    <1399, 1404, 1401>,
    <1399, 1401, 1405>    <1399, 1405, 1402>,
    <1399, 1402, 1406>    <1399, 1406, 1403>,
    <1399, 1403, 1407>    <1408, 1416, 1409>,
    <1408, 1409, 1413>    <1408, 1413, 1410>,
    <1408, 1410, 1414>    <1408, 1414, 1411>,
    <1408, 1411, 1415>    <1408, 1415, 1412>,
    <1408, 1412, 1416>    <1417, 1425, 1418>,
    <1417, 1418, 1422>    <1417, 1422, 1419>,
    <1417, 1419, 1423>    <1417, 1423, 1420>,
    <1417, 1420, 1424>    <1417, 1424, 1421>,
    <1417, 1421, 1425>    <1426, 1434, 1427>,
    <1426, 1427, 1431>    <1426, 1431, 1428>,
    <1426, 1428, 1432>    <1426, 1432, 1429>,
    <1426, 1429, 1433>    <1426, 1433, 1430>,
    <1426, 1430, 1434>    <1435, 1443, 1436>,
    <1435, 1436, 1440>    <1435, 1440, 1437>,
    <1435, 1437, 1441>    <1435, 1441, 1438>,
    <1435, 1438, 1442>    <1435, 1442, 1439>,
    <1435, 1439, 1443>    <1444, 1452, 1445>,
    <1444, 1445, 1449>    <1444, 1449, 1446>,
    <1444, 1446, 1450>    <1444, 1450, 1447>,
    <1444, 1447, 1451>    <1444, 1451, 1448>,
    <1444, 1448, 1452>    <1453, 1461, 1454>,
    <1453, 1454, 1458>    <1453, 1458, 1455>,
    <1453, 1455, 1459>    <1453, 1459, 1456>,
    <1453, 1456, 1460>    <1453, 1460, 1457>,
    <1453, 1457, 1461>    <1462, 1470, 1463>,
    <1462, 1463, 1467>    <1462, 1467, 1464>,
    <1462, 1464, 1468>    <1462, 1468, 1465>,
    <1462, 1465, 1469>    <1462, 1469, 1466>,
    <1462, 1466, 1470>    <1471, 1479, 1472>,
    <1471, 1472, 1476>    <1471, 1476, 1473>,
    <1471, 1473, 1477>    <1471, 1477, 1474>,
    <1471, 1474, 1478>    <1471, 1478, 1475>,
    <1471, 1475, 1479>    <1480, 1488, 1481>,
    <1480, 1481, 1485>    <1480, 1485, 1482>,
    <1480, 1482, 1486>    <1480, 1486, 1483>,
    <1480, 1483, 1487>    <1480, 1487, 1484>,
    <1480, 1484, 1488>    <1489, 1497, 1490>,
    <1489, 1490, 1494>    <1489, 1494, 1491>,
    <1489, 1491, 1495>    <1489, 1495, 1492>,
    <1489, 1492, 1496>    <1489, 1496, 1493>,
    <1489, 1493, 1497>    <1498, 1506, 1499>,
    <1498, 1499, 1503>    <1498, 1503, 1500>,
    <1498, 1500, 1504>    <1498, 1504, 1501>,
    <1498, 1501, 1505>    <1498, 1505, 1502>,
    <1498, 1502, 1506>    <1507, 1515, 1508>,
    <1507, 1508, 1512>    <1507, 1512, 1509>,
    <1507, 1509, 1513>    <1507, 1513, 1510>,
    <1507, 1510, 1514>    <1507, 1514, 1511>,
    <1507, 1511, 1515>    <1516, 1524, 1517>,
    <1516, 1517, 1521>    <1516, 1521, 1518>,
    <1516, 1518, 1522>    <1516, 1522, 1519>,
    <1516, 1519, 1523>    <1516, 1523, 1520>,
    <1516, 1520, 1524>    <1525, 1533, 1526>,
    <1525, 1526, 1530>    <1525, 1530, 1527>,
    <1525, 1527, 1531>    <1525, 1531, 1528>,
    <1525, 1528, 1532>    <1525, 1532, 1529>,
    <1525, 1529, 1533>    <1534, 1542, 1535>,
    <1534, 1535, 1539>    <1534, 1539, 1536>,
    <1534, 1536, 1540>    <1534, 1540, 1537>,
    <1534, 1537, 1541>    <1534, 1541, 1538>,
    <1534, 1538, 1542>    <1543, 1551, 1544>,
    <1543, 1544, 1548>    <1543, 1548, 1545>,
    <1543, 1545, 1549>    <1543, 1549, 1546>,
    <1543, 1546, 1550>    <1543, 1550, 1547>,
    <1543, 1547, 1551>    <1552, 1560, 1553>,
    <1552, 1553, 1557>    <1552, 1557, 1554>,
    <1552, 1554, 1558>    <1552, 1558, 1555>,
    <1552, 1555, 1559>    <1552, 1559, 1556>,
    <1552, 1556, 1560>    <1561, 1569, 1562>,
    <1561, 1562, 1566>    <1561, 1566, 1563>,
    <1561, 1563, 1567>    <1561, 1567, 1564>,
    <1561, 1564, 1568>    <1561, 1568, 1565>,
    <1561, 1565, 1569>    <1570, 1578, 1571>,
    <1570, 1571, 1575>    <1570, 1575, 1572>,
    <1570, 1572, 1576>    <1570, 1576, 1573>,
    <1570, 1573, 1577>    <1570, 1577, 1574>,
    <1570, 1574, 1578>    <1579, 1587, 1580>,
    <1579, 1580, 1584>    <1579, 1584, 1581>,
    <1579, 1581, 1585>    <1579, 1585, 1582>,
    <1579, 1582, 1586>    <1579, 1586, 1583>,
    <1579, 1583, 1587>    <1588, 1596, 1589>,
    <1588, 1589, 1593>    <1588, 1593, 1590>,
    <1588, 1590, 1594>    <1588, 1594, 1591>,
    <1588, 1591, 1595>    <1588, 1595, 1592>,
    <1588, 1592, 1596>    <1597, 1605, 1598>,
    <1597, 1598, 1602>    <1597, 1602, 1599>,
    <1597, 1599, 1603>    <1597, 1603, 1600>,
    <1597, 1600, 1604>    <1597, 1604, 1601>,
    <1597, 1601, 1605>    <1606, 1614, 1607>,
    <1606, 1607, 1611>    <1606, 1611, 1608>,
    <1606, 1608, 1612>    <1606, 1612, 1609>,
    <1606, 1609, 1613>    <1606, 1613, 1610>,
    <1606, 1610, 1614>    <1615, 1623, 1616>,
    <1615, 1616, 1620>    <1615, 1620, 1617>,
    <1615, 1617, 1621>    <1615, 1621, 1618>,
    <1615, 1618, 1622>    <1615, 1622, 1619>,
    <1615, 1619, 1623>    <1624, 1632, 1625>,
    <1624, 1625, 1629>    <1624, 1629, 1626>,
    <1624, 1626, 1630>    <1624, 1630, 1627>,
    <1624, 1627, 1631>    <1624, 1631, 1628>,
    <1624, 1628, 1632>    <1633, 1641, 1634>,
    <1633, 1634, 1638>    <1633, 1638, 1635>,
    <1633, 1635, 1639>    <1633, 1639, 1636>,
    <1633, 1636, 1640>    <1633, 1640, 1637>,
    <1633, 1637, 1641>    <1642, 1650, 1643>,
    <1642, 1643, 1647>    <1642, 1647, 1644>,
    <1642, 1644, 1648>    <1642, 1648, 1645>,
    <1642, 1645, 1649>    <1642, 1649, 1646>,
    <1642, 1646, 1650>    <1651, 1659, 1652>,
    <1651, 1652, 1656>    <1651, 1656, 1653>,
    <1651, 1653, 1657>    <1651, 1657, 1654>,
    <1651, 1654, 1658>    <1651, 1658, 1655>,
    <1651, 1655, 1659>    <1660, 1668, 1661>,
    <1660, 1661, 1665>    <1660, 1665, 1662>,
    <1660, 1662, 1666>    <1660, 1666, 1663>,
    <1660, 1663, 1667>    <1660, 1667, 1664>,
    <1660, 1664, 1668>    <1669, 1677, 1670>,
    <1669, 1670, 1674>    <1669, 1674, 1671>,
    <1669, 1671, 1675>    <1669, 1675, 1672>,
    <1669, 1672, 1676>    <1669, 1676, 1673>,
    <1669, 1673, 1677>    <1678, 1686, 1679>,
    <1678, 1679, 1683>    <1678, 1683, 1680>,
    <1678, 1680, 1684>    <1678, 1684, 1681>,
    <1678, 1681, 1685>    <1678, 1685, 1682>,
    <1678, 1682, 1686>    <1687, 1695, 1688>,
    <1687, 1688, 1692>    <1687, 1692, 1689>,
    <1687, 1689, 1693>    <1687, 1693, 1690>,
    <1687, 1690, 1694>    <1687, 1694, 1691>,
    <1687, 1691, 1695>    <1696, 1704, 1697>,
    <1696, 1697, 1701>    <1696, 1701, 1698>,
    <1696, 1698, 1702>    <1696, 1702, 1699>,
    <1696, 1699, 1703>    <1696, 1703, 1700>,
    <1696, 1700, 1704>    <1705, 1713, 1706>,
    <1705, 1706, 1710>    <1705, 1710, 1707>,
    <1705, 1707, 1711>    <1705, 1711, 1708>,
    <1705, 1708, 1712>    <1705, 1712, 1709>,
    <1705, 1709, 1713>    <1714, 1722, 1715>,
    <1714, 1715, 1719>    <1714, 1719, 1716>,
    <1714, 1716, 1720>    <1714, 1720, 1717>,
    <1714, 1717, 1721>    <1714, 1721, 1718>,
    <1714, 1718, 1722>    <1723, 1731, 1724>,
    <1723, 1724, 1728>    <1723, 1728, 1725>,
    <1723, 1725, 1729>    <1723, 1729, 1726>,
    <1723, 1726, 1730>    <1723, 1730, 1727>,
    <1723, 1727, 1731>    <1732, 1740, 1733>,
    <1732, 1733, 1737>    <1732, 1737, 1734>,
    <1732, 1734, 1738>    <1732, 1738, 1735>,
    <1732, 1735, 1739>    <1732, 1739, 1736>,
    <1732, 1736, 1740>    <1741, 1749, 1742>,
    <1741, 1742, 1746>    <1741, 1746, 1743>,
    <1741, 1743, 1747>    <1741, 1747, 1744>,
    <1741, 1744, 1748>    <1741, 1748, 1745>,
    <1741, 1745, 1749>    <1750, 1758, 1751>,
    <1750, 1751, 1755>    <1750, 1755, 1752>,
    <1750, 1752, 1756>    <1750, 1756, 1753>,
    <1750, 1753, 1757>    <1750, 1757, 1754>,
    <1750, 1754, 1758>    <1759, 1767, 1760>,
    <1759, 1760, 1764>    <1759, 1764, 1761>,
    <1759, 1761, 1765>    <1759, 1765, 1762>,
    <1759, 1762, 1766>    <1759, 1766, 1763>,
    <1759, 1763, 1767>    <1768, 1776, 1769>,
    <1768, 1769, 1773>    <1768, 1773, 1770>,
    <1768, 1770, 1774>    <1768, 1774, 1771>,
    <1768, 1771, 1775>    <1768, 1775, 1772>,
    <1768, 1772, 1776>    <1777, 1785, 1778>,
    <1777, 1778, 1782>    <1777, 1782, 1779>,
    <1777, 1779, 1783>    <1777, 1783, 1780>,
    <1777, 1780, 1784>    <1777, 1784, 1781>,
    <1777, 1781, 1785>    <1786, 1794, 1787>,
    <1786, 1787, 1791>    <1786, 1791, 1788>,
    <1786, 1788, 1792>    <1786, 1792, 1789>,
    <1786, 1789, 1793>    <1786, 1793, 1790>,
    <1786, 1790, 1794>    <1795, 1803, 1796>,
    <1795, 1796, 1800>    <1795, 1800, 1797>,
    <1795, 1797, 1801>    <1795, 1801, 1798>,
    <1795, 1798, 1802>    <1795, 1802, 1799>,
    <1795, 1799, 1803>    <1804, 1812, 1805>,
    <1804, 1805, 1809>    <1804, 1809, 1806>,
    <1804, 1806, 1810>    <1804, 1810, 1807>,
    <1804, 1807, 1811>    <1804, 1811, 1808>,
    <1804, 1808, 1812>    <1813, 1821, 1814>,
    <1813, 1814, 1818>    <1813, 1818, 1815>,
    <1813, 1815, 1819>    <1813, 1819, 1816>,
    <1813, 1816, 1820>    <1813, 1820, 1817>,
    <1813, 1817, 1821>    <1822, 1830, 1823>,
    <1822, 1823, 1827>    <1822, 1827, 1824>,
    <1822, 1824, 1828>    <1822, 1828, 1825>,
    <1822, 1825, 1829>    <1822, 1829, 1826>,
    <1822, 1826, 1830>    <1831, 1839, 1832>,
    <1831, 1832, 1836>    <1831, 1836, 1833>,
    <1831, 1833, 1837>    <1831, 1837, 1834>,
    <1831, 1834, 1838>    <1831, 1838, 1835>,
    <1831, 1835, 1839>    <1840, 1848, 1841>,
    <1840, 1841, 1845>    <1840, 1845, 1842>,
    <1840, 1842, 1846>    <1840, 1846, 1843>,
    <1840, 1843, 1847>    <1840, 1847, 1844>,
    <1840, 1844, 1848>    <1849, 1857, 1850>,
    <1849, 1850, 1854>    <1849, 1854, 1851>,
    <1849, 1851, 1855>    <1849, 1855, 1852>,
    <1849, 1852, 1856>    <1849, 1856, 1853>,
    <1849, 1853, 1857>    <1858, 1866, 1859>,
    <1858, 1859, 1863>    <1858, 1863, 1860>,
    <1858, 1860, 1864>    <1858, 1864, 1861>,
    <1858, 1861, 1865>    <1858, 1865, 1862>,
    <1858, 1862, 1866>    <1867, 1875, 1868>,
    <1867, 1868, 1872>    <1867, 1872, 1869>,
    <1867, 1869, 1873>    <1867, 1873, 1870>,
    <1867, 1870, 1874>    <1867, 1874, 1871>,
    <1867, 1871, 1875>    <1876, 1884, 1877>,
    <1876, 1877, 1881>    <1876, 1881, 1878>,
    <1876, 1878, 1882>    <1876, 1882, 1879>,
    <1876, 1879, 1883>    <1876, 1883, 1880>,
    <1876, 1880, 1884>    <1885, 1893, 1886>,
    <1885, 1886, 1890>    <1885, 1890, 1887>,
    <1885, 1887, 1891>    <1885, 1891, 1888>,
    <1885, 1888, 1892>    <1885, 1892, 1889>,
    <1885, 1889, 1893>    <1894, 1902, 1895>,
    <1894, 1895, 1899>    <1894, 1899, 1896>,
    <1894, 1896, 1900>    <1894, 1900, 1897>,
    <1894, 1897, 1901>    <1894, 1901, 1898>,
    <1894, 1898, 1902>    <1903, 1911, 1904>,
    <1903, 1904, 1908>    <1903, 1908, 1905>,
    <1903, 1905, 1909>    <1903, 1909, 1906>,
    <1903, 1906, 1910>    <1903, 1910, 1907>,
    <1903, 1907, 1911>    <1912, 1920, 1913>,
    <1912, 1913, 1917>    <1912, 1917, 1914>,
    <1912, 1914, 1918>    <1912, 1918, 1915>,
    <1912, 1915, 1919>    <1912, 1919, 1916>,
    <1912, 1916, 1920>    <1921, 1929, 1922>,
    <1921, 1922, 1926>    <1921, 1926, 1923>,
    <1921, 1923, 1927>    <1921, 1927, 1924>,
    <1921, 1924, 1928>    <1921, 1928, 1925>,
    <1921, 1925, 1929>    <1930, 1938, 1931>,
    <1930, 1931, 1935>    <1930, 1935, 1932>,
    <1930, 1932, 1936>    <1930, 1936, 1933>,
    <1930, 1933, 1937>    <1930, 1937, 1934>,
    <1930, 1934, 1938>    <1939, 1947, 1940>,
    <1939, 1940, 1944>    <1939, 1944, 1941>,
    <1939, 1941, 1945>    <1939, 1945, 1942>,
    <1939, 1942, 1946>    <1939, 1946, 1943>,
    <1939, 1943, 1947>    <1948, 1956, 1949>,
    <1948, 1949, 1953>    <1948, 1953, 1950>,
    <1948, 1950, 1954>    <1948, 1954, 1951>,
    <1948, 1951, 1955>    <1948, 1955, 1952>,
    <1948, 1952, 1956>    <1957, 1965, 1958>,
    <1957, 1958, 1962>    <1957, 1962, 1959>,
    <1957, 1959, 1963>    <1957, 1963, 1960>,
    <1957, 1960, 1964>    <1957, 1964, 1961>,
    <1957, 1961, 1965>    <1966, 1974, 1967>,
    <1966, 1967, 1971>    <1966, 1971, 1968>,
    <1966, 1968, 1972>    <1966, 1972, 1969>,
    <1966, 1969, 1973>    <1966, 1973, 1970>,
    <1966, 1970, 1974>    <1975, 1983, 1976>,
    <1975, 1976, 1980>    <1975, 1980, 1977>,
    <1975, 1977, 1981>    <1975, 1981, 1978>,
    <1975, 1978, 1982>    <1975, 1982, 1979>,
    <1975, 1979, 1983>    <1984, 1992, 1985>,
    <1984, 1985, 1989>    <1984, 1989, 1986>,
    <1984, 1986, 1990>    <1984, 1990, 1987>,
    <1984, 1987, 1991>    <1984, 1991, 1988>,
    <1984, 1988, 1992>    <1993, 2001, 1994>,
    <1993, 1994, 1998>    <1993, 1998, 1995>,
    <1993, 1995, 1999>    <1993, 1999, 1996>,
    <1993, 1996, 2000>    <1993, 2000, 1997>,
    <1993, 1997, 2001>    <2002, 2010, 2003>,
    <2002, 2003, 2007>    <2002, 2007, 2004>,
    <2002, 2004, 2008>    <2002, 2008, 2005>,
    <2002, 2005, 2009>    <2002, 2009, 2006>,
    <2002, 2006, 2010>    <2011, 2019, 2012>,
    <2011, 2012, 2016>    <2011, 2016, 2013>,
    <2011, 2013, 2017>    <2011, 2017, 2014>,
    <2011, 2014, 2018>    <2011, 2018, 2015>,
    <2011, 2015, 2019>    <2020, 2028, 2021>,
    <2020, 2021, 2025>    <2020, 2025, 2022>,
    <2020, 2022, 2026>    <2020, 2026, 2023>,
    <2020, 2023, 2027>    <2020, 2027, 2024>,
    <2020, 2024, 2028>    <2029, 2037, 2030>,
    <2029, 2030, 2034>    <2029, 2034, 2031>,
    <2029, 2031, 2035>    <2029, 2035, 2032>,
    <2029, 2032, 2036>    <2029, 2036, 2033>,
    <2029, 2033, 2037>    <2038, 2046, 2039>,
    <2038, 2039, 2043>    <2038, 2043, 2040>,
    <2038, 2040, 2044>    <2038, 2044, 2041>,
    <2038, 2041, 2045>    <2038, 2045, 2042>,
    <2038, 2042, 2046>    <2047, 2055, 2048>,
    <2047, 2048, 2052>    <2047, 2052, 2049>,
    <2047, 2049, 2053>    <2047, 2053, 2050>,
    <2047, 2050, 2054>    <2047, 2054, 2051>,
    <2047, 2051, 2055>    <2056, 2064, 2057>,
    <2056, 2057, 2061>    <2056, 2061, 2058>,
    <2056, 2058, 2062>    <2056, 2062, 2059>,
    <2056, 2059, 2063>    <2056, 2063, 2060>,
    <2056, 2060, 2064>    <2065, 2073, 2066>,
    <2065, 2066, 2070>    <2065, 2070, 2067>,
    <2065, 2067, 2071>    <2065, 2071, 2068>,
    <2065, 2068, 2072>    <2065, 2072, 2069>,
    <2065, 2069, 2073>    <2074, 2082, 2075>,
    <2074, 2075, 2079>    <2074, 2079, 2076>,
    <2074, 2076, 2080>    <2074, 2080, 2077>,
    <2074, 2077, 2081>    <2074, 2081, 2078>,
    <2074, 2078, 2082>    <2083, 2091, 2084>,
    <2083, 2084, 2088>    <2083, 2088, 2085>,
    <2083, 2085, 2089>    <2083, 2089, 2086>,
    <2083, 2086, 2090>    <2083, 2090, 2087>,
    <2083, 2087, 2091>    <2092, 2100, 2093>,
    <2092, 2093, 2097>    <2092, 2097, 2094>,
    <2092, 2094, 2098>    <2092, 2098, 2095>,
    <2092, 2095, 2099>    <2092, 2099, 2096>,
    <2092, 2096, 2100>    <2101, 2109, 2102>,
    <2101, 2102, 2106>    <2101, 2106, 2103>,
    <2101, 2103, 2107>    <2101, 2107, 2104>,
    <2101, 2104, 2108>    <2101, 2108, 2105>,
    <2101, 2105, 2109>    <2110, 2118, 2111>,
    <2110, 2111, 2115>    <2110, 2115, 2112>,
    <2110, 2112, 2116>    <2110, 2116, 2113>,
    <2110, 2113, 2117>    <2110, 2117, 2114>,
    <2110, 2114, 2118>    <2119, 2127, 2120>,
    <2119, 2120, 2124>    <2119, 2124, 2121>,
    <2119, 2121, 2125>    <2119, 2125, 2122>,
    <2119, 2122, 2126>    <2119, 2126, 2123>,
    <2119, 2123, 2127>    <2128, 2136, 2129>,
    <2128, 2129, 2133>    <2128, 2133, 2130>,
    <2128, 2130, 2134>    <2128, 2134, 2131>,
    <2128, 2131, 2135>    <2128, 2135, 2132>,
    <2128, 2132, 2136>    <2137, 2145, 2138>,
    <2137, 2138, 2142>    <2137, 2142, 2139>,
    <2137, 2139, 2143>    <2137, 2143, 2140>,
    <2137, 2140, 2144>    <2137, 2144, 2141>,
    <2137, 2141, 2145>    <2146, 2154, 2147>,
    <2146, 2147, 2151>    <2146, 2151, 2148>,
    <2146, 2148, 2152>    <2146, 2152, 2149>,
    <2146, 2149, 2153>    <2146, 2153, 2150>,
    <2146, 2150, 2154>    <2155, 2163, 2156>,
    <2155, 2156, 2160>    <2155, 2160, 2157>,
    <2155, 2157, 2161>    <2155, 2161, 2158>,
    <2155, 2158, 2162>    <2155, 2162, 2159>,
    <2155, 2159, 2163>    <2164, 2172, 2165>,
    <2164, 2165, 2169>    <2164, 2169, 2166>,
    <2164, 2166, 2170>    <2164, 2170, 2167>,
    <2164, 2167, 2171>    <2164, 2171, 2168>,
    <2164, 2168, 2172>    <2173, 2181, 2174>,
    <2173, 2174, 2178>    <2173, 2178, 2175>,
    <2173, 2175, 2179>    <2173, 2179, 2176>,
    <2173, 2176, 2180>    <2173, 2180, 2177>,
    <2173, 2177, 2181>    <2182, 2190, 2183>,
    <2182, 2183, 2187>    <2182, 2187, 2184>,
    <2182, 2184, 2188>    <2182, 2188, 2185>,
    <2182, 2185, 2189>    <2182, 2189, 2186>,
    <2182, 2186, 2190>    <2191, 2199, 2192>,
    <2191, 2192, 2196>    <2191, 2196, 2193>,
    <2191, 2193, 2197>    <2191, 2197, 2194>,
    <2191, 2194, 2198>    <2191, 2198, 2195>,
    <2191, 2195, 2199>    <2200, 2208, 2201>,
    <2200, 2201, 2205>    <2200, 2205, 2202>,
    <2200, 2202, 2206>    <2200, 2206, 2203>,
    <2200, 2203, 2207>    <2200, 2207, 2204>,
    <2200, 2204, 2208>    <2209, 2217, 2210>,
    <2209, 2210, 2214>    <2209, 2214, 2211>,
    <2209, 2211, 2215>    <2209, 2215, 2212>,
    <2209, 2212, 2216>    <2209, 2216, 2213>,
    <2209, 2213, 2217>    <2218, 2226, 2219>,
    <2218, 2219, 2223>    <2218, 2223, 2220>,
    <2218, 2220, 2224>    <2218, 2224, 2221>,
    <2218, 2221, 2225>    <2218, 2225, 2222>,
    <2218, 2222, 2226>    <2227, 2235, 2228>,
    <2227, 2228, 2232>    <2227, 2232, 2229>,
    <2227, 2229, 2233>    <2227, 2233, 2230>,
    <2227, 2230, 2234>    <2227, 2234, 2231>,
    <2227, 2231, 2235>    <2236, 2244, 2237>,
    <2236, 2237, 2241>    <2236, 2241, 2238>,
    <2236, 2238, 2242>    <2236, 2242, 2239>,
    <2236, 2239, 2243>    <2236, 2243, 2240>,
    <2236, 2240, 2244>    <2245, 2253, 2246>,
    <2245, 2246, 2250>    <2245, 2250, 2247>,
    <2245, 2247, 2251>    <2245, 2251, 2248>,
    <2245, 2248, 2252>    <2245, 2252, 2249>,
    <2245, 2249, 2253>    <2254, 2262, 2255>,
    <2254, 2255, 2259>    <2254, 2259, 2256>,
    <2254, 2256, 2260>    <2254, 2260, 2257>,
    <2254, 2257, 2261>    <2254, 2261, 2258>,
    <2254, 2258, 2262>    <2263, 2271, 2264>,
    <2263, 2264, 2268>    <2263, 2268, 2265>,
    <2263, 2265, 2269>    <2263, 2269, 2266>,
    <2263, 2266, 2270>    <2263, 2270, 2267>,
    <2263, 2267, 2271>    <2272, 2280, 2273>,
    <2272, 2273, 2277>    <2272, 2277, 2274>,
    <2272, 2274, 2278>    <2272, 2278, 2275>,
    <2272, 2275, 2279>    <2272, 2279, 2276>,
    <2272, 2276, 2280>    <2281, 2289, 2282>,
    <2281, 2282, 2286>    <2281, 2286, 2283>,
    <2281, 2283, 2287>    <2281, 2287, 2284>,
    <2281, 2284, 2288>    <2281, 2288, 2285>,
    <2281, 2285, 2289>    <2290, 2298, 2291>,
    <2290, 2291, 2295>    <2290, 2295, 2292>,
    <2290, 2292, 2296>    <2290, 2296, 2293>,
    <2290, 2293, 2297>    <2290, 2297, 2294>,
    <2290, 2294, 2298>    <2299, 2307, 2300>,
    <2299, 2300, 2304>    <2299, 2304, 2301>,
    <2299, 2301, 2305>    <2299, 2305, 2302>,
    <2299, 2302, 2306>    <2299, 2306, 2303>,
    <2299, 2303, 2307>    <2308, 2316, 2309>,
    <2308, 2309, 2313>    <2308, 2313, 2310>,
    <2308, 2310, 2314>    <2308, 2314, 2311>,
    <2308, 2311, 2315>    <2308, 2315, 2312>,
    <2308, 2312, 2316>    <2317, 2325, 2318>,
    <2317, 2318, 2322>    <2317, 2322, 2319>,
    <2317, 2319, 2323>    <2317, 2323, 2320>,
    <2317, 2320, 2324>    <2317, 2324, 2321>,
    <2317, 2321, 2325>    <2326, 2334, 2327>,
    <2326, 2327, 2331>    <2326, 2331, 2328>,
    <2326, 2328, 2332>    <2326, 2332, 2329>,
    <2326, 2329, 2333>    <2326, 2333, 2330>,
    <2326, 2330, 2334>    <2335, 2343, 2336>,
    <2335, 2336, 2340>    <2335, 2340, 2337>,
    <2335, 2337, 2341>    <2335, 2341, 2338>,
    <2335, 2338, 2342>    <2335, 2342, 2339>,
    <2335, 2339, 2343>    <2344, 2352, 2345>,
    <2344, 2345, 2349>    <2344, 2349, 2346>,
    <2344, 2346, 2350>    <2344, 2350, 2347>,
    <2344, 2347, 2351>    <2344, 2351, 2348>,
    <2344, 2348, 2352>    <2353, 2361, 2354>,
    <2353, 2354, 2358>    <2353, 2358, 2355>,
    <2353, 2355, 2359>    <2353, 2359, 2356>,
    <2353, 2356, 2360>    <2353, 2360, 2357>,
    <2353, 2357, 2361>    <2362, 2370, 2363>,
    <2362, 2363, 2367>    <2362, 2367, 2364>,
    <2362, 2364, 2368>    <2362, 2368, 2365>,
    <2362, 2365, 2369>    <2362, 2369, 2366>,
    <2362, 2366, 2370>    <2371, 2379, 2372>,
    <2371, 2372, 2376>    <2371, 2376, 2373>,
    <2371, 2373, 2377>    <2371, 2377, 2374>,
    <2371, 2374, 2378>    <2371, 2378, 2375>,
    <2371, 2375, 2379>    <2380, 2388, 2381>,
    <2380, 2381, 2385>    <2380, 2385, 2382>,
    <2380, 2382, 2386>    <2380, 2386, 2383>,
    <2380, 2383, 2387>    <2380, 2387, 2384>,
    <2380, 2384, 2388>    <2389, 2397, 2390>,
    <2389, 2390, 2394>    <2389, 2394, 2391>,
    <2389, 2391, 2395>    <2389, 2395, 2392>,
    <2389, 2392, 2396>    <2389, 2396, 2393>,
    <2389, 2393, 2397>    <2398, 2406, 2399>,
    <2398, 2399, 2403>    <2398, 2403, 2400>,
    <2398, 2400, 2404>    <2398, 2404, 2401>,
    <2398, 2401, 2405>    <2398, 2405, 2402>,
    <2398, 2402, 2406>    <2407, 2415, 2408>,
    <2407, 2408, 2412>    <2407, 2412, 2409>,
    <2407, 2409, 2413>    <2407, 2413, 2410>,
    <2407, 2410, 2414>    <2407, 2414, 2411>,
    <2407, 2411, 2415>    <2416, 2424, 2417>,
    <2416, 2417, 2421>    <2416, 2421, 2418>,
    <2416, 2418, 2422>    <2416, 2422, 2419>,
    <2416, 2419, 2423>    <2416, 2423, 2420>,
    <2416, 2420, 2424>    <2425, 2433, 2426>,
    <2425, 2426, 2430>    <2425, 2430, 2427>,
    <2425, 2427, 2431>    <2425, 2431, 2428>,
    <2425, 2428, 2432>    <2425, 2432, 2429>,
    <2425, 2429, 2433>    <2434, 2442, 2435>,
    <2434, 2435, 2439>    <2434, 2439, 2436>,
    <2434, 2436, 2440>    <2434, 2440, 2437>,
    <2434, 2437, 2441>    <2434, 2441, 2438>,
    <2434, 2438, 2442>    <2443, 2451, 2444>,
    <2443, 2444, 2448>    <2443, 2448, 2445>,
    <2443, 2445, 2449>    <2443, 2449, 2446>,
    <2443, 2446, 2450>    <2443, 2450, 2447>,
    <2443, 2447, 2451>    <2452, 2460, 2453>,
    <2452, 2453, 2457>    <2452, 2457, 2454>,
    <2452, 2454, 2458>    <2452, 2458, 2455>,
    <2452, 2455, 2459>    <2452, 2459, 2456>,
    <2452, 2456, 2460>    <2461, 2469, 2462>,
    <2461, 2462, 2466>    <2461, 2466, 2463>,
    <2461, 2463, 2467>    <2461, 2467, 2464>,
    <2461, 2464, 2468>    <2461, 2468, 2465>,
    <2461, 2465, 2469>    <2470, 2478, 2471>,
    <2470, 2471, 2475>    <2470, 2475, 2472>,
    <2470, 2472, 2476>    <2470, 2476, 2473>,
    <2470, 2473, 2477>    <2470, 2477, 2474>,
    <2470, 2474, 2478>    <2479, 2487, 2480>,
    <2479, 2480, 2484>    <2479, 2484, 2481>,
    <2479, 2481, 2485>    <2479, 2485, 2482>,
    <2479, 2482, 2486>    <2479, 2486, 2483>,
    <2479, 2483, 2487>    <2488, 2496, 2489>,
    <2488, 2489, 2493>    <2488, 2493, 2490>,
    <2488, 2490, 2494>    <2488, 2494, 2491>,
    <2488, 2491, 2495>    <2488, 2495, 2492>,
    <2488, 2492, 2496>    <2497, 2505, 2498>,
    <2497, 2498, 2502>    <2497, 2502, 2499>,
    <2497, 2499, 2503>    <2497, 2503, 2500>,
    <2497, 2500, 2504>    <2497, 2504, 2501>,
    <2497, 2501, 2505>    <2506, 2514, 2507>,
    <2506, 2507, 2511>    <2506, 2511, 2508>,
    <2506, 2508, 2512>    <2506, 2512, 2509>,
    <2506, 2509, 2513>    <2506, 2513, 2510>,
    <2506, 2510, 2514>    <2515, 2523, 2516>,
    <2515, 2516, 2520>    <2515, 2520, 2517>,
    <2515, 2517, 2521>    <2515, 2521, 2518>,
    <2515, 2518, 2522>    <2515, 2522, 2519>,
    <2515, 2519, 2523>    <2524, 2532, 2525>,
    <2524, 2525, 2529>    <2524, 2529, 2526>,
    <2524, 2526, 2530>    <2524, 2530, 2527>,
    <2524, 2527, 2531>    <2524, 2531, 2528>,
    <2524, 2528, 2532>    <2533, 2541, 2534>,
    <2533, 2534, 2538>    <2533, 2538, 2535>,
    <2533, 2535, 2539>    <2533, 2539, 2536>,
    <2533, 2536, 2540>    <2533, 2540, 2537>,
    <2533, 2537, 2541>    <2542, 2550, 2543>,
    <2542, 2543, 2547>    <2542, 2547, 2544>,
    <2542, 2544, 2548>    <2542, 2548, 2545>,
    <2542, 2545, 2549>    <2542, 2549, 2546>,
    <2542, 2546, 2550>    <2551, 2559, 2552>,
    <2551, 2552, 2556>    <2551, 2556, 2553>,
    <2551, 2553, 2557>    <2551, 2557, 2554>,
    <2551, 2554, 2558>    <2551, 2558, 2555>,
    <2551, 2555, 2559>    <2560, 2568, 2561>,
    <2560, 2561, 2565>    <2560, 2565, 2562>,
    <2560, 2562, 2566>    <2560, 2566, 2563>,
    <2560, 2563, 2567>    <2560, 2567, 2564>,
    <2560, 2564, 2568>    <2569, 2577, 2570>,
    <2569, 2570, 2574>    <2569, 2574, 2571>,
    <2569, 2571, 2575>    <2569, 2575, 2572>,
    <2569, 2572, 2576>    <2569, 2576, 2573>,
    <2569, 2573, 2577>    <2578, 2586, 2579>,
    <2578, 2579, 2583>    <2578, 2583, 2580>,
    <2578, 2580, 2584>    <2578, 2584, 2581>,
    <2578, 2581, 2585>    <2578, 2585, 2582>,
    <2578, 2582, 2586>    <2587, 2595, 2588>,
    <2587, 2588, 2592>    <2587, 2592, 2589>,
    <2587, 2589, 2593>    <2587, 2593, 2590>,
    <2587, 2590, 2594>    <2587, 2594, 2591>,
    <2587, 2591, 2595>    <2596, 2604, 2597>,
    <2596, 2597, 2601>    <2596, 2601, 2598>,
    <2596, 2598, 2602>    <2596, 2602, 2599>,
    <2596, 2599, 2603>    <2596, 2603, 2600>,
    <2596, 2600, 2604>    <2605, 2613, 2606>,
    <2605, 2606, 2610>    <2605, 2610, 2607>,
    <2605, 2607, 2611>    <2605, 2611, 2608>,
    <2605, 2608, 2612>    <2605, 2612, 2609>,
    <2605, 2609, 2613>    <2614, 2622, 2615>,
    <2614, 2615, 2619>    <2614, 2619, 2616>,
    <2614, 2616, 2620>    <2614, 2620, 2617>,
    <2614, 2617, 2621>    <2614, 2621, 2618>,
    <2614, 2618, 2622>    <2623, 2631, 2624>,
    <2623, 2624, 2628>    <2623, 2628, 2625>,
    <2623, 2625, 2629>    <2623, 2629, 2626>,
    <2623, 2626, 2630>    <2623, 2630, 2627>,
    <2623, 2627, 2631>    <2632, 2640, 2633>,
    <2632, 2633, 2637>    <2632, 2637, 2634>,
    <2632, 2634, 2638>    <2632, 2638, 2635>,
    <2632, 2635, 2639>    <2632, 2639, 2636>,
    <2632, 2636, 2640>    <2641, 2649, 2642>,
    <2641, 2642, 2646>    <2641, 2646, 2643>,
    <2641, 2643, 2647>    <2641, 2647, 2644>,
    <2641, 2644, 2648>    <2641, 2648, 2645>,
    <2641, 2645, 2649>    <2650, 2658, 2651>,
    <2650, 2651, 2655>    <2650, 2655, 2652>,
    <2650, 2652, 2656>    <2650, 2656, 2653>,
    <2650, 2653, 2657>    <2650, 2657, 2654>,
    <2650, 2654, 2658>    <2659, 2667, 2660>,
    <2659, 2660, 2664>    <2659, 2664, 2661>,
    <2659, 2661, 2665>    <2659, 2665, 2662>,
    <2659, 2662, 2666>    <2659, 2666, 2663>,
    <2659, 2663, 2667>    <2668, 2676, 2669>,
    <2668, 2669, 2673>    <2668, 2673, 2670>,
    <2668, 2670, 2674>    <2668, 2674, 2671>,
    <2668, 2671, 2675>    <2668, 2675, 2672>,
    <2668, 2672, 2676>    <2677, 2685, 2678>,
    <2677, 2678, 2682>    <2677, 2682, 2679>,
    <2677, 2679, 2683>    <2677, 2683, 2680>,
    <2677, 2680, 2684>    <2677, 2684, 2681>,
    <2677, 2681, 2685>    <2686, 2694, 2687>,
    <2686, 2687, 2691>    <2686, 2691, 2688>,
    <2686, 2688, 2692>    <2686, 2692, 2689>,
    <2686, 2689, 2693>    <2686, 2693, 2690>,
    <2686, 2690, 2694>    <2695, 2703, 2696>,
    <2695, 2696, 2700>    <2695, 2700, 2697>,
    <2695, 2697, 2701>    <2695, 2701, 2698>,
    <2695, 2698, 2702>    <2695, 2702, 2699>,
    <2695, 2699, 2703>    <2704, 2712, 2705>,
    <2704, 2705, 2709>    <2704, 2709, 2706>,
    <2704, 2706, 2710>    <2704, 2710, 2707>,
    <2704, 2707, 2711>    <2704, 2711, 2708>,
    <2704, 2708, 2712>    <2713, 2721, 2714>,
    <2713, 2714, 2718>    <2713, 2718, 2715>,
    <2713, 2715, 2719>    <2713, 2719, 2716>,
    <2713, 2716, 2720>    <2713, 2720, 2717>,
    <2713, 2717, 2721>    <2722, 2730, 2723>,
    <2722, 2723, 2727>    <2722, 2727, 2724>,
    <2722, 2724, 2728>    <2722, 2728, 2725>,
    <2722, 2725, 2729>    <2722, 2729, 2726>,
    <2722, 2726, 2730>    <2731, 2739, 2732>,
    <2731, 2732, 2736>    <2731, 2736, 2733>,
    <2731, 2733, 2737>    <2731, 2737, 2734>,
    <2731, 2734, 2738>    <2731, 2738, 2735>,
    <2731, 2735, 2739>    <2740, 2748, 2741>,
    <2740, 2741, 2745>    <2740, 2745, 2742>,
    <2740, 2742, 2746>    <2740, 2746, 2743>,
    <2740, 2743, 2747>    <2740, 2747, 2744>,
    <2740, 2744, 2748>    <2749, 2757, 2750>,
    <2749, 2750, 2754>    <2749, 2754, 2751>,
    <2749, 2751, 2755>    <2749, 2755, 2752>,
    <2749, 2752, 2756>    <2749, 2756, 2753>,
    <2749, 2753, 2757>    <2758, 2766, 2759>,
    <2758, 2759, 2763>    <2758, 2763, 2760>,
    <2758, 2760, 2764>    <2758, 2764, 2761>,
    <2758, 2761, 2765>    <2758, 2765, 2762>,
    <2758, 2762, 2766>    <2767, 2775, 2768>,
    <2767, 2768, 2772>    <2767, 2772, 2769>,
    <2767, 2769, 2773>    <2767, 2773, 2770>,
    <2767, 2770, 2774>    <2767, 2774, 2771>,
    <2767, 2771, 2775>    <2776, 2784, 2777>,
    <2776, 2777, 2781>    <2776, 2781, 2778>,
    <2776, 2778, 2782>    <2776, 2782, 2779>,
    <2776, 2779, 2783>    <2776, 2783, 2780>,
    <2776, 2780, 2784>    <2785, 2793, 2786>,
    <2785, 2786, 2790>    <2785, 2790, 2787>,
    <2785, 2787, 2791>    <2785, 2791, 2788>,
    <2785, 2788, 2792>    <2785, 2792, 2789>,
    <2785, 2789, 2793>    <2794, 2802, 2795>,
    <2794, 2795, 2799>    <2794, 2799, 2796>,
    <2794, 2796, 2800>    <2794, 2800, 2797>,
    <2794, 2797, 2801>    <2794, 2801, 2798>,
    <2794, 2798, 2802>    <2803, 2811, 2804>,
    <2803, 2804, 2808>    <2803, 2808, 2805>,
    <2803, 2805, 2809>    <2803, 2809, 2806>,
    <2803, 2806, 2810>    <2803, 2810, 2807>,
    <2803, 2807, 2811>    <2812, 2820, 2813>,
    <2812, 2813, 2817>    <2812, 2817, 2814>,
    <2812, 2814, 2818>    <2812, 2818, 2815>,
    <2812, 2815, 2819>    <2812, 2819, 2816>,
    <2812, 2816, 2820>    <2821, 2829, 2822>,
    <2821, 2822, 2826>    <2821, 2826, 2823>,
    <2821, 2823, 2827>    <2821, 2827, 2824>,
    <2821, 2824, 2828>    <2821, 2828, 2825>,
    <2821, 2825, 2829>    <2830, 2838, 2831>,
    <2830, 2831, 2835>    <2830, 2835, 2832>,
    <2830, 2832, 2836>    <2830, 2836, 2833>,
    <2830, 2833, 2837>    <2830, 2837, 2834>,
    <2830, 2834, 2838>    <2839, 2847, 2840>,
    <2839, 2840, 2844>    <2839, 2844, 2841>,
    <2839, 2841, 2845>    <2839, 2845, 2842>,
    <2839, 2842, 2846>    <2839, 2846, 2843>,
    <2839, 2843, 2847>    <2848, 2856, 2849>,
    <2848, 2849, 2853>    <2848, 2853, 2850>,
    <2848, 2850, 2854>    <2848, 2854, 2851>,
    <2848, 2851, 2855>    <2848, 2855, 2852>,
    <2848, 2852, 2856>    <2857, 2865, 2858>,
    <2857, 2858, 2862>    <2857, 2862, 2859>,
    <2857, 2859, 2863>    <2857, 2863, 2860>,
    <2857, 2860, 2864>    <2857, 2864, 2861>,
    <2857, 2861, 2865>    <2866, 2874, 2867>,
    <2866, 2867, 2871>    <2866, 2871, 2868>,
    <2866, 2868, 2872>    <2866, 2872, 2869>,
    <2866, 2869, 2873>    <2866, 2873, 2870>,
    <2866, 2870, 2874>    <2875, 2883, 2876>,
    <2875, 2876, 2880>    <2875, 2880, 2877>,
    <2875, 2877, 2881>    <2875, 2881, 2878>,
    <2875, 2878, 2882>    <2875, 2882, 2879>,
    <2875, 2879, 2883>    <2884, 2892, 2885>,
    <2884, 2885, 2889>    <2884, 2889, 2886>,
    <2884, 2886, 2890>    <2884, 2890, 2887>,
    <2884, 2887, 2891>    <2884, 2891, 2888>,
    <2884, 2888, 2892>    <2893, 2901, 2894>,
    <2893, 2894, 2898>    <2893, 2898, 2895>,
    <2893, 2895, 2899>    <2893, 2899, 2896>,
    <2893, 2896, 2900>    <2893, 2900, 2897>,
    <2893, 2897, 2901>    <2902, 2910, 2903>,
    <2902, 2903, 2907>    <2902, 2907, 2904>,
    <2902, 2904, 2908>    <2902, 2908, 2905>,
    <2902, 2905, 2909>    <2902, 2909, 2906>,
    <2902, 2906, 2910>    <2911, 2919, 2912>,
    <2911, 2912, 2916>    <2911, 2916, 2913>,
    <2911, 2913, 2917>    <2911, 2917, 2914>,
    <2911, 2914, 2918>    <2911, 2918, 2915>,
    <2911, 2915, 2919>    <2920, 2928, 2921>,
    <2920, 2921, 2925>    <2920, 2925, 2922>,
    <2920, 2922, 2926>    <2920, 2926, 2923>,
    <2920, 2923, 2927>    <2920, 2927, 2924>,
    <2920, 2924, 2928>    <2929, 2937, 2930>,
    <2929, 2930, 2934>    <2929, 2934, 2931>,
    <2929, 2931, 2935>    <2929, 2935, 2932>,
    <2929, 2932, 2936>    <2929, 2936, 2933>,
    <2929, 2933, 2937>    <2938, 2946, 2939>,
    <2938, 2939, 2943>    <2938, 2943, 2940>,
    <2938, 2940, 2944>    <2938, 2944, 2941>,
    <2938, 2941, 2945>    <2938, 2945, 2942>,
    <2938, 2942, 2946>    <2947, 2955, 2948>,
    <2947, 2948, 2952>    <2947, 2952, 2949>,
    <2947, 2949, 2953>    <2947, 2953, 2950>,
    <2947, 2950, 2954>    <2947, 2954, 2951>,
    <2947, 2951, 2955>    <2956, 2964, 2957>,
    <2956, 2957, 2961>    <2956, 2961, 2958>,
    <2956, 2958, 2962>    <2956, 2962, 2959>,
    <2956, 2959, 2963>    <2956, 2963, 2960>,
    <2956, 2960, 2964>    <2965, 2973, 2966>,
    <2965, 2966, 2970>    <2965, 2970, 2967>,
    <2965, 2967, 2971>    <2965, 2971, 2968>,
    <2965, 2968, 2972>    <2965, 2972, 2969>,
    <2965, 2969, 2973>    <2974, 2982, 2975>,
    <2974, 2975, 2979>    <2974, 2979, 2976>,
    <2974, 2976, 2980>    <2974, 2980, 2977>,
    <2974, 2977, 2981>    <2974, 2981, 2978>,
    <2974, 2978, 2982>    <2983, 2991, 2984>,
    <2983, 2984, 2988>    <2983, 2988, 2985>,
    <2983, 2985, 2989>    <2983, 2989, 2986>,
    <2983, 2986, 2990>    <2983, 2990, 2987>,
    <2983, 2987, 2991>    <2992, 3000, 2993>,
    <2992, 2993, 2997>    <2992, 2997, 2994>,
    <2992, 2994, 2998>    <2992, 2998, 2995>,
    <2992, 2995, 2999>    <2992, 2999, 2996>,
    <2992, 2996, 3000>    <3001, 3009, 3002>,
    <3001, 3002, 3006>    <3001, 3006, 3003>,
    <3001, 3003, 3007>    <3001, 3007, 3004>,
    <3001, 3004, 3008>    <3001, 3008, 3005>,
    <3001, 3005, 3009>    <3010, 3018, 3011>,
    <3010, 3011, 3015>    <3010, 3015, 3012>,
    <3010, 3012, 3016>    <3010, 3016, 3013>,
    <3010, 3013, 3017>    <3010, 3017, 3014>,
    <3010, 3014, 3018>    <3019, 3027, 3020>,
    <3019, 3020, 3024>    <3019, 3024, 3021>,
    <3019, 3021, 3025>    <3019, 3025, 3022>,
    <3019, 3022, 3026>    <3019, 3026, 3023>,
    <3019, 3023, 3027>    <3028, 3036, 3029>,
    <3028, 3029, 3033>    <3028, 3033, 3030>,
    <3028, 3030, 3034>    <3028, 3034, 3031>,
    <3028, 3031, 3035>    <3028, 3035, 3032>,
    <3028, 3032, 3036>    <3037, 3045, 3038>,
    <3037, 3038, 3042>    <3037, 3042, 3039>,
    <3037, 3039, 3043>    <3037, 3043, 3040>,
    <3037, 3040, 3044>    <3037, 3044, 3041>,
    <3037, 3041, 3045>    <3046, 3054, 3047>,
    <3046, 3047, 3051>    <3046, 3051, 3048>,
    <3046, 3048, 3052>    <3046, 3052, 3049>,
    <3046, 3049, 3053>    <3046, 3053, 3050>,
    <3046, 3050, 3054>    <3055, 3063, 3056>,
    <3055, 3056, 3060>    <3055, 3060, 3057>,
    <3055, 3057, 3061>    <3055, 3061, 3058>,
    <3055, 3058, 3062>    <3055, 3062, 3059>,
    <3055, 3059, 3063>    <3064, 3072, 3065>,
    <3064, 3065, 3069>    <3064, 3069, 3066>,
    <3064, 3066, 3070>    <3064, 3070, 3067>,
    <3064, 3067, 3071>    <3064, 3071, 3068>,
    <3064, 3068, 3072>    <3073, 3081, 3074>,
    <3073, 3074, 3078>    <3073, 3078, 3075>,
    <3073, 3075, 3079>    <3073, 3079, 3076>,
    <3073, 3076, 3080>    <3073, 3080, 3077>,
    <3073, 3077, 3081>    <3082, 3090, 3083>,
    <3082, 3083, 3087>    <3082, 3087, 3084>,
    <3082, 3084, 3088>    <3082, 3088, 3085>,
    <3082, 3085, 3089>    <3082, 3089, 3086>,
    <3082, 3086, 3090>    <3091, 3099, 3092>,
    <3091, 3092, 3096>    <3091, 3096, 3093>,
    <3091, 3093, 3097>    <3091, 3097, 3094>,
    <3091, 3094, 3098>    <3091, 3098, 3095>,
    <3091, 3095, 3099>    <3100, 3108, 3101>,
    <3100, 3101, 3105>    <3100, 3105, 3102>,
    <3100, 3102, 3106>    <3100, 3106, 3103>,
    <3100, 3103, 3107>    <3100, 3107, 3104>,
    <3100, 3104, 3108>    <3109, 3117, 3110>,
    <3109, 3110, 3114>    <3109, 3114, 3111>,
    <3109, 3111, 3115>    <3109, 3115, 3112>,
    <3109, 3112, 3116>    <3109, 3116, 3113>,
    <3109, 3113, 3117>    <3118, 3126, 3119>,
    <3118, 3119, 3123>    <3118, 3123, 3120>,
    <3118, 3120, 3124>    <3118, 3124, 3121>,
    <3118, 3121, 3125>    <3118, 3125, 3122>,
    <3118, 3122, 3126>    <3127, 3135, 3128>,
    <3127, 3128, 3132>    <3127, 3132, 3129>,
    <3127, 3129, 3133>    <3127, 3133, 3130>,
    <3127, 3130, 3134>    <3127, 3134, 3131>,
    <3127, 3131, 3135>    <3136, 3144, 3137>,
    <3136, 3137, 3141>    <3136, 3141, 3138>,
    <3136, 3138, 3142>    <3136, 3142, 3139>,
    <3136, 3139, 3143>    <3136, 3143, 3140>,
    <3136, 3140, 3144>    <3145, 3153, 3146>,
    <3145, 3146, 3150>    <3145, 3150, 3147>,
    <3145, 3147, 3151>    <3145, 3151, 3148>,
    <3145, 3148, 3152>    <3145, 3152, 3149>,
    <3145, 3149, 3153>    <3154, 3162, 3155>,
    <3154, 3155, 3159>    <3154, 3159, 3156>,
    <3154, 3156, 3160>    <3154, 3160, 3157>,
    <3154, 3157, 3161>    <3154, 3161, 3158>,
    <3154, 3158, 3162>    <3163, 3171, 3164>,
    <3163, 3164, 3168>    <3163, 3168, 3165>,
    <3163, 3165, 3169>    <3163, 3169, 3166>,
    <3163, 3166, 3170>    <3163, 3170, 3167>,
    <3163, 3167, 3171>    <3172, 3180, 3173>,
    <3172, 3173, 3177>    <3172, 3177, 3174>,
    <3172, 3174, 3178>    <3172, 3178, 3175>,
    <3172, 3175, 3179>    <3172, 3179, 3176>,
    <3172, 3176, 3180>    <3181, 3189, 3182>,
    <3181, 3182, 3186>    <3181, 3186, 3183>,
    <3181, 3183, 3187>    <3181, 3187, 3184>,
    <3181, 3184, 3188>    <3181, 3188, 3185>,
    <3181, 3185, 3189>    <3190, 3198, 3191>,
    <3190, 3191, 3195>    <3190, 3195, 3192>,
    <3190, 3192, 3196>    <3190, 3196, 3193>,
    <3190, 3193, 3197>    <3190, 3197, 3194>,
    <3190, 3194, 3198>    <3199, 3207, 3200>,
    <3199, 3200, 3204>    <3199, 3204, 3201>,
    <3199, 3201, 3205>    <3199, 3205, 3202>,
    <3199, 3202, 3206>    <3199, 3206, 3203>,
    <3199, 3203, 3207>    <3208, 3216, 3209>,
    <3208, 3209, 3213>    <3208, 3213, 3210>,
    <3208, 3210, 3214>    <3208, 3214, 3211>,
    <3208, 3211, 3215>    <3208, 3215, 3212>,
    <3208, 3212, 3216>    <3217, 3225, 3218>,
    <3217, 3218, 3222>    <3217, 3222, 3219>,
    <3217, 3219, 3223>    <3217, 3223, 3220>,
    <3217, 3220, 3224>    <3217, 3224, 3221>,
    <3217, 3221, 3225>    <3226, 3234, 3227>,
    <3226, 3227, 3231>    <3226, 3231, 3228>,
    <3226, 3228, 3232>    <3226, 3232, 3229>,
    <3226, 3229, 3233>    <3226, 3233, 3230>,
    <3226, 3230, 3234>    <3235, 3243, 3236>,
    <3235, 3236, 3240>    <3235, 3240, 3237>,
    <3235, 3237, 3241>    <3235, 3241, 3238>,
    <3235, 3238, 3242>    <3235, 3242, 3239>,
    <3235, 3239, 3243>    <3244, 3252, 3245>,
    <3244, 3245, 3249>    <3244, 3249, 3246>,
    <3244, 3246, 3250>    <3244, 3250, 3247>,
    <3244, 3247, 3251>    <3244, 3251, 3248>,
    <3244, 3248, 3252>    <3253, 3261, 3254>,
    <3253, 3254, 3258>    <3253, 3258, 3255>,
    <3253, 3255, 3259>    <3253, 3259, 3256>,
    <3253, 3256, 3260>    <3253, 3260, 3257>,
    <3253, 3257, 3261>    <3262, 3270, 3263>,
    <3262, 3263, 3267>    <3262, 3267, 3264>,
    <3262, 3264, 3268>    <3262, 3268, 3265>,
    <3262, 3265, 3269>    <3262, 3269, 3266>,
    <3262, 3266, 3270>    <3271, 3279, 3272>,
    <3271, 3272, 3276>    <3271, 3276, 3273>,
    <3271, 3273, 3277>    <3271, 3277, 3274>,
    <3271, 3274, 3278>    <3271, 3278, 3275>,
    <3271, 3275, 3279>    <3280, 3288, 3281>,
    <3280, 3281, 3285>    <3280, 3285, 3282>,
    <3280, 3282, 3286>    <3280, 3286, 3283>,
    <3280, 3283, 3287>    <3280, 3287, 3284>,
    <3280, 3284, 3288>    <3289, 3297, 3290>,
    <3289, 3290, 3294>    <3289, 3294, 3291>,
    <3289, 3291, 3295>    <3289, 3295, 3292>,
    <3289, 3292, 3296>    <3289, 3296, 3293>,
    <3289, 3293, 3297>    <3298, 3306, 3299>,
    <3298, 3299, 3303>    <3298, 3303, 3300>,
    <3298, 3300, 3304>    <3298, 3304, 3301>,
    <3298, 3301, 3305>    <3298, 3305, 3302>,
    <3298, 3302, 3306>    <3307, 3315, 3308>,
    <3307, 3308, 3312>    <3307, 3312, 3309>,
    <3307, 3309, 3313>    <3307, 3313, 3310>,
    <3307, 3310, 3314>    <3307, 3314, 3311>,
    <3307, 3311, 3315>    <3316, 3324, 3317>,
    <3316, 3317, 3321>    <3316, 3321, 3318>,
    <3316, 3318, 3322>    <3316, 3322, 3319>,
    <3316, 3319, 3323>    <3316, 3323, 3320>,
    <3316, 3320, 3324>    <3325, 3333, 3326>,
    <3325, 3326, 3330>    <3325, 3330, 3327>,
    <3325, 3327, 3331>    <3325, 3331, 3328>,
    <3325, 3328, 3332>    <3325, 3332, 3329>,
    <3325, 3329, 3333>    <3334, 3342, 3335>,
    <3334, 3335, 3339>    <3334, 3339, 3336>,
    <3334, 3336, 3340>    <3334, 3340, 3337>,
    <3334, 3337, 3341>    <3334, 3341, 3338>,
    <3334, 3338, 3342>    <3343, 3351, 3344>,
    <3343, 3344, 3348>    <3343, 3348, 3345>,
    <3343, 3345, 3349>    <3343, 3349, 3346>,
    <3343, 3346, 3350>    <3343, 3350, 3347>,
    <3343, 3347, 3351>    <3352, 3360, 3353>,
    <3352, 3353, 3357>    <3352, 3357, 3354>,
    <3352, 3354, 3358>    <3352, 3358, 3355>,
    <3352, 3355, 3359>    <3352, 3359, 3356>,
    <3352, 3356, 3360>    <3361, 3369, 3362>,
    <3361, 3362, 3366>    <3361, 3366, 3363>,
    <3361, 3363, 3367>    <3361, 3367, 3364>,
    <3361, 3364, 3368>    <3361, 3368, 3365>,
    <3361, 3365, 3369>    <3370, 3378, 3371>,
    <3370, 3371, 3375>    <3370, 3375, 3372>,
    <3370, 3372, 3376>    <3370, 3376, 3373>,
    <3370, 3373, 3377>    <3370, 3377, 3374>,
    <3370, 3374, 3378>    <3379, 3387, 3380>,
    <3379, 3380, 3384>    <3379, 3384, 3381>,
    <3379, 3381, 3385>    <3379, 3385, 3382>,
    <3379, 3382, 3386>    <3379, 3386, 3383>,
    <3379, 3383, 3387>    <3388, 3396, 3389>,
    <3388, 3389, 3393>    <3388, 3393, 3390>,
    <3388, 3390, 3394>    <3388, 3394, 3391>,
    <3388, 3391, 3395>    <3388, 3395, 3392>,
    <3388, 3392, 3396>    <3397, 3405, 3398>,
    <3397, 3398, 3402>    <3397, 3402, 3399>,
    <3397, 3399, 3403>    <3397, 3403, 3400>,
    <3397, 3400, 3404>    <3397, 3404, 3401>,
    <3397, 3401, 3405>    <3406, 3414, 3407>,
    <3406, 3407, 3411>    <3406, 3411, 3408>,
    <3406, 3408, 3412>    <3406, 3412, 3409>,
    <3406, 3409, 3413>    <3406, 3413, 3410>,
    <3406, 3410, 3414>    <3415, 3423, 3416>,
    <3415, 3416, 3420>    <3415, 3420, 3417>,
    <3415, 3417, 3421>    <3415, 3421, 3418>,
    <3415, 3418, 3422>    <3415, 3422, 3419>,
    <3415, 3419, 3423>    <3424, 3432, 3425>,
    <3424, 3425, 3429>    <3424, 3429, 3426>,
    <3424, 3426, 3430>    <3424, 3430, 3427>,
    <3424, 3427, 3431>    <3424, 3431, 3428>,
    <3424, 3428, 3432>    <3433, 3441, 3434>,
    <3433, 3434, 3438>    <3433, 3438, 3435>,
    <3433, 3435, 3439>    <3433, 3439, 3436>,
    <3433, 3436, 3440>    <3433, 3440, 3437>,
    <3433, 3437, 3441>    <3442, 3450, 3443>,
    <3442, 3443, 3447>    <3442, 3447, 3444>,
    <3442, 3444, 3448>    <3442, 3448, 3445>,
    <3442, 3445, 3449>    <3442, 3449, 3446>,
    <3442, 3446, 3450>    <3451, 3459, 3452>,
    <3451, 3452, 3456>    <3451, 3456, 3453>,
    <3451, 3453, 3457>    <3451, 3457, 3454>,
    <3451, 3454, 3458>    <3451, 3458, 3455>,
    <3451, 3455, 3459>    <3460, 3468, 3461>,
    <3460, 3461, 3465>    <3460, 3465, 3462>,
    <3460, 3462, 3466>    <3460, 3466, 3463>,
    <3460, 3463, 3467>    <3460, 3467, 3464>,
    <3460, 3464, 3468>    <3469, 3477, 3470>,
    <3469, 3470, 3474>    <3469, 3474, 3471>,
    <3469, 3471, 3475>    <3469, 3475, 3472>,
    <3469, 3472, 3476>    <3469, 3476, 3473>,
    <3469, 3473, 3477>    <3478, 3486, 3479>,
    <3478, 3479, 3483>    <3478, 3483, 3480>,
    <3478, 3480, 3484>    <3478, 3484, 3481>,
    <3478, 3481, 3485>    <3478, 3485, 3482>,
    <3478, 3482, 3486>    <3487, 3495, 3488>,
    <3487, 3488, 3492>    <3487, 3492, 3489>,
    <3487, 3489, 3493>    <3487, 3493, 3490>,
    <3487, 3490, 3494>    <3487, 3494, 3491>,
    <3487, 3491, 3495>    <3496, 3504, 3497>,
    <3496, 3497, 3501>    <3496, 3501, 3498>,
    <3496, 3498, 3502>    <3496, 3502, 3499>,
    <3496, 3499, 3503>    <3496, 3503, 3500>,
    <3496, 3500, 3504>    <3505, 3513, 3506>,
    <3505, 3506, 3510>    <3505, 3510, 3507>,
    <3505, 3507, 3511>    <3505, 3511, 3508>,
    <3505, 3508, 3512>    <3505, 3512, 3509>,
    <3505, 3509, 3513>    <3514, 3522, 3515>,
    <3514, 3515, 3519>    <3514, 3519, 3516>,
    <3514, 3516, 3520>    <3514, 3520, 3517>,
    <3514, 3517, 3521>    <3514, 3521, 3518>,
    <3514, 3518, 3522>    <3523, 3531, 3524>,
    <3523, 3524, 3528>    <3523, 3528, 3525>,
    <3523, 3525, 3529>    <3523, 3529, 3526>,
    <3523, 3526, 3530>    <3523, 3530, 3527>,
    <3523, 3527, 3531>    <3532, 3540, 3533>,
    <3532, 3533, 3537>    <3532, 3537, 3534>,
    <3532, 3534, 3538>    <3532, 3538, 3535>,
    <3532, 3535, 3539>    <3532, 3539, 3536>,
    <3532, 3536, 3540>    <3541, 3549, 3542>,
    <3541, 3542, 3546>    <3541, 3546, 3543>,
    <3541, 3543, 3547>    <3541, 3547, 3544>,
    <3541, 3544, 3548>    <3541, 3548, 3545>,
    <3541, 3545, 3549>    <3550, 3558, 3551>,
    <3550, 3551, 3555>    <3550, 3555, 3552>,
    <3550, 3552, 3556>    <3550, 3556, 3553>,
    <3550, 3553, 3557>    <3550, 3557, 3554>,
    <3550, 3554, 3558>    <3559, 3567, 3560>,
    <3559, 3560, 3564>    <3559, 3564, 3561>,
    <3559, 3561, 3565>    <3559, 3565, 3562>,
    <3559, 3562, 3566>    <3559, 3566, 3563>,
    <3559, 3563, 3567>    <3568, 3576, 3569>,
    <3568, 3569, 3573>    <3568, 3573, 3570>,
    <3568, 3570, 3574>    <3568, 3574, 3571>,
    <3568, 3571, 3575>    <3568, 3575, 3572>,
    <3568, 3572, 3576>    <3577, 3585, 3578>,
    <3577, 3578, 3582>    <3577, 3582, 3579>,
    <3577, 3579, 3583>    <3577, 3583, 3580>,
    <3577, 3580, 3584>    <3577, 3584, 3581>,
    <3577, 3581, 3585>    <3586, 3594, 3587>,
    <3586, 3587, 3591>    <3586, 3591, 3588>,
    <3586, 3588, 3592>    <3586, 3592, 3589>,
    <3586, 3589, 3593>    <3586, 3593, 3590>,
    <3586, 3590, 3594>    <3595, 3603, 3596>,
    <3595, 3596, 3600>    <3595, 3600, 3597>,
    <3595, 3597, 3601>    <3595, 3601, 3598>,
    <3595, 3598, 3602>    <3595, 3602, 3599>,
    <3595, 3599, 3603>    <3604, 3612, 3605>,
    <3604, 3605, 3609>    <3604, 3609, 3606>,
    <3604, 3606, 3610>    <3604, 3610, 3607>,
    <3604, 3607, 3611>    <3604, 3611, 3608>,
    <3604, 3608, 3612>    <3613, 3621, 3614>,
    <3613, 3614, 3618>    <3613, 3618, 3615>,
    <3613, 3615, 3619>    <3613, 3619, 3616>,
    <3613, 3616, 3620>    <3613, 3620, 3617>,
    <3613, 3617, 3621>    <3622, 3630, 3623>,
    <3622, 3623, 3627>    <3622, 3627, 3624>,
    <3622, 3624, 3628>    <3622, 3628, 3625>,
    <3622, 3625, 3629>    <3622, 3629, 3626>,
    <3622, 3626, 3630>    <3631, 3639, 3632>,
    <3631, 3632, 3636>    <3631, 3636, 3633>,
    <3631, 3633, 3637>    <3631, 3637, 3634>,
    <3631, 3634, 3638>    <3631, 3638, 3635>,
    <3631, 3635, 3639>    <3640, 3648, 3641>,
    <3640, 3641, 3645>    <3640, 3645, 3642>,
    <3640, 3642, 3646>    <3640, 3646, 3643>,
    <3640, 3643, 3647>    <3640, 3647, 3644>,
    <3640, 3644, 3648>    <3649, 3657, 3650>,
    <3649, 3650, 3654>    <3649, 3654, 3651>,
    <3649, 3651, 3655>    <3649, 3655, 3652>,
    <3649, 3652, 3656>    <3649, 3656, 3653>,
    <3649, 3653, 3657>    <3658, 3666, 3659>,
    <3658, 3659, 3663>    <3658, 3663, 3660>,
    <3658, 3660, 3664>    <3658, 3664, 3661>,
    <3658, 3661, 3665>    <3658, 3665, 3662>,
    <3658, 3662, 3666>    <3667, 3675, 3668>,
    <3667, 3668, 3672>    <3667, 3672, 3669>,
    <3667, 3669, 3673>    <3667, 3673, 3670>,
    <3667, 3670, 3674>    <3667, 3674, 3671>,
    <3667, 3671, 3675>    <3676, 3684, 3677>,
    <3676, 3677, 3681>    <3676, 3681, 3678>,
    <3676, 3678, 3682>    <3676, 3682, 3679>,
    <3676, 3679, 3683>    <3676, 3683, 3680>,
    <3676, 3680, 3684>    <3685, 3693, 3686>,
    <3685, 3686, 3690>    <3685, 3690, 3687>,
    <3685, 3687, 3691>    <3685, 3691, 3688>,
    <3685, 3688, 3692>    <3685, 3692, 3689>,
    <3685, 3689, 3693>    <3694, 3702, 3695>,
    <3694, 3695, 3699>    <3694, 3699, 3696>,
    <3694, 3696, 3700>    <3694, 3700, 3697>,
    <3694, 3697, 3701>    <3694, 3701, 3698>,
    <3694, 3698, 3702>    <3703, 3711, 3704>,
    <3703, 3704, 3708>    <3703, 3708, 3705>,
    <3703, 3705, 3709>    <3703, 3709, 3706>,
    <3703, 3706, 3710>    <3703, 3710, 3707>,
    <3703, 3707, 3711>    <3712, 3720, 3713>,
    <3712, 3713, 3717>    <3712, 3717, 3714>,
    <3712, 3714, 3718>    <3712, 3718, 3715>,
    <3712, 3715, 3719>    <3712, 3719, 3716>,
    <3712, 3716, 3720>    <3721, 3729, 3722>,
    <3721, 3722, 3726>    <3721, 3726, 3723>,
    <3721, 3723, 3727>    <3721, 3727, 3724>,
    <3721, 3724, 3728>    <3721, 3728, 3725>,
    <3721, 3725, 3729>    <3730, 3738, 3731>,
    <3730, 3731, 3735>    <3730, 3735, 3732>,
    <3730, 3732, 3736>    <3730, 3736, 3733>,
    <3730, 3733, 3737>    <3730, 3737, 3734>,
    <3730, 3734, 3738>    <3739, 3747, 3740>,
    <3739, 3740, 3744>    <3739, 3744, 3741>,
    <3739, 3741, 3745>    <3739, 3745, 3742>,
    <3739, 3742, 3746>    <3739, 3746, 3743>,
    <3739, 3743, 3747>    <3748, 3756, 3749>,
    <3748, 3749, 3753>    <3748, 3753, 3750>,
    <3748, 3750, 3754>    <3748, 3754, 3751>,
    <3748, 3751, 3755>    <3748, 3755, 3752>,
    <3748, 3752, 3756>    <3757, 3765, 3758>,
    <3757, 3758, 3762>    <3757, 3762, 3759>,
    <3757, 3759, 3763>    <3757, 3763, 3760>,
    <3757, 3760, 3764>    <3757, 3764, 3761>,
    <3757, 3761, 3765>    <3766, 3774, 3767>,
    <3766, 3767, 3771>    <3766, 3771, 3768>,
    <3766, 3768, 3772>    <3766, 3772, 3769>,
    <3766, 3769, 3773>    <3766, 3773, 3770>,
    <3766, 3770, 3774>    <3775, 3783, 3776>,
    <3775, 3776, 3780>    <3775, 3780, 3777>,
    <3775, 3777, 3781>    <3775, 3781, 3778>,
    <3775, 3778, 3782>    <3775, 3782, 3779>,
    <3775, 3779, 3783>    <3784, 3792, 3785>,
    <3784, 3785, 3789>    <3784, 3789, 3786>,
    <3784, 3786, 3790>    <3784, 3790, 3787>,
    <3784, 3787, 3791>    <3784, 3791, 3788>,
    <3784, 3788, 3792>    <3793, 3801, 3794>,
    <3793, 3794, 3798>    <3793, 3798, 3795>,
    <3793, 3795, 3799>    <3793, 3799, 3796>,
    <3793, 3796, 3800>    <3793, 3800, 3797>,
    <3793, 3797, 3801>    <3802, 3810, 3803>,
    <3802, 3803, 3807>    <3802, 3807, 3804>,
    <3802, 3804, 3808>    <3802, 3808, 3805>,
    <3802, 3805, 3809>    <3802, 3809, 3806>,
    <3802, 3806, 3810>    <3811, 3819, 3812>,
    <3811, 3812, 3816>    <3811, 3816, 3813>,
    <3811, 3813, 3817>    <3811, 3817, 3814>,
    <3811, 3814, 3818>    <3811, 3818, 3815>,
    <3811, 3815, 3819>    <3820, 3828, 3821>,
    <3820, 3821, 3825>    <3820, 3825, 3822>,
    <3820, 3822, 3826>    <3820, 3826, 3823>,
    <3820, 3823, 3827>    <3820, 3827, 3824>,
    <3820, 3824, 3828>    <3829, 3837, 3830>,
    <3829, 3830, 3834>    <3829, 3834, 3831>,
    <3829, 3831, 3835>    <3829, 3835, 3832>,
    <3829, 3832, 3836>    <3829, 3836, 3833>,
    <3829, 3833, 3837>    <3838, 3846, 3839>,
    <3838, 3839, 3843>    <3838, 3843, 3840>,
    <3838, 3840, 3844>    <3838, 3844, 3841>,
    <3838, 3841, 3845>    <3838, 3845, 3842>,
    <3838, 3842, 3846>    <3847, 3855, 3848>,
    <3847, 3848, 3852>    <3847, 3852, 3849>,
    <3847, 3849, 3853>    <3847, 3853, 3850>,
    <3847, 3850, 3854>    <3847, 3854, 3851>,
    <3847, 3851, 3855>    <3856, 3864, 3857>,
    <3856, 3857, 3861>    <3856, 3861, 3858>,
    <3856, 3858, 3862>    <3856, 3862, 3859>,
    <3856, 3859, 3863>    <3856, 3863, 3860>,
    <3856, 3860, 3864>    <3865, 3873, 3866>,
    <3865, 3866, 3870>    <3865, 3870, 3867>,
    <3865, 3867, 3871>    <3865, 3871, 3868>,
    <3865, 3868, 3872>    <3865, 3872, 3869>,
    <3865, 3869, 3873>    <3874, 3882, 3875>,
    <3874, 3875, 3879>    <3874, 3879, 3876>,
    <3874, 3876, 3880>    <3874, 3880, 3877>,
    <3874, 3877, 3881>    <3874, 3881, 3878>,
    <3874, 3878, 3882>    <3883, 3891, 3884>,
    <3883, 3884, 3888>    <3883, 3888, 3885>,
    <3883, 3885, 3889>    <3883, 3889, 3886>,
    <3883, 3886, 3890>    <3883, 3890, 3887>,
    <3883, 3887, 3891>    <3892, 3900, 3893>,
    <3892, 3893, 3897>    <3892, 3897, 3894>,
    <3892, 3894, 3898>    <3892, 3898, 3895>,
    <3892, 3895, 3899>    <3892, 3899, 3896>,
    <3892, 3896, 3900>    <3901, 3909, 3902>,
    <3901, 3902, 3906>    <3901, 3906, 3903>,
    <3901, 3903, 3907>    <3901, 3907, 3904>,
    <3901, 3904, 3908>    <3901, 3908, 3905>,
    <3901, 3905, 3909>
  }
  photons {
    collect off
  }
  scale <1.0, 1.192135, 1.0>
}

#declare Goeland2 = union {
  object { Aile2 }
  object { // AileD2 -> Aile2
    Aile2
    photons {
      collect off
    }
    scale -1.0
    rotate -180.0*x
  }
  object { Bec2 }
  object { Oeil2 }
  object { // OeilD2 -> Oeil2
    Oeil2
    material {
      T_Oeil
    }
    photons {
      collect off
    }
    scale -1.0
    rotate <-179.859985, -1.234978, 13.581944>
    translate  <1.354105, 0.201074, -0.034>
  }
  object { Corps }
  photons {
    collect off
  }
  scale 0.026598
}




//
// ********  OBJECTS  *******
//



// Lightgroup_nuage
light_group{light_source{Soleil_nuage} object{Nuage} object{Nuage2}}



// Mer
#include "functions.inc"
#declare Sea=2; //0: rien , 1 : plan , 2 : iso
#declare Echelle=0.44;
#declare Warp_scale=1000;
#declare Scale_x=50*Echelle ;
#declare Scale_y=30*Echelle ;
#declare Damp=1 ;
#declare Lacunarity=3 ;
#declare Octave=6 ;
#declare Offset=1.5 ;
#declare Gain=1 ;
#declare H_houle=1.2;
#declare H_cretes=0.3;
#declare Wave_Height=4.5*Echelle ;
#declare Cretes=function{f_ridged_mf(x/Scale_x, y/Scale_y, 0,Damp,Lacunarity,Octave,Offset,Gain,1)} 
#declare F_bozo=function{pattern {bozo warp {turbulence <1,1,0>*0.4 omega 0}  scale <18,1,1>*100*Echelle}}
#declare F_bozo2=function{pattern {bozo warp {turbulence <1,1,0>*0.4 omega 0}  scale <16,1,1>*80*Echelle  rotate z*-20 }}
#declare Element_houle=function{F_bozo(x,y,0)-.5+F_bozo2(x,y,0)-.5}
#declare Houle2=function{
Element_houle(x,y,z)*1
+Element_houle(x*6,y*4,z*4)*.8
}

#declare T_eau=texture // free (without foam) sea texture
      {      
         pigment
         {
            color rgbt 1 
         } 
//normal{bumps 0.5 scale <1,0.3,1>}     
    
     finish
         {
            ambient 0
            
            specular 1
            roughness 0.0001
            conserve_energy
            reflection
            {
               0.0 ,3
               fresnel  on
             falloff 1
              exponent 1
               metallic 0.0
            }
         }

      }
      
#declare T_mousse=texture  // foam texture
        {pigment{
                color rgb 1 transmit .3
                }
         finish{ambient 0
                diffuse 1
                }
normal{bumps 0.1 scale 0.2}
        }
 
#declare P_img=
   pigment
   {
     cylindrical
      color_map
      {
         [0.0     rgb 1 ]
         [1  rgb 0 ]
      
      }

warp   { turbulence .02 lambda 7 }
      scale 200
    rotate 90.0 * x
 poly_wave 0.5     
   }


#declare F_img=function{pigment {P_img}}
#declare f_crackle_moi = function {pattern {crackle  warp {turbulence 0.65 lambda 3} scale <1,1,2>*2}} //turb 0.7
#declare F_var_crackle=function{
min(1, f_crackle_moi(x, y, z)*max(0,(F_img(x, y, z).gray)*40))} 


#declare M_Iso_Sea = 
   material  // M_Iso_Sea
   {  texture{
    function{F_var_crackle(x,y,z)}
    texture_map{
    
     [.35 T_mousse] //.4
     [.85 T_eau] //.5

    }
   } 
      
      interior
      {
         ior 1.333
         caustics 2.0
         media
         {
            samples 1,1
            absorption rgb <1.0, 0.1, 0.18>*2
            scattering
            {
               3 ,  rgb <1,1,0.9>*.15 
               extinction 1
            }
         }
      } 
   }
//Geometrie


#declare IsoMer=
isosurface {
   function {
                   z -(
                                                           Houle2(x,y,z)*H_houle 
                                                       +Cretes(x,y,z)*H_cretes  
)*Wave_Height
   }
   contained_by {box{<-1000,-40,Wave_Height*(H_houle+H_cretes)*-1.1>,<1000,1000,Wave_Height*(H_houle+H_cretes)*1.1>}}

   threshold 0
   accuracy 0.01
   max_gradient 3
   max_trace 1
   hollow

translate z*-2.5//-(H_houle+H_cretes)*Wave_Height/3
rotate z*10

}
 // end isosurface
#if(Sea=2)
object{IsoMer 
 material { M_Iso_Sea }
//texture{T_eau}

} 
#end

#if (Sea=1)
plane{z,-4 hollow  material{M_Iso_Sea}}
#end







// Macro_fenetre


#local S_pig=seed(10);
#local  Arr=0.01;
#local F=20;
#local A=0.008;

#local L_fenetre=.58;
#local H_fenetre=1.04;
#local H_pierre=.25;

#local Prof_chaine=0.3;
#local Larg_long=.3;
#local Larg_courte=.2;
#local Cnt=0;
#declare Trou_fenetre=box{<-L_fenetre/2-.03,-Prof_chaine*2,H_pierre-.03>,<L_fenetre/2+.03,Prof_chaine*2,H_pierre+H_fenetre+.03>}
#macro Fenetre()

object{ IsoRBoxN (<-(Larg_courte+L_fenetre/2),-0.03,0>,<(Larg_courte+L_fenetre/2),Prof_chaine, H_pierre>,Arr,F,A)texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}} //seuil
#declare Pierre_long=object{ IsoRBoxN (<-Larg_long,-0.03,0>,<0,Prof_chaine, H_pierre>,Arr,F,A)translate -x*L_fenetre/2}
#declare Pierre_court=object{ IsoRBoxN (<-Larg_courte,-0.03,0>,<0,Prof_chaine, H_pierre>,Arr,F,A) translate -x*L_fenetre/2}
object{Pierre_long translate z* H_pierre texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}} object{Pierre_long translate z* H_pierre scale <-1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
object{Pierre_court translate z* H_pierre*2 texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}} object{Pierre_court translate z* H_pierre*2 scale <-1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
object{Pierre_long  translate z* H_pierre*3 texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}} object{Pierre_long  translate z* H_pierre*3  scale <-1,1,1> texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
object{Pierre_court translate z* H_pierre*4 texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}} object{Pierre_court translate z* H_pierre*4  scale <-1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
#declare Pierre_voute1=difference{
object{ IsoRBoxN (<-(Larg_long+L_fenetre/2),-0.03,0>,<0,Prof_chaine, H_pierre>,Arr,F,A) translate <0,0,H_pierre*5>} 
box { <0,-Prof_chaine,0>,<.5,Prof_chaine+.004, 1.3>rotate y*-20 translate z* H_pierre*2 }
translate -x*0.01}
object {Pierre_voute1 texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
object {Pierre_voute1 scale<-1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
#declare Pierre_voute2=intersection{
object{ IsoRBoxN (<-(.362),-0.03,0>,<0,Prof_chaine, H_pierre*1.2>,Arr,F,A) translate <0,0,H_pierre*5>} 
difference{box { <0,-Prof_chaine,0>,<.5,Prof_chaine+.004, 1.3>rotate y*-20 translate z* H_pierre*2 }box { <0,-Prof_chaine,0>,<.5,Prof_chaine+.004, 1.3>rotate y*-12.7 translate z* .8 }}
translate -x*0.005}
object {Pierre_voute2 texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
object {Pierre_voute2 scale<-1,1,1> texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
#declare Pierre_voute3=intersection{
object{ IsoRBoxN (<-L_fenetre/2,-0.03,0>,<L_fenetre/2,Prof_chaine, H_pierre*1.4>,Arr,F,A) translate <0,0,H_pierre*5>} 
difference{box { <0,-Prof_chaine,0>,<.5,Prof_chaine+.004, 1.3>rotate y*-12.7 translate z* .8 }box { <0,-Prof_chaine,0>,<.5,Prof_chaine+.004, 1.3>rotate y*12.7 translate z* .8 }}
}
object {Pierre_voute3 texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
#end 
//Fenetre()



// Macro_moulure
#macro M_moulure(R,Ht)
#local X_coin=R*0.4142;
union{
object{Moulure_pleine translate <0,R,Ht>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
union{
object{Moulure_coin translate<X_coin,R,Ht>}
object{Moulure_coin translate<X_coin,R,Ht>scale<-1,1,1> rotate z*-45}texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}
}
object{Moulure_pleine translate <0,R,Ht> scale<-1,1,1>texture{M_granite  finish{diffuse 0.6+(rand(S_pig)>0.4)*.1}}}
}
#end

#macro Tour_moulure(R,Ht)
#declare Cnt_tour=0;

#while (Cnt_tour<8)
object{ M_moulure(R,Ht) rotate z*45*Cnt_tour}
#declare Cnt_tour=Cnt_tour+1;
#end

#end



// Appel_macros_tour
#declare R1=-2.3;

#declare Bs=8;
#declare R2=-2.0;

#declare Ht=18.4;

union{

Tour_empierre(R1,R2,Bs,Ht,0.01,"01111111")
Fenetre_murs()
Tour_chainage(R1,R2,Bs,Ht)

Tour_moulure(R2-0.08,Ht)

Tour_Corbeau(R2-.55,19.2)
Tour_empierre(R2-.17,-2.17,18.6,19.2,0.01,"11111111")
Tour_soleplate(R2-.58,19.2)
Tour_solehaute(R2-.56,19.3)
Tour_empierre(R2-.55,-2.55,19.3,21.3,0.01"01011101")
Fenetre_murs2(-2.55)
Tour_chainage(R2-.55,-2.55,19.3,21.2)
Tour_chanfrein (R2-.65,21.35)

}


object { // Nuage1 -> Nuage
  Nuage
  // Nuage1 does not inherit transformations, so do 
  // inverse transformations of Nuage
    translate  <61.497792, -507.098275, -84.312721>
    rotate -13.802025*z
    scale <1.0/353.023529, 1.0/550.656616, 1.0/258.17923>
    translate  -0.17*z
    rotate 0.0*z rotate 0.0*y rotate 0.0*x
    scale <1.0/0.9, 1.0/0.8, 1.0/0.5>
  // Now write the regular transformations of Nuage1
  rotate <-0.0, -0.0, 0.0>
  translate  <-191.807234, 364.285469, 183.777559>
}




union { // Nuages_soleil
  sphere { // Ciel1
    <0,0,0>,1
    material {
      M_ciel_bouchxE9_1
      scale <1.0, 1.0, 0.1>
      translate <0.000000, 0.000000, 0.900000>
    }
    no_shadow
    double_illuminate
    hollow
    photons {
      pass_through
    }
    scale 1000.0
  }
  object { Soleil }
  object { Soleil_nuage }
  rotate <-46.095371, 62.739456, -72.975426>
}


#declare Bouton_porte = lathe {
  quadratic_spline
  8  // control points
  <0.279904, -0.329001>,
  <0.327807, 0.020093>,
  <0.300808, 0.338546>,
  <1.202379, 0.467492>,
  <1.383504, 0.861543>,
  <0.838026, 1.300241>,
  <0.658002, 1.645608>,
  <0.016366, 1.867389>
  rotate <90,0,90>
  material {
    T_bronze
  }
  scale 0.02
  rotate 90.0*x
  translate  <0.297729, -1.885371, 5.992815>
}
#declare Porte = union {
  object { // Cube079 -> Cube036
    Cube036
    material {
      T_peinture_Bois_Bleu
    }
    rotate -0.0*x
    translate  0.022529*y
  }
  object { Moulures_porte }
  object { // Moulures_porte1 -> Moulures_porte
    Moulures_porte
    translate  -0.788421*z
  }
  object { Bouton_porte }
}
#declare Ouverture_porte = difference {
  box { // Cube035
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  0.5*z
    scale <1.1, 0.05, 2.3>
    translate  <0.0, -1.869294, 4.966013>
  }
  object { Cube036 }
  material {
    T_peinture_Bois_Bleu
  }
}
#declare Dormant_porte = union {
  object { Ouverture_porte }
  object { Cube080 }
  object { // Cube081 -> Cube080
    Cube080
    scale <-1.0, 1.0, 1.0>
  }
  box { // Cube082
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    material {
      T_peinture_Bois
    }
    scale <0.02, 0.07, 1.2>
    rotate 90.0*y
    translate  <0.0, -1.869294, 6.874979>
  }
}
#declare Ensemble_porte = union {
  object { Porte }
  object { Dormant_porte }
  translate  -0.326815*y
}
#declare TMesh001 = mesh2 {
  vertex_vectors {
    96,
    <-1.0883941, -2.5983288, 0.0019875>,
    <-0.9909295, -2.3648551, 3.1482237>,
    <1.0775622, -2.5897025, 0.0019875>,
    <0.9806251, -2.3570030, 3.1482237>,
    <2.5983467, -1.0881666, 0.0019875>,
    <2.3649142, -0.9902349, 3.1482237>,
    <2.5981388, 1.0603225, 0.0019875>,
    <2.3647249, 0.9654203, 3.1482237>,
    <1.0881845, 2.5985742, 0.0019875>,
    <0.9902940, 2.3656089, 3.1482237>,
    <-1.0968456, 2.5899479, 0.0019875>,
    <-0.9986224, 2.3577568, 3.1482237>,
    <-2.5985564, 1.0884120, 0.0019875>,
    <-2.3655497, 0.9909887, 3.1482237>,
    <-2.5981703, -1.0374254, 0.0019875>,
    <-2.3651983, -0.9440479, 3.1482237>,
    <-0.9574582, 2.2604489, 3.2237167>,
    <-2.2678998, 0.9501600, 3.2237167>,
    <-2.2675629, -0.9049148, 3.2237167>,
    <-0.9500832, -2.2670098, 3.2237167>,
    <0.9400006, -2.2594821, 3.2237167>,
    <0.9492700, 2.2679766, 3.2237167>,
    <2.2670866, -0.9491932, 3.2237167>,
    <2.2669051, 0.9256482, 3.2237167>,
    <-1.0480763, -2.6084563, 0.0228570>,
    <1.0371158, -2.6001516, 0.0228570>,
    <0.9427801, -2.3733594, 3.0952115>,
    <-0.9532261, -2.3809106, 3.0952115>,
    <1.1135787, -2.5685869, 0.0228562>,
    <2.5768110, -1.1238748, 0.0228562>,
    <2.3494046, -1.0283309, 3.0952123>,
    <1.0190031, -2.3418935, 3.0952123>,
    <2.6085969, -1.0478119, 0.0228566>,
    <2.6083968, 1.0198438, 0.0228566>,
    <2.3809090, 0.9274911, 3.0952119>,
    <2.3810909, -0.9525066, 3.0952119>,
    <2.5770978, 1.0963983, 0.0228570>,
    <1.1237491, 2.5769837, 0.0228570>,
    <1.0282459, 2.3500329, 3.0952115>,
    <2.3497083, 1.0038055, 3.0952115>,
    <1.0477787, 2.6086890, 0.0228576>,
    <-1.0565618, 2.6003812, 0.0228576>,
    <-0.9609723, 2.3740846, 3.0952109>,
    <0.9525138, 2.3816389, 3.0952109>,
    <-1.1328267, 2.5686180, 0.0228563>,
    <-2.5773075, 1.1243054, 0.0228563>,
    <-2.3503153, 1.0292564, 3.0952122>,
    <-1.0369980, 2.3424207, 3.0952122>,
    <-2.6088904, 1.0480433, 0.0228571>,
    <-2.6085190, -0.9968720, 0.0228571>,
    <-2.3814616, -0.9060052, 3.0952114>,
    <-2.3817992, 0.9532335, 3.0952114>,
    <-2.5774522, -1.0736549, 0.0228579>,
    <-1.1238115, -2.5765219, 0.0228579>,
    <-1.0287239, -2.3490764, 3.0952106>,
    <-2.3504924, -0.9825474, 3.0952106>,
    <-1.0222378, 2.3022631, 3.1667540>,
    <-2.3099838, 1.0146670, 3.1667540>,
    <-2.2821184, 1.0030161, 3.1882967>,
    <-1.0104911, 2.2744953, 3.1882967>,
    <-2.3430089, 0.9346660, 3.1668018>,
    <-2.3426778, -0.8883015, 3.1668018>,
    <-2.3149402, -0.8771840, 3.1882489>,
    <-2.3152671, 0.9230668, 3.1882489>,
    <-2.3100961, -0.9685856, 3.1668467>,
    <-1.0141982, -2.3083680, 3.1668467>,
    <-1.0026427, -2.2806872, 3.1882040>,
    <-2.2824747, -0.9575147, 3.1882040>,
    <-0.9346126, -2.3420425, 3.1667949>,
    <0.9243664, -2.3346387, 3.1667949>,
    <0.9128179, -2.3069159, 3.1882558>,
    <-0.9230010, -2.3142274, 3.1882558>,
    <0.9337835, 2.3428073, 3.1668320>,
    <-0.9422573, 2.3354008, 3.1668320>,
    <-0.9305958, 2.3078341, 3.1882187>,
    <0.9221616, 2.3151487, 3.1882187>,
    <1.0044617, -2.3016729, 3.1667503>,
    <2.3089509, -1.0136946, 3.1667503>,
    <2.2810253, -1.0019790, 3.1883004>,
    <0.9928652, -2.2738349, 3.1883004>,
    <2.3422712, -0.9338540, 3.1667702>,
    <2.3420928, 0.9094850, 3.1667702>,
    <2.3142209, 0.8981527, 3.1882805>,
    <2.3143970, -0.9221600, 3.1882805>,
    <2.3092668, 0.9896289, 3.1667972>,
    <1.0136043, 2.3095730, 3.1667972>,
    <1.0019446, 2.2818242, 3.1882535>,
    <2.2814648, 0.9783250, 3.1882535>,
    <-0.5042125, -2.5916721, 0.1508691>,
    <0.4933553, -2.5791955, 0.1508691>,
    <0.4966280, -2.4348609, 2.3738188>,
    <-0.5072008, -2.4463356, 2.3738188>,
    <-0.5190225, -1.3479976, 0.1469110>,
    <0.4785453, -1.3359096, 0.1480417>,
    <0.4818179, -1.3280845, 2.3804681>,
    <-0.5220108, -1.3392018, 2.3794282>
  }
  normal_vectors {
    94,
    <0.7006664, -0.7096485, 0.0739298>,
    <0.9972698, 0.0000965, 0.0738442>,
    <0.7116981, 0.6986058, 0.0737280>,
    <-0.0039372, 0.9972817, 0.0735781>,
    <-0.7051315, 0.7052136, 0.0739137>,
    <-0.9972799, -0.0001811, 0.0737077>,
    <-0.7168357, -0.6933558, 0.0735146>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.4317246, 0.4317748, 0.7919497>,
    <-0.6116604, -0.0001111, 0.7911204>,
    <-0.4403756, -0.4259511, 0.7903385>,
    <0.0024354, -0.6115015, 0.7912396>,
    <-0.0024175, 0.6123343, 0.7905953>,
    <0.4289339, -0.4344325, 0.7920127>,
    <0.6109508, 0.0000591, 0.7916685>,
    <0.4364314, 0.4284029, 0.7912007>,
    <0.0035722, -0.8969288, -0.4421605>,
    <0.2994916, -0.9507770, 0.0795481>,
    <0.0038087, -0.9563067, 0.2923405>,
    <-0.2814488, -0.9562623, 0.0796804>,
    <0.6302800, -0.6383598, -0.4418641>,
    <0.8794861, -0.4691770, 0.0798567>,
    <0.6718720, -0.6804849, 0.2924523>,
    <0.4694800, -0.8793565, 0.0795032>,
    <0.8975094, 0.0000869, -0.4409954>,
    <0.9521486, 0.2951043, 0.0795397>,
    <0.9564406, 0.0000926, 0.2919268>,
    <0.9555219, -0.2839377, 0.0797322>,
    <0.6404799, 0.6286978, -0.4410494>,
    <0.4717261, 0.8781358, 0.0796993>,
    <0.6825823, 0.6700256, 0.2917996>,
    <0.8803962, 0.4675418, 0.0794179>,
    <-0.0035420, 0.8971686, -0.4416741>,
    <-0.3002504, 0.9505397, 0.0795231>,
    <-0.0037760, 0.9564416, 0.2918994>,
    <0.2805423, 0.9565390, 0.0795563>,
    <-0.6333477, 0.6334214, -0.4445762>,
    <-0.8832574, 0.4620616, 0.0797208>,
    <-0.6758773, 0.6759561, 0.2937230>,
    <-0.4737956, 0.8770375, 0.0795166>,
    <-0.8960264, -0.0001627, -0.4440007>,
    <-0.9517641, -0.2964132, 0.0792734>,
    <-0.9560579, -0.0001736, 0.2931779>,
    <-0.9550346, 0.2856170, 0.0795729>,
    <-0.6446029, -0.6234889, -0.4424349>,
    <-0.4772017, -0.8751698, 0.0797268>,
    <-0.6874159, -0.6648996, 0.2921780>,
    <-0.8843238, -0.4601180, 0.0791382>,
    <-0.4489686, 0.4490209, 0.7725332>,
    <-0.4418920, 0.4143162, 0.7956592>,
    <-0.4230692, 0.4231185, 0.8012385>,
    <-0.4143149, 0.4419801, 0.7956109>,
    <-0.6361868, -0.0001155, 0.7715350>,
    <-0.6065849, -0.0198181, 0.7947717>,
    <-0.5993355, -0.0001088, 0.8004979>,
    <-0.6063926, 0.0195238, 0.7949257>,
    <-0.4577404, -0.4427472, 0.7710050>,
    <-0.4231216, -0.4361341, 0.7942010>,
    <-0.4316330, -0.4174949, 0.7996193>,
    <-0.4502394, -0.4084377, 0.7940171>,
    <0.0025293, -0.6350756, 0.7724458>,
    <0.0213110, -0.6064327, 0.7948492>,
    <0.0023882, -0.5996390, 0.8002671>,
    <-0.0164799, -0.6064617, 0.7949419>,
    <-0.0025109, 0.6359964, 0.7716880>,
    <-0.0214069, 0.6071653, 0.7942871>,
    <-0.0023704, 0.6004166, 0.7996839>,
    <0.0165416, 0.6072578, 0.7943327>,
    <0.4451226, -0.4508288, 0.7737049>,
    <0.4385889, -0.4179713, 0.7955751>,
    <0.4207910, -0.4261853, 0.8008127>,
    <0.4123797, -0.4440151, 0.7954832>,
    <0.6337467, 0.0000613, 0.7735406>,
    <0.6061697, 0.0183755, 0.7951230>,
    <0.5994734, 0.0000580, 0.8003947>,
    <0.6060370, -0.0182013, 0.7952282>,
    <0.4528860, 0.4445548, 0.7728294>,
    <0.4199220, 0.4381254, 0.7948029>,
    <0.4281439, 0.4202679, 0.8000423>,
    <0.4459144, 0.4117805, 0.7947309>,
    <0.0039192, -0.9840689, 0.1777443>,
    <0.0175665, -0.9970930, 0.0741419>,
    <0.0039655, -0.9956813, 0.0927527>,
    <0.0134892, -0.9972085, 0.0734391>,
    <0.0121126, -0.9999206, 0.0034872>,
    <-0.0000284, 0.0022737, 0.9999974>,
    <-0.9999076, -0.0133940, 0.0023417>,
    <-0.0000579, 0.0050657, -0.9999872>,
    <0.9999289, 0.0119092, 0.0005656>
  }
  uv_vectors {
    376,
    <0.0076743, 0.1952564>,
    <0.2845723, 0.1952564>,
    <0.3028846, 0.7841138>,
    <0.0511230, 0.7841138>,
    <0.2991508, 0.1952565>,
    <0.6954442, 0.1952565>,
    <0.6777436, 0.7841137>,
    <0.3174173, 0.7841137>,
    <0.7101168, 0.1952565>,
    <0.9938905, 0.1952565>,
    <0.9503924, 0.7841137>,
    <0.6923702, 0.7841137>,
    <0.9922871, 0.1952564>,
    <0.7154656, 0.1952564>,
    <0.6972482, 0.7841138>,
    <0.9489334, 0.7841138>,
    <0.7008490, 0.1952566>,
    <0.3089141, 0.1952566>,
    <0.3263299, 0.7841136>,
    <0.6826774, 0.7841136>,
    <0.2941976, 0.1952567>,
    <0.0061534, 0.1952567>,
    <0.0497463, 0.7841135>,
    <0.3116596, 0.7841135>,
    <0.0654755, 0.8087434>,
    <0.9332225, 0.8087434>,
    <0.6820884, 0.8087434>,
    <0.3265389, 0.8087434>,
    <0.0019738, 0.1912566>,
    <0.3011415, 0.1912566>,
    <0.7085862, 0.1912566>,
    <0.9963753, 0.1912566>,
    <0.0654755, 0.8087434>,
    <0.0669183, 0.8087434>,
    <0.9346652, 0.8087434>,
    <0.9332225, 0.8087434>,
    <0.0669183, 0.8087434>,
    <0.3180524, 0.8087434>,
    <0.6773903, 0.8087434>,
    <0.9346652, 0.8087434>,
    <0.0036272, 0.1912566>,
    <0.9980286, 0.1912566>,
    <0.7032024, 0.1912566>,
    <0.2914163, 0.1912566>,
    <0.9412367, 0.7978257>,
    <0.6944520, 0.7978257>,
    <0.6922189, 0.8019547>,
    <0.9359146, 0.8019547>,
    <0.6791187, 0.7978349>,
    <0.3297231, 0.7978349>,
    <0.3318539, 0.8019455>,
    <0.6768956, 0.8019455>,
    <0.3143355, 0.7978435>,
    <0.0575486, 0.7978435>,
    <0.0628540, 0.8019369>,
    <0.3164574, 0.8019369>,
    <0.0510945, 0.7978336>,
    <0.0525135, 0.7978336>,
    <0.0578270, 0.8019468>,
    <0.0564256, 0.8019468>,
    <0.9490075, 0.7978407>,
    <0.9475880, 0.7978407>,
    <0.9423044, 0.8019397>,
    <0.9437064, 0.8019397>,
    <0.0588318, 0.7978250>,
    <0.3056898, 0.7978250>,
    <0.3079353, 0.8019554>,
    <0.0641674, 0.8019554>,
    <0.3209923, 0.7978288>,
    <0.6742925, 0.7978288>,
    <0.6721205, 0.8019516>,
    <0.3232336, 0.8019516>,
    <0.6896531, 0.7978340>,
    <0.9426377, 0.7978340>,
    <0.9373193, 0.8019464>,
    <0.6874865, 0.8019464>,
    <0.0036272, 0.1912566>,
    <0.0482271, 0.7942741>,
    <0.0450922, 0.7841137>,
    <0.0016245, 0.1952565>,
    <0.0482271, 0.7942741>,
    <0.0467222, 0.7942741>,
    <0.0436449, 0.7841137>,
    <0.0450922, 0.7841137>,
    <0.0467222, 0.7942741>,
    <0.0019738, 0.1912566>,
    <0.0000328, 0.1952565>,
    <0.0436449, 0.7841137>,
    <0.0036272, 0.1912566>,
    <0.2914163, 0.1912566>,
    <0.2845723, 0.1952564>,
    <0.0076743, 0.1952564>,
    <0.2914163, 0.1912566>,
    <0.3101862, 0.7942741>,
    <0.3028846, 0.7841138>,
    <0.2845723, 0.1952564>,
    <0.3101862, 0.7942741>,
    <0.0482271, 0.7942741>,
    <0.0511230, 0.7841138>,
    <0.3028846, 0.7841138>,
    <0.0482271, 0.7942741>,
    <0.0036272, 0.1912566>,
    <0.0076743, 0.1952564>,
    <0.0511230, 0.7841138>,
    <0.2914163, 0.1912566>,
    <0.7032024, 0.1912566>,
    <0.6954442, 0.1952565>,
    <0.2991508, 0.1952565>,
    <0.7032024, 0.1912566>,
    <0.6850132, 0.7942741>,
    <0.6777436, 0.7841137>,
    <0.6954442, 0.1952565>,
    <0.6850132, 0.7942741>,
    <0.3101862, 0.7942741>,
    <0.3174173, 0.7841137>,
    <0.6777436, 0.7841137>,
    <0.3101862, 0.7942741>,
    <0.2914163, 0.1912566>,
    <0.2991508, 0.1952565>,
    <0.3174173, 0.7841137>,
    <0.7032024, 0.1912566>,
    <0.9980286, 0.1912566>,
    <0.9938905, 0.1952565>,
    <0.7101168, 0.1952565>,
    <0.9980286, 0.1912566>,
    <0.9533777, 0.7942741>,
    <0.9503924, 0.7841137>,
    <0.9938905, 0.1952565>,
    <0.9533777, 0.7942741>,
    <0.6850132, 0.7942741>,
    <0.6923702, 0.7841137>,
    <0.9503924, 0.7841137>,
    <0.6850132, 0.7942741>,
    <0.7032024, 0.1912566>,
    <0.7101168, 0.1952565>,
    <0.6923702, 0.7841137>,
    <0.9963753, 0.1912566>,
    <0.9518728, 0.7942741>,
    <0.9550022, 0.7841135>,
    <0.9983749, 0.1952567>,
    <0.9518728, 0.7942741>,
    <0.9533777, 0.7942741>,
    <0.9564501, 0.7841135>,
    <0.9550022, 0.7841135>,
    <0.9533777, 0.7942741>,
    <0.9980286, 0.1912566>,
    <0.9999672, 0.1952567>,
    <0.9564501, 0.7841135>,
    <0.9963753, 0.1912566>,
    <0.7085862, 0.1912566>,
    <0.7154656, 0.1952564>,
    <0.9922871, 0.1952564>,
    <0.7085862, 0.1912566>,
    <0.6899137, 0.7942741>,
    <0.6972482, 0.7841138>,
    <0.7154656, 0.1952564>,
    <0.6899137, 0.7942741>,
    <0.9518728, 0.7942741>,
    <0.9489334, 0.7841138>,
    <0.6972482, 0.7841138>,
    <0.9518728, 0.7942741>,
    <0.9963753, 0.1912566>,
    <0.9922871, 0.1952564>,
    <0.9489334, 0.7841138>,
    <0.7085862, 0.1912566>,
    <0.3011415, 0.1912566>,
    <0.3089141, 0.1952566>,
    <0.7008490, 0.1952566>,
    <0.3011415, 0.1912566>,
    <0.3190385, 0.7942741>,
    <0.3263299, 0.7841136>,
    <0.3089141, 0.1952566>,
    <0.3190385, 0.7942741>,
    <0.6899137, 0.7942741>,
    <0.6826774, 0.7841136>,
    <0.3263299, 0.7841136>,
    <0.6899137, 0.7942741>,
    <0.7085862, 0.1912566>,
    <0.7008490, 0.1952566>,
    <0.6826774, 0.7841136>,
    <0.3011415, 0.1912566>,
    <0.0019738, 0.1912566>,
    <0.0061534, 0.1952567>,
    <0.2941976, 0.1952567>,
    <0.0019738, 0.1912566>,
    <0.0467222, 0.7942741>,
    <0.0497463, 0.7841135>,
    <0.0061534, 0.1952567>,
    <0.0467222, 0.7942741>,
    <0.3190385, 0.7942741>,
    <0.3116596, 0.7841135>,
    <0.0497463, 0.7841135>,
    <0.3190385, 0.7942741>,
    <0.3011415, 0.1912566>,
    <0.2941976, 0.1952567>,
    <0.3116596, 0.7841135>,
    <0.9518728, 0.7942741>,
    <0.6899137, 0.7942741>,
    <0.6944520, 0.7978257>,
    <0.9412367, 0.7978257>,
    <0.6899137, 0.7942741>,
    <0.6820884, 0.8087434>,
    <0.6922189, 0.8019547>,
    <0.6944520, 0.7978257>,
    <0.6820884, 0.8087434>,
    <0.9332225, 0.8087434>,
    <0.9359146, 0.8019547>,
    <0.6922189, 0.8019547>,
    <0.9332225, 0.8087434>,
    <0.9518728, 0.7942741>,
    <0.9412367, 0.7978257>,
    <0.9359146, 0.8019547>,
    <0.6899137, 0.7942741>,
    <0.3190385, 0.7942741>,
    <0.3297231, 0.7978349>,
    <0.6791187, 0.7978349>,
    <0.3190385, 0.7942741>,
    <0.3265389, 0.8087434>,
    <0.3318539, 0.8019455>,
    <0.3297231, 0.7978349>,
    <0.3265389, 0.8087434>,
    <0.6820884, 0.8087434>,
    <0.6768956, 0.8019455>,
    <0.3318539, 0.8019455>,
    <0.6820884, 0.8087434>,
    <0.6899137, 0.7942741>,
    <0.6791187, 0.7978349>,
    <0.6768956, 0.8019455>,
    <0.3190385, 0.7942741>,
    <0.0467222, 0.7942741>,
    <0.0575486, 0.7978435>,
    <0.3143355, 0.7978435>,
    <0.0467222, 0.7942741>,
    <0.0654755, 0.8087434>,
    <0.0628540, 0.8019369>,
    <0.0575486, 0.7978435>,
    <0.0654755, 0.8087434>,
    <0.3265389, 0.8087434>,
    <0.3164574, 0.8019369>,
    <0.0628540, 0.8019369>,
    <0.3265389, 0.8087434>,
    <0.3190385, 0.7942741>,
    <0.3143355, 0.7978435>,
    <0.3164574, 0.8019369>,
    <0.0467222, 0.7942741>,
    <0.0482271, 0.7942741>,
    <0.0525135, 0.7978336>,
    <0.0510945, 0.7978336>,
    <0.0482271, 0.7942741>,
    <0.0669183, 0.8087434>,
    <0.0578270, 0.8019468>,
    <0.0525135, 0.7978336>,
    <0.0669183, 0.8087434>,
    <0.0654755, 0.8087434>,
    <0.0564256, 0.8019468>,
    <0.0578270, 0.8019468>,
    <0.0654755, 0.8087434>,
    <0.0467222, 0.7942741>,
    <0.0510945, 0.7978336>,
    <0.0564256, 0.8019468>,
    <0.9533777, 0.7942741>,
    <0.9518728, 0.7942741>,
    <0.9475880, 0.7978407>,
    <0.9490075, 0.7978407>,
    <0.9518728, 0.7942741>,
    <0.9332225, 0.8087434>,
    <0.9423044, 0.8019397>,
    <0.9475880, 0.7978407>,
    <0.9332225, 0.8087434>,
    <0.9346652, 0.8087434>,
    <0.9437064, 0.8019397>,
    <0.9423044, 0.8019397>,
    <0.9346652, 0.8087434>,
    <0.9533777, 0.7942741>,
    <0.9490075, 0.7978407>,
    <0.9437064, 0.8019397>,
    <0.0482271, 0.7942741>,
    <0.3101862, 0.7942741>,
    <0.3056898, 0.7978250>,
    <0.0588318, 0.7978250>,
    <0.3101862, 0.7942741>,
    <0.3180524, 0.8087434>,
    <0.3079353, 0.8019554>,
    <0.3056898, 0.7978250>,
    <0.3180524, 0.8087434>,
    <0.0669183, 0.8087434>,
    <0.0641674, 0.8019554>,
    <0.3079353, 0.8019554>,
    <0.0669183, 0.8087434>,
    <0.0482271, 0.7942741>,
    <0.0588318, 0.7978250>,
    <0.0641674, 0.8019554>,
    <0.3101862, 0.7942741>,
    <0.6850132, 0.7942741>,
    <0.6742925, 0.7978288>,
    <0.3209923, 0.7978288>,
    <0.6850132, 0.7942741>,
    <0.6773903, 0.8087434>,
    <0.6721205, 0.8019516>,
    <0.6742925, 0.7978288>,
    <0.6773903, 0.8087434>,
    <0.3180524, 0.8087434>,
    <0.3232336, 0.8019516>,
    <0.6721205, 0.8019516>,
    <0.3180524, 0.8087434>,
    <0.3101862, 0.7942741>,
    <0.3209923, 0.7978288>,
    <0.3232336, 0.8019516>,
    <0.6850132, 0.7942741>,
    <0.9533777, 0.7942741>,
    <0.9426377, 0.7978340>,
    <0.6896531, 0.7978340>,
    <0.9533777, 0.7942741>,
    <0.9346652, 0.8087434>,
    <0.9373193, 0.8019464>,
    <0.9426377, 0.7978340>,
    <0.9346652, 0.8087434>,
    <0.6773903, 0.8087434>,
    <0.6874865, 0.8019464>,
    <0.9373193, 0.8019464>,
    <0.6773903, 0.8087434>,
    <0.6850132, 0.7942741>,
    <0.6896531, 0.7978340>,
    <0.6874865, 0.8019464>,
    <0.0032497, 0.2197917>,
    <0.0056410, 0.2197917>,
    <0.2439331, 0.2192498>,
    <0.2416162, 0.2190331>,
    <0.0056410, 0.2197917>,
    <0.0333046, 0.6458493>,
    <0.2454329, 0.6471237>,
    <0.2439331, 0.2192498>,
    <0.0333046, 0.6458493>,
    <0.0311053, 0.6458493>,
    <0.2433021, 0.6469244>,
    <0.2454329, 0.6471237>,
    <0.0311053, 0.6458493>,
    <0.0032497, 0.2197917>,
    <0.2416162, 0.2190331>,
    <0.2433021, 0.6469244>,
    <0.7016638, 0.2075523>,
    <0.2983128, 0.2075523>,
    <0.3166350, 0.7964478>,
    <0.6834038, 0.7964478>,
    <0.2922114, 0.2035521>,
    <0.2905914, 0.2035521>,
    <0.7094086, 0.2035521>,
    <0.7073726, 0.2035521>,
    <0.2922114, 0.2035521>,
    <0.7073726, 0.2035521>,
    <0.6996200, 0.2075522>,
    <0.2999393, 0.2075522>,
    <0.7094086, 0.2035521>,
    <0.2905914, 0.2035521>,
    <0.2983128, 0.2075523>,
    <0.7016638, 0.2075523>,
    <0.2999393, 0.2075522>,
    <0.6996200, 0.2075522>,
    <0.5953943, 0.2320890>,
    <0.4041848, 0.2320890>,
    <0.6996200, 0.2075522>,
    <0.6815381, 0.7964479>,
    <0.5960216, 0.6581745>,
    <0.5953943, 0.2320890>,
    <0.6815381, 0.7964479>,
    <0.3181198, 0.7964479>,
    <0.4036120, 0.6581745>,
    <0.5960216, 0.6581745>,
    <0.3181198, 0.7964479>,
    <0.2999393, 0.2075522>,
    <0.4041848, 0.2320890>,
    <0.4036120, 0.6581745>,
    <0.4013461, 0.2313304>,
    <0.5925556, 0.2315471>,
    <0.5931829, 0.6594490>,
    <0.4007733, 0.6592497>
  }
  texture_list {
    1,
    texture { T_Ciment }
  }
  face_indices {
    188,   // 0 triangles and 94 quads
    <28, 29, 30>, 0,
    <28, 30, 31>, 0,
    <32, 33, 34>, 0,
    <32, 34, 35>, 0,
    <36, 37, 38>, 0,
    <36, 38, 39>, 0,
    <40, 41, 42>, 0,
    <40, 42, 43>, 0,
    <44, 45, 46>, 0,
    <44, 46, 47>, 0,
    <48, 49, 50>, 0,
    <48, 50, 51>, 0,
    <52, 53, 54>, 0,
    <52, 54, 55>, 0,
    <19, 16, 17>, 0,
    <19, 17, 18>, 0,
    <0, 14, 12>, 0,
    <0, 12, 10>, 0,
    <19, 20, 21>, 0,
    <19, 21, 16>, 0,
    <20, 22, 23>, 0,
    <20, 23, 21>, 0,
    <2, 8, 6>, 0,
    <2, 6, 4>, 0,
    <0, 10, 8>, 0,
    <0, 8, 2>, 0,
    <56, 57, 58>, 0,
    <56, 58, 59>, 0,
    <60, 61, 62>, 0,
    <60, 62, 63>, 0,
    <64, 65, 66>, 0,
    <64, 66, 67>, 0,
    <68, 69, 70>, 0,
    <68, 70, 71>, 0,
    <72, 73, 74>, 0,
    <72, 74, 75>, 0,
    <76, 77, 78>, 0,
    <76, 78, 79>, 0,
    <80, 81, 82>, 0,
    <80, 82, 83>, 0,
    <84, 85, 86>, 0,
    <84, 86, 87>, 0,
    <0, 2, 25>, 0,
    <0, 25, 24>, 0,
    <2, 3, 26>, 0,
    <2, 26, 25>, 0,
    <3, 1, 27>, 0,
    <3, 27, 26>, 0,
    <1, 0, 24>, 0,
    <1, 24, 27>, 0,
    <2, 4, 29>, 0,
    <2, 29, 28>, 0,
    <4, 5, 30>, 0,
    <4, 30, 29>, 0,
    <5, 3, 31>, 0,
    <5, 31, 30>, 0,
    <3, 2, 28>, 0,
    <3, 28, 31>, 0,
    <4, 6, 33>, 0,
    <4, 33, 32>, 0,
    <6, 7, 34>, 0,
    <6, 34, 33>, 0,
    <7, 5, 35>, 0,
    <7, 35, 34>, 0,
    <5, 4, 32>, 0,
    <5, 32, 35>, 0,
    <6, 8, 37>, 0,
    <6, 37, 36>, 0,
    <8, 9, 38>, 0,
    <8, 38, 37>, 0,
    <9, 7, 39>, 0,
    <9, 39, 38>, 0,
    <7, 6, 36>, 0,
    <7, 36, 39>, 0,
    <8, 10, 41>, 0,
    <8, 41, 40>, 0,
    <10, 11, 42>, 0,
    <10, 42, 41>, 0,
    <11, 9, 43>, 0,
    <11, 43, 42>, 0,
    <9, 8, 40>, 0,
    <9, 40, 43>, 0,
    <10, 12, 45>, 0,
    <10, 45, 44>, 0,
    <12, 13, 46>, 0,
    <12, 46, 45>, 0,
    <13, 11, 47>, 0,
    <13, 47, 46>, 0,
    <11, 10, 44>, 0,
    <11, 44, 47>, 0,
    <12, 14, 49>, 0,
    <12, 49, 48>, 0,
    <14, 15, 50>, 0,
    <14, 50, 49>, 0,
    <15, 13, 51>, 0,
    <15, 51, 50>, 0,
    <13, 12, 48>, 0,
    <13, 48, 51>, 0,
    <14, 0, 53>, 0,
    <14, 53, 52>, 0,
    <0, 1, 54>, 0,
    <0, 54, 53>, 0,
    <1, 15, 55>, 0,
    <1, 55, 54>, 0,
    <15, 14, 52>, 0,
    <15, 52, 55>, 0,
    <11, 13, 57>, 0,
    <11, 57, 56>, 0,
    <13, 17, 58>, 0,
    <13, 58, 57>, 0,
    <17, 16, 59>, 0,
    <17, 59, 58>, 0,
    <16, 11, 56>, 0,
    <16, 56, 59>, 0,
    <13, 15, 61>, 0,
    <13, 61, 60>, 0,
    <15, 18, 62>, 0,
    <15, 62, 61>, 0,
    <18, 17, 63>, 0,
    <18, 63, 62>, 0,
    <17, 13, 60>, 0,
    <17, 60, 63>, 0,
    <15, 1, 65>, 0,
    <15, 65, 64>, 0,
    <1, 19, 66>, 0,
    <1, 66, 65>, 0,
    <19, 18, 67>, 0,
    <19, 67, 66>, 0,
    <18, 15, 64>, 0,
    <18, 64, 67>, 0,
    <1, 3, 69>, 0,
    <1, 69, 68>, 0,
    <3, 20, 70>, 0,
    <3, 70, 69>, 0,
    <20, 19, 71>, 0,
    <20, 71, 70>, 0,
    <19, 1, 68>, 0,
    <19, 68, 71>, 0,
    <9, 11, 73>, 0,
    <9, 73, 72>, 0,
    <11, 16, 74>, 0,
    <11, 74, 73>, 0,
    <16, 21, 75>, 0,
    <16, 75, 74>, 0,
    <21, 9, 72>, 0,
    <21, 72, 75>, 0,
    <3, 5, 77>, 0,
    <3, 77, 76>, 0,
    <5, 22, 78>, 0,
    <5, 78, 77>, 0,
    <22, 20, 79>, 0,
    <22, 79, 78>, 0,
    <20, 3, 76>, 0,
    <20, 76, 79>, 0,
    <5, 7, 81>, 0,
    <5, 81, 80>, 0,
    <7, 23, 82>, 0,
    <7, 82, 81>, 0,
    <23, 22, 83>, 0,
    <23, 83, 82>, 0,
    <22, 5, 80>, 0,
    <22, 80, 83>, 0,
    <7, 9, 85>, 0,
    <7, 85, 84>, 0,
    <9, 21, 86>, 0,
    <9, 86, 85>, 0,
    <21, 23, 87>, 0,
    <21, 87, 86>, 0,
    <23, 7, 84>, 0,
    <23, 84, 87>, 0,
    <24, 25, 89>, 0,
    <24, 89, 88>, 0,
    <25, 26, 90>, 0,
    <25, 90, 89>, 0,
    <26, 27, 91>, 0,
    <26, 91, 90>, 0,
    <27, 24, 88>, 0,
    <27, 88, 91>, 0,
    <92, 93, 94>, 0,
    <92, 94, 95>, 0,
    <88, 89, 93>, 0,
    <88, 93, 92>, 0,
    <89, 90, 94>, 0,
    <89, 94, 93>, 0,
    <90, 91, 95>, 0,
    <90, 95, 94>, 0,
    <91, 88, 92>, 0,
    <91, 92, 95>, 0
  }
  normal_indices {
    188,   // from 0 triangles and 94 quads
    <0, 0, 0>,
    <0, 0, 0>,
    <1, 1, 1>,
    <1, 1, 1>,
    <2, 2, 2>,
    <2, 2, 2>,
    <3, 3, 3>,
    <3, 3, 3>,
    <4, 4, 4>,
    <4, 4, 4>,
    <5, 5, 5>,
    <5, 5, 5>,
    <6, 6, 6>,
    <6, 6, 6>,
    <7, 7, 7>,
    <7, 7, 7>,
    <8, 8, 8>,
    <8, 8, 8>,
    <9, 9, 9>,
    <9, 9, 9>,
    <10, 10, 10>,
    <10, 10, 10>,
    <11, 11, 11>,
    <11, 11, 11>,
    <12, 12, 12>,
    <12, 12, 12>,
    <13, 13, 13>,
    <13, 13, 13>,
    <14, 14, 14>,
    <14, 14, 14>,
    <15, 15, 15>,
    <15, 15, 15>,
    <16, 16, 16>,
    <16, 16, 16>,
    <17, 17, 17>,
    <17, 17, 17>,
    <18, 18, 18>,
    <18, 18, 18>,
    <19, 19, 19>,
    <19, 19, 19>,
    <20, 20, 20>,
    <20, 20, 20>,
    <21, 21, 21>,
    <21, 21, 21>,
    <22, 22, 22>,
    <22, 22, 22>,
    <23, 23, 23>,
    <23, 23, 23>,
    <24, 24, 24>,
    <24, 24, 24>,
    <25, 25, 25>,
    <25, 25, 25>,
    <26, 26, 26>,
    <26, 26, 26>,
    <27, 27, 27>,
    <27, 27, 27>,
    <28, 28, 28>,
    <28, 28, 28>,
    <29, 29, 29>,
    <29, 29, 29>,
    <30, 30, 30>,
    <30, 30, 30>,
    <31, 31, 31>,
    <31, 31, 31>,
    <32, 32, 32>,
    <32, 32, 32>,
    <33, 33, 33>,
    <33, 33, 33>,
    <34, 34, 34>,
    <34, 34, 34>,
    <35, 35, 35>,
    <35, 35, 35>,
    <36, 36, 36>,
    <36, 36, 36>,
    <37, 37, 37>,
    <37, 37, 37>,
    <38, 38, 38>,
    <38, 38, 38>,
    <39, 39, 39>,
    <39, 39, 39>,
    <40, 40, 40>,
    <40, 40, 40>,
    <41, 41, 41>,
    <41, 41, 41>,
    <42, 42, 42>,
    <42, 42, 42>,
    <43, 43, 43>,
    <43, 43, 43>,
    <44, 44, 44>,
    <44, 44, 44>,
    <45, 45, 45>,
    <45, 45, 45>,
    <46, 46, 46>,
    <46, 46, 46>,
    <47, 47, 47>,
    <47, 47, 47>,
    <48, 48, 48>,
    <48, 48, 48>,
    <49, 49, 49>,
    <49, 49, 49>,
    <50, 50, 50>,
    <50, 50, 50>,
    <51, 51, 51>,
    <51, 51, 51>,
    <52, 52, 52>,
    <52, 52, 52>,
    <53, 53, 53>,
    <53, 53, 53>,
    <54, 54, 54>,
    <54, 54, 54>,
    <55, 55, 55>,
    <55, 55, 55>,
    <56, 56, 56>,
    <56, 56, 56>,
    <57, 57, 57>,
    <57, 57, 57>,
    <58, 58, 58>,
    <58, 58, 58>,
    <59, 59, 59>,
    <59, 59, 59>,
    <60, 60, 60>,
    <60, 60, 60>,
    <61, 61, 61>,
    <61, 61, 61>,
    <62, 62, 62>,
    <62, 62, 62>,
    <63, 63, 63>,
    <63, 63, 63>,
    <64, 64, 64>,
    <64, 64, 64>,
    <65, 65, 65>,
    <65, 65, 65>,
    <66, 66, 66>,
    <66, 66, 66>,
    <67, 67, 67>,
    <67, 67, 67>,
    <68, 68, 68>,
    <68, 68, 68>,
    <69, 69, 69>,
    <69, 69, 69>,
    <70, 70, 70>,
    <70, 70, 70>,
    <71, 71, 71>,
    <71, 71, 71>,
    <72, 72, 72>,
    <72, 72, 72>,
    <73, 73, 73>,
    <73, 73, 73>,
    <74, 74, 74>,
    <74, 74, 74>,
    <75, 75, 75>,
    <75, 75, 75>,
    <76, 76, 76>,
    <76, 76, 76>,
    <77, 77, 77>,
    <77, 77, 77>,
    <78, 78, 78>,
    <78, 78, 78>,
    <79, 79, 79>,
    <79, 79, 79>,
    <80, 80, 80>,
    <80, 80, 80>,
    <81, 81, 81>,
    <81, 81, 81>,
    <82, 82, 82>,
    <82, 82, 82>,
    <83, 83, 83>,
    <83, 83, 83>,
    <84, 84, 84>,
    <84, 84, 84>,
    <85, 85, 85>,
    <85, 85, 85>,
    <86, 86, 86>,
    <86, 86, 86>,
    <87, 87, 87>,
    <87, 87, 87>,
    <88, 88, 88>,
    <88, 88, 88>,
    <89, 89, 89>,
    <89, 89, 89>,
    <90, 90, 90>,
    <90, 90, 90>,
    <91, 91, 91>,
    <91, 91, 91>,
    <92, 92, 92>,
    <92, 92, 92>,
    <93, 93, 93>,
    <93, 93, 93>
  }
  uv_indices {
    188,   // from 0 triangles and 94 quads
    <0, 1, 2>,
    <0, 2, 3>    <4, 5, 6>,
    <4, 6, 7>    <8, 9, 10>,
    <8, 10, 11>    <340, 341, 342>,
    <340, 342, 343>    <12, 13, 14>,
    <12, 14, 15>    <16, 17, 18>,
    <16, 18, 19>    <20, 21, 22>,
    <20, 22, 23>    <24, 25, 26>,
    <24, 26, 27>    <28, 29, 30>,
    <28, 30, 31>    <32, 33, 34>,
    <32, 34, 35>    <36, 37, 38>,
    <36, 38, 39>    <40, 41, 42>,
    <40, 42, 43>    <344, 345, 346>,
    <344, 346, 347>    <44, 45, 46>,
    <44, 46, 47>    <48, 49, 50>,
    <48, 50, 51>    <52, 53, 54>,
    <52, 54, 55>    <56, 57, 58>,
    <56, 58, 59>    <60, 61, 62>,
    <60, 62, 63>    <64, 65, 66>,
    <64, 66, 67>    <68, 69, 70>,
    <68, 70, 71>    <72, 73, 74>,
    <72, 74, 75>    <348, 349, 350>,
    <348, 350, 351>    <76, 77, 78>,
    <76, 78, 79>    <80, 81, 82>,
    <80, 82, 83>    <84, 85, 86>,
    <84, 86, 87>    <88, 89, 90>,
    <88, 90, 91>    <92, 93, 94>,
    <92, 94, 95>    <96, 97, 98>,
    <96, 98, 99>    <100, 101, 102>,
    <100, 102, 103>    <104, 105, 106>,
    <104, 106, 107>    <108, 109, 110>,
    <108, 110, 111>    <112, 113, 114>,
    <112, 114, 115>    <116, 117, 118>,
    <116, 118, 119>    <120, 121, 122>,
    <120, 122, 123>    <124, 125, 126>,
    <124, 126, 127>    <128, 129, 130>,
    <128, 130, 131>    <132, 133, 134>,
    <132, 134, 135>    <352, 353, 354>,
    <352, 354, 355>    <136, 137, 138>,
    <136, 138, 139>    <140, 141, 142>,
    <140, 142, 143>    <144, 145, 146>,
    <144, 146, 147>    <148, 149, 150>,
    <148, 150, 151>    <152, 153, 154>,
    <152, 154, 155>    <156, 157, 158>,
    <156, 158, 159>    <160, 161, 162>,
    <160, 162, 163>    <164, 165, 166>,
    <164, 166, 167>    <168, 169, 170>,
    <168, 170, 171>    <172, 173, 174>,
    <172, 174, 175>    <176, 177, 178>,
    <176, 178, 179>    <180, 181, 182>,
    <180, 182, 183>    <184, 185, 186>,
    <184, 186, 187>    <188, 189, 190>,
    <188, 190, 191>    <192, 193, 194>,
    <192, 194, 195>    <196, 197, 198>,
    <196, 198, 199>    <200, 201, 202>,
    <200, 202, 203>    <204, 205, 206>,
    <204, 206, 207>    <208, 209, 210>,
    <208, 210, 211>    <212, 213, 214>,
    <212, 214, 215>    <216, 217, 218>,
    <216, 218, 219>    <220, 221, 222>,
    <220, 222, 223>    <224, 225, 226>,
    <224, 226, 227>    <228, 229, 230>,
    <228, 230, 231>    <232, 233, 234>,
    <232, 234, 235>    <236, 237, 238>,
    <236, 238, 239>    <240, 241, 242>,
    <240, 242, 243>    <244, 245, 246>,
    <244, 246, 247>    <248, 249, 250>,
    <248, 250, 251>    <252, 253, 254>,
    <252, 254, 255>    <256, 257, 258>,
    <256, 258, 259>    <260, 261, 262>,
    <260, 262, 263>    <264, 265, 266>,
    <264, 266, 267>    <268, 269, 270>,
    <268, 270, 271>    <272, 273, 274>,
    <272, 274, 275>    <276, 277, 278>,
    <276, 278, 279>    <280, 281, 282>,
    <280, 282, 283>    <284, 285, 286>,
    <284, 286, 287>    <288, 289, 290>,
    <288, 290, 291>    <292, 293, 294>,
    <292, 294, 295>    <296, 297, 298>,
    <296, 298, 299>    <300, 301, 302>,
    <300, 302, 303>    <304, 305, 306>,
    <304, 306, 307>    <308, 309, 310>,
    <308, 310, 311>    <312, 313, 314>,
    <312, 314, 315>    <316, 317, 318>,
    <316, 318, 319>    <320, 321, 322>,
    <320, 322, 323>    <356, 357, 358>,
    <356, 358, 359>    <360, 361, 362>,
    <360, 362, 363>    <364, 365, 366>,
    <364, 366, 367>    <368, 369, 370>,
    <368, 370, 371>    <372, 373, 374>,
    <372, 374, 375>    <324, 325, 326>,
    <324, 326, 327>    <328, 329, 330>,
    <328, 330, 331>    <332, 333, 334>,
    <332, 334, 335>    <336, 337, 338>,
    <336, 338, 339>
  }
  uv_mapping
  translate  4.877311*z
}

#declare Tore_creux = difference {
  torus { // Torus001
    1.9, 0.22  rotate -x*90
    translate  34.0*z
  }
  torus { // Torus002
    1.9, 0.2  rotate -x*90
    translate  34.0*z
  }
}
#declare Coupe_tore = intersection {
  object { Tore_creux }
  cylinder { // Cylndr051
    <0,0,1>, <0,0,0>, 1 
    scale <1.9, 1.9, 0.2>
    translate  34.0*z
  }
}
#declare CSG001 = difference {
  sphere { // Sphere002
    <0,0,0>,1
    scale 1.7
    translate  34.0*z
  }
  sphere { // Sphere003
    <0,0,0>,1
    scale 1.68
    translate  34.0*z
  }
  translate  0.2*z
}
#declare Tores_calotte = union {
  object { Torus005 }
  object { // Torus006 -> Torus005
    Torus005
    rotate -22.5*z
  }
  object { // Torus007 -> Torus005
    Torus005
    rotate -45.0*z
  }
  object { // Torus008 -> Torus005
    Torus005
    rotate -67.5*z
  }
  object { // Torus009 -> Torus005
    Torus005
    rotate -90.0*z
  }
  object { // Torus010 -> Torus005
    Torus005
    rotate -112.5*z
    translate  <0.0, -0.0, 0.0>
  }
  object { // Torus011 -> Torus005
    Torus005
    rotate -135.0*z
    translate  -0.0*y
  }
  object { // Torus012 -> Torus005
    Torus005
    rotate -157.5*z
    translate  -0.0*y
  }
  object { // Torus013 -> Torus005
    Torus005
    rotate 180.0*z
  }
  object { // Torus014 -> Torus005
    Torus005
    rotate 157.5*z
    translate  -0.0*x
  }
  object { // Torus015 -> Torus005
    Torus005
    rotate 135.0*z
  }
  object { // Torus016 -> Torus005
    Torus005
    rotate 112.5*z
    translate  -0.0*y
  }
  object { // Torus017 -> Torus005
    Torus005
    rotate 90.0*z
  }
  object { // Torus018 -> Torus005
    Torus005
    rotate 67.5*z
    translate  -0.0*x
  }
  object { // Torus019 -> Torus005
    Torus005
    rotate 45.0*z
    translate  0.0*y
  }
  object { // Torus020 -> Torus005
    Torus005
    rotate 22.5*z
    translate  <-0.0, 0.0, 0.0>
  }
}
#declare Unionspheretoures = union {
  object { CSG001 }
  object { Tores_calotte }
  translate  -0.2*z
}
#declare Hemisphere = intersection {
  cylinder { // Cylndr050
    <0,0,1>, <0,0,0>, 1 
    scale <1.9, 1.9, 2.0>
    translate  34.0*z
  }
  object { Unionspheretoures }
  translate  0.128608*z
}
#declare Tore_creux3 = difference {
  torus { // Torus023
    0.34, 0.18  rotate -x*90
    translate  34.0*z
  }
  torus { // Torus024
    0.34, 0.16  rotate -x*90
    translate  34.0*z
  }
}
#declare Coupe_tore3 = intersection {
  object { Tore_creux3 }
  cylinder { // Cylndr054
    <0,0,1>, <0,0,0>, 1 
    scale <0.35, 0.35, 0.239039>
    translate  33.834036*z
  }
  translate  -33.790972*z
  scale 1.2
  translate  36.424003*z
}
#declare Tore_creux2 = difference {
  torus { // Torus021
    0.34, 0.18  rotate -x*90
    translate  34.0*z
  }
  torus { // Torus022
    0.34, 0.16  rotate -x*90
    translate  34.0*z
  }
}
#declare Coupe_tore2 = intersection {
  object { Tore_creux2 }
  cylinder { // Cylndr053
    <0,0,1>, <0,0,0>, 1 
    translate  -0.5*z
    scale <0.35, 0.35, 0.5>
    translate  33.916463*z
  }
  translate  -33.790972*z
  scale 1.2
  translate  36.007838*z
}
#declare Boule_percee = difference {
  sphere { // Sphere004
    <0,0,0>,1
    scale 0.5
    translate  37.255145*z
  }
  object { Cylndr003 }
  object { Cylndr004 }
  object { // Cylndr005 -> Cylndr004
    Cylndr004
    rotate <0.0, 0.0, -22.5>
    translate  0.0*y
  }
  object { // Cylndr006 -> Cylndr004
    Cylndr004
    rotate <0.0, 0.0, -45.0>
  }
  object { // Cylndr007 -> Cylndr004
    Cylndr004
    rotate <-0.0, 0.0, -67.5>
    translate  -0.0*x
  }
  object { // Cylndr008 -> Cylndr004
    Cylndr004
    rotate <0.0, 0.0, -90.0>
    translate  0.0*x
  }
  object { // Cylndr009 -> Cylndr004
    Cylndr004
    rotate <0.0, 0.0, -112.5>
    translate  0.0*y
  }
  object { // Cylndr010 -> Cylndr004
    Cylndr004
    rotate <-0.0, 0.0, -135.0>
    translate  0.0*y
  }
  object { // Cylndr011 -> Cylndr004
    Cylndr004
    rotate <0.0, 0.0, -157.5>
    translate  -0.0*x
  }
  object { // Cylndr012 -> Cylndr004
    Cylndr004
    rotate <0.0, 0.0, 180.0>
    translate  0.0*x
  }
  object { // Cylndr013 -> Cylndr004
    Cylndr004
    rotate <-0.0, 0.0, 157.5>
    translate  0.0*x
  }
  object { // Cylndr014 -> Cylndr004
    Cylndr004
    rotate <0.0, 0.0, 135.0>
  }
  object { // Cylndr015 -> Cylndr004
    Cylndr004
    rotate <0.0, 0.0, 112.5>
  }
  object { // Cylndr016 -> Cylndr004
    Cylndr004
    rotate <0.0, 0.0, 90.0>
  }
  object { // Cylndr017 -> Cylndr004
    Cylndr004
    rotate <-0.0, 0.0, 67.5>
  }
  object { // Cylndr018 -> Cylndr004
    Cylndr004
    rotate <0.0, 0.0, 45.0>
  }
  object { // Cylndr019 -> Cylndr004
    Cylndr004
    rotate <-0.0, 0.0, 22.5>
    translate  0.0*x
  }
  object { // Cylndr020 -> Cylndr003
    Cylndr003
    rotate <-0.0, -0.0, -22.5>
    translate  0.0*y
  }
  object { // Cylndr021 -> Cylndr003
    Cylndr003
    rotate <-0.0, -0.0, -45.0>
    translate  0.0*x
  }
  object { // Cylndr022 -> Cylndr003
    Cylndr003
    rotate <0.0, -0.0, -67.5>
    translate  0.0*x
  }
  object { // Cylndr023 -> Cylndr003
    Cylndr003
    rotate <-0.0, -0.0, -90.0>
    translate  -0.0*x
  }
  object { // Cylndr024 -> Cylndr003
    Cylndr003
    rotate <0.0, -0.0, -112.5>
    translate  -0.0*x
  }
  object { // Cylndr025 -> Cylndr003
    Cylndr003
    rotate <0.0, -0.0, -135.0>
  }
  object { // Cylndr026 -> Cylndr003
    Cylndr003
    rotate <0.0, -0.0, -157.5>
  }
  object { // Cylndr027 -> Cylndr003
    Cylndr003
    rotate <-0.0, -0.0, 180.0>
    translate  0.0*y
  }
  object { // Cylndr028 -> Cylndr003
    Cylndr003
    rotate <0.0, -0.0, 157.5>
  }
  object { // Cylndr029 -> Cylndr003
    Cylndr003
    rotate <0.0, -0.0, 135.0>
    translate  0.0*y
  }
  object { // Cylndr030 -> Cylndr003
    Cylndr003
    rotate <-0.0, -0.0, 112.5>
  }
  object { // Cylndr031 -> Cylndr003
    Cylndr003
    rotate <0.0, -0.0, 90.0>
  }
  object { // Cylndr032 -> Cylndr003
    Cylndr003
    rotate <0.0, -0.0, 67.5>
    translate  0.0*x
  }
  object { // Cylndr033 -> Cylndr003
    Cylndr003
    rotate <0.0, -0.0, 45.0>
    translate  0.0*x
  }
  object { // Cylndr034 -> Cylndr003
    Cylndr003
    rotate <0.0, -0.0, 22.5>
    translate  0.0*y
  }
  translate  -0.063958*z
}
#declare Boule_porteboule = union {
  object { Coupe_tore3 }
  object { Coupe_tore2 }
  object { Boule_percee }
  translate  -0.258734*z
}
#declare TMesh017 = mesh2 {
  vertex_vectors {
    18800,
    <2.0388076, -0.0029310, 34.2956273>,
    <2.0491333, -0.0099057, 34.2918022>,
    <2.0500000, 0.0000000, 34.2918022>,
    <2.0332337, 0.0380994, 34.2969740>,
    <2.0435005, -0.0061520, 34.2939713>,
    <2.0497223, -0.0031731, 34.2918022>,
    <2.0403635, 0.0327151, 34.2943910>,
    <2.0363936, 0.0113181, 34.2964553>,
    <2.0427721, 0.0076869, 34.2941812>,
    <2.0202357, 0.0000000, 34.3035582>,
    <2.0336417, -0.0358941, 34.2969740>,
    <2.0248579, 0.0217884, 34.3007907>,
    <2.0252209, -0.0174473, 34.3007907>,
    <2.0364247, -0.0151457, 34.2964553>,
    <2.0311587, 0.0004919, 34.2985195>,
    <2.0457752, -0.0482883, 34.2918022>,
    <2.0396729, -0.0431202, 34.2943910>,
    <2.0479214, -0.0237576, 34.2918022>,
    <2.0420766, -0.0217180, 34.2941812>,
    <2.0316779, -0.0943957, 34.2957498>,
    <2.0225009, -0.1323669, 34.2979383>,
    <2.0297308, -0.2316769, 34.2918022>,
    <2.0382455, -0.1343532, 34.2918022>,
    <2.0279668, -0.1074402, 34.2967308>,
    <2.0258817, -0.1942023, 34.2945157>,
    <2.0338614, -0.1844636, 34.2918022>,
    <2.0346750, -0.1107668, 34.2940173>,
    <2.0305455, -0.1470231, 34.2943649>,
    <2.0423834, -0.0870575, 34.2918022>,
    <2.0323509, -0.0654493, 34.2965012>,
    <2.0374616, -0.0744679, 34.2941812>,
    <2.0204924, -0.0538001, 34.3015015>,
    <2.0268625, -0.0635728, 34.2987032>,
    <2.0296254, 0.1181152, 34.2957497>,
    <2.0354350, 0.1664777, 34.2918022>,
    <2.0244857, 0.2916293, 34.2918020>,
    <2.0203647, 0.1611803, 34.2979360>,
    <2.0322405, 0.1386903, 34.2940173>,
    <2.0292824, 0.2368022, 34.2918021>,
    <2.0219628, 0.2422123, 34.2945063>,
    <2.0257073, 0.1348403, 34.2967308>,
    <2.0271654, 0.1868393, 34.2943648>,
    <2.0199418, 0.0626803, 34.3015015>,
    <2.0310790, 0.0790930, 34.2965012>,
    <2.0255670, 0.0787693, 34.2987032>,
    <2.0424915, 0.0858218, 34.2918022>,
    <2.0367464, 0.0818492, 34.2941812>,
    <2.0083859, 0.3485630, 34.2956993>,
    <2.0198635, 0.3444602, 34.2918015>,
    <2.0188570, 0.3559649, 34.2918009>,
    <1.9959198, 0.3904766, 34.2968956>,
    <2.0135987, 0.3471490, 34.2939980>,
    <2.0191343, 0.3527954, 34.2918012>,
    <2.0038263, 0.3865399, 34.2943337>,
    <2.0036132, 0.3639441, 34.2964351>,
    <2.0104976, 0.3623030, 34.2941429>,
    <1.9895468, 0.3508108, 34.3035582>,
    <2.0079625, 0.3040950, 34.2978516>,
    <1.9904179, 0.3735960, 34.3006309>,
    <1.9969099, 0.3259223, 34.3013242>,
    <2.0080965, 0.3328741, 34.2966650>,
    <2.0002337, 0.3498522, 34.2986280>,
    <2.0173834, 0.2953707, 34.2944781>,
    <2.0214967, 0.3257934, 34.2918018>,
    <2.0150291, 0.3266462, 34.2943271>,
    <2.0104897, 0.2211527, 34.2997659>,
    <2.0147531, 0.1954051, 34.2989716>,
    <2.0089716, 0.2628474, 34.2989247>,
    <2.0152985, 0.2494069, 34.2968900>,
    <2.0048912, 0.1754054, 34.3035582>,
    <1.9972190, 0.2631081, 34.3035582>,
    <2.0078952, 0.2034837, 34.3014013>,
    <2.0030052, 0.2656398, 34.3011850>,
    <2.0125635, 0.0877027, 34.3035582>,
    <2.0137682, 0.1415238, 34.3012225>,
    <2.0114345, -0.1967892, 34.2997909>,
    <2.0092255, -0.2730950, 34.2979383>,
    <2.0100808, -0.2341179, 34.2989810>,
    <2.0210695, -0.2463763, 34.2945157>,
    <2.0164372, -0.1672304, 34.2989810>,
    <2.0178827, -0.2105468, 34.2969276>,
    <2.0032634, -0.1751142, 34.3035582>,
    <2.0117495, -0.0875571, 34.3035582>,
    <2.0078484, -0.1883020, 34.3014107>,
    <2.0142730, -0.1266978, 34.3012225>,
    <1.9862910, -0.3502284, 34.3035582>,
    <1.9947772, -0.2626713, 34.3035582>,
    <1.9954306, -0.3144683, 34.3015015>,
    <2.0023990, -0.2502535, 34.3012225>,
    <2.0115410, -0.3129262, 34.2957498>,
    <2.0051239, -0.3428561, 34.2969740>,
    <2.0188572, -0.3559621, 34.2918022>,
    <2.0235408, -0.3024285, 34.2918022>,
    <2.0079659, -0.3284777, 34.2965012>,
    <2.0122489, -0.3457498, 34.2943910>,
    <2.0211049, -0.3302714, 34.2918022>,
    <2.0166853, -0.3096665, 34.2940173>,
    <2.0143179, -0.3305667, 34.2941812>,
    <2.0263533, -0.2702811, 34.2918022>,
    <2.0100346, -0.2999168, 34.2967308>,
    <2.0180722, -0.2837219, 34.2943649>,
    <1.9940826, -0.3449737, 34.3007907>,
    <2.0024840, -0.3216202, 34.2987032>,
    <2.0058281, -0.3617380, 34.2956273>,
    <2.0162829, -0.3655752, 34.2918022>,
    <2.0106227, -0.3626738, 34.2939713>,
    <2.0180325, -0.3590430, 34.2918022>,
    <2.0051482, -0.3535081, 34.2964553>,
    <2.0117575, -0.3545430, 34.2941812>,
    <1.9950497, -0.3887022, 34.2969740>,
    <1.9888071, -0.3703002, 34.3007907>,
    <2.0014051, -0.3701827, 34.2964553>,
    <1.9978702, -0.3594033, 34.2985195>,
    <2.0063098, -0.4027993, 34.2918022>,
    <2.0004813, -0.3965219, 34.2943910>,
    <2.0126836, -0.3790102, 34.2918022>,
    <2.0066235, -0.3758695, 34.2941812>,
    <2.0097935, 0.1625222, 34.3035582>,
    <2.0199169, 0.0683778, 34.3035582>,
    <2.0195980, 0.1367557, 34.3035582>,
    <2.0045724, 0.2437832, 34.3035582>,
    <2.0142225, 0.1213340, 34.3035582>,
    <2.0197574, 0.1025668, 34.3035582>,
    <2.0120852, 0.1902695, 34.3035582>,
    <2.0075093, 0.1980739, 34.3035582>,
    <2.0134702, 0.1528597, 34.3035582>,
    <2.0048912, 0.1754054, 34.3035582>,
    <1.9970596, 0.2972970, 34.3035582>,
    <1.9972190, 0.2631081, 34.3035582>,
    <2.0076488, 0.1681586, 34.3035582>,
    <2.0022010, 0.2331304, 34.3035582>,
    <2.0125635, 0.0877027, 34.3035582>,
    <2.0200763, 0.0341889, 34.3035582>,
    <2.0137093, 0.1015763, 34.3035582>,
    <2.0097935, 0.1625222, 34.3035582>,
    <2.0045724, 0.2437832, 34.3035582>,
    <2.0048912, 0.1754054, 34.3035582>,
    <2.0075093, 0.1980739, 34.3035582>,
    <1.9970596, 0.2972970, 34.3035582>,
    <1.9972190, 0.2631081, 34.3035582>,
    <2.0076488, 0.1681586, 34.3035582>,
    <2.0022010, 0.2331304, 34.3035582>,
    <2.0199169, 0.0683778, 34.3035582>,
    <2.0125635, 0.0877027, 34.3035582>,
    <2.0200763, 0.0341889, 34.3035582>,
    <2.0142225, 0.1213340, 34.3035582>,
    <2.0137093, 0.1015763, 34.3035582>,
    <2.0197574, 0.1025668, 34.3035582>,
    <2.0120852, 0.1902695, 34.3035582>,
    <2.0134702, 0.1528597, 34.3035582>,
    <1.9834209, -0.4455888, 34.2957497>,
    <1.9676109, -0.4813809, 34.2979383>,
    <1.9586615, -0.5806270, 34.2918019>,
    <1.9839482, -0.4862556, 34.2918021>,
    <1.9773465, -0.4577697, 34.2967308>,
    <1.9609785, -0.5429973, 34.2945156>,
    <1.9709285, -0.5348461, 34.2918020>,
    <1.9839502, -0.4623049, 34.2940173>,
    <1.9735964, -0.4973020, 34.2943648>,
    <1.9962367, -0.4403939, 34.2918022>,
    <1.9888441, -0.4171465, 34.2965012>,
    <1.9929177, -0.4270226, 34.2941812>,
    <1.9781013, -0.4034355, 34.3015015>,
    <1.9832610, -0.4142608, 34.2987032>,
    <1.9781781, 0.4694708, 34.2956981>,
    <1.9756046, 0.5173897, 34.2917995>,
    <1.9430889, 0.6387431, 34.2917984>,
    <1.9610449, 0.5119065, 34.2978477>,
    <1.9772453, 0.4897394, 34.2939964>,
    <1.9573336, 0.5855798, 34.2917989>,
    <1.9488514, 0.5906635, 34.2944661>,
    <1.9711690, 0.4861353, 34.2966635>,
    <1.9636762, 0.5370647, 34.2943249>,
    <1.9773911, 0.4172885, 34.3013237>,
    <1.9865675, 0.4308680, 34.2964343>,
    <1.9809623, 0.4303775, 34.2986272>,
    <1.9965597, 0.4391817, 34.2918002>,
    <1.9916854, 0.4342916, 34.2941421>,
    <1.9167676, 0.6918087, 34.2956970>,
    <1.9293627, 0.6899716, 34.2917979>,
    <1.9263732, 0.7011287, 34.2917977>,
    <1.8969886, 0.7308399, 34.2968945>,
    <1.9223923, 0.6914105, 34.2939951>,
    <1.9271969, 0.6980546, 34.2917978>,
    <1.9058598, 0.7284827, 34.2943318>,
    <1.9092553, 0.7060764, 34.2964332>,
    <1.9166690, 0.7057828, 34.2941404>,
    <1.8965388, 0.6902837, 34.3035582>,
    <1.9238966, 0.6479498, 34.2978474>,
    <1.8939244, 0.7130486, 34.3006305>,
    <1.9086098, 0.6672328, 34.3013235>,
    <1.9191024, 0.6762696, 34.2966628>,
    <1.9080702, 0.6915010, 34.2986266>,
    <1.9351181, 0.6413635, 34.2944658>,
    <1.9342126, 0.6718707, 34.2917981>,
    <1.9273530, 0.6714637, 34.2943241>,
    <1.9407876, 0.5673984, 34.2997397>,
    <1.9495026, 0.5437531, 34.2989139>,
    <1.9320583, 0.6077208, 34.2989138>,
    <1.9407823, 0.5964996, 34.2968505>,
    <1.9430428, 0.5205472, 34.3035582>,
    <1.9197908, 0.6054155, 34.3035582>,
    <1.9412493, 0.5490517, 34.3013912>,
    <1.9254065, 0.6090429, 34.3011842>,
    <1.9662948, 0.4356790, 34.3035582>,
    <1.9579636, 0.4899742, 34.3011843>,
    <1.9460196, -0.5430439, 34.2997908>,
    <1.9314038, -0.6179701, 34.2979380>,
    <1.9386165, -0.5796551, 34.2989809>,
    <1.9475159, -0.5936223, 34.2945154>,
    <1.9558052, -0.5147279, 34.2989809>,
    <1.9502252, -0.5577295, 34.2969274>,
    <1.9414149, -0.5202561, 34.3035582>,
    <1.9638530, -0.4352422, 34.3035582>,
    <1.9438235, -0.5340530, 34.3014107>,
    <1.9601403, -0.4743333, 34.3012225>,
    <1.8965389, -0.6902837, 34.3035582>,
    <1.9189769, -0.6052699, 34.3035582>,
    <1.9112006, -0.6564989, 34.3015014>,
    <1.9284389, -0.5942862, 34.3012225>,
    <1.9269627, -0.6576144, 34.2957490>,
    <1.9402789, -0.6492321, 34.2918011>,
    <1.9324700, -0.6552455, 34.2940164>,
    <1.9486314, -0.6180600, 34.2918015>,
    <1.9277251, -0.6445511, 34.2967303>,
    <1.9382727, -0.6299240, 34.2943643>,
    <1.9156604, -0.6860407, 34.2969728>,
    <1.9047968, -0.6863478, 34.3007902>,
    <1.9208795, -0.6723509, 34.2965003>,
    <1.9167995, -0.6647048, 34.2987027>,
    <1.9263698, -0.7011413, 34.2918001>,
    <1.9219099, -0.6900325, 34.2943894>,
    <1.9330447, -0.6762302, 34.2918006>,
    <1.9265616, -0.6754319, 34.2941799>,
    <1.9129422, -0.7047059, 34.2956252>,
    <1.9221672, -0.7101539, 34.2917991>,
    <1.9173262, -0.7063968, 34.2939688>,
    <1.9250235, -0.7040285, 34.2917996>,
    <1.9137889, -0.6965161, 34.2964536>,
    <1.9198772, -0.6985971, 34.2941791>,
    <1.8977869, -0.7294349, 34.2969720>,
    <1.8952299, -0.7103753, 34.3007900>,
    <1.9072081, -0.7122843, 34.2964533>,
    <1.9058165, -0.7011356, 34.2985183>,
    <1.9058846, -0.7450720, 34.2917985>,
    <1.9015080, -0.7379789, 34.2943882>,
    <1.9162909, -0.7227557, 34.2917987>,
    <1.9111195, -0.7187026, 34.2941785>,
    <1.9476109, 0.5090129, 34.3035582>,
    <1.9266429, 0.5881140, 34.3035582>,
    <1.9430428, 0.5205472, 34.3035582>,
    <1.9384374, 0.5436197, 34.3035582>,
    <1.9115909, 0.6391989, 34.3035582>,
    <1.9197908, 0.6054155, 34.3035582>,
    <1.9456123, 0.5140592, 34.3035582>,
    <1.9284589, 0.5769895, 34.3035582>,
    <1.9731469, 0.4183776, 34.3035582>,
    <1.9662948, 0.4356790, 34.3035582>,
    <1.9813468, 0.3845942, 34.3035582>,
    <1.9587829, 0.4693600, 34.3035582>,
    <1.9633368, 0.4496871, 34.3035582>,
    <1.9567470, 0.4859444, 34.3035582>,
    <1.9649470, 0.4521610, 34.3035582>,
    <1.9416950, 0.5370292, 34.3035582>,
    <1.9510369, 0.5003622, 34.3035582>,
    <1.8171525, 0.0335956, 34.0159774>,
    <1.8120676, 0.0606396, 34.0159774>,
    <1.8189473, 0.0993812, 34.0159774>,
    <1.8230072, 0.0529769, 34.0159774>,
    <1.8150993, 0.0456555, 34.0159774>,
    <1.8159109, 0.0828299, 34.0159774>,
    <1.8208516, 0.0776148, 34.0159774>,
    <1.8199453, 0.0418557, 34.0159774>,
    <1.8180278, 0.0612828, 34.0159774>,
    <1.8277371, -0.0010847, 34.0159774>,
    <1.8146734, -0.0150136, 34.0159774>,
    <1.8253303, 0.0264247, 34.0159774>,
    <1.8200602, -0.0176395, 34.0159774>,
    <1.8162258, 0.0154119, 34.0159774>,
    <1.8207205, 0.0166119, 34.0159774>,
    <1.8020372, 0.0725781, 34.0159774>,
    <1.8072014, 0.0230462, 34.0159774>,
    <1.8063969, 0.0540456, 34.0159774>,
    <1.8119614, 0.0314377, 34.0159774>,
    <1.8124682, -0.0930061, 34.0159774>,
    <1.8159300, -0.1360450, 34.0159774>,
    <1.8067148, -0.2413779, 34.0159774>,
    <1.8057595, -0.1271375, 34.0160180>,
    <1.8141728, -0.1126244, 34.0159774>,
    <1.8108364, -0.1942666, 34.0159774>,
    <1.8060224, -0.2001095, 34.0159774>,
    <1.8095906, -0.1060416, 34.0159774>,
    <1.8101823, -0.1531326, 34.0159774>,
    <1.8050257, -0.0121538, 34.0161399>,
    <1.8135345, -0.0566624, 34.0159774>,
    <1.8091236, -0.0470369, 34.0159774>,
    <1.8216715, -0.0704166, 34.0159774>,
    <1.8176715, -0.0640892, 34.0159774>,
    <1.8058864, 0.1756983, 34.0159774>,
    <1.8007592, 0.1939672, 34.0159774>,
    <1.8087369, 0.2160851, 34.0159774>,
    <1.8116245, 0.1830797, 34.0159774>,
    <1.8037588, 0.1819429, 34.0159774>,
    <1.8050443, 0.2079951, 34.0159774>,
    <1.8103063, 0.1981465, 34.0159774>,
    <1.8084293, 0.1784834, 34.0159774>,
    <1.8068118, 0.1908138, 34.0159774>,
    <1.8138422, 0.1577326, 34.0159774>,
    <1.8055616, 0.1570082, 34.0159774>,
    <1.8127752, 0.1699275, 34.0159774>,
    <1.8097254, 0.1573724, 34.0159774>,
    <1.8054433, 0.1669876, 34.0159774>,
    <1.8091470, 0.1675620, 34.0159774>,
    <1.7947333, 0.1560619, 34.0159774>,
    <1.7994908, 0.1564775, 34.0159774>,
    <1.7968344, 0.1738661, 34.0159774>,
    <1.8015888, 0.1699955, 34.0159774>,
    <1.8091270, 0.1386585, 34.0159774>,
    <1.8072504, 0.1197826, 34.0159774>,
    <1.8081161, 0.1321396, 34.0159774>,
    <1.7998943, 0.1388924, 34.0159774>,
    <1.8071780, 0.1471598, 34.0159774>,
    <1.8039044, 0.1435289, 34.0159774>,
    <1.8160597, 0.1323855, 34.0159774>,
    <1.8149091, 0.1455376, 34.0159774>,
    <1.8121149, 0.1363572, 34.0159774>,
    <1.8109252, 0.1472371, 34.0159774>,
    <1.8173779, 0.1173191, 34.0159774>,
    <1.8139077, 0.1067267, 34.0159774>,
    <1.8126631, 0.1239335, 34.0159774>,
    <1.8069142, 0.0874083, 34.0159774>,
    <1.8009633, 0.0848542, 34.0159774>,
    <1.8043535, 0.0863236, 34.0159774>,
    <1.7981706, 0.1167747, 34.0159774>,
    <1.8070050, 0.1023808, 34.0159774>,
    <1.8026128, 0.1104265, 34.0159774>,
    <1.8091972, 0.0756568, 34.0159774>,
    <1.8112970, 0.0909398, 34.0159774>,
    <1.8024670, 0.0676666, 34.0159774>,
    <1.8060852, 0.0694041, 34.0159774>,
    <1.7964279, 0.2772335, 34.0159774>,
    <1.8046766, 0.2624924, 34.0159774>,
    <1.7952718, 0.2529012, 34.0159774>,
    <1.8000610, 0.2716647, 34.0159774>,
    <1.8068324, 0.2378528, 34.0159774>,
    <1.8028519, 0.2319352, 34.0159774>,
    <1.7959228, 0.2671766, 34.0159774>,
    <1.8011947, 0.2535238, 34.0159774>,
    <1.7874288, 0.2395495, 34.0159774>,
    <1.7897060, 0.3091324, 34.0159774>,
    <1.7887813, 0.2573043, 34.0159774>,
    <1.7868933, 0.2779577, 34.0159774>,
    <1.7934866, 0.2907229, 34.0159774>,
    <1.7913823, 0.2767928, 34.0159774>,
    <1.7999462, 0.3165579, 34.0159774>,
    <1.7937920, 0.3154721, 34.0159774>,
    <1.8023533, 0.2890465, 34.0159774>,
    <1.7974542, 0.2928384, 34.0159774>,
    <1.7947937, 0.2258390, 34.0159774>,
    <1.7949842, 0.2378726, 34.0159774>,
    <1.7974916, 0.2110772, 34.0159774>,
    <1.7997164, 0.2231471, 34.0159774>,
    <1.7885031, 0.2272710, 34.0159774>,
    <1.7912960, 0.1953495, 34.0159774>,
    <1.7920920, 0.2264311, 34.0159774>,
    <1.7945684, 0.2023721, 34.0159774>,
    <1.7869992, 0.2444599, 34.0159774>,
    <1.7908438, 0.2434526, 34.0159774>,
    <1.8009868, -0.1824944, 34.0164423>,
    <1.7970935, -0.2604297, 34.0161247>,
    <1.8023616, -0.1590689, 34.0161399>,
    <1.8025420, -0.2471178, 34.0159774>,
    <1.7985406, -0.2233030, 34.0162110>,
    <1.8018943, -0.2088935, 34.0159774>,
    <1.7812953, -0.3378428, 34.0175836>,
    <1.8056182, -0.1464025, 34.0184480>,
    <1.7916667, -0.2807898, 34.0165664>,
    <1.7978110, -0.2329026, 34.0184620>,
    <1.8019574, -0.1621187, 34.0170234>,
    <1.7965831, -0.2279990, 34.0169117>,
    <1.8058930, -0.0233029, 34.0171572>,
    <1.8040795, -0.0986200, 34.0166273>,
    <1.7957197, -0.2987876, 34.0160090>,
    <1.8020357, -0.2948629, 34.0159774>,
    <1.7999485, -0.3187204, 34.0159774>,
    <1.7898435, -0.3263762, 34.0160841>,
    <1.7983028, -0.2979827, 34.0159774>,
    <1.8008301, -0.3086433, 34.0159774>,
    <1.7940113, -0.3246828, 34.0159774>,
    <1.7929918, -0.3116914, 34.0160485>,
    <1.7965418, -0.3118065, 34.0159774>,
    <1.7860815, -0.3278322, 34.0164039>,
    <1.7959784, -0.2861512, 34.0160485>,
    <1.7909182, -0.3050199, 34.0162618>,
    <1.8038893, -0.2736755, 34.0159774>,
    <1.8001548, -0.2773872, 34.0159774>,
    <1.7839375, 0.3491877, 34.0159774>,
    <1.7764538, 0.3671311, 34.0159774>,
    <1.7718637, 0.4213633, 34.0159774>,
    <1.7857022, 0.3697172, 34.0159774>,
    <1.7809567, 0.3545682, 34.0159774>,
    <1.7740017, 0.3966643, 34.0159774>,
    <1.7787069, 0.3958240, 34.0159774>,
    <1.7846844, 0.3591287, 34.0159774>,
    <1.7794984, 0.3776063, 34.0159774>,
    <1.7927989, 0.3432322, 34.0159774>,
    <1.7864029, 0.3313477, 34.0159774>,
    <1.7894922, 0.3379931, 34.0159774>,
    <1.7817641, 0.3017178, 34.0159774>,
    <1.7837487, 0.3218896, 34.0159774>,
    <1.7838521, -0.3570940, 34.0160090>,
    <1.7857034, -0.3718876, 34.0159774>,
    <1.7718641, -0.4235394, 34.0159774>,
    <1.7752844, -0.3842563, 34.0160841>,
    <1.7847054, -0.3626616, 34.0159774>,
    <1.7787077, -0.3979976, 34.0159774>,
    <1.7735855, -0.4036039, 34.0159774>,
    <1.7803169, -0.3668022, 34.0160485>,
    <1.7792214, -0.3829554, 34.0159774>,
    <1.7769384, -0.3660843, 34.0164039>,
    <1.7865569, -0.3424524, 34.0160485>,
    <1.7825756, -0.3484270, 34.0162618>,
    <1.7928006, -0.3453987, 34.0159774>,
    <1.7898506, -0.3424360, 34.0159774>,
    <1.8763065, -0.7833750, 34.2957474>,
    <1.8546348, -0.8159187, 34.2979367>,
    <1.8280883, -0.9119067, 34.2917994>,
    <1.8693751, -0.8233669, 34.2917986>,
    <1.8682806, -0.7943417, 34.2967288>,
    <1.8370921, -0.8753252, 34.2945134>,
    <1.8481174, -0.8689540, 34.2917989>,
    <1.8737592, -0.7998654, 34.2940143>,
    <1.8574942, -0.8325332, 34.2943622>,
    <1.8894384, -0.7803409, 34.2917984>,
    <1.8866805, -0.7563446, 34.2964990>,
    <1.8887425, -0.7666903, 34.2941783>,
    <1.8789268, -0.7411436, 34.3015009>,
    <1.8818865, -0.7526089, 34.2987017>,
    <1.7655202, 0.4186939, 34.0159774>,
    <1.7593978, 0.4257650, 34.0160180>,
    <1.7487304, 0.5076980, 34.0159774>,
    <1.7590067, 0.4693463, 34.0159774>,
    <1.7635041, 0.4185440, 34.0159774>,
    <1.7514602, 0.4808949, 34.0159774>,
    <1.7534354, 0.4901389, 34.0159774>,
    <1.7627221, 0.4413828, 34.0159774>,
    <1.7578248, 0.4573351, 34.0159774>,
    <1.7652232, 0.4461459, 34.0159774>,
    <1.7706567, 0.3932981, 34.0159774>,
    <1.7682620, 0.4195412, 34.0159774>,
    <1.7767702, 0.3194894, 34.0161399>,
    <1.7717631, 0.3677783, 34.0159774>,
    <1.7641235, -0.4312906, 34.0160090>,
    <1.7588479, -0.4721180, 34.0159774>,
    <1.7695382, -0.4072425, 34.0160485>,
    <1.7652234, -0.4483236, 34.0159774>,
    <1.7621845, -0.4469264, 34.0159774>,
    <1.7679846, -0.4248937, 34.0159774>,
    <1.7471412, -0.5158080, 34.0159774>,
    <1.7548103, -0.4579521, 34.0161247>,
    <1.7527997, -0.4946902, 34.0159774>,
    <1.7491894, -0.4948462, 34.0159774>,
    <1.7607084, -0.4401964, 34.0160485>,
    <1.7559512, -0.4698034, 34.0159774>,
    <1.7642176, -0.4121533, 34.0165664>,
    <1.7686767, -0.4011487, 34.0162618>,
    <1.8659985, 0.8056223, 34.2956983>,
    <1.8557461, 0.8525915, 34.2917999>,
    <1.8026514, 0.9664555, 34.2918015>,
    <1.8414831, 0.8443164, 34.2978488>,
    <1.8618207, 0.8255192, 34.2939967>,
    <1.8259114, 0.9165733, 34.2918008>,
    <1.8163073, 0.9199544, 34.2944683>,
    <1.8560674, 0.8207615, 34.2966642>,
    <1.8402041, 0.8697511, 34.2943262>,
    <1.8734329, 0.7537720, 34.3013240>,
    <1.8808379, 0.7690196, 34.2964340>,
    <1.8750719, 0.7674371, 34.2986274>,
    <1.8899639, 0.7792100, 34.2917988>,
    <1.8856415, 0.7734123, 34.2941412>,
    <1.7671183, 1.0139256, 34.2956998>,
    <1.7802383, 1.0145214, 34.2918021>,
    <1.7753575, 1.0249884, 34.2918022>,
    <1.7407656, 1.0488679, 34.2968965>,
    <1.7729029, 1.0146054, 34.2939985>,
    <1.7767021, 1.0221048, 34.2918022>,
    <1.7501570, 1.0482241, 34.2943349>,
    <1.7571798, 1.0266312, 34.2964357>,
    <1.7647623, 1.0277571, 34.2941437>,
    <1.7467057, 1.0084734, 34.3035582>,
    <1.7814767, 0.9718491, 34.2978493>,
    <1.7404883, 1.0306231, 34.3006313>,
    <1.7627605, 0.9879916, 34.3013243>,
    <1.7720028, 0.9989737, 34.2966652>,
    <1.7583118, 1.0119488, 34.2986283>,
    <1.7940302, 0.9675012, 34.2944686>,
    <1.7881575, 0.9975382, 34.2918019>,
    <1.7812028, 0.9958045, 34.2943273>,
    <1.8117554, 0.8953436, 34.2997408>,
    <1.8244970, 0.8736160, 34.2989152>,
    <1.7963155, 0.9335864, 34.2989154>,
    <1.8070673, 0.9241660, 34.2968524>,
    <1.8216222, 0.8493786, 34.3035582>,
    <1.7841639, 0.9289260, 34.3035582>,
    <1.8151841, 0.8772618, 34.3013919>,
    <1.7893045, 0.9336063, 34.3011851>,
    <1.8590805, 0.7698311, 34.3035582>,
    <1.8418163, 0.8219921, 34.3011849>,
    <1.8225807, -0.8728661, 34.2997899>,
    <1.7948994, -0.9440104, 34.2979372>,
    <1.8087957, -0.9075832, 34.2989799>,
    <1.8149504, -0.9228080, 34.2945137>,
    <1.8371873, -0.8466980, 34.2989797>,
    <1.8240233, -0.8879988, 34.2969259>,
    <1.8221986, -0.8497051, 34.3035582>,
    <1.8593687, -0.7699944, 34.3035582>,
    <1.8220634, -0.8636647, 34.3014101>,
    <1.8486926, -0.8077564, 34.3012219>,
    <1.7478582, -1.0091264, 34.3035582>,
    <1.7850284, -0.9294158, 34.3035582>,
    <1.7682571, -0.9784319, 34.3015012>,
    <1.7962433, -0.9202331, 34.3012220>,
    <1.7835246, -0.9822362, 34.2957487>,
    <1.7674320, -1.0082639, 34.2969736>,
    <1.7753564, -1.0249907, 34.2918022>,
    <1.7980710, -0.9762789, 34.2918006>,
    <1.7749575, -0.9956886, 34.2965005>,
    <1.7728922, -1.0132775, 34.2943907>,
    <1.7862573, -1.0016136, 34.2918014>,
    <1.7893447, -0.9808513, 34.2940160>,
    <1.7800099, -0.9997037, 34.2941804>,
    <1.8117104, -0.9470291, 34.2918000>,
    <1.7865758, -0.9695162, 34.2967297>,
    <1.7994858, -0.9569320, 34.2943632>,
    <1.7566853, -1.0066857, 34.3007905>,
    <1.7722951, -0.9874627, 34.2987026>,
    <1.7615104, -1.0261753, 34.2956272>,
    <1.7696505, -1.0331411, 34.2918022>,
    <1.7655348, -1.0286011, 34.2939713>,
    <1.7735282, -1.0276025, 34.2918022>,
    <1.7637668, -1.0182559, 34.2964551>,
    <1.7694023, -1.0213611, 34.2941811>,
    <1.7422918, -1.0479032, 34.2969740>,
    <1.7430922, -1.0286959, 34.3007907>,
    <1.7545465, -1.0326444, 34.2964552>,
    <1.7551120, -1.0214228, 34.2985194>,
    <1.7475487, -1.0647067, 34.2918022>,
    <1.7444700, -1.0569613, 34.2943910>,
    <1.7616738, -1.0445335, 34.2918022>,
    <1.7572843, -1.0396444, 34.2941812>,
    <1.7178985, 0.5986294, 34.0160090>,
    <1.7275447, 0.5867623, 34.0159774>,
    <1.7360824, 0.5549003, 34.0159774>,
    <1.7222695, 0.5794350, 34.0160841>,
    <1.7221334, 0.5931266, 34.0159774>,
    <1.7321113, 0.5697201, 34.0159774>,
    <1.7291521, 0.5672536, 34.0159774>,
    <1.7195472, 0.5903549, 34.0160485>,
    <1.7261108, 0.5789894, 34.0159774>,
    <1.7077186, 0.6068614, 34.0175836>,
    <1.7029492, 0.6350131, 34.0160841>,
    <1.7154824, 0.5912725, 34.0164039>,
    <1.7009648, 0.6310548, 34.0164039>,
    <1.7121856, 0.6123665, 34.0160485>,
    <1.7118574, 0.6059124, 34.0162618>,
    <1.7174189, 0.6245508, 34.0159774>,
    <1.7074484, 0.6344150, 34.0159774>,
    <1.7225810, 0.6052861, 34.0159774>,
    <1.7164094, 0.6108252, 34.0159774>,
    <1.7310258, 0.5525518, 34.0160090>,
    <1.7421129, 0.5323949, 34.0159774>,
    <1.7262343, 0.5664912, 34.0160485>,
    <1.7392595, 0.5430437, 34.0159774>,
    <1.7352110, 0.5454138, 34.0159774>,
    <1.7320676, 0.5567592, 34.0159774>,
    <1.7358250, 0.5261480, 34.0161247>,
    <1.7451130, 0.5211982, 34.0159774>,
    <1.7441639, 0.5105981, 34.0159774>,
    <1.7318933, 0.5453717, 34.0160485>,
    <1.7389362, 0.5311253, 34.0159774>,
    <1.7263910, 0.5500521, 34.0165664>,
    <1.7231182, 0.5682565, 34.0162618>,
    <1.7497643, 0.4621799, 34.0164423>,
    <1.7415322, 0.4975155, 34.0162110>,
    <1.7530386, 0.4470769, 34.0161399>,
    <1.7465805, 0.4861744, 34.0159774>,
    <1.7656702, 0.4091519, 34.0184462>,
    <1.7799260, 0.3124249, 34.0171348>,
    <1.7552640, 0.4388663, 34.0170234>,
    <1.7651566, 0.3881660, 34.0166273>,
    <1.7443262, 0.4918999, 34.0184620>,
    <1.7397242, 0.4998752, 34.0169117>,
    <1.7274813, -0.5677423, 34.0160024>,
    <1.7371863, -0.5529599, 34.0159774>,
    <1.7290904, -0.5831741, 34.0159774>,
    <1.7180138, -0.5968906, 34.0160617>,
    <1.7311592, -0.5627153, 34.0159774>,
    <1.7329028, -0.5689462, 34.0159774>,
    <1.7238029, -0.5893973, 34.0159774>,
    <1.7222310, -0.5831213, 34.0160336>,
    <1.7270888, -0.5775199, 34.0159774>,
    <1.6975737, -0.6359649, 34.0172683>,
    <1.7333338, -0.5370908, 34.0161023>,
    <1.7112216, -0.6069238, 34.0163144>,
    <1.7210499, -0.5692039, 34.0164769>,
    <1.7290817, -0.5575539, 34.0160336>,
    <1.7192854, -0.5827782, 34.0162021>,
    <1.7422921, -0.5205873, 34.0159774>,
    <1.7419346, -0.5352392, 34.0159774>,
    <1.7361821, -0.5435832, 34.0159774>,
    <1.7432376, -0.4922331, 34.0164673>,
    <1.7483909, -0.4750899, 34.0162110>,
    <1.7383169, -0.5120109, 34.0161961>,
    <1.7443896, -0.4998274, 34.0159774>,
    <1.7441464, -0.4972545, 34.0186055>,
    <1.7257743, -0.5584344, 34.0183725>,
    <1.7429994, -0.4906076, 34.0170795>,
    <1.7303222, -0.5351118, 34.0168520>,
    <1.7608944, -0.4331393, 34.0184620>,
    <1.7549782, -0.4457972, 34.0169117>,
    <1.7152527, -0.6118359, 34.0160024>,
    <1.7227789, -0.6067289, 34.0159774>,
    <1.7174226, -0.6267193, 34.0159774>,
    <1.7061662, -0.6324375, 34.0160617>,
    <1.7184858, -0.6094340, 34.0159774>,
    <1.7200411, -0.6169469, 34.0159774>,
    <1.7105405, -0.6315591, 34.0159774>,
    <1.7113949, -0.6200881, 34.0160336>,
    <1.7152686, -0.6193175, 34.0159774>,
    <1.7022811, -0.6330220, 34.0163144>,
    <1.7158679, -0.6062897, 34.0160336>,
    <1.7093187, -0.6176587, 34.0162021>,
    <1.7257556, -0.5956199, 34.0159774>,
    <1.7211328, -0.5997480, 34.0159774>,
    <1.8286248, 0.8390384, 34.3035582>,
    <1.7946678, 0.9134158, 34.3035582>,
    <1.8216222, 0.8493786, 34.3035582>,
    <1.8137686, 0.8715785, 34.3035582>,
    <1.7706867, 0.9609446, 34.3035582>,
    <1.7841639, 0.9289260, 34.3035582>,
    <1.8255612, 0.8435622, 34.3035582>,
    <1.7979051, 0.9025765, 34.3035582>,
    <1.8695843, 0.7543209, 34.3035582>,
    <1.8590805, 0.7698311, 34.3035582>,
    <1.8830616, 0.7223023, 34.3035582>,
    <1.8465446, 0.8019745, 34.3035582>,
    <1.8540926, 0.7832554, 34.3035582>,
    <1.8426299, 0.8183581, 34.3035582>,
    <1.8561071, 0.7863395, 34.3035582>,
    <1.8186488, 0.8658869, 34.3035582>,
    <1.8338767, 0.8312833, 34.3035582>,
    <1.6949519, -0.6615557, 34.0160024>,
    <1.6941628, -0.6766010, 34.0159774>,
    <1.6715651, -0.7250625, 34.0159774>,
    <1.6819022, -0.6864448, 34.0160617>,
    <1.6947817, -0.6673429, 34.0159774>,
    <1.6827398, -0.7010981, 34.0159774>,
    <1.6767216, -0.7057305, 34.0159774>,
    <1.6898396, -0.6703065, 34.0160336>,
    <1.6858573, -0.6863751, 34.0159774>,
    <1.6871311, -0.6672517, 34.0163144>,
    <1.7002128, -0.6474112, 34.0160336>,
    <1.6955511, -0.6515467, 34.0162021>,
    <1.7057513, -0.6517489, 34.0159774>,
    <1.7033605, -0.6483192, 34.0159774>,
    <1.6790208, 0.6931214, 34.0160090>,
    <1.6560483, 0.7377011, 34.0161247>,
    <1.6410839, 0.7882514, 34.0159774>,
    <1.6745578, 0.7164667, 34.0159774>,
    <1.6694440, 0.7115506, 34.0160485>,
    <1.6448266, 0.7720694, 34.0159774>,
    <1.6560607, 0.7561336, 34.0159774>,
    <1.6775490, 0.7019948, 34.0159774>,
    <1.6610209, 0.7374589, 34.0159774>,
    <1.6954016, 0.6717669, 34.0159774>,
    <1.6906973, 0.6646926, 34.0160485>,
    <1.6937599, 0.6662258, 34.0159774>,
    <1.6746738, 0.6895426, 34.0165664>,
    <1.6847928, 0.6711751, 34.0162618>,
    <1.6626393, -0.7311973, 34.0160024>,
    <1.6503108, -0.7706427, 34.0159774>,
    <1.6722024, -0.7082597, 34.0160336>,
    <1.6607216, -0.7483167, 34.0159774>,
    <1.6579709, -0.7464146, 34.0159774>,
    <1.6675088, -0.7257240, 34.0159774>,
    <1.6311949, -0.8116370, 34.0159774>,
    <1.6489421, -0.7554638, 34.0161023>,
    <1.6404347, -0.7918221, 34.0159774>,
    <1.6368521, -0.7913495, 34.0159774>,
    <1.6577845, -0.7391791, 34.0160336>,
    <1.6478598, -0.7678616, 34.0159774>,
    <1.6666029, -0.7104085, 34.0164769>,
    <1.6727086, -0.7010525, 34.0162021>,
    <1.7117973, -1.0973221, 34.2957497>,
    <1.6849477, -1.1257300, 34.2979383>,
    <1.6419558, -1.2155094, 34.2918019>,
    <1.6979935, -1.1354792, 34.2918021>,
    <1.7020283, -1.1067622, 34.2967308>,
    <1.6572955, -1.1811436, 34.2945156>,
    <1.6691407, -1.1766854, 34.2918020>,
    <1.7064047, -1.1131045, 34.2940173>,
    <1.6847485, -1.1424832, 34.2943648>,
    <1.7252258, -1.0965875, 34.2918022>,
    <1.7266888, -1.0724854, 34.2965012>,
    <1.7269109, -1.0830226, 34.2941812>,
    <1.7217933, -1.0562512, 34.3015015>,
    <1.7226519, -1.0680035, 34.2987032>,
    <1.5887386, 0.8865125, 34.0160024>,
    <1.5991951, 0.8780798, 34.0159774>,
    <1.6131371, 0.8481828, 34.0159774>,
    <1.5951565, 0.8701046, 34.0160617>,
    <1.5932002, 0.8827802, 34.0159774>,
    <1.6066524, 0.8620885, 34.0159774>,
    <1.6041671, 0.8591446, 34.0159774>,
    <1.5909839, 0.8798109, 34.0160336>,
    <1.5991337, 0.8701745, 34.0159774>,
    <1.5721672, 0.9006201, 34.0172683>,
    <1.5731944, 0.9118923, 34.0160617>,
    <1.5860645, 0.8810610, 34.0163144>,
    <1.5709538, 0.9090143, 34.0163144>,
    <1.5821056, 0.8970768, 34.0160336>,
    <1.5815715, 0.8925482, 34.0162021>,
    <1.5826594, 0.9135382, 34.0159774>,
    <1.5766877, 0.9135805, 34.0159774>,
    <1.5910893, 0.8954614, 34.0159774>,
    <1.5858059, 0.8973364, 34.0159774>,
    <1.6086605, 0.8447371, 34.0160024>,
    <1.6237137, 0.8255020, 34.0159774>,
    <1.6012750, 0.8580972, 34.0160336>,
    <1.6183250, 0.8370578, 34.0159774>,
    <1.6142915, 0.8379064, 34.0159774>,
    <1.6088609, 0.8493156, 34.0159774>,
    <1.6176125, 0.8203444, 34.0161023>,
    <1.6308008, 0.8103037, 34.0159774>,
    <1.6312931, 0.8010920, 34.0159774>,
    <1.6108801, 0.8374993, 34.0160336>,
    <1.6215353, 0.8221356, 34.0159774>,
    <1.6016032, 0.8471140, 34.0164769>,
    <1.5974453, 0.8599263, 34.0162021>,
    <1.6363076, 0.7751032, 34.0164673>,
    <1.6263456, 0.7975624, 34.0161961>,
    <1.6439166, 0.7597789, 34.0162110>,
    <1.6352141, 0.7847638, 34.0159774>,
    <1.6493057, 0.7523779, 34.0186055>,
    <1.6759152, 0.6914800, 34.0184620>,
    <1.6394704, 0.7667409, 34.0170795>,
    <1.6589672, 0.7236646, 34.0169117>,
    <1.6197591, 0.8135764, 34.0183725>,
    <1.6179803, 0.8119715, 34.0168520>,
    <1.6028164, -0.8593658, 34.0160024>,
    <1.6149399, -0.8464958, 34.0159774>,
    <1.6017209, -0.8748441, 34.0159774>,
    <1.5884316, -0.8864246, 34.0160617>,
    <1.6073111, -0.8550550, 34.0159774>,
    <1.6079457, -0.8614950, 34.0159774>,
    <1.5954338, -0.8800531, 34.0159774>,
    <1.5949756, -0.8735981, 34.0160336>,
    <1.6007321, -0.8689273, 34.0159774>,
    <1.5615085, -0.9213375, 34.0172683>,
    <1.6139016, -0.8301955, 34.0161023>,
    <1.5799989, -0.8951215, 34.0163144>,
    <1.5962260, -0.8596807, 34.0164769>,
    <1.6061615, -0.8496097, 34.0160336>,
    <1.5921333, -0.8727458, 34.0162021>,
    <1.6255899, -0.8155013, 34.0159774>,
    <1.6226931, -0.8298690, 34.0159774>,
    <1.6155798, -0.8370862, 34.0159774>,
    <1.6314854, -0.7875794, 34.0164606>,
    <1.6395942, -0.7714004, 34.0161961>,
    <1.6231632, -0.8063614, 34.0161961>,
    <1.6312606, -0.7954213, 34.0159774>,
    <1.6315966, -0.7922826, 34.0185831>,
    <1.6027336, -0.8498704, 34.0183725>,
    <1.6315836, -0.7857338, 34.0170646>,
    <1.6112740, -0.8277130, 34.0168520>,
    <1.6596712, -0.7304727, 34.0183725>,
    <1.6514605, -0.7426339, 34.0168520>,
    <1.5831180, -0.9006636, 34.0160024>,
    <1.5914161, -0.8969430, 34.0159774>,
    <1.5826712, -0.9156969, 34.0159774>,
    <1.5705921, -0.9193728, 34.0160617>,
    <1.5867190, -0.8988605, 34.0159774>,
    <1.5869462, -0.9065290, 34.0159774>,
    <1.5750530, -0.9192686, 34.0159774>,
    <1.5778859, -0.9081195, 34.0160336>,
    <1.5818348, -0.9080344, 34.0159774>,
    <1.5666627, -0.9192699, 34.0163144>,
    <1.5846867, -0.8953082, 34.0160336>,
    <1.5762619, -0.9053640, 34.0162021>,
    <1.5962761, -0.8865207, 34.0159774>,
    <1.5910074, -0.8897821, 34.0159774>,
    <1.5550377, 0.9428344, 34.0160024>,
    <1.5380418, 0.9648965, 34.0160617>,
    <1.5204291, 1.0024122, 34.0159774>,
    <1.5510954, 0.9586162, 34.0159774>,
    <1.5485255, 0.9505783, 34.0160336>,
    <1.5288637, 0.9842701, 34.0159774>,
    <1.5355939, 0.9807546, 34.0159774>,
    <1.5534426, 0.9493274, 34.0159774>,
    <1.5412205, 0.9667970, 34.0159774>,
    <1.5668213, 0.9361573, 34.0159774>,
    <1.5633644, 0.9284428, 34.0160336>,
    <1.5655825, 0.9312497, 34.0159774>,
    <1.5487070, 0.9430597, 34.0163144>,
    <1.5591875, 0.9298375, 34.0162021>,
    <1.5544917, -0.9461031, 34.0160024>,
    <1.5511013, -0.9607848, 34.0159774>,
    <1.5204307, -1.0045880, 34.0159774>,
    <1.5373177, -0.9683477, 34.0160617>,
    <1.5533190, -0.9517738, 34.0159774>,
    <1.5355974, -0.9829273, 34.0159774>,
    <1.5288667, -0.9864435, 34.0159774>,
    <1.5479372, -0.9538328, 34.0160336>,
    <1.5412249, -0.9689679, 34.0159774>,
    <1.5457987, -0.9503495, 34.0163144>,
    <1.5621289, -0.9330859, 34.0160336>,
    <1.5568188, -0.9363465, 34.0162021>,
    <1.5668300, -0.9383212, 34.0159774>,
    <1.5650714, -0.9345279, 34.0159774>,
    <1.6974491, 1.1172518, 34.2956998>,
    <1.6795016, 1.1618866, 34.2918021>,
    <1.6074374, 1.2648051, 34.2918015>,
    <1.6667262, 1.1512446, 34.2978493>,
    <1.6899984, 1.1361796, 34.2939985>,
    <1.6390085, 1.2197170, 34.2918019>,
    <1.6289864, 1.2214448, 34.2944686>,
    <1.6850414, 1.1304551, 34.2966652>,
    <1.6610832, 1.1760332, 34.2943273>,
    <1.7134294, 1.0673224, 34.3013243>,
    <1.7182988, 1.0837049, 34.2964357>,
    <1.7127667, 1.0810881, 34.2986283>,
    <1.7259425, 1.0955612, 34.2918022>,
    <1.7224627, 1.0889708, 34.2941437>,
    <1.5649628, 1.3060333, 34.2956984>,
    <1.5770087, 1.3082593, 34.2918000>,
    <1.5703718, 1.3177338, 34.2917980>,
    <1.5332640, 1.3361296, 34.2968946>,
    <1.5702193, 1.3074393, 34.2939968>,
    <1.5722033, 1.3151203, 34.2917990>,
    <1.5420784, 1.3366845, 34.2943320>,
    <1.5531761, 1.3169890, 34.2964341>,
    <1.5599758, 1.3190289, 34.2941414>,
    <1.5475923, 1.2985842, 34.3035582>,
    <1.5865292, 1.2672083, 34.2978489>,
    <1.5369287, 1.3187431, 34.3006306>,
    <1.5661909, 1.2805875, 34.3013240>,
    <1.5724844, 1.2922559, 34.2966643>,
    <1.5572320, 1.3030522, 34.2986274>,
    <1.5990576, 1.2646044, 34.2944683>,
    <1.5877621, 1.2929034, 34.2918009>,
    <1.5816460, 1.2903556, 34.2943263>,
    <1.6292241, 1.1968452, 34.2997409>,
    <1.6452217, 1.1774023, 34.2989154>,
    <1.6076032, 1.2319815, 34.2989152>,
    <1.6194306, 1.2242368, 34.2968524>,
    <1.6471490, 1.1535288, 34.3035582>,
    <1.5973707, 1.2260565, 34.3035582>,
    <1.6358386, 1.1797358, 34.3013919>,
    <1.6011447, 1.2311605, 34.3011850>,
    <1.6969273, 1.0810011, 34.3035582>,
    <1.6710621, 1.1294749, 34.3011851>,
    <1.6438330, -1.1765311, 34.2997908>,
    <1.6043181, -1.2418745, 34.2979380>,
    <1.6242921, -1.2083816, 34.2989809>,
    <1.6273586, -1.2241566, 34.2945154>,
    <1.6625927, -1.1531561, 34.2989809>,
    <1.6424387, -1.1915321, 34.2969274>,
    <1.6477253, -1.1538553, 34.3035582>,
    <1.6977918, -1.0814909, 34.3035582>,
    <1.6450274, -1.1674656, 34.3014107>,
    <1.6807031, -1.1168148, 34.3012225>,
    <1.5475923, -1.2985842, 34.3035582>,
    <1.5976588, -1.2262197, 34.3035582>,
    <1.5726315, -1.2715831, 34.3015014>,
    <1.6100094, -1.2188868, 34.3012225>,
    <1.5863387, -1.2774295, 34.2957490>,
    <1.6012168, -1.2736908, 34.2918011>,
    <1.5921053, -1.2769067, 34.2940164>,
    <1.6197276, -1.2472547, 34.2918015>,
    <1.5916400, -1.2655053, 34.2967303>,
    <1.6062549, -1.2551199, 34.2943643>,
    <1.5661603, -1.3004212, 34.2969728>,
    <1.5563379, -1.2974048, 34.3007902>,
    <1.5756839, -1.2892866, 34.2965003>,
    <1.5747407, -1.2809309, 34.2987027>,
    <1.5703911, -1.3177146, 34.2918001>,
    <1.5703344, -1.3060308, 34.2943894>,
    <1.5851844, -1.2965876, 34.2918006>,
    <1.5796727, -1.2938781, 34.2941799>,
    <1.5570483, -1.3168868, 34.2956253>,
    <1.5633589, -1.3247468, 34.2917991>,
    <1.5603754, -1.3197957, 34.2939688>,
    <1.5681381, -1.3199675, 34.2917996>,
    <1.5607522, -1.3095701, 34.2964536>,
    <1.5654675, -1.3133615, 34.2941791>,
    <1.5345193, -1.3350820, 34.2969721>,
    <1.5391146, -1.3166980, 34.3007900>,
    <1.5491753, -1.3221366, 34.2964534>,
    <1.5519476, -1.3114081, 34.2985183>,
    <1.5361162, -1.3519894, 34.2917986>,
    <1.5347643, -1.3441079, 34.2943884>,
    <1.5535270, -1.3345786, 34.2917988>,
    <1.5503615, -1.3292591, 34.2941785>,
    <1.5108581, 1.0064326, 34.0160024>,
    <1.4942411, 1.0262502, 34.0161023>,
    <1.4691625, 1.0756284, 34.0159774>,
    <1.4919365, 1.0431038, 34.0159774>,
    <1.5050462, 1.0128618, 34.0160336>,
    <1.4763184, 1.0593995, 34.0159774>,
    <1.4795895, 1.0607371, 34.0159774>,
    <1.5035105, 1.0208265, 34.0159774>,
    <1.4903571, 1.0394372, 34.0159774>,
    <1.5057132, 1.0234287, 34.0159774>,
    <1.5244377, 0.9851678, 34.0160336>,
    <1.5163199, 1.0023587, 34.0159774>,
    <1.5223367, 0.9801878, 34.0164769>,
    <1.5275780, 0.9757352, 34.0162021>,
    <1.5105762, -1.0090773, 34.0160024>,
    <1.4915844, -1.0457853, 34.0159774>,
    <1.5239771, -0.9881477, 34.0160336>,
    <1.5057137, -1.0256063, 34.0159774>,
    <1.5033359, -1.0232540, 34.0159774>,
    <1.5163219, -1.0045337, 34.0159774>,
    <1.4656406, -1.0828369, 34.0159774>,
    <1.4928726, -1.0305950, 34.0161023>,
    <1.4781807, -1.0649278, 34.0159774>,
    <1.4747351, -1.0638392, 34.0159774>,
    <1.5044090, -1.0160941, 34.0160336>,
    <1.4896542, -1.0426195, 34.0159774>,
    <1.5180866, -0.9892844, 34.0164769>,
    <1.5257263, -0.9811348, 34.0162021>,
    <1.4090910, 1.1505295, 34.0160090>,
    <1.4222130, 1.1426784, 34.0159774>,
    <1.4411333, 1.1156580, 34.0159774>,
    <1.4197650, 1.1339859, 34.0160841>,
    <1.4149516, 1.1468078, 34.0159774>,
    <1.4323331, 1.1282258, 34.0159774>,
    <1.4303961, 1.1248957, 34.0159774>,
    <1.4134712, 1.1433169, 34.0160485>,
    <1.4235244, 1.1348836, 34.0159774>,
    <1.3957657, 1.1561477, 34.0175836>,
    <1.3826013, 1.1796040, 34.0160841>,
    <1.4093460, 1.1427810, 34.0164039>,
    <1.3820978, 1.1751986, 34.0164039>,
    <1.3990253, 1.1614832, 34.0160485>,
    <1.4009293, 1.1553012, 34.0162618>,
    <1.3997732, 1.1747249, 34.0159774>,
    <1.3870310, 1.1805835, 34.0159774>,
    <1.4112131, 1.1583875, 34.0159774>,
    <1.4035196, 1.1614813, 34.0159774>,
    <1.4371859, 1.1117208, 34.0160090>,
    <1.4544972, 1.0965726, 34.0159774>,
    <1.4279168, 1.1231797, 34.0160485>,
    <1.4481739, 1.1056032, 34.0159774>,
    <1.4435592, 1.1064455, 34.0159774>,
    <1.4367250, 1.1160314, 34.0159774>,
    <1.4497896, 1.0899827, 34.0161247>,
    <1.4611459, 1.0870773, 34.0159774>,
    <1.4627354, 1.0787979, 34.0159774>,
    <1.4404577, 1.1052696, 34.0160485>,
    <1.4519465, 1.0942930, 34.0159774>,
    <1.4310858, 1.1115053, 34.0165664>,
    <1.4243898, 1.1237680, 34.0162618>,
    <1.4751220, 1.0499191, 34.0164673>,
    <1.4621300, 1.0693299, 34.0162110>,
    <1.4831813, 1.0390992, 34.0161961>,
    <1.4699273, 1.0626917, 34.0159774>,
    <1.4933433, 1.0277797, 34.0186055>,
    <1.5287854, 0.9741840, 34.0183725>,
    <1.4807592, 1.0407499, 34.0170795>,
    <1.5053098, 1.0046526, 34.0168520>,
    <1.4548089, 1.0816077, 34.0184620>,
    <1.4529468, 1.0801000, 34.0169117>,
    <1.4294173, -1.1249159, 34.0160090>,
    <1.4435795, -1.1143434, 34.0159774>,
    <1.4256386, -1.1399658, 34.0159774>,
    <1.4104457, -1.1492089, 34.0160841>,
    <1.4345801, -1.1214480, 34.0159774>,
    <1.4340869, -1.1279002, 34.0159774>,
    <1.4185423, -1.1440041, 34.0159774>,
    <1.4192393, -1.1375746, 34.0160485>,
    <1.4256921, -1.1339673, 34.0159774>,
    <1.3786679, -1.1787402, 34.0175836>,
    <1.4454285, -1.0981199, 34.0161247>,
    <1.4003488, -1.1567465, 34.0164039>,
    <1.4230237, -1.1241179, 34.0165664>,
    <1.4344211, -1.1158927, 34.0160485>,
    <1.4166707, -1.1362625, 34.0162618>,
    <1.4594499, -1.0856687, 34.0159774>,
    <1.4541022, -1.0993155, 34.0159774>,
    <1.4458436, -1.1051878, 34.0159774>,
    <1.4701137, -1.0591903, 34.0164673>,
    <1.4808985, -1.0446651, 34.0161961>,
    <1.4586738, -1.0762503, 34.0162110>,
    <1.4685217, -1.0668777, 34.0159774>,
    <1.4694192, -1.0638208, 34.0186055>,
    <1.4311213, -1.1155607, 34.0184620>,
    <1.4705417, -1.0573856, 34.0170795>,
    <1.4433360, -1.0952275, 34.0169117>,
    <1.5077610, -1.0078148, 34.0183725>,
    <1.4975751, -1.0183863, 34.0168520>,
    <1.4014038, -1.1636091, 34.0160090>,
    <1.4116525, -1.1599400, 34.0159774>,
    <1.3997832, -1.1768912, 34.0159774>,
    <1.3788756, -1.1868391, 34.0160841>,
    <1.4061526, -1.1615539, 34.0159774>,
    <1.4055855, -1.1686046, 34.0159774>,
    <1.3848083, -1.1859380, 34.0159774>,
    <1.3931684, -1.1718505, 34.0160485>,
    <1.3981265, -1.1713635, 34.0159774>,
    <1.3755083, -1.1857258, 34.0164039>,
    <1.4047955, -1.1577096, 34.0160485>,
    <1.3932119, -1.1677936, 34.0162618>,
    <1.4182486, -1.1505197, 34.0159774>,
    <1.4124935, -1.1528169, 34.0159774>,
    <1.4956840, -1.3782450, 34.2957477>,
    <1.4642475, -1.4014328, 34.2979371>,
    <1.4059550, -1.4821507, 34.2918001>,
    <1.4750324, -1.4130732, 34.2917991>,
    <1.4844569, -1.3858517, 34.2967291>,
    <1.4270931, -1.4509711, 34.2945139>,
    <1.4394662, -1.4486395, 34.2917996>,
    <1.4874575, -1.3927114, 34.2940148>,
    <1.4609906, -1.4178292, 34.2943627>,
    <1.5086002, -1.3795054, 34.2917988>,
    <1.5148047, -1.3565049, 34.2964993>,
    <1.5129225, -1.3666981, 34.2941785>,
    <1.5132080, -1.3399602, 34.3015011>,
    <1.5118067, -1.3515399, 34.2987020>,
    <1.4784085, 1.3956722, 34.2956971>,
    <1.4522154, 1.4358902, 34.2917980>,
    <1.3633907, 1.5247150, 34.2917980>,
    <1.4423582, 1.4238497, 34.2978474>,
    <1.4674642, 1.4127615, 34.2939952>,
    <1.4023034, 1.4858023, 34.2917980>,
    <1.3924202, 1.4859585, 34.2944657>,
    <1.4640087, 1.4065966, 34.2966629>,
    <1.4320543, 1.4469573, 34.2943241>,
    <1.5038247, 1.3500796, 34.3013236>,
    <1.5049748, 1.3664364, 34.2964333>,
    <1.5003698, 1.3632045, 34.2986267>,
    <1.5094604, 1.3786453, 34.2917980>,
    <1.5076901, 1.3719664, 34.2941405>,
    <1.3140681, 1.5575039, 34.2956971>,
    <1.3258964, 1.5622093, 34.2917980>,
    <1.3177337, 1.5703720, 34.2917980>,
    <1.2774249, 1.5814183, 34.2968946>,
    <1.3191393, 1.5599708, 34.2939952>,
    <1.3199818, 1.5681239, 34.2917980>,
    <1.2862875, 1.5838081, 34.2943320>,
    <1.3004286, 1.5661037, 34.2964333>,
    <1.3069979, 1.5695546, 34.2941405>,
    <1.2973079, 1.5460713, 34.3035582>,
    <1.3421691, 1.5230877, 34.2978474>,
    <1.2836681, 1.5644871, 34.3006306>,
    <1.3192881, 1.5321438, 34.3013236>,
    <1.3238586, 1.5452150, 34.2966629>,
    <1.3066883, 1.5528898, 34.2986267>,
    <1.3551795, 1.5229962, 34.2944657>,
    <1.3391438, 1.5489618, 34.2917980>,
    <1.3334068, 1.5451788, 34.2943241>,
    <1.3970715, 1.4617750, 34.2997396>,
    <1.4164408, 1.4456562, 34.2989138>,
    <1.3693511, 1.4923300, 34.2989138>,
    <1.3825160, 1.4869755, 34.2968503>,
    <1.4224501, 1.4223278, 34.3035582>,
    <1.3598790, 1.4841996, 34.3035582>,
    <1.4066449, 1.4461168, 34.3013912>,
    <1.3629293, 1.4901487, 34.3011842>,
    <1.4850212, 1.3604560, 34.3035582>,
    <1.4506580, 1.4033123, 34.3011842>,
    <1.4143594, -1.4436696, 34.2997902>,
    <1.3636191, -1.5007018, 34.2979376>,
    <1.3893285, -1.4713938, 34.2989802>,
    <1.3898697, -1.4878450, 34.2945143>,
    <1.4371925, -1.4242417, 34.2989801>,
    <1.4104580, -1.4583511, 34.2969264>,
    <1.4220285, -1.4218169, 34.3035582>,
    <1.4848104, -1.3602005, 34.3035582>,
    <1.4170663, -1.4348642, 34.3014103>,
    <1.4615865, -1.3918033, 34.3012220>,
    <1.2964647, -1.5450497, 34.3035582>,
    <1.3592466, -1.4834333, 34.3035582>,
    <1.3264539, -1.5235303, 34.3015013>,
    <1.3730698, -1.4788181, 34.3012222>,
    <1.3397890, -1.5327036, 34.2957491>,
    <1.3156314, -1.5515091, 34.2969737>,
    <1.3177236, -1.5703822, 34.2918022>,
    <1.3557308, -1.5323748, 34.2918011>,
    <1.3270524, -1.5423200, 34.2965007>,
    <1.3192285, -1.5583075, 34.2943908>,
    <1.3359636, -1.5521421, 34.2918017>,
    <1.3458258, -1.5335130, 34.2940164>,
    <1.3305752, -1.5480043, 34.2941807>,
    <1.3785522, -1.5095534, 34.2918006>,
    <1.3469978, -1.5217689, 34.2967301>,
    <1.3635669, -1.5145280, 34.2943637>,
    <1.3058119, -1.5460330, 34.3007906>,
    <1.3272610, -1.5335425, 34.2987028>,
    <1.3040327, -1.5664278, 34.2956272>,
    <1.3095742, -1.5760896, 34.2918022>,
    <1.3071036, -1.5702276, 34.2939713>,
    <1.3151123, -1.5722112, 34.2918022>,
    <1.3088022, -1.5596858, 34.2964552>,
    <1.3131991, -1.5647286, 34.2941811>,
    <1.2784437, -1.5801516, 34.2969740>,
    <1.2854858, -1.5620344, 34.3007907>,
    <1.2952167, -1.5700531, 34.2964552>,
    <1.2994378, -1.5595225, 34.2985194>,
    <1.2780098, -1.5981922, 34.2918022>,
    <1.2775797, -1.5896363, 34.2943910>,
    <1.2981823, -1.5840668, 34.2918022>,
    <1.2955588, -1.5777647, 34.2941812>,
    <1.3402405, 1.2260251, 34.0160090>,
    <1.3034094, 1.2600563, 34.0161247>,
    <1.2720549, 1.3024431, 34.0159774>,
    <1.3280611, 1.2464370, 34.0159774>,
    <1.3249392, 1.2400664, 34.0160485>,
    <1.2811066, 1.2885170, 34.0159774>,
    <1.2971131, 1.2773849, 34.0159774>,
    <1.3358217, 1.2338608, 34.0159774>,
    <1.3081614, 1.2615329, 34.0159774>,
    <1.3629355, 1.2115626, 34.0159774>,
    <1.3609367, 1.2033038, 34.0160485>,
    <1.3632883, 1.2057938, 34.0159774>,
    <1.3373925, 1.2211631, 34.0165664>,
    <1.3531762, 1.2073710, 34.0162618>,
    <1.3393440, -1.2293653, 34.0160090>,
    <1.3276319, -1.2490435, 34.0159774>,
    <1.2677144, -1.3089618, 34.0159774>,
    <1.3014015, -1.2644769, 34.0161247>,
    <1.3354342, -1.2365011, 34.0159774>,
    <1.2953793, -1.2812965, 34.0159774>,
    <1.2791557, -1.2926459, 34.0159774>,
    <1.3237945, -1.2436109, 34.0160485>,
    <1.3072972, -1.2645747, 34.0159774>,
    <1.3308671, -1.2308054, 34.0165664>,
    <1.3591299, -1.2078869, 34.0160485>,
    <1.3494503, -1.2141631, 34.0162618>,
    <1.3629429, -1.2137320, 34.0159774>,
    <1.3625910, -1.2089697, 34.0159774>,
    <1.1892599, 1.3768747, 34.0160024>,
    <1.2019690, 1.3725276, 34.0159774>,
    <1.2252957, 1.3492019, 34.0159774>,
    <1.2009041, 1.3636499, 34.0160617>,
    <1.1947283, 1.3748940, 34.0159774>,
    <1.2144459, 1.3600512, 34.0159774>,
    <1.2131178, 1.3564346, 34.0159774>,
    <1.1936627, 1.3713444, 34.0160336>,
    <1.2046154, 1.3650779, 34.0159774>,
    <1.1688917, 1.3844361, 34.0172683>,
    <1.1659741, 1.3954062, 34.0160617>,
    <1.1886190, 1.3708304, 34.0163144>,
    <1.1648588, 1.3919298, 34.0163144>,
    <1.1794145, 1.3845326, 34.0160336>,
    <1.1804655, 1.3800906, 34.0162021>,
    <1.1743032, 1.4001922, 34.0159774>,
    <1.1686773, 1.3981894, 34.0159774>,
    <1.1884073, 1.3860887, 34.0159774>,
    <1.1828014, 1.3860435, 34.0159774>,
    <1.2222687, 1.3444320, 34.0160024>,
    <1.2429919, 1.3315061, 34.0159774>,
    <1.2107598, 1.3544597, 34.0160336>,
    <1.2339757, 1.3405221, 34.0159774>,
    <1.2298956, 1.3399397, 34.0159774>,
    <1.2208903, 1.3488036, 34.0159774>,
    <1.2390258, 1.3245699, 34.0161023>,
    <1.2548497, 1.3196483, 34.0159774>,
    <1.2584631, 1.3111604, 34.0159774>,
    <1.2268306, 1.3383891, 34.0160336>,
    <1.2420965, 1.3275976, 34.0159774>,
    <1.2148348, 1.3442415, 34.0164769>,
    <1.2065394, 1.3548650, 34.0162021>,
    <1.2720749, 1.2884435, 34.0164673>,
    <1.2550263, 1.3061468, 34.0161961>,
    <1.2844604, 1.2766513, 34.0162110>,
    <1.2677323, 1.2971581, 34.0159774>,
    <1.2921092, 1.2714886, 34.0186055>,
    <1.3379387, 1.2233675, 34.0184620>,
    <1.2779207, 1.2816541, 34.0170795>,
    <1.3109707, 1.2478477, 34.0169117>,
    <1.2434084, 1.3188956, 34.0183725>,
    <1.2422520, 1.3168117, 34.0168520>,
    <1.2127881, -1.3560404, 34.0160024>,
    <1.2295323, -1.3471442, 34.0159774>,
    <1.2061937, -1.3704829, 34.0159774>,
    <1.1897435, -1.3768178, 34.0160617>,
    <1.2188256, -1.3531884, 34.0159774>,
    <1.2166091, -1.3600675, 34.0159774>,
    <1.1985040, -1.3732276, 34.0159774>,
    <1.2002805, -1.3670034, 34.0160336>,
    <1.2072882, -1.3645846, 34.0159774>,
    <1.1524866, -1.4003835, 34.0172683>,
    <1.2339774, -1.3316206, 34.0161023>,
    <1.1788413, -1.3820991, 34.0163144>,
    <1.2062097, -1.3543402, 34.0164769>,
    <1.2196070, -1.3476768, 34.0160336>,
    <1.1978989, -1.3652257, 34.0162021>,
    <1.2544129, -1.3173890, 34.0159774>,
    <1.2461664, -1.3305100, 34.0159774>,
    <1.2345724, -1.3373003, 34.0159774>,
    <1.2659152, -1.2967505, 34.0164673>,
    <1.2814610, -1.2819587, 34.0162110>,
    <1.2509839, -1.3122359, 34.0161961>,
    <1.2659993, -1.3010693, 34.0159774>,
    <1.2626656, -1.3029033, 34.0186055>,
    <1.2156547, -1.3472943, 34.0183725>,
    <1.2653576, -1.2963255, 34.0170795>,
    <1.2312793, -1.3294361, 34.0168520>,
    <1.3107744, -1.2540049, 34.0184620>,
    <1.3006949, -1.2608207, 34.0169117>,
    <1.1798806, -1.3883829, 34.0160024>,
    <1.1889510, -1.3877257, 34.0159774>,
    <1.1743179, -1.4023588, 34.0159774>,
    <1.1617102, -1.4016782, 34.0160617>,
    <1.1838813, -1.3879209, 34.0159774>,
    <1.1814714, -1.3952053, 34.0159774>,
    <1.1659385, -1.4031088, 34.0159774>,
    <1.1724134, -1.3935990, 34.0160336>,
    <1.1761537, -1.3948715, 34.0159774>,
    <1.1580498, -1.4002302, 34.0163144>,
    <1.1831861, -1.3838859, 34.0160336>,
    <1.1718277, -1.3904492, 34.0162021>,
    <1.1970830, -1.3795936, 34.0159774>,
    <1.1910165, -1.3808563, 34.0159774>,
    <1.1374398, -1.4212911, 34.0160024>,
    <1.1292329, -1.4339284, 34.0159774>,
    <1.0854316, -1.4645990, 34.0159774>,
    <1.1136931, -1.4363182, 34.0160617>,
    <1.1343988, -1.4262194, 34.0159774>,
    <1.1070915, -1.4494323, 34.0159774>,
    <1.0995642, -1.4504343, 34.0159774>,
    <1.1286367, -1.4263118, 34.0160336>,
    <1.1171538, -1.4382397, 34.0159774>,
    <1.1278146, -1.4222993, 34.0163144>,
    <1.1490679, -1.4116703, 34.0160336>,
    <1.1429607, -1.4129132, 34.0162021>,
    <1.1516952, -1.4181998, 34.0159774>,
    <1.1513402, -1.4140336, 34.0159774>,
    <1.1383279, 1.4182740, 34.0160024>,
    <1.1148128, 1.4331912, 34.0160617>,
    <1.0854284, 1.4624230, 34.0159774>,
    <1.1292244, 1.4317567, 34.0159774>,
    <1.1295606, 1.4233228, 34.0160336>,
    <1.0995597, 1.4482595, 34.0159774>,
    <1.1070859, 1.4472582, 34.0159774>,
    <1.1346074, 1.4238306, 34.0159774>,
    <1.1171474, 1.4360664, 34.0159774>,
    <1.1516836, 1.4160306, 34.0159774>,
    <1.1510755, 1.4075974, 34.0160336>,
    <1.1521983, 1.4109950, 34.0159774>,
    <1.1323095, 1.4163133, 34.0163144>,
    <1.1466775, 1.4074756, 34.0162021>,
    <1.2329594, -1.6162314, 34.2957498>,
    <1.1977796, -1.6333772, 34.2979383>,
    <1.1272109, -1.7037832, 34.2918022>,
    <1.2072388, -1.6477470, 34.2918022>,
    <1.2204595, -1.6216276, 34.2967308>,
    <1.1531203, -1.6763576, 34.2945157>,
    <1.1660336, -1.6765992, 34.2918022>,
    <1.2226294, -1.6293919, 34.2940173>,
    <1.1921879, -1.6495182, 34.2943649>,
    <1.2461297, -1.6205151, 34.2918022>,
    <1.2554036, -1.5979448, 34.2965012>,
    <1.2521816, -1.6081383, 34.2941812>,
    <1.2559431, -1.5804597, 34.3015015>,
    <1.2529660, -1.5921181, 34.2987032>,
    <1.0750613, 1.4629261, 34.0160024>,
    <1.0526711, 1.4758627, 34.0161023>,
    <1.0122138, 1.5136885, 34.0159774>,
    <1.0447376, 1.4909150, 34.0159774>,
    <1.0674019, 1.4669789, 34.0160336>,
    <1.0244888, 1.5008857, 34.0159774>,
    <1.0271047, 1.5032617, 34.0159774>,
    <1.0632331, 1.4739396, 34.0159774>,
    <1.0445081, 1.4869290, 34.0159774>,
    <1.0644122, 1.4771387, 34.0159774>,
    <1.0950955, 1.4475877, 34.0160336>,
    <1.0815860, 1.4609668, 34.0159774>,
    <1.0948350, 1.4421794, 34.0164769>,
    <1.1012767, 1.4397940, 34.0162021>,
    <1.0746350, -1.4654467, 34.0160024>,
    <1.0442346, -1.4934457, 34.0159774>,
    <1.0943856, -1.4503620, 34.0160336>,
    <1.0644135, -1.4793161, 34.0159774>,
    <1.0629833, -1.4762927, 34.0159774>,
    <1.0815888, -1.4631429, 34.0159774>,
    <1.0071825, -1.5193899, 34.0159774>,
    <1.0506379, -1.4796093, 34.0161023>,
    <1.0250918, -1.5068496, 34.0159774>,
    <1.0222259, -1.5046485, 34.0159774>,
    <1.0664393, -1.4699304, 34.0160336>,
    <1.0435031, -1.4898110, 34.0159774>,
    <1.0884550, -1.4494035, 34.0164769>,
    <1.0984253, -1.4443657, 34.0162021>,
    <1.2132084, 1.6307084, 34.2956984>,
    <1.1808333, 1.6662334, 34.2918000>,
    <1.0779156, 1.7382989, 34.2918012>,
    <1.1726919, 1.6520709, 34.2978488>,
    <1.1996341, 1.6458352, 34.2939968>,
    <1.1230027, 1.7067278, 34.2918007>,
    <1.1130446, 1.7049436, 34.2944682>,
    <1.1970547, 1.6388844, 34.2966643>,
    <1.1588120, 1.6733609, 34.2943262>,
    <1.2456062, 1.5895882, 34.3013240>,
    <1.2443522, 1.6064143, 34.2964341>,
    <1.2401640, 1.6021888, 34.2986274>,
    <1.2471596, 1.6197899, 34.2917990>,
    <1.2463128, 1.6126096, 34.2941414>,
    <1.0236132, 1.7620001, 34.2956991>,
    <1.0344675, 1.7687218, 34.2918010>,
    <1.0250020, 1.7753489, 34.2918001>,
    <0.9833982, 1.7792168, 34.2968953>,
    <1.0281938, 1.7653310, 34.2939976>,
    <1.0276108, 1.7735226, 34.2918006>,
    <0.9917087, 1.7831153, 34.2943332>,
    <1.0087040, 1.7681207, 34.2964348>,
    <1.0145803, 1.7726742, 34.2941425>,
    <1.0091265, 1.7478583, 34.3035582>,
    <1.0571469, 1.7328395, 34.2978491>,
    <0.9924837, 1.7636154, 34.3006308>,
    <1.0330916, 1.7378432, 34.3013241>,
    <1.0353577, 1.7515572, 34.2966647>,
    <1.0171363, 1.7561571, 34.2986278>,
    <1.0700261, 1.7350658, 34.2944683>,
    <1.0498198, 1.7579721, 34.2918013>,
    <1.0447868, 1.7532032, 34.2943267>,
    <1.1215813, 1.6816526, 34.2997408>,
    <1.1434066, 1.6690813, 34.2989152>,
    <1.0891148, 1.7070970, 34.2989153>,
    <1.1030281, 1.7041290, 34.2968523>,
    <1.1532172, 1.6469648, 34.3035582>,
    <1.0811718, 1.6974116, 34.3035582>,
    <1.1336385, 1.6677881, 34.3013919>,
    <1.0831550, 1.7038165, 34.3011850>,
    <1.2252625, 1.5965181, 34.3035582>,
    <1.1842247, 1.6330465, 34.3011850>,
    <1.1436141, -1.6547590, 34.3035582>,
    <1.2111844, -1.6087857, 34.3035582>,
    <1.1524691, -1.6458777, 34.3035582>,
    <1.1731761, -1.6346457, 34.3035582>,
    <1.2538245, -1.5769177, 34.3035582>,
    <1.2244669, -1.5954637, 34.3035582>,
    <1.1474881, -1.6508735, 34.3035582>,
    <1.2009331, -1.6136180, 34.3035582>,
    <1.0084735, -1.7467057, 34.3035582>,
    <1.0671887, -1.7096137, 34.3035582>,
    <1.0804713, -1.6962917, 34.3035582>,
    <1.0378311, -1.7281597, 34.3035582>,
    <1.1101780, -1.6787580, 34.3035582>,
    <1.0929363, -1.6892390, 34.3035582>,
    <1.1259040, -1.6725217, 34.3035582>,
    <1.0965463, -1.6910677, 34.3035582>,
    <1.1685442, -1.6406537, 34.3035582>,
    <1.1369728, -1.6614200, 34.3035582>,
    <1.1414565, -1.6664774, 34.2997909>,
    <1.0820572, -1.7144023, 34.2979383>,
    <1.1122256, -1.6897162, 34.2989810>,
    <1.1102182, -1.7063982, 34.2945157>,
    <1.1672267, -1.6512036, 34.2989810>,
    <1.1353202, -1.6805701, 34.2969276>,
    <1.1524691, -1.6458777, 34.3035582>,
    <1.2244669, -1.5954637, 34.3035582>,
    <1.1455072, -1.6580995, 34.3014107>,
    <1.1965041, -1.6230344, 34.3012225>,
    <1.0804713, -1.6962917, 34.3035582>,
    <1.0415859, -1.7305348, 34.3015015>,
    <1.0949050, -1.6941756, 34.3012225>,
    <1.0532342, -1.7420209, 34.2957498>,
    <1.0262219, -1.7563911, 34.2969740>,
    <1.0250131, -1.7753428, 34.2918022>,
    <1.0690329, -1.7445198, 34.2918022>,
    <1.0390506, -1.7493113, 34.2965012>,
    <1.0285889, -1.7637151, 34.2943910>,
    <1.0461382, -1.7605509, 34.2918022>,
    <1.0590653, -1.7439001, 34.2940173>,
    <1.0415496, -1.7555407, 34.2941812>,
    <1.0954673, -1.7260103, 34.2918022>,
    <1.0621765, -1.7324383, 34.2967308>,
    <1.0797820, -1.7282260, 34.2943649>,
    <1.0174903, -1.7492780, 34.3007907>,
    <1.0407306, -1.7406438, 34.2987032>,
    <1.0122142, -1.7690730, 34.2956273>,
    <1.0159947, -1.7795497, 34.2918022>,
    <1.0145792, -1.7733480, 34.2939713>,
    <1.0221231, -1.7766912, 34.2918022>,
    <1.0180817, -1.7632618, 34.2964553>,
    <1.0215371, -1.7689909, 34.2941812>,
    <0.9846294, -1.7781456, 34.2969740>,
    <0.9947112, -1.7615263, 34.3007907>,
    <1.0029023, -1.7711126, 34.2964553>,
    <1.0088876, -1.7614752, 34.2985195>,
    <0.9810689, -1.7958369, 34.2918022>,
    <0.9821313, -1.7873361, 34.2943910>,
    <1.0033894, -1.7854282, 34.2918022>,
    <1.0019001, -1.7787663, 34.2941812>,
    <1.1624647, 1.6405221, 34.3035582>,
    <1.2391338, 1.5868540, 34.3035582>,
    <1.1809597, 1.6276368, 34.3035582>,
    <1.0950431, 1.6877475, 34.3035582>,
    <1.1960074, 1.6170423, 34.3035582>,
    <1.2100468, 1.6072454, 34.3035582>,
    <1.1380014, 1.6576921, 34.3035582>,
    <1.1329678, 1.6611833, 34.3035582>,
    <1.1694003, 1.6356901, 34.3035582>,
    <1.1532172, 1.6469648, 34.3035582>,
    <1.0520848, 1.7178029, 34.3035582>,
    <1.0811718, 1.6974116, 34.3035582>,
    <1.1584189, 1.6433408, 34.3035582>,
    <1.1049629, 1.6807732, 34.3035582>,
    <1.2252625, 1.5965181, 34.3035582>,
    <1.2682209, 1.5664627, 34.3035582>,
    <1.2130309, 1.6051031, 34.3035582>,
    <0.9318760, 1.5627189, 34.0160024>,
    <0.9451631, 1.5606373, 34.0159774>,
    <0.9721839, 1.5417175, 34.0159774>,
    <0.9456033, 1.5517336, 34.0160617>,
    <0.9376206, 1.5617109, 34.0159774>,
    <0.9596159, 1.5505176, 34.0159774>,
    <0.9589348, 1.5467258, 34.0159774>,
    <0.9371530, 1.5580459, 34.0160336>,
    <0.9490614, 1.5537611, 34.0159774>,
    <0.9096905, 1.5669992, 34.0172683>,
    <0.9056417, 1.5769643, 34.0160617>,
    <0.9321072, 1.5567402, 34.0163144>,
    <0.9048479, 1.5734847, 34.0163144>,
    <0.9208319, 1.5685592, 34.0160336>,
    <0.9225370, 1.5644132, 34.0162021>,
    <0.9131163, 1.5830763, 34.0159774>,
    <0.9079213, 1.5801281, 34.0159774>,
    <0.9294538, 1.5716369, 34.0159774>,
    <0.9239396, 1.5706195, 34.0159774>,
    <0.9697012, 1.5367216, 34.0160024>,
    <0.9912697, 1.5283537, 34.0159774>,
    <0.9569215, 1.5443870, 34.0160336>,
    <0.9822389, 1.5346770, 34.0159774>,
    <0.9776145, 1.5338902, 34.0159774>,
    <0.9679139, 1.5405606, 34.0159774>,
    <0.9886951, 1.5207328, 34.0161023>,
    <1.0007651, 1.5217050, 34.0159774>,
    <1.0050905, 1.5144684, 34.0159774>,
    <0.9748318, 1.5318461, 34.0160336>,
    <0.9896526, 1.5253391, 34.0159774>,
    <0.9625433, 1.5351058, 34.0164769>,
    <0.9525944, 1.5440989, 34.0162021>,
    <1.0264972, 1.4916120, 34.0164606>,
    <1.0074929, 1.5054826, 34.0161961>,
    <1.0378860, 1.4841521, 34.0161961>,
    <1.0173573, 1.5017933, 34.0159774>,
    <1.0509518, 1.4771242, 34.0185831>,
    <1.1029903, 1.4387026, 34.0183725>,
    <1.0347929, 1.4849792, 34.0170646>,
    <1.0704760, 1.4593371, 34.0168520>,
    <0.9951033, 1.5150844, 34.0183725>,
    <0.9943791, 1.5128173, 34.0168520>,
    <0.9586805, -1.5465623, 34.0160024>,
    <0.9756757, -1.5414512, 34.0159774>,
    <0.9500534, -1.5593921, 34.0159774>,
    <0.9325494, -1.5628678, 34.0160617>,
    <0.9647890, -1.5450494, 34.0159774>,
    <0.9621189, -1.5509438, 34.0159774>,
    <0.9420038, -1.5607599, 34.0159774>,
    <0.9446982, -1.5550013, 34.0160336>,
    <0.9521552, -1.5537738, 34.0159774>,
    <0.8886208, -1.5810523, 34.0172683>,
    <0.9827219, -1.5269045, 34.0161023>,
    <0.9202854, -1.5664561, 34.0163144>,
    <0.9520568, -1.5438694, 34.0164769>,
    <0.9663800, -1.5398195, 34.0160336>,
    <0.9422545, -1.5530239, 34.0162021>,
    <1.0003964, -1.5199338, 34.0159774>,
    <0.9907037, -1.5309285, 34.0159774>,
    <0.9809346, -1.5336222, 34.0159774>,
    <1.0193957, -1.4987068, 34.0164606>,
    <1.0345723, -1.4887330, 34.0161961>,
    <1.0027263, -1.5108583, 34.0161961>,
    <1.0153478, -1.5053789, 34.0159774>,
    <1.0169628, -1.5028105, 34.0185831>,
    <0.9625669, -1.5385452, 34.0183725>,
    <1.0203186, -1.4971664, 34.0170646>,
    <0.9813375, -1.5235658, 34.0168520>,
    <1.0723885, -1.4632323, 34.0183725>,
    <1.0592219, -1.4697246, 34.0168520>,
    <0.9209719, -1.5724784, 34.0160024>,
    <0.9300795, -1.5733781, 34.0159774>,
    <0.9131290, -1.5852470, 34.0159774>,
    <0.9004302, -1.5825733, 34.0160617>,
    <0.9250526, -1.5726903, 34.0159774>,
    <0.9214153, -1.5794449, 34.0159774>,
    <0.9047454, -1.5845313, 34.0159774>,
    <0.9126371, -1.5763531, 34.0160336>,
    <0.9162358, -1.5781931, 34.0159774>,
    <0.8958795, -1.5810659, 34.0163144>,
    <0.9249324, -1.5686585, 34.0160336>,
    <0.9122000, -1.5733367, 34.0162021>,
    <0.9394996, -1.5667820, 34.0159774>,
    <0.9333058, -1.5669723, 34.0159774>,
    <0.8739168, 1.5949304, 34.0160024>,
    <0.8454987, 1.6067822, 34.0160617>,
    <0.8108468, 1.6307654, 34.0159774>,
    <0.8628450, 1.6065182, 34.0159774>,
    <0.8636219, 1.5987455, 34.0160336>,
    <0.8274850, 1.6191487, 34.0159774>,
    <0.8371697, 1.6184908, 34.0159774>,
    <0.8695219, 1.5996476, 34.0159774>,
    <0.8490214, 1.6092164, 34.0159774>,
    <0.8880886, 1.5947469, 34.0159774>,
    <0.8887215, 1.5864443, 34.0160336>,
    <0.8894686, 1.5898779, 34.0159774>,
    <0.8662637, 1.5929159, 34.0163144>,
    <0.8837201, 1.5858819, 34.0162021>,
    <0.8710280, -1.5986516, 34.0160024>,
    <0.8616808, -1.6092387, 34.0159774>,
    <0.7991409, -1.6384023, 34.0159774>,
    <0.8344180, -1.6142757, 34.0160617>,
    <0.8681066, -1.6025440, 34.0159774>,
    <0.8324905, -1.6228508, 34.0159774>,
    <0.8165614, -1.6264206, 34.0159774>,
    <0.8583697, -1.6035204, 34.0160336>,
    <0.8443435, -1.6135755, 34.0159774>,
    <0.8531471, -1.6018042, 34.0163144>,
    <0.8857258, -1.5904609, 34.0160336>,
    <0.8767422, -1.5919055, 34.0162021>,
    <0.8880981, -1.5969196, 34.0159774>,
    <0.8884715, -1.5927554, 34.0159774>,
    <0.9335684, -1.8057803, 34.2957497>,
    <0.8959453, -1.8165570, 34.2979383>,
    <0.8142139, -1.8736426, 34.2918017>,
    <0.9027634, -1.8323517, 34.2918021>,
    <0.9203211, -1.8089241, 34.2967308>,
    <0.8444966, -1.8511312, 34.2945155>,
    <0.8571710, -1.8536117, 34.2918020>,
    <0.9211089, -1.8169475, 34.2940172>,
    <0.8876333, -1.8314826, 34.2943648>,
    <0.9457949, -1.8122858, 34.2918022>,
    <0.9588483, -1.7916683, 34.2965012>,
    <0.9539046, -1.8011476, 34.2941812>,
    <0.9624174, -1.7745419, 34.3015015>,
    <0.9574599, -1.7855067, 34.2987032>,
    <0.7953880, 1.6318674, 34.0160024>,
    <0.7682326, 1.6420521, 34.0161023>,
    <0.7051702, 1.6800431, 34.0159774>,
    <0.7564356, 1.6561378, 34.0159774>,
    <0.7856070, 1.6352439, 34.0160336>,
    <0.7277935, 1.6656907, 34.0159774>,
    <0.7299972, 1.6684662, 34.0159774>,
    <0.7801295, 1.6414514, 34.0159774>,
    <0.7548542, 1.6531273, 34.0159774>,
    <0.7836605, 1.6434426, 34.0159774>,
    <0.8207456, 1.6188585, 34.0160336>,
    <0.8044304, 1.6300095, 34.0159774>,
    <0.8211972, 1.6135918, 34.0164769>,
    <0.8281514, 1.6122717, 34.0162021>,
    <0.9116014, 1.8166096, 34.2956978>,
    <0.8735458, 1.8459751, 34.2917991>,
    <0.7596865, 1.8990694, 34.2917983>,
    <0.8679952, 1.8306096, 34.2978476>,
    <0.8956051, 1.8291503, 34.2939960>,
    <0.8095667, 1.8758095, 34.2917986>,
    <0.8000731, 1.8723212, 34.2944660>,
    <0.8942754, 1.8218551, 34.2966633>,
    <0.8506265, 1.8491674, 34.2943247>,
    <0.9506525, 1.7817369, 34.3013237>,
    <0.9464903, 1.7980928, 34.2964340>,
    <0.9431025, 1.7932026, 34.2986271>,
    <0.9469241, 1.8117577, 34.2917996>,
    <0.9473414, 1.8045368, 34.2941416>,
    <0.7020977, 1.9129793, 34.2956970>,
    <0.7116217, 1.9214827, 34.2917979>,
    <0.7011537, 1.9263640, 34.2917977>,
    <0.6595044, 1.9229553, 34.2968945>,
    <0.7060312, 1.9170545, 34.2939951>,
    <0.7040379, 1.9250191, 34.2917978>,
    <0.6670134, 1.9282327, 34.2943318>,
    <0.6863522, 1.9164181, 34.2964332>,
    <0.6913505, 1.9219219, 34.2941404>,
    <0.6902837, 1.8965388, 34.3035582>,
    <0.7401837, 1.8900856, 34.2978474>,
    <0.6711611, 1.9091810, 34.3006305>,
    <0.7156245, 1.8908367, 34.3013235>,
    <0.7154763, 1.9047348, 34.2966628>,
    <0.6967325, 1.9061011, 34.2986266>,
    <0.7524798, 1.8945146, 34.2944658>,
    <0.7286047, 1.9135633, 34.2917980>,
    <0.7244764, 1.9079930, 34.2943241>,
    <0.8125264, 1.8508657, 34.2997396>,
    <0.8362024, 1.8422755, 34.2989139>,
    <0.7761353, 1.8702856, 34.2989138>,
    <0.7903518, 1.8697789, 34.2968504>,
    <0.8497051, 1.8221986, 34.3035582>,
    <0.7699944, 1.8593687, 34.3035582>,
    <0.8268080, 1.8393055, 34.3013912>,
    <0.7708356, 1.8660202, 34.3011842>,
    <0.9294158, 1.7850285, 34.3035582>,
    <0.8826578, 1.8138760, 34.3011843>,
    <0.8388908, -1.8282088, 34.3035582>,
    <0.9134158, -1.7946678, 34.3035582>,
    <0.8491572, -1.8209983, 34.3035582>,
    <0.8714955, -1.8135346, 34.3035582>,
    <0.9609446, -1.7706867, 34.3035582>,
    <0.9288153, -1.7838520, 34.3035582>,
    <0.8433824, -1.8250542, 34.3035582>,
    <0.9024843, -1.7976451, 34.3035582>,
    <0.6898409, -1.8952908, 34.3035582>,
    <0.7540995, -1.8689603, 34.3035582>,
    <0.7694991, -1.8581445, 34.3035582>,
    <0.7219702, -1.8821256, 34.3035582>,
    <0.8017946, -1.8460376, 34.3035582>,
    <0.7829971, -1.8533645, 34.3035582>,
    <0.8183581, -1.8426298, 34.3035582>,
    <0.7862288, -1.8557951, 34.3035582>,
    <0.8658869, -1.8186488, 34.3035582>,
    <0.8311911, -1.8336167, 34.3035582>,
    <0.8347307, -1.8393742, 34.2997908>,
    <0.7679076, -1.8762580, 34.2979379>,
    <0.8019070, -1.8571846, 34.2989808>,
    <0.7970273, -1.8732665, 34.2945153>,
    <0.8627613, -1.8288073, 34.2989809>,
    <0.8262371, -1.8521883, 34.2969274>,
    <0.8491572, -1.8209983, 34.3035582>,
    <0.9288153, -1.7838520, 34.3035582>,
    <0.8401765, -1.8318262, 34.3014107>,
    <0.8964878, -1.8061490, 34.3012225>,
    <0.7694991, -1.8581445, 34.3035582>,
    <0.7252549, -1.8851163, 34.3015013>,
    <0.7840778, -1.8585679, 34.3012224>,
    <0.7347202, -1.8984540, 34.2957487>,
    <0.7498365, -1.9036609, 34.2918006>,
    <0.7401327, -1.9013183, 34.2940160>,
    <0.7790884, -1.8900213, 34.2918012>,
    <0.7451936, -1.8905689, 34.2967300>,
    <0.7632599, -1.8894787, 34.2943640>,
    <0.7056249, -1.9079146, 34.2969724>,
    <0.6982698, -1.8993908, 34.3007901>,
    <0.7194870, -1.9031705, 34.2965000>,
    <0.7226519, -1.8949248, 34.2987025>,
    <0.7011224, -1.9263749, 34.2917990>,
    <0.7066757, -1.9155408, 34.2943888>,
    <0.7245005, -1.9154744, 34.2917998>,
    <0.7208594, -1.9097412, 34.2941794>,
    <0.6896294, -1.9179705, 34.2956249>,
    <0.6915260, -1.9289462, 34.2917985>,
    <0.6912128, -1.9225920, 34.2939684>,
    <0.6980499, -1.9271981, 34.2917988>,
    <0.6964160, -1.9132669, 34.2964533>,
    <0.6988173, -1.9195109, 34.2941785>,
    <0.6609001, -1.9221249, 34.2969719>,
    <0.6737223, -1.9075472, 34.3007899>,
    <0.6801089, -1.9183608, 34.2964531>,
    <0.6876778, -1.9099092, 34.2985181>,
    <0.6543181, -1.9389160, 34.2917983>,
    <0.6568411, -1.9307291, 34.2943881>,
    <0.6780992, -1.9325439, 34.2917984>,
    <0.6777912, -1.9257244, 34.2941782>,
    <0.8609120, 1.8184714, 34.3035582>,
    <0.9462262, 1.7794377, 34.3035582>,
    <0.8833260, 1.8110172, 34.3035582>,
    <0.7868048, 1.8537780, 34.3035582>,
    <0.8982370, 1.8013942, 34.3035582>,
    <0.9147761, 1.7952275, 34.3035582>,
    <0.8350654, 1.8323976, 34.3035582>,
    <0.8284901, 1.8339180, 34.3035582>,
    <0.8693173, 1.8156761, 34.3035582>,
    <0.8497051, 1.8221986, 34.3035582>,
    <0.7385443, 1.8751584, 34.3035582>,
    <0.7699944, 1.8593687, 34.3035582>,
    <0.8560090, 1.8201021, 34.3035582>,
    <0.7969264, 1.8477467, 34.3035582>,
    <0.9294158, 1.7850285, 34.3035582>,
    <0.9776763, 1.7636480, 34.3035582>,
    <0.9164925, 1.7919915, 34.3035582>,
    <0.7680537, -1.6468316, 34.0160024>,
    <0.7171907, -1.6766166, 34.0159774>,
    <0.8016931, -1.6300101, 34.0160336>,
    <0.7602455, -1.6565397, 34.0159774>,
    <0.7482157, -1.6585115, 34.0159774>,
    <0.7841394, -1.6416497, 34.0159774>,
    <0.6241490, -1.7200028, 34.0159774>,
    <0.7313808, -1.6615029, 34.0161023>,
    <0.6713631, -1.6979865, 34.0159774>,
    <0.6698887, -1.6947055, 34.0159774>,
    <0.7533708, -1.6525434, 34.0160336>,
    <0.7099285, -1.6762550, 34.0159774>,
    <0.7950796, -1.6284669, 34.0164769>,
    <0.8065668, -1.6248717, 34.0162021>,
    <0.6527223, 1.6979830, 34.0160090>,
    <0.6622161, 1.7000727, 34.0159774>,
    <0.6890008, 1.6790605, 34.0161247>,
    <0.6557399, 1.6992896, 34.0159774>,
    <0.6827795, 1.6904840, 34.0159774>,
    <0.7008712, 1.6782448, 34.0159774>,
    <0.6659404, 1.6909488, 34.0160485>,
    <0.6768404, 1.6895055, 34.0159774>,
    <0.6220541, 1.7025844, 34.0175836>,
    <0.6186142, 1.7101962, 34.0160841>,
    <0.6672047, 1.6856480, 34.0165664>,
    <0.6197940, 1.7061386, 34.0164039>,
    <0.6368321, 1.7036953, 34.0160485>,
    <0.6451187, 1.6972355, 34.0162618>,
    <0.6241346, 1.7178300, 34.0159774>,
    <0.6197926, 1.7139023, 34.0159774>,
    <0.6428708, 1.7090933, 34.0159774>,
    <0.6375902, 1.7071465, 34.0159774>,
    <0.7411409, 1.6523636, 34.0164673>,
    <0.7165103, 1.6643740, 34.0162110>,
    <0.7529949, 1.6472921, 34.0161961>,
    <0.7232760, 1.6641045, 34.0159774>,
    <0.7750703, 1.6389354, 34.0186055>,
    <0.8335233, 1.6098498, 34.0183725>,
    <0.7544502, 1.6454221, 34.0170795>,
    <0.7944322, 1.6261617, 34.0168520>,
    <0.7132962, 1.6668178, 34.0184620>,
    <0.7078448, 1.6668139, 34.0169117>,
    <0.7049866, -1.6708965, 34.0164769>,
    <0.6390092, -1.7018752, 34.0161573>,
    <0.7176023, -1.6658811, 34.0161961>,
    <0.6349087, -1.7094186, 34.0159774>,
    <0.6763710, -1.6841303, 34.0162327>,
    <0.6750178, -1.6881248, 34.0159774>,
    <0.5886800, -1.7173371, 34.0180289>,
    <0.7276426, -1.6628712, 34.0186381>,
    <0.6271497, -1.7036296, 34.0166970>,
    <0.6665287, -1.6891496, 34.0185926>,
    <0.7197172, -1.6634880, 34.0171013>,
    <0.6713138, -1.6847760, 34.0169987>,
    <0.7914394, -1.6324630, 34.0183725>,
    <0.7635512, -1.6430287, 34.0168520>,
    <0.5878969, -1.7228952, 34.0160187>,
    <0.5709837, -1.7342494, 34.0159774>,
    <0.5193328, -1.7480899, 34.0159774>,
    <0.5549899, -1.7314114, 34.0161167>,
    <0.5804221, -1.7278640, 34.0159774>,
    <0.5448743, -1.7412458, 34.0159774>,
    <0.5374581, -1.7396129, 34.0159774>,
    <0.5742689, -1.7262855, 34.0160703>,
    <0.5581581, -1.7341696, 34.0159774>,
    <0.5713348, -1.7237607, 34.0165345>,
    <0.6082130, -1.7149743, 34.0160703>,
    <0.5960337, -1.7167858, 34.0163488>,
    <0.5974717, -1.7271515, 34.0159774>,
    <0.6063523, -1.7194829, 34.0159774>,
    <0.5841544, 1.7225192, 34.0160090>,
    <0.5568045, 1.7285818, 34.0160841>,
    <0.5193298, 1.7459122, 34.0159774>,
    <0.5709758, 1.7320738, 34.0159774>,
    <0.5741016, 1.7243149, 34.0160485>,
    <0.5374536, 1.7374360, 34.0159774>,
    <0.5448692, 1.7390690, 34.0159774>,
    <0.5787656, 1.7264572, 34.0159774>,
    <0.5581519, 1.7319933, 34.0159774>,
    <0.5974607, 1.7249772, 34.0159774>,
    <0.5998016, 1.7168479, 34.0160485>,
    <0.5997485, 1.7203831, 34.0159774>,
    <0.5786096, 1.7189719, 34.0164039>,
    <0.5953854, 1.7154308, 34.0162618>,
    <0.6058463, -1.9405933, 34.2957473>,
    <0.5670335, -1.9452918, 34.2979367>,
    <0.4765129, -1.9865587, 34.2917994>,
    <0.5708761, -1.9612742, 34.2917986>,
    <0.5922853, -1.9415584, 34.2967288>,
    <0.5103270, -1.9701574, 34.2945134>,
    <0.5222908, -1.9742926, 34.2917989>,
    <0.5916243, -1.9493415, 34.2940143>,
    <0.5561638, -1.9579946, 34.2943622>,
    <0.6167311, -1.9489874, 34.2917984>,
    <0.6331743, -1.9310018, 34.2964990>,
    <0.6266511, -1.9394273, 34.2941782>,
    <0.6397371, -1.9151855, 34.3015009>,
    <0.6329039, -1.9248456, 34.2987017>,
    <0.5085835, -1.7453295, 34.0160187>,
    <0.4707539, -1.7611069, 34.0159774>,
    <0.5319098, -1.7380791, 34.0160703>,
    <0.4945486, -1.7547310, 34.0159774>,
    <0.4942389, -1.7514006, 34.0159774>,
    <0.5162200, -1.7454073, 34.0159774>,
    <0.4270631, -1.7728138, 34.0159774>,
    <0.4804428, -1.7507517, 34.0161573>,
    <0.4481813, -1.7671552, 34.0159774>,
    <0.4462410, -1.7641066, 34.0159774>,
    <0.4989558, -1.7469093, 34.0160703>,
    <0.4713099, -1.7574411, 34.0159774>,
    <0.5231285, -1.7366724, 34.0166970>,
    <0.5356365, -1.7347422, 34.0163488>,
    <0.5093826, 1.7428638, 34.0160090>,
    <0.4838471, 1.7474181, 34.0161247>,
    <0.4334334, 1.7689281, 34.0159774>,
    <0.4713899, 1.7587577, 34.0159774>,
    <0.5007584, 1.7440831, 34.0160485>,
    <0.4491052, 1.7611604, 34.0159774>,
    <0.4507288, 1.7642938, 34.0159774>,
    <0.4945547, 1.7491375, 34.0159774>,
    <0.4725814, 1.7549218, 34.0159774>,
    <0.4945468, 1.7525528, 34.0159774>,
    <0.5333934, 1.7353387, 34.0160485>,
    <0.5162166, 1.7432298, 34.0159774>,
    <0.5345295, 1.7304676, 34.0165664>,
    <0.5415842, 1.7303113, 34.0162618>,
    <0.5823107, 1.9473495, 34.2956983>,
    <0.5397281, 1.9696190, 34.2917999>,
    <0.4183747, 2.0021365, 34.2918015>,
    <0.5369665, 1.9537507, 34.2978488>,
    <0.5643758, 1.9568962, 34.2939967>,
    <0.4715378, 1.9878911, 34.2918008>,
    <0.4628194, 1.9829586, 34.2944683>,
    <0.5643451, 1.9495580, 34.2966642>,
    <0.5166111, 1.9688450, 34.2943262>,
    <0.6268417, 1.9198985, 34.3013240>,
    <0.6198810, 1.9351470, 34.2964340>,
    <0.6174006, 1.9297892, 34.2986274>,
    <0.6179364, 1.9486626, 34.2917988>,
    <0.6195992, 1.9416248, 34.2941412>,
    <0.3593522, 2.0064421, 34.2956998>,
    <0.3671475, 2.0158631, 34.2918021>,
    <0.3559926, 2.0188520, 34.2918022>,
    <0.3157153, 2.0090957, 34.2968965>,
    <0.3624728, 2.0108812, 34.2939985>,
    <0.3590656, 2.0180287, 34.2918022>,
    <0.3221202, 2.0151851, 34.2943349>,
    <0.3432751, 2.0072422, 34.2964357>,
    <0.3471773, 2.0131646, 34.2941437>,
    <0.3508107, 1.9895466, 34.3035582>,
    <0.4008652, 1.9906820, 34.2978493>,
    <0.3296922, 1.9981333, 34.3006313>,
    <0.3766645, 1.9878103, 34.3013243>,
    <0.3739784, 2.0007557, 34.2966652>,
    <0.3553454, 1.9992031, 34.2986283>,
    <0.4121196, 1.9966923, 34.2944686>,
    <0.3852476, 2.0110131, 34.2918019>,
    <0.3822126, 2.0051692, 34.2943273>,
    <0.4788987, 1.9645010, 34.2997408>,
    <0.5036691, 1.9599387, 34.2989152>,
    <0.4397015, 1.9773832, 34.2989154>,
    <0.4537343, 1.9790361, 34.2968524>,
    <0.5205472, 1.9430427, 34.3035582>,
    <0.4356790, 1.9662946, 34.3035582>,
    <0.4949952, 1.9557336, 34.3013919>,
    <0.4352859, 1.9726172, 34.3011851>,
    <0.6054155, 1.9197908, 34.3035582>,
    <0.5543546, 1.9400601, 34.3011849>,
    <0.5090568, -1.9482801, 34.3035582>,
    <0.5878928, -1.9260189, 34.3035582>,
    <0.5206129, -1.9440468, 34.3035582>,
    <0.5435476, -1.9385408, 34.3035582>,
    <0.6388669, -1.9106548, 34.3035582>,
    <0.6052269, -1.9196688, 34.3035582>,
    <0.5141126, -1.9464280, 34.3035582>,
    <0.5768509, -1.9284091, 34.3035582>,
    <0.3513849, -1.9928027, 34.3035582>,
    <0.4186648, -1.9747748, 34.3035582>,
    <0.4359989, -1.9684247, 34.3035582>,
    <0.3850248, -1.9837888, 34.3035582>,
    <0.4695103, -1.9598716, 34.3035582>,
    <0.4499298, -1.9649761, 34.3035582>,
    <0.4859446, -1.9567469, 34.3035582>,
    <0.4523047, -1.9657609, 34.3035582>,
    <0.5369187, -1.9413829, 34.3035582>,
    <0.5003897, -1.9514552, 34.3035582>,
    <0.5030404, -1.9585919, 34.2997899>,
    <0.4309079, -1.9837426, 34.2979372>,
    <0.4676724, -1.9707043, 34.2989799>,
    <0.4598229, -1.9842013, 34.2945137>,
    <0.5323550, -1.9523308, 34.2989797>,
    <0.4923177, -1.9689413, 34.2969259>,
    <0.5206129, -1.9440468, 34.3035582>,
    <0.6052269, -1.9196688, 34.3035582>,
    <0.5097892, -1.9525541, 34.3014101>,
    <0.5695112, -1.9359439, 34.3012219>,
    <0.4359989, -1.9684247, 34.3035582>,
    <0.3877496, -1.9873114, 34.3015012>,
    <0.4500740, -1.9701451, 34.3012220>,
    <0.3942721, -1.9992434, 34.2957487>,
    <0.3641108, -2.0043109, 34.2969736>,
    <0.3559899, -2.0188527, 34.2918022>,
    <0.4079062, -2.0049418, 34.2918006>,
    <0.3785366, -2.0017450, 34.2965005>,
    <0.3635809, -2.0105838, 34.2943907>,
    <0.3809049, -2.0121768, 34.2918014>,
    <0.3989566, -2.0021277, 34.2940160>,
    <0.3785379, -2.0072181, 34.2941804>,
    <0.4390801, -1.9965888, 34.2918000>,
    <0.4060186, -1.9936713, 34.2967297>,
    <0.4237937, -1.9945239, 34.2943632>,
    <0.3587019, -1.9967183, 34.3007905>,
    <0.3832665, -1.9952429, 34.2987026>,
    <0.5313918, 1.9398238, 34.3035582>,
    <0.6216823, 1.9149623, 34.3035582>,
    <0.5530809, 1.9333859, 34.3035582>,
    <0.4519458, 1.9614662, 34.3035582>,
    <0.5708939, 1.9289469, 34.3035582>,
    <0.5873816, 1.9241741, 34.3035582>,
    <0.5025134, 1.9474261, 34.3035582>,
    <0.4966342, 1.9492923, 34.3035582>,
    <0.5395252, 1.9374096, 34.3035582>,
    <0.5205472, 1.9430427, 34.3035582>,
    <0.4013783, 1.9755064, 34.3035582>,
    <0.4356790, 1.9662946, 34.3035582>,
    <0.5266473, 1.9412320, 34.3035582>,
    <0.4636739, 1.9584698, 34.3035582>,
    <0.6054155, 1.9197908, 34.3035582>,
    <0.6559830, 1.9057506, 34.3035582>,
    <0.5909762, 1.9235919, 34.3035582>,
    <0.3464810, -2.0107035, 34.2956272>,
    <0.3460786, -2.0197209, 34.2918022>,
    <0.3470803, -2.0146116, 34.2939713>,
    <0.3528140, -2.0191311, 34.2918022>,
    <0.3540627, -2.0077086, 34.2964551>,
    <0.3551288, -2.0130134, 34.2941811>,
    <0.3175862, -2.0105346, 34.2969740>,
    <0.3331070, -2.0004630, 34.3007907>,
    <0.3371137, -2.0098943, 34.2964552>,
    <0.3462346, -2.0040295, 34.2985194>,
    <0.3076911, -2.0230801, 34.2918022>,
    <0.3118475, -2.0168907, 34.2943910>,
    <0.3322241, -2.0209334, 34.2918022>,
    <0.3333337, -2.0154829, 34.2941812>,
    <0.3392046, 1.7876607, 34.0160187>,
    <0.3613078, 1.7882533, 34.0159774>,
    <0.3877269, 1.7811749, 34.0159774>,
    <0.3594128, 1.7816803, 34.0161167>,
    <0.3490257, 1.7878014, 34.0159774>,
    <0.3727305, 1.7851929, 34.0159774>,
    <0.3731083, 1.7814716, 34.0159774>,
    <0.3476314, 1.7849575, 34.0160703>,
    <0.3613210, 1.7847332, 34.0159774>,
    <0.3373395, 1.7823843, 34.0180289>,
    <0.2933026, 1.7929764, 34.0161573>,
    <0.3475635, 1.7817133, 34.0165345>,
    <0.2963447, 1.7900483, 34.0166970>,
    <0.3234933, 1.7897773, 34.0160703>,
    <0.3293813, 1.7865497, 34.0163488>,
    <0.3767421, 1.7841174, 34.0159774>,
    <0.3273853, 1.7904850, 34.0159774>,
    <0.3603485, 1.7885102, 34.0159774>,
    <0.3370578, 1.7899160, 34.0159774>,
    <0.3865087, 1.7758649, 34.0160187>,
    <0.4096605, 1.7752980, 34.0159774>,
    <0.3724566, 1.7786354, 34.0160703>,
    <0.3994077, 1.7780451, 34.0159774>,
    <0.3946926, 1.7758952, 34.0159774>,
    <0.3835521, 1.7787767, 34.0159774>,
    <0.4102392, 1.7674028, 34.0161573>,
    <0.4203732, 1.7724276, 34.0159774>,
    <0.4264432, 1.7672326, 34.0159774>,
    <0.3932463, 1.7730650, 34.0160703>,
    <0.4085701, 1.7720733, 34.0159774>,
    <0.3848438, 1.7716222, 34.0166970>,
    <0.3708813, 1.7767483, 34.0163488>,
    <0.4544165, 1.7531490, 34.0164836>,
    <0.4324530, 1.7595940, 34.0162327>,
    <0.4671732, 1.7501164, 34.0162110>,
    <0.4420711, 1.7595801, 34.0159774>,
    <0.4832177, 1.7478507, 34.0186605>,
    <0.5434240, 1.7299491, 34.0184620>,
    <0.4649116, 1.7497427, 34.0171162>,
    <0.5059698, 1.7381276, 34.0169117>,
    <0.4220961, 1.7639665, 34.0185926>,
    <0.4203618, 1.7617640, 34.0169987>,
    <0.4453587, -1.7576725, 34.0164769>,
    <0.4017276, -1.7714864, 34.0161023>,
    <0.4625770, -1.7536744, 34.0162327>,
    <0.4204998, -1.7710040, 34.0159774>,
    <0.4259383, -1.7632536, 34.0161961>,
    <0.4395276, -1.7624405, 34.0159774>,
    <0.2982102, -1.7898510, 34.0172683>,
    <0.4410514, -1.7609479, 34.0186381>,
    <0.3677719, -1.7768715, 34.0164769>,
    <0.3794434, -1.7754104, 34.0183725>,
    <0.4464347, -1.7566871, 34.0171013>,
    <0.4019293, -1.7678223, 34.0168520>,
    <0.5032750, -1.7441195, 34.0185926>,
    <0.4901145, -1.7451456, 34.0169987>,
    <0.3722569, -1.7817527, 34.0160024>,
    <0.3899107, -1.7827688, 34.0159774>,
    <0.3596963, -1.7908647, 34.0159774>,
    <0.3422796, -1.7881225, 34.0160617>,
    <0.3784493, -1.7824267, 34.0159774>,
    <0.3739244, -1.7870523, 34.0159774>,
    <0.3516637, -1.7893970, 34.0159774>,
    <0.3563130, -1.7848926, 34.0160336>,
    <0.3635929, -1.7863040, 34.0159774>,
    <0.3301927, -1.7872344, 34.0163144>,
    <0.3818805, -1.7780418, 34.0160336>,
    <0.3551363, -1.7821551, 34.0162021>,
    <0.4076316, -1.7780205, 34.0159774>,
    <0.3975298, -1.7772106, 34.0159774>,
    <0.3279561, -1.7932095, 34.0160024>,
    <0.3361409, -1.7971764, 34.0159774>,
    <0.3161498, -1.8025330, 34.0159774>,
    <0.3055709, -1.7956359, 34.0160617>,
    <0.3316524, -1.7948108, 34.0159774>,
    <0.3259226, -1.7999144, 34.0159774>,
    <0.3085186, -1.7989926, 34.0159774>,
    <0.3188804, -1.7939919, 34.0160336>,
    <0.3214843, -1.7969665, 34.0159774>,
    <0.3031206, -1.7925409, 34.0163144>,
    <0.3330669, -1.7909663, 34.0160336>,
    <0.3199453, -1.7909640, 34.0162021>,
    <0.3472503, -1.7941996, 34.0159774>,
    <0.3413645, -1.7922601, 34.0159774>,
    <0.2747470, -1.8004884, 34.0160024>,
    <0.2613217, -1.8073302, 34.0159774>,
    <0.2080548, -1.8119907, 34.0159774>,
    <0.2466677, -1.8016263, 34.0160617>,
    <0.2696498, -1.8032370, 34.0159774>,
    <0.2343956, -1.8096861, 34.0159774>,
    <0.2273757, -1.8067902, 34.0159774>,
    <0.2646125, -1.8004335, 34.0160336>,
    <0.2487055, -1.8050243, 34.0159774>,
    <0.2659021, -1.7965355, 34.0163144>,
    <0.2896268, -1.7979694, 34.0160336>,
    <0.2837136, -1.7959849, 34.0162021>,
    <0.2886382, -1.8049402, 34.0159774>,
    <0.2904140, -1.8011546, 34.0159774>,
    <0.1981402, -1.8073379, 34.0160024>,
    <0.1573249, -1.8164291, 34.0159774>,
    <0.2229260, -1.8041359, 34.0160336>,
    <0.1824946, -1.8142270, 34.0159774>,
    <0.1824524, -1.8109211, 34.0159774>,
    <0.2054548, -1.8088084, 34.0159774>,
    <0.1065959, -1.8208673, 34.0159774>,
    <0.1698638, -1.8076361, 34.0161023>,
    <0.1321554, -1.8186311, 34.0159774>,
    <0.1304584, -1.8153196, 34.0159774>,
    <0.1886251, -1.8071369, 34.0160336>,
    <0.1578784, -1.8129708, 34.0159774>,
    <0.2182613, -1.8003215, 34.0164769>,
    <0.2294194, -1.8009556, 34.0162021>,
    <0.2600145, -2.0182993, 34.2957498>,
    <0.2210778, -2.0164664, 34.2979383>,
    <0.1242951, -2.0391256, 34.2918022>,
    <0.2216225, -2.0306105, 34.2918022>,
    <0.2465563, -2.0171829, 34.2967308>,
    <0.1606214, -2.0295832, 34.2945157>,
    <0.1715103, -2.0349948, 34.2918022>,
    <0.2443349, -2.0236129, 34.2940173>,
    <0.2079147, -2.0259395, 34.2943649>,
    <0.2689200, -2.0264724, 34.2918022>,
    <0.2886833, -2.0141431, 34.2965012>,
    <0.2805802, -2.0200987, 34.2941812>,
    <0.2983027, -2.0018311, 34.3015015>,
    <0.2896723, -2.0090238, 34.2987032>,
    <0.2354180, 2.0194203, 34.2956998>,
    <0.1895083, 2.0334188, 34.2918022>,
    <0.0643499, 2.0443697, 34.2918022>,
    <0.1896817, 2.0177087, 34.2978494>,
    <0.2160525, 2.0254933, 34.2939985>,
    <0.1191805, 2.0395722, 34.2918022>,
    <0.1115026, 2.0332381, 34.2944689>,
    <0.2173611, 2.0184989, 34.2966653>,
    <0.1669399, 2.0288976, 34.2943274>,
    <0.2841847, 2.0007591, 34.3013243>,
    <0.2745623, 2.0141180, 34.2964357>,
    <0.2731061, 2.0086520, 34.2986283>,
    <0.2701676, 2.0263614, 34.2918022>,
    <0.2730956, 2.0201085, 34.2941437>,
    <0.0054819, 2.0373738, 34.2956998>,
    <0.0115120, 2.0489927, 34.2918022>,
    <-0.0000000, 2.0499999, 34.2918022>,
    <-0.0379594, 2.0319799, 34.2968965>,
    <0.0077781, 2.0426976, 34.2939985>,
    <0.0031731, 2.0497223, 34.2918022>,
    <-0.0327143, 2.0397935, 34.2943349>,
    <-0.0104943, 2.0350943, 34.2964357>,
    <-0.0076860, 2.0422085, 34.2941437>,
    <0.0000039, 2.0169302, 34.3035582>,
    <0.0491369, 2.0289555, 34.2978494>,
    <-0.0222850, 2.0226101, 34.3006313>,
    <0.0257910, 2.0207429, 34.3013243>,
    <0.0208839, 2.0341788, 34.2966653>,
    <0.0027994, 2.0287795, 34.2986283>,
    <0.0591623, 2.0375775, 34.2944689>,
    <0.0301823, 2.0473592, 34.2918022>,
    <0.0282202, 2.0405308, 34.2943274>,
    <0.1306088, 2.0173584, 34.2997410>,
    <0.1558084, 2.0176056, 34.2989154>,
    <0.0897321, 2.0228947, 34.2989154>,
    <0.1032595, 2.0274694, 34.2968527>,
    <0.1754073, 2.0032384, 34.3035582>,
    <0.0877056, 2.0100843, 34.3035582>,
    <0.1480077, 2.0114243, 34.3013920>,
    <0.0862161, 2.0168556, 34.3011851>,
    <0.2631090, 1.9963925, 34.3035582>,
    <0.2092384, 2.0071476, 34.3011851>,
    <0.1094191, 1.8125749, 34.0162913>,
    <0.1641493, 1.8187595, 34.0176445>,
    <0.1542392, 1.8032850, 34.0160475>,
    <0.1338979, 1.8147375, 34.0166837>,
    <0.2909683, 1.7999201, 34.0168568>,
    <0.2878717, 1.7948930, 34.0160951>,
    <0.1280067, 1.8081256, 34.0160951>,
    <0.1964702, 1.8063483, 34.0164483>,
    <-0.0827065, 1.8017855, 34.0159774>,
    <0.0211341, 1.8154222, 34.0160069>,
    <0.0127126, 1.8047771, 34.0161399>,
    <-0.0237328, 1.8070902, 34.0159774>,
    <0.0656661, 1.8140835, 34.0160951>,
    <0.0556674, 1.8089934, 34.0159774>,
    <-0.0015021, 1.8281451, 34.0159774>,
    <0.0168747, 1.8234667, 34.0160951>,
    <0.0547834, 1.8263676, 34.0168971>,
    <0.0733731, 1.8192706, 34.0164483>,
    <0.1992644, 1.7995814, 34.0164520>,
    <0.1811438, 1.8003257, 34.0161399>,
    <0.2467785, 1.7961963, 34.0162327>,
    <0.2537901, 1.7961711, 34.0159774>,
    <0.1487599, 1.8055410, 34.0184807>,
    <0.2360623, 1.7979109, 34.0185926>,
    <0.1699769, 1.8014656, 34.0170451>,
    <0.2382956, 1.7959918, 34.0169987>,
    <0.0205625, 1.8057255, 34.0171572>,
    <0.1061316, 1.8035548, 34.0166273>,
    <0.1326569, -1.8085926, 34.0164769>,
    <0.0816503, -1.8150990, 34.0161573>,
    <0.1513081, -1.8075074, 34.0161961>,
    <0.1008663, -1.8179086, 34.0159774>,
    <0.1107168, -1.8109206, 34.0162327>,
    <0.1244509, -1.8124855, 34.0159774>,
    <-0.0315651, -1.8149879, 34.0180289>,
    <0.1289678, -1.8107995, 34.0186381>,
    <0.0445005, -1.8145043, 34.0166970>,
    <0.0620736, -1.8147468, 34.0185926>,
    <0.1346726, -1.8076567, 34.0171013>,
    <0.0856492, -1.8112327, 34.0169987>,
    <0.1974010, -1.8041828, 34.0183725>,
    <0.1827779, -1.8032874, 34.0168520>,
    <0.0383239, -1.8207499, 34.0160187>,
    <0.0600142, -1.8249426, 34.0159774>,
    <0.0653325, -1.8244773, 34.0159774>,
    <-0.0231007, -1.8206471, 34.0161461>,
    <0.0472878, -1.8225558, 34.0159774>,
    <0.0527471, -1.8255784, 34.0159774>,
    <0.0138422, -1.8238868, 34.0160951>,
    <0.0140182, -1.8211302, 34.0160703>,
    <0.0283096, -1.8235435, 34.0159774>,
    <-0.0309735, -1.8170586, 34.0165345>,
    <0.0550371, -1.8184955, 34.0160703>,
    <0.0200193, -1.8179603, 34.0163488>,
    <0.0802564, -1.8231717, 34.0159774>,
    <0.0721284, -1.8204730, 34.0159774>,
    <0.1556728, -2.0172787, 34.2997909>,
    <0.0800114, -2.0278432, 34.2979383>,
    <0.1186114, -2.0222050, 34.2989810>,
    <0.1083595, -2.0339075, 34.2945157>,
    <0.1856761, -2.0168429, 34.2989810>,
    <0.1431733, -2.0252187, 34.2969276>,
    <0.1756924, -2.0065192, 34.3035582>,
    <0.2635387, -1.9996610, 34.3035582>,
    <0.1634483, -2.0127253, 34.3014107>,
    <0.2253217, -2.0082950, 34.3012225>,
    <0.0000000, -2.0202357, 34.3035582>,
    <0.0878462, -2.0133775, 34.3035582>,
    <0.0368466, -2.0224455, 34.3015015>,
    <0.1013929, -2.0180713, 34.3012225>,
    <0.0411305, -2.0364296, 34.2957498>,
    <0.0535388, -2.0453159, 34.2918022>,
    <0.0452257, -2.0404435, 34.2940173>,
    <0.0856887, -2.0425032, 34.2918022>,
    <0.0536965, -2.0329615, 34.2967308>,
    <0.0710321, -2.0374006, 34.2943649>,
    <0.0105302, -2.0356521, 34.2969740>,
    <0.0065323, -2.0262184, 34.3007907>,
    <0.0251867, -2.0358210, 34.2965012>,
    <0.0310028, -2.0298493, 34.2987032>,
    <0.0000000, -2.0499999, 34.2918022>,
    <0.0089142, -2.0424457, 34.2943910>,
    <0.0256933, -2.0477520, 34.2918022>,
    <0.0242261, -2.0417878, 34.2941812>,
    <-0.0079418, -2.0392459, 34.2956273>,
    <-0.0099059, -2.0491333, 34.2918022>,
    <-0.0080311, -2.0436648, 34.2939713>,
    <-0.0031732, -2.0497223, 34.2918022>,
    <0.0000439, -2.0373800, 34.2964553>,
    <0.0001707, -2.0434297, 34.2941812>,
    <-0.0363639, -2.0336829, 34.2969740>,
    <-0.0193263, -2.0253853, 34.3007907>,
    <-0.0170248, -2.0365891, 34.2964553>,
    <-0.0070242, -2.0318163, 34.2985195>,
    <-0.0482885, -2.0457753, 34.2918022>,
    <-0.0431203, -2.0396729, 34.2943910>,
    <-0.0237578, -2.0479214, 34.2918022>,
    <-0.0217181, -2.0420766, 34.2941812>,
    <-0.0237233, 1.8164945, 34.0159774>,
    <-0.0548016, 1.8103331, 34.0159774>,
    <-0.0828587, 1.8134007, 34.0159774>,
    <-0.0382987, 1.8214764, 34.0159774>,
    <-0.0364783, 1.8139237, 34.0159774>,
    <-0.0661239, 1.8121104, 34.0159774>,
    <-0.0591231, 1.8177023, 34.0159774>,
    <-0.0297149, 1.8189064, 34.0159774>,
    <-0.0474027, 1.8158746, 34.0159774>,
    <-0.0194152, 1.8248987, 34.0159774>,
    <-0.0080071, 1.8163579, 34.0159774>,
    <-0.0087426, 1.8207005, 34.0159774>,
    <-0.0589188, 1.8058950, 34.0159774>,
    <-0.0271459, 1.8117266, 34.0159774>,
    <-0.0973186, 1.8045709, 34.0159774>,
    <-0.1123283, 1.7991939, 34.0159774>,
    <-0.2069139, 1.7909187, 34.0159774>,
    <-0.1410046, 1.8028632, 34.0159774>,
    <-0.1029862, 1.8023264, 34.0159774>,
    <-0.1555608, 1.7954116, 34.0159774>,
    <-0.1734741, 1.7969789, 34.0159774>,
    <-0.1150852, 1.8039651, 34.0159774>,
    <-0.1362531, 1.7997129, 34.0159774>,
    <-0.1104760, 1.8083957, 34.0159774>,
    <-0.0769148, 1.8071257, 34.0159774>,
    <-0.0901968, 1.8081191, 34.0159774>,
    <-0.0853367, 1.8015554, 34.0159774>,
    <-0.0776271, 1.8046989, 34.0159774>,
    <-0.1367993, 1.8100903, 34.0159774>,
    <-0.1042080, 1.8095319, 34.0159774>,
    <-0.1953748, 1.8022327, 34.0159774>,
    <-0.1231125, 1.8097584, 34.0159774>,
    <-0.1555610, 1.8002253, 34.0159774>,
    <-0.1978115, 1.7975818, 34.0159774>,
    <-0.1639490, 1.8065616, 34.0159774>,
    <-0.1615245, 1.8032136, 34.0159774>,
    <-0.1938568, 1.8113160, 34.0159774>,
    <-0.1037764, 1.8191972, 34.0159774>,
    <-0.1943415, 1.8073624, 34.0159774>,
    <-0.1511029, 1.8150566, 34.0159774>,
    <-0.1228284, 1.8139952, 34.0159774>,
    <-0.1592955, 1.8106292, 34.0159774>,
    <-0.0534014, 1.8236045, 34.0159774>,
    <-0.0528551, 1.8188385, 34.0159774>,
    <-0.0875456, 1.8166058, 34.0159774>,
    <-0.0943957, -2.0316780, 34.2957498>,
    <-0.1323668, -2.0225010, 34.2979383>,
    <-0.2316765, -2.0297309, 34.2918022>,
    <-0.1343531, -2.0382456, 34.2918022>,
    <-0.1074401, -2.0279669, 34.2967308>,
    <-0.1942020, -2.0258818, 34.2945157>,
    <-0.1844634, -2.0338615, 34.2918022>,
    <-0.1107667, -2.0346751, 34.2940173>,
    <-0.1470229, -2.0305456, 34.2943649>,
    <-0.0870575, -2.0423834, 34.2918022>,
    <-0.0654493, -2.0323510, 34.2965012>,
    <-0.0744679, -2.0374616, 34.2941812>,
    <-0.0538001, -2.0204924, 34.3015015>,
    <-0.0635727, -2.0268626, 34.2987032>,
    <-0.2415897, 1.7945037, 34.0159774>,
    <-0.2614260, 1.7957254, 34.0159774>,
    <-0.2505665, 1.7949970, 34.0159774>,
    <-0.2256771, 1.8043952, 34.0159774>,
    <-0.2228891, 1.7977946, 34.0159774>,
    <-0.2248106, 1.8008858, 34.0159774>,
    <-0.2613573, 1.7861553, 34.0159774>,
    <-0.2341356, 1.7885370, 34.0159774>,
    <-0.2508053, 1.7907640, 34.0159774>,
    <-0.2270034, 1.7934733, 34.0159774>,
    <-0.3158007, 1.7813918, 34.0159774>,
    <-0.2885790, 1.7837736, 34.0159774>,
    <-0.2932526, 1.7872959, 34.0159774>,
    <-0.2709227, 1.7893298, 34.0159774>,
    <-0.2828904, 1.7963592, 34.0159774>,
    <-0.2625977, 1.8053017, 34.0159774>,
    <-0.2737549, 1.8004345, 34.0159774>,
    <-0.2305136, 1.8081089, 34.0159774>,
    <-0.2730687, 1.7962825, 34.0159774>,
    <-0.2512425, 1.8022838, 34.0159774>,
    <-0.3279235, 1.7857460, 34.0159774>,
    <-0.3239684, 1.7818941, 34.0159774>,
    <-0.3013395, 1.7924050, 34.0159774>,
    <-0.2970893, 1.7899287, 34.0159774>,
    <-0.3191447, 1.8003543, 34.0159774>,
    <-0.3258569, 1.7925569, 34.0159774>,
    <-0.2916333, 1.8027613, 34.0159774>,
    <-0.2983071, 1.7970428, 34.0159774>,
    <-0.2415702, -1.7982187, 34.0164520>,
    <-0.2070494, -1.8049135, 34.0161867>,
    <-0.3839287, -1.7851730, 34.0159774>,
    <-0.3067045, -1.7899960, 34.0160180>,
    <-0.2248940, -1.8011690, 34.0162327>,
    <-0.3041099, -1.7959065, 34.0160951>,
    <-0.3385607, -1.7908337, 34.0159774>,
    <-0.2669228, -1.7944151, 34.0161399>,
    <-0.2758171, -1.7963822, 34.0159774>,
    <-0.3945291, -1.7624743, 34.0159774>,
    <-0.2452921, -1.7994731, 34.0184807>,
    <-0.3464474, -1.7766690, 34.0161399>,
    <-0.3327288, -1.7801199, 34.0171572>,
    <-0.2384696, -1.7979109, 34.0170451>,
    <-0.2882399, -1.7893854, 34.0166273>,
    <-0.1602749, -1.8081943, 34.0185926>,
    <-0.1320231, -1.8092971, 34.0166970>,
    <-0.1829568, -1.8042442, 34.0169987>,
    <-0.1241850, -1.8152337, 34.0163326>,
    <-0.1631365, -1.8202159, 34.0176445>,
    <-0.1377057, -1.8166313, 34.0166837>,
    <-0.3001569, -1.8013224, 34.0168568>,
    <-0.1624441, -1.8103445, 34.0161880>,
    <-0.2177494, -1.8077631, 34.0164483>,
    <-0.0731287, -1.8180726, 34.0161880>,
    <-0.0959901, -1.8139815, 34.0163488>,
    <-0.0264355, -1.8259969, 34.0168971>,
    <-0.0617097, -1.8213458, 34.0164483>,
    <-0.1188311, 2.0285930, 34.2956998>,
    <-0.1664780, 2.0354350, 34.2918021>,
    <-0.2916310, 2.0244853, 34.2918019>,
    <-0.1635736, 2.0186736, 34.2978494>,
    <-0.1389586, 2.0316468, 34.2939985>,
    <-0.2368029, 2.0292823, 34.2918020>,
    <-0.2432623, 2.0212155, 34.2944688>,
    <-0.1364525, 2.0243644, 34.2966653>,
    <-0.1879146, 2.0264559, 34.2943274>,
    <-0.0675601, 2.0172857, 34.3013243>,
    <-0.0793604, 2.0299185, 34.2964357>,
    <-0.0798428, 2.0237430, 34.2986283>,
    <-0.0858218, 2.0424915, 34.2918022>,
    <-0.0818485, 2.0361828, 34.2941437>,
    <-0.1622125, 2.0071470, 34.3035582>,
    <-0.2433207, 2.0022554, 34.3035582>,
    <-0.3502469, 1.9862866, 34.3035582>,
    <-0.1751215, 2.0016084, 34.3035582>,
    <-0.1976973, 2.0050070, 34.3035582>,
    <-0.2967838, 1.9942710, 34.3035582>,
    <-0.2626842, 1.9939475, 34.3035582>,
    <-0.1678602, 2.0047239, 34.3035582>,
    <-0.2327254, 1.9993244, 34.3035582>,
    <-0.0681953, 2.0175772, 34.3035582>,
    <-0.0875588, 2.0092693, 34.3035582>,
    <-0.0340957, 2.0172537, 34.3035582>,
    <-0.1210800, 2.0117102, 34.3035582>,
    <-0.1013813, 2.0108157, 34.3035582>,
    <-0.1363945, 2.0182242, 34.3035582>,
    <-0.1022949, 2.0179007, 34.3035582>,
    <-0.1898576, 2.0102398, 34.3035582>,
    <-0.1525307, 2.0113010, 34.3035582>,
    <-0.2216901, 2.0082723, 34.2997409>,
    <-0.3039393, 2.0062799, 34.2978491>,
    <-0.1969151, 2.0127620, 34.2989154>,
    <-0.2955609, 2.0166398, 34.2944686>,
    <-0.2629079, 2.0069883, 34.2989153>,
    <-0.2503789, 2.0138872, 34.2968525>,
    <-0.1751215, 2.0016084, 34.3035582>,
    <-0.3255090, 1.9942657, 34.3013241>,
    <-0.2626842, 1.9939475, 34.3035582>,
    <-0.2035256, 2.0052171, 34.3013919>,
    <-0.2653242, 2.0003922, 34.3011850>,
    <-0.0875588, 2.0092693, 34.3035582>,
    <-0.1424798, 2.0111399, 34.3011851>,
    <-0.3483904, 2.0073036, 34.2956991>,
    <-0.3444655, 2.0198624, 34.2918011>,
    <-0.3559749, 2.0188547, 34.2918001>,
    <-0.3902340, 1.9945136, 34.2968953>,
    <-0.3470520, 2.0129885, 34.2939977>,
    <-0.3528030, 2.0191326, 34.2918006>,
    <-0.3864211, 2.0031235, 34.2943332>,
    <-0.3637281, 2.0023276, 34.2964348>,
    <-0.3621950, 2.0098473, 34.2941425>,
    <-0.3731802, 1.9879949, 34.3006308>,
    <-0.3326692, 2.0067453, 34.2966648>,
    <-0.3495432, 1.9983392, 34.2986278>,
    <-0.3257967, 2.0214960, 34.2918015>,
    <-0.3265454, 2.0143268, 34.2943269>,
    <-0.3129260, -2.0115410, 34.2957498>,
    <-0.3428561, -2.0051239, 34.2969740>,
    <-0.3559621, -2.0188572, 34.2918022>,
    <-0.3024282, -2.0235409, 34.2918022>,
    <-0.3284776, -2.0079659, 34.2965012>,
    <-0.3457498, -2.0122489, 34.2943910>,
    <-0.3302713, -2.0211049, 34.2918022>,
    <-0.3096663, -2.0166854, 34.2940173>,
    <-0.3305666, -2.0143179, 34.2941812>,
    <-0.2730948, -2.0092255, 34.2979383>,
    <-0.2702807, -2.0263534, 34.2918022>,
    <-0.2463760, -2.0210695, 34.2945157>,
    <-0.2999167, -2.0100346, 34.2967308>,
    <-0.2837216, -2.0180723, 34.2943649>,
    <-0.3502284, -1.9862910, 34.3035582>,
    <-0.3144682, -1.9954306, 34.3015015>,
    <-0.3449737, -1.9940826, 34.3007907>,
    <-0.3216201, -2.0024840, 34.2987032>,
    <-0.1967891, -2.0114346, 34.2997909>,
    <-0.2341177, -2.0100809, 34.2989810>,
    <-0.1672303, -2.0164372, 34.2989810>,
    <-0.2105465, -2.0178827, 34.2969276>,
    <-0.1751142, -2.0032634, 34.3035582>,
    <-0.0875571, -2.0117495, 34.3035582>,
    <-0.1883019, -2.0078484, 34.3014107>,
    <-0.1266977, -2.0142730, 34.3012225>,
    <-0.2626713, -1.9947772, 34.3035582>,
    <-0.2502534, -2.0023990, 34.3012225>,
    <-0.3617381, -2.0058281, 34.2956273>,
    <-0.3655755, -2.0162828, 34.2918022>,
    <-0.3626740, -2.0106227, 34.2939713>,
    <-0.3590432, -2.0180324, 34.2918022>,
    <-0.3535082, -2.0051482, 34.2964553>,
    <-0.3545431, -2.0117575, 34.2941812>,
    <-0.3887021, -1.9950497, 34.2969740>,
    <-0.3703001, -1.9888071, 34.3007907>,
    <-0.3701827, -2.0014051, 34.2964553>,
    <-0.3594034, -1.9978702, 34.2985195>,
    <-0.4027993, -2.0063098, 34.2918022>,
    <-0.3965219, -2.0004813, 34.2943910>,
    <-0.3790105, -2.0126835, 34.2918022>,
    <-0.3758697, -2.0066234, 34.2941812>,
    <-0.3523817, -1.7858515, 34.0159774>,
    <-0.3787762, -1.7865539, 34.0159774>,
    <-0.4239473, -1.7744509, 34.0159774>,
    <-0.3808042, -1.7770307, 34.0159774>,
    <-0.3633680, -1.7865258, 34.0159774>,
    <-0.3984058, -1.7812945, 34.0159774>,
    <-0.3993641, -1.7765789, 34.0159774>,
    <-0.3632864, -1.7822804, 34.0159774>,
    <-0.3802651, -1.7820793, 34.0159774>,
    <-0.3761196, -1.7713483, 34.0159774>,
    <-0.3352124, -1.7874831, 34.0159774>,
    <-0.3486316, -1.7813140, 34.0159774>,
    <-0.3717274, -1.7884424, 34.0159774>,
    <-0.3471346, -1.7891006, 34.0159774>,
    <-0.3848817, 1.7690874, 34.0159774>,
    <-0.4139240, 1.7550998, 34.0159774>,
    <-0.5003487, 1.7319421, 34.0159774>,
    <-0.4161970, 1.7643812, 34.0159774>,
    <-0.3973227, 1.7631164, 34.0159774>,
    <-0.4593298, 1.7429332, 34.0159774>,
    <-0.4657143, 1.7455666, 34.0159774>,
    <-0.3981369, 1.7672423, 34.0159774>,
    <-0.4298221, 1.7549770, 34.0159774>,
    <-0.3628547, 1.7841430, 34.0159774>,
    <-0.3586981, 1.7770342, 34.0159774>,
    <-0.3620967, 1.7799504, 34.0159774>,
    <-0.3655935, 1.7680499, 34.0159774>,
    <-0.3607765, 1.7728572, 34.0159774>,
    <-0.4237643, -1.7678410, 34.0159774>,
    <-0.4731368, -1.7612708, 34.0159774>,
    <-0.4031605, -1.7720149, 34.0159774>,
    <-0.4487315, -1.7678101, 34.0159774>,
    <-0.4441317, -1.7653043, 34.0159774>,
    <-0.4222032, -1.7708423, 34.0159774>,
    <-0.5223243, -1.7480911, 34.0159774>,
    <-0.4334371, -1.7617004, 34.0159774>,
    <-0.4975416, -1.7547316, 34.0159774>,
    <-0.4881120, -1.7532873, 34.0159774>,
    <-0.4266253, -1.7655004, 34.0159774>,
    <-0.4604991, -1.7603994, 34.0159774>,
    <-0.3947613, -1.7657041, 34.0159774>,
    <-0.3990890, -1.7694682, 34.0159774>,
    <-0.4512333, -1.7536990, 34.0159774>,
    <-0.5055380, -1.7413122, 34.0159774>,
    <-0.4426029, -1.7574350, 34.0159774>,
    <-0.5132117, -1.7454943, 34.0159774>,
    <-0.4752509, -1.7486104, 34.0159774>,
    <-0.4760927, -1.7519021, 34.0159774>,
    <-0.5003448, -1.7341219, 34.0159774>,
    <-0.4217910, -1.7551698, 34.0159774>,
    <-0.5024968, -1.7378235, 34.0159774>,
    <-0.4593248, -1.7451129, 34.0159774>,
    <-0.4380463, -1.7544622, 34.0159774>,
    <-0.4687121, -1.7465530, 34.0159774>,
    <-0.3970802, -1.7617908, 34.0159774>,
    <-0.4176959, -1.7602839, 34.0159774>,
    <-0.4486365, 1.7590375, 34.0159774>,
    <-0.5032570, 1.7410801, 34.0159774>,
    <-0.4350617, 1.7612269, 34.0159774>,
    <-0.5023585, 1.7357477, 34.0159774>,
    <-0.4739096, 1.7508176, 34.0159774>,
    <-0.4694633, 1.7484923, 34.0159774>,
    <-0.4931748, 1.7537231, 34.0159774>,
    <-0.4170636, 1.7741170, 34.0159774>,
    <-0.4999865, 1.7475058, 34.0159774>,
    <-0.4592081, 1.7628244, 34.0159774>,
    <-0.4355421, 1.7654422, 34.0159774>,
    <-0.4689182, 1.7560854, 34.0159774>,
    <-0.3694671, 1.7868704, 34.0159774>,
    <-0.4019436, 1.7740312, 34.0159774>,
    <-0.4455881, -1.9834210, 34.2957497>,
    <-0.4813800, -1.9676111, 34.2979383>,
    <-0.5806252, -1.9586620, 34.2918019>,
    <-0.4862546, -1.9839485, 34.2918021>,
    <-0.4577689, -1.9773467, 34.2967308>,
    <-0.5429959, -1.9609789, 34.2945156>,
    <-0.5348446, -1.9709289, 34.2918020>,
    <-0.4623040, -1.9839504, 34.2940173>,
    <-0.4973009, -1.9735967, 34.2943648>,
    <-0.4403934, -1.9962368, 34.2918022>,
    <-0.4171461, -1.9888442, 34.2965012>,
    <-0.4270222, -1.9929178, 34.2941812>,
    <-0.4034352, -1.9781014, 34.3015015>,
    <-0.4142604, -1.9832611, 34.2987032>,
    <-0.5621467, 1.7285733, 34.0159774>,
    <-0.5862039, 1.7200200, 34.0159774>,
    <-0.5555524, 1.7370087, 34.0159774>,
    <-0.5319517, 1.7433328, 34.0159774>,
    <-0.5738791, 1.7241601, 34.0159774>,
    <-0.5711398, 1.7284587, 34.0159774>,
    <-0.5438716, 1.7401388, 34.0159774>,
    <-0.5490892, 1.7349988, 34.0159774>,
    <-0.5598212, 1.7318461, 34.0159774>,
    <-0.5612860, 1.7251188, 34.0159774>,
    <-0.5162377, 1.7475434, 34.0159774>,
    <-0.5250882, 1.7406359, 34.0159774>,
    <-0.5628396, 1.7267304, 34.0159774>,
    <-0.5399360, 1.7368642, 34.0159774>,
    <-0.6205551, 1.6997317, 34.0159774>,
    <-0.5976919, 1.7093323, 34.0159774>,
    <-0.6066461, 1.7079785, 34.0159774>,
    <-0.5841536, 1.7176871, 34.0159774>,
    <-0.5480663, 1.7256476, 34.0159774>,
    <-0.5557321, 1.7248817, 34.0159774>,
    <-0.5300339, 1.7320074, 34.0159774>,
    <-0.5302178, 1.7353310, 34.0159774>,
    <-0.5663012, 1.7142697, 34.0159774>,
    <-0.5355184, 1.7225182, 34.0159774>,
    <-0.5570368, 1.7204277, 34.0159774>,
    <-0.5321909, 1.7275471, 34.0159774>,
    <-0.5941593, 1.7068048, 34.0159774>,
    <-0.5762059, 1.7155611, 34.0159774>,
    <-0.5497406, -1.7273848, 34.0159774>,
    <-0.5662963, -1.7164505, 34.0159774>,
    <-0.5574190, -1.7225071, 34.0159774>,
    <-0.5355144, -1.7246983, 34.0159774>,
    <-0.5318948, -1.7334631, 34.0159774>,
    <-0.5322035, -1.7295409, 34.0159774>,
    <-0.5707414, -1.7251154, 34.0159774>,
    <-0.5399183, -1.7395014, 34.0159774>,
    <-0.5594835, -1.7262980, 34.0159774>,
    <-0.5375903, -1.7355444, 34.0159774>,
    <-0.6205470, -1.7019141, 34.0159774>,
    <-0.6019819, -1.7104712, 34.0159774>,
    <-0.5941529, -1.7089863, 34.0159774>,
    <-0.5777299, -1.7175240, 34.0159774>,
    <-0.5911868, -1.7223607, 34.0159774>,
    <-0.5739695, -1.7342529, 34.0159774>,
    <-0.6271273, -1.7200094, 34.0159774>,
    <-0.6339099, -1.7052130, 34.0159774>,
    <-0.5833095, -1.7277795, 34.0159774>,
    <-0.6004539, -1.7271565, 34.0159774>,
    <-0.6338421, -1.7102245, 34.0159774>,
    <-0.6084003, -1.7154763, 34.0159774>,
    <-0.6061569, -1.7205022, 34.0159774>,
    <-0.6285162, -1.7019107, 34.0159774>,
    <-0.5819137, -1.7238095, 34.0159774>,
    <-0.6037242, -1.7137071, 34.0159774>,
    <-0.5478633, -1.7412480, 34.0159774>,
    <-0.5639315, -1.7328054, 34.0159774>,
    <-0.5989906, 1.7184935, 34.0159774>,
    <-0.5880324, 1.7283050, 34.0159774>,
    <-0.5940535, 1.7228723, 34.0159774>,
    <-0.5705490, 1.7329901, 34.0159774>,
    <-0.5941378, 1.7186538, 34.0159774>,
    <-0.5820524, 1.7258889, 34.0159774>,
    <-0.6224634, 1.7079939, 34.0159774>,
    <-0.6216945, 1.7025518, 34.0159774>,
    <-0.6090568, 1.7138804, 34.0159774>,
    <-0.6073871, 1.7111511, 34.0159774>,
    <-0.6271439, 1.7178241, 34.0159774>,
    <-0.6240107, 1.7123259, 34.0159774>,
    <-0.6071737, 1.7231756, 34.0159774>,
    <-0.6086375, 1.7181443, 34.0159774>,
    <-0.5084316, 1.9489036, 34.3035582>,
    <-0.5875240, 1.9302121, 34.3035582>,
    <-0.6902837, 1.8965389, 34.3035582>,
    <-0.5202653, 1.9414128, 34.3035582>,
    <-0.5430345, 1.9407261, 34.3035582>,
    <-0.6389038, 1.9133755, 34.3035582>,
    <-0.6052745, 1.9189758, 34.3035582>,
    <-0.5136089, 1.9456264, 34.3035582>,
    <-0.5766262, 1.9292669, 34.3035582>,
    <-0.4175055, 1.9750860, 34.3035582>,
    <-0.4352561, 1.9638497, 34.3035582>,
    <-0.3838762, 1.9806863, 34.3035582>,
    <-0.4686515, 1.9603584, 34.3035582>,
    <-0.4491123, 1.9629223, 34.3035582>,
    <-0.4847642, 1.9638854, 34.3035582>,
    <-0.4511349, 1.9694857, 34.3035582>,
    <-0.5361441, 1.9470488, 34.3035582>,
    <-0.4995563, 1.9545218, 34.3035582>,
    <-0.4692881, 1.9771673, 34.2956978>,
    <-0.5173793, 1.9756076, 34.2917991>,
    <-0.6387216, 1.9430948, 34.2917983>,
    <-0.5116714, 1.9597477, 34.2978476>,
    <-0.4896296, 1.9766642, 34.2939960>,
    <-0.5855620, 1.9573385, 34.2917986>,
    <-0.5905619, 1.9483680, 34.2944660>,
    <-0.4859194, 1.9699757, 34.2966633>,
    <-0.5369478, 1.9630814, 34.2943247>,
    <-0.4168718, 1.9750020, 34.3013237>,
    <-0.4306460, 1.9853093, 34.2964340>,
    <-0.4300629, 1.9791725, 34.2986271>,
    <-0.4391810, 1.9965603, 34.2917996>,
    <-0.4341766, 1.9910370, 34.2941416>,
    <-0.5671990, 1.9396893, 34.2997396>,
    <-0.6478731, 1.9235227, 34.2978474>,
    <-0.5435303, 1.9482767, 34.2989139>,
    <-0.6413020, 1.9348715, 34.2944658>,
    <-0.6075814, 1.9313173, 34.2989138>,
    <-0.5963641, 1.9400859, 34.2968504>,
    <-0.5202653, 1.9414128, 34.3035582>,
    <-0.6671855, 1.9083604, 34.3013236>,
    <-0.6052745, 1.9189758, 34.3035582>,
    <-0.5488161, 1.9399212, 34.3013912>,
    <-0.6089021, 1.9246270, 34.3011842>,
    <-0.4352561, 1.9638497, 34.3035582>,
    <-0.4896539, 1.9561441, 34.3011843>,
    <-0.6917858, 1.9167026, 34.2956971>,
    <-0.6899555, 1.9293670, 34.2917980>,
    <-0.7011274, 1.9263735, 34.2917980>,
    <-0.7308358, 1.8969857, 34.2968946>,
    <-0.6913927, 1.9223704, 34.2939952>,
    <-0.6980453, 1.9271994, 34.2917980>,
    <-0.7284786, 1.9058609, 34.2943320>,
    <-0.7060641, 1.9092320, 34.2964333>,
    <-0.7057741, 1.9166713, 34.2941405>,
    <-0.7130470, 1.8939085, 34.3006306>,
    <-0.6762315, 1.9189527, 34.2966629>,
    <-0.6914764, 1.9079702, 34.2986267>,
    <-0.6718502, 1.9342182, 34.2917981>,
    <-0.6714300, 1.9272554, 34.2943242>,
    <-0.6576135, -1.9269630, 34.2957490>,
    <-0.6492308, -1.9402792, 34.2918011>,
    <-0.6179691, -1.9314041, 34.2979380>,
    <-0.6552445, -1.9324703, 34.2940164>,
    <-0.6180583, -1.9486318, 34.2918015>,
    <-0.5936208, -1.9475163, 34.2945154>,
    <-0.6445502, -1.9277254, 34.2967303>,
    <-0.6299226, -1.9382731, 34.2943643>,
    <-0.6902837, -1.8965389, 34.3035582>,
    <-0.6860402, -1.9156606, 34.2969728>,
    <-0.6564986, -1.9112007, 34.3015014>,
    <-0.6863474, -1.9047970, 34.3007902>,
    <-0.6723502, -1.9208797, 34.2965003>,
    <-0.6647042, -1.9167996, 34.2987027>,
    <-0.7011413, -1.9263698, 34.2918001>,
    <-0.6900321, -1.9219100, 34.2943894>,
    <-0.6762295, -1.9330449, 34.2918006>,
    <-0.6754311, -1.9265618, 34.2941799>,
    <-0.5430431, -1.9460198, 34.2997908>,
    <-0.5796542, -1.9386167, 34.2989809>,
    <-0.5147270, -1.9558054, 34.2989809>,
    <-0.5577284, -1.9502255, 34.2969274>,
    <-0.5202561, -1.9414149, 34.3035582>,
    <-0.4352422, -1.9638530, 34.3035582>,
    <-0.5340525, -1.9438236, 34.3014107>,
    <-0.4743328, -1.9601404, 34.3012225>,
    <-0.6052699, -1.9189769, 34.3035582>,
    <-0.5942857, -1.9284391, 34.3012225>,
    <-0.7047049, -1.9129427, 34.2956253>,
    <-0.7101528, -1.9221677, 34.2917991>,
    <-0.7063958, -1.9173267, 34.2939689>,
    <-0.7040281, -1.9250237, 34.2917996>,
    <-0.6965154, -1.9137892, 34.2964536>,
    <-0.6985966, -1.9198774, 34.2941791>,
    <-0.7294322, -1.8977882, 34.2969723>,
    <-0.7103740, -1.8952305, 34.3007901>,
    <-0.7122828, -1.9072088, 34.2964534>,
    <-0.7011347, -1.9058169, 34.2985183>,
    <-0.7450680, -1.9058864, 34.2917988>,
    <-0.7379755, -1.9015096, 34.2943885>,
    <-0.7227535, -1.9162919, 34.2917988>,
    <-0.7187007, -1.9111204, 34.2941786>,
    <-0.6471818, 1.6984639, 34.0159774>,
    <-0.6664769, 1.6851776, 34.0159774>,
    <-0.6985444, 1.6761465, 34.0159774>,
    <-0.6594367, 1.6989742, 34.0159774>,
    <-0.6534934, 1.6935631, 34.0159774>,
    <-0.6826781, 1.6805769, 34.0159774>,
    <-0.6777127, 1.6883062, 34.0159774>,
    <-0.6522868, 1.6989027, 34.0159774>,
    <-0.6662744, 1.6905434, 34.0159774>,
    <-0.6428643, 1.7086477, 34.0159774>,
    <-0.6360493, 1.7027602, 34.0159774>,
    <-0.6383797, 1.7060378, 34.0159774>,
    <-0.6408669, 1.6928959, 34.0159774>,
    <-0.6380273, 1.6981476, 34.0159774>,
    <-0.7076042, 1.6636332, 34.0159774>,
    <-0.7139912, 1.6561617, 34.0159774>,
    <-0.8074272, 1.6125916, 34.0159774>,
    <-0.7495784, 1.6463579, 34.0159774>,
    <-0.7100272, 1.6605647, 34.0159774>,
    <-0.7607092, 1.6343766, 34.0159774>,
    <-0.7780769, 1.6297234, 34.0159774>,
    <-0.7256499, 1.6562445, 34.0159774>,
    <-0.7440369, 1.6450223, 34.0159774>,
    <-0.7227836, 1.6619981, 34.0159774>,
    <-0.6874195, 1.6739245, 34.0159774>,
    <-0.7038334, 1.6686200, 34.0159774>,
    <-0.6672731, 1.6779467, 34.0159774>,
    <-0.6760782, 1.6765943, 34.0159774>,
    <-0.7478410, 1.6547075, 34.0159774>,
    <-0.7172855, 1.6652079, 34.0159774>,
    <-0.7994852, 1.6276087, 34.0159774>,
    <-0.7351267, 1.6589553, 34.0159774>,
    <-0.7623564, 1.6388997, 34.0159774>,
    <-0.8011539, 1.6219655, 34.0159774>,
    <-0.7718203, 1.6422580, 34.0159774>,
    <-0.7689824, 1.6396681, 34.0159774>,
    <-0.7904254, 1.6416846, 34.0159774>,
    <-0.7190148, 1.6749839, 34.0159774>,
    <-0.7961877, 1.6346472, 34.0159774>,
    <-0.7585564, 1.6565453, 34.0159774>,
    <-0.7357234, 1.6633068, 34.0159774>,
    <-0.7670824, 1.6484909, 34.0159774>,
    <-0.6743581, 1.6958077, 34.0159774>,
    <-0.6722147, 1.6915160, 34.0159774>,
    <-0.7040481, 1.6775537, 34.0159774>,
    <-0.7454548, -1.6505943, 34.0159774>,
    <-0.7169879, -1.6674838, 34.0159774>,
    <-0.8021307, -1.6384047, 34.0159774>,
    <-0.7987898, -1.6279482, 34.0159774>,
    <-0.7334974, -1.6577941, 34.0159774>,
    <-0.7713238, -1.6486400, 34.0159774>,
    <-0.8010301, -1.6335634, 34.0159774>,
    <-0.7702402, -1.6404185, 34.0159774>,
    <-0.7678357, -1.6453845, 34.0159774>,
    <-0.7937038, -1.6211696, 34.0159774>,
    <-0.7126146, -1.6589821, 34.0159774>,
    <-0.7964658, -1.6244413, 34.0159774>,
    <-0.7552177, -1.6391160, 34.0159774>,
    <-0.7317071, -1.6539991, 34.0159774>,
    <-0.7647121, -1.6389043, 34.0159774>,
    <-0.6672670, -1.6801282, 34.0159774>,
    <-0.6587464, -1.6880663, 34.0159774>,
    <-0.7001376, -1.6692096, 34.0159774>,
    <-0.6892942, -1.6836544, 34.0159774>,
    <-0.7201771, -1.6766200, 34.0159774>,
    <-0.7025714, -1.6807444, 34.0159774>,
    <-0.7632345, -1.6565422, 34.0159774>,
    <-0.7010541, -1.6768224, 34.0159774>,
    <-0.7330964, -1.6661865, 34.0159774>,
    <-0.6637948, -1.6936120, 34.0159774>,
    <-0.6652035, -1.6894412, 34.0159774>,
    <-0.6743458, -1.6979913, 34.0159774>,
    <-0.6677335, -1.6961979, 34.0159774>,
    <-0.7833687, -1.8763094, 34.2957480>,
    <-0.8158971, -1.8546519, 34.2979350>,
    <-0.9118943, -1.8280940, 34.2918007>,
    <-0.8233575, -1.8693794, 34.2917995>,
    <-0.7943353, -1.8682836, 34.2967294>,
    <-0.8752534, -1.8371534, 34.2945050>,
    <-0.8689425, -1.8481228, 34.2918001>,
    <-0.7998578, -1.8737627, 34.2940151>,
    <-0.8325243, -1.8574983, 34.2943631>,
    <-0.7803343, -1.8894415, 34.2917990>,
    <-0.7563400, -1.8866827, 34.2964995>,
    <-0.7666847, -1.8887451, 34.2941788>,
    <-0.7411416, -1.8789278, 34.3015011>,
    <-0.7526051, -1.8818883, 34.2987021>,
    <-0.8539807, 1.6049408, 34.0159774>,
    <-0.8761869, 1.5923402, 34.0159774>,
    <-0.8489517, 1.6143930, 34.0159774>,
    <-0.8268078, 1.6247191, 34.0159774>,
    <-0.8647684, 1.5985575, 34.0159774>,
    <-0.8628172, 1.6032663, 34.0159774>,
    <-0.8379919, 1.6195038, 34.0159774>,
    <-0.8422375, 1.6135360, 34.0159774>,
    <-0.8522589, 1.6085677, 34.0159774>,
    <-0.8525414, 1.6017052, 34.0159774>,
    <-0.8120641, 1.6315943, 34.0159774>,
    <-0.8196139, 1.6233220, 34.0159774>,
    <-0.8543429, 1.6030057, 34.0159774>,
    <-0.8335474, 1.6169625, 34.0159774>,
    <-0.9064926, 1.5663956, 34.0159774>,
    <-0.8856441, 1.5798203, 34.0159774>,
    <-0.8942272, 1.5769322, 34.0159774>,
    <-0.8737625, 1.5903989, 34.0159774>,
    <-0.8400004, 1.6045413, 34.0159774>,
    <-0.8470559, 1.6024863, 34.0159774>,
    <-0.8238394, 1.6139814, 34.0159774>,
    <-0.8238448, 1.6174082, 34.0159774>,
    <-0.8569599, 1.5894936, 34.0159774>,
    <-0.8321936, 1.6010426, 34.0159774>,
    <-0.8482533, 1.5975536, 34.0159774>,
    <-0.8271800, 1.6081205, 34.0159774>,
    <-0.8817262, 1.5779446, 34.0159774>,
    <-0.8655663, 1.5896853, 34.0159774>,
    <-0.8410211, -1.6059861, 34.0159774>,
    <-0.8555806, -1.5923161, 34.0159774>,
    <-0.8479628, -1.5997714, 34.0159774>,
    <-0.8267007, -1.6057830, 34.0159774>,
    <-0.8239483, -1.6153572, 34.0159774>,
    <-0.8242813, -1.6111267, 34.0159774>,
    <-0.8607797, -1.6002769, 34.0159774>,
    <-0.8269317, -1.6226562, 34.0159774>,
    <-0.8502323, -1.6032587, 34.0159774>,
    <-0.8277882, -1.6173608, 34.0159774>,
    <-0.9064790, -1.5685819, 34.0159774>,
    <-0.8903978, -1.5797126, 34.0159774>,
    <-0.8817160, -1.5801290, 34.0159774>,
    <-0.8673146, -1.5911864, 34.0159774>,
    <-0.8885142, 1.5886166, 34.0159774>,
    <-0.8794264, 1.6001817, 34.0159774>,
    <-0.8844125, 1.5937860, 34.0159774>,
    <-0.8630224, 1.6078314, 34.0159774>,
    <-0.8837629, 1.5896171, 34.0159774>,
    <-0.8731177, 1.5988407, 34.0159774>,
    <-0.9098070, 1.5742005, 34.0159774>,
    <-0.9081046, 1.5689747, 34.0159774>,
    <-0.8976263, 1.5823256, 34.0159774>,
    <-0.8955080, 1.5799278, 34.0159774>,
    <-0.9161230, 1.5830689, 34.0159774>,
    <-0.9120830, 1.5781981, 34.0159774>,
    <-0.8973858, 1.5918067, 34.0159774>,
    <-0.8979538, 1.5865976, 34.0159774>,
    <-0.8792723, -1.5949767, 34.0159774>,
    <-0.8646660, -1.6092443, 34.0159774>,
    <-0.9161050, -1.5852580, 34.0159774>,
    <-0.9107840, -1.5759533, 34.0159774>,
    <-0.8729589, -1.6012582, 34.0159774>,
    <-0.8910790, -1.5969277, 34.0159774>,
    <-0.9130345, -1.5799345, 34.0159774>,
    <-0.8931410, -1.5865485, 34.0159774>,
    <-0.8930018, -1.5910867, 34.0159774>,
    <-0.9081955, -1.5712259, 34.0159774>,
    <-0.8712545, -1.5973390, 34.0159774>,
    <-0.8897131, -1.5846161, 34.0159774>,
    <-0.8354789, -1.6228543, 34.0159774>,
    <-0.8532525, -1.6100897, 34.0159774>,
    <-0.8392593, 1.8290060, 34.3035582>,
    <-0.9137471, 1.7952395, 34.3035582>,
    <-1.0091362, 1.7478492, 34.3035582>,
    <-0.8497100, 1.8221941, 34.3035582>,
    <-0.8718478, 1.8142332, 34.3035582>,
    <-0.9614417, 1.7715444, 34.3035582>,
    <-0.9294231, 1.7850216, 34.3035582>,
    <-0.8438315, 1.8260258, 34.3035582>,
    <-0.9029632, 1.7985722, 34.3035582>,
    <-0.7543209, 1.8695844, 34.3035582>,
    <-0.7699968, 1.8593665, 34.3035582>,
    <-0.7223023, 1.8830616, 34.3035582>,
    <-0.8020988, 1.8467590, 34.3035582>,
    <-0.7833935, 1.8543308, 34.3035582>,
    <-0.8183581, 1.8426299, 34.3035582>,
    <-0.7863395, 1.8561071, 34.3035582>,
    <-0.8660526, 1.8189347, 34.3035582>,
    <-0.8314214, 1.8341150, 34.3035582>,
    <-0.9324954, 1.5605228, 34.0159774>,
    <-0.9491904, 1.5440876, 34.0159774>,
    <-0.9792034, 1.5296246, 34.0159774>,
    <-0.9446529, 1.5588970, 34.0159774>,
    <-0.9378601, 1.5546003, 34.0159774>,
    <-0.9643469, 1.5367431, 34.0159774>,
    <-0.9607993, 1.5452172, 34.0159774>,
    <-0.9375991, 1.5600683, 34.0159774>,
    <-0.9499229, 1.5494069, 34.0159774>,
    <-0.9300117, 1.5713018, 34.0159774>,
    <-0.9222778, 1.5666871, 34.0159774>,
    <-0.9251420, 1.5695102, 34.0159774>,
    <-0.9253092, 1.5561361, 34.0159774>,
    <-0.9234247, 1.5618011, 34.0159774>,
    <-0.8056349, 1.8660227, 34.2956984>,
    <-0.8525908, 1.8557463, 34.2918000>,
    <-0.9664551, 1.8026515, 34.2918015>,
    <-0.8443927, 1.8416155, 34.2978489>,
    <-0.8255235, 1.8618299, 34.2939968>,
    <-0.9165727, 1.8259116, 34.2918009>,
    <-0.9200052, 1.8163956, 34.2944683>,
    <-0.8207919, 1.8561212, 34.2966643>,
    <-0.8697713, 1.8402400, 34.2943263>,
    <-0.7538226, 1.8735209, 34.3013240>,
    <-0.7690227, 1.8808474, 34.2964341>,
    <-0.7674565, 1.8751081, 34.2986274>,
    <-0.7792090, 1.8899642, 34.2917990>,
    <-0.7734105, 1.8856420, 34.2941414>,
    <-0.8955673, 1.8121416, 34.2997409>,
    <-0.9721133, 1.7819327, 34.2978493>,
    <-0.8737671, 1.8247580, 34.2989152>,
    <-0.9676002, 1.7942015, 34.2944686>,
    <-0.9338361, 1.7967465, 34.2989154>,
    <-0.9243082, 1.8073130, 34.2968524>,
    <-0.8497100, 1.8221941, 34.3035582>,
    <-0.9884775, 1.7635989, 34.3013243>,
    <-0.9294231, 1.7850216, 34.3035582>,
    <-0.8775321, 1.8156506, 34.3013919>,
    <-0.9339765, 1.7899433, 34.3011851>,
    <-0.7699968, 1.8593665, 34.3035582>,
    <-0.8221508, 1.8420904, 34.3011850>,
    <-1.0141314, 1.7674737, 34.2956998>,
    <-1.0145212, 1.7802383, 34.2918021>,
    <-1.0249884, 1.7753575, 34.2918022>,
    <-1.0491483, 1.7412518, 34.2968965>,
    <-1.0147239, 1.7731076, 34.2939985>,
    <-1.0221048, 1.7767021, 34.2918022>,
    <-1.0483668, 1.7504034, 34.2943349>,
    <-1.0268871, 1.7576216, 34.2964357>,
    <-1.0278890, 1.7649901, 34.2941437>,
    <-1.0310938, 1.7413095, 34.3006313>,
    <-0.9992167, 1.7724222, 34.2966652>,
    <-1.0123128, 1.7589402, 34.2986283>,
    <-0.9975380, 1.7881576, 34.2918019>,
    <-0.9959260, 1.7814128, 34.2943273>,
    <-0.9820994, -1.7837366, 34.2956994>,
    <-1.0085188, -1.7675078, 34.2968964>,
    <-1.0249907, -1.7753564, 34.2918022>,
    <-0.9762707, -1.7980749, 34.2918015>,
    <-0.9956986, -1.7751473, 34.2964354>,
    <-1.0133516, -1.7730244, 34.2943347>,
    <-1.0016092, -1.7862594, 34.2918019>,
    <-0.9807953, -1.7894264, 34.2939980>,
    <-0.9997501, -1.7800995, 34.2941434>,
    <-0.9434511, -1.7954172, 34.2978512>,
    <-0.9470181, -1.8117156, 34.2918011>,
    <-0.9225508, -1.8151815, 34.2944773>,
    <-0.9691519, -1.7869402, 34.2966648>,
    <-0.9566762, -1.7997162, 34.2943267>,
    <-1.0091264, -1.7478583, 34.3035582>,
    <-0.9766161, -1.7696300, 34.3013242>,
    <-1.0072445, -1.7567490, 34.3006312>,
    <-0.9872624, -1.7726108, 34.2986281>,
    <-0.8726964, -1.8227339, 34.2997655>,
    <-0.9072066, -1.8091381, 34.2989243>,
    <-0.8466304, -1.8372465, 34.2989710>,
    <-0.8877437, -1.8242534, 34.2968893>,
    <-0.8497051, -1.8221986, 34.3035582>,
    <-0.7699944, -1.8593687, 34.3035582>,
    <-0.8635999, -1.8221214, 34.3014011>,
    <-0.8077534, -1.8486941, 34.3012222>,
    <-0.9294158, -1.7850285, 34.3035582>,
    <-0.9199828, -1.7964712, 34.3011849>,
    <-1.0281941, -1.7599088, 34.2956998>,
    <-1.0344618, -1.7687257, 34.2918021>,
    <-1.0299085, -1.7645489, 34.2939985>,
    <-1.0276025, -1.7735281, 34.2918022>,
    <-1.0189654, -1.7633530, 34.2964356>,
    <-1.0214111, -1.7694901, 34.2941437>,
    <-1.0577726, -1.7327730, 34.2978517>,
    <-1.0348981, -1.7371634, 34.3013243>,
    <-1.0371241, -1.7508331, 34.2966652>,
    <-1.0240108, -1.7530178, 34.2986283>,
    <-1.0779128, -1.7383013, 34.2918015>,
    <-1.0703320, -1.7350090, 34.2944780>,
    <-1.0498161, -1.7579748, 34.2918019>,
    <-1.0448236, -1.7532528, 34.2943273>,
    <-0.9430488, -1.5582856, 34.0159774>,
    <-0.9611930, -1.5536880, 34.0159774>,
    <-1.0049962, -1.5230175, 34.0159774>,
    <-0.9613756, -1.5432224, 34.0159774>,
    <-0.9509927, -1.5563266, 34.0159774>,
    <-0.9833355, -1.5381841, 34.0159774>,
    <-0.9830547, -1.5332240, 34.0159774>,
    <-0.9492325, -1.5526114, 34.0159774>,
    <-0.9668448, -1.5449921, 34.0159774>,
    <-0.9298725, -1.5575693, 34.0159774>,
    <-0.9288676, -1.5659561, 34.0159774>,
    <-0.9293770, -1.5618536, 34.0159774>,
    <-0.9387293, -1.5694168, 34.0159774>,
    <-0.9327104, -1.5681609, 34.0159774>,
    <-0.9859523, 1.5157284, 34.0159774>,
    <-0.9909445, 1.5072615, 34.0159774>,
    <-1.0753965, 1.4481273, 34.0159774>,
    <-1.0242897, 1.4914262, 34.0159774>,
    <-0.9878056, 1.5122858, 34.0159774>,
    <-1.0331705, 1.4776944, 34.0159774>,
    <-1.0494668, 1.4700956, 34.0159774>,
    <-1.0024411, 1.5053181, 34.0159774>,
    <-1.0186001, 1.4910734, 34.0159774>,
    <-1.0006177, 1.5114818, 34.0159774>,
    <-0.9678611, 1.5293686, 34.0159774>,
    <-0.9831049, 1.5212941, 34.0159774>,
    <-0.9487185, 1.5368285, 34.0159774>,
    <-0.9571553, 1.5339675, 34.0159774>,
    <-1.0015015, -1.5177021, 34.0159774>,
    <-1.0461934, -1.4941712, 34.0159774>,
    <-0.9818518, -1.5299009, 34.0159774>,
    <-1.0260145, -1.5083005, 34.0159774>,
    <-1.0207773, -1.5075930, 34.0159774>,
    <-1.0024106, -1.5200890, 34.0159774>,
    <-1.0832449, -1.4682275, 34.0159774>,
    <-1.0053396, -1.5108959, 34.0159774>,
    <-1.0653359, -1.4807675, 34.0159774>,
    <-1.0561771, -1.4825514, 34.0159774>,
    <-1.0017026, -1.5157334, 34.0159774>,
    <-1.0340198, -1.4977419, 34.0159774>,
    <-0.9451700, -1.5456919, 34.0159774>,
    <-0.9673831, -1.5357592, 34.0159774>,
    <-1.0222850, -1.4951077, 34.0159774>,
    <-1.0699259, -1.4642558, 34.0159774>,
    <-1.0138860, -1.5027233, 34.0159774>,
    <-1.0766192, -1.4669237, 34.0159774>,
    <-1.0442377, -1.4812964, 34.0159774>,
    <-1.0457664, -1.4844240, 34.0159774>,
    <-1.0629918, -1.4589919, 34.0159774>,
    <-0.9896973, -1.5103127, 34.0159774>,
    <-1.0662800, -1.4617343, 34.0159774>,
    <-1.0282052, -1.4833494, 34.0159774>,
    <-1.0081986, -1.5016765, 34.0159774>,
    <-1.0375190, -1.4814921, 34.0159774>,
    <-0.9487084, -1.5390130, 34.0159774>,
    <-0.9814389, -1.5208991, 34.0159774>,
    <-1.0242633, 1.4997864, 34.0159774>,
    <-0.9957598, 1.5155981, 34.0159774>,
    <-1.0710616, 1.4636943, 34.0159774>,
    <-1.0122444, 1.5063423, 34.0159774>,
    <-1.0355781, 1.4818627, 34.0159774>,
    <-1.0708460, 1.4584484, 34.0159774>,
    <-1.0460108, 1.4831560, 34.0159774>,
    <-1.0422370, 1.4814689, 34.0159774>,
    <-1.0742892, 1.4723193, 34.0159774>,
    <-1.0002189, 1.5241842, 34.0159774>,
    <-1.0727319, 1.4686533, 34.0159774>,
    <-1.0391339, 1.4969356, 34.0159774>,
    <-1.0141169, 1.5101535, 34.0159774>,
    <-1.0440148, 1.4890053, 34.0159774>,
    <-0.9587976, 1.5531878, 34.0159774>,
    <-0.9559414, 1.5493335, 34.0159774>,
    <-0.9848671, 1.5300552, 34.0159774>,
    <-1.1072204, 1.4338933, 34.0159774>,
    <-1.1250106, 1.4250326, 34.0159774>,
    <-1.1152414, 1.4298318, 34.0159774>,
    <-1.0983858, 1.4504156, 34.0159774>,
    <-1.0926705, 1.4460937, 34.0159774>,
    <-1.0958804, 1.4478098, 34.0159774>,
    <-1.1201655, 1.4167793, 34.0159774>,
    <-1.0977810, 1.4324533, 34.0159774>,
    <-1.1133315, 1.4260467, 34.0159774>,
    <-1.0940727, 1.4402943, 34.0159774>,
    <-1.1649346, 1.3854313, 34.0159774>,
    <-1.1425501, 1.4011053, 34.0159774>,
    <-1.1483589, 1.4018187, 34.0159774>,
    <-1.1300370, 1.4147456, 34.0159774>,
    <-1.1307110, -1.4272293, 34.0159774>,
    <-1.1147514, -1.4461664, 34.0159774>,
    <-1.1403738, -1.4282254, 34.0159774>,
    <-1.1503485, -1.4108627, 34.0159774>,
    <-1.1239793, -1.4353306, 34.0159774>,
    <-1.1283082, -1.4366738, 34.0159774>,
    <-1.1451999, -1.4196895, 34.0159774>,
    <-1.1401434, -1.4190647, 34.0159774>,
    <-1.1349004, -1.4273192, 34.0159774>,
    <-1.1649240, -1.3876187, 34.0159774>,
    <-1.1221744, -1.4290880, 34.0159774>,
    <-1.1589547, -1.3970036, 34.0159774>,
    <-1.1484357, -1.4033651, 34.0159774>,
    <-1.1277652, -1.4274641, 34.0159774>,
    <-1.1426881, -1.4130105, 34.0159774>,
    <-1.0973817, -1.4536999, 34.0159774>,
    <-1.0997235, -1.4566890, 34.0159774>,
    <-1.1135640, -1.4420448, 34.0159774>,
    <-1.1064634, -1.4361660, 34.0159774>,
    <-1.1189198, -1.4198310, 34.0159774>,
    <-1.1124532, -1.4286774, 34.0159774>,
    <-1.0928165, -1.4381086, 34.0159774>,
    <-1.0919575, -1.4478830, 34.0159774>,
    <-1.0913617, -1.4437914, 34.0159774>,
    <-1.1144470, -1.4323105, 34.0159774>,
    <-1.0966542, -1.4487923, 34.0159774>,
    <-1.1425421, -1.4032906, 34.0159774>,
    <-1.1292436, -1.4174062, 34.0159774>,
    <-1.1439169, 1.4148486, 34.0159774>,
    <-1.1308144, 1.4327392, 34.0159774>,
    <-1.1380431, 1.4229455, 34.0159774>,
    <-1.1044316, 1.4512131, 34.0159774>,
    <-1.1353724, 1.4196933, 34.0159774>,
    <-1.1194709, 1.4358038, 34.0159774>,
    <-1.1776105, 1.3831405, 34.0159774>,
    <-1.1722590, 1.3817825, 34.0159774>,
    <-1.1579175, 1.4021994, 34.0159774>,
    <-1.1529982, 1.4021803, 34.0159774>,
    <-1.1773140, 1.4001790, 34.0159774>,
    <-1.1792270, 1.3900713, 34.0159774>,
    <-1.1546908, 1.4160203, 34.0159774>,
    <-1.1576106, 1.4077316, 34.0159774>,
    <-1.1638836, -1.4032242, 34.0159774>,
    <-1.1603481, -1.4142393, 34.0159774>,
    <-1.1772993, -1.4023700, 34.0159774>,
    <-1.1851529, -1.3814115, 34.0159774>,
    <-1.1620150, -1.4084062, 34.0159774>,
    <-1.1690126, -1.4081723, 34.0159774>,
    <-1.1858768, -1.3868357, 34.0159774>,
    <-1.1713016, -1.3952304, 34.0159774>,
    <-1.1714587, -1.4003404, 34.0159774>,
    <-1.1759045, -1.3822644, 34.0159774>,
    <-1.1582083, -1.4061241, 34.0159774>,
    <-1.1659382, -1.3955644, 34.0159774>,
    <-1.1509278, -1.4208354, 34.0159774>,
    <-1.1537501, -1.4141206, 34.0159774>,
    <-1.1442772, 1.6575123, 34.3035582>,
    <-1.2118478, 1.6123438, 34.3035582>,
    <-1.2964647, 1.5450496, 34.3035582>,
    <-1.1528004, 1.6464494, 34.3035582>,
    <-1.1738394, 1.6377510, 34.3035582>,
    <-1.2541562, 1.5786967, 34.3035582>,
    <-1.2246326, 1.5957495, 34.3035582>,
    <-1.1480061, 1.6526723, 34.3035582>,
    <-1.2013475, 1.6153388, 34.3035582>,
    <-1.0681835, 1.7137436, 34.3035582>,
    <-1.0809683, 1.6971493, 34.3035582>,
    <-1.0386599, 1.7307964, 34.3035582>,
    <-1.1109862, 1.6821135, 34.3035582>,
    <-1.0935993, 1.6913886, 34.3035582>,
    <-1.1272309, 1.6796379, 34.3035582>,
    <-1.0977072, 1.6966907, 34.3035582>,
    <-1.1695393, 1.6459908, 34.3035582>,
    <-1.1378849, 1.6658094, 34.3035582>,
    <-1.1174134, 1.6977516, 34.2956998>,
    <-1.1618862, 1.6795018, 34.2918021>,
    <-1.2648040, 1.6074384, 34.2918017>,
    <-1.1512635, 1.6668884, 34.2978494>,
    <-1.1362815, 1.6901835, 34.2939985>,
    <-1.2197164, 1.6390091, 34.2918020>,
    <-1.2213799, 1.6289620, 34.2944687>,
    <-1.1305986, 1.6853418, 34.2966653>,
    <-1.1760882, 1.6612140, 34.2943273>,
    <-1.0676453, 1.7140724, 34.3013243>,
    <-1.0839442, 1.7187208, 34.2964357>,
    <-1.0813859, 1.7133156, 34.2986283>,
    <-1.0955611, 1.7259426, 34.2918022>,
    <-1.0891026, 1.7226906, 34.2941437>,
    <-1.1963530, 1.6287519, 34.2997409>,
    <-1.2664389, 1.5856483, 34.2978490>,
    <-1.1771682, 1.6450727, 34.2989154>,
    <-1.2643372, 1.5987661, 34.2944685>,
    <-1.2313335, 1.6069063, 34.2989153>,
    <-1.2239233, 1.6191305, 34.2968525>,
    <-1.1528004, 1.6464494, 34.3035582>,
    <-1.2790839, 1.5644153, 34.3013241>,
    <-1.2246326, 1.5957495, 34.3035582>,
    <-1.1791415, 1.6352681, 34.3013919>,
    <-1.2301351, 1.5999987, 34.3011850>,
    <-1.0809683, 1.6971493, 34.3035582>,
    <-1.1293372, 1.6710918, 34.3011851>,
    <-1.3053861, 1.5641990, 34.2956988>,
    <-1.3082566, 1.5770114, 34.2918006>,
    <-1.3177291, 1.5703766, 34.2917990>,
    <-1.3352181, 1.5321825, 34.2968951>,
    <-1.3070626, 1.5697754, 34.2939972>,
    <-1.3151166, 1.5722070, 34.2917998>,
    <-1.3362217, 1.5415369, 34.2943327>,
    <-1.3161720, 1.5522061, 34.2964345>,
    <-1.3186030, 1.5594731, 34.2941420>,
    <-1.3171985, 1.5350805, 34.3006308>,
    <-1.2915080, 1.5716069, 34.2966645>,
    <-1.3019064, 1.5558729, 34.2986276>,
    <-1.2929015, 1.5877639, 34.2918012>,
    <-1.2899857, 1.5812165, 34.2943266>,
    <-1.2141196, -1.6306670, 34.2957483>,
    <-1.1808286, -1.6662382, 34.2918000>,
    <-1.1750809, -1.6510937, 34.2979354>,
    <-1.2000529, -1.6459172, 34.2940155>,
    <-1.1229994, -1.7067310, 34.2918009>,
    <-1.1140716, -1.7044707, 34.2945057>,
    <-1.1987620, -1.6383725, 34.2967298>,
    <-1.1598814, -1.6729403, 34.2943637>,
    <-1.2985827, -1.5475906, 34.3035582>,
    <-1.2777533, -1.5820304, 34.2969721>,
    <-1.2503055, -1.5875281, 34.3015013>,
    <-1.2848562, -1.5651222, 34.3007900>,
    <-1.2449597, -1.6067199, 34.2964996>,
    <-1.2416399, -1.6022506, 34.2987023>,
    <-1.3177242, -1.5703814, 34.2917980>,
    <-1.2864652, -1.5840321, 34.2943882>,
    <-1.2471526, -1.6197969, 34.2917990>,
    <-1.2465008, -1.6128446, 34.2941788>,
    <-1.1225701, -1.6816979, 34.2997658>,
    <-1.1451436, -1.6686014, 34.2989714>,
    <-1.0896147, -1.7072686, 34.2989247>,
    <-1.1041390, -1.7037542, 34.2968899>,
    <-1.1538546, -1.6477245, 34.3035582>,
    <-1.0814905, -1.6977914, 34.3035582>,
    <-1.1343679, -1.6682323, 34.3014013>,
    <-1.0834601, -1.7041806, 34.3011851>,
    <-1.2262187, -1.5976576, 34.3035582>,
    <-1.1857746, -1.6331933, 34.3012224>,
    <-1.3127687, -1.5599302, 34.2956246>,
    <-1.3247512, -1.5633544, 34.2917980>,
    <-1.3182538, -1.5614535, 34.2939680>,
    <-1.3199745, -1.5681311, 34.2917980>,
    <-1.3003020, -1.5672398, 34.2964529>,
    <-1.3071858, -1.5697897, 34.2941780>,
    <-1.3346999, -1.5347933, 34.2969719>,
    <-1.3151716, -1.5402119, 34.3007899>,
    <-1.3205924, -1.5502551, 34.2964529>,
    <-1.3052283, -1.5562728, 34.2985179>,
    <-1.3519889, -1.5361167, 34.2917984>,
    <-1.3441073, -1.5347643, 34.2943881>,
    <-1.3345805, -1.5535251, 34.2917982>,
    <-1.3292605, -1.5503595, 34.2941780>,
    <-1.2186076, 1.3402354, 34.0159774>,
    <-1.2367641, 1.3136016, 34.0159774>,
    <-1.3000301, 1.2503353, 34.0159774>,
    <-1.2433741, 1.3205022, 34.0159774>,
    <-1.2263959, 1.3288443, 34.0159774>,
    <-1.2700027, 1.2803629, 34.0159774>,
    <-1.2768487, 1.2794509, 34.0159774>,
    <-1.2291644, 1.3320098, 34.0159774>,
    <-1.2504711, 1.3055461, 34.0159774>,
    <-1.2070609, 1.3642861, 34.0159774>,
    <-1.1999058, 1.3602088, 34.0159774>,
    <-1.2043076, 1.3610346, 34.0159774>,
    <-1.2013845, 1.3489812, 34.0159774>,
    <-1.1996169, 1.3555526, 34.0159774>,
    <-1.2687951, 1.2996553, 34.0159774>,
    <-1.3071181, 1.2567946, 34.0159774>,
    <-1.2581340, 1.3083385, 34.0159774>,
    <-1.3036736, 1.2526259, 34.0159774>,
    <-1.2865717, 1.2799006, 34.0159774>,
    <-1.2815585, 1.2801101, 34.0159774>,
    <-1.3047082, 1.2727846, 34.0159774>,
    <-1.2489929, 1.3285000, 34.0159774>,
    <-1.3074986, 1.2639945, 34.0159774>,
    <-1.2798437, 1.2976491, 34.0159774>,
    <-1.2606578, 1.3117487, 34.0159774>,
    <-1.2848831, 1.2869582, 34.0159774>,
    <-1.2141511, 1.3633418, 34.0159774>,
    <-1.2358559, 1.3359855, 34.0159774>,
    <-1.2644113, -1.2969516, 34.0159774>,
    <-1.2427411, -1.3231467, 34.0159774>,
    <-1.3138408, -1.2658303, 34.0159774>,
    <-1.3070931, -1.2571735, 34.0159774>,
    <-1.2552133, -1.3081591, 34.0159774>,
    <-1.2879883, -1.2863203, 34.0159774>,
    <-1.3110234, -1.2617630, 34.0159774>,
    <-1.2844343, -1.2787360, 34.0159774>,
    <-1.2834916, -1.2845417, 34.0159774>,
    <-1.3000274, -1.2525167, 34.0159774>,
    <-1.2367588, -1.3157847, 34.0159774>,
    <-1.3037417, -1.2546466, 34.0159774>,
    <-1.2699992, -1.2825446, 34.0159774>,
    <-1.2528688, -1.3046775, 34.0159774>,
    <-1.2788488, -1.2790983, 34.0159774>,
    <-1.2013768, -1.3511663, 34.0159774>,
    <-1.1941415, -1.3631908, 34.0159774>,
    <-1.2280230, -1.3300854, 34.0159774>,
    <-1.2241121, -1.3463590, 34.0159774>,
    <-1.2498988, -1.3297715, 34.0159774>,
    <-1.2350757, -1.3394494, 34.0159774>,
    <-1.2834931, -1.2961776, 34.0159774>,
    <-1.2316721, -1.3368111, 34.0159774>,
    <-1.2579615, -1.3159712, 34.0159774>,
    <-1.2052279, -1.3631772, 34.0159774>,
    <-1.2038670, -1.3597439, 34.0159774>,
    <-1.2141401, -1.3655297, 34.0159774>,
    <-1.2090650, -1.3648048, 34.0159774>,
    <-1.3518641, 1.2165190, 34.0159774>,
    <-1.3684217, 1.1970831, 34.0159774>,
    <-1.3503709, 1.2271215, 34.0159774>,
    <-1.3330941, 1.2443986, 34.0159774>,
    <-1.3598181, 1.2068308, 34.0159774>,
    <-1.3595950, 1.2119233, 34.0159774>,
    <-1.3418201, 1.2356726, 34.0159774>,
    <-1.3437687, 1.2286124, 34.0159774>,
    <-1.3514866, 1.2205161, 34.0159774>,
    <-1.3493915, 1.2139577, 34.0159774>,
    <-1.3215909, 1.2559019, 34.0159774>,
    <-1.3258020, 1.2454945, 34.0159774>,
    <-1.3515427, 1.2145766, 34.0159774>,
    <-1.3367746, 1.2348044, 34.0159774>,
    <-1.3880267, 1.1623372, 34.0159774>,
    <-1.3730268, 1.1820832, 34.0159774>,
    <-1.3801045, 1.1764337, 34.0159774>,
    <-1.3654797, 1.1960879, 34.0159774>,
    <-1.3382073, 1.2210255, 34.0159774>,
    <-1.3444631, 1.2165293, 34.0159774>,
    <-1.3257708, 1.2355494, 34.0159774>,
    <-1.3275919, 1.2383356, 34.0159774>,
    <-1.3483102, 1.2020546, 34.0159774>,
    <-1.3257758, 1.2245893, 34.0159774>,
    <-1.3433660, 1.2120198, 34.0159774>,
    <-1.3254086, 1.2306081, 34.0159774>,
    <-1.3687037, 1.1816607, 34.0159774>,
    <-1.3575336, 1.1982206, 34.0159774>,
    <-1.3392986, -1.2220649, 34.0159774>,
    <-1.3483051, -1.2042393, 34.0159774>,
    <-1.3436963, -1.2138507, 34.0159774>,
    <-1.3257724, -1.2267719, 34.0159774>,
    <-1.3264603, -1.2367103, 34.0159774>,
    <-1.3253264, -1.2326210, 34.0159774>,
    <-1.3559132, -1.2099420, 34.0159774>,
    <-1.3317601, -1.2425488, 34.0159774>,
    <-1.3470216, -1.2163515, 34.0159774>,
    <-1.3307539, -1.2372798, 34.0159774>,
    <-1.3880166, -1.1645280, 34.0159774>,
    <-1.3767119, -1.1804876, 34.0159774>,
    <-1.3686962, -1.1838483, 34.0159774>,
    <-1.3589450, -1.1991645, 34.0159774>,
    <-1.3787319, 1.1893680, 34.0159774>,
    <-1.3741473, 1.2033443, 34.0159774>,
    <-1.3766455, 1.1956287, 34.0159774>,
    <-1.3613489, 1.2161432, 34.0159774>,
    <-1.3746094, 1.1919332, 34.0159774>,
    <-1.3677606, 1.2042416, 34.0159774>,
    <-1.3938103, 1.1685385, 34.0159774>,
    <-1.3904235, 1.1642098, 34.0159774>,
    <-1.3851430, 1.1803397, 34.0159774>,
    <-1.3823325, 1.1788108, 34.0159774>,
    <-1.4027781, 1.1747125, 34.0159774>,
    <-1.3973161, 1.1715168, 34.0159774>,
    <-1.3881593, 1.1893318, 34.0159774>,
    <-1.3869116, 1.1842424, 34.0159774>,
    <-1.3714779, -1.1986365, 34.0159774>,
    <-1.3626322, -1.2170393, 34.0159774>,
    <-1.4027661, -1.1769056, 34.0159774>,
    <-1.3945830, -1.1699826, 34.0159774>,
    <-1.3676937, -1.2066985, 34.0159774>,
    <-1.3832403, -1.1964314, 34.0159774>,
    <-1.3980596, -1.1729538, 34.0159774>,
    <-1.3816278, -1.1859731, 34.0159774>,
    <-1.3830492, -1.1902851, 34.0159774>,
    <-1.3905337, -1.1664256, 34.0159774>,
    <-1.3647515, -1.2035986, 34.0159774>,
    <-1.3777456, -1.1853296, 34.0159774>,
    <-1.3398598, -1.2398115, 34.0159774>,
    <-1.3521960, -1.2217375, 34.0159774>,
    <-1.4104523, 1.1479258, 34.0159774>,
    <-1.4205194, 1.1267718, 34.0159774>,
    <-1.4437755, 1.1029164, 34.0159774>,
    <-1.4213205, 1.1422402, 34.0159774>,
    <-1.4134680, 1.1405256, 34.0159774>,
    <-1.4322498, 1.1146866, 34.0159774>,
    <-1.4318144, 1.1238630, 34.0159774>,
    <-1.4150927, 1.1457533, 34.0159774>,
    <-1.4230269, 1.1315199, 34.0159774>,
    <-1.4118047, 1.1589046, 34.0159774>,
    <-1.4029593, 1.1572129, 34.0159774>,
    <-1.4066161, 1.1588863, 34.0159774>,
    <-1.4021994, 1.1462612, 34.0159774>,
    <-1.4023661, 1.1522292, 34.0159774>,
    <-1.3782945, -1.4957306, 34.2957478>,
    <-1.4017236, -1.4644955, 34.2979373>,
    <-1.4821443, -1.4059613, 34.2918004>,
    <-1.4130686, -1.4750370, 34.2917993>,
    <-1.3859672, -1.4845588, 34.2967293>,
    <-1.4511639, -1.4272631, 34.2945142>,
    <-1.4486335, -1.4394721, 34.2917999>,
    <-1.3927272, -1.4874775, 34.2940149>,
    <-1.4179038, -1.4610611, 34.2943630>,
    <-1.3795027, -1.5086030, 34.2917988>,
    <-1.3565224, -1.5148225, 34.2964993>,
    <-1.3666956, -1.5129244, 34.2941785>,
    <-1.3401455, -1.5133638, 34.3015011>,
    <-1.3516169, -1.5118737, 34.2987020>,
    <-1.4188590, -1.1423455, 34.0159774>,
    <-1.4343365, -1.1318197, 34.0159774>,
    <-1.4650075, -1.0880180, 34.0159774>,
    <-1.4309285, -1.1219228, 34.0159774>,
    <-1.4256539, -1.1377877, 34.0159774>,
    <-1.4498406, -1.1096781, 34.0159774>,
    <-1.4478803, -1.1051131, 34.0159774>,
    <-1.4227291, -1.1348987, 34.0159774>,
    <-1.4366731, -1.1217153, 34.0159774>,
    <-1.4062326, -1.1461787, 34.0159774>,
    <-1.4081567, -1.1544035, 34.0159774>,
    <-1.4072322, -1.1503742, 34.0159774>,
    <-1.4186075, -1.1542824, 34.0159774>,
    <-1.4125219, -1.1551609, 34.0159774>,
    <-1.3950328, 1.4776576, 34.2956978>,
    <-1.4358720, 1.4522337, 34.2917991>,
    <-1.5246936, 1.3634120, 34.2917992>,
    <-1.4231683, 1.4415041, 34.2978479>,
    <-1.4123788, 1.4670342, 34.2939960>,
    <-1.4857805, 1.4023251, 34.2917991>,
    <-1.4857401, 1.3921564, 34.2944666>,
    <-1.4058778, 1.4631486, 34.2966635>,
    <-1.4465985, 1.4316448, 34.2943250>,
    <-1.3486383, 1.5020631, 34.3013237>,
    <-1.3656201, 1.5040118, 34.2964339>,
    <-1.3620797, 1.4990205, 34.2986271>,
    <-1.3786331, 1.5094726, 34.2917990>,
    <-1.3715334, 1.5071944, 34.2941413>,
    <-1.4453644, 1.0875502, 34.0159774>,
    <-1.4471595, 1.0778868, 34.0159774>,
    <-1.5062923, 0.9934364, 34.0159774>,
    <-1.4730776, 1.0516022, 34.0159774>,
    <-1.4459284, 1.0836816, 34.0159774>,
    <-1.4767259, 1.0356616, 34.0159774>,
    <-1.4894404, 1.0229475, 34.0159774>,
    <-1.4572981, 1.0721285, 34.0159774>,
    <-1.4676104, 1.0532167, 34.0159774>,
    <-1.4576929, 1.0785440, 34.0159774>,
    <-1.4330297, 1.1065551, 34.0159774>,
    <-1.4445924, 1.0937540, 34.0159774>,
    <-1.4175931, 1.1201120, 34.0159774>,
    <-1.4245425, 1.1145380, 34.0159774>,
    <-1.4615638, 1.3966531, 34.2997400>,
    <-1.5234396, 1.3423935, 34.2978480>,
    <-1.4451934, 1.4157848, 34.2989142>,
    <-1.5230437, 1.3551911, 34.2944666>,
    <-1.4924094, 1.3692621, 34.2989143>,
    <-1.4868326, 1.3822584, 34.2968510>,
    <-1.5475924, 1.2985842, 34.3035582>,
    <-1.4220285, 1.4218169, 34.3035582>,
    <-1.5330931, 1.3200312, 34.3013238>,
    <-1.4848104, 1.3602006, 34.3035582>,
    <-1.4458670, 1.4061340, 34.3013914>,
    <-1.4904852, 1.3630382, 34.3011845>,
    <-1.3592466, 1.4834333, 34.3035582>,
    <-1.4024868, 1.4495495, 34.3011845>,
    <-1.5579275, 1.3144166, 34.2956981>,
    <-1.5622030, 1.3259027, 34.2917996>,
    <-1.5703911, 1.3177146, 34.2918001>,
    <-1.5820699, 1.2779655, 34.2968955>,
    <-1.5602210, 1.3193535, 34.2939964>,
    <-1.5681296, 1.3199761, 34.2917998>,
    <-1.5841436, 1.2865547, 34.2943333>,
    <-1.5666735, 1.3009031, 34.2964343>,
    <-1.5698594, 1.3072503, 34.2941419>,
    <-1.5655890, 1.2845869, 34.3006309>,
    <-1.5456662, 1.3242150, 34.2966637>,
    <-1.5536559, 1.3073134, 34.2986273>,
    <-1.5489460, 1.3391596, 34.2917994>,
    <-1.5453802, 1.3335732, 34.2943252>,
    <-1.5335015, -1.3404594, 34.2957492>,
    <-1.5526216, -1.3165607, 34.2969738>,
    <-1.5703822, -1.3177236, 34.2918022>,
    <-1.5323706, -1.3557351, 34.2918014>,
    <-1.5433143, -1.3278850, 34.2965008>,
    <-1.5588665, -1.3196961, 34.2943909>,
    <-1.5521398, -1.3359659, 34.2918018>,
    <-1.5339687, -1.3462121, 34.2940166>,
    <-1.5485166, -1.3310063, 34.2941808>,
    <-1.5017312, -1.3644827, 34.2979377>,
    <-1.5095477, -1.3785579, 34.2918009>,
    <-1.4882286, -1.3901987, 34.2945145>,
    <-1.5227126, -1.3477900, 34.2967302>,
    <-1.5149984, -1.3639670, 34.2943640>,
    <-1.5475923, -1.2985841, 34.3035582>,
    <-1.5254397, -1.3280473, 34.3015014>,
    <-1.5479566, -1.3074164, 34.3007906>,
    <-1.5349538, -1.3284407, 34.2987029>,
    <-1.4445305, -1.4150814, 34.2997903>,
    <-1.4723610, -1.3901399, 34.2989804>,
    <-1.4248204, -1.4376800, 34.2989802>,
    <-1.4589010, -1.4109236, 34.2969266>,
    <-1.4230875, -1.4230874, 34.3035582>,
    <-1.3608351, -1.4853390, 34.3035582>,
    <-1.4359012, -1.4179333, 34.3014104>,
    <-1.3924101, -1.4620949, 34.3012221>,
    <-1.4853399, -1.3608358, 34.3035582>,
    <-1.4802445, -1.3742615, 34.3012223>,
    <-1.5672549, -1.3047225, 34.2956273>,
    <-1.5760896, -1.3095743, 34.2918022>,
    <-1.5706966, -1.3074948, 34.2939713>,
    <-1.5722111, -1.3151124, 34.2918022>,
    <-1.5606917, -1.3096415, 34.2964552>,
    <-1.5652428, -1.3136284, 34.2941811>,
    <-1.5812656, -1.2793713, 34.2969740>,
    <-1.5639588, -1.2870895, 34.3007907>,
    <-1.5710596, -1.2960555, 34.2964553>,
    <-1.5609752, -1.3006490, 34.2985195>,
    <-1.5981927, -1.2780092, 34.2918022>,
    <-1.5901966, -1.2780458, 34.2943910>,
    <-1.5840669, -1.2981822, 34.2918022>,
    <-1.5782794, -1.2959875, 34.2941812>,
    <-1.4757469, 1.0597032, 34.0159774>,
    <-1.4545352, 1.0840744, 34.0159774>,
    <-1.5069332, 1.0103903, 34.0159774>,
    <-1.4668598, 1.0697390, 34.0159774>,
    <-1.4804137, 1.0387554, 34.0159774>,
    <-1.5055463, 1.0046912, 34.0159774>,
    <-1.4902889, 1.0369319, 34.0159774>,
    <-1.4865362, 1.0361079, 34.0159774>,
    <-1.5061147, 1.0271327, 34.0159774>,
    <-1.4609208, 1.0916762, 34.0159774>,
    <-1.5076283, 1.0180672, 34.0159774>,
    <-1.4859456, 1.0559371, 34.0159774>,
    <-1.4695523, 1.0732092, 34.0159774>,
    <-1.4893022, 1.0446988, 34.0159774>,
    <-1.4326587, 1.1320385, 34.0159774>,
    <-1.4286566, 1.1293935, 34.0159774>,
    <-1.4492441, 1.1013850, 34.0159774>,
    <-1.4599058, -1.0842182, 34.0159774>,
    <-1.4938539, -1.0468213, 34.0159774>,
    <-1.4456134, -1.1024016, 34.0159774>,
    <-1.4797246, -1.0670001, 34.0159774>,
    <-1.4745615, -1.0681262, 34.0159774>,
    <-1.4615763, -1.0861503, 34.0159774>,
    <-1.5197978, -1.0097697, 34.0159774>,
    <-1.4611846, -1.0765096, 34.0159774>,
    <-1.5072577, -1.0276788, 34.0159774>,
    <-1.4992616, -1.0324874, 34.0159774>,
    <-1.4594214, -1.0822994, 34.0159774>,
    <-1.4836360, -1.0543400, 34.0159774>,
    <-1.4165450, -1.1297858, 34.0159774>,
    <-1.4340212, -1.1128550, 34.0159774>,
    <-1.4717081, -1.0558781, 34.0159774>,
    <-1.5059288, -1.0105819, 34.0159774>,
    <-1.4664204, -1.0659069, 34.0159774>,
    <-1.5131465, -1.0107662, 34.0159774>,
    <-1.4876130, -1.0353916, 34.0159774>,
    <-1.4901192, -1.0378076, 34.0159774>,
    <-1.4976073, -1.0080183, 34.0159774>,
    <-1.4462862, -1.0813115, 34.0159774>,
    <-1.5016352, -1.0094706, 34.0159774>,
    <-1.4732496, -1.0428043, 34.0159774>,
    <-1.4607180, -1.0668684, 34.0159774>,
    <-1.4813664, -1.0378734, 34.0159774>,
    <-1.4175857, -1.1222995, 34.0159774>,
    <-1.4421468, -1.0940838, 34.0159774>,
    <-1.5421229, 0.9643174, 34.0159774>,
    <-1.5531252, 0.9449313, 34.0159774>,
    <-1.5431543, 0.9742345, 34.0159774>,
    <-1.5291403, 0.9942488, 34.0159774>,
    <-1.5472382, 0.9548242, 34.0159774>,
    <-1.5497645, 0.9572493, 34.0159774>,
    <-1.5362183, 0.9841402, 34.0159774>,
    <-1.5369808, 0.9766898, 34.0159774>,
    <-1.5432163, 0.9672581, 34.0159774>,
    <-1.5374479, 0.9647033, 34.0159774>,
    <-1.5198093, 1.0075748, 34.0159774>,
    <-1.5223791, 0.9962766, 34.0159774>,
    <-1.5405051, 0.9637870, 34.0159774>,
    <-1.5312662, 0.9838022, 34.0159774>,
    <-1.5309165, 0.9582686, 34.0159774>,
    <-1.5400992, 0.9504627, 34.0159774>,
    <-1.5456622, 0.9441886, 34.0159774>,
    <-1.5453080, 0.9512866, 34.0159774>,
    <-1.5297421, 0.9711468, 34.0159774>,
    <-1.5339071, 0.9670502, 34.0159774>,
    <-1.5212425, 0.9863441, 34.0159774>,
    <-1.5230863, 0.9890397, 34.0159774>,
    <-1.5338329, 0.9541037, 34.0159774>,
    <-1.5219662, 0.9710515, 34.0159774>,
    <-1.5322682, 0.9626289, 34.0159774>,
    <-1.5211632, 0.9796880, 34.0159774>,
    <-1.5380854, 0.9480304, 34.0159774>,
    <-1.5377426, 0.9550444, 34.0159774>,
    <-1.5504422, -0.9548401, 34.0159774>,
    <-1.5418590, -0.9782629, 34.0159774>,
    <-1.5598002, -0.9526402, 34.0159774>,
    <-1.5631832, -0.9329035, 34.0159774>,
    <-1.5468479, -0.9648611, 34.0159774>,
    <-1.5513517, -0.9647059, 34.0159774>,
    <-1.5614330, -0.9428546, 34.0159774>,
    <-1.5564883, -0.9439527, 34.0159774>,
    <-1.5543583, -0.9535849, 34.0159774>,
    <-1.5689804, -0.9060874, 34.0159774>,
    <-1.5431806, -0.9592703, 34.0159774>,
    <-1.5663575, -0.9171814, 34.0159774>,
    <-1.5592922, -0.9256386, 34.0159774>,
    <-1.5478187, -0.9559516, 34.0159774>,
    <-1.5568652, -0.9372979, 34.0159774>,
    <-1.5281792, -0.9911418, 34.0159774>,
    <-1.5313363, -0.9932910, 34.0159774>,
    <-1.5394165, -0.9746180, 34.0159774>,
    <-1.5307055, -0.9715821, 34.0159774>,
    <-1.5367682, -0.9520912, 34.0159774>,
    <-1.5337381, -0.9625710, 34.0159774>,
    <-1.5184906, -0.9781941, 34.0159774>,
    <-1.5210473, -0.9876280, 34.0159774>,
    <-1.5190672, -0.9840316, 34.0159774>,
    <-1.5369582, -0.9650800, 34.0159774>,
    <-1.5258342, -0.9867422, 34.0159774>,
    <-1.5533086, -0.9284691, 34.0159774>,
    <-1.5457232, -0.9461032, 34.0159774>,
    <-1.5638337, 0.9329623, 34.0159774>,
    <-1.5624399, 0.9466913, 34.0159774>,
    <-1.5636173, 0.9385177, 34.0159774>,
    <-1.5520588, 0.9615172, 34.0159774>,
    <-1.5592050, 0.9376029, 34.0159774>,
    <-1.5564167, 0.9484057, 34.0159774>,
    <-1.5735014, 0.9118836, 34.0159774>,
    <-1.5536776, 0.9302845, 34.0159774>,
    <-1.5675739, 0.9243445, 34.0159774>,
    <-1.5588542, 0.9314179, 34.0159774>,
    <-1.5856627, 0.9135251, 34.0159774>,
    <-1.5802010, 0.9104715, 34.0159774>,
    <-1.5738052, 0.9304597, 34.0159774>,
    <-1.5718104, 0.9253759, 34.0159774>,
    <-1.5724667, -0.9228932, 34.0159774>,
    <-1.5737865, -0.9326658, 34.0159774>,
    <-1.5856560, -0.9157145, 34.0159774>,
    <-1.5809797, -0.9036515, 34.0159774>,
    <-1.5730298, -0.9272848, 34.0159774>,
    <-1.5798535, -0.9240012, 34.0159774>,
    <-1.5842626, -0.9069413, 34.0159774>,
    <-1.5755958, -0.9151734, 34.0159774>,
    <-1.5781500, -0.9185619, 34.0159774>,
    <-1.5743517, -0.9036926, 34.0159774>,
    <-1.5686863, -0.9263475, 34.0159774>,
    <-1.5713401, -0.9158866, 34.0159774>,
    <-1.5671903, -0.9420862, 34.0159774>,
    <-1.5675571, -0.9347351, 34.0159774>,
    <-1.5904503, 0.8822406, 34.0159774>,
    <-1.5991505, 0.8532322, 34.0160180>,
    <-1.6246891, 0.8146490, 34.0159774>,
    <-1.6016662, 0.8729791, 34.0159774>,
    <-1.5923890, 0.8731112, 34.0159774>,
    <-1.6135175, 0.8312500, 34.0159774>,
    <-1.6118615, 0.8471485, 34.0159774>,
    <-1.5956071, 0.8782556, 34.0159774>,
    <-1.6034572, 0.8577575, 34.0159774>,
    <-1.5932257, 0.8943636, 34.0159774>,
    <-1.5823781, 0.8964265, 34.0159774>,
    <-1.5879942, 0.8952958, 34.0159774>,
    <-1.5642143, 0.9080177, 34.0161399>,
    <-1.5759933, 0.8979541, 34.0159774>,
    <-1.5962438, -0.8777876, 34.0159774>,
    <-1.6089171, -0.8658324, 34.0159774>,
    <-1.6315158, -0.8173706, 34.0159774>,
    <-1.6036531, -0.8569474, 34.0159774>,
    <-1.6016806, -0.8728057, 34.0159774>,
    <-1.6203407, -0.8413352, 34.0159774>,
    <-1.6174481, -0.8374217, 34.0159774>,
    <-1.5981574, -0.8706700, 34.0159774>,
    <-1.6093506, -0.8556372, 34.0159774>,
    <-1.5834577, -0.8852388, 34.0159774>,
    <-1.5888657, -0.8899463, 34.0159774>,
    <-1.5865584, -0.8871641, 34.0159774>,
    <-1.5973279, -0.8906847, 34.0159774>,
    <-1.5927120, -0.8907981, 34.0159774>,
    <-1.6170334, -1.2336253, 34.2957498>,
    <-1.6344111, -1.1986385, 34.2979383>,
    <-1.7037858, -1.1272071, 34.2918022>,
    <-1.6477488, -1.2072363, 34.2918022>,
    <-1.6225757, -1.2212469, 34.2967308>,
    <-1.6767485, -1.1534413, 34.2945157>,
    <-1.6766016, -1.1660302, 34.2918022>,
    <-1.6298526, -1.2230101, 34.2940173>,
    <-1.6499948, -1.1925811, 34.2943649>,
    <-1.6205162, -1.2461282, 34.2918022>,
    <-1.5989421, -1.2562330, 34.2965012>,
    <-1.6086538, -1.2526092, 34.2941812>,
    <-1.5823705, -1.2575350, 34.3015015>,
    <-1.5935319, -1.2541428, 34.2987032>,
    <-1.6324693, -0.7846394, 34.0159774>,
    <-1.6255265, -0.8069987, 34.0159774>,
    <-1.6745587, -0.7250654, 34.0159774>,
    <-1.6585887, -0.7335335, 34.0159774>,
    <-1.6289220, -0.7955412, 34.0159774>,
    <-1.6566389, -0.7544580, 34.0159774>,
    <-1.6667634, -0.7302430, 34.0159774>,
    <-1.6447273, -0.7614098, 34.0159774>,
    <-1.6478757, -0.7627342, 34.0159774>,
    <-1.6497297, -0.7329233, 34.0159774>,
    <-1.6119151, -0.8140155, 34.0159774>,
    <-1.6539485, -0.7336541, 34.0159774>,
    <-1.6317824, -0.7714107, 34.0159774>,
    <-1.6235729, -0.7973655, 34.0159774>,
    <-1.6389197, -0.7651453, 34.0159774>,
    <-1.5907677, -0.8593652, 34.0159774>,
    <-1.5900872, -0.8685811, 34.0159774>,
    <-1.6098696, -0.8276323, 34.0159774>,
    <-1.6256917, -0.8147068, 34.0159774>,
    <-1.6530378, -0.7712170, 34.0159774>,
    <-1.6146983, -0.8352247, 34.0159774>,
    <-1.6423597, -0.7941161, 34.0159774>,
    <-1.6375295, -0.7959550, 34.0159774>,
    <-1.6276997, -0.8162880, 34.0159774>,
    <-1.6637157, -0.7483183, 34.0159774>,
    <-1.6248474, -0.8129409, 34.0159774>,
    <-1.6443614, -0.7801418, 34.0159774>,
    <-1.6050139, -0.8476911, 34.0159774>,
    <-1.6285583, 0.7905284, 34.0164107>,
    <-1.6599959, 0.7251966, 34.0159774>,
    <-1.6427081, 0.7607359, 34.0161399>,
    <-1.6410264, 0.7732573, 34.0159774>,
    <-1.6139707, 0.8202463, 34.0161399>,
    <-1.6277612, 0.7961815, 34.0159774>,
    <-1.6279041, 0.7980716, 34.0182821>,
    <-1.5695470, 0.9001338, 34.0171348>,
    <-1.6280194, 0.7916744, 34.0169523>,
    <-1.5991296, 0.8465922, 34.0166273>,
    <-1.7023221, 0.6179602, 34.0159774>,
    <-1.6748475, 0.6907049, 34.0173461>,
    <-1.6807203, 0.6726899, 34.0159774>,
    <-1.6548777, 0.7330971, 34.0166273>,
    <-1.6763797, -0.6905285, 34.0159774>,
    <-1.6785841, -0.6710453, 34.0159774>,
    <-1.6775407, -0.6816532, 34.0159774>,
    <-1.6651169, -0.6999256, 34.0159774>,
    <-1.6695273, -0.7082470, 34.0159774>,
    <-1.6666984, -0.7055744, 34.0159774>,
    <-1.6882309, -0.6726287, 34.0159774>,
    <-1.6793597, -0.7057976, 34.0159774>,
    <-1.6818854, -0.6820837, 34.0159774>,
    <-1.6748510, -0.7049671, 34.0159774>,
    <-1.7023184, -0.6201470, 34.0159774>,
    <-1.6971541, -0.6390105, 34.0159774>,
    <-1.6907713, -0.6449099, 34.0159774>,
    <-1.6868467, -0.6626375, 34.0159774>,
    <-1.6311865, 1.2135994, 34.2956991>,
    <-1.6662433, 1.1808234, 34.2918011>,
    <-1.7383020, 1.0779125, 34.2918015>,
    <-1.6526798, 1.1731985, 34.2978491>,
    <-1.6461151, 1.1998550, 34.2939977>,
    <-1.7067339, 1.1229967, 34.2918014>,
    <-1.7051742, 1.1132328, 34.2944685>,
    <-1.6394464, 1.1975187, 34.2966648>,
    <-1.6736453, 1.1590411, 34.2943268>,
    <-1.5907042, 1.2465409, 34.3013242>,
    <-1.6070067, 1.2448405, 34.2964348>,
    <-1.6030270, 1.2408627, 34.2986278>,
    <-1.6198043, 1.2471452, 34.2918006>,
    <-1.6129217, 1.2465579, 34.2941425>,
    <-1.6821667, 1.1220118, 34.2997409>,
    <-1.7330157, 1.0572942, 34.2978491>,
    <-1.6696557, 1.1438865, 34.2989153>,
    <-1.7351845, 1.0701231, 34.2944685>,
    <-1.7074445, 1.0894057, 34.2989153>,
    <-1.7044570, 1.1033010, 34.2968524>,
    <-1.7478583, 1.0091265, 34.3035582>,
    <-1.6477253, 1.1538553, 34.3035582>,
    <-1.7379600, 1.0331900, 34.3013241>,
    <-1.6977918, 1.0814909, 34.3035582>,
    <-1.6684086, 1.1341589, 34.3013919>,
    <-1.7041809, 1.0834607, 34.3011850>,
    <-1.5976589, 1.2262198, 34.3035582>,
    <-1.6338967, 1.1849369, 34.3011850>,
    <-1.7620316, 1.0236404, 34.2956991>,
    <-1.7687222, 1.0344671, 34.2918011>,
    <-1.7753489, 1.0250020, 34.2918001>,
    <-1.7792180, 0.9834046, 34.2968953>,
    <-1.7653430, 1.0282039, 34.2939976>,
    <-1.7735226, 1.0276108, 34.2918006>,
    <-1.7831138, 0.9917120, 34.2943332>,
    <-1.7681319, 1.0087156, 34.2964348>,
    <-1.7726737, 1.0145813, 34.2941425>,
    <-1.7636262, 0.9924959, 34.3006308>,
    <-1.7516286, 1.0354176, 34.2966647>,
    <-1.7562041, 1.0171772, 34.2986278>,
    <-1.7579734, 1.0498185, 34.2918014>,
    <-1.7532514, 1.0448260, 34.2943268>,
    <-1.7420751, -1.0532765, 34.2957498>,
    <-1.7563966, -1.0262253, 34.2969740>,
    <-1.7753428, -1.0250131, 34.2918022>,
    <-1.7445217, -1.0690303, 34.2918022>,
    <-1.7493321, -1.0390659, 34.2965012>,
    <-1.7637156, -1.0285883, 34.2943910>,
    <-1.7605519, -1.0461368, 34.2918022>,
    <-1.7439215, -1.0590797, 34.2940173>,
    <-1.7555416, -1.0415483, 34.2941812>,
    <-1.7146982, -1.0823008, 34.2979383>,
    <-1.7260127, -1.0954638, 34.2918022>,
    <-1.7065985, -1.1103803, 34.2945157>,
    <-1.7325588, -1.0622740, 34.2967308>,
    <-1.7283073, -1.0798455, 34.2943649>,
    <-1.7467057, -1.0084735, 34.3035582>,
    <-1.7307225, -1.0417414, 34.3015015>,
    <-1.7492981, -1.0175065, 34.3007907>,
    <-1.7407241, -1.0407957, 34.2987032>,
    <-1.6673424, -1.1421751, 34.2997909>,
    <-1.6902996, -1.1127091, 34.2989810>,
    <-1.6521753, -1.1680339, 34.2989810>,
    <-1.6811260, -1.1357798, 34.2969276>,
    <-1.6471490, -1.1535288, 34.3035582>,
    <-1.5973706, -1.2260565, 34.3035582>,
    <-1.6591392, -1.1463724, 34.3014107>,
    <-1.6244633, -1.1976937, 34.3012225>,
    <-1.6969274, -1.0810011, 34.3035582>,
    <-1.6947854, -1.0954118, 34.3012225>,
    <-1.7690731, -1.0122140, 34.2956273>,
    <-1.7795498, -1.0159945, 34.2918022>,
    <-1.7733481, -1.0145790, 34.2939713>,
    <-1.7766913, -1.0221230, 34.2918022>,
    <-1.7632620, -1.0180814, 34.2964553>,
    <-1.7689911, -1.0215368, 34.2941812>,
    <-1.7781455, -0.9846296, 34.2969740>,
    <-1.7615263, -0.9947113, 34.3007907>,
    <-1.7711126, -1.0029022, 34.2964553>,
    <-1.7614753, -1.0088874, 34.2985195>,
    <-1.7958369, -0.9810690, 34.2918022>,
    <-1.7873361, -0.9821314, 34.2943910>,
    <-1.7854283, -1.0033892, 34.2918022>,
    <-1.7787664, -1.0019000, 34.2941812>,
    <-1.6686191, 0.7234216, 34.0162913>,
    <-1.6589648, 0.7698905, 34.0176539>,
    <-1.6439924, 0.7657427, 34.0159774>,
    <-1.6642299, 0.7425638, 34.0166837>,
    <-1.6142752, 0.8589215, 34.0169690>,
    <-1.6148275, 0.8396339, 34.0159774>,
    <-1.6580039, 0.7410472, 34.0160951>,
    <-1.6398547, 0.7918057, 34.0164483>,
    <-1.6996973, 0.6474388, 34.0160069>,
    <-1.6731572, 0.6918514, 34.0159774>,
    <-1.6979608, 0.6373724, 34.0159774>,
    <-1.6836234, 0.6866537, 34.0160951>,
    <-1.6787014, 0.6879646, 34.0159774>,
    <-1.7204168, 0.6245426, 34.0159774>,
    <-1.7100432, 0.6399045, 34.0160951>,
    <-1.6998918, 0.6758133, 34.0168971>,
    <-1.6873011, 0.6904944, 34.0164483>,
    <-1.6986050, -0.6575077, 34.0159774>,
    <-1.6971541, -0.6766097, 34.0159774>,
    <-1.7204109, -0.6267358, 34.0159774>,
    <-1.7103542, -0.6230274, 34.0159774>,
    <-1.6980089, -0.6659434, 34.0159774>,
    <-1.7087412, -0.6517614, 34.0159774>,
    <-1.7146371, -0.6246310, 34.0159774>,
    <-1.7036494, -0.6424844, 34.0159774>,
    <-1.7064597, -0.6460506, 34.0159774>,
    <-1.7053327, -0.6210694, 34.0159774>,
    <-1.6941841, -0.6640363, 34.0159774>,
    <-1.6997814, -0.6432072, 34.0159774>,
    <-1.6857324, -0.7011035, 34.0159774>,
    <-1.6896840, -0.6830290, 34.0159774>,
    <-1.7170048, 0.6009379, 34.0159774>,
    <-1.7211970, 0.5724392, 34.0159774>,
    <-1.7343872, 0.5430497, 34.0159774>,
    <-1.7267354, 0.5876844, 34.0159774>,
    <-1.7185884, 0.5895452, 34.0159774>,
    <-1.7280222, 0.5571092, 34.0159774>,
    <-1.7303113, 0.5668251, 34.0159774>,
    <-1.7215363, 0.5946884, 34.0159774>,
    <-1.7249659, 0.5763972, 34.0159774>,
    <-1.7234928, 0.6065995, 34.0159774>,
    <-1.7109453, 0.6182561, 34.0159774>,
    <-1.7161240, 0.6152758, 34.0159774>,
    <-1.7111472, 0.5958660, 34.0159774>,
    <-1.7101468, 0.6098447, 34.0159774>,
    <-1.7237138, -0.5887543, 34.0159774>,
    <-1.7346576, -0.5735702, 34.0159774>,
    <-1.7484982, -0.5219191, 34.0159774>,
    <-1.7280706, -0.5654348, 34.0159774>,
    <-1.7285399, -0.5821476, 34.0159774>,
    <-1.7416541, -0.5474607, 34.0159774>,
    <-1.7382508, -0.5438410, 34.0159774>,
    <-1.7248036, -0.5804327, 34.0159774>,
    <-1.7333976, -0.5632754, 34.0159774>,
    <-1.7131600, -0.5966742, 34.0159774>,
    <-1.7177810, -0.6037455, 34.0159774>,
    <-1.7155342, -0.6002750, 34.0159774>,
    <-1.7275596, -0.6000583, 34.0159774>,
    <-1.7221418, -0.6029647, 34.0159774>,
    <-1.7308202, 0.5276478, 34.0159774>,
    <-1.7290062, 0.5183733, 34.0159774>,
    <-1.7556903, 0.4187864, 34.0159774>,
    <-1.7443722, 0.4848062, 34.0159774>,
    <-1.7299047, 0.5240820, 34.0159774>,
    <-1.7423482, 0.4685798, 34.0159774>,
    <-1.7499479, 0.4522823, 34.0159774>,
    <-1.7366378, 0.5093357, 34.0159774>,
    <-1.7397866, 0.4881942, 34.0159774>,
    <-1.7391297, 0.5153860, 34.0159774>,
    <-1.7259738, 0.5492016, 34.0159774>,
    <-1.7323146, 0.5335313, 34.0159774>,
    <-1.7156641, 0.5681668, 34.0159774>,
    <-1.7205818, 0.5599217, 34.0159774>,
    <-1.7424411, -0.5199572, 34.0159774>,
    <-1.7616788, -0.4727296, 34.0159774>,
    <-1.7351934, -0.5420682, 34.0159774>,
    <-1.7551393, -0.4971349, 34.0159774>,
    <-1.7507546, -0.4996535, 34.0159774>,
    <-1.7446353, -0.5213373, 34.0159774>,
    <-1.7748586, -0.4235416, 34.0159774>,
    <-1.7410927, -0.5119536, 34.0159774>,
    <-1.7682181, -0.4483246, 34.0159774>,
    <-1.7624166, -0.4553250, 34.0159774>,
    <-1.7413751, -0.5181500, 34.0159774>,
    <-1.7548123, -0.4826787, 34.0159774>,
    <-1.7172439, -0.5777426, 34.0159774>,
    <-1.7278755, -0.5558558, 34.0159774>,
    <-1.7438388, -0.4892892, 34.0159774>,
    <-1.7606075, -0.4346553, 34.0159774>,
    <-1.7423455, -0.5003522, 34.0159774>,
    <-1.7681051, -0.4299955, 34.0159774>,
    <-1.7518233, -0.4644285, 34.0159774>,
    <-1.7552502, -0.4649257, 34.0159774>,
    <-1.7517709, -0.4355926, 34.0159774>,
    <-1.7286124, -0.5220194, 34.0159774>,
    <-1.7560526, -0.4355797, 34.0159774>,
    <-1.7407795, -0.4766121, 34.0159774>,
    <-1.7372340, -0.5035114, 34.0159774>,
    <-1.7467204, -0.4692025, 34.0159774>,
    <-1.7156614, -0.5703519, 34.0159774>,
    <-1.7290909, -0.5354374, 34.0159774>,
    <-1.7497251, 0.4912296, 34.0159774>,
    <-1.7380535, 0.5216645, 34.0159774>,
    <-1.7623824, 0.4334198, 34.0159774>,
    <-1.7447320, 0.5039776, 34.0159774>,
    <-1.7468719, 0.4702255, 34.0159774>,
    <-1.7588385, 0.4296182, 34.0159774>,
    <-1.7556951, 0.4645102, 34.0159774>,
    <-1.7517197, 0.4656435, 34.0159774>,
    <-1.7703920, 0.4380316, 34.0159774>,
    <-1.7469884, 0.5253759, 34.0159774>,
    <-1.7668701, 0.4359092, 34.0159774>,
    <-1.7592842, 0.4794870, 34.0159774>,
    <-1.7486163, 0.5056937, 34.0159774>,
    <-1.7579258, 0.4702743, 34.0159774>,
    <-1.7339006, 0.5742204, 34.0159774>,
    <-1.7292352, 0.5731036, 34.0159774>,
    <-1.7390019, 0.5397415, 34.0159774>,
    <-1.7706109, 0.3880114, 34.0159774>,
    <-1.7778298, 0.3709663, 34.0159774>,
    <-1.7737593, 0.3804762, 34.0159774>,
    <-1.7748819, 0.4045035, 34.0159774>,
    <-1.7676431, 0.4058102, 34.0159774>,
    <-1.7712877, 0.4041176, 34.0159774>,
    <-1.7681174, 0.3724056, 34.0159774>,
    <-1.7627628, 0.3923902, 34.0159774>,
    <-1.7697256, 0.3803776, 34.0159774>,
    <-1.7649621, 0.4007807, 34.0159774>,
    <-1.7668009, 0.3773177, 34.0159774>,
    <-1.7700360, 0.3652442, 34.0159774>,
    <-1.7742682, 0.3600796, 34.0159774>,
    <-1.7727643, 0.3696551, 34.0159774>,
    <-1.7706342, -0.3894465, 34.0159774>,
    <-1.7694425, -0.3696422, 34.0159774>,
    <-1.7702492, -0.3803582, 34.0159774>,
    <-1.7611946, -0.4004235, 34.0159774>,
    <-1.7669753, -0.4079404, 34.0159774>,
    <-1.7637330, -0.4057120, 34.0159774>,
    <-1.7791527, -0.3703150, 34.0159774>,
    <-1.7762167, -0.4040103, 34.0159774>,
    <-1.7745645, -0.3804655, 34.0159774>,
    <-1.7716257, -0.4040483, 34.0159774>,
    <-1.7839786, -0.3153927, 34.0159774>,
    <-1.7820404, -0.3365104, 34.0159774>,
    <-1.7769065, -0.3417861, 34.0159774>,
    <-1.7760890, -0.3602772, 34.0159774>,
    <-1.7862931, 0.3490055, 34.0159774>,
    <-1.7865153, 0.3778564, 34.0159774>,
    <-1.7867277, 0.3613016, 34.0159774>,
    <-1.7799157, 0.4024874, 34.0159774>,
    <-1.7827381, 0.3589189, 34.0159774>,
    <-1.7816419, 0.3797565, 34.0159774>,
    <-1.7907505, 0.3029127, 34.0160180>,
    <-1.7791966, 0.3357146, 34.0161399>,
    <-1.7881301, 0.3315858, 34.0159774>,
    <-1.7825744, 0.3418676, 34.0159774>,
    <-1.7855810, 0.3813422, 34.0159774>,
    <-1.7912549, 0.3359763, 34.0159774>,
    <-1.7888505, 0.3691407, 34.0159774>,
    <-1.7895294, 0.3445514, 34.0159774>,
    <-1.7868288, -0.3530724, 34.0159774>,
    <-1.7886972, -0.3718952, 34.0159774>,
    <-1.8029412, -0.3187358, 34.0159774>,
    <-1.7925509, -0.3166437, 34.0159774>,
    <-1.7876943, -0.3613328, 34.0159774>,
    <-1.7957939, -0.3454101, 34.0159774>,
    <-1.7969796, -0.3176843, 34.0159774>,
    <-1.7892511, -0.3372636, 34.0159774>,
    <-1.7926156, -0.3401939, 34.0159774>,
    <-1.7874381, -0.3149634, 34.0159774>,
    <-1.7835579, -0.3605576, 34.0159774>,
    <-1.7855140, -0.3389051, 34.0159774>,
    <-1.7817019, -0.3980021, 34.0159774>,
    <-1.7824243, -0.3798659, 34.0159774>,
    <-1.7987558, 0.2382906, 34.0164520>,
    <-1.8053091, 0.2045987, 34.0161867>,
    <-1.8015866, 0.2222320, 34.0162327>,
    <-1.7963165, 0.3015444, 34.0160951>,
    <-1.7950620, 0.2634589, 34.0161399>,
    <-1.7968110, 0.2732339, 34.0159774>,
    <-1.8002636, 0.2404731, 34.0184835>,
    <-1.7827223, 0.3219989, 34.0171912>,
    <-1.7985836, 0.2343194, 34.0170451>,
    <-1.7906452, 0.2821262, 34.0166273>,
    <-1.8150542, 0.0292771, 34.0180289>,
    <-1.8086076, 0.1573659, 34.0185926>,
    <-1.8096531, 0.1299593, 34.0166970>,
    <-1.8046699, 0.1800654, 34.0169987>,
    <-1.7999323, -0.2778683, 34.0159774>,
    <-1.8078886, -0.2621890, 34.0159774>,
    <-1.8139028, -0.1934483, 34.0159774>,
    <-1.8012769, -0.2422630, 34.0159774>,
    <-1.8033912, -0.2716163, 34.0159774>,
    <-1.8106957, -0.2301050, 34.0159774>,
    <-1.8076544, -0.2174520, 34.0159774>,
    <-1.7999036, -0.2658535, 34.0159774>,
    <-1.8054022, -0.2467728, 34.0159774>,
    <-1.7917405, -0.2809657, 34.0159774>,
    <-1.7965466, -0.2956269, 34.0159774>,
    <-1.7939950, -0.2897604, 34.0159774>,
    <-1.8053483, -0.2912246, 34.0159774>,
    <-1.8005776, -0.2950393, 34.0159774>,
    <-1.8057800, -0.9335690, 34.2957497>,
    <-1.8165566, -0.8959461, 34.2979383>,
    <-1.8736418, -0.8142155, 34.2918017>,
    <-1.8323513, -0.9027644, 34.2918021>,
    <-1.8089237, -0.9203218, 34.2967308>,
    <-1.8511306, -0.8444979, 34.2945155>,
    <-1.8536110, -0.8571724, 34.2918020>,
    <-1.8169471, -0.9211097, 34.2940172>,
    <-1.8314821, -0.8876343, 34.2943648>,
    <-1.8122855, -0.9457953, 34.2918022>,
    <-1.7916681, -0.9588487, 34.2965012>,
    <-1.8011474, -0.9539050, 34.2941812>,
    <-1.7745418, -0.9624176, 34.3015015>,
    <-1.7855065, -0.9574603, 34.2987032>,
    <-1.8057752, -0.1422293, 34.0164520>,
    <-1.8009416, -0.2013585, 34.0159774>,
    <-1.8150915, -0.1062360, 34.0159774>,
    <-1.8133906, -0.0689560, 34.0161573>,
    <-1.8034349, -0.1665341, 34.0161399>,
    <-1.8085440, -0.1502513, 34.0159774>,
    <-1.8140260, -0.0898028, 34.0159774>,
    <-1.8090237, -0.1056128, 34.0162327>,
    <-1.8087241, -0.1261187, 34.0159774>,
    <-1.8073181, -0.1615200, 34.0184964>,
    <-1.8136156, -0.0392822, 34.0166970>,
    <-1.8129445, -0.0813276, 34.0185926>,
    <-1.8048658, -0.1544878, 34.0170451>,
    <-1.8095622, -0.0923605, 34.0169987>,
    <-1.7953972, -0.2513969, 34.0173461>,
    <-1.7926359, -0.2571936, 34.0159774>,
    <-1.7990346, -0.2079956, 34.0166273>,
    <-1.8184714, 0.8609120, 34.3035582>,
    <-1.7794377, 0.9462262, 34.3035582>,
    <-1.8110171, 0.8833259, 34.3035582>,
    <-1.8537779, 0.7868048, 34.3035582>,
    <-1.8013941, 0.8982370, 34.3035582>,
    <-1.7952274, 0.9147761, 34.3035582>,
    <-1.8323975, 0.8350654, 34.3035582>,
    <-1.8339180, 0.8284901, 34.3035582>,
    <-1.8156760, 0.8693172, 34.3035582>,
    <-1.8965387, 0.6902837, 34.3035582>,
    <-1.8221985, 0.8497051, 34.3035582>,
    <-1.8751583, 0.7385442, 34.3035582>,
    <-1.8593686, 0.7699944, 34.3035582>,
    <-1.8201020, 0.8560090, 34.3035582>,
    <-1.8477466, 0.7969264, 34.3035582>,
    <-1.7850284, 0.9294158, 34.3035582>,
    <-1.7636480, 0.9776763, 34.3035582>,
    <-1.7919915, 0.9164924, 34.3035582>,
    <-1.8157079, 0.1237651, 34.0163326>,
    <-1.8210124, 0.1659036, 34.0176445>,
    <-1.8172930, 0.1388044, 34.0166837>,
    <-1.8017066, 0.2977212, 34.0168568>,
    <-1.8107225, 0.1601757, 34.0161880>,
    <-1.8081584, 0.2152435, 34.0164483>,
    <-1.8211752, 0.0291471, 34.0161461>,
    <-1.8171195, 0.0322989, 34.0165345>,
    <-1.8186454, 0.0753163, 34.0161880>,
    <-1.8142819, 0.0945960, 34.0163488>,
    <-1.8307319, -0.0010941, 34.0159774>,
    <-1.8268077, 0.0165538, 34.0160951>,
    <-1.8290605, 0.0550896, 34.0168971>,
    <-1.8228324, 0.0734606, 34.0164483>,
    <-1.8201698, -0.0281562, 34.0160187>,
    <-1.8243183, -0.0442092, 34.0159774>,
    <-1.8173437, -0.0431917, 34.0160703>,
    <-1.8202323, -0.0716766, 34.0159774>,
    <-1.8219823, -0.0353602, 34.0159774>,
    <-1.8184644, -0.0606398, 34.0159774>,
    <-1.8277009, -0.0214696, 34.0159774>,
    <-1.8211823, -0.0058635, 34.0160703>,
    <-1.8245227, -0.0106944, 34.0159774>,
    <-1.8175178, -0.0129213, 34.0163488>,
    <-1.8094752, -0.1720370, 34.0159774>,
    <-1.8217840, -0.1033681, 34.0159774>,
    <-1.8052191, -0.2063142, 34.0159774>,
    <-1.8176434, -0.1506946, 34.0159774>,
    <-1.8147859, -0.1425928, 34.0159774>,
    <-1.8111919, -0.1805974, 34.0159774>,
    <-1.8073553, -0.1582434, 34.0159774>,
    <-1.8261913, -0.0529932, 34.0159774>,
    <-1.8190436, -0.0796687, 34.0159774>,
    <-1.8084650, -0.1666960, 34.0159774>,
    <-1.8172078, -0.1098222, 34.0159774>,
    <-1.7956670, -0.2368180, 34.0159774>,
    <-1.8002037, -0.2236591, 34.0159774>,
    <-1.8166045, 0.9116124, 34.2956978>,
    <-1.8459676, 0.8735619, 34.2917991>,
    <-1.8990584, 0.7597100, 34.2917983>,
    <-1.8306041, 0.8680070, 34.2978476>,
    <-1.8291441, 0.8956184, 34.2939960>,
    <-1.8757995, 0.8095882, 34.2917986>,
    <-1.8723123, 0.8000922, 34.2944660>,
    <-1.8218497, 0.8942871, 34.2966633>,
    <-1.8491597, 0.8506431, 34.2943247>,
    <-1.7817350, 0.9506565, 34.3013237>,
    <-1.7980892, 0.9464980, 34.2964340>,
    <-1.7931993, 0.9431094, 34.2986271>,
    <-1.8117537, 0.9469327, 34.2917996>,
    <-1.8045330, 0.9473496, 34.2941416>,
    <-1.8508613, 0.8125358, 34.2997396>,
    <-1.8900801, 0.7401955, 34.2978474>,
    <-1.8422703, 0.8362135, 34.2989139>,
    <-1.8945057, 0.7524989, 34.2944658>,
    <-1.8702804, 0.7761464, 34.2989138>,
    <-1.8697718, 0.7903671, 34.2968504>,
    <-1.8221985, 0.8497051, 34.3035582>,
    <-1.8908348, 0.7156285, 34.3013235>,
    <-1.8593686, 0.7699944, 34.3035582>,
    <-1.8393027, 0.8268138, 34.3013912>,
    <-1.8660174, 0.7708415, 34.3011842>,
    <-1.7850284, 0.9294158, 34.3035582>,
    <-1.8138733, 0.8826637, 34.3011843>,
    <-1.9129741, 0.7021088, 34.2956970>,
    <-1.9214752, 0.7116377, 34.2917979>,
    <-1.9263640, 0.7011537, 34.2917977>,
    <-1.9229496, 0.6595077, 34.2968945>,
    <-1.9170483, 0.7060445, 34.2939951>,
    <-1.9250151, 0.7040464, 34.2917978>,
    <-1.9282311, 0.6670168, 34.2943318>,
    <-1.9164144, 0.6863599, 34.2964332>,
    <-1.9219180, 0.6913587, 34.2941404>,
    <-1.9091646, 0.6711608, 34.3006305>,
    <-1.9047293, 0.7154880, 34.2966628>,
    <-1.9060978, 0.6967394, 34.2986266>,
    <-1.9135533, 0.7286261, 34.2917980>,
    <-1.9079852, 0.7244929, 34.2943241>,
    <-1.8984536, -0.7347210, 34.2957487>,
    <-1.9036603, -0.7498377, 34.2918006>,
    <-1.8762576, -0.7679084, 34.2979379>,
    <-1.9013178, -0.7401336, 34.2940160>,
    <-1.8900205, -0.7790899, 34.2918012>,
    <-1.8732659, -0.7970286, 34.2945153>,
    <-1.8905684, -0.7451945, 34.2967300>,
    <-1.8894781, -0.7632610, 34.2943640>,
    <-1.8952907, -0.6898409, 34.3035582>,
    <-1.9079143, -0.7056254, 34.2969724>,
    <-1.8851161, -0.7252552, 34.3015013>,
    <-1.8993906, -0.6982702, 34.3007901>,
    <-1.9031701, -0.7194876, 34.2965000>,
    <-1.8949245, -0.7226524, 34.2987025>,
    <-1.9263748, -0.7011224, 34.2917990>,
    <-1.9155406, -0.7066761, 34.2943888>,
    <-1.9154741, -0.7245011, 34.2917998>,
    <-1.9097408, -0.7208601, 34.2941794>,
    <-1.8282088, -0.8388908, 34.3035582>,
    <-1.7946678, -0.9134158, 34.3035582>,
    <-1.8209982, -0.8491572, 34.3035582>,
    <-1.8135346, -0.8714955, 34.3035582>,
    <-1.7706868, -0.9609446, 34.3035582>,
    <-1.7838520, -0.9288153, 34.3035582>,
    <-1.8250542, -0.8433824, 34.3035582>,
    <-1.7976451, -0.9024843, 34.3035582>,
    <-1.8689603, -0.7540995, 34.3035582>,
    <-1.8581445, -0.7694991, 34.3035582>,
    <-1.8821255, -0.7219702, 34.3035582>,
    <-1.8460376, -0.8017946, 34.3035582>,
    <-1.8533645, -0.7829971, 34.3035582>,
    <-1.8426298, -0.8183581, 34.3035582>,
    <-1.8557951, -0.7862288, 34.3035582>,
    <-1.8186488, -0.8658869, 34.3035582>,
    <-1.8336167, -0.8311911, 34.3035582>,
    <-1.8393738, -0.8347314, 34.2997908>,
    <-1.8571842, -0.8019078, 34.2989808>,
    <-1.8288069, -0.8627621, 34.2989809>,
    <-1.8521877, -0.8262382, 34.2969274>,
    <-1.8209982, -0.8491572, 34.3035582>,
    <-1.7838520, -0.9288153, 34.3035582>,
    <-1.8318260, -0.8401769, 34.3014107>,
    <-1.8061488, -0.8964882, 34.3012225>,
    <-1.8581445, -0.7694991, 34.3035582>,
    <-1.8585676, -0.7840782, 34.3012224>,
    <-1.9179701, -0.6896304, 34.2956250>,
    <-1.9289458, -0.6915272, 34.2917986>,
    <-1.9225916, -0.6912138, 34.2939684>,
    <-1.9271979, -0.6980504, 34.2917988>,
    <-1.9132666, -0.6964167, 34.2964533>,
    <-1.9195107, -0.6988178, 34.2941785>,
    <-1.9221179, -0.6609014, 34.2969721>,
    <-1.9075214, -0.6737190, 34.3007900>,
    <-1.9183604, -0.6801103, 34.2964532>,
    <-1.9099089, -0.6876787, 34.2985181>,
    <-1.9389150, -0.6543217, 34.2917986>,
    <-1.9307283, -0.6568442, 34.2943883>,
    <-1.9325433, -0.6781014, 34.2917985>,
    <-1.9257238, -0.6777930, 34.2941783>,
    <-1.9391716, 0.5312792, 34.3035582>,
    <-1.9149620, 0.6216830, 34.3035582>,
    <-1.9333853, 0.5530822, 34.3035582>,
    <-1.9604880, 0.4517770, 34.3035582>,
    <-1.9285799, 0.5708308, 34.3035582>,
    <-1.9241736, 0.5873826, 34.3035582>,
    <-1.9469366, 0.5024296, 34.3035582>,
    <-1.9484975, 0.4964970, 34.3035582>,
    <-1.9370017, 0.5394553, 34.3035582>,
    <-1.9875908, 0.3504717, 34.3035582>,
    <-1.9420647, 0.5203777, 34.3035582>,
    <-1.9740394, 0.4011243, 34.3035582>,
    <-1.9648278, 0.4354247, 34.3035582>,
    <-1.9404373, 0.5265098, 34.3035582>,
    <-1.9573288, 0.4634764, 34.3035582>,
    <-1.9193017, 0.6053307, 34.3035582>,
    <-1.9057503, 0.6559833, 34.3035582>,
    <-1.9231843, 0.5909059, 34.3035582>,
    <-1.9405240, -0.6058398, 34.2957480>,
    <-1.9449137, -0.5669932, 34.2979350>,
    <-1.9865558, -0.4765242, 34.2918007>,
    <-1.9612720, -0.5708843, 34.2917995>,
    <-1.9414043, -0.5922639, 34.2967294>,
    <-1.9699034, -0.5103746, 34.2945050>,
    <-1.9742899, -0.5223010, 34.2918001>,
    <-1.9493143, -0.5916265, 34.2940151>,
    <-1.9578908, -0.5561536, 34.2943631>,
    <-1.9489858, -0.6167370, 34.2917990>,
    <-1.9309753, -0.6331739, 34.2964994>,
    <-1.9394260, -0.6266560, 34.2941787>,
    <-1.9149451, -0.6396964, 34.3015011>,
    <-1.9247430, -0.6328892, 34.2987021>,
    <-1.9473084, 0.5823045, 34.2956983>,
    <-1.9696190, 0.5397282, 34.2917999>,
    <-2.0021365, 0.4183745, 34.2918015>,
    <-1.9535244, 0.5369275, 34.2978488>,
    <-1.9568807, 0.5643735, 34.2939967>,
    <-1.9878910, 0.4715379, 34.2918008>,
    <-1.9828077, 0.4627933, 34.2944683>,
    <-1.9494661, 0.5643295, 34.2966642>,
    <-1.9687838, 0.5166005, 34.2943262>,
    <-1.9197480, 0.6268159, 34.3013240>,
    <-1.9351309, 0.6198800, 34.2964340>,
    <-1.9297275, 0.6173911, 34.2986274>,
    <-1.9486626, 0.6179365, 34.2917988>,
    <-1.9416242, 0.6196003, 34.2941412>,
    <-1.9638406, 0.4787843, 34.2997408>,
    <-1.9899021, 0.4007299, 34.2978493>,
    <-1.9594924, 0.5035918, 34.2989152>,
    <-1.9963995, 0.4120687, 34.2944686>,
    <-1.9766460, 0.4395737, 34.2989154>,
    <-1.9786159, 0.4536614, 34.2968524>,
    <-1.9420647, 0.5203777, 34.3035582>,
    <-1.9863764, 0.3764158, 34.3013243>,
    <-1.9648278, 0.4354247, 34.3035582>,
    <-1.9549359, 0.4948569, 34.3013919>,
    <-1.9715247, 0.4350965, 34.3011851>,
    <-1.9193017, 0.6053307, 34.3035582>,
    <-1.9395914, 0.5542734, 34.3011849>,
    <-2.0058346, 0.3592462, 34.2956998>,
    <-2.0158633, 0.3671465, 34.2918021>,
    <-2.0188526, 0.3559903, 34.2918022>,
    <-2.0082559, 0.3155690, 34.2968965>,
    <-2.0105312, 0.3624112, 34.2939985>,
    <-2.0180291, 0.3590639, 34.2918022>,
    <-2.0147641, 0.3220458, 34.2943349>,
    <-2.0064867, 0.3431435, 34.2964357>,
    <-2.0127753, 0.3471086, 34.2941437>,
    <-1.9966951, 0.3294426, 34.3006313>,
    <-2.0000384, 0.3738536, 34.2966652>,
    <-1.9981286, 0.3551587, 34.2986283>,
    <-2.0110132, 0.3852470, 34.2918019>,
    <-2.0048103, 0.3821499, 34.2943273>,
    <-1.9982839, -0.3943314, 34.2956994>,
    <-2.0030831, -0.3637113, 34.2968964>,
    <-2.0188513, -0.3559955, 34.2918022>,
    <-2.0049392, -0.4079161, 34.2918015>,
    <-2.0006096, -0.3784250, 34.2964354>,
    <-2.0100055, -0.3634839, 34.2943347>,
    <-2.0121747, -0.3809128, 34.2918019>,
    <-2.0015630, -0.3989486, 34.2939980>,
    <-2.0066508, -0.3784447, 34.2941434>,
    <-1.9824432, -0.4314328, 34.2978512>,
    <-1.9965859, -0.4390912, 34.2918011>,
    <-1.9837094, -0.4600781, 34.2944773>,
    <-1.9924929, -0.4063161, 34.2966648>,
    <-1.9939219, -0.4240290, 34.2943267>,
    <-1.9895465, -0.3508107, 34.3035582>,
    <-1.9847095, -0.3895838, 34.3013242>,
    <-1.9945944, -0.3578733, 34.3006312>,
    <-1.9935338, -0.3833018, 34.2986281>,
    <-1.9471948, -0.5088653, 34.3035582>,
    <-1.9260189, -0.5878926, 34.3035582>,
    <-1.9424186, -0.5203258, 34.3035582>,
    <-1.9379303, -0.5434398, 34.3035582>,
    <-1.9106548, -0.6388668, 34.3035582>,
    <-1.9188547, -0.6050834, 34.3035582>,
    <-1.9451052, -0.5138793, 34.3035582>,
    <-1.9277308, -0.5767312, 34.3035582>,
    <-1.9731468, -0.4183775, 34.3035582>,
    <-1.9659826, -0.4355683, 34.3035582>,
    <-1.9813467, -0.3845941, 34.3035582>,
    <-1.9585488, -0.4692769, 34.3035582>,
    <-1.9630767, -0.4495949, 34.3035582>,
    <-1.9567470, -0.4859444, 34.3035582>,
    <-1.9649469, -0.4521610, 34.3035582>,
    <-1.9413829, -0.5369185, 34.3035582>,
    <-1.9507769, -0.5002700, 34.3035582>,
    <-1.9574899, -0.5030721, 34.2997655>,
    <-1.9694726, -0.4679592, 34.2989243>,
    <-1.9515860, -0.5323119, 34.2989710>,
    <-1.9682379, -0.4925334, 34.2968893>,
    <-1.9424186, -0.5203258, 34.3035582>,
    <-1.9188547, -0.6050834, 34.3035582>,
    <-1.9512248, -0.5096405, 34.3014011>,
    <-1.9351631, -0.5693762, 34.3012222>,
    <-1.9659826, -0.4355683, 34.3035582>,
    <-1.9683235, -0.4500880, 34.3011849>,
    <-2.0096168, -0.3437148, 34.2956998>,
    <-2.0198607, -0.3444755, 34.2918022>,
    <-2.0140587, -0.3453395, 34.2939985>,
    <-2.0191301, -0.3528181, 34.2918022>,
    <-2.0065141, -0.3530243, 34.2964356>,
    <-2.0124469, -0.3550325, 34.2941437>,
    <-2.0077014, -0.3037110, 34.2978494>,
    <-1.9971434, -0.3241022, 34.3013243>,
    <-2.0084283, -0.3310589, 34.2966653>,
    <-2.0020817, -0.3425711, 34.2986283>,
    <-2.0244849, -0.2916334, 34.2918022>,
    <-2.0171274, -0.2956476, 34.2944689>,
    <-2.0214950, -0.3258023, 34.2918022>,
    <-2.0149243, -0.3266539, 34.2943274>,
    <-2.0188128, 0.2353119, 34.2956998>,
    <-2.0334191, 0.1895071, 34.2918022>,
    <-2.0443698, 0.0643495, 34.2918022>,
    <-2.0169289, 0.1895462, 34.2978494>,
    <-2.0251434, 0.2159908, 34.2939985>,
    <-2.0395724, 0.1191797, 34.2918022>,
    <-2.0329454, 0.1114515, 34.2944689>,
    <-2.0177817, 0.2172362, 34.2966653>,
    <-2.0285388, 0.1668770, 34.2943274>,
    <-1.9993252, 0.2839360, 34.3013243>,
    <-2.0133626, 0.2744305, 34.2964357>,
    <-2.0075776, 0.2729194, 34.2986283>,
    <-2.0263619, 0.2701658, 34.2918022>,
    <-2.0197193, 0.2730268, 34.2941437>,
    <-2.0166981, 0.1304942, 34.2997410>,
    <-2.0287294, 0.0490977, 34.2978494>,
    <-2.0168685, 0.1556805, 34.2989154>,
    <-2.0374267, 0.0591360, 34.2944689>,
    <-2.0224484, 0.0896547, 34.2989154>,
    <-2.0270493, 0.1031865, 34.2968527>,
    <-2.0169302, 0.0000039, 34.3035582>,
    <-2.0022605, 0.1752378, 34.3035582>,
    <-2.0205926, 0.0257650, 34.3013243>,
    <-2.0095954, 0.0876209, 34.3035582>,
    <-2.0106266, 0.1478694, 34.3013920>,
    <-2.0163870, 0.0861348, 34.3011851>,
    <-1.9949256, 0.2628547, 34.3035582>,
    <-2.0060552, 0.2090490, 34.3011851>,
    <-2.0373331, 0.0054749, 34.2956998>,
    <-2.0489928, 0.0115119, 34.2918022>,
    <-2.0500000, -0.0000000, 34.2918022>,
    <-2.0319825, -0.0379610, 34.2968965>,
    <-2.0426824, 0.0077755, 34.2939985>,
    <-2.0497224, 0.0031731, 34.2918022>,
    <-2.0397936, -0.0327141, 34.2943349>,
    <-2.0350791, -0.0104969, 34.2964357>,
    <-2.0422086, -0.0076860, 34.2941437>,
    <-2.0226203, -0.0222919, 34.3006313>,
    <-2.0340872, 0.0208680, 34.2966653>,
    <-2.0287184, 0.0027888, 34.2986283>,
    <-2.0473593, 0.0301822, 34.2918022>,
    <-2.0404698, 0.0282095, 34.2943274>,
    <-2.0286610, -0.1188426, 34.2956998>,
    <-2.0354351, -0.1664777, 34.2918022>,
    <-2.0190506, -0.1636387, 34.2978494>,
    <-2.0316723, -0.1389627, 34.2939985>,
    <-2.0292822, -0.2368035, 34.2918022>,
    <-2.0214668, -0.2433066, 34.2944689>,
    <-2.0245173, -0.1364787, 34.2966653>,
    <-2.0265577, -0.1879323, 34.2943274>,
    <-2.0175362, -0.0676033, 34.3013243>,
    <-2.0299440, -0.0793645, 34.2964357>,
    <-2.0238449, -0.0798602, 34.2986283>,
    <-2.0424916, -0.0858215, 34.2918022>,
    <-2.0361829, -0.0818482, 34.2941437>,
    <-2.0082337, -0.1624004, 34.3035582>,
    <-2.0038854, -0.2436026, 34.3035582>,
    <-2.0032384, -0.1754034, 34.3035582>,
    <-2.0063313, -0.1979264, 34.3035582>,
    <-1.9967160, -0.2972067, 34.3035582>,
    <-1.9963925, -0.2631071, 34.3035582>,
    <-2.0060482, -0.1680892, 34.3035582>,
    <-2.0012260, -0.2330543, 34.3035582>,
    <-2.0175772, -0.0681953, 34.3035582>,
    <-2.0100843, -0.0876997, 34.3035582>,
    <-2.0172537, -0.0340957, 34.3035582>,
    <-2.0123215, -0.1211857, 34.3035582>,
    <-2.0114949, -0.1014988, 34.3035582>,
    <-2.0182242, -0.1363945, 34.3035582>,
    <-2.0179007, -0.1022949, 34.3035582>,
    <-2.0110548, -0.1899985, 34.3035582>,
    <-2.0119801, -0.1526482, 34.3035582>,
    <-2.0093729, -0.2218807, 34.2997410>,
    <-2.0135059, -0.1970437, 34.2989154>,
    <-2.0082168, -0.2631212, 34.2989154>,
    <-2.0145873, -0.2505008, 34.2968527>,
    <-2.0032384, -0.1754034, 34.3035582>,
    <-1.9963925, -0.2631071, 34.3035582>,
    <-2.0065467, -0.2037555, 34.3013920>,
    <-2.0022129, -0.2656396, 34.3011851>,
    <-2.0100843, -0.0876997, 34.3035582>,
    <-2.0119210, -0.1426147, 34.3011851>,
    <2.0385482, 0.0601933, 34.2894060>,
    <2.0317323, 0.1141924, 34.2882268>,
    <2.0361633, 0.1581538, 34.2918022>,
    <2.0430178, 0.0798064, 34.2918022>,
    <2.0358688, 0.0818498, 34.2888889>,
    <2.0342507, 0.1422156, 34.2903408>,
    <2.0395666, 0.1192536, 34.2918022>,
    <2.0406743, 0.0673744, 34.2904043>,
    <2.0376438, 0.1039799, 34.2903620>,
    <2.0388169, -0.0031792, 34.2886392>,
    <2.0465009, 0.0399944, 34.2918022>,
    <2.0435631, -0.0035647, 34.2903193>,
    <2.0389115, 0.0317582, 34.2888888>,
    <2.0428518, 0.0322030, 34.2903619>,
    <2.0251450, 0.0152141, 34.2825385>,
    <2.0335590, 0.0006041, 34.2865643>,
    <2.0293072, 0.0766667, 34.2859512>,
    <2.0343891, 0.0460067, 34.2873502>,
    <2.0375162, -0.0728720, 34.2894050>,
    <2.0415255, -0.0968630, 34.2918006>,
    <2.0338467, -0.1846307, 34.2917990>,
    <2.0304182, -0.1272689, 34.2882253>,
    <2.0394357, -0.0820940, 34.2904030>,
    <2.0375369, -0.1424523, 34.2917998>,
    <2.0322792, -0.1647493, 34.2903384>,
    <2.0346302, -0.0951798, 34.2888876>,
    <2.0359724, -0.1230839, 34.2903601>,
    <2.0287977, -0.0747152, 34.2859504>,
    <2.0383206, -0.0404998, 34.2888882>,
    <2.0337325, -0.0502042, 34.2873495>,
    <2.0457130, -0.0490000, 34.2918014>,
    <2.0421952, -0.0419590, 34.2903612>,
    <2.0143605, 0.3381240, 34.2894175>,
    <2.0210804, 0.3305516, 34.2918015>,
    <2.0244042, 0.2925605, 34.2918020>,
    <2.0152813, 0.3124005, 34.2886792>,
    <2.0173144, 0.3349419, 34.2904038>,
    <2.0225359, 0.3139144, 34.2918018>,
    <2.0202479, 0.3017206, 34.2903194>,
    <2.0142892, 0.3289858, 34.2889152>,
    <2.0187613, 0.3198079, 34.2903616>,
    <1.9945492, 0.3619201, 34.2830970>,
    <2.0070408, 0.3683426, 34.2886789>,
    <2.0086942, 0.3261198, 34.2867238>,
    <2.0019403, 0.3686423, 34.2867237>,
    <2.0113404, 0.3501927, 34.2889150>,
    <2.0084221, 0.3447325, 34.2874563>,
    <2.0118525, 0.3660178, 34.2903188>,
    <2.0198999, 0.3440444, 34.2918012>,
    <2.0153478, 0.3488254, 34.2903613>,
    <2.0215886, 0.2621728, 34.2894178>,
    <2.0296697, 0.2323756, 34.2918022>,
    <2.0180700, 0.2882701, 34.2889154>,
    <2.0268226, 0.2649176, 34.2918021>,
    <2.0248541, 0.2512628, 34.2904043>,
    <2.0223335, 0.2789772, 34.2903619>,
    <2.0225276, 0.2200452, 34.2882666>,
    <2.0328238, 0.1963244, 34.2918022>,
    <2.0308474, 0.1811154, 34.2903408>,
    <2.0217093, 0.2466732, 34.2889155>,
    <2.0276454, 0.2182624, 34.2903620>,
    <2.0124589, 0.2718102, 34.2861105>,
    <2.0142577, 0.2880295, 34.2874565>,
    <2.0228196, 0.1736616, 34.2863463>,
    <2.0227667, 0.1939671, 34.2872643>,
    <2.0269371, 0.1463812, 34.2872378>,
    <2.0290409, 0.1650613, 34.2889218>,
    <2.0121443, 0.1960439, 34.2816852>,
    <2.0184136, 0.1214762, 34.2818098>,
    <2.0183817, 0.1813116, 34.2844824>,
    <2.0236883, 0.1254566, 34.2848968>,
    <2.0050698, 0.2680750, 34.2819691>,
    <2.0142360, 0.2331669, 34.2850030>,
    <2.0224164, -0.1781253, 34.2863450>,
    <2.0213734, -0.2348331, 34.2882644>,
    <2.0259038, -0.1568021, 34.2872364>,
    <2.0288035, -0.2044764, 34.2903380>,
    <2.0218790, -0.2051765, 34.2872627>,
    <2.0273395, -0.1845076, 34.2889197>,
    <1.9986500, -0.3388765, 34.2830965>,
    <2.0156067, -0.1559804, 34.2816848>,
    <2.0129361, -0.2727391, 34.2861091>,
    <2.0093234, -0.2312656, 34.2819686>,
    <2.0192429, -0.1711418, 34.2844816>,
    <2.0151330, -0.2271704, 34.2850020>,
    <2.0206337, -0.0823353, 34.2818094>,
    <2.0238828, -0.1176755, 34.2848961>,
    <2.0202485, -0.2779616, 34.2894147>,
    <2.0276788, -0.2551299, 34.2917976>,
    <2.0204120, -0.2625642, 34.2889128>,
    <2.0305545, -0.2222616, 34.2917982>,
    <2.0231918, -0.2702614, 34.2904005>,
    <2.0257443, -0.2399909, 34.2903586>,
    <2.0232528, -0.3057196, 34.2917974>,
    <2.0147833, -0.3195478, 34.2886767>,
    <2.0252387, -0.2830208, 34.2917973>,
    <2.0192841, -0.3127359, 34.2903158>,
    <2.0171529, -0.2998162, 34.2889125>,
    <2.0210107, -0.2940961, 34.2903580>,
    <2.0092181, -0.3259509, 34.2867222>,
    <2.0140354, -0.2948258, 34.2874544>,
    <2.0138576, -0.3428442, 34.2894157>,
    <2.0205820, -0.3362479, 34.2917992>,
    <2.0138899, -0.3340501, 34.2889131>,
    <2.0217400, -0.3230114, 34.2917981>,
    <2.0168178, -0.3400555, 34.2904018>,
    <2.0180951, -0.3274216, 34.2903587>,
    <2.0061021, -0.3722237, 34.2886783>,
    <2.0196605, -0.3467809, 34.2918006>,
    <2.0108317, -0.3705565, 34.2903187>,
    <2.0108431, -0.3535632, 34.2889139>,
    <2.0148259, -0.3525399, 34.2903604>,
    <2.0020008, -0.3672037, 34.2867229>,
    <2.0085639, -0.3451151, 34.2874549>,
    <2.0091936, -0.1137577, 34.2751756>,
    <1.9995243, -0.1745708, 34.2713544>,
    <2.0122979, -0.1346539, 34.2782754>,
    <1.9995465, -0.2480329, 34.2765461>,
    <2.0053265, -0.1412904, 34.2735942>,
    <2.0066724, -0.1982384, 34.2779935>,
    <1.9924800, -0.0006800, 34.2582471>,
    <2.0076623, 0.0006696, 34.2713146>,
    <1.9976891, -0.0989534, 34.2658251>,
    <2.0007505, -0.0007292, 34.2658251>,
    <2.0094659, -0.0644732, 34.2735676>,
    <2.0034321, -0.0736234, 34.2692880>,
    <2.0148912, 0.0048936, 34.2763869>,
    <2.0155140, -0.0659892, 34.2778874>,
    <2.0007323, -0.0685961, 34.2989756>,
    <1.9937338, -0.1205183, 34.2975521>,
    <1.9957500, -0.1959959, 34.3035582>,
    <2.0066268, -0.1017946, 34.3035582>,
    <1.9974273, -0.0891764, 34.2980080>,
    <1.9950967, -0.1591700, 34.3007100>,
    <2.0006761, -0.1503190, 34.3035582>,
    <2.0033736, -0.0830412, 34.3008727>,
    <1.9991001, -0.1224926, 34.3007914>,
    <2.0002373, 0.0143167, 34.2967794>,
    <2.0132605, -0.0513719, 34.3035582>,
    <2.0104257, 0.0073417, 34.3007507>,
    <2.0013251, -0.0335751, 34.2980080>,
    <2.0072521, -0.0384326, 34.3007914>,
    <1.9839767, -0.0119740, 34.2867877>,
    <1.9926886, 0.0098003, 34.2926777>,
    <1.9909516, -0.0782151, 34.2937748>,
    <1.9955609, -0.0448809, 34.2951914>,
    <1.9894174, -0.1997372, 34.2989756>,
    <1.9846658, -0.2240080, 34.2967794>,
    <1.9896544, -0.2769088, 34.3035582>,
    <1.9875351, -0.2082516, 34.2980080>,
    <1.9849460, -0.3001802, 34.3007507>,
    <1.9878020, -0.3140432, 34.3035582>,
    <1.9895836, -0.2307209, 34.3008727>,
    <1.9874510, -0.2643300, 34.3007914>,
    <1.9921899, -0.2378761, 34.3035582>,
    <1.9910627, -0.1602436, 34.2980080>,
    <1.9920283, -0.1954568, 34.3007914>,
    <1.9848769, -0.1388463, 34.2926777>,
    <1.9884891, -0.1394426, 34.2951914>,
    <1.9969153, 0.4162542, 34.2894175>,
    <1.9812123, 0.4652153, 34.2882664>,
    <1.9777664, 0.5093250, 34.2918020>,
    <1.9981221, 0.4333531, 34.2918015>,
    <1.9907592, 0.4350620, 34.2889152>,
    <1.9786506, 0.4932969, 34.2903406>,
    <1.9878732, 0.4716046, 34.2918018>,
    <1.9978716, 0.4218631, 34.2904038>,
    <1.9886319, 0.4562296, 34.2903616>,
    <2.0084659, 0.3947475, 34.2918012>,
    <2.0019474, 0.3920511, 34.2889150>,
    <2.0058195, 0.3910780, 34.2903613>,
    <1.9858672, 0.4276977, 34.2861104>,
    <1.9956240, 0.4023092, 34.2874563>,
    <1.9984408, 0.2368080, 34.2751756>,
    <1.9993190, 0.1754451, 34.2713146>,
    <2.0051483, 0.2166991, 34.2782756>,
    <2.0116716, 0.1035530, 34.2763869>,
    <1.9993013, 0.2091774, 34.2735677>,
    <2.0102319, 0.1536284, 34.2778875>,
    <1.9623278, 0.3453208, 34.2582471>,
    <1.9772462, 0.3489496, 34.2713545>,
    <1.9845228, 0.2494450, 34.2658251>,
    <1.9704813, 0.3467085, 34.2658251>,
    <1.9902673, 0.2852219, 34.2735942>,
    <1.9857800, 0.2753875, 34.2692880>,
    <1.9842347, 0.3533543, 34.2765463>,
    <1.9968887, 0.2841055, 34.2779937>,
    <1.9987528, 0.1159159, 34.2672229>,
    <1.9993852, 0.1418673, 34.2690713>,
    <2.0036472, 0.0655281, 34.2690713>,
    <2.0090001, 0.0751326, 34.2733316>,
    <1.9839423, 0.1728608, 34.2582019>,
    <1.9892105, 0.0969918, 34.2582019>,
    <1.9925700, 0.1407328, 34.2634197>,
    <1.9970431, 0.0719000, 34.2639559>,
    <1.9760030, 0.2484982, 34.2582019>,
    <1.9875913, 0.2022373, 34.2639559>,
    <1.9786947, -0.1158931, 34.2481381>,
    <1.9838188, -0.1742733, 34.2582019>,
    <1.9620916, -0.3466602, 34.2582471>,
    <1.9693187, -0.1730838, 34.2427102>,
    <1.9812516, -0.1413484, 34.2526827>,
    <1.9758323, -0.2499045, 34.2582019>,
    <1.9676146, -0.2489496, 34.2497196>,
    <1.9749322, -0.1409367, 34.2458152>,
    <1.9750153, -0.2024873, 34.2520259>,
    <1.9641476, -0.0006015, 34.2254060>,
    <1.9776270, -0.0006705, 34.2427102>,
    <1.9684847, -0.0974323, 34.2353389>,
    <1.9714979, -0.0006539, 34.2353389>,
    <1.9792052, -0.0654144, 34.2458152>,
    <1.9737777, -0.0724657, 34.2399571>,
    <1.9839085, -0.0006853, 34.2497196>,
    <1.9891343, -0.0984063, 34.2582019>,
    <1.9845111, -0.0728068, 34.2520259>,
    <1.9885495, -0.2329760, 34.2672347>,
    <1.9773914, -0.3481399, 34.2713544>,
    <1.9937209, -0.2075925, 34.2690979>,
    <1.9855851, -0.3457525, 34.2765461>,
    <1.9846619, -0.2835121, 34.2690979>,
    <1.9918287, -0.2753277, 34.2734378>,
    <1.9702280, -0.3481448, 34.2658251>,
    <1.9867364, -0.2074114, 34.2634197>,
    <1.9791889, -0.2759752, 34.2639559>,
    <1.9925135, -0.1459768, 34.2639559>,
    <1.9937172, -0.4281888, 34.2894166>,
    <1.9936907, -0.4498901, 34.2918006>,
    <1.9708874, -0.5349971, 34.2917990>,
    <1.9775644, -0.4783249, 34.2882651>,
    <1.9941129, -0.4359471, 34.2904030>,
    <1.9818460, -0.4940976, 34.2917998>,
    <1.9727961, -0.5151457, 34.2903384>,
    <1.9871836, -0.4481175, 34.2889141>,
    <1.9836684, -0.4747525, 34.2903601>,
    <1.9853722, -0.4275280, 34.2861096>,
    <1.9998921, -0.3997208, 34.2889145>,
    <1.9940843, -0.4069029, 34.2874555>,
    <2.0061263, -0.4034774, 34.2918014>,
    <2.0035474, -0.3997870, 34.2903610>,
    <1.9895879, 0.2773606, 34.2989756>,
    <1.9931647, 0.2241048, 34.2975521>,
    <2.0045724, 0.2437832, 34.3035582>,
    <1.9907158, 0.2560024, 34.2980080>,
    <2.0057807, 0.1824684, 34.3007100>,
    <2.0120852, 0.1902695, 34.3035582>,
    <1.9961751, 0.2628253, 34.3008727>,
    <2.0018232, 0.2207418, 34.3007914>,
    <1.9699564, 0.3606265, 34.2967794>,
    <1.9970596, 0.2972970, 34.3035582>,
    <1.9803650, 0.3557714, 34.3007507>,
    <1.9817841, 0.3128957, 34.2980080>,
    <1.9886675, 0.3090675, 34.3007914>,
    <1.9571683, 0.3323839, 34.2867877>,
    <1.9630683, 0.3549626, 34.2926777>,
    <1.9792749, 0.2672513, 34.2937748>,
    <1.9779178, 0.3008393, 34.2951914>,
    <2.0023178, 0.1462441, 34.2989756>,
    <1.9975251, 0.1232135, 34.2967794>,
    <2.0199169, 0.0683778, 34.3035582>,
    <1.9998770, 0.1384748, 34.2980080>,
    <2.0111462, 0.0484864, 34.3007507>,
    <2.0200763, 0.0341889, 34.3035582>,
    <2.0095801, 0.1149911, 34.3008727>,
    <2.0103198, 0.0831585, 34.3007914>,
    <2.0197574, 0.1025668, 34.3035582>,
    <1.9974076, 0.1849080, 34.2980080>,
    <2.0082167, 0.1476563, 34.3007914>,
    <1.9819698, 0.2072158, 34.2926777>,
    <1.9880617, 0.2064844, 34.2951914>,
    <1.9910992, 0.1059892, 34.2933120>,
    <1.9957279, 0.0665035, 34.2949171>,
    <1.9938663, 0.1149122, 34.2949171>,
    <2.0032817, 0.0590450, 34.2980246>,
    <1.9741929, 0.1697833, 34.2854038>,
    <1.9676509, 0.2401527, 34.2856693>,
    <1.9834296, 0.1358727, 34.2900253>,
    <1.9809230, 0.1819327, 34.2908029>,
    <1.9795429, 0.0948982, 34.2856693>,
    <1.9879982, 0.0742733, 34.2908029>,
    <1.9776536, -0.2409359, 34.2933120>,
    <1.9708039, -0.3329568, 34.2967794>,
    <1.9754461, -0.2807397, 34.2949171>,
    <1.9786265, -0.3413732, 34.3007507>,
    <1.9811768, -0.2323056, 34.2949171>,
    <1.9805675, -0.2890508, 34.2980246>,
    <1.9731764, -0.1754849, 34.2854038>,
    <1.9786634, -0.1048860, 34.2856693>,
    <1.9759125, -0.2103671, 34.2900253>,
    <1.9807954, -0.1642471, 34.2908029>,
    <1.9516492, -0.3563015, 34.2867877>,
    <1.9655991, -0.2502291, 34.2856693>,
    <1.9633029, -0.3362389, 34.2926777>,
    <1.9698959, -0.2719283, 34.2908029>,
    <1.9676768, -0.1157007, 34.2753407>,
    <1.9579514, -0.1728460, 34.2695801>,
    <1.9637751, -0.1406636, 34.2729301>,
    <1.9568091, -0.2503823, 34.2772285>,
    <1.9704956, -0.1415094, 34.2800513>,
    <1.9642378, -0.2032546, 34.2795037>,
    <1.9663438, -0.0014045, 34.2695801>,
    <1.9735236, -0.0034213, 34.2772285>,
    <1.9681104, -0.0655542, 34.2729301>,
    <1.9740209, -0.0742331, 34.2795037>,
    <1.9513931, -0.0006617, 34.2505667>,
    <1.9595117, -0.0007192, 34.2614925>,
    <1.9565130, -0.0969194, 34.2614925>,
    <1.9621746, -0.0721152, 34.2665723>,
    <1.9687585, 0.2294643, 34.2481381>,
    <1.9694560, 0.1715144, 34.2427102>,
    <1.9756969, 0.2048398, 34.2526827>,
    <1.9809518, 0.0965052, 34.2497196>,
    <1.9694020, 0.2041478, 34.2458152>,
    <1.9801719, 0.1435468, 34.2520259>,
    <1.9344122, 0.3404783, 34.2254060>,
    <1.9476989, 0.3427510, 34.2427102>,
    <1.9554980, 0.2458717, 34.2353389>,
    <1.9416599, 0.3417031, 34.2353389>,
    <1.9604957, 0.2792647, 34.2458152>,
    <1.9563751, 0.2713781, 34.2399571>,
    <1.9538875, 0.3438272, 34.2497196>,
    <1.9670047, 0.2729061, 34.2520259>,
    <1.9693472, 0.1139581, 34.2371711>,
    <1.9697369, 0.1391163, 34.2396408>,
    <1.9739387, 0.0639013, 34.2396408>,
    <1.9785585, 0.0711933, 34.2454279>,
    <1.9557301, 0.1704748, 34.2253660>,
    <1.9609256, 0.0956851, 34.2253660>,
    <1.9636846, 0.1387591, 34.2321345>,
    <1.9680388, 0.0709193, 34.2328481>,
    <1.9479012, 0.2450359, 34.2253660>,
    <1.9587194, 0.1993710, 34.2328481>,
    <1.9516320, -0.1142247, 34.2126378>,
    <1.9556208, -0.1717241, 34.2253660>,
    <1.9342033, -0.3416631, 34.2254060>,
    <1.9429610, -0.1706696, 34.2059260>,
    <1.9536730, -0.1393036, 34.2183311>,
    <1.9477503, -0.2462798, 34.2253660>,
    <1.9405419, -0.2454335, 34.2146338>,
    <1.9481685, -0.1389382, 34.2097470>,
    <1.9475952, -0.1995921, 34.2175110>,
    <1.9396905, -0.0005048, 34.1849198>,
    <1.9511498, -0.0005788, 34.2059260>,
    <1.9429179, -0.0960670, 34.1969055>,
    <1.9458871, -0.0005586, 34.1969055>,
    <1.9523800, -0.0644458, 34.2097470>,
    <1.9476488, -0.0714145, 34.2025384>,
    <1.9566002, -0.0005973, 34.2146338>,
    <1.9608582, -0.0969363, 34.2253660>,
    <1.9569536, -0.0717213, 34.2175110>,
    <1.9592170, -0.2297467, 34.2371711>,
    <1.9474660, -0.3440717, 34.2427102>,
    <1.9639695, -0.2050384, 34.2396408>,
    <1.9536495, -0.3451770, 34.2497196>,
    <1.9550465, -0.2798404, 34.2396408>,
    <1.9608624, -0.2734613, 34.2454279>,
    <1.9414328, -0.3429909, 34.2353389>,
    <1.9579471, -0.2043392, 34.2321345>,
    <1.9504549, -0.2719045, 34.2328481>,
    <1.9635825, -0.1437860, 34.2328481>,
    <1.9579704, 0.2277339, 34.2753407>,
    <1.9582332, 0.1697754, 34.2695801>,
    <1.9583972, 0.2024799, 34.2729301>,
    <1.9706118, 0.0932215, 34.2772285>,
    <1.9653478, 0.2027983, 34.2800513>,
    <1.9698125, 0.1409218, 34.2795037>,
    <1.9368052, 0.3400459, 34.2695801>,
    <1.9444982, 0.3392376, 34.2772285>,
    <1.9496758, 0.2771852, 34.2729301>,
    <1.9572494, 0.2696184, 34.2795037>,
    <1.9218620, 0.3382042, 34.2505667>,
    <1.9298672, 0.3395573, 34.2614925>,
    <1.9436190, 0.2442979, 34.2614925>,
    <1.9448874, 0.2697085, 34.2665723>,
    <1.9575608, 0.1130032, 34.2635082>,
    <1.9623775, 0.0630077, 34.2662252>,
    <1.9582036, 0.1377740, 34.2662252>,
    <1.9677138, 0.0689301, 34.2725930>,
    <1.9430385, 0.1693014, 34.2505227>,
    <1.9352626, 0.2433785, 34.2505227>,
    <1.9514760, 0.1378274, 34.2579678>,
    <1.9466051, 0.1980631, 34.2587527>,
    <1.9481979, 0.0949975, 34.2505227>,
    <1.9558618, 0.0704141, 34.2587527>,
    <1.9380431, -0.1134948, 34.2365221>,
    <1.9289925, -0.1695158, 34.2291393>,
    <1.9216322, -0.3395075, 34.2505667>,
    <1.9429182, -0.1706757, 34.2505227>,
    <1.9344083, -0.1380244, 34.2333423>,
    <1.9271673, -0.2438159, 34.2387176>,
    <1.9350965, -0.2447468, 34.2505227>,
    <1.9404632, -0.1384264, 34.2427845>,
    <1.9343685, -0.1983064, 34.2418824>,
    <1.9371288, -0.0006367, 34.2291393>,
    <1.9481238, -0.0963738, 34.2505227>,
    <1.9431243, -0.0006571, 34.2387176>,
    <1.9385929, -0.0640530, 34.2333423>,
    <1.9436681, -0.0712963, 34.2418824>,
    <1.9244904, -0.0005552, 34.2060335>,
    <1.9313399, -0.0006145, 34.2192172>,
    <1.9283896, -0.0954176, 34.2192172>,
    <1.9334329, -0.0709589, 34.2254131>,
    <1.9474419, -0.2286404, 34.2635082>,
    <1.9362224, -0.3428358, 34.2695801>,
    <1.9435012, -0.2787126, 34.2662252>,
    <1.9429299, -0.3460706, 34.2772285>,
    <1.9523738, -0.2043574, 34.2662252>,
    <1.9497713, -0.2738063, 34.2725930>,
    <1.9457622, -0.2031368, 34.2579678>,
    <1.9514251, -0.1429704, 34.2587527>,
    <1.9296174, -0.3409740, 34.2614925>,
    <1.9383752, -0.2702875, 34.2587527>,
    <1.9572879, -0.4147929, 34.2989756>,
    <1.9422483, -0.4648935, 34.2975521>,
    <1.9310771, -0.5395838, 34.3035582>,
    <1.9568044, -0.4484202, 34.3035582>,
    <1.9508700, -0.4345687, 34.2980080>,
    <1.9368504, -0.5031990, 34.3007100>,
    <1.9432359, -0.4953198, 34.3035582>,
    <1.9571626, -0.4294384, 34.3008727>,
    <1.9466522, -0.4676615, 34.3007914>,
    <1.9713128, -0.3997636, 34.3035582>,
    <1.9637472, -0.3803626, 34.2980080>,
    <1.9681847, -0.3860741, 34.3007914>,
    <1.9468953, -0.4227463, 34.2937748>,
    <1.9566905, -0.3906067, 34.2951914>,
    <1.9418173, 0.2264080, 34.2126378>,
    <1.9430796, 0.1693149, 34.2059260>,
    <1.9481821, 0.2020645, 34.2183311>,
    <1.9536797, 0.0952667, 34.2146338>,
    <1.9426979, 0.2014685, 34.2097470>,
    <1.9526657, 0.1416365, 34.2175110>,
    <1.9103099, 0.3363267, 34.1849198>,
    <1.9216080, 0.3382436, 34.2059260>,
    <1.9300825, 0.2427766, 34.1969055>,
    <1.9164218, 0.3373496, 34.1969055>,
    <1.9339099, 0.2755605, 34.2097470>,
    <1.9304607, 0.2678761, 34.2025384>,
    <1.9269788, 0.3391718, 34.2146338>,
    <1.9396774, 0.2691897, 34.2175110>,
    <1.9435631, 0.1125544, 34.1991181>,
    <1.9436839, 0.1373668, 34.2021355>,
    <1.9478339, 0.0631397, 34.2021355>,
    <1.9517757, 0.0703162, 34.2092829>,
    <1.9313742, 0.1684452, 34.1848862>,
    <1.9365079, 0.0945872, 34.1848862>,
    <1.9385088, 0.1370685, 34.1929998>,
    <1.9427344, 0.0700920, 34.1938690>,
    <1.9236396, 0.2420771, 34.1848862>,
    <1.9335284, 0.1969021, 34.1938690>,
    <1.9286984, -0.1127781, 34.1698789>,
    <1.9312824, -0.1694935, 34.1848862>,
    <1.9101346, -0.3373208, 34.1849198>,
    <1.9208476, -0.1686061, 34.1620860>,
    <1.9301080, -0.1375254, 34.1765488>,
    <1.9235129, -0.2431209, 34.1848862>,
    <1.9175329, -0.2424089, 34.1722289>,
    <1.9255858, -0.1372173, 34.1665078>,
    <1.9241941, -0.1970877, 34.1755900>,
    <1.9198519, -0.0003926, 34.1380150>,
    <1.9289327, -0.0004695, 34.1620860>,
    <1.9217656, -0.0948990, 34.1516897>,
    <1.9246965, -0.0004464, 34.1516897>,
    <1.9297440, -0.0635966, 34.1665078>,
    <1.9258394, -0.0705018, 34.1581668>,
    <1.9333865, -0.0004913, 34.1722289>,
    <1.9364514, -0.0956371, 34.1848862>,
    <1.9334328, -0.0707650, 34.1755900>,
    <1.9335809, -0.2266517, 34.1991181>,
    <1.9214069, -0.3393836, 34.2059260>,
    <1.9380084, -0.2022373, 34.2021355>,
    <1.9267714, -0.3403483, 34.2146338>,
    <1.9292060, -0.2760574, 34.2021355>,
    <1.9343342, -0.2696744, 34.2092829>,
    <1.9162277, -0.3384499, 34.1969055>,
    <1.9328602, -0.2016324, 34.1929998>,
    <1.9253913, -0.2683252, 34.1938690>,
    <1.9383454, -0.1418430, 34.1938690>,
    <1.9250431, 0.6827776, 34.2894164>,
    <1.9329757, 0.6764874, 34.2917999>,
    <1.9428462, 0.6396503, 34.2918015>,
    <1.9304168, 0.6576046, 34.2886788>,
    <1.9285047, 0.6801568, 34.2904025>,
    <1.9372982, 0.6603555, 34.2918008>,
    <1.9371624, 0.6479495, 34.2903190>,
    <1.9265597, 0.6737657, 34.2889144>,
    <1.9325576, 0.6655039, 34.2903608>,
    <1.9014008, 0.7027717, 34.2830969>,
    <1.9125872, 0.7112660, 34.2886777>,
    <1.9215474, 0.6699716, 34.2867235>,
    <1.9075122, 0.7106753, 34.2867230>,
    <1.9199731, 0.6941385, 34.2889138>,
    <1.9180474, 0.6882544, 34.2874556>,
    <1.9177295, 0.7098123, 34.2903168>,
    <1.9294702, 0.6895703, 34.2917988>,
    <1.9241571, 0.6934880, 34.2903595>,
    <1.9453502, 0.6092351, 34.2894178>,
    <1.9584828, 0.5812937, 34.2918021>,
    <1.9373534, 0.6343250, 34.2889153>,
    <1.9500281, 0.6128472, 34.2918019>,
    <1.9504607, 0.5990578, 34.2904042>,
    <1.9431658, 0.6259137, 34.2903617>,
    <1.9535904, 0.5679103, 34.2882666>,
    <1.9678493, 0.5463371, 34.2918021>,
    <1.9685440, 0.5310158, 34.2903407>,
    <1.9481606, 0.5939918, 34.2889155>,
    <1.9589401, 0.5670431, 34.2903619>,
    <1.9346858, 0.6171407, 34.2861105>,
    <1.9336408, 0.6334260, 34.2874564>,
    <1.9619920, 0.5221821, 34.2863580>,
    <1.9583543, 0.5422698, 34.2872643>,
    <1.9708587, 0.4959060, 34.2872643>,
    <1.9695527, 0.5148921, 34.2889217>,
    <1.9477337, 0.5421339, 34.2817251>,
    <1.9674592, 0.4687773, 34.2819691>,
    <1.9563675, 0.5288208, 34.2845089>,
    <1.9716947, 0.4740619, 34.2850030>,
    <1.9280575, 0.6121791, 34.2819691>,
    <1.9431463, 0.5793930, 34.2850030>,
    <1.9607939, -0.5266589, 34.2863568>,
    <1.9498858, -0.5822731, 34.2882644>,
    <1.9679732, -0.5063286, 34.2872630>,
    <1.9624746, -0.5536669, 34.2903380>,
    <1.9555336, -0.5531548, 34.2872627>,
    <1.9645003, -0.5337473, 34.2889197>,
    <1.9094406, -0.6807908, 34.2830964>,
    <1.9580130, -0.5037896, 34.2817246>,
    <1.9349944, -0.6181386, 34.2861090>,
    <1.9386384, -0.5766677, 34.2819686>,
    <1.9589234, -0.5192945, 34.2845081>,
    <1.9450708, -0.5736435, 34.2850020>,
    <1.9760932, -0.4326533, 34.2819687>,
    <1.9730046, -0.4677906, 34.2850022>,
    <1.9412888, -0.6245516, 34.2894146>,
    <1.9525710, -0.6033566, 34.2917976>,
    <1.9441236, -0.6094162, 34.2889127>,
    <1.9611105, -0.5714860, 34.2917982>,
    <1.9455246, -0.6174792, 34.2904005>,
    <1.9532948, -0.5881112, 34.2903586>,
    <1.9394268, -0.6524116, 34.2917970>,
    <1.9286848, -0.6645586, 34.2886764>,
    <1.9453245, -0.6304011, 34.2917971>,
    <1.9343001, -0.6586320, 34.2903155>,
    <1.9344451, -0.6455371, 34.2889124>,
    <1.9392376, -0.6405739, 34.2903579>,
    <1.9220924, -0.6698977, 34.2867220>,
    <1.9322416, -0.6400809, 34.2874543>,
    <1.9589493, -0.4609733, 34.2751874>,
    <1.9388331, -0.5191325, 34.2713544>,
    <1.9584199, -0.4821550, 34.2783020>,
    <1.9260983, -0.5914825, 34.2765461>,
    <1.9503263, -0.4873652, 34.2735942>,
    <1.9417628, -0.5436818, 34.2779935>,
    <1.9501566, -0.4443452, 34.2658251>,
    <1.9678178, -0.4125487, 34.2735942>,
    <1.9602109, -0.4203972, 34.2692880>,
    <1.9737381, -0.4154367, 34.2779935>,
    <1.9237269, -0.6873438, 34.2894150>,
    <1.9314938, -0.6820181, 34.2917981>,
    <1.9252863, -0.6786872, 34.2889126>,
    <1.9349336, -0.6691805, 34.2917974>,
    <1.9271260, -0.6851126, 34.2904009>,
    <1.9305785, -0.6728901, 34.2903581>,
    <1.9109873, -0.7149312, 34.2886775>,
    <1.9287563, -0.6922349, 34.2917990>,
    <1.9159335, -0.7141143, 34.2903174>,
    <1.9188967, -0.6973770, 34.2889131>,
    <1.9229959, -0.6970637, 34.2903592>,
    <1.9078208, -0.7092723, 34.2867225>,
    <1.9181198, -0.6886590, 34.2874545>,
    <1.9283080, 0.2247671, 34.2365221>,
    <1.9291229, 0.1680256, 34.2291393>,
    <1.9289880, 0.1999790, 34.2333423>,
    <1.9402275, 0.0945373, 34.2387176>,
    <1.9350206, 0.2006346, 34.2427845>,
    <1.9394167, 0.1406059, 34.2418824>,
    <1.9078101, 0.3357519, 34.2291393>,
    <1.9137180, 0.3367729, 34.2387176>,
    <1.9202640, 0.2735532, 34.2333423>,
    <1.9265199, 0.2673013, 34.2418824>,
    <1.8953495, 0.3336375, 34.2060335>,
    <1.9021052, 0.3347685, 34.2192172>,
    <1.9156621, 0.2408933, 34.2192172>,
    <1.9163816, 0.2658563, 34.2254131>,
    <1.9291673, 0.1116575, 34.2216509>,
    <1.9335922, 0.0626162, 34.2249699>,
    <1.9294752, 0.1362959, 34.2249699>,
    <1.9379725, 0.0697507, 34.2328318>,
    <1.9162470, 0.1670689, 34.2059966>,
    <1.9085749, 0.2401239, 34.2059966>,
    <1.9237826, 0.1359677, 34.2149211>,
    <1.9188950, 0.1953473, 34.2158771>,
    <1.9213386, 0.0937898, 34.2059966>,
    <1.9280270, 0.0695041, 34.2158771>,
    <1.9128161, -0.1119035, 34.1894897>,
    <1.9046678, -0.1672459, 34.1809181>,
    <1.8951567, -0.3347310, 34.2060335>,
    <1.9161461, -0.1682221, 34.2059966>,
    <1.9095674, -0.1361314, 34.1857817>,
    <1.9018574, -0.2404889, 34.1920745>,
    <1.9084355, -0.2412720, 34.2059966>,
    <1.9145417, -0.1364703, 34.1968260>,
    <1.9086273, -0.1955514, 34.1957715>,
    <1.9126901, -0.0005165, 34.1809181>,
    <1.9212764, -0.0949447, 34.2059966>,
    <1.9175893, -0.0005404, 34.1920745>,
    <1.9136933, -0.0631189, 34.1857817>,
    <1.9177953, -0.0702444, 34.1957715>,
    <1.9026680, -0.0004319, 34.1544411>,
    <1.9080302, -0.0004910, 34.1694828>,
    <1.9051219, -0.0941328, 34.1694828>,
    <1.9094425, -0.0699548, 34.1766071>,
    <1.9192480, -0.2250352, 34.2216509>,
    <1.9075889, -0.3370059, 34.2291393>,
    <1.9150897, -0.2740998, 34.2249699>,
    <1.9134898, -0.3380671, 34.2387176>,
    <1.9238297, -0.2008246, 34.2249699>,
    <1.9206424, -0.2678344, 34.2328318>,
    <1.9181666, -0.2001593, 34.2149211>,
    <1.9236644, -0.1408331, 34.2158771>,
    <1.9018918, -0.3359788, 34.2192172>,
    <1.9108052, -0.2663502, 34.2158771>,
    <1.9189808, 0.2238502, 34.1698789>,
    <1.9209438, 0.1675071, 34.1620860>,
    <1.9246664, 0.1997236, 34.1765488>,
    <1.9304951, 0.0942499, 34.1722289>,
    <1.9201594, 0.1992418, 34.1665078>,
    <1.9291851, 0.1400394, 34.1755900>,
    <1.8907533, 0.3329921, 34.1380150>,
    <1.8997094, 0.3344933, 34.1620860>,
    <1.9090487, 0.2402538, 34.1516897>,
    <1.8955336, 0.3337804, 34.1516897>,
    <1.9114703, 0.2724661, 34.1665078>,
    <1.9088241, 0.2649878, 34.1581668>,
    <1.9040994, 0.3352453, 34.1722289>,
    <1.9163479, 0.2660472, 34.1755900>,
    <1.9221531, 0.1114232, 34.1542153>,
    <1.9219481, 0.1359427, 34.1576891>,
    <1.9260564, 0.0625371, 34.1576891>,
    <1.9291870, 0.0696109, 34.1659804>,
    <1.9116146, 0.1668337, 34.1379890>,
    <1.9166995, 0.0937316, 34.1379890>,
    <1.9178074, 0.1357124, 34.1472010>,
    <1.9218988, 0.0694433, 34.1481994>,
    <1.9039553, 0.2397119, 34.1379890>,
    <1.9127836, 0.1949056, 34.1481994>,
    <1.9105904, -0.1115972, 34.1211611>,
    <1.9115432, -0.1676492, 34.1379890>,
    <1.8906169, -0.3337654, 34.1380150>,
    <1.9036504, -0.1669558, 34.1125260>,
    <1.9112728, -0.1360678, 34.1286034>,
    <1.9038568, -0.2405237, 34.1379890>,
    <1.8992868, -0.2399678, 34.1237934>,
    <1.9078703, -0.1358264, 34.1174128>,
    <1.9055228, -0.1950499, 34.1275355>,
    <1.9052346, -0.0002686, 34.0861253>,
    <1.9116509, -0.0003459, 34.1125260>,
    <1.9056703, -0.0939639, 34.1010718>,
    <1.9085698, -0.0003206, 34.1010718>,
    <1.9119850, -0.0628925, 34.1174128>,
    <1.9090121, -0.0697552, 34.1081947>,
    <1.9149728, -0.0003703, 34.1237934>,
    <1.9166555, -0.0945483, 34.1379890>,
    <1.9146634, -0.0699668, 34.1275355>,
    <1.9122998, -0.2240480, 34.1542153>,
    <1.8995464, -0.3354180, 34.1620860>,
    <1.9163556, -0.1998654, 34.1576891>,
    <1.9039288, -0.3362128, 34.1722289>,
    <1.9076547, -0.2728692, 34.1576891>,
    <1.9119661, -0.2664465, 34.1659804>,
    <1.8953785, -0.3346597, 34.1516897>,
    <1.9122379, -0.1993732, 34.1472010>,
    <1.9047596, -0.2653459, 34.1481994>,
    <1.9175691, -0.1402069, 34.1481994>,
    <1.9248703, -0.5423243, 34.2989756>,
    <1.9161689, -0.5654517, 34.2967794>,
    <1.9119284, -0.6184479, 34.3035582>,
    <1.9216598, -0.5504141, 34.2980080>,
    <1.9035687, -0.6406407, 34.3007507>,
    <1.9039987, -0.6548051, 34.3035582>,
    <1.9197632, -0.5729032, 34.3008727>,
    <1.9120790, -0.6057091, 34.3007914>,
    <1.9207979, -0.5803336, 34.3035582>,
    <1.9331039, -0.5036464, 34.2980080>,
    <1.9279539, -0.5385064, 34.3007914>,
    <1.9308625, -0.4815177, 34.2926777>,
    <1.9342418, -0.4827210, 34.2951914>,
    <1.9009429, 0.2218688, 34.1211611>,
    <1.9037213, 0.1661461, 34.1125260>,
    <1.9058642, 0.1978884, 34.1286034>,
    <1.9121023, 0.0934856, 34.1237934>,
    <1.9024715, 0.1975353, 34.1174128>,
    <1.9104437, 0.1388039, 34.1275355>,
    <1.8763365, 0.3305760, 34.0861253>,
    <1.8826688, 0.3316140, 34.1125260>,
    <1.8930355, 0.2383798, 34.1010718>,
    <1.8796301, 0.3311039, 34.1010718>,
    <1.8938588, 0.2700757, 34.1174128>,
    <1.8921228, 0.2628010, 34.1081947>,
    <1.8859443, 0.3321669, 34.1237934>,
    <1.8977250, 0.2635739, 34.1275355>,
    <1.9057679, 0.1105989, 34.1038334>,
    <1.9051900, 0.1348873, 34.1076575>,
    <1.9092679, 0.0621118, 34.1076575>,
    <1.9114787, 0.0690988, 34.1168389>,
    <1.8970517, 0.1656895, 34.0861074>,
    <1.9021020, 0.0931443, 34.0861074>,
    <1.9022096, 0.1347319, 34.0961373>,
    <1.9061650, 0.0689930, 34.0972345>,
    <1.8894466, 0.2380120, 34.0861074>,
    <1.8971155, 0.1934422, 34.0972345>,
    <1.8976648, -0.1107375, 34.0680823>,
    <1.8970029, -0.1662473, 34.0861074>,
    <1.8762432, -0.3311050, 34.0861253>,
    <1.8910971, -0.1658369, 34.0592183>,
    <1.8977397, -0.1349750, 34.0759583>,
    <1.8893792, -0.2385673, 34.0861074>,
    <1.8863580, -0.2381842, 34.0708032>,
    <1.8951244, -0.1348517, 34.0642124>,
    <1.8921488, -0.1935409, 34.0748134>,
    <1.8860144, 0.0005654, 34.0361559>,
    <1.8990367, -0.0003039, 34.0592183>,
    <1.8919416, -0.0935620, 34.0484530>,
    <1.8948260, -0.0005532, 34.0484530>,
    <1.8992067, -0.0623989, 34.0642124>,
    <1.8959349, -0.0693732, 34.0551646>,
    <1.9019184, -0.0002380, 34.0708032>,
    <1.9020720, -0.0937029, 34.0861074>,
    <1.9012158, -0.0693511, 34.0748134>,
    <1.8960203, -0.2220145, 34.1038334>,
    <1.8825486, -0.3322954, 34.1125260>,
    <1.8996688, -0.1979947, 34.1076575>,
    <1.8858157, -0.3328962, 34.1237934>,
    <1.8910474, -0.2703727, 34.1076575>,
    <1.8944379, -0.2638758, 34.1168389>,
    <1.8795187, -0.3317354, 34.1010718>,
    <1.8967067, -0.1976302, 34.0961373>,
    <1.8891866, -0.2630572, 34.0972345>,
    <1.9018849, -0.1389273, 34.0972345>,
    <1.9031879, 0.2219536, 34.1894897>,
    <1.9047735, 0.1660371, 34.1809181>,
    <1.9041957, 0.1975296, 34.1857817>,
    <1.9147244, 0.0934188, 34.1920745>,
    <1.9091534, 0.1980596, 34.1968260>,
    <1.9135881, 0.1388491, 34.1957715>,
    <1.8837217, 0.3316265, 34.1809181>,
    <1.8885506, 0.3324537, 34.1920745>,
    <1.8955805, 0.2701494, 34.1857817>,
    <1.9008575, 0.2638445, 34.1957715>,
    <1.8738371, 0.3299695, 34.1544411>,
    <1.8791282, 0.3308424, 34.1694828>,
    <1.8925248, 0.2381182, 34.1694828>,
    <1.8925813, 0.2626791, 34.1766071>,
    <1.9056163, 0.1104131, 34.1722608>,
    <1.9096369, 0.0619534, 34.1760819>,
    <1.9055658, 0.1347294, 34.1760819>,
    <1.9131249, 0.0689749, 34.1852017>,
    <1.8945113, 0.1652963, 34.1544124>,
    <1.8869221, 0.2375221, 34.1544124>,
    <1.9010111, 0.1344760, 34.1645454>,
    <1.8960757, 0.1931512, 34.1656437>,
    <1.8995492, 0.0928487, 34.1544124>,
    <1.9051078, 0.0687906, 34.1656437>,
    <1.8928973, -0.1106046, 34.1359011>,
    <1.8857508, -0.1654306, 34.1264018>,
    <1.8736872, -0.3308202, 34.1544411>,
    <1.8944329, -0.1661933, 34.1544124>,
    <1.8900802, -0.1346014, 34.1317777>,
    <1.8817867, -0.2378036, 34.1387967>,
    <1.8868138, -0.2384152, 34.1544124>,
    <1.8938230, -0.1348669, 34.1440880>,
    <1.8880889, -0.1933100, 34.1429132>,
    <1.8936801, -0.0003805, 34.1264018>,
    <1.8995008, -0.0937470, 34.1544124>,
    <1.8973341, -0.0004073, 34.1387967>,
    <1.8941583, -0.0623444, 34.1317777>,
    <1.8971489, -0.0693664, 34.1429132>,
    <1.8865889, -0.0002954, 34.0973598>,
    <1.8902909, -0.0003527, 34.1138015>,
    <1.8874171, -0.0931042, 34.1138015>,
    <1.8909325, -0.0691336, 34.1216372>,
    <1.8958387, -0.2221711, 34.1722608>,
    <1.8835423, -0.3326438, 34.1809181>,
    <1.8913833, -0.2705928, 34.1760819>,
    <1.8883629, -0.3335181, 34.1920745>,
    <1.9000115, -0.1982155, 34.1760819>,
    <1.8960376, -0.2642837, 34.1852017>,
    <1.8954820, -0.1976741, 34.1645454>,
    <1.9008104, -0.1390333, 34.1656437>,
    <1.8789577, -0.3318096, 34.1694828>,
    <1.8881103, -0.2630730, 34.1656437>,
    <1.9270183, 0.5801362, 34.2751874>,
    <1.9386801, 0.5196210, 34.2713545>,
    <1.9371902, 0.5613728, 34.2783022>,
    <1.9639321, 0.4499558, 34.2765463>,
    <1.9327382, 0.5529500, 34.2735942>,
    <1.9535506, 0.4994694, 34.2779937>,
    <1.8725513, 0.6808293, 34.2582471>,
    <1.8866129, 0.6869934, 34.2713545>,
    <1.9110578, 0.5902641, 34.2658251>,
    <1.8803399, 0.6836117, 34.2658251>,
    <1.9105024, 0.6264950, 34.2735942>,
    <1.9077911, 0.6160308, 34.2692880>,
    <1.8927304, 0.6925448, 34.2765462>,
    <1.9172171, 0.6265454, 34.2779937>,
    <1.9483182, 0.4611348, 34.2672347>,
    <1.9445091, 0.4866771, 34.2690979>,
    <1.9619625, 0.4122377, 34.2690979>,
    <1.9659682, 0.4219523, 34.2734379>,
    <1.9237848, 0.5147427, 34.2582019>,
    <1.9421474, 0.4409411, 34.2582019>,
    <1.9378604, 0.4846009, 34.2634197>,
    <1.9542182, 0.4175906, 34.2639559>,
    <1.9028318, 0.5878523, 34.2582019>,
    <1.9222772, 0.5443064, 34.2639559>,
    <1.9285092, -0.4577292, 34.2481381>,
    <1.9234179, -0.5161122, 34.2582019>,
    <1.8720861, -0.6821073, 34.2582471>,
    <1.9093447, -0.5124229, 34.2427102>,
    <1.9266071, -0.4832417, 34.2526827>,
    <1.9024196, -0.5892076, 34.2582019>,
    <1.8944925, -0.5868402, 34.2497196>,
    <1.9204552, -0.4817389, 34.2458152>,
    <1.9098488, -0.5423689, 34.2520259>,
    <1.9216601, -0.4377759, 34.2353389>,
    <1.9377775, -0.4081060, 34.2458152>,
    <1.9312080, -0.4141077, 34.2399571>,
    <1.9418268, -0.4423209, 34.2582019>,
    <1.9417192, -0.4163074, 34.2520259>,
    <1.9178831, -0.5747446, 34.2672347>,
    <1.8868966, -0.6862213, 34.2713544>,
    <1.9273837, -0.5506447, 34.2690979>,
    <1.8953802, -0.6852932, 34.2765461>,
    <1.9052791, -0.6238379, 34.2690979>,
    <1.9137582, -0.6170224, 34.2734378>,
    <1.8798411, -0.6849823, 34.2658251>,
    <1.9205368, -0.5492536, 34.2634197>,
    <1.9011979, -0.6154651, 34.2639559>,
    <1.9368941, -0.4897554, 34.2639559>,
    <1.8880638, 0.2204716, 34.0680823>,
    <1.8911620, 0.1650707, 34.0592183>,
    <1.8923469, 0.1966146, 34.0759583>,
    <1.8990602, 0.0929970, 34.0708032>,
    <1.8897486, 0.1962834, 34.0642124>,
    <1.8970108, 0.1379676, 34.0748134>,
    <1.8572335, 0.3280941, 34.0361559>,
    <1.8702365, 0.3294677, 34.0592183>,
    <1.8794362, 0.2364024, 34.0484530>,
    <1.8661260, 0.3284991, 34.0484530>,
    <1.8811876, 0.2683443, 34.0642124>,
    <1.8791728, 0.2609123, 34.0551646>,
    <1.8730653, 0.3300303, 34.0708032>,
    <1.8843747, 0.2618451, 34.0748134>,
    <1.8930403, 0.1097562, 34.0506060>,
    <1.8929397, 0.1340106, 34.0541438>,
    <1.8969865, 0.0617285, 34.0541438>,
    <1.8991888, 0.0687955, 34.0633523>,
    <1.8781554, 0.1638297, 34.0364647>,
    <1.8826857, 0.0938252, 34.0364059>,
    <1.8879935, 0.1333686, 34.0438443>,
    <1.8920432, 0.0681611, 34.0448606>,
    <1.8704175, 0.2347992, 34.0364059>,
    <1.8830838, 0.1916685, 34.0448606>,
    <1.8625581, -0.1037175, 34.0264558>,
    <1.8780940, -0.1648360, 34.0364647>,
    <1.8574832, -0.3269844, 34.0361559>,
    <1.8460349, -0.1410060, 34.0228405>,
    <1.8711775, -0.1319829, 34.0303723>,
    <1.8703999, -0.2345644, 34.0364059>,
    <1.8529800, -0.2205894, 34.0277741>,
    <1.8562826, -0.1186992, 34.0246615>,
    <1.8640060, -0.1820660, 34.0296825>,
    <1.8519000, -0.0008895, 34.0228405>,
    <1.8354975, -0.0618824, 34.0186848>,
    <1.8367773, 0.0007241, 34.0186848>,
    <1.8592151, -0.0604509, 34.0246615>,
    <1.8475497, -0.0592191, 34.0213137>,
    <1.8668794, 0.0006266, 34.0277741>,
    <1.8827980, -0.0936021, 34.0364059>,
    <1.8721225, -0.0697901, 34.0296825>,
    <1.8833441, -0.2206415, 34.0506060>,
    <1.8701352, -0.3300666, 34.0592183>,
    <1.8874547, -0.1967347, 34.0541438>,
    <1.8729827, -0.3304991, 34.0708032>,
    <1.8788884, -0.2686214, 34.0541438>,
    <1.8822821, -0.2620403, 34.0633523>,
    <1.8659507, -0.3295899, 34.0484530>,
    <1.8824797, -0.1965204, 34.0438443>,
    <1.8751442, -0.2614395, 34.0448606>,
    <1.8877677, -0.1382528, 34.0448606>,
    <1.8521870, 0.2213854, 34.0264558>,
    <1.8423510, 0.1818381, 34.0228405>,
    <1.8656132, 0.1950124, 34.0303723>,
    <1.8630535, 0.1046199, 34.0277741>,
    <1.8485928, 0.2055592, 34.0246615>,
    <1.8672405, 0.1444526, 34.0296825>,
    <1.8237959, 0.3208454, 34.0228405>,
    <1.8181842, 0.2579872, 34.0186848>,
    <1.8085730, 0.3198654, 34.0186848>,
    <1.8413661, 0.2634321, 34.0246615>,
    <1.8296278, 0.2626609, 34.0213137>,
    <1.8383279, 0.3248898, 34.0277741>,
    <1.8557371, 0.2564326, 34.0296825>,
    <1.8383189, 0.1117077, 34.0204813>,
    <1.8403709, 0.1436788, 34.0215203>,
    <1.8453646, 0.0607853, 34.0215203>,
    <1.8554870, 0.0753810, 34.0248083>,
    <1.8138417, 0.1577366, 34.0159774>,
    <1.8207894, 0.0783260, 34.0159774>,
    <1.8287206, 0.1306256, 34.0185671>,
    <1.8335100, 0.0648824, 34.0186456>,
    <1.8068939, 0.2371473, 34.0159774>,
    <1.8239569, 0.1947258, 34.0186456>,
    <1.8299072, -0.2094038, 34.0204813>,
    <1.8237088, -0.3226134, 34.0228405>,
    <1.8374702, -0.1782600, 34.0215203>,
    <1.8386896, -0.3236662, 34.0277741>,
    <1.8279938, -0.2607601, 34.0215203>,
    <1.8404717, -0.2481034, 34.0248083>,
    <1.8138428, -0.1599025, 34.0159774>,
    <1.8091353, -0.3184613, 34.0186848>,
    <1.8068956, -0.2393115, 34.0159774>,
    <1.8237593, -0.1891385, 34.0185671>,
    <1.8170590, -0.2547120, 34.0186456>,
    <1.8207899, -0.0804936, 34.0159774>,
    <1.8301978, -0.1251848, 34.0186456>,
    <1.9077208, 0.6185837, 34.2989756>,
    <1.9204594, 0.5669489, 34.2975521>,
    <1.9266429, 0.5881140, 34.3035582>,
    <1.9124659, 0.5978462, 34.2980080>,
    <1.9382193, 0.5282806, 34.3007100>,
    <1.9416950, 0.5370292, 34.3035582>,
    <1.9160164, 0.6054139, 34.3008727>,
    <1.9279836, 0.5651516, 34.3007914>,
    <1.8755492, 0.6969819, 34.2967794>,
    <1.9115909, 0.6391989, 34.3035582>,
    <1.8864383, 0.6938057, 34.3007507>,
    <1.8946396, 0.6521225, 34.2980080>,
    <1.9016809, 0.6494405, 34.3007914>,
    <1.8692024, 0.6671848, 34.2867877>,
    <1.8702445, 0.6903372, 34.2926777>,
    <1.9008089, 0.6069322, 34.2937748>,
    <1.8933356, 0.6396852, 34.2951914>,
    <1.9436480, 0.4918960, 34.2989756>,
    <1.9448179, 0.4682587, 34.2967794>,
    <1.9731469, 0.4183776, 34.3035582>,
    <1.9435042, 0.4837691, 34.2980080>,
    <1.9716439, 0.3969758, 34.3007507>,
    <1.9813468, 0.3845942, 34.3035582>,
    <1.9556475, 0.4624292, 34.3008727>,
    <1.9633223, 0.4311196, 34.3007914>,
    <1.9649470, 0.4521610, 34.3035582>,
    <1.9317516, 0.5291212, 34.2980080>,
    <1.9473603, 0.4944280, 34.3007914>,
    <1.9149575, 0.5482781, 34.2926777>,
    <1.9200991, 0.5486667, 34.2951914>,
    <1.9427406, 0.4499922, 34.2933120>,
    <1.9548759, 0.4117162, 34.2949171>,
    <1.9433749, 0.4593707, 34.2949171>,
    <1.9630157, 0.4058184, 34.2980246>,
    <1.9147943, 0.5099834, 34.2854038>,
    <1.8958526, 0.5781862, 34.2856693>,
    <1.9298416, 0.4781629, 34.2900253>,
    <1.9188818, 0.5231692, 34.2908029>,
    <1.9334982, 0.4370553, 34.2856693>,
    <1.9458067, 0.4180823, 34.2908029>,
    <1.9177173, -0.4556364, 34.2753407>,
    <1.8981979, -0.5102172, 34.2695801>,
    <1.8601943, -0.6898123, 34.2867877>,
    <1.9128696, -0.5155125, 34.2854038>,
    <1.9095275, -0.4795372, 34.2729301>,
    <1.8836287, -0.5863842, 34.2772285>,
    <1.8924249, -0.5878016, 34.2856693>,
    <1.9160429, -0.4815549, 34.2800513>,
    <1.8991517, -0.5412713, 34.2795037>,
    <1.9304855, -0.4469286, 34.2856693>,
    <1.9268322, -0.4063205, 34.2729301>,
    <1.9311614, -0.4159041, 34.2795037>,
    <1.9099593, -0.4351919, 34.2614925>,
    <1.9198421, -0.4117476, 34.2665723>,
    <1.9062092, -0.5808553, 34.2933120>,
    <1.8836175, -0.6703348, 34.2967794>,
    <1.8972014, -0.6196983, 34.2949171>,
    <1.8901930, -0.6801062, 34.3007507>,
    <1.9112478, -0.5729962, 34.2949171>,
    <1.9010088, -0.6288505, 34.2980246>,
    <1.9096531, -0.5503936, 34.2900253>,
    <1.9224605, -0.5058241, 34.2908029>,
    <1.8754095, -0.6721715, 34.2926777>,
    <1.8930575, -0.6099796, 34.2908029>,
    <1.8833462, 0.2197740, 34.1359011>,
    <1.8858287, 0.1645399, 34.1264018>,
    <1.8847389, 0.1956524, 34.1317777>,
    <1.8944923, 0.0925780, 34.1387967>,
    <1.8884709, 0.1960409, 34.1440880>,
    <1.8929725, 0.1374901, 34.1429132>,
    <1.8649769, 0.3284593, 34.1264018>,
    <1.8685800, 0.3290675, 34.1387967>,
    <1.8762078, 0.2675199, 34.1317777>,
    <1.8803723, 0.2611239, 34.1429132>,
    <1.8579787, 0.3273118, 34.0973598>,
    <1.8616343, 0.3278982, 34.1138015>,
    <1.8749103, 0.2360568, 34.1138015>,
    <1.8742099, 0.2602736, 34.1216372>,
    <1.8875924, 0.1095064, 34.1168394>,
    <1.8911695, 0.0614856, 34.1210460>,
    <1.8871318, 0.1335684, 34.1210460>,
    <1.8936457, 0.0684116, 34.1311462>,
    <1.8784922, 0.1640376, 34.0973402>,
    <1.8709624, 0.2356522, 34.0973402>,
    <1.8838534, 0.1333975, 34.1083733>,
    <1.8788407, 0.1915414, 34.1095803>,
    <1.8834920, 0.0922026, 34.0973402>,
    <1.8878007, 0.0682952, 34.1095803>,
    <1.8787004, -0.1096567, 34.0775018>,
    <1.8720297, -0.1641925, 34.0677166>,
    <1.8578761, -0.3278937, 34.0973598>,
    <1.8784385, -0.1646512, 34.0973402>,
    <1.8761078, -0.1335244, 34.0732308>,
    <1.8675650, -0.2358416, 34.0805061>,
    <1.8708883, -0.2362631, 34.0973402>,
    <1.8789365, -0.1336649, 34.0861763>,
    <1.8733774, -0.1916500, 34.0849170>,
    <1.8798919, -0.0003242, 34.0677166>,
    <1.8834589, -0.0928171, 34.0973402>,
    <1.8829743, -0.0002618, 34.0805061>,
    <1.8801502, -0.0617966, 34.0732308>,
    <1.8823565, -0.0686891, 34.0849170>,
    <1.8658112, 0.0019212, 34.0416239>,
    <1.8755224, -0.0005683, 34.0557354>,
    <1.8726662, -0.0926325, 34.0557354>,
    <1.8767398, -0.0686943, 34.0632019>,
    <1.8779313, -0.2199342, 34.1168394>,
    <1.8648447, -0.3292089, 34.1264018>,
    <1.8731152, -0.2678466, 34.1210460>,
    <1.8684386, -0.3298697, 34.1387967>,
    <1.8816560, -0.1961578, 34.1210460>,
    <1.8767565, -0.2614559, 34.1311462>,
    <1.8783977, -0.1957569, 34.1083733>,
    <1.8835577, -0.1376258, 34.1095803>,
    <1.8615118, -0.3285929, 34.1138015>,
    <1.8709801, -0.2605555, 34.1095803>,
    <1.8942958, 0.7566914, 34.2894164>,
    <1.8703294, 0.8021817, 34.2882660>,
    <1.8592764, 0.8450228, 34.2918015>,
    <1.8925151, 0.7737402, 34.2917999>,
    <1.8849673, 0.7741444, 34.2889144>,
    <1.8629303, 0.8293918, 34.2903401>,
    <1.8757796, 0.8096307, 34.2918008>,
    <1.8942636, 0.7623812, 34.2904025>,
    <1.8791966, 0.7946210, 34.2903608>,
    <1.9094054, 0.7375175, 34.2917988>,
    <1.9034543, 0.7337298, 34.2889138>,
    <1.9074365, 0.7334441, 34.2903595>,
    <1.8814284, 0.7660423, 34.2861101>,
    <1.8954457, 0.7427339, 34.2874556>,
    <1.8691999, 0.2182428, 34.0775018>,
    <1.8720988, 0.1633793, 34.0677166>,
    <1.8707905, 0.1942883, 34.0732308>,
    <1.8801460, 0.0920406, 34.0805061>,
    <1.8736019, 0.1946396, 34.0861763>,
    <1.8781963, 0.1365701, 34.0849170>,
    <1.8513860, 0.3261232, 34.0677166>,
    <1.8544131, 0.3267172, 34.0805061>,
    <1.8623161, 0.2656284, 34.0732308>,
    <1.8656870, 0.2592222, 34.0849170>,
    <1.8385780, 0.3231202, 34.0418191>,
    <1.8471183, 0.3251323, 34.0557354>,
    <1.8602923, 0.2339707, 34.0557354>,
    <1.8601514, 0.2582477, 34.0632019>,
    <1.8737979, 0.1086179, 34.0581798>,
    <1.8777694, 0.0610801, 34.0621232>,
    <1.8737645, 0.1326284, 34.0621232>,
    <1.8801268, 0.0680780, 34.0723106>,
    <1.8585135, 0.1626204, 34.0420789>,
    <1.8506576, 0.2322709, 34.0419288>,
    <1.8686786, 0.1319843, 34.0506039>,
    <1.8638379, 0.1896879, 34.0517365>,
    <1.8626088, 0.0949159, 34.0419288>,
    <1.8727044, 0.0674451, 34.0517365>,
    <1.8410045, -0.0955887, 34.0293375>,
    <1.8239086, -0.1151285, 34.0241543>,
    <1.8385269, -0.3223308, 34.0418241>,
    <1.8585518, -0.1626461, 34.0420827>,
    <1.8343937, -0.1015477, 34.0268358>,
    <1.8325540, -0.2061535, 34.0309519>,
    <1.8508350, -0.2301227, 34.0419363>,
    <1.8510216, -0.1285949, 34.0346672>,
    <1.8435091, -0.1720259, 34.0335085>,
    <1.8276003, 0.0055977, 34.0240386>,
    <1.8629271, -0.0926622, 34.0419363>,
    <1.8439811, 0.0026382, 34.0306517>,
    <1.8363998, -0.0541506, 34.0268358>,
    <1.8508253, -0.0691083, 34.0335085>,
    <1.8108706, 0.0382201, 34.0184901>,
    <1.8111369, -0.0067284, 34.0186526>,
    <1.8238857, -0.0357398, 34.0223007>,
    <1.8641963, -0.2184211, 34.0581798>,
    <1.8512776, -0.3267621, 34.0677166>,
    <1.8598506, -0.2659228, 34.0621232>,
    <1.8543222, -0.3272329, 34.0805061>,
    <1.8683308, -0.1947661, 34.0621232>,
    <1.8633851, -0.2594369, 34.0723106>,
    <1.8632178, -0.1945297, 34.0506039>,
    <1.8684702, -0.1368614, 34.0517365>,
    <1.8469377, -0.3262529, 34.0557354>,
    <1.8559747, -0.2587865, 34.0517365>,
    <1.8990026, 0.5678495, 34.2481381>,
    <1.9097524, 0.5109011, 34.2427102>,
    <1.9101115, 0.5448040, 34.2526827>,
    <1.9340987, 0.4390278, 34.2497196>,
    <1.9040324, 0.5430294, 34.2458152>,
    <1.9251620, 0.4852192, 34.2520259>,
    <1.8459007, 0.6712128, 34.2254060>,
    <1.8585908, 0.6757582, 34.2427102>,
    <1.8830944, 0.5817050, 34.2353389>,
    <1.8528256, 0.6736775, 34.2353389>,
    <1.8822176, 0.6154586, 34.2458152>,
    <1.8795291, 0.6069763, 34.2399571>,
    <1.8644986, 0.6778927, 34.2497196>,
    <1.8897319, 0.6103268, 34.2520259>,
    <1.9196397, 0.4542004, 34.2371711>,
    <1.9156549, 0.4790441, 34.2396408>,
    <1.9328538, 0.4057014, 34.2396408>,
    <1.9361372, 0.4136848, 34.2454279>,
    <1.8964155, 0.5074938, 34.2253660>,
    <1.9145192, 0.4347425, 34.2253660>,
    <1.9097566, 0.4776413, 34.2321345>,
    <1.9258249, 0.4115882, 34.2328481>,
    <1.8757581, 0.5795627, 34.2253660>,
    <1.8943417, 0.5364701, 34.2328481>,
    <1.9021475, -0.4513868, 34.2126378>,
    <1.8960909, -0.5087052, 34.2253660>,
    <1.8454892, -0.6723433, 34.2254060>,
    <1.8838066, -0.5054684, 34.2059260>,
    <1.8998025, -0.4764390, 34.2183311>,
    <1.8753935, -0.5807615, 34.2253660>,
    <1.8684416, -0.5786764, 34.2146338>,
    <1.8944451, -0.4751233, 34.2097470>,
    <1.8833481, -0.5347562, 34.2175110>,
    <1.8967188, -0.4319917, 34.1969055>,
    <1.9115281, -0.4024940, 34.2097470>,
    <1.9056587, -0.4085352, 34.2025384>,
    <1.9142356, -0.4359630, 34.2253660>,
    <1.9147688, -0.4104531, 34.2175110>,
    <1.8895570, -0.5664708, 34.2371711>,
    <1.8581322, -0.6770184, 34.2427102>,
    <1.8985278, -0.5429631, 34.2396408>,
    <1.8640298, -0.6791806, 34.2497196>,
    <1.8767512, -0.6150792, 34.2396408>,
    <1.8835864, -0.6098070, 34.2454279>,
    <1.8523784, -0.6749064, 34.2353389>,
    <1.8927184, -0.5412288, 34.2321345>,
    <1.8736074, -0.6064666, 34.2328481>,
    <1.9087831, -0.4825741, 34.2328481>,
    <1.8299426, 0.2227177, 34.0292978>,
    <1.8172409, 0.1930431, 34.0239716>,
    <1.8250818, 0.2120733, 34.0267837>,
    <1.8391511, 0.1159547, 34.0306145>,
    <1.8451094, 0.1949592, 34.0346523>,
    <1.8451596, 0.1512357, 34.0334787>,
    <1.8014889, 0.3098129, 34.0240854>,
    <1.8175036, 0.3186764, 34.0309073>,
    <1.8188781, 0.2585138, 34.0267837>,
    <1.8345341, 0.2533922, 34.0334787>,
    <1.7907948, 0.2773206, 34.0185953>,
    <1.7961134, 0.2365220, 34.0184328>,
    <1.8071000, 0.2530975, 34.0222412>,
    <1.8159980, 0.1160369, 34.0214373>,
    <1.8222369, 0.0658515, 34.0226142>,
    <1.8168956, 0.1509169, 34.0225769>,
    <1.8315501, 0.0828493, 34.0267162>,
    <1.7947329, 0.1560643, 34.0159774>,
    <1.7904363, 0.2051734, 34.0159774>,
    <1.8083686, 0.1313084, 34.0192839>,
    <1.8033810, 0.1862330, 34.0191093>,
    <1.7990295, 0.1069549, 34.0159774>,
    <1.8110913, 0.0788933, 34.0191391>,
    <1.8138203, -0.1950734, 34.0227027>,
    <1.8099836, -0.3212378, 34.0268959>,
    <1.8129607, -0.2554316, 34.0246118>,
    <1.8227413, -0.3188232, 34.0324158>,
    <1.8176776, -0.1583999, 34.0230769>,
    <1.8224227, -0.2377300, 34.0279170>,
    <1.8101230, -0.1695792, 34.0206301>,
    <1.8122266, -0.0923175, 34.0197890>,
    <1.7970423, -0.3229487, 34.0224156>,
    <1.8040135, -0.2479346, 34.0212444>,
    <1.8890724, -0.7678948, 34.2894159>,
    <1.8852772, -0.7892648, 34.2917995>,
    <1.8480431, -0.8691135, 34.2917987>,
    <1.8644598, -0.8144610, 34.2882648>,
    <1.8881146, -0.7756052, 34.2904021>,
    <1.8659366, -0.8307407, 34.2917992>,
    <1.8533700, -0.8498948, 34.2903381>,
    <1.8791780, -0.7863846, 34.2889136>,
    <1.8710909, -0.8120052, 34.2903596>,
    <1.8809700, -0.7657910, 34.2861094>,
    <1.9000969, -0.7409319, 34.2889137>,
    <1.8931307, -0.7469939, 34.2874550>,
    <1.9055823, -0.7457202, 34.2917998>,
    <1.9036843, -0.7416348, 34.2903599>,
    <1.8886937, 0.5642652, 34.2753407>,
    <1.8990863, 0.5072169, 34.2695801>,
    <1.8935407, 0.5394606, 34.2729301>,
    <1.9248230, 0.4339066, 34.2772285>,
    <1.9003075, 0.5409809, 34.2800513>,
    <1.9156405, 0.4807740, 34.2795037>,
    <1.8482980, 0.6712022, 34.2695801>,
    <1.8559112, 0.6717409, 34.2772285>,
    <1.8719002, 0.6115315, 34.2729301>,
    <1.8806039, 0.6053941, 34.2795037>,
    <1.8339361, 0.6667940, 34.2505667>,
    <1.8415847, 0.6695166, 34.2614925>,
    <1.8716692, 0.5780924, 34.2614925>,
    <1.8685059, 0.6033372, 34.2665723>,
    <1.9082232, 0.4512065, 34.2635082>,
    <1.9216795, 0.4027984, 34.2662252>,
    <1.9045860, 0.4757041, 34.2662252>,
    <1.9260748, 0.4095116, 34.2725930>,
    <1.8841205, 0.5041344, 34.2505227>,
    <1.8635994, 0.5757359, 34.2505227>,
    <1.8978952, 0.4746037, 34.2579678>,
    <1.8826386, 0.5330785, 34.2587527>,
    <1.9021043, 0.4318553, 34.2505227>,
    <1.9139206, 0.4089762, 34.2587527>,
    <1.8888917, -0.4483082, 34.2365221>,
    <1.8702507, -0.5019065, 34.2291393>,
    <1.8334834, -0.6680375, 34.2505667>,
    <1.8837634, -0.5054670, 34.2505227>,
    <1.8810526, -0.4718339, 34.2333423>,
    <1.8555511, -0.5747609, 34.2387176>,
    <1.8631983, -0.5770545, 34.2505227>,
    <1.8869457, -0.4732812, 34.2427845>,
    <1.8705456, -0.5311932, 34.2418824>,
    <1.9017923, -0.4331978, 34.2505227>,
    <1.8980186, -0.3997130, 34.2333423>,
    <1.9017590, -0.4077276, 34.2418824>,
    <1.8825239, -0.4288293, 34.2192172>,
    <1.8917378, -0.4056179, 34.2254131>,
    <1.8781541, -0.5633370, 34.2635082>,
    <1.8472782, -0.6738503, 34.2695801>,
    <1.8655799, -0.6119648, 34.2662252>,
    <1.8533346, -0.6782051, 34.2772285>,
    <1.8872293, -0.5402799, 34.2662252>,
    <1.8726151, -0.6082247, 34.2725930>,
    <1.8809273, -0.5379288, 34.2579678>,
    <1.8969521, -0.4796597, 34.2587527>,
    <1.8410927, -0.6708683, 34.2614925>,
    <1.8619920, -0.6027766, 34.2587527>,
    <1.8730014, 0.5601613, 34.2126378>,
    <1.8841586, 0.5041548, 34.2059260>,
    <1.8834967, 0.5372929, 34.2183311>,
    <1.9074561, 0.4330724, 34.2146338>,
    <1.8781993, 0.5357537, 34.2097470>,
    <1.8984054, 0.4785615, 34.2175110>,
    <1.8228855, 0.6629389, 34.1849198>,
    <1.8336790, 0.6667886, 34.2059260>,
    <1.8586026, 0.5742436, 34.1969055>,
    <1.8287269, 0.6650077, 34.1969055>,
    <1.8566789, 0.6071940, 34.2097470>,
    <1.8546165, 0.5990274, 34.2025384>,
    <1.8388071, 0.6686354, 34.2146338>,
    <1.8634650, 0.6019216, 34.2175110>,
    <1.8944912, 0.4483406, 34.1991181>,
    <1.8903015, 0.4727971, 34.2021355>,
    <1.9072779, 0.4004182, 34.2021355>,
    <1.9099136, 0.4081702, 34.2092829>,
    <1.8727821, 0.5012657, 34.1848862>,
    <1.8906632, 0.4294213, 34.1848862>,
    <1.8852568, 0.4716046, 34.1929998>,
    <1.9010486, 0.4063794, 34.1938690>,
    <1.8523790, 0.5724359, 34.1848862>,
    <1.8699621, 0.5296644, 34.1938690>,
    <1.8798134, -0.4459797, 34.1698789>,
    <1.8725097, -0.5022822, 34.1848862>,
    <1.8225403, -0.6638875, 34.1849198>,
    <1.8623875, -0.4995962, 34.1620860>,
    <1.8769043, -0.4705958, 34.1765488>,
    <1.8520730, -0.5734418, 34.1848862>,
    <1.8463074, -0.5717023, 34.1722289>,
    <1.8725044, -0.4695072, 34.1665078>,
    <1.8607374, -0.5282262, 34.1755900>,
    <1.8760906, -0.4271684, 34.1516897>,
    <1.8893835, -0.3977270, 34.1665078>,
    <1.8843391, -0.4038492, 34.1581668>,
    <1.8904252, -0.4304454, 34.1848862>,
    <1.8917715, -0.4054270, 34.1755900>,
    <1.8648478, -0.5589712, 34.1991181>,
    <1.8332831, -0.6678764, 34.2059260>,
    <1.8734476, -0.5356964, 34.2021355>,
    <1.8383985, -0.6697580, 34.2146338>,
    <1.8519602, -0.6068665, 34.2021355>,
    <1.8581188, -0.6014710, 34.2092829>,
    <1.8283447, -0.6660575, 34.1969055>,
    <1.8684826, -0.5342068, 34.1929998>,
    <1.8495461, -0.5985894, 34.1938690>,
    <1.8842668, -0.4762782, 34.1938690>,
    <1.8599823, 0.5561995, 34.2365221>,
    <1.8706379, 0.5004616, 34.2291393>,
    <1.8649563, 0.5319061, 34.2333423>,
    <1.8943348, 0.4300181, 34.2387176>,
    <1.8707835, 0.5335993, 34.2427845>,
    <1.8855366, 0.4752460, 34.2418824>,
    <1.8205234, 0.6619388, 34.2291393>,
    <1.8261643, 0.6639702, 34.2387176>,
    <1.8435889, 0.6028477, 34.2333423>,
    <1.8508354, 0.5977770, 34.2418824>,
    <1.8086194, 0.6576928, 34.2060335>,
    <1.8150761, 0.6599797, 34.2192172>,
    <1.8447282, 0.5698849, 34.2192172>,
    <1.8411020, 0.5945935, 34.2254131>,
    <1.8804698, 0.4449575, 34.2216509>,
    <1.8933433, 0.3974297, 34.2249699>,
    <1.8764946, 0.4692751, 34.2249699>,
    <1.8964182, 0.4052164, 34.2328318>,
    <1.8581237, 0.4972835, 34.2059966>,
    <1.8378823, 0.5678964, 34.2059966>,
    <1.8709455, 0.4679634, 34.2149211>,
    <1.8558210, 0.5255922, 34.2158771>,
    <1.8758627, 0.4260019, 34.2059966>,
    <1.8866667, 0.4032465, 34.2158771>,
    <1.8643242, -0.4423605, 34.1894897>,
    <1.8466897, -0.4954471, 34.1809181>,
    <1.8082396, -0.6587362, 34.2060335>,
    <1.8578241, -0.4984017, 34.2059966>,
    <1.8569178, -0.4656562, 34.1857817>,
    <1.8312035, -0.5670894, 34.1920745>,
    <1.8375457, -0.5690029, 34.2059966>,
    <1.8617577, -0.4668537, 34.1968260>,
    <1.8456738, -0.5240102, 34.1957715>,
    <1.8756009, -0.4271284, 34.2059966>,
    <1.8736595, -0.3944693, 34.1857817>,
    <1.8764619, -0.4021989, 34.1957715>,
    <1.8598328, -0.4235237, 34.1694828>,
    <1.8682863, -0.4004633, 34.1766071>,
    <1.8510133, -0.5548904, 34.2216509>,
    <1.8200879, -0.6631354, 34.2291393>,
    <1.8383983, -0.6024874, 34.2249699>,
    <1.8257149, -0.6652051, 34.2387176>,
    <1.8597295, -0.5318431, 34.2249699>,
    <1.8449546, -0.5972814, 34.2328318>,
    <1.8542680, -0.5302045, 34.2149211>,
    <1.8699842, -0.4727343, 34.2158771>,
    <1.8146557, -0.6611346, 34.2192172>,
    <1.8355246, -0.5941116, 34.2158771>,
    <1.8509560, 0.5536769, 34.1698789>,
    <1.8626730, 0.4985307, 34.1620860>,
    <1.8607447, 0.5309042, 34.1765488>,
    <1.8848002, 0.4280450, 34.1722289>,
    <1.8563899, 0.5296470, 34.1665078>,
    <1.8755589, 0.4729113, 34.1755900>,
    <1.8042050, 0.6562591, 34.1380150>,
    <1.8127644, 0.6592926, 34.1620860>,
    <1.8383263, 0.5681066, 34.1516897>,
    <1.8087758, 0.6578655, 34.1516897>,
    <1.8351176, 0.6002501, 34.1665078>,
    <1.8338101, 0.5924259, 34.1581668>,
    <1.8169571, 0.6607955, 34.1722289>,
    <1.8410356, 0.5947756, 34.1755900>,
    <1.8736029, 0.4435088, 34.1542153>,
    <1.8691432, 0.4676202, 34.1576891>,
    <1.8859358, 0.3960432, 34.1576891>,
    <1.8877905, 0.4035531, 34.1659804>,
    <1.8536025, 0.4962476, 34.1379890>,
    <1.8713042, 0.4251390, 34.1379890>,
    <1.8651054, 0.4666744, 34.1472010>,
    <1.8806421, 0.4021226, 34.1481994>,
    <1.8334044, 0.5666885, 34.1379890>,
    <1.8498791, 0.5240959, 34.1481994>,
    <1.8621856, -0.4416723, 34.1211611>,
    <1.8533906, -0.4970382, 34.1379890>,
    <1.8039364, -0.6569970, 34.1380150>,
    <1.8457381, -0.4949848, 34.1125260>,
    <1.8586083, -0.4658897, 34.1286034>,
    <1.8331664, -0.5674709, 34.1379890>,
    <1.8287624, -0.5661298, 34.1237934>,
    <1.8552995, -0.4650611, 34.1174128>,
    <1.8427036, -0.5229772, 34.1275355>,
    <1.8604022, -0.4234525, 34.1010718>,
    <1.8720165, -0.3939497, 34.1174128>,
    <1.8678971, -0.4001920, 34.1081947>,
    <1.8711191, -0.4259356, 34.1379890>,
    <1.8734258, -0.4013817, 34.1275355>,
    <1.8443421, -0.5527115, 34.1542153>,
    <1.8124433, -0.6601750, 34.1620860>,
    <1.8525356, -0.5296006, 34.1576891>,
    <1.8166211, -0.6617188, 34.1722289>,
    <1.8312899, -0.5999844, 34.1576891>,
    <1.8366511, -0.5944080, 34.1659804>,
    <1.8084704, -0.6587044, 34.1516897>,
    <1.8485659, -0.5284009, 34.1472010>,
    <1.8297451, -0.5920727, 34.1481994>,
    <1.8640903, -0.4710592, 34.1481994>,
    <1.8559712, -0.7485298, 34.2989756>,
    <1.8321795, -0.7951526, 34.2975521>,
    <1.8082399, -0.8667735, 34.3035582>,
    <1.8498514, -0.7816320, 34.3035582>,
    <1.8460752, -0.7668376, 34.2980080>,
    <1.8202297, -0.8319422, 34.3007100>,
    <1.8280939, -0.8253665, 34.3035582>,
    <1.8533835, -0.7629590, 34.3008727>,
    <1.8362086, -0.7987050, 34.3007914>,
    <1.8728779, -0.7363458, 34.3035582>,
    <1.8683821, -0.7157726, 34.2980080>,
    <1.8719677, -0.7222446, 34.3007914>,
    <1.8440490, -0.7544464, 34.2937748>,
    <1.8594455, -0.7245587, 34.2951914>,
    <1.8335362, 0.5485933, 34.1211611>,
    <1.8459485, 0.4941997, 34.1125260>,
    <1.8425469, 0.5258319, 34.1286034>,
    <1.8668196, 0.4240984, 34.1237934>,
    <1.8392670, 0.5248950, 34.1174128>,
    <1.8573167, 0.4684402, 34.1275355>,
    <1.7904268, 0.6513763, 34.0861253>,
    <1.7964826, 0.6534980, 34.1125260>,
    <1.8228818, 0.5634805, 34.1010718>,
    <1.7935787, 0.6524680, 34.1010718>,
    <1.8181887, 0.5948378, 34.1174128>,
    <1.8177423, 0.5873721, 34.1081947>,
    <1.7996124, 0.6546113, 34.1237934>,
    <1.8231252, 0.5891061, 34.1275355>,
    <1.8576097, 0.4398518, 34.1038334>,
    <1.8528229, 0.4636708, 34.1076575>,
    <1.8694762, 0.3927091, 34.1076575>,
    <1.8704401, 0.3999738, 34.1168389>,
    <1.8394595, 0.4925919, 34.0861074>,
    <1.8570305, 0.4220258, 34.0861074>,
    <1.8499148, 0.4630003, 34.0961373>,
    <1.8652256, 0.3989470, 34.0972345>,
    <1.8194113, 0.5624950, 34.0861074>,
    <1.8347031, 0.5199340, 34.0972345>,
    <1.8496061, -0.4385819, 34.0680823>,
    <1.8393146, -0.4931327, 34.0861074>,
    <1.7902431, -0.6518810, 34.0861253>,
    <1.8335716, -0.4917061, 34.0592183>,
    <1.8454706, -0.4624635, 34.0759583>,
    <1.8192485, -0.5630302, 34.0861074>,
    <1.8163397, -0.5621283, 34.0708032>,
    <1.8429175, -0.4618895, 34.0642124>,
    <1.8297948, -0.5191688, 34.0748134>,
    <1.8469593, -0.4206848, 34.0484530>,
    <1.8595190, -0.3912463, 34.0642124>,
    <1.8550889, -0.3975516, 34.0551646>,
    <1.8569039, -0.4225707, 34.0861074>,
    <1.8602894, -0.3984402, 34.0748134>,
    <1.8286630, -0.5478820, 34.1038334>,
    <1.7962460, -0.6541482, 34.1125260>,
    <1.8364271, -0.5248608, 34.1076575>,
    <1.7993591, -0.6553072, 34.1237934>,
    <1.8153685, -0.5946421, 34.1076575>,
    <1.8198356, -0.5888326, 34.1168389>,
    <1.7933593, -0.6530706, 34.1010718>,
    <1.8335734, -0.5239874, 34.0961373>,
    <1.8148062, -0.5871146, 34.0972345>,
    <1.8488665, -0.4670755, 34.0972345>,
    <1.8357324, 0.5490667, 34.1894897>,
    <1.8470037, 0.4942750, 34.1809181>,
    <1.8409661, 0.5251888, 34.1857817>,
    <1.8694134, 0.4244880, 34.1920745>,
    <1.8457564, 0.5265717, 34.1968260>,
    <1.8604055, 0.4690307, 34.1957715>,
    <1.7975174, 0.6536932, 34.1809181>,
    <1.8021293, 0.6553464, 34.1920745>,
    <1.8198714, 0.5952093, 34.1857817>,
    <1.8261631, 0.5899165, 34.1957715>,
    <1.7880708, 0.6503449, 34.1544411>,
    <1.7931299, 0.6521233, 34.1694828>,
    <1.8224244, 0.5631342, 34.1694828>,
    <1.8182150, 0.5873318, 34.1766071>,
    <1.8574927, 0.4396425, 34.1722608>,
    <1.8698671, 0.3926172, 34.1760819>,
    <1.8532205, 0.4635806, 34.1760819>,
    <1.8720829, 0.4001376, 34.1852017>,
    <1.8370261, 0.4917636, 34.1544124>,
    <1.8170103, 0.5615742, 34.1544124>,
    <1.8487790, 0.4625401, 34.1645454>,
    <1.8337298, 0.5194669, 34.1656437>,
    <1.8545678, 0.4212914, 34.1544124>,
    <1.8642196, 0.3985640, 34.1656437>,
    <1.8449337, -0.4376224, 34.1359011>,
    <1.8283753, -0.4903745, 34.1264018>,
    <1.7877754, -0.6511566, 34.1544411>,
    <1.8367930, -0.4926333, 34.1544124>,
    <1.8379924, -0.4607655, 34.1317777>,
    <1.8119040, -0.5609596, 34.1387967>,
    <1.8167485, -0.5624349, 34.1544124>,
    <1.8416321, -0.4616769, 34.1440880>,
    <1.8258366, -0.5182364, 34.1429132>,
    <1.8543641, -0.4221677, 34.1544124>,
    <1.8545558, -0.3903144, 34.1317777>,
    <1.8562816, -0.3977491, 34.1429132>,
    <1.8425756, -0.4194362, 34.1138015>,
    <1.8502000, -0.3964403, 34.1216372>,
    <1.8284571, -0.5480048, 34.1722608>,
    <1.7971641, -0.6546639, 34.1809181>,
    <1.8156610, -0.5949172, 34.1760819>,
    <1.8017597, -0.6563620, 34.1920745>,
    <1.8367263, -0.5251377, 34.1760819>,
    <1.8213401, -0.5895121, 34.1852017>,
    <1.8323596, -0.5238180, 34.1645454>,
    <1.8477900, -0.4669934, 34.1656437>,
    <1.7927940, -0.6530462, 34.1694828>,
    <1.8137435, -0.5869433, 34.1656437>,
    <1.8210948, 0.5449816, 34.0680823>,
    <1.8337644, 0.4909625, 34.0592183>,
    <1.8294561, 0.5222301, 34.0759583>,
    <1.8540605, 0.4213525, 34.0708032>,
    <1.8269536, 0.5214543, 34.0642124>,
    <1.8442331, 0.4652840, 34.0748134>,
    <1.7720149, 0.6456495, 34.0361559>,
    <1.7846096, 0.6492283, 34.0592183>,
    <1.8098230, 0.5591826, 34.0484530>,
    <1.7807226, 0.6475688, 34.0484530>,
    <1.8060093, 0.5909339, 34.0642124>,
    <1.8053118, 0.5832694, 34.0551646>,
    <1.7873001, 0.6502708, 34.0708032>,
    <1.8102779, 0.5850854, 34.0748134>,
    <1.8452163, 0.4368182, 34.0506060>,
    <1.8409080, 0.4606836, 34.0541438>,
    <1.8574450, 0.3902023, 34.0541438>,
    <1.8583897, 0.3975410, 34.0633523>,
    <1.8211437, 0.4875131, 34.0364647>,
    <1.8377604, 0.4193598, 34.0364059>,
    <1.8361389, 0.4592036, 34.0438443>,
    <1.8514510, 0.3956890, 34.0448606>,
    <1.8011987, 0.5560618, 34.0364059>,
    <1.8211808, 0.5157643, 34.0448606>,
    <1.8163183, -0.4256800, 34.0264558>,
    <1.8209613, -0.4884969, 34.0364647>,
    <1.7725069, -0.6446042, 34.0361559>,
    <1.7936016, -0.4595836, 34.0228405>,
    <1.8198753, -0.4549751, 34.0303723>,
    <1.8012765, -0.5558313, 34.0364059>,
    <1.7865873, -0.5391087, 34.0277741>,
    <1.8075488, -0.4393645, 34.0246615>,
    <1.8041213, -0.5030613, 34.0296825>,
    <1.7970033, -0.3798949, 34.0186848>,
    <1.8205516, -0.3825101, 34.0246615>,
    <1.8093059, -0.3793175, 34.0213137>,
    <1.8379641, -0.4191632, 34.0364059>,
    <1.8316111, -0.3939001, 34.0296825>,
    <1.8164223, -0.5443358, 34.0506060>,
    <1.7844100, -0.6498007, 34.0592183>,
    <1.8246197, -0.5215026, 34.0541438>,
    <1.7871373, -0.6507181, 34.0708032>,
    <1.8037005, -0.5908097, 34.0541438>,
    <1.8081832, -0.5849142, 34.0633523>,
    <1.7803773, -0.6486138, 34.0484530>,
    <1.8197650, -0.5204399, 34.0438443>,
    <1.8012672, -0.5830981, 34.0448606>,
    <1.8350902, -0.4639749, 34.0448606>,
    <1.7855196, 0.5397492, 34.0264558>,
    <1.7826615, 0.4991395, 34.0228405>,
    <1.8033511, 0.5160742, 34.0303723>,
    <1.8165018, 0.4266392, 34.0277741>,
    <1.7847127, 0.5235572, 34.0246615>,
    <1.8137263, 0.4665731, 34.0296825>,
    <1.7402494, 0.6328137, 34.0228405>,
    <1.7455887, 0.5699928, 34.0186848>,
    <1.7253781, 0.6292625, 34.0186848>,
    <1.7675460, 0.5792963, 34.0246615>,
    <1.7560838, 0.5765402, 34.0213137>,
    <1.7539019, 0.6392699, 34.0277741>,
    <1.7829524, 0.5748546, 34.0296825>,
    <1.7908421, 0.4294047, 34.0204813>,
    <1.7873231, 0.4612328, 34.0215203>,
    <1.8066353, 0.3804654, 34.0215203>,
    <1.8141014, 0.3965604, 34.0248083>,
    <1.7586825, 0.4705544, 34.0159774>,
    <1.7793144, 0.3935561, 34.0159774>,
    <1.7780797, 0.4463970, 34.0185671>,
    <1.7942137, 0.3824827, 34.0186456>,
    <1.7380507, 0.5475526, 34.0159774>,
    <1.7622585, 0.5086952, 34.0186456>,
    <1.7658621, -0.5241788, 34.0204813>,
    <1.7400780, -0.6345598, 34.0228405>,
    <1.7787091, -0.4948046, 34.0215203>,
    <1.7546146, -0.6381401, 34.0277741>,
    <1.7550503, -0.5744083, 34.0215203>,
    <1.7695116, -0.5640677, 34.0248083>,
    <1.7586855, -0.4727198, 34.0159774>,
    <1.7264855, -0.6280072, 34.0186848>,
    <1.7380541, -0.5497196, 34.0159774>,
    <1.7633461, -0.5031862, 34.0185671>,
    <1.7453595, -0.5666009, 34.0186456>,
    <1.7793170, -0.3957201, 34.0159774>,
    <1.7807918, -0.4413182, 34.0186456>,
    <1.8165706, 0.5434748, 34.1359011>,
    <1.8286067, 0.4895109, 34.1264018>,
    <1.8221308, 0.5199616, 34.1317777>,
    <1.8496347, 0.4201467, 34.1387967>,
    <1.8257387, 0.5209922, 34.1440880>,
    <1.8403391, 0.4641125, 34.1429132>,
    <1.7796073, 0.6473192, 34.1264018>,
    <1.7830501, 0.6485438, 34.1387967>,
    <1.8012496, 0.5892558, 34.1317777>,
    <1.8064616, 0.5836801, 34.1429132>,
    <1.7729147, 0.6449738, 34.0973598>,
    <1.7764130, 0.6461862, 34.1138015>,
    <1.8054354, 0.5580454, 34.1138015>,
    <1.8005404, 0.5817727, 34.1216372>,
    <1.8399001, 0.4356198, 34.1168394>,
    <1.8517615, 0.3889497, 34.1210460>,
    <1.8352681, 0.4592362, 34.1210460>,
    <1.8529974, 0.3962004, 34.1311462>,
    <1.8214688, 0.4877423, 34.0973402>,
    <1.8016177, 0.5569613, 34.0973402>,
    <1.8320692, 0.4584986, 34.1083733>,
    <1.8170361, 0.5148887, 34.1095803>,
    <1.8388667, 0.4178668, 34.0973402>,
    <1.8472614, 0.3950708, 34.1095803>,
    <1.8311175, -0.4342244, 34.0775018>,
    <1.8150795, -0.4867756, 34.0677166>,
    <1.7727126, -0.6455290, 34.0973598>,
    <1.8213094, -0.4883372, 34.0973402>,
    <1.8244202, -0.4572802, 34.0732308>,
    <1.7982390, -0.5565579, 34.0805061>,
    <1.8014387, -0.5575501, 34.0973402>,
    <1.8271805, -0.4579081, 34.0861763>,
    <1.8116369, -0.5140470, 34.0849170>,
    <1.8387274, -0.4184663, 34.0973402>,
    <1.8408567, -0.3873441, 34.0732308>,
    <1.8418315, -0.3945134, 34.0849170>,
    <1.8281381, -0.4164224, 34.0557354>,
    <1.8363034, -0.3935498, 34.0632019>,
    <1.8112101, -0.5426923, 34.1168394>,
    <1.7793470, -0.6480343, 34.1264018>,
    <1.7981473, -0.5890405, 34.1210460>,
    <1.7827716, -0.6493092, 34.1387967>,
    <1.8190069, -0.5199239, 34.1210460>,
    <1.8028430, -0.5833791, 34.1311462>,
    <1.8158678, -0.5189632, 34.1083733>,
    <1.8310438, -0.4626114, 34.1095803>,
    <1.7761717, -0.6468490, 34.1138015>,
    <1.7973107, -0.5814894, 34.1095803>,
    <1.8029045, 0.5395110, 34.0775018>,
    <1.8152845, 0.4859864, 34.0677166>,
    <1.8086298, 0.5161975, 34.0732308>,
    <1.8355996, 0.4171262, 34.0805061>,
    <1.8113388, 0.5170302, 34.0861763>,
    <1.8259471, 0.4606407, 34.0849170>,
    <1.7666263, 0.6426612, 34.0677166>,
    <1.7695066, 0.6437691, 34.0805061>,
    <1.7878961, 0.5849822, 34.0732308>,
    <1.7923295, 0.5792572, 34.0849170>,
    <1.7551847, 0.6377632, 34.0420193>,
    <1.7625884, 0.6409523, 34.0557354>,
    <1.7913922, 0.5534634, 34.0557354>,
    <1.7870421, 0.5773422, 34.0632019>,
    <1.8264638, 0.4323558, 34.0581798>,
    <1.8386324, 0.3862269, 34.0621232>,
    <1.8222642, 0.4559927, 34.0621232>,
    <1.8397418, 0.3935243, 34.0723106>,
    <1.8028243, 0.4819571, 34.0422290>,
    <1.7831934, 0.5505204, 34.0422290>,
    <1.8173577, 0.4544864, 34.0506039>,
    <1.8025712, 0.5104719, 34.0517365>,
    <1.8200410, 0.4127498, 34.0422290>,
    <1.8325302, 0.3916259, 34.0517365>,
    <1.7987169, -0.4288234, 34.0309305>,
    <1.7744295, -0.4800018, 34.0269691>,
    <1.7545412, -0.6398150, 34.0420193>,
    <1.8023168, -0.4841462, 34.0422290>,
    <1.7887548, -0.4513480, 34.0289563>,
    <1.7680354, -0.5491232, 34.0327086>,
    <1.7826232, -0.5526899, 34.0422290>,
    <1.8014961, -0.4529349, 34.0352527>,
    <1.7850514, -0.5081347, 34.0346796>,
    <1.8195975, -0.4149532, 34.0422290>,
    <1.8049417, -0.3826987, 34.0289563>,
    <1.8149126, -0.3901946, 34.0346796>,
    <1.7780381, -0.4147058, 34.0224156>,
    <1.7923540, -0.3901862, 34.0249273>,
    <1.7979509, -0.5388243, 34.0581798>,
    <1.7664128, -0.6432720, 34.0677166>,
    <1.7854206, -0.5848464, 34.0621232>,
    <1.7693275, -0.6442612, 34.0805061>,
    <1.8061282, -0.5162432, 34.0621232>,
    <1.7900253, -0.5790689, 34.0723106>,
    <1.8011414, -0.5151349, 34.0506039>,
    <1.8163275, -0.4592537, 34.0517365>,
    <1.7622327, -0.6420260, 34.0557354>,
    <1.7828497, -0.5771569, 34.0517365>,
    <1.7718002, 0.5284124, 34.0309305>,
    <1.7760380, 0.4715688, 34.0268940>,
    <1.7742924, 0.5042224, 34.0289563>,
    <1.8044179, 0.4084601, 34.0324084>,
    <1.7864251, 0.5086436, 34.0352527>,
    <1.7997705, 0.4526273, 34.0346796>,
    <1.7285128, 0.6261832, 34.0269691>,
    <1.7405672, 0.6318098, 34.0327086>,
    <1.7539859, 0.5717678, 34.0289563>,
    <1.7666610, 0.5696970, 34.0346796>,
    <1.7174975, 0.6192540, 34.0224156>,
    <1.7465762, 0.5294639, 34.0224156>,
    <1.7461799, 0.5604990, 34.0249273>,
    <1.7799662, 0.4032314, 34.0226829>,
    <1.7884533, 0.3648928, 34.0230322>,
    <1.7778888, 0.4371608, 34.0246044>,
    <1.7980880, 0.3829535, 34.0278873>,
    <1.7735274, 0.4047801, 34.0206226>,
    <1.7585079, 0.4722357, 34.0212444>,
    <1.7831868, 0.3430630, 34.0197592>,
    <1.7492991, -0.5315859, 34.0235084>,
    <1.7266448, -0.6323711, 34.0269467>,
    <1.7400955, -0.5745756, 34.0248897>,
    <1.7395847, -0.6352186, 34.0327086>,
    <1.7604001, -0.5080767, 34.0249046>,
    <1.7529050, -0.5692296, 34.0290881>,
    <1.7468847, -0.5131208, 34.0209790>,
    <1.7628825, -0.4583062, 34.0212444>,
    <1.7133641, -0.6319436, 34.0223261>,
    <1.7300420, -0.5712831, 34.0211848>,
    <1.7772344, 1.0066848, 34.2894179>,
    <1.7861388, 1.0018677, 34.2918022>,
    <1.8022561, 0.9673041, 34.2918022>,
    <1.7868977, 0.9828274, 34.2886794>,
    <1.7810985, 1.0047050, 34.2904043>,
    <1.7931970, 0.9867314, 34.2918022>,
    <1.7952175, 0.9744903, 34.2903196>,
    <1.7802929, 0.9980732, 34.2889155>,
    <1.7876343, 0.9909784, 34.2903620>,
    <1.7504792, 1.0222697, 34.2830970>,
    <1.7600207, 1.0325776, 34.2886794>,
    <1.7760155, 0.9934663, 34.2867239>,
    <1.7551253, 1.0311145, 34.2867239>,
    <1.7702686, 1.0169928, 34.2889155>,
    <1.7693939, 1.0108637, 34.2874565>,
    <1.7653373, 1.0320389, 34.2903196>,
    <1.7804147, 1.0141432, 34.2918022>,
    <1.7745020, 1.0170788, 34.2903620>,
    <1.8100035, 0.9377858, 34.2894179>,
    <1.8277886, 0.9125494, 34.2918021>,
    <1.7977714, 0.9611059, 34.2889155>,
    <1.8139832, 0.9421554, 34.2918022>,
    <1.8168036, 0.9286506, 34.2904043>,
    <1.8049561, 0.9538317, 34.2903620>,
    <1.8252944, 0.8985199, 34.2882666>,
    <1.8430829, 0.8797505, 34.2918019>,
    <1.8464275, 0.8647826, 34.2903405>,
    <1.8154181, 0.9232622, 34.2889155>,
    <1.8307134, 0.8985948, 34.2903618>,
    <1.7981282, 0.9437196, 34.2861106>,
    <1.7942712, 0.9595760, 34.2874565>,
    <1.8415090, 0.8549454, 34.2863579>,
    <1.8344384, 0.8740962, 34.2872643>,
    <1.8548037, 0.8306081, 34.2872641>,
    <1.8502207, 0.8490790, 34.2889215>,
    <1.8240027, 0.8721181, 34.2817250>,
    <1.8561668, 0.8033012, 34.2819690>,
    <1.8348171, 0.8605064, 34.2845089>,
    <1.8594202, 0.8092411, 34.2850029>,
    <1.7924622, 0.9376823, 34.2819691>,
    <1.8130150, 0.9080145, 34.2850030>,
    <1.8395515, -0.8591468, 34.2863567>,
    <1.8191518, -0.9120219, 34.2882644>,
    <1.8501519, -0.8403725, 34.2872628>,
    <1.8365165, -0.8860373, 34.2903378>,
    <1.8297702, -0.8843266, 34.2872627>,
    <1.8419705, -0.8667719, 34.2889196>,
    <1.7622139, -1.0020187, 34.2830967>,
    <1.8407842, -0.8361415, 34.2817246>,
    <1.7982588, -0.9447561, 34.2861091>,
    <1.8090488, -0.9045478, 34.2819686>,
    <1.8389883, -0.8515691, 34.2845081>,
    <1.8159086, -0.9026867, 34.2850020>,
    <1.8709424, -0.7692258, 34.2819686>,
    <1.8617990, -0.8032933, 34.2850021>,
    <1.8033440, -0.9521647, 34.2894147>,
    <1.8181351, -0.9332514, 34.2917976>,
    <1.8087639, -0.9377518, 34.2889127>,
    <1.8320789, -0.9033488, 34.2917981>,
    <1.8087434, -0.9459356, 34.2904005>,
    <1.8214951, -0.9183636, 34.2903586>,
    <1.7966730, -0.9792769, 34.2917974>,
    <1.7839848, -0.9893742, 34.2886767>,
    <1.8063028, -0.9586259, 34.2917973>,
    <1.7905440, -0.9845126, 34.2903158>,
    <1.7929603, -0.9716426, 34.2889125>,
    <1.7985418, -0.9675871, 34.2903580>,
    <1.7765654, -0.9934876, 34.2867223>,
    <1.7917377, -0.9658868, 34.2874544>,
    <1.8491413, -0.7941381, 34.2751874>,
    <1.8192314, -0.8479205, 34.2713545>,
    <1.8449418, -0.8149061, 34.2783020>,
    <1.7941267, -0.9169600, 34.2765462>,
    <1.8360663, -0.8186317, 34.2735942>,
    <1.8178537, -0.8726056, 34.2779935>,
    <1.8433696, -0.7762357, 34.2658251>,
    <1.8662839, -0.7479892, 34.2735942>,
    <1.8574297, -0.7543975, 34.2692880>,
    <1.8716127, -0.7518615, 34.2779935>,
    <1.7751465, -1.0109502, 34.2894157>,
    <1.7837211, -1.0070526, 34.2917992>,
    <1.7781850, -1.0026968, 34.2889131>,
    <1.7893369, -0.9950093, 34.2917981>,
    <1.7788818, -1.0093425, 34.2904018>,
    <1.7844036, -0.9979066, 34.2903587>,
    <1.7578101, -1.0359059, 34.2886787>,
    <1.7792520, -1.0166365, 34.2918006>,
    <1.7628241, -1.0359581, 34.2903190>,
    <1.7686476, -1.0199919, 34.2889140>,
    <1.7727398, -1.0203935, 34.2903605>,
    <1.7556736, -1.0297849, 34.2867232>,
    <1.7693957, -1.0112729, 34.2874551>,
    <1.8014865, -0.8683407, 34.2989756>,
    <1.7888750, -0.8896003, 34.2967794>,
    <1.7755111, -0.9410533, 34.3035582>,
    <1.7969004, -0.8757449, 34.2980080>,
    <1.7634026, -0.9614569, 34.3007507>,
    <1.7613674, -0.9754778, 34.3035582>,
    <1.7911353, -0.8975626, 34.3008727>,
    <1.7778506, -0.9285312, 34.3007914>,
    <1.7909238, -0.9050772, 34.3035582>,
    <1.8163509, -0.8316944, 34.2980080>,
    <1.8052335, -0.8651305, 34.3007914>,
    <1.8179402, -0.8095007, 34.2926777>,
    <1.8210836, -0.8112792, 34.2951914>,
    <1.7970029, 0.9059458, 34.2751874>,
    <1.8189960, 0.8483750, 34.2713545>,
    <1.8102786, 0.8892339, 34.2783022>,
    <1.8559615, 0.7841532, 34.2765462>,
    <1.8073568, 0.8801659, 34.2735942>,
    <1.8371399, 0.8311119, 34.2779937>,
    <1.7258783, 0.9956511, 34.2582471>,
    <1.7386559, 1.0041634, 34.2713545>,
    <1.7795262, 0.9131484, 34.2658251>,
    <1.7330654, 0.9997437, 34.2658251>,
    <1.7726878, 0.9487324, 34.2735942>,
    <1.7718348, 0.9379563, 34.2692880>,
    <1.7437164, 1.0106927, 34.2765463>,
    <1.7792918, 0.9499480, 34.2779937>,
    <1.8386437, 0.7924511, 34.2672347>,
    <1.8304570, 0.8169439, 34.2690979>,
    <1.8605715, 0.7466661, 34.2690979>,
    <1.8628295, 0.7569287, 34.2734378>,
    <1.8051741, 0.8409843, 34.2582019>,
    <1.8360732, 0.7714926, 34.2582019>,
    <1.8242699, 0.8137446, 34.2634197>,
    <1.8520154, 0.7505929, 34.2639559>,
    <1.7718440, 0.9093448, 34.2582019>,
    <1.7985557, 0.8698371, 34.2639559>,
    <1.8197270, -0.7856574, 34.2481381>,
    <1.8045749, -0.8422693, 34.2582019>,
    <1.7251982, -0.9968289, 34.2582471>,
    <1.7913561, -0.8361922, 34.2427102>,
    <1.8134236, -0.8104520, 34.2526827>,
    <1.7712027, -0.9106078, 34.2582019>,
    <1.7638072, -0.9068999, 34.2497196>,
    <1.8076260, -0.8079038, 34.2458152>,
    <1.7866525, -0.8657708, 34.2520259>,
    <1.8164468, -0.7648178, 34.2353389>,
    <1.8374715, -0.7383975, 34.2458152>,
    <1.8299596, -0.7431672, 34.2399571>,
    <1.8355179, -0.7727957, 34.2582019>,
    <1.8399291, -0.7471588, 34.2520259>,
    <1.7889428, -0.8990499, 34.2672347>,
    <1.7390693, -1.0034522, 34.2713545>,
    <1.8024840, -0.8769659, 34.2690979>,
    <1.7475853, -1.0040113, 34.2765462>,
    <1.7680053, -0.9452086, 34.2690979>,
    <1.7775391, -0.9399691, 34.2734378>,
    <1.7323362, -1.0010068, 34.2658251>,
    <1.7959826, -0.8744069, 34.2634197>,
    <1.7654401, -0.9362543, 34.2639559>,
    <1.8224232, -0.8186531, 34.2639559>,
    <1.7708696, 0.9402148, 34.2989756>,
    <1.7924673, 0.8916636, 34.2975521>,
    <1.7946678, 0.9134158, 34.3035582>,
    <1.7792294, 0.9206757, 34.2980080>,
    <1.8167358, 0.8566979, 34.3007100>,
    <1.8186488, 0.8658869, 34.3035582>,
    <1.7812838, 0.9286574, 34.3008727>,
    <1.8002174, 0.8911846, 34.3007914>,
    <1.7254561, 1.0117704, 34.2967794>,
    <1.7706867, 0.9609446, 34.3035582>,
    <1.7363480, 1.0103451, 34.3007507>,
    <1.7521153, 0.9709395, 34.2980080>,
    <1.7593412, 0.9694187, 34.3007914>,
    <1.7247888, 0.9815621, 34.2867877>,
    <1.7216174, 1.0044320, 34.2926777>,
    <1.7661982, 0.9276361, 34.2937748>,
    <1.7531283, 0.9585539, 34.2951914>,
    <1.8280132, 0.8216822, 34.2989756>,
    <1.8330777, 0.7985454, 34.2967794>,
    <1.8695843, 0.7543209, 34.3035582>,
    <1.8291831, 0.8136189, 34.2980080>,
    <1.8713301, 0.7328277, 34.3007507>,
    <1.8830616, 0.7223023, 34.3035582>,
    <1.8448532, 0.7947168, 34.3008727>,
    <1.8575427, 0.7651040, 34.3007914>,
    <1.8561071, 0.7863395, 34.3035582>,
    <1.8100228, 0.8563392, 34.2980080>,
    <1.8314326, 0.8248951, 34.3007914>,
    <1.7901509, 0.8722895, 34.2926777>,
    <1.7951423, 0.8735604, 34.2951914>,
    <1.8342365, 0.7802794, 34.2933120>,
    <1.8524933, 0.7446674, 34.2949171>,
    <1.8332369, 0.7895764, 34.2949171>,
    <1.8613724, 0.7401493, 34.2980246>,
    <1.7968670, 0.8346530, 34.2854038>,
    <1.7664243, 0.8985288, 34.2856693>,
    <1.8169583, 0.8058543, 34.2900253>,
    <1.7984083, 0.8482574, 34.2908029>,
    <1.8278421, 0.7660997, 34.2856693>,
    <1.8428446, 0.7494706, 34.2908029>,
    <1.8094651, -0.7817240, 34.2753407>,
    <1.7807668, -0.8320887, 34.2695801>,
    <1.7122303, -1.0024188, 34.2867877>,
    <1.7943002, -0.8398526, 34.2854038>,
    <1.7972501, -0.8038407, 34.2729301>,
    <1.7532080, -0.9045813, 34.2772285>,
    <1.7616245, -0.9075044, 34.2856693>,
    <1.8033189, -0.8069602, 34.2800513>,
    <1.7763221, -0.8628436, 34.2795037>,
    <1.8235653, -0.7753697, 34.2856693>,
    <1.8270053, -0.7347394, 34.2729301>,
    <1.8296128, -0.7449321, 34.2795037>,
    <1.8053724, -0.7602413, 34.2614925>,
    <1.8191762, -0.7388693, 34.2665723>,
    <1.7763877, -0.9030412, 34.2933120>,
    <1.7386072, -0.9872420, 34.2967794>,
    <1.7607725, -0.9397307, 34.2949171>,
    <1.7433773, -0.9980003, 34.3007507>,
    <1.7827145, -0.8961754, 34.2949171>,
    <1.7629291, -0.9494020, 34.2980246>,
    <1.7850724, -0.8736430, 34.2900253>,
    <1.8054296, -0.8319744, 34.2908029>,
    <1.7302294, -0.9876463, 34.2926777>,
    <1.7583894, -0.9294491, 34.2908029>,
    <1.7715464, 0.8889809, 34.2481381>,
    <1.7920219, 0.8347644, 34.2427102>,
    <1.7864884, 0.8682146, 34.2526827>,
    <1.8284790, 0.7682107, 34.2497196>,
    <1.7808098, 0.8654114, 34.2458152>,
    <1.8116570, 0.8121485, 34.2520259>,
    <1.7013025, 0.9815528, 34.2254060>,
    <1.7130105, 0.9882328, 34.2427102>,
    <1.7534739, 0.8998635, 34.2353389>,
    <1.7076942, 0.9851827, 34.2353389>,
    <1.7467492, 0.9329520, 34.2458152>,
    <1.7455745, 0.9241317, 34.2399571>,
    <1.7184578, 0.9913608, 34.2497196>,
    <1.7550404, 0.9292031, 34.2520259>,
    <1.8116050, 0.7806420, 34.2371711>,
    <1.8033667, 0.8044163, 34.2396408>,
    <1.8330401, 0.7351744, 34.2396408>,
    <1.8348873, 0.7436067, 34.2454279>,
    <1.7794793, 0.8290929, 34.2253660>,
    <1.8099411, 0.7605906, 34.2253660>,
    <1.7978016, 0.8020106, 34.2321345>,
    <1.8250957, 0.7397512, 34.2328481>,
    <1.7466212, 0.8964799, 34.2253660>,
    <1.7724053, 0.8572689, 34.2328481>,
    <1.7948671, -0.7748336, 34.2126378>,
    <1.7789493, -0.8302296, 34.2253660>,
    <1.7007009, -0.9825947, 34.2254060>,
    <1.7674137, -0.8249088, 34.2059260>,
    <1.7882074, -0.7990981, 34.2183311>,
    <1.7460539, -0.8975971, 34.2253660>,
    <1.7395697, -0.8943364, 34.2146338>,
    <1.7831600, -0.7968721, 34.2097470>,
    <1.7618764, -0.8536720, 34.2175110>,
    <1.7928888, -0.7547905, 34.1969055>,
    <1.8125954, -0.7283126, 34.2097470>,
    <1.8057661, -0.7332428, 34.2025384>,
    <1.8094498, -0.7617433, 34.2253660>,
    <1.8144048, -0.7367135, 34.2175110>,
    <1.7624837, -0.8859829, 34.2371711>,
    <1.7123400, -0.9893942, 34.2427102>,
    <1.7754004, -0.8643902, 34.2396408>,
    <1.7177725, -0.9925477, 34.2497196>,
    <1.7414317, -0.9316292, 34.2396408>,
    <1.7490786, -0.9276240, 34.2454279>,
    <1.7070403, -0.9863152, 34.2353389>,
    <1.7699803, -0.8616734, 34.2321345>,
    <1.7398312, -0.9226015, 34.2328481>,
    <1.7959863, -0.8066994, 34.2328481>,
    <1.7619645, 0.8836454, 34.2753407>,
    <1.7821196, 0.8292823, 34.2695801>,
    <1.7710597, 0.8600693, 34.2729301>,
    <1.8200812, 0.7615498, 34.2772285>,
    <1.7773801, 0.8627121, 34.2800513>,
    <1.8029020, 0.8060953, 34.2795037>,
    <1.7036514, 0.9819529, 34.2695801>,
    <1.7110140, 0.9837882, 34.2772285>,
    <1.7372491, 0.9272848, 34.2729301>,
    <1.7468225, 0.9227272, 34.2795037>,
    <1.6902869, 0.9751235, 34.2505667>,
    <1.6973465, 0.9791330, 34.2614925>,
    <1.7428497, 0.8943218, 34.2614925>,
    <1.7353506, 0.9186337, 34.2665723>,
    <1.8008716, 0.7757110, 34.2635082>,
    <1.8225167, 0.7303749, 34.2662252>,
    <1.7930230, 0.7992047, 34.2662252>,
    <1.8256106, 0.7377486, 34.2725930>,
    <1.7679544, 0.8236496, 34.2505227>,
    <1.7353116, 0.8905998, 34.2505227>,
    <1.7866479, 0.7969594, 34.2579678>,
    <1.7614689, 0.8518966, 34.2587527>,
    <1.7982162, 0.7555913, 34.2505227>,
    <1.8138259, 0.7351117, 34.2587527>,
    <1.7823473, -0.7695000, 34.2365221>,
    <1.7546822, -0.8190470, 34.2291393>,
    <1.6896252, -0.9762696, 34.2505667>,
    <1.7673714, -0.8248999, 34.2505227>,
    <1.7705421, -0.7913071, 34.2333423>,
    <1.7275550, -0.8882420, 34.2387176>,
    <1.7346876, -0.8918287, 34.2505227>,
    <1.7760943, -0.7937557, 34.2427845>,
    <1.7498871, -0.8479400, 34.2418824>,
    <1.7976758, -0.7568593, 34.2505227>,
    <1.7997740, -0.7232280, 34.2333423>,
    <1.8020658, -0.7317703, 34.2418824>,
    <1.7794587, -0.7492113, 34.2192172>,
    <1.7925633, -0.7279525, 34.2254131>,
    <1.7517998, -0.8809179, 34.2635082>,
    <1.7022091, -0.9843962, 34.2695801>,
    <1.7309744, -0.9266250, 34.2662252>,
    <1.7074415, -0.9897567, 34.2772285>,
    <1.7647429, -0.8597886, 34.2662252>,
    <1.7385624, -0.9241718, 34.2725930>,
    <1.7589415, -0.8563760, 34.2579678>,
    <1.7848411, -0.8017749, 34.2587527>,
    <1.6966273, -0.9803787, 34.2614925>,
    <1.7290331, -0.9169505, 34.2587527>,
    <1.7472753, 0.8768945, 34.2126378>,
    <1.7679884, 0.8236763, 34.2059260>,
    <1.7615822, 0.8561960, 34.2183311>,
    <1.8032753, 0.7577193, 34.2146338>,
    <1.7566325, 0.8537603, 34.2097470>,
    <1.7864630, 0.8009458, 34.2175110>,
    <1.6800736, 0.9694081, 34.1849198>,
    <1.6900347, 0.9750736, 34.2059260>,
    <1.7306498, 0.8882625, 34.1969055>,
    <1.6854670, 0.9724598, 34.1969055>,
    <1.7230336, 0.9203783, 34.2097470>,
    <1.7224206, 0.9119776, 34.2025384>,
    <1.6947642, 0.9777828, 34.2146338>,
    <1.7306322, 0.9163643, 34.2175110>,
    <1.7878560, 0.7705043, 34.1991181>,
    <1.7794832, 0.7938616, 34.2021355>,
    <1.8087701, 0.7255303, 34.2021355>,
    <1.8100197, 0.7336222, 34.2092829>,
    <1.7572864, 0.8188555, 34.1848862>,
    <1.7873715, 0.7512076, 34.1848862>,
    <1.7747222, 0.7918113, 34.1929998>,
    <1.8016003, 0.7303192, 34.1938690>,
    <1.7248347, 0.8854016, 34.1848862>,
    <1.7495779, 0.8463331, 34.1938690>,
    <1.7738112, -0.7656304, 34.1698789>,
    <1.7568417, -0.8198093, 34.1848862>,
    <1.6795689, -0.9702824, 34.1849198>,
    <1.7473397, -0.8154064, 34.1620860>,
    <1.7666718, -0.7893674, 34.1765488>,
    <1.7243587, -0.8863390, 34.1848862>,
    <1.7189827, -0.8836247, 34.1722289>,
    <1.7625277, -0.7875312, 34.1665078>,
    <1.7407430, -0.8433149, 34.1755900>,
    <1.7734115, -0.7464584, 34.1516897>,
    <1.7916149, -0.7197726, 34.1665078>,
    <1.7855841, -0.7249259, 34.1581668>,
    <1.7869593, -0.7521748, 34.1848862>,
    <1.7926295, -0.7277703, 34.1755900>,
    <1.7394522, -0.8743066, 34.1991181>,
    <1.6894559, -0.9760762, 34.2059260>,
    <1.7519630, -0.8528788, 34.2021355>,
    <1.6941668, -0.9788174, 34.2146338>,
    <1.7184435, -0.9192364, 34.2021355>,
    <1.7254455, -0.9149922, 34.2092829>,
    <1.6849084, -0.9734273, 34.1969055>,
    <1.7473321, -0.8505496, 34.1929998>,
    <1.7175034, -0.9106658, 34.1938690>,
    <1.7729357, -0.7962420, 34.1938690>,
    <1.7341191, 1.0741366, 34.2894179>,
    <1.7026175, 1.1147741, 34.2882666>,
    <1.6842931, 1.1550450, 34.2918022>,
    <1.7294049, 1.0906173, 34.2918022>,
    <1.7219016, 1.0897046, 34.2889155>,
    <1.6906058, 1.1402860, 34.2903408>,
    <1.7066914, 1.1230564, 34.2918022>,
    <1.7330993, 1.0797344, 34.2904043>,
    <1.7126628, 1.1088681, 34.2903620>,
    <1.7523286, 1.0578779, 34.2918022>,
    <1.7471257, 1.0531142, 34.2889155>,
    <1.7510970, 1.0535244, 34.2903620>,
    <1.7198234, 1.0811110, 34.2861106>,
    <1.7376752, 1.0605908, 34.2874565>,
    <1.7351420, 0.8707321, 34.2365221>,
    <1.7553144, 0.8176913, 34.2291393>,
    <1.7442589, 0.8476715, 34.2333423>,
    <1.7908838, 0.7524329, 34.2387176>,
    <1.7497036, 0.8503508, 34.2427845>,
    <1.7743655, 0.7954459, 34.2418824>,
    <1.6779211, 0.9680130, 34.2291393>,
    <1.6831236, 0.9709931, 34.2387176>,
    <1.7108972, 0.9138249, 34.2333423>,
    <1.7189142, 0.9100896, 34.2418824>,
    <1.6669352, 0.9617644, 34.2060335>,
    <1.6728967, 0.9651378, 34.2192172>,
    <1.7177432, 0.8815607, 34.2192172>,
    <1.7098814, 0.9052643, 34.2254131>,
    <1.7746351, 0.7647378, 34.2216509>,
    <1.7955663, 0.7201675, 34.2249699>,
    <1.7664977, 0.7879956, 34.2249699>,
    <1.7972423, 0.7283699, 34.2328318>,
    <1.7435422, 0.8123885, 34.2059966>,
    <1.7113465, 0.8784137, 34.2059966>,
    <1.7612606, 0.7857403, 34.2149211>,
    <1.7363588, 0.8398672, 34.2158771>,
    <1.7733897, 0.7452701, 34.2059966>,
    <1.7879810, 0.7247366, 34.2158771>,
    <1.7591859, -0.7593766, 34.1894897>,
    <1.7326008, -0.8085945, 34.1809181>,
    <1.6663800, -0.9627261, 34.2060335>,
    <1.7430530, -0.8134376, 34.2059966>,
    <1.7478467, -0.7810322, 34.1857817>,
    <1.7049094, -0.8764592, 34.1920745>,
    <1.7108229, -0.8794449, 34.2059966>,
    <1.7524052, -0.7830520, 34.1968260>,
    <1.7266405, -0.8365472, 34.1957715>,
    <1.7729363, -0.7463341, 34.2059966>,
    <1.7766956, -0.7138340, 34.1857817>,
    <1.7781131, -0.7219328, 34.1957715>,
    <1.7580337, -0.7400460, 34.1694828>,
    <1.7703631, -0.7188039, 34.1766071>,
    <1.7265366, -0.8678854, 34.2216509>,
    <1.6772844, -0.9691158, 34.2291393>,
    <1.7058480, -0.9125688, 34.2249699>,
    <1.6824665, -0.9721312, 34.2387176>,
    <1.7391225, -0.8467019, 34.2249699>,
    <1.7132088, -0.9085803, 34.2328318>,
    <1.7340285, -0.8441398, 34.2149211>,
    <1.7594855, -0.7902718, 34.2158771>,
    <1.6722822, -0.9662021, 34.2192172>,
    <1.7044724, -0.9038212, 34.2158771>,
    <1.7266909, 0.8666805, 34.1698789>,
    <1.7478059, 0.8144067, 34.1620860>,
    <1.7402853, 0.8459535, 34.1765488>,
    <1.7818367, 0.7488341, 34.1722289>,
    <1.7362150, 0.8439592, 34.1665078>,
    <1.7649448, 0.7914141, 34.1755900>,
    <1.6628369, 0.9595859, 34.1380150>,
    <1.6707395, 0.9640597, 34.1620860>,
    <1.7117473, 0.8786978, 34.1516897>,
    <1.6670593, 0.9619616, 34.1516897>,
    <1.7030057, 0.9097957, 34.1665078>,
    <1.7030768, 0.9018634, 34.1581668>,
    <1.6746075, 0.9662678, 34.1722289>,
    <1.7097845, 0.9054321, 34.1755900>,
    <1.7681242, 0.7621186, 34.1542153>,
    <1.7595453, 0.7850893, 34.1576891>,
    <1.7885121, 0.7175157, 34.1576891>,
    <1.7890345, 0.7252336, 34.1659804>,
    <1.7392696, 0.8105831, 34.1379890>,
    <1.7690502, 0.7436287, 34.1379890>,
    <1.7557332, 0.7834567, 34.1472010>,
    <1.7822431, 0.7225835, 34.1481994>,
    <1.7071465, 0.8764465, 34.1379890>,
    <1.7307670, 0.8373618, 34.1481994>,
    <1.7571993, -0.7583275, 34.1211611>,
    <1.7389236, -0.8113250, 34.1379890>,
    <1.6624443, -0.9602660, 34.1380150>,
    <1.7317440, -0.8079739, 34.1125260>,
    <1.7494710, -0.7815557, 34.1286034>,
    <1.7067763, -0.8771758, 34.1379890>,
    <1.7026720, -0.8750903, 34.1237934>,
    <1.7463563, -0.7801652, 34.1174128>,
    <1.7238947, -0.8350142, 34.1275355>,
    <1.7586068, -0.7400748, 34.1010718>,
    <1.7751677, -0.7130370, 34.1174128>,
    <1.7700269, -0.7184691, 34.1081947>,
    <1.7687296, -0.7443811, 34.1379890>,
    <1.7752651, -0.7206008, 34.1275355>,
    <1.7203451, -0.8645812, 34.1542153>,
    <1.6702700, -0.9648730, 34.1620860>,
    <1.7324272, -0.8432442, 34.1576891>,
    <1.6741162, -0.9671187, 34.1722289>,
    <1.6992823, -0.9088695, 34.1576891>,
    <1.7055304, -0.9043087, 34.1659804>,
    <1.6666129, -0.9627348, 34.1516897>,
    <1.7287262, -0.8413734, 34.1472010>,
    <1.6991349, -0.9008097, 34.1481994>,
    <1.7539720, -0.7875986, 34.1481994>,
    <1.7269571, -1.0843653, 34.2894177>,
    <1.7192522, -1.1051174, 34.2918021>,
    <1.6657415, -1.1815398, 34.2918019>,
    <1.6944155, -1.1262604, 34.2882665>,
    <1.7245834, -1.0919228, 34.2904043>,
    <1.6920105, -1.1440232, 34.2918020>,
    <1.6761427, -1.1609417, 34.2903406>,
    <1.7139099, -1.1009883, 34.2889154>,
    <1.7010009, -1.1255234, 34.2903619>,
    <1.7194157, -1.0807836, 34.2861104>,
    <1.7425699, -1.0596210, 34.2889152>,
    <1.7346562, -1.0643827, 34.2874563>,
    <1.7471422, -1.0652856, 34.2918022>,
    <1.7459816, -1.0609345, 34.2903618>,
    <1.7104185, 0.8586492, 34.1211611>,
    <1.7320875, 0.8072373, 34.1125260>,
    <1.7232447, 0.8377982, 34.1286034>,
    <1.7648144, 0.7418252, 34.1237934>,
    <1.7201774, 0.8363060, 34.1174128>,
    <1.7477561, 0.7838432, 34.1275355>,
    <1.6501159, 0.9523847, 34.0861253>,
    <1.6557113, 0.9555259, 34.1125260>,
    <1.6973408, 0.8714600, 34.1010718>,
    <1.6530303, 0.9540072, 34.1010718>,
    <1.6872738, 0.9015260, 34.1174128>,
    <1.6881306, 0.8940963, 34.1081947>,
    <1.6586002, 0.9571657, 34.1237934>,
    <1.6931306, 0.8967387, 34.1275355>,
    <1.7530089, 0.7557400, 34.1038334>,
    <1.7441588, 0.7783659, 34.1076575>,
    <1.7728814, 0.7113741, 34.1076575>,
    <1.7725692, 0.7186958, 34.1168389>,
    <1.7259763, 0.8045271, 34.0861074>,
    <1.7555340, 0.7380842, 34.0861074>,
    <1.7414113, 0.7772006, 34.0961373>,
    <1.7676122, 0.7167791, 34.0972345>,
    <1.6940941, 0.8698869, 34.0861074>,
    <1.7165443, 0.8306279, 34.0972345>,
    <1.7453479, -0.7531003, 34.0680823>,
    <1.7257397, -0.8050345, 34.0861074>,
    <1.6498473, -0.9528499, 34.0861253>,
    <1.7203335, -0.8026354, 34.0592183>,
    <1.7371278, -0.7759002, 34.0759583>,
    <1.6938408, -0.8703857, 34.0861074>,
    <1.6911329, -0.8689923, 34.0708032>,
    <1.7347141, -0.7748933, 34.0642124>,
    <1.7118433, -0.8290219, 34.0748134>,
    <1.7458560, -0.7350270, 34.0484530>,
    <1.7633305, -0.7082062, 34.0642124>,
    <1.7578759, -0.7136514, 34.0551646>,
    <1.7553147, -0.7385989, 34.0861074>,
    <1.7628390, -0.7154228, 34.0748134>,
    <1.7057428, -0.8571025, 34.1038334>,
    <1.6553653, -0.9561251, 34.1125260>,
    <1.7173866, -0.8357792, 34.1076575>,
    <1.6582299, -0.9578070, 34.1237934>,
    <1.6845304, -0.9008435, 34.1076575>,
    <1.6899385, -0.8958980, 34.1168389>,
    <1.6527097, -0.9545626, 34.1010718>,
    <1.7147278, -0.8344235, 34.0961373>,
    <1.6852839, -0.8933328, 34.0972345>,
    <1.7396713, -0.7810319, 34.0972345>,
    <1.7124991, 0.8594967, 34.1894897>,
    <1.7331137, 0.8074947, 34.1809181>,
    <1.7217996, 0.8368904, 34.1857817>,
    <1.7673013, 0.7426593, 34.1920745>,
    <1.7262770, 0.8390841, 34.1968260>,
    <1.7506955, 0.7849611, 34.1957715>,
    <1.6566965, 0.9558978, 34.1809181>,
    <1.6609512, 0.9583266, 34.1920745>,
    <1.6888665, 0.9021841, 34.1857817>,
    <1.6959817, 0.8980642, 34.1957715>,
    <1.6479748, 0.9509600, 34.1544411>,
    <1.6526482, 0.9535898, 34.1694828>,
    <1.6969504, 0.8710395, 34.1694828>,
    <1.6886032, 0.8941386, 34.1766071>,
    <1.7529301, 0.7555136, 34.1722608>,
    <1.7732824, 0.7113514, 34.1760819>,
    <1.7445660, 0.7783461, 34.1760819>,
    <1.7741586, 0.7191424, 34.1852017>,
    <1.7237237, 0.8032888, 34.1544124>,
    <1.6918895, 0.8685631, 34.1544124>,
    <1.7403726, 0.7765502, 34.1645454>,
    <1.7156668, 0.8299988, 34.1656437>,
    <1.7532363, 0.7369333, 34.1544124>,
    <1.7666880, 0.7162273, 34.1656437>,
    <1.7409127, -0.7513433, 34.1359011>,
    <1.7154455, -0.8004187, 34.1264018>,
    <1.6475429, -0.9517080, 34.1544411>,
    <1.7233432, -0.8041049, 34.1544124>,
    <1.7300581, -0.7729295, 34.1317777>,
    <1.6869675, -0.8670712, 34.1387967>,
    <1.6914822, -0.8693653, 34.1544124>,
    <1.7334843, -0.7744591, 34.1440880>,
    <1.7081073, -0.8274164, 34.1429132>,
    <1.7528836, -0.7377609, 34.1544124>,
    <1.7586036, -0.7064248, 34.1317777>,
    <1.7590122, -0.7140463, 34.1429132>,
    <1.7417484, -0.7330240, 34.1138015>,
    <1.7532502, -0.7117014, 34.1216372>,
    <1.7055187, -0.8571876, 34.1722608>,
    <1.6561800, -0.9567923, 34.1809181>,
    <1.6847708, -0.9011652, 34.1760819>,
    <1.6604108, -0.9592626, 34.1920745>,
    <1.7176331, -0.8361039, 34.1760819>,
    <1.6913022, -0.8968285, 34.1852017>,
    <1.7135619, -0.8340460, 34.1645454>,
    <1.7386254, -0.7807641, 34.1656437>,
    <1.6521571, -0.9544404, 34.1694828>,
    <1.6842671, -0.8929795, 34.1656437>,
    <1.6987926, 0.8529326, 34.0680823>,
    <1.7206482, 0.8019362, 34.0592183>,
    <1.7109783, 0.8319780, 34.0759583>,
    <1.7527260, 0.7369055, 34.0708032>,
    <1.7086471, 0.8307809, 34.0642124>,
    <1.7354194, 0.7784631, 34.0748134>,
    <1.6329484, 0.9435822, 34.0361559>,
    <1.6447577, 0.9492619, 34.0592183>,
    <1.6852173, 0.8649707, 34.0484530>,
    <1.6412109, 0.9469608, 34.0484530>,
    <1.6759561, 0.8955680, 34.0642124>,
    <1.6765962, 0.8879032, 34.0551646>,
    <1.6472287, 0.9507531, 34.0708032>,
    <1.6811767, 0.8905481, 34.0748134>,
    <1.7413249, 0.7506069, 34.0506060>,
    <1.7329406, 0.7733586, 34.0541438>,
    <1.7614654, 0.7068197, 34.0541438>,
    <1.7611242, 0.7142075, 34.0633523>,
    <1.7087907, 0.7963796, 34.0364647>,
    <1.7369888, 0.7321481, 34.0364059>,
    <1.7284912, 0.7710841, 34.0438443>,
    <1.7546006, 0.7111925, 34.0448606>,
    <1.6772446, 0.8604243, 34.0364059>,
    <1.7039395, 0.8241872, 34.0448606>,
    <1.7148719, -0.7347264, 34.0264558>,
    <1.7084931, -0.7973215, 34.0364647>,
    <1.6336676, -0.9426428, 34.0361559>,
    <1.6866437, -0.7642214, 34.0228405>,
    <1.7132649, -0.7641550, 34.0303723>,
    <1.6774156, -0.8602156, 34.0364059>,
    <1.6658929, -0.8412624, 34.0277741>,
    <1.7038716, -0.7467009, 34.0246615>,
    <1.6894057, -0.8087841, 34.0296825>,
    <1.7038701, -0.6864010, 34.0186848>,
    <1.7265494, -0.6929680, 34.0246615>,
    <1.7160572, -0.6879195, 34.0213137>,
    <1.7372780, -0.7319945, 34.0364059>,
    <1.7354335, -0.7060548, 34.0296825>,
    <1.6943081, -0.8514919, 34.0506060>,
    <1.6444659, -0.9497914, 34.0592183>,
    <1.7063439, -0.8304256, 34.0541438>,
    <1.6469907, -0.9511653, 34.0708032>,
    <1.6737075, -0.8950472, 34.0541438>,
    <1.6791435, -0.8900157, 34.0633523>,
    <1.6407061, -0.9479315, 34.0484530>,
    <1.7017550, -0.8285488, 34.0438443>,
    <1.6726572, -0.8870419, 34.0448606>,
    <1.7266518, -0.7756017, 34.0448606>,
    <1.6645807, 0.8417011, 34.0264558>,
    <1.6687782, 0.8012576, 34.0228405>,
    <1.6862823, 0.8214477, 34.0303723>,
    <1.7147382, 0.7356840, 34.0277741>,
    <1.6665819, 0.8256332, 34.0246615>,
    <1.7050886, 0.7745084, 34.0296825>,
    <1.6037988, 0.9255356, 34.0228405>,
    <1.6199143, 0.8646555, 34.0186848>,
    <1.5897190, 0.9195148, 34.0186848>,
    <1.6399972, 0.8775444, 34.0246615>,
    <1.6291507, 0.8728824, 34.0213137>,
    <1.6161670, 0.9342134, 34.0277741>,
    <1.6559795, 0.8758008, 34.0296825>,
    <1.6889175, 0.7340331, 34.0204813>,
    <1.6799369, 0.7647530, 34.0215203>,
    <1.7129815, 0.6885654, 34.0215203>,
    <1.7175713, 0.7056755, 34.0248083>,
    <1.6500391, 0.7690445, 34.0159774>,
    <1.6837290, 0.6967977, 34.0159774>,
    <1.6733733, 0.7485800, 34.0185671>,
    <1.7003625, 0.6884363, 34.0186456>,
    <1.6163493, 0.8412914, 34.0159774>,
    <1.6469750, 0.8071839, 34.0186456>,
    <1.6481305, -0.8230514, 34.0204813>,
    <1.6035504, -0.9272412, 34.0228405>,
    <1.6658733, -0.7963396, 34.0215203>,
    <1.6172098, -0.9332356, 34.0277741>,
    <1.6287516, -0.8706236, 34.0215203>,
    <1.6447633, -0.8629103, 34.0248083>,
    <1.6500469, -0.7712081, 34.0159774>,
    <1.5913420, -0.9184913, 34.0186848>,
    <1.6163590, -0.8434525, 34.0159774>,
    <1.6493175, -0.8019732, 34.0185671>,
    <1.6205923, -0.8612978, 34.0186456>,
    <1.6837347, -0.6989637, 34.0159774>,
    <1.6772399, -0.7440751, 34.0186456>,
    <1.6945994, 0.8506623, 34.1359011>,
    <1.7158234, 0.7996083, 34.1264018>,
    <1.7041582, 0.8284719, 34.1317777>,
    <1.7485769, 0.7349494, 34.1387967>,
    <1.7075323, 0.8301133, 34.1440880>,
    <1.7317879, 0.7766331, 34.1429132>,
    <1.6401653, 0.9465105, 34.1264018>,
    <1.6433432, 0.9483143, 34.1387967>,
    <1.6715614, 0.8930874, 34.1317777>,
    <1.6776624, 0.8885014, 34.1429132>,
    <1.6339816, 0.9430386, 34.0973598>,
    <1.6372163, 0.9448400, 34.1138015>,
    <1.6811032, 0.8630780, 34.1138015>,
    <1.6721624, 0.8855948, 34.1216372>,
    <1.7363033, 0.7484970, 34.1168394>,
    <1.7560887, 0.7045957, 34.1210460>,
    <1.7276408, 0.7709503, 34.1210460>,
    <1.7560467, 0.7119508, 34.1311462>,
    <1.7091010, 0.7966271, 34.0973402>,
    <1.6775318, 0.8613475, 34.0973402>,
    <1.7246185, 0.7696685, 34.1083733>,
    <1.7000218, 0.8225914, 34.1095803>,
    <1.7383683, 0.7308344, 34.0973402>,
    <1.7505940, 0.7098424, 34.1095803>,
    <1.7278969, -0.7455986, 34.0775018>,
    <1.7029785, -0.7945687, 34.0677166>,
    <1.6336862, -0.9435503, 34.0973598>,
    <1.7088407, -0.7971854, 34.0973402>,
    <1.7172983, -0.7671421, 34.0732308>,
    <1.6742745, -0.8603635, 34.0805061>,
    <1.6772532, -0.8618962, 34.0973402>,
    <1.7199066, -0.7682381, 34.0861763>,
    <1.6948507, -0.8208249, 34.0849170>,
    <1.7381271, -0.7314005, 34.0973402>,
    <1.7456293, -0.7011226, 34.0732308>,
    <1.7453434, -0.7083505, 34.0849170>,
    <1.7280609, -0.7275613, 34.0557354>,
    <1.7400706, -0.7064484, 34.0632019>,
    <1.6894562, -0.8489609, 34.1168394>,
    <1.6397848, -0.9471696, 34.1264018>,
    <1.6685436, -0.8923366, 34.1210460>,
    <1.6429359, -0.9490198, 34.1387967>,
    <1.7010883, -0.8278923, 34.1210460>,
    <1.6741510, -0.8875767, 34.1311462>,
    <1.6981637, -0.8264011, 34.1083733>,
    <1.7228945, -0.7735407, 34.1095803>,
    <1.6368636, -0.9454509, 34.1138015>,
    <1.6690309, -0.8847549, 34.1095803>,
    <1.6818286, 0.8443864, 34.0775018>,
    <1.7033132, 0.7938267, 34.0677166>,
    <1.6915146, 0.8224220, 34.0732308>,
    <1.7352795, 0.7295377, 34.0805061>,
    <1.6940391, 0.8237110, 34.0861763>,
    <1.7182174, 0.7707149, 34.0849170>,
    <1.6281879, 0.9396719, 34.0677166>,
    <1.6308344, 0.9412604, 34.0805061>,
    <1.6591516, 0.8865614, 34.0732308>,
    <1.6645131, 0.8816917, 34.0849170>,
    <1.6177455, 0.9328904, 34.0420193>,
    <1.6245011, 0.9372958, 34.0557354>,
    <1.6680597, 0.8561378, 34.0557354>,
    <1.6596333, 0.8788936, 34.0632019>,
    <1.7236323, 0.7429558, 34.0581798>,
    <1.7436289, 0.6996378, 34.0621232>,
    <1.7153946, 0.7655014, 34.0621232>,
    <1.7434572, 0.7070136, 34.0723106>,
    <1.6917158, 0.7877251, 34.0422290>,
    <1.6604771, 0.8518379, 34.0422290>,
    <1.7108147, 0.7631769, 34.0506039>,
    <1.6865318, 0.8157433, 34.0517365>,
    <1.7206885, 0.7225590, 34.0422290>,
    <1.7366731, 0.7039053, 34.0517365>,
    <1.6970291, -0.7345977, 34.0309239>,
    <1.6643531, -0.7804503, 34.0269467>,
    <1.6168048, -0.9348037, 34.0420193>,
    <1.6908867, -0.7897984, 34.0422290>,
    <1.6833720, -0.7548714, 34.0289414>,
    <1.6458748, -0.8478879, 34.0327086>,
    <1.6595899, -0.8538807, 34.0422290>,
    <1.6955165, -0.7589503, 34.0352527>,
    <1.6697393, -0.8104605, 34.0346796>,
    <1.7199202, -0.7246572, 34.0422290>,
    <1.7112336, -0.6900759, 34.0289414>,
    <1.7196268, -0.6994976, 34.0346796>,
    <1.6797233, -0.7152445, 34.0223261>,
    <1.6978605, -0.6942527, 34.0248676>,
    <1.6770745, -0.8428567, 34.0581798>,
    <1.6278758, -0.9402366, 34.0677166>,
    <1.6567408, -0.8860002, 34.0621232>,
    <1.6305727, -0.9417139, 34.0805061>,
    <1.6890466, -0.8220351, 34.0621232>,
    <1.6622765, -0.8811062, 34.0723106>,
    <1.6843355, -0.8200905, 34.0506039>,
    <1.7089940, -0.7676943, 34.0517365>,
    <1.6239811, -0.9382930, 34.0557354>,
    <1.6555512, -0.8779928, 34.0517365>,
    <1.6529814, 0.8282354, 34.0309239>,
    <1.6666060, 0.7743778, 34.0269467>,
    <1.6595392, 0.8049775, 34.0289414>,
    <1.7070211, 0.7160494, 34.0327086>,
    <1.6709082, 0.8111854, 34.0352527>,
    <1.6937742, 0.7583420, 34.0346796>,
    <1.5931823, 0.9172627, 34.0269467>,
    <1.6043426, 0.9245365, 34.0327086>,
    <1.6278121, 0.8679704, 34.0289414>,
    <1.6408388, 0.8678835, 34.0346796>,
    <1.5828131, 0.9095229, 34.0223261>,
    <1.6251168, 0.8302745, 34.0223261>,
    <1.6215924, 0.8561890, 34.0248676>,
    <1.6800017, 0.7198662, 34.0235084>,
    <1.7013494, 0.6796131, 34.0249046>,
    <1.6737782, 0.7441111, 34.0248897>,
    <1.7082330, 0.6910041, 34.0290881>,
    <1.6648427, 0.7352873, 34.0209790>,
    <1.6413226, 0.7879624, 34.0211848>,
    <1.6903097, 0.6782840, 34.0212444>,
    <1.6305665, -0.8272951, 34.0235018>,
    <1.5906883, -0.9227303, 34.0269467>,
    <1.6139845, -0.8681729, 34.0248897>,
    <1.6029067, -0.9277331, 34.0327086>,
    <1.6456265, -0.8058606, 34.0248897>,
    <1.6275025, -0.8650925, 34.0290881>,
    <1.6314695, -0.8085274, 34.0209641>,
    <1.6570380, -0.7562678, 34.0211848>,
    <1.5777159, -0.9200541, 34.0223261>,
    <1.6046827, -0.8632279, 34.0211848>,
    <1.6978351, -1.0594705, 34.2989756>,
    <1.6664722, -1.1013896, 34.2975521>,
    <1.6304990, -1.1677906, 34.3035582>,
    <1.6860466, -1.0909922, 34.3035582>,
    <1.6849588, -1.0758217, 34.2980080>,
    <1.6483377, -1.1355599, 34.3007100>,
    <1.6570983, -1.1303415, 34.3035582>,
    <1.6927669, -1.0732176, 34.3008727>,
    <1.6697182, -1.1054965, 34.3007914>,
    <1.7165609, -1.0503760, 34.3035582>,
    <1.7157214, -1.0293481, 34.2980080>,
    <1.7181133, -1.0363314, 34.3007914>,
    <1.6851982, -1.0633402, 34.2937748>,
    <1.7054409, -1.0364877, 34.2951914>,
    <1.5754163, 1.3000145, 34.2894165>,
    <1.5850172, 1.2968220, 34.2918000>,
    <1.6069012, 1.2655715, 34.2918015>,
    <1.5890811, 1.2781913, 34.2886789>,
    <1.5795634, 1.2987380, 34.2904026>,
    <1.5946020, 1.2831353, 34.2918009>,
    <1.5987219, 1.2714260, 34.2903190>,
    <1.5799264, 1.2920618, 34.2889145>,
    <1.5883874, 1.2863506, 34.2903608>,
    <1.5463692, 1.3107078, 34.2830969>,
    <1.5539664, 1.3225263, 34.2886778>,
    <1.5765175, 1.2867782, 34.2867235>,
    <1.5494043, 1.3202301, 34.2867231>,
    <1.5667655, 1.3089573, 34.2889140>,
    <1.5669725, 1.3027647, 34.2874556>,
    <1.5592897, 1.3229260, 34.2903170>,
    <1.5772421, 1.3079241, 34.2917990>,
    <1.5709147, 1.3097825, 34.2903597>,
    <1.6196601, 1.2378433, 34.2894178>,
    <1.6415575, 1.2160782, 34.2918021>,
    <1.6035634, 1.2586859, 34.2889153>,
    <1.6228196, 1.2428385, 34.2918019>,
    <1.6279434, 1.2300273, 34.2904043>,
    <1.6119021, 1.2527699, 34.2903617>,
    <1.6415376, 1.2018285, 34.2882666>,
    <1.6623153, 1.1864330, 34.2918022>,
    <1.6682082, 1.1722734, 34.2903408>,
    <1.6275148, 1.2244801, 34.2889155>,
    <1.6468615, 1.2028431, 34.2903620>,
    <1.6069350, 1.2416246, 34.2861105>,
    <1.6003826, 1.2565709, 34.2874564>,
    <1.6650726, 1.1617316, 34.2863581>,
    <1.6547839, 1.1793636, 34.2872643>,
    <1.6823915, 1.1400726, 34.2872643>,
    <1.6746706, 1.1574670, 34.2889218>,
    <1.6448502, 1.1756035, 34.2817251>,
    <1.6884756, 1.1134173, 34.2819691>,
    <1.6575167, 1.1660461, 34.2845089>,
    <1.6906482, 1.1198319, 34.2850030>,
    <1.6024036, 1.2346950, 34.2819691>,
    <1.6277960, 1.2090467, 34.2850030>,
    <1.6618971, -1.1662030, 34.2863462>,
    <1.6301737, -1.2179606, 34.2882265>,
    <1.6757839, -1.1493534, 34.2872643>,
    <1.6516713, -1.1958908, 34.2903405>,
    <1.6472445, -1.1901435, 34.2872377>,
    <1.6621508, -1.1753474, 34.2889216>,
    <1.5611303, -1.2900837, 34.2825386>,
    <1.6675704, -1.1429405, 34.2816852>,
    <1.6038195, -1.2456840, 34.2859510>,
    <1.6242777, -1.2043554, 34.2818098>,
    <1.6630028, -1.1580678, 34.2844823>,
    <1.6308768, -1.2046970, 34.2848968>,
    <1.7089438, -1.0824253, 34.2819690>,
    <1.6940235, -1.1143877, 34.2850030>,
    <1.6831444, -1.1031124, 34.2751756>,
    <1.6443411, -1.1507388, 34.2713146>,
    <1.6753978, -1.1227593, 34.2782756>,
    <1.6075924, -1.2137515, 34.2763869>,
    <1.6660103, -1.1248870, 34.2735677>,
    <1.6386773, -1.1744661, 34.2778875>,
    <1.6805728, -1.0845407, 34.2658251>,
    <1.7080438, -1.0607024, 34.2735942>,
    <1.6982114, -1.0654758, 34.2692880>,
    <1.7126193, -1.0654412, 34.2779936>,
    <1.6004049, -1.2641074, 34.2894054>,
    <1.6167695, -1.2514794, 34.2918011>,
    <1.6123920, -1.2456251, 34.2888885>,
    <1.6407692, -1.2172042, 34.2918015>,
    <1.6067687, -1.2598029, 34.2904035>,
    <1.6286204, -1.2288942, 34.2903614>,
    <1.5597803, -1.3129623, 34.2886388>,
    <1.5934182, -1.2848285, 34.2918006>,
    <1.5631684, -1.3163083, 34.2903183>,
    <1.5823102, -1.2862596, 34.2888882>,
    <1.5856145, -1.2884516, 34.2903608>,
    <1.5581845, -1.3066843, 34.2865642>,
    <1.5880045, -1.2724377, 34.2873499>,
    <1.6238806, -1.1684257, 34.2989756>,
    <1.6079218, -1.1873058, 34.2967794>,
    <1.5859136, -1.2357211, 34.3035582>,
    <1.6181653, -1.1749963, 34.2980080>,
    <1.5707671, -1.2539911, 34.3007507>,
    <1.5663614, -1.2674693, 34.3035582>,
    <1.6087092, -1.1954858, 34.3008727>,
    <1.5904928, -1.2238857, 34.3007914>,
    <1.6070318, -1.2027060, 34.3035582>,
    <1.6447093, -1.1347710, 34.2980080>,
    <1.6279961, -1.1658001, 34.3007914>,
    <1.6501470, -1.1132123, 34.2926777>,
    <1.6529200, -1.1154954, 34.2951914>,
    <1.6123866, 1.2042288, 34.2751874>,
    <1.6440425, 1.1513517, 34.2713545>,
    <1.6283625, 1.1900760, 34.2783022>,
    <1.6915985, 1.0945244, 34.2765463>,
    <1.6270597, 1.1806385, 34.2735942>,
    <1.6649085, 1.1375014, 34.2779937>,
    <1.5267654, 1.2802205, 34.2582471>,
    <1.5378706, 1.2908224, 34.2713545>,
    <1.5939246, 1.2082871, 34.2658251>,
    <1.5331326, 1.2854991, 34.2658251>,
    <1.5810110, 1.2421431, 34.2735942>,
    <1.5820422, 1.2313826, 34.2692880>,
    <1.5417202, 1.2981315, 34.2765462>,
    <1.5873034, 1.2444872, 34.2779937>,
    <1.6731029, 1.0996891, 34.2672347>,
    <1.6607874, 1.1223882, 34.2690979>,
    <1.7026481, 1.0584074, 34.2690979>,
    <1.7030896, 1.0689062, 34.2734379>,
    <1.6317140, 1.1416731, 34.2582019>,
    <1.6742109, 1.0786026, 34.2582019>,
    <1.6552499, 1.1181632, 34.2634197>,
    <1.6935400, 1.0607888, 34.2639559>,
    <1.5870197, 1.2032073, 34.2582019>,
    <1.6201860, 1.1689383, 34.2639559>,
    <1.6556533, -1.0897138, 34.2481381>,
    <1.6309008, -1.1428345, 34.2582019>,
    <1.5258911, -1.2812624, 34.2582471>,
    <1.6189381, -1.1345543, 34.2427102>,
    <1.6451401, -1.1130371, 34.2526827>,
    <1.5861688, -1.2043398, 34.2582019>,
    <1.5795295, -1.1994040, 34.2497196>,
    <1.6398731, -1.1095209, 34.2458152>,
    <1.6091698, -1.1628668, 34.2520259>,
    <1.6560417, -1.0686212, 34.2353389>,
    <1.6813348, -1.0462532, 34.2458152>,
    <1.6731088, -1.0496460, 34.2399571>,
    <1.6734377, -1.0797896, 34.2582019>,
    <1.6822337, -1.0553081, 34.2520259>,
    <1.6056428, -1.1959769, 34.2672229>,
    <1.5383890, -1.2899876, 34.2713146>,
    <1.6228085, -1.1765034, 34.2690713>,
    <1.5466417, -1.2913985, 34.2763869>,
    <1.5770034, -1.2377222, 34.2690713>,
    <1.5872776, -1.2338055, 34.2733316>,
    <1.5321951, -1.2866163, 34.2658251>,
    <1.6168585, -1.1729918, 34.2634197>,
    <1.5760402, -1.2285960, 34.2639559>,
    <1.6525789, -1.1226764, 34.2639559>,
    <1.5767474, 1.2334942, 34.2989756>,
    <1.6047607, 1.1892199, 34.2975521>,
    <1.6548253, 1.1326921, 34.3035582>,
    <1.6026045, 1.2118497, 34.3035582>,
    <1.5874443, 1.2156037, 34.2980080>,
    <1.6306516, 1.1604848, 34.3007100>,
    <1.6292383, 1.1708502, 34.3035582>,
    <1.5880568, 1.2241255, 34.3008727>,
    <1.6101427, 1.1911554, 34.3007914>,
    <1.5230292, 1.2966769, 34.2967794>,
    <1.5752729, 1.2547434, 34.3035582>,
    <1.5351936, 1.2978321, 34.3007507>,
    <1.5546893, 1.2607044, 34.2980080>,
    <1.5623526, 1.2607932, 34.3007914>,
    <1.5275116, 1.2661024, 34.2867877>,
    <1.5201903, 1.2883820, 34.2926777>,
    <1.5754355, 1.2198400, 34.2937748>,
    <1.5575403, 1.2483384, 34.2951914>,
    <1.6523735, 1.1257608, 34.2989756>,
    <1.6643597, 1.1041175, 34.2967794>,
    <1.7021611, 1.0667943, 34.3035582>,
    <1.6564030, 1.1180299, 34.2980080>,
    <1.7136201, 1.0459480, 34.3007507>,
    <1.7246079, 1.0371603, 34.3035582>,
    <1.6724172, 1.1021318, 34.3008727>,
    <1.6923846, 1.0750173, 34.3007914>,
    <1.6790166, 1.0983225, 34.3035582>,
    <1.6282487, 1.1570718, 34.2980080>,
    <1.6516246, 1.1307157, 34.3007914>,
    <1.6097530, 1.1694905, 34.2926777>,
    <1.6129049, 1.1713540, 34.2951914>,
    <1.6701555, 1.0866475, 34.2933120>,
    <1.6944437, 1.0547422, 34.2949171>,
    <1.6671046, 1.0955205, 34.2949171>,
    <1.7034508, 1.0516641, 34.2980246>,
    <1.6244165, 1.1339051, 34.2854038>,
    <1.5831634, 1.1915128, 34.2856693>,
    <1.6490025, 1.1089434, 34.2900253>,
    <1.6229529, 1.1474098, 34.2908029>,
    <1.6668865, 1.0717801, 34.2856693>,
    <1.6843997, 1.0579230, 34.2908029>,
    <1.6462630, -1.0840848, 34.2753407>,
    <1.6092233, -1.1286725, 34.2695801>,
    <1.5121177, -1.2844482, 34.2867877>,
    <1.6213832, -1.1388198, 34.2854038>,
    <1.6303709, -1.1037249, 34.2729301>,
    <1.5694979, -1.1952730, 34.2772285>,
    <1.5774175, -1.1997296, 34.2856693>,
    <1.6358687, -1.1079035, 34.2800513>,
    <1.5995468, -1.1582188, 34.2795037>,
    <1.6613908, -1.0803919, 34.2856693>,
    <1.6716781, -1.0408460, 34.2729301>,
    <1.6725219, -1.0513750, 34.2795037>,
    <1.6459303, -1.0621912, 34.2614925>,
    <1.6632355, -1.0435409, 34.2665723>,
    <1.5931287, -1.1982401, 34.2933120>,
    <1.5414501, -1.2747236, 34.2967794>,
    <1.5714683, -1.2317345, 34.2949171>,
    <1.5446996, -1.2865032, 34.3007507>,
    <1.6006455, -1.1926561, 34.2949171>,
    <1.5721718, -1.2418518, 34.2980246>,
    <1.6066052, -1.1706439, 34.2900253>,
    <1.6339085, -1.1331609, 34.2908029>,
    <1.5327881, -1.2733685, 34.2926777>,
    <1.5706374, -1.2209643, 34.2908029>,
    <1.5902627, 1.1831012, 34.2481381>,
    <1.6198418, 1.1332638, 34.2427102>,
    <1.6085838, 1.1652449, 34.2526827>,
    <1.6673020, 1.0740519, 34.2497196>,
    <1.6034782, 1.1614982, 34.2458152>,
    <1.6431058, 1.1144011, 34.2520259>,
    <1.5050110, 1.2620689, 34.2254060>,
    <1.5153812, 1.2706805, 34.2427102>,
    <1.5705751, 1.1906802, 34.2353389>,
    <1.5106753, 1.2667535, 34.2353389>,
    <1.5582067, 1.2220982, 34.2458152>,
    <1.5585815, 1.2132079, 34.2399571>,
    <1.5202026, 1.2747069, 34.2497196>,
    <1.5670230, 1.2198460, 34.2520259>,
    <1.6485256, 1.0833642, 34.2371711>,
    <1.6362840, 1.1053468, 34.2396408>,
    <1.6775304, 1.0423095, 34.2396408>,
    <1.6778853, 1.0509345, 34.2454279>,
    <1.6084746, 1.1255005, 34.2253660>,
    <1.6503688, 1.0633285, 34.2253660>,
    <1.6312212, 1.1020112, 34.2321345>,
    <1.6689120, 1.0454373, 34.2328481>,
    <1.5644140, 1.1861579, 34.2253660>,
    <1.5966153, 1.1520201, 34.2328481>,
    <1.6330506, -1.0747376, 34.2126378>,
    <1.6077552, -1.1265279, 34.2253660>,
    <1.5042377, -1.2629905, 34.2254060>,
    <1.5973188, -1.1192848, 34.2059260>,
    <1.6222786, -1.0974770, 34.2183311>,
    <1.5636613, -1.1871597, 34.2253660>,
    <1.5578418, -1.1828226, 34.2146338>,
    <1.6176944, -1.0944083, 34.2097470>,
    <1.5868709, -1.1466495, 34.2175110>,
    <1.6345828, -1.0546554, 34.1969055>,
    <1.6585878, -1.0320018, 34.2097470>,
    <1.6510061, -1.0356712, 34.2025384>,
    <1.6496849, -1.0643784, 34.2253660>,
    <1.6589109, -1.0405893, 34.2175110>,
    <1.5818583, -1.1785750, 34.2371711>,
    <1.5145192, -1.2717078, 34.2427102>,
    <1.5983283, -1.1595532, 34.2396408>,
    <1.5193216, -1.2757568, 34.2497196>,
    <1.5531997, -1.2198721, 34.2396408>,
    <1.5614260, -1.2172557, 34.2454279>,
    <1.5098347, -1.2677553, 34.2353389>,
    <1.5934623, -1.1559366, 34.2321345>,
    <1.5531912, -1.2107037, 34.2328481>,
    <1.6286193, -1.1063136, 34.2328481>,
    <1.5817131, 1.1761666, 34.2753407>,
    <1.6110294, 1.1261397, 34.2695801>,
    <1.5947881, 1.1545361, 34.2729301>,
    <1.6601388, 1.0660111, 34.2772285>,
    <1.6004799, 1.1582081, 34.2800513>,
    <1.6354718, 1.1068873, 34.2795037>,
    <1.5072096, 1.2628655, 34.2695801>,
    <1.5140061, 1.2659355, 34.2772285>,
    <1.5497975, 1.2148596, 34.2729301>,
    <1.5599038, 1.2120102, 34.2795037>,
    <1.4952792, 1.2538244, 34.2505667>,
    <1.5015354, 1.2589989, 34.2614925>,
    <1.5610745, 1.1833777, 34.2614925>,
    <1.5494677, 1.2060181, 34.2665723>,
    <1.6388085, 1.0766430, 34.2635082>,
    <1.6679936, 1.0357526, 34.2662252>,
    <1.6269957, 1.0984152, 34.2662252>,
    <1.6697398, 1.0435427, 34.2725930>,
    <1.5980700, 1.1181386, 34.2505227>,
    <1.5542973, 1.1784032, 34.2505227>,
    <1.6211141, 1.0951000, 34.2579678>,
    <1.5867780, 1.1448302, 34.2587527>,
    <1.6396902, 1.0563692, 34.2505227>,
    <1.6586190, 1.0389113, 34.2587527>,
    <1.6216471, -1.0673109, 34.2365221>,
    <1.5857986, -1.1113012, 34.2291393>,
    <1.4944285, -1.2548382, 34.2505667>,
    <1.5972787, -1.1192686, 34.2505227>,
    <1.6062345, -1.0867368, 34.2333423>,
    <1.5470679, -1.1747344, 34.2387176>,
    <1.5534694, -1.1795052, 34.2505227>,
    <1.6112772, -1.0901123, 34.2427845>,
    <1.5760591, -1.1389226, 34.2418824>,
    <1.6389378, -1.0575241, 34.2505227>,
    <1.6468442, -1.0247680, 34.2333423>,
    <1.6476178, -1.0335785, 34.2418824>,
    <1.6223255, -1.0468289, 34.2192172>,
    <1.6389226, -1.0281686, 34.2254131>,
    <1.5722156, -1.1717304, 34.2635082>,
    <1.5054040, -1.2650173, 34.2695801>,
    <1.5437689, -1.2131252, 34.2662252>,
    <1.5096076, -1.2711773, 34.2772285>,
    <1.5886304, -1.1531680, 34.2662252>,
    <1.5516636, -1.2120185, 34.2725930>,
    <1.5835111, -1.1488027, 34.2579678>,
    <1.6184986, -1.0995285, 34.2587527>,
    <1.5006107, -1.2601008, 34.2614925>,
    <1.5435384, -1.2032634, 34.2587527>,
    <1.5684591, 1.1669837, 34.2126378>,
    <1.5980988, 1.1181708, 34.2059260>,
    <1.5861429, 1.1490840, 34.2183311>,
    <1.6443029, 1.0593433, 34.2146338>,
    <1.5816914, 1.1458258, 34.2097470>,
    <1.6202399, 1.0989937, 34.2175110>,
    <1.4862136, 1.2464224, 34.1849198>,
    <1.4950395, 1.2537315, 34.2059260>,
    <1.5501122, 1.1752920, 34.1969055>,
    <1.4909951, 1.2503642, 34.1969055>,
    <1.5370349, 1.2055973, 34.2097470>,
    <1.5378899, 1.1972178, 34.2025384>,
    <1.4992267, 1.2572208, 34.2146338>,
    <1.5452150, 1.2029638, 34.2175110>,
    <1.6268978, 1.0692565, 34.1991181>,
    <1.6145962, 1.0908051, 34.2021355>,
    <1.6553038, 1.0285975, 34.2021355>,
    <1.6551293, 1.0367835, 34.2092829>,
    <1.5883965, 1.1115649, 34.1848862>,
    <1.6297715, 1.0501689, 34.1848862>,
    <1.6102636, 1.0879592, 34.1929998>,
    <1.6474114, 1.0320686, 34.1938690>,
    <1.5448822, 1.1714647, 34.1848862>,
    <1.5760336, 1.1372864, 34.1938690>,
    <1.6139127, -1.0620179, 34.1698789>,
    <1.5877929, -1.1124269, 34.1848862>,
    <1.4855647, -1.2471957, 34.1849198>,
    <1.5791998, -1.1064409, 34.1620860>,
    <1.6027599, -1.0841545, 34.1765488>,
    <1.5442506, -1.1723053, 34.1848862>,
    <1.5394277, -1.1686987, 34.1722289>,
    <1.5989976, -1.0816266, 34.1665078>,
    <1.5678571, -1.1327799, 34.1755900>,
    <1.6168483, -1.0430677, 34.1516897>,
    <1.6394091, -1.0199483, 34.1665078>,
    <1.6325750, -1.0239760, 34.1581668>,
    <1.6291976, -1.0510498, 34.1848862>,
    <1.6390195, -1.0280007, 34.1755900>,
    <1.5612043, -1.1630766, 34.1991181>,
    <1.4942954, -1.2546183, 34.2059260>,
    <1.5772459, -1.1441468, 34.2021355>,
    <1.4984588, -1.2581360, 34.2146338>,
    <1.5327127, -1.2036757, 34.2021355>,
    <1.5403453, -1.2007119, 34.2092829>,
    <1.4902769, -1.2512201, 34.1969055>,
    <1.5730898, -1.1410489, 34.1929998>,
    <1.5332752, -1.1950720, 34.1938690>,
    <1.6077349, -1.0920123, 34.1938690>,
    <1.5575802, 1.1588080, 34.2365221>,
    <1.5866567, 1.1100759, 34.2291393>,
    <1.5705631, 1.1376809, 34.2333423>,
    <1.6330176, 1.0519855, 34.2387176>,
    <1.5754598, 1.1412649, 34.2427845>,
    <1.6092812, 1.0914766, 34.2418824>,
    <1.4843360, 1.2446747, 34.2291393>,
    <1.4889419, 1.2485129, 34.2387176>,
    <1.5262208, 1.1970360, 34.2333423>,
    <1.5347646, 1.1947496, 34.2418824>,
    <1.4746021, 1.2366133, 34.2060335>,
    <1.4798872, 1.2409707, 34.2192172>,
    <1.5385654, 1.1664508, 34.2192172>,
    <1.5267070, 1.1884291, 34.2254131>,
    <1.6148791, 1.0612818, 34.2216509>,
    <1.6432318, 1.0210233, 34.2249699>,
    <1.6028266, 1.0827733, 34.2249699>,
    <1.6434580, 1.0293921, 34.2328318>,
    <1.5759841, 1.1028094, 34.2059966>,
    <1.5328124, 1.1622408, 34.2059966>,
    <1.5980608, 1.0796428, 34.2149211>,
    <1.5641382, 1.1286233, 34.2158771>,
    <1.6170331, 1.0418937, 34.2059966>,
    <1.6349684, 1.0242058, 34.2158771>,
    <1.6005956, -1.0533193, 34.1894897>,
    <1.5658678, -1.0971731, 34.1809181>,
    <1.4738883, -1.2374639, 34.2060335>,
    <1.5753202, -1.1037576, 34.2059966>,
    <1.5856681, -1.0726770, 34.1857817>,
    <1.5268124, -1.1591982, 34.1920745>,
    <1.5321177, -1.1631655, 34.2059966>,
    <1.5898066, -1.0754576, 34.1968260>,
    <1.5551440, -1.1236662, 34.1957715>,
    <1.6164018, -1.0428627, 34.2059966>,
    <1.6257476, -1.0115092, 34.1857817>,
    <1.6257373, -1.0197311, 34.1957715>,
    <1.6028176, -1.0340824, 34.1694828>,
    <1.6186483, -1.0153039, 34.1766071>,
    <1.5495999, -1.1545102, 34.2216509>,
    <1.4835175, -1.2456502, 34.2291393>,
    <1.5214665, -1.1949223, 34.2249699>,
    <1.4880972, -1.2495196, 34.2387176>,
    <1.5656730, -1.1358340, 34.2249699>,
    <1.5294079, -1.1922725, 34.2328318>,
    <1.5611013, -1.1324263, 34.2149211>,
    <1.5955257, -1.0837972, 34.2158771>,
    <1.4790972, -1.2419121, 34.2192172>,
    <1.5216308, -1.1860687, 34.2158771>,
    <1.5499610, 1.1533504, 34.1698789>,
    <1.5798326, 1.1055373, 34.1620860>,
    <1.5669481, 1.1352989, 34.1765488>,
    <1.6247328, 1.0468703, 34.1722289>,
    <1.5632859, 1.1326281, 34.1665078>,
    <1.6007037, 1.0858702, 34.1755900>,
    <1.4709443, 1.2337563, 34.1380150>,
    <1.4779500, 1.2395344, 34.1620860>,
    <1.5331578, 1.1625902, 34.1516897>,
    <1.4746900, 1.2368291, 34.1516897>,
    <1.5191488, 1.1916977, 34.1665078>,
    <1.5205963, 1.1838982, 34.1581668>,
    <1.4813758, 1.2423806, 34.1722289>,
    <1.5265823, 1.1885775, 34.1755900>,
    <1.6089219, 1.0575719, 34.1542153>,
    <1.5964845, 1.0787039, 34.1576891>,
    <1.6367453, 1.0171869, 34.1576891>,
    <1.6359195, 1.0248783, 34.1659804>,
    <1.5720899, 1.1002895, 34.1379890>,
    <1.6130446, 1.0395237, 34.1379890>,
    <1.5930138, 1.0764341, 34.1472010>,
    <1.6296915, 1.0210891, 34.1481994>,
    <1.5290178, 1.1595742, 34.1379890>,
    <1.5590664, 1.1251850, 34.1481994>,
    <1.5988213, -1.0519412, 34.1211611>,
    <1.5716204, -1.1009601, 34.1379890>,
    <1.4704396, -1.2343578, 34.1380150>,
    <1.5651317, -1.0964132, 34.1125260>,
    <1.5871769, -1.0734746, 34.1286034>,
    <1.5285265, -1.1602281, 34.1379890>,
    <1.5248467, -1.1574616, 34.1237934>,
    <1.5843510, -1.0715643, 34.1174128>,
    <1.5527062, -1.1216796, 34.1275355>,
    <1.6033769, -1.0342102, 34.1010718>,
    <1.6243813, -1.0104590, 34.1174128>,
    <1.6183754, -1.0149159, 34.1081947>,
    <1.6125982, -1.0402090, 34.1379890>,
    <1.6231638, -1.0179248, 34.1275355>,
    <1.5440762, -1.1501811, 34.1542153>,
    <1.4773464, -1.2402537, 34.1620860>,
    <1.5596799, -1.1312662, 34.1576891>,
    <1.4807442, -1.2431332, 34.1722289>,
    <1.5156429, -1.1901390, 34.1576891>,
    <1.5225880, -1.1867325, 34.1659804>,
    <1.4741161, -1.2375130, 34.1516897>,
    <1.5563600, -1.1287812, 34.1472010>,
    <1.5168972, -1.1821760, 34.1481994>,
    <1.5905602, -1.0802073, 34.1481994>,
    <1.5353305, 1.1426155, 34.1211611>,
    <1.5655980, 1.0957474, 34.1125260>,
    <1.5515826, 1.1243085, 34.1286034>,
    <1.6091864, 1.0370120, 34.1237934>,
    <1.5488210, 1.1223063, 34.1174128>,
    <1.5850909, 1.0754295, 34.1275355>,
    <1.4596671, 1.2244555, 34.0861253>,
    <1.4646320, 1.2285205, 34.1125260>,
    <1.5202269, 1.1529608, 34.1010718>,
    <1.4622554, 1.2265594, 34.1010718>,
    <1.5050920, 1.1808218, 34.1174128>,
    <1.5072259, 1.1736538, 34.1081947>,
    <1.4671923, 1.2306371, 34.1237934>,
    <1.5116911, 1.1771242, 34.1275355>,
    <1.5951439, 1.0486654, 34.1038334>,
    <1.5824993, 1.0694108, 34.1076575>,
    <1.6224186, 1.0084244, 34.1076575>,
    <1.6208397, 1.0155806, 34.1168389>,
    <1.5600502, 1.0920171, 34.0861074>,
    <1.6006965, 1.0317164, 34.0861074>,
    <1.5799959, 1.0677861, 34.0961373>,
    <1.6162908, 1.0128322, 34.0972345>,
    <1.5173027, 1.1508477, 34.0861074>,
    <1.5462291, 1.1160835, 34.0972345>,
    <1.5880581, -1.0447363, 34.0680823>,
    <1.5597290, -1.0924758, 34.0861074>,
    <1.4593218, -1.2248670, 34.0861253>,
    <1.5548234, -1.0891774, 34.0592183>,
    <1.5760032, -1.0657616, 34.0759583>,
    <1.5169667, -1.1512949, 34.0861074>,
    <1.5145418, -1.1494525, 34.0708032>,
    <1.5738021, -1.0643526, 34.0642124>,
    <1.5418784, -1.1136857, 34.0748134>,
    <1.5917038, -1.0270373, 34.0484530>,
    <1.6135639, -1.0036478, 34.0642124>,
    <1.6072496, -1.0080681, 34.0551646>,
    <1.6003912, -1.0321851, 34.0861074>,
    <1.6118256, -1.0106677, 34.0748134>,
    <1.5309945, -1.1402803, 34.1038334>,
    <1.4641872, -1.2290506, 34.1125260>,
    <1.5461641, -1.1213029, 34.1076575>,
    <1.4667163, -1.2312044, 34.1237934>,
    <1.5025088, -1.1796733, 34.1076575>,
    <1.5086935, -1.1757421, 34.1168389>,
    <1.4618432, -1.2270507, 34.1010718>,
    <1.5437811, -1.1195061, 34.0961373>,
    <1.5045550, -1.1724075, 34.0972345>,
    <1.5776170, -1.0712570, 34.0972345>,
    <1.5372323, 1.1438114, 34.1894897>,
    <1.5665637, 1.0961791, 34.1809181>,
    <1.5503171, 1.1231635, 34.1857817>,
    <1.6114906, 1.0382653, 34.1920745>,
    <1.5543455, 1.1261014, 34.1968260>,
    <1.5877914, 1.0770409, 34.1957715>,
    <1.4655376, 1.2290578, 34.1809181>,
    <1.4693060, 1.2321887, 34.1920745>,
    <1.5065461, 1.1817465, 34.1857817>,
    <1.5142687, 1.1789248, 34.1957715>,
    <1.4578058, 1.2226806, 34.1544411>,
    <1.4619516, 1.2260820, 34.1694828>,
    <1.5199155, 1.1524788, 34.1694828>,
    <1.5076839, 1.1737775, 34.1766071>,
    <1.5951056, 1.0484287, 34.1722608>,
    <1.6228174, 1.0084717, 34.1760819>,
    <1.5829037, 1.0694619, 34.1760819>,
    <1.6223273, 1.0162964, 34.1852017>,
    <1.5580468, 1.0904065, 34.1544124>,
    <1.5153615, 1.1491612, 34.1544124>,
    <1.5790859, 1.0669652, 34.1645454>,
    <1.5454742, 1.1153117, 34.1656437>,
    <1.5986335, 1.0301839, 34.1544124>,
    <1.6154765, 1.0121283, 34.1656437>,
    <1.5839949, -1.0422350, 34.1359011>,
    <1.5503928, -1.0861425, 34.1264018>,
    <1.4572506, -1.2233422, 34.1544411>,
    <1.5575303, -1.0911441, 34.1544124>,
    <1.5695568, -1.0616084, 34.1317777>,
    <1.5107733, -1.1468373, 34.1387967>,
    <1.5148211, -1.1498805, 34.1544124>,
    <1.5726653, -1.0637097, 34.1440880>,
    <1.5384779, -1.1114558, 34.1429132>,
    <1.5981425, -1.0309377, 34.1544124>,
    <1.6092170, -1.0010710, 34.1317777>,
    <1.6082960, -1.0086476, 34.1429132>,
    <1.5879990, -1.0243391, 34.1138015>,
    <1.6030287, -1.0053377, 34.1216372>,
    <1.5307590, -1.1403252, 34.1722608>,
    <1.4648736, -1.2298491, 34.1809181>,
    <1.5026896, -1.1800319, 34.1760819>,
    <1.4686113, -1.2330166, 34.1920745>,
    <1.5463505, -1.1216654, 34.1760819>,
    <1.5098749, -1.1768952, 34.1852017>,
    <1.5426985, -1.1189318, 34.1645454>,
    <1.5766335, -1.0708116, 34.1656437>,
    <1.4613203, -1.2268344, 34.1694828>,
    <1.5036150, -1.1718831, 34.1656437>,
    <1.5248734, 1.1349675, 34.0680823>,
    <1.5552506, 1.0885431, 34.0592183>,
    <1.5405132, 1.1164467, 34.0759583>,
    <1.5981359, 1.0300679, 34.0708032>,
    <1.5384241, 1.1148644, 34.0642124>,
    <1.5738757, 1.0679889, 34.0748134>,
    <1.4442592, 1.2128397, 34.0361559>,
    <1.4549302, 1.2204524, 34.0592183>,
    <1.5094052, 1.1444754, 34.0484530>,
    <1.4518298, 1.2175784, 34.0484530>,
    <1.4949795, 1.1729905, 34.0642124>,
    <1.4969371, 1.1655578, 34.0551646>,
    <1.4571070, 1.2223473, 34.0708032>,
    <1.5009938, 1.1689519, 34.0748134>,
    <1.5845233, 1.0415877, 34.0506060>,
    <1.5723182, 1.0625349, 34.0541438>,
    <1.6119639, 1.0019601, 34.0541438>,
    <1.6103480, 1.0091731, 34.0633523>,
    <1.5445114, 1.0810426, 34.0364647>,
    <1.5834339, 1.0226846, 34.0364059>,
    <1.5683219, 1.0595331, 34.0438443>,
    <1.6044354, 1.0050845, 34.0448606>,
    <1.5023224, 1.1386374, 34.0364059>,
    <1.5349226, 1.1075653, 34.0448606>,
    <1.5613029, -1.0214580, 34.0264558>,
    <1.5441074, -1.0819231, 34.0364647>,
    <1.4451839, -1.2120440, 34.0361559>,
    <1.5284125, -1.0456535, 34.0228405>,
    <1.5545866, -1.0501225, 34.0303723>,
    <1.5025811, -1.1384662, 34.0364059>,
    <1.4945643, -1.1178650, 34.0277741>,
    <1.5484027, -1.0313604, 34.0246615>,
    <1.5233457, -1.0899395, 34.0296825>,
    <1.5589303, -0.9720704, 34.0186848>,
    <1.5800665, -0.9823820, 34.0246615>,
    <1.5706392, -0.9756347, 34.0213137>,
    <1.5837994, -1.0225883, 34.0364059>,
    <1.5865128, -0.9967638, 34.0296825>,
    <1.5207122, -1.1327765, 34.0506060>,
    <1.4545551, -1.2209235, 34.0592183>,
    <1.5362212, -1.1141169, 34.0541438>,
    <1.4568011, -1.2227119, 34.0708032>,
    <1.4928592, -1.1720895, 34.0541438>,
    <1.4990839, -1.1680746, 34.0633523>,
    <1.4511810, -1.2184481, 34.0484530>,
    <1.5320355, -1.1114841, 34.0438443>,
    <1.4932219, -1.1640348, 34.0448606>,
    <1.5657476, -1.0636637, 34.0448606>,
    <1.5211256, 1.3590722, 34.2894164>,
    <1.4827063, 1.3939610, 34.2882660>,
    <1.4528424, 1.4352631, 34.2918009>,
    <1.5132052, 1.3749004, 34.2918000>,
    <1.5062462, 1.3724259, 34.2889145>,
    <1.4645301, 1.4189165, 34.2903399>,
    <1.4836231, 1.4044824, 34.2918006>,
    <1.5190004, 1.3645570, 34.2904026>,
    <1.4930261, 1.3904880, 34.2903607>,
    <1.5419883, 1.3461173, 34.2917990>,
    <1.5377017, 1.3405112, 34.2889140>,
    <1.5415365, 1.3416102, 34.2903597>,
    <1.5059598, 1.3633337, 34.2861101>,
    <1.5271006, 1.3462286, 34.2874556>,
    <1.4930485, 1.1180616, 34.0264558>,
    <1.5041662, 1.0790063, 34.0228405>,
    <1.5179664, 1.1018508, 34.0303723>,
    <1.5608574, 1.0223607, 34.0277741>,
    <1.4977939, 1.1026032, 34.0246615>,
    <1.5446308, 1.0588985, 34.0296825>,
    <1.4185933, 1.1901123, 34.0228405>,
    <1.4449871, 1.1330119, 34.0186848>,
    <1.4057244, 1.1817942, 34.0186848>,
    <1.4625989, 1.1491091, 34.0246615>,
    <1.4526911, 1.1426756, 34.0213137>,
    <1.4293094, 1.2007568, 34.0277741>,
    <1.4786786, 1.1501242, 34.0296825>,
    <1.5356449, 1.0163327, 34.0204813>,
    <1.5214790, 1.0450117, 34.0215203>,
    <1.5672499, 0.9757214, 34.0215203>,
    <1.5688316, 0.9933308, 34.0248083>,
    <1.4912163, 1.0441315, 34.0159774>,
    <1.5369379, 0.9788349, 34.0159774>,
    <1.5177860, 1.0279879, 34.0185671>,
    <1.5548087, 0.9734449, 34.0186456>,
    <1.4454948, 1.1094282, 34.0159774>,
    <1.4816148, 1.0811145, 34.0186456>,
    <1.4802892, -1.0969376, 34.0204813>,
    <1.4182724, -1.1917698, 34.0228405>,
    <1.5023917, -1.0736966, 34.0215203>,
    <1.4306494, -1.1999881, 34.0277741>,
    <1.4529341, -1.1404070, 34.0215203>,
    <1.4700170, -1.1355493, 34.0248083>,
    <1.4912272, -1.0462941, 34.0159774>,
    <1.4078076, -1.1810983, 34.0186848>,
    <1.4455052, -1.1115926, 34.0159774>,
    <1.4851379, -1.0764179, 34.0185671>,
    <1.4465460, -1.1298528, 34.0186456>,
    <1.5369492, -0.9809955, 34.0159774>,
    <1.5226897, -1.0242456, 34.0186456>,
    <1.5211387, 1.1320029, 34.1359011>,
    <1.5509057, 1.0854101, 34.1264018>,
    <1.5344056, 1.1118095, 34.1317777>,
    <1.5943895, 1.0274211, 34.1387967>,
    <1.5374434, 1.1140119, 34.1440880>,
    <1.5706173, 1.0655561, 34.1429132>,
    <1.4508877, 1.2169426, 34.1264018>,
    <1.4537040, 1.2192709, 34.1387967>,
    <1.4910836, 1.1697830, 34.1317777>,
    <1.4978883, 1.1663261, 34.1429132>,
    <1.4454009, 1.2124497, 34.0973598>,
    <1.4482735, 1.2147854, 34.1138015>,
    <1.5056916, 1.1418864, 34.1138015>,
    <1.4929766, 1.1625086, 34.1216372>,
    <1.5799498, 1.0386316, 34.1168394>,
    <1.6070580, 0.9988329, 34.1210460>,
    <1.5675199, 1.0592395, 34.1210460>,
    <1.6057395, 1.0060690, 34.1311462>,
    <1.5448031, 1.0813069, 34.0973402>,
    <1.5024749, 1.1395620, 34.0973402>,
    <1.5647662, 1.0574523, 34.1083733>,
    <1.5313531, 1.1053001, 34.1095803>,
    <1.5850506, 1.0215958, 34.0973402>,
    <1.6007357, 1.0030458, 34.1095803>,
    <1.5721749, -1.0343181, 34.0775018>,
    <1.5391329, -1.0782196, 34.0677166>,
    <1.4450211, -1.2129023, 34.0973598>,
    <1.5444498, -1.0818114, 34.0973402>,
    <1.5579969, -1.0536949, 34.0732308>,
    <1.4994379, -1.1380274, 34.0805061>,
    <1.5021053, -1.1400540, 34.0973402>,
    <1.5603742, -1.0552255, 34.0861763>,
    <1.5265674, -1.1026625, 34.0849170>,
    <1.5847147, -1.0221115, 34.0973402>,
    <1.5973616, -0.9935980, 34.0732308>,
    <1.5958239, -1.0006648, 34.0849170>,
    <1.5754755, -1.0165948, 34.0557354>,
    <1.5909656, -0.9978827, 34.0632019>,
    <1.5163691, -1.1294343, 34.1168394>,
    <1.4503985, -1.2175256, 34.1264018>,
    <1.4882421, -1.1685196, 34.1210460>,
    <1.4531804, -1.2198948, 34.1387967>,
    <1.5314829, -1.1107057, 34.1210460>,
    <1.4945908, -1.1648057, 34.1311462>,
    <1.5288617, -1.1087293, 34.1083733>,
    <1.5623959, -1.0609663, 34.1095803>,
    <1.4478201, -1.2153258, 34.1138015>,
    <1.4900385, -1.1611377, 34.1095803>,
    <1.5096512, 1.1236054, 34.0775018>,
    <1.5395872, 1.0775467, 34.0677166>,
    <1.5230034, 1.1036575, 34.0732308>,
    <1.5822339, 1.0197825, 34.0805061>,
    <1.5252670, 1.1053638, 34.0861763>,
    <1.5582806, 1.0573714, 34.0849170>,
    <1.4402775, 1.2081307, 34.0677166>,
    <1.4426103, 1.2101520, 34.0805061>,
    <1.4799943, 1.1612026, 34.0732308>,
    <1.4861212, 1.1573365, 34.0849170>,
    <1.4311462, 1.1996678, 34.0420193>,
    <1.4370523, 1.2051586, 34.0557354>,
    <1.4940420, 1.1327974, 34.0557354>,
    <1.4817964, 1.1537394, 34.0632019>,
    <1.5684280, 1.0309806, 34.0581798>,
    <1.5956455, 0.9917901, 34.0621232>,
    <1.5564030, 1.0517502, 34.0621232>,
    <1.5941986, 0.9990207, 34.0723106>,
    <1.5291991, 1.0695541, 34.0422290>,
    <1.4873020, 1.1272683, 34.0422290>,
    <1.5522868, 1.0486768, 34.0506039>,
    <1.5192455, 1.0962270, 34.0517365>,
    <1.5690477, 1.0104090, 34.0422290>,
    <1.5880454, 0.9947950, 34.0517365>,
    <1.5437467, -1.0182203, 34.0309239>,
    <1.5036295, -1.0577422, 34.0269467>,
    <1.4299368, -1.2013927, 34.0420193>,
    <1.5280743, -1.0714555, 34.0422290>,
    <1.5267866, -1.0358303, 34.0289414>,
    <1.4736910, -1.1208981, 34.0327086>,
    <1.4861251, -1.1291297, 34.0422290>,
    <1.5380094, -1.0419099, 34.0352527>,
    <1.5036820, -1.0881661, 34.0346796>,
    <1.5679782, -1.0123458, 34.0422290>,
    <1.5654765, -0.9768577, 34.0289414>,
    <1.5720800, -0.9875522, 34.0346796>,
    <1.5301213, -0.9962472, 34.0223261>,
    <1.5516075, -0.9786906, 34.0248676>,
    <1.5052399, -1.1212798, 34.0581798>,
    <1.4398762, -1.2086330, 34.0677166>,
    <1.4777213, -1.1602336, 34.0621232>,
    <1.4422737, -1.2105531, 34.0805061>,
    <1.5206437, -1.1028502, 34.0621232>,
    <1.4840204, -1.1563715, 34.0723106>,
    <1.5163495, -1.1001292, 34.0506039>,
    <1.5497312, -1.0528101, 34.0517365>,
    <1.4363838, -1.2060517, 34.0557354>,
    <1.4779472, -1.1521526, 34.0517365>,
    <1.4840545, 1.1026961, 34.0309305>,
    <1.5069906, 1.0518661, 34.0269691>,
    <1.4946426, 1.0808436, 34.0289563>,
    <1.5566780, 1.0016712, 34.0327086>,
    <1.5046102, 1.0890718, 34.0352527>,
    <1.5363014, 1.0410060, 34.0346796>,
    <1.4098708, 1.1798303, 34.0269691>,
    <1.4193563, 1.1891609, 34.0327086>,
    <1.4524590, 1.1373701, 34.0289563>,
    <1.4651486, 1.1396912, 34.0346796>,
    <1.4018036, 1.1696347, 34.0224156>,
    <1.4572259, 1.0989364, 34.0224156>,
    <1.4489072, 1.1241794, 34.0249273>,
    <1.5293541, 1.0008290, 34.0235084>,
    <1.5572118, 0.9650789, 34.0248897>,
    <1.5191984, 1.0234162, 34.0249046>,
    <1.5621963, 0.9772448, 34.0290881>,
    <1.5117426, 1.0134275, 34.0209790>,
    <1.4801477, 1.0604584, 34.0212444>,
    <1.5460804, 0.9625257, 34.0211848>,
    <1.4622572, -1.0980515, 34.0235084>,
    <1.4064178, -1.1850829, 34.0269691>,
    <1.4388343, -1.1354182, 34.0249046>,
    <1.4175102, -1.1920700, 34.0327086>,
    <1.4807888, -1.0795383, 34.0248897>,
    <1.4526294, -1.1346831, 34.0290881>,
    <1.4664400, -1.0797613, 34.0209790>,
    <1.5006658, -1.0327238, 34.0211848>,
    <1.3942642, -1.1802823, 34.0224156>,
    <1.4306428, -1.1290008, 34.0212444>,
    <1.5138953, -1.3656050, 34.2894054>,
    <1.5012283, -1.3868774, 34.2918011>,
    <1.4352634, -1.4528424, 34.2918019>,
    <1.4732261, -1.4029791, 34.2882265>,
    <1.5093247, -1.3740166, 34.2904035>,
    <1.4676463, -1.4204595, 34.2918015>,
    <1.4490827, -1.4343641, 34.2903405>,
    <1.4972320, -1.3809519, 34.2888885>,
    <1.4797125, -1.4038019, 34.2903614>,
    <1.5061225, -1.3613220, 34.2859510>,
    <1.5354107, -1.3412327, 34.2888882>,
    <1.5256581, -1.3457176, 34.2873499>,
    <1.5356099, -1.3524959, 34.2918006>,
    <1.5374409, -1.3448410, 34.2903608>,
    <1.4885579, -1.3385941, 34.2989756>,
    <1.4498213, -1.3738695, 34.2975521>,
    <1.4028498, -1.4329846, 34.3035582>,
    <1.4717340, -1.3678148, 34.3035582>,
    <1.4727971, -1.3522348, 34.2980080>,
    <1.4260206, -1.4043544, 34.3007100>,
    <1.4359843, -1.4011611, 34.3035582>,
    <1.4812962, -1.3513576, 34.3008727>,
    <1.4526634, -1.3788317, 34.3007914>,
    <1.5092273, -1.3334533, 34.3035582>,
    <1.5115232, -1.3121477, 34.2980080>,
    <1.5129415, -1.3196789, 34.3007914>,
    <1.4748819, -1.3396750, 34.2937748>,
    <1.4998400, -1.3171029, 34.2951914>,
    <1.3656107, 1.5138895, 34.2894046>,
    <1.3868862, 1.5012194, 34.2918000>,
    <1.4029805, 1.4732245, 34.2882262>,
    <1.3740236, 1.5093175, 34.2904026>,
    <1.4204636, 1.4676420, 34.2918006>,
    <1.4343649, 1.4490817, 34.2903399>,
    <1.3809556, 1.4972282, 34.2888879>,
    <1.4038056, 1.4797085, 34.2903607>,
    <1.2900846, 1.5611295, 34.2825385>,
    <1.3129695, 1.5597731, 34.2886379>,
    <1.3613234, 1.5061209, 34.2859508>,
    <1.3066881, 1.5581806, 34.2865637>,
    <1.3412393, 1.5354040, 34.2888874>,
    <1.3457212, 1.5256544, 34.2873494>,
    <1.3163199, 1.5631567, 34.2903170>,
    <1.3525097, 1.5355959, 34.2917990>,
    <1.3448511, 1.5374307, 34.2903597>,
    <1.4371110, 1.4340803, 34.2863460>,
    <1.4227519, 1.4507332, 34.2872375>,
    <1.4583304, 1.4154269, 34.2872640>,
    <1.4461202, 1.4328025, 34.2889212>,
    <1.4152833, 1.4435635, 34.2816852>,
    <1.4694805, 1.3897032, 34.2819690>,
    <1.4293420, 1.4365064, 34.2844823>,
    <1.4705057, 1.3963982, 34.2850029>,
    <1.3619114, 1.4949706, 34.2818097>,
    <1.3910725, 1.4747428, 34.2848967>,
    <1.4341366, -1.4370100, 34.2863344>,
    <1.3939121, -1.4825326, 34.2882267>,
    <1.4507335, -1.4227518, 34.2872377>,
    <1.4189153, -1.4645315, 34.2903406>,
    <1.4155534, -1.4581032, 34.2872377>,
    <1.4328022, -1.4461207, 34.2889216>,
    <1.3133931, -1.5415714, 34.2825385>,
    <1.4437545, -1.4149411, 34.2816454>,
    <1.3631441, -1.5052587, 34.2859512>,
    <1.3904674, -1.4681112, 34.2818098>,
    <1.4366335, -1.4291141, 34.2844558>,
    <1.3969071, -1.4695934, 34.2848968>,
    <1.4949708, -1.3619112, 34.2818098>,
    <1.4747431, -1.3910722, 34.2848968>,
    <1.4660166, -1.3785675, 34.2751638>,
    <1.4195362, -1.4187933, 34.2713146>,
    <1.4549714, -1.3964944, 34.2782491>,
    <1.3724039, -1.4744672, 34.2763869>,
    <1.4453653, -1.3970970, 34.2735677>,
    <1.4098383, -1.4411765, 34.2778875>,
    <1.4667126, -1.3598925, 34.2658251>,
    <1.4978976, -1.3410492, 34.2735677>,
    <1.4873938, -1.3441801, 34.2692880>,
    <1.5015561, -1.3460982, 34.2778875>,
    <1.3565842, -1.5228072, 34.2894060>,
    <1.3748946, -1.5132112, 34.2918021>,
    <1.3715977, -1.5066882, 34.2888889>,
    <1.4044794, -1.4836264, 34.2918020>,
    <1.3635994, -1.5196724, 34.2904043>,
    <1.3904850, -1.4930294, 34.2903619>,
    <1.3080939, -1.5638648, 34.2886392>,
    <1.3461092, -1.5419966, 34.2918022>,
    <1.3108515, -1.5677463, 34.2903193>,
    <1.3349181, -1.5414804, 34.2888888>,
    <1.3377932, -1.5442112, 34.2903619>,
    <1.3076108, -1.5574067, 34.2865643>,
    <1.3429247, -1.5288586, 34.2873502>,
    <1.3955936, -1.4317791, 34.2989756>,
    <1.3763580, -1.4473446, 34.2967794>,
    <1.3461702, -1.4910476, 34.3035582>,
    <1.3886787, -1.4370913, 34.2980080>,
    <1.3276259, -1.5059581, 34.3007507>,
    <1.3208816, -1.5183025, 34.3035582>,
    <1.3758050, -1.4556204, 34.3008727>,
    <1.3525678, -1.4799951, 34.3007914>,
    <1.3732024, -1.4627775, 34.3035582>,
    <1.4222400, -1.4025833, 34.2980080>,
    <1.4003452, -1.4301787, 34.3007914>,
    <1.4312553, -1.3822157, 34.2926777>,
    <1.4336391, -1.3849945, 34.2951914>,
    <1.3786689, 1.4659600, 34.2751756>,
    <1.4191357, 1.4193451, 34.2713545>,
    <1.3967226, 1.4548441, 34.2782756>,
    <1.4758369, 1.3716395, 34.2765462>,
    <1.3973253, 1.4452379, 34.2735942>,
    <1.4420896, 1.4093287, 34.2779937>,
    <1.2812624, 1.5258911, 34.2582471>,
    <1.2899876, 1.5383889, 34.2713146>,
    <1.3598925, 1.4667126, 34.2658251>,
    <1.2866163, 1.5321951, 34.2658251>,
    <1.3410492, 1.4978976, 34.2735677>,
    <1.3441801, 1.4873938, 34.2692880>,
    <1.2913987, 1.5466415, 34.2763869>,
    <1.3460983, 1.5015560, 34.2778875>,
    <1.4567257, 1.3735136, 34.2672347>,
    <1.4406557, 1.3937294, 34.2690979>,
    <1.4929904, 1.3379897, 34.2690979>,
    <1.4916021, 1.3484057, 34.2734378>,
    <1.4086752, 1.4076727, 34.2582019>,
    <1.4614785, 1.3529399, 34.2582019>,
    <1.4359359, 1.3886069, 34.2634197>,
    <1.4836073, 1.3387532, 34.2639559>,
    <1.3539745, 1.4605109, 34.2582019>,
    <1.3925877, 1.4325218, 34.2639559>,
    <1.4412734, -1.3606598, 34.2481381>,
    <1.4076727, -1.4086752, 34.2582019>,
    <1.2802205, -1.5267654, 34.2582471>,
    <1.3973296, -1.3984436, 34.2427102>,
    <1.4268699, -1.3818032, 34.2526827>,
    <1.3529399, -1.4614785, 34.2582019>,
    <1.3472586, -1.4554648, 34.2497196>,
    <1.4222935, -1.3774257, 34.2458152>,
    <1.3827932, -1.4246296, 34.2520259>,
    <1.4453186, -1.3399551, 34.2353389>,
    <1.4741116, -1.3223190, 34.2458152>,
    <1.4654214, -1.3242318, 34.2399571>,
    <1.4605109, -1.3539745, 34.2582019>,
    <1.4734245, -1.3313924, 34.2520259>,
    <1.3735703, -1.4566242, 34.2672229>,
    <1.2910135, -1.5375282, 34.2713146>,
    <1.3938568, -1.4404274, 34.2690713>,
    <1.2988959, -1.5403506, 34.2763869>,
    <1.3381171, -1.4927622, 34.2690713>,
    <1.3489154, -1.4906890, 34.2733316>,
    <1.2854991, -1.5331326, 34.2658251>,
    <1.3886069, -1.4359359, 34.2634197>,
    <1.3387532, -1.4836073, 34.2639559>,
    <1.4325218, -1.3925877, 34.2639559>,
    <1.3382007, 1.4880661, 34.2989756>,
    <1.3740369, 1.4499004, 34.2975521>,
    <1.4331824, 1.4029433, 34.3035582>,
    <1.3671965, 1.4709829, 34.3035582>,
    <1.3520676, 1.4725460, 34.2980080>,
    <1.4045391, 1.4261078, 34.3007100>,
    <1.4009212, 1.4356414, 34.3035582>,
    <1.3508589, 1.4806877, 34.3008727>,
    <1.3786450, 1.4523839, 34.3007914>,
    <1.2741629, 1.5407708, 34.2967794>,
    <1.3324961, 1.5080866, 34.3035582>,
    <1.2856260, 1.5436294, 34.3007507>,
    <1.3116419, 1.5109113, 34.2980080>,
    <1.3189344, 1.5120542, 34.3007914>,
    <1.2845155, 1.5121495, 34.2867877>,
    <1.2730929, 1.5324403, 34.2926777>,
    <1.3398173, 1.4749492, 34.2937748>,
    <1.3168879, 1.4995472, 34.2951914>,
    <1.4326586, 1.3963153, 34.2989756>,
    <1.4484807, 1.3773204, 34.2967794>,
    <1.4923387, 1.3472393, 34.3035582>,
    <1.4381369, 1.3895457, 34.2980080>,
    <1.5077011, 1.3291503, 34.3007507>,
    <1.5202094, 1.3224712, 34.3035582>,
    <1.4566732, 1.3766753, 34.3008727>,
    <1.4814783, 1.3538041, 34.3007914>,
    <1.4634923, 1.3737696, 34.3035582>,
    <1.4031321, 1.4226715, 34.2980080>,
    <1.4307876, 1.4008241, 34.3007914>,
    <1.3828452, 1.4317703, 34.2926777>,
    <1.3855751, 1.4341047, 34.2951914>,
    <1.4566803, 1.3608530, 34.2933120>,
    <1.4859050, 1.3337051, 34.2949171>,
    <1.4524862, 1.3692254, 34.2949171>,
    <1.4959905, 1.3326413, 34.2980246>,
    <1.4030689, 1.3989967, 34.2854038>,
    <1.3524758, 1.4485425, 34.2856693>,
    <1.4318434, 1.3789170, 34.2900253>,
    <1.3996709, 1.4123145, 34.2908029>,
    <1.4554189, 1.3451218, 34.2856693>,
    <1.4751540, 1.3347571, 34.2908029>,
    <1.4329590, -1.3534430, 34.2753407>,
    <1.3887813, -1.3909983, 34.2695801>,
    <1.2661221, -1.5280772, 34.2867877>,
    <1.3987535, -1.4028335, 34.2854038>,
    <1.4139268, -1.3700740, 34.2729301>,
    <1.3380875, -1.4497911, 34.2772285>,
    <1.3449406, -1.4554345, 34.2856693>,
    <1.4185313, -1.3750416, 34.2800513>,
    <1.3740621, -1.4184060, 34.2795037>,
    <1.4483247, -1.3522073, 34.2856693>,
    <1.4655227, -1.3152944, 34.2729301>,
    <1.4644717, -1.3257419, 34.2795037>,
    <1.4364773, -1.3318669, 34.2614925>,
    <1.4567582, -1.3165050, 34.2665723>,
    <1.3601582, -1.4560861, 34.2933120>,
    <1.2960193, -1.5235433, 34.2967794>,
    <1.3329545, -1.4855442, 34.2949171>,
    <1.2965102, -1.5345236, 34.3007507>,
    <1.3683675, -1.4515416, 34.2949171>,
    <1.3314888, -1.4949513, 34.2980246>,
    <1.3784411, -1.4313817, 34.2900253>,
    <1.4118014, -1.3990504, 34.2908029>,
    <1.2881152, -1.5210191, 34.2926777>,
    <1.3343382, -1.4750929, 34.2908029>,
    <1.3606598, 1.4412734, 34.2481381>,
    <1.3984436, 1.3973296, 34.2427102>,
    <1.3818032, 1.4268699, 34.2526827>,
    <1.4554648, 1.3472586, 34.2497196>,
    <1.3774257, 1.4222935, 34.2458152>,
    <1.4246296, 1.3827932, 34.2520259>,
    <1.2629905, 1.5042377, 34.2254060>,
    <1.2717078, 1.5145192, 34.2427102>,
    <1.3399551, 1.4453186, 34.2353389>,
    <1.2677553, 1.5098347, 34.2353389>,
    <1.3223190, 1.4741116, 34.2458152>,
    <1.3242318, 1.4654214, 34.2399571>,
    <1.2757568, 1.5193216, 34.2497196>,
    <1.3313924, 1.4734245, 34.2520259>,
    <1.4353566, 1.3531690, 34.2371711>,
    <1.4194838, 1.3726918, 34.2396408>,
    <1.4710498, 1.3177746, 34.2396408>,
    <1.4699016, 1.3263302, 34.2454279>,
    <1.3885971, 1.3877103, 34.2253660>,
    <1.4406510, 1.3337577, 34.2253660>,
    <1.4150771, 1.3685278, 34.2321345>,
    <1.4620192, 1.3193583, 34.2328481>,
    <1.3346729, 1.4397951, 34.2253660>,
    <1.3723130, 1.4117676, 34.2328481>,
    <1.4216146, -1.3419861, 34.2126378>,
    <1.3877103, -1.3885971, 34.2253660>,
    <1.2620689, -1.5050110, 34.2254060>,
    <1.3786902, -1.3796518, 34.2059260>,
    <1.4070577, -1.3625095, 34.2183311>,
    <1.3337577, -1.4406510, 34.2253660>,
    <1.3287797, -1.4353692, 34.2146338>,
    <1.4030759, -1.3586914, 34.2097470>,
    <1.3636492, -1.4047865, 34.2175110>,
    <1.4266108, -1.3224752, 34.1969055>,
    <1.4541849, -1.3043341, 34.2097470>,
    <1.4460812, -1.3066312, 34.2025384>,
    <1.4397951, -1.3346729, 34.2253660>,
    <1.4530119, -1.3128473, 34.2175110>,
    <1.3531690, -1.4353566, 34.2371711>,
    <1.2706805, -1.5153812, 34.2427102>,
    <1.3726918, -1.4194838, 34.2396408>,
    <1.2747069, -1.5202026, 34.2497196>,
    <1.3177746, -1.4710498, 34.2396408>,
    <1.3263302, -1.4699016, 34.2454279>,
    <1.2667535, -1.5106753, 34.2353389>,
    <1.3685278, -1.4150771, 34.2321345>,
    <1.3193583, -1.4620192, 34.2328481>,
    <1.4117676, -1.3723130, 34.2328481>,
    <1.3534857, 1.4330032, 34.2753407>,
    <1.3909642, 1.3887836, 34.2695801>,
    <1.3700678, 1.4139421, 34.2729301>,
    <1.4496548, 1.3380965, 34.2772285>,
    <1.3751376, 1.4186307, 34.2800513>,
    <1.4183813, 1.3741233, 34.2795037>,
    <1.2650265, 1.5054101, 34.2695801>,
    <1.2712142, 1.5096322, 34.2772285>,
    <1.3153171, 1.4655406, 34.2729301>,
    <1.3258327, 1.4645432, 34.2795037>,
    <1.2548382, 1.4944285, 34.2505667>,
    <1.2601008, 1.5006107, 34.2614925>,
    <1.3318669, 1.4364773, 34.2614925>,
    <1.3165050, 1.4567582, 34.2665723>,
    <1.4269415, 1.3448613, 34.2635082>,
    <1.4627678, 1.3096586, 34.2662252>,
    <1.4115116, 1.3642500, 34.2662252>,
    <1.4630489, 1.3176255, 34.2725930>,
    <1.3796290, 1.3786535, 34.2505227>,
    <1.3260564, 1.4304015, 34.2505227>,
    <1.4063236, 1.3599665, 34.2579678>,
    <1.3638736, 1.4029788, 34.2587527>,
    <1.4313430, 1.3250498, 34.2505227>,
    <1.4530158, 1.3111441, 34.2587527>,
    <1.4116741, -1.3326922, 34.2365221>,
    <1.3687313, -1.3697891, 34.2291393>,
    <1.2538244, -1.4952792, 34.2505667>,
    <1.3786535, -1.3796290, 34.2505227>,
    <1.3931224, -1.3491465, 34.2333423>,
    <1.3195740, -1.4255331, 34.2387176>,
    <1.3250498, -1.4313430, 34.2505227>,
    <1.3975023, -1.3533464, 34.2427845>,
    <1.3543434, -1.3952996, 34.2418824>,
    <1.4304015, -1.3260564, 34.2505227>,
    <1.4438758, -1.2951710, 34.2333423>,
    <1.4431078, -1.3039820, 34.2418824>,
    <1.4158989, -1.3126390, 34.2192172>,
    <1.4354840, -1.2971443, 34.2254131>,
    <1.3448618, -1.4269531, 34.2635082>,
    <1.2628674, -1.5072486, 34.2695801>,
    <1.3096598, -1.4627939, 34.2662252>,
    <1.2659430, -1.5141623, 34.2772285>,
    <1.3642512, -1.4115376, 34.2662252>,
    <1.3176305, -1.4631530, 34.2725930>,
    <1.3599665, -1.4063236, 34.2579678>,
    <1.4029788, -1.3638736, 34.2587527>,
    <1.2589989, -1.5015354, 34.2614925>,
    <1.3111441, -1.4530158, 34.2587527>,
    <1.3419861, 1.4216146, 34.2126378>,
    <1.3796518, 1.3786902, 34.2059260>,
    <1.3625095, 1.4070577, 34.2183311>,
    <1.4353692, 1.3287797, 34.2146338>,
    <1.3586914, 1.4030759, 34.2097470>,
    <1.4047865, 1.3636492, 34.2175110>,
    <1.2471957, 1.4855647, 34.1849198>,
    <1.2546183, 1.4942954, 34.2059260>,
    <1.3224752, 1.4266108, 34.1969055>,
    <1.2512201, 1.4902769, 34.1969055>,
    <1.3043341, 1.4541849, 34.2097470>,
    <1.3066312, 1.4460812, 34.2025384>,
    <1.2581360, 1.4984588, 34.2146338>,
    <1.3128473, 1.4530119, 34.2175110>,
    <1.4165071, 1.3355199, 34.1991181>,
    <1.4006505, 1.3546050, 34.2021355>,
    <1.4515419, 1.3004113, 34.2021355>,
    <1.4499486, 1.3084426, 34.2092829>,
    <1.3712440, 1.3704999, 34.1848862>,
    <1.4226517, 1.3172213, 34.1848862>,
    <1.3968780, 1.3510500, 34.1929998>,
    <1.4431666, 1.3024592, 34.1938690>,
    <1.3179892, 1.4219335, 34.1848862>,
    <1.3546024, 1.3936838, 34.1938690>,
    <1.4049763, -1.3261364, 34.1698789>,
    <1.3704999, -1.3712440, 34.1848862>,
    <1.2464224, -1.4862136, 34.1849198>,
    <1.3630768, -1.3638568, 34.1620860>,
    <1.3901489, -1.3460001, 34.1765488>,
    <1.3172213, -1.4226517, 34.1848862>,
    <1.3130979, -1.4182624, 34.1722289>,
    <1.3868827, -1.3428573, 34.1665078>,
    <1.3473327, -1.3878260, 34.1755900>,
    <1.4111579, -1.3079840, 34.1516897>,
    <1.4373906, -1.2891334, 34.1665078>,
    <1.4299609, -1.2919132, 34.1581668>,
    <1.4219335, -1.3179892, 34.1848862>,
    <1.4356086, -1.2969958, 34.1755900>,
    <1.3355199, -1.4165071, 34.1991181>,
    <1.2537315, -1.4950395, 34.2059260>,
    <1.3546050, -1.4006505, 34.2021355>,
    <1.2572208, -1.4992267, 34.2146338>,
    <1.3004113, -1.4515419, 34.2021355>,
    <1.3084426, -1.4499486, 34.2092829>,
    <1.2503642, -1.4909951, 34.1969055>,
    <1.3510500, -1.3968780, 34.1929998>,
    <1.3024592, -1.4431666, 34.1938690>,
    <1.3936838, -1.3546024, 34.1938690>,
    <1.3326922, 1.4116741, 34.2365221>,
    <1.3697891, 1.3687313, 34.2291393>,
    <1.3491465, 1.3931224, 34.2333423>,
    <1.4255331, 1.3195740, 34.2387176>,
    <1.3533464, 1.3975023, 34.2427845>,
    <1.3952996, 1.3543434, 34.2418824>,
    <1.2456502, 1.4835175, 34.2291393>,
    <1.2495196, 1.4880972, 34.2387176>,
    <1.2951710, 1.4438758, 34.2333423>,
    <1.3039820, 1.4431078, 34.2418824>,
    <1.2374639, 1.4738883, 34.2060335>,
    <1.2419121, 1.4790972, 34.2192172>,
    <1.3126390, 1.4158989, 34.2192172>,
    <1.2971443, 1.4354840, 34.2254131>,
    <1.4060558, 1.3255794, 34.2216509>,
    <1.4409686, 1.2908559, 34.2249699>,
    <1.3904544, 1.3446514, 34.2249699>,
    <1.4397381, 1.2991368, 34.2328318>,
    <1.3605405, 1.3597220, 34.2059966>,
    <1.3077045, 1.4107538, 34.2059966>,
    <1.3863046, 1.3407409, 34.2149211>,
    <1.3443920, 1.3830867, 34.2158771>,
    <1.4115438, 1.3068598, 34.2059966>,
    <1.4322780, 1.2925551, 34.2158771>,
    <1.3933719, -1.3152576, 34.1894897>,
    <1.3515566, -1.3524146, 34.1809181>,
    <1.2366133, -1.4746021, 34.2060335>,
    <1.3597220, -1.3605405, 34.2059966>,
    <1.3753099, -1.3317290, 34.1857817>,
    <1.3023241, -1.4067156, 34.1920745>,
    <1.3068598, -1.4115438, 34.2059966>,
    <1.3789026, -1.3351861, 34.1968260>,
    <1.3363953, -1.3766431, 34.1957715>,
    <1.4107538, -1.3077045, 34.2059966>,
    <1.4254021, -1.2784502, 34.1857817>,
    <1.4239642, -1.2865454, 34.1957715>,
    <1.3989006, -1.2966987, 34.1694828>,
    <1.4177517, -1.2809545, 34.1766071>,
    <1.3255794, -1.4060558, 34.2216509>,
    <1.2446747, -1.4843360, 34.2291393>,
    <1.2908559, -1.4409686, 34.2249699>,
    <1.2485129, -1.4889419, 34.2387176>,
    <1.3446514, -1.3904544, 34.2249699>,
    <1.2991368, -1.4397381, 34.2328318>,
    <1.3407409, -1.3863046, 34.2149211>,
    <1.3830867, -1.3443920, 34.2158771>,
    <1.2409707, -1.4798872, 34.2192172>,
    <1.2925551, -1.4322780, 34.2158771>,
    <1.3261364, 1.4049763, 34.1698789>,
    <1.3638568, 1.3630768, 34.1620860>,
    <1.3460001, 1.3901489, 34.1765488>,
    <1.4182624, 1.3130979, 34.1722289>,
    <1.3428573, 1.3868827, 34.1665078>,
    <1.3878260, 1.3473327, 34.1755900>,
    <1.2343578, 1.4704396, 34.1380150>,
    <1.2402537, 1.4773464, 34.1620860>,
    <1.3079840, 1.4111579, 34.1516897>,
    <1.2375130, 1.4741161, 34.1516897>,
    <1.2891334, 1.4373906, 34.1665078>,
    <1.2919132, 1.4299609, 34.1581668>,
    <1.2431332, 1.4807442, 34.1722289>,
    <1.2969958, 1.4356086, 34.1755900>,
    <1.4008333, 1.3208914, 34.1542153>,
    <1.3849154, 1.3395426, 34.1576891>,
    <1.4352467, 1.2859514, 34.1576891>,
    <1.4330980, 1.2933825, 34.1659804>,
    <1.3571431, 1.3565642, 34.1379890>,
    <1.4080275, 1.3038333, 34.1379890>,
    <1.3818915, 1.3367046, 34.1472010>,
    <1.4276226, 1.2885694, 34.1481994>,
    <1.3044306, 1.4074689, 34.1379890>,
    <1.3399944, 1.3788199, 34.1481994>,
    <1.3918639, -1.3135923, 34.1211611>,
    <1.3565642, -1.3571431, 34.1379890>,
    <1.2337563, -1.4709443, 34.1380150>,
    <1.3509637, -1.3515385, 34.1125260>,
    <1.3766572, -1.3327765, 34.1286034>,
    <1.3038333, -1.4080275, 34.1379890>,
    <1.3006898, -1.4046640, 34.1237934>,
    <1.3742059, -1.3304045, 34.1174128>,
    <1.3343395, -1.3742634, 34.1275355>,
    <1.3994293, -1.2969218, 34.1010718>,
    <1.4242390, -1.2771787, 34.1174128>,
    <1.4175503, -1.2805250, 34.1081947>,
    <1.4074689, -1.3044306, 34.1379890>,
    <1.4217435, -1.2843197, 34.1275355>,
    <1.3208914, -1.4008333, 34.1542153>,
    <1.2395344, -1.4779500, 34.1620860>,
    <1.3395426, -1.3849154, 34.1576891>,
    <1.2423806, -1.4813758, 34.1722289>,
    <1.2859514, -1.4352467, 34.1576891>,
    <1.2933825, -1.4330980, 34.1659804>,
    <1.2368291, -1.4746900, 34.1516897>,
    <1.3367046, -1.3818915, 34.1472010>,
    <1.2885694, -1.4276226, 34.1481994>,
    <1.3788199, -1.3399944, 34.1481994>,
    <1.3135923, 1.3918639, 34.1211611>,
    <1.3515385, 1.3509637, 34.1125260>,
    <1.3327765, 1.3766572, 34.1286034>,
    <1.4046640, 1.3006898, 34.1237934>,
    <1.3304045, 1.3742059, 34.1174128>,
    <1.3742634, 1.3343395, 34.1275355>,
    <1.2248670, 1.4593218, 34.0861253>,
    <1.2290506, 1.4641872, 34.1125260>,
    <1.2969218, 1.3994293, 34.1010718>,
    <1.2270507, 1.4618432, 34.1010718>,
    <1.2771787, 1.4242390, 34.1174128>,
    <1.2805250, 1.4175503, 34.1081947>,
    <1.2312044, 1.4667163, 34.1237934>,
    <1.2843197, 1.4217435, 34.1275355>,
    <1.3888113, 1.3097276, 34.1038334>,
    <1.3727563, 1.3279622, 34.1076575>,
    <1.4226594, 1.2748342, 34.1076575>,
    <1.4198618, 1.2816076, 34.1168389>,
    <1.3467228, 1.3463268, 34.0861074>,
    <1.3972227, 1.2940003, 34.0861074>,
    <1.3705731, 1.3259274, 34.0961373>,
    <1.4158593, 1.2781110, 34.0972345>,
    <1.2944089, 1.3968406, 34.0861074>,
    <1.3289325, 1.3676276, 34.0972345>,
    <1.3825159, -1.3046285, 34.0680823>,
    <1.3463268, -1.3467228, 34.0861074>,
    <1.2244555, -1.4596671, 34.0861253>,
    <1.3420704, -1.3426256, 34.0592183>,
    <1.3669926, -1.3232404, 34.0759583>,
    <1.2940003, -1.3972227, 34.0861074>,
    <1.2919322, -1.3949872, 34.0708032>,
    <1.3650707, -1.3214722, 34.0642124>,
    <1.3250644, -1.3645107, 34.0748134>,
    <1.3891865, -1.2878429, 34.0484530>,
    <1.4147696, -1.2685942, 34.0642124>,
    <1.4077867, -1.2718559, 34.0551646>,
    <1.3968406, -1.2944089, 34.0861074>,
    <1.4118377, -1.2752040, 34.0748134>,
    <1.3097276, -1.3888113, 34.1038334>,
    <1.2285205, -1.4646320, 34.1125260>,
    <1.3279622, -1.3727563, 34.1076575>,
    <1.2306371, -1.4671923, 34.1237934>,
    <1.2748342, -1.4226594, 34.1076575>,
    <1.2816076, -1.4198618, 34.1168389>,
    <1.2265594, -1.4622554, 34.1010718>,
    <1.3259274, -1.3705731, 34.0961373>,
    <1.2781110, -1.4158593, 34.0972345>,
    <1.3676276, -1.3289325, 34.0972345>,
    <1.3152576, 1.3933719, 34.1894897>,
    <1.3524146, 1.3515566, 34.1809181>,
    <1.3317290, 1.3753099, 34.1857817>,
    <1.4067156, 1.3023241, 34.1920745>,
    <1.3351861, 1.3789026, 34.1968260>,
    <1.3766431, 1.3363953, 34.1957715>,
    <1.2298491, 1.4648736, 34.1809181>,
    <1.2330166, 1.4686113, 34.1920745>,
    <1.2784502, 1.4254021, 34.1857817>,
    <1.2865454, 1.4239642, 34.1957715>,
    <1.2233422, 1.4572506, 34.1544411>,
    <1.2268344, 1.4613203, 34.1694828>,
    <1.2966987, 1.3989006, 34.1694828>,
    <1.2809545, 1.4177517, 34.1766071>,
    <1.3888146, 1.3094879, 34.1722608>,
    <1.4230439, 1.2749500, 34.1760819>,
    <1.3731457, 1.3280828, 34.1760819>,
    <1.4212025, 1.2825708, 34.1852017>,
    <1.3450295, 1.3443928, 34.1544124>,
    <1.2927900, 1.3948426, 34.1544124>,
    <1.3698195, 1.3249609, 34.1645454>,
    <1.3283231, 1.3667364, 34.1656437>,
    <1.3954571, 1.2921329, 34.1544124>,
    <1.4151795, 1.2772763, 34.1656437>,
    <1.3789482, -1.3014589, 34.1359011>,
    <1.3382322, -1.3388644, 34.1264018>,
    <1.2226806, -1.4578058, 34.1544411>,
    <1.3443928, -1.3450295, 34.1544124>,
    <1.3613653, -1.3180308, 34.1317777>,
    <1.2886751, -1.3917573, 34.1387967>,
    <1.2921329, -1.3954571, 34.1544124>,
    <1.3640618, -1.3206400, 34.1440880>,
    <1.3221027, -1.3617241, 34.1429132>,
    <1.3948426, -1.2927900, 34.1544124>,
    <1.4109353, -1.2653001, 34.1317777>,
    <1.4087125, -1.2726016, 34.1429132>,
    <1.3859992, -1.2845302, 34.1138015>,
    <1.4041001, -1.2684274, 34.1216372>,
    <1.3094879, -1.3888146, 34.1722608>,
    <1.2290578, -1.4655376, 34.1809181>,
    <1.2749500, -1.4230439, 34.1760819>,
    <1.2321887, -1.4693060, 34.1920745>,
    <1.3280828, -1.3731457, 34.1760819>,
    <1.2825708, -1.4212025, 34.1852017>,
    <1.3249609, -1.3698195, 34.1645454>,
    <1.3667364, -1.3283231, 34.1656437>,
    <1.2260820, -1.4619516, 34.1694828>,
    <1.2772763, -1.4151795, 34.1656437>,
    <1.3046215, 1.3825170, 34.0680823>,
    <1.3425970, 1.3420749, 34.0592183>,
    <1.3232404, 1.3669926, 34.0759583>,
    <1.3949872, 1.2919322, 34.0708032>,
    <1.3214565, 1.3650732, 34.0642124>,
    <1.3645107, 1.3250644, 34.0748134>,
    <1.2116806, 1.4452411, 34.0361559>,
    <1.2208949, 1.4545596, 34.0592183>,
    <1.2877285, 1.3892045, 34.0484530>,
    <1.2183337, 1.4511990, 34.0484530>,
    <1.2685785, 1.4147721, 34.0642124>,
    <1.2717931, 1.4077966, 34.0551646>,
    <1.2227119, 1.4568011, 34.0708032>,
    <1.2752040, 1.4118377, 34.0748134>,
    <1.3795754, 1.3009197, 34.0506060>,
    <1.3639209, 1.3194262, 34.0541438>,
    <1.4134830, 1.2666561, 34.0541438>,
    <1.4106421, 1.2734755, 34.0633523>,
    <1.3332958, 1.3328550, 34.0364647>,
    <1.3817600, 1.2821432, 34.0364059>,
    <1.3604969, 1.3157872, 34.0438443>,
    <1.4055175, 1.2684359, 34.0448606>,
    <1.2817459, 1.3822496, 34.0364059>,
    <1.3192652, 1.3572890, 34.0448606>,
    <1.3602753, -1.2771685, 34.0264558>,
    <1.3327980, -1.3336563, 34.0364647>,
    <1.2127823, -1.4446229, 34.0361559>,
    <1.3237136, -1.2953363, 34.0228405>,
    <1.3486605, -1.3041927, 34.0303723>,
    <1.2820847, -1.3821306, 34.0364059>,
    <1.2778062, -1.3605161, 34.0277741>,
    <1.3458637, -1.2847009, 34.0246615>,
    <1.3109855, -1.3379891, 34.0296825>,
    <1.3665842, -1.2282357, 34.0186848>,
    <1.3855517, -1.2419647, 34.0246615>,
    <1.3774674, -1.2337304, 34.0213137>,
    <1.3821911, -1.2821164, 34.0364059>,
    <1.3893729, -1.2571975, 34.0296825>,
    <1.3009089, -1.3796433, 34.0506060>,
    <1.2204478, -1.4549588, 34.0592183>,
    <1.3194205, -1.3639568, 34.0541438>,
    <1.2223473, -1.4571070, 34.0708032>,
    <1.2666504, -1.4135190, 34.0541438>,
    <1.2734755, -1.4106421, 34.0633523>,
    <1.2175603, -1.4519444, 34.0484530>,
    <1.3157630, -1.3606497, 34.0438443>,
    <1.2684132, -1.4056612, 34.0448606>,
    <1.3572664, -1.3194089, 34.0448606>,
    <1.2761303, 1.3604393, 34.0264558>,
    <1.2938219, 1.3239527, 34.0228405>,
    <1.3035144, 1.3487677, 34.0303723>,
    <1.3595324, 1.2779615, 34.0277741>,
    <1.2834722, 1.3460578, 34.0246615>,
    <1.3372253, 1.3111061, 34.0296825>,
    <1.1902560, 1.4185113, 34.0228405>,
    <1.2261130, 1.3669195, 34.0186848>,
    <1.1789760, 1.4081428, 34.0186848>,
    <1.2407362, 1.3857457, 34.0246615>,
    <1.2320593, 1.3777314, 34.0213137>,
    <1.1990050, 1.4308045, 34.0277741>,
    <1.2564340, 1.3894935, 34.0296825>,
    <1.3356802, 1.2677268, 34.0204813>,
    <1.3167607, 1.2934971, 34.0215203>,
    <1.3738698, 1.2332064, 34.0215203>,
    <1.3724009, 1.2507868, 34.0248083>,
    <1.2870382, 1.2874585, 34.0159774>,
    <1.3434057, 1.2310917, 34.0159774>,
    <1.3160439, 1.2761322, 34.0185671>,
    <1.3619779, 1.2288444, 34.0186456>,
    <1.2306707, 1.3438254, 34.0159774>,
    <1.2711966, 1.3221705, 34.0186456>,
    <1.2674367, -1.3375195, 34.0204813>,
    <1.1898739, -1.4201070, 34.0228405>,
    <1.2932299, -1.3184540, 34.0215203>,
    <1.2006019, -1.4302928, 34.0277741>,
    <1.2329396, -1.3755627, 34.0215203>,
    <1.2505814, -1.3737033, 34.0248083>,
    <1.2870506, -1.2896250, 34.0159774>,
    <1.1814602, -1.4078456, 34.0186848>,
    <1.2306842, -1.3459919, 34.0159774>,
    <1.2757944, -1.3181861, 34.0185671>,
    <1.2285091, -1.3641063, 34.0186456>,
    <1.3434169, -1.2332581, 34.0159774>,
    <1.3218344, -1.2733258, 34.0186456>,
    <1.3014589, 1.3789482, 34.1359011>,
    <1.3388644, 1.3382322, 34.1264018>,
    <1.3180308, 1.3613653, 34.1317777>,
    <1.3917573, 1.2886751, 34.1387967>,
    <1.3206400, 1.3640618, 34.1440880>,
    <1.3617241, 1.3221027, 34.1429132>,
    <1.2175256, 1.4503985, 34.1264018>,
    <1.2198948, 1.4531804, 34.1387967>,
    <1.2653001, 1.4109353, 34.1317777>,
    <1.2726016, 1.4087125, 34.1429132>,
    <1.2129023, 1.4450211, 34.0973598>,
    <1.2153258, 1.4478201, 34.1138015>,
    <1.2845302, 1.3859992, 34.1138015>,
    <1.2684274, 1.4041001, 34.1216372>,
    <1.3755904, 1.2972078, 34.1168394>,
    <1.4091977, 1.2627211, 34.1210460>,
    <1.3597708, 1.3153443, 34.1210460>,
    <1.4066426, 1.2696183, 34.1311462>,
    <1.3335672, 1.3331316, 34.0973402>,
    <1.2817661, 1.3831515, 34.0973402>,
    <1.3573692, 1.3131061, 34.1083733>,
    <1.3161551, 1.3544248, 34.1095803>,
    <1.3835719, 1.2813167, 34.0973402>,
    <1.4022399, 1.2657721, 34.1095803>,
    <1.3686831, -1.2916106, 34.0775018>,
    <1.3285210, -1.3291097, 34.0677166>,
    <1.2124497, -1.4454009, 34.0973598>,
    <1.3331316, -1.3335672, 34.0973402>,
    <1.3513562, -1.3082318, 34.0732308>,
    <1.2790418, -1.3811128, 34.0805061>,
    <1.2813167, -1.3835719, 34.0973402>,
    <1.3534307, -1.3101504, 34.0861763>,
    <1.3119001, -1.3509962, 34.0849170>,
    <1.3831515, -1.2817661, 34.0973402>,
    <1.4005587, -1.2558836, 34.0732308>,
    <1.3978162, -1.2625744, 34.0849170>,
    <1.3750181, -1.2747410, 34.0557354>,
    <1.3935188, -1.2589975, 34.0632019>,
    <1.2972078, -1.3755904, 34.1168394>,
    <1.2169426, -1.4508877, 34.1264018>,
    <1.2627211, -1.4091977, 34.1210460>,
    <1.2192709, -1.4537040, 34.1387967>,
    <1.3153443, -1.3597708, 34.1210460>,
    <1.2696183, -1.4066426, 34.1311462>,
    <1.3131061, -1.3573692, 34.1083733>,
    <1.3544248, -1.3161551, 34.1095803>,
    <1.2147854, -1.4482735, 34.1138015>,
    <1.2657721, -1.4022399, 34.1095803>,
    <1.2916036, 1.3686841, 34.0775018>,
    <1.3290811, 1.3285255, 34.0677166>,
    <1.3082161, 1.3513587, 34.0732308>,
    <1.3811128, 1.2790418, 34.0805061>,
    <1.3101504, 1.3534307, 34.0861763>,
    <1.3509962, 1.3119001, 34.0849170>,
    <1.2086044, 1.4398807, 34.0677166>,
    <1.2105531, 1.4422737, 34.0805061>,
    <1.2558679, 1.4005612, 34.0732308>,
    <1.2625744, 1.3978162, 34.0849170>,
    <1.2010563, 1.4299897, 34.0420193>,
    <1.2059373, 1.4364018, 34.0557354>,
    <1.2746266, 1.3750361, 34.0557354>,
    <1.2589347, 1.3935287, 34.0632019>,
    <1.3655666, 1.2876787, 34.0581798>,
    <1.3991786, 1.2538068, 34.0621232>,
    <1.3501204, 1.3060417, 34.0621232>,
    <1.3965010, 1.2606730, 34.0723106>,
    <1.3202126, 1.3188806, 34.0422290>,
    <1.2689301, 1.3684426, 34.0422290>,
    <1.3465909, 1.3023111, 34.0506039>,
    <1.3057953, 1.3434006, 34.0517365>,
    <1.3697262, 1.2675537, 34.0422290>,
    <1.3911635, 1.2554564, 34.0517365>,
    <1.3435534, -1.2709229, 34.0309305>,
    <1.2972366, -1.3029270, 34.0269691>,
    <1.1996149, -1.4314828, 34.0420193>,
    <1.3188256, -1.3205625, 34.0422290>,
    <1.3238183, -1.2853410, 34.0289563>,
    <1.2567144, -1.3598632, 34.0327086>,
    <1.2674987, -1.3700762, 34.0422290>,
    <1.3337586, -1.2932219, 34.0352527>,
    <1.2919234, -1.3328194, 34.0346796>,
    <1.3683876, -1.2692800, 34.0422290>,
    <1.3721610, -1.2339824, 34.0289563>,
    <1.3767538, -1.2456109, 34.0346796>,
    <1.3341616, -1.2470538, 34.0224156>,
    <1.3582940, -1.2334455, 34.0249273>,
    <1.2876681, -1.3656344, 34.0581798>,
    <1.2081262, -1.4403061, 34.0677166>,
    <1.2538012, -1.3992145, 34.0621232>,
    <1.2101520, -1.4426103, 34.0805061>,
    <1.3060361, -1.3501563, 34.0621232>,
    <1.2606730, -1.3965010, 34.0723106>,
    <1.3022871, -1.3467434, 34.0506039>,
    <1.3433780, -1.3059388, 34.0517365>,
    <1.2051406, -1.4371667, 34.0557354>,
    <1.2554339, -1.3913071, 34.0517365>,
    <1.2698562, 1.3437990, 34.0309239>,
    <1.3010119, 1.2979146, 34.0269467>,
    <1.2839459, 1.3242129, 34.0289414>,
    <1.3590218, 1.2568468, 34.0327086>,
    <1.2925848, 1.3338588, 34.0352527>,
    <1.3321374, 1.2920306, 34.0346796>,
    <1.1831468, 1.4070701, 34.0269467>,
    <1.1912290, 1.4176424, 34.0327086>,
    <1.2325875, 1.3725556, 34.0289414>,
    <1.2449290, 1.3768610, 34.0346796>,
    <1.1759627, 1.3963349, 34.0223261>,
    <1.2428196, 1.3363346, 34.0223261>,
    <1.2307008, 1.3594264, 34.0248676>,
    <1.3321787, 1.2513348, 34.0235084>,
    <1.3660326, 1.2207852, 34.0249046>,
    <1.3180644, 1.2719638, 34.0248897>,
    <1.3686733, 1.2337777, 34.0290881>,
    <1.3126071, 1.2606918, 34.0209790>,
    <1.2724943, 1.3021414, 34.0211848>,
    <1.3560402, 1.2158309, 34.0212444>,
    <1.2494758, -1.3354648, 34.0235084>,
    <1.1793086, -1.4114217, 34.0269467>,
    <1.2198838, -1.3681703, 34.0248897>,
    <1.1890284, -1.4201979, 34.0327086>,
    <1.2709582, -1.3204450, 34.0249046>,
    <1.2335984, -1.3698133, 34.0290881>,
    <1.2567911, -1.3182077, 34.0209790>,
    <1.2987729, -1.2778609, 34.0212444>,
    <1.1680872, -1.4045798, 34.0223261>,
    <1.2128794, -1.3604348, 34.0211848>,
    <1.2642500, 1.6003031, 34.2894047>,
    <1.2184994, 1.6297957, 34.2882262>,
    <1.1876723, 1.6614469, 34.2918015>,
    <1.2521022, 1.6163305, 34.2918000>,
    <1.2459361, 1.6121729, 34.2888880>,
    <1.1986519, 1.6497373, 34.2903402>,
    <1.2196619, 1.6390466, 34.2918009>,
    <1.2601172, 1.6065462, 34.2904026>,
    <1.2301253, 1.6277569, 34.2903608>,
    <1.2848428, 1.5934039, 34.2917990>,
    <1.2862666, 1.5823032, 34.2888874>,
    <1.2884620, 1.5856040, 34.2903597>,
    <1.2456860, 1.6038175, 34.2859508>,
    <1.2724417, 1.5880005, 34.2873494>,
    <1.2538694, -1.6076667, 34.2894050>,
    <1.2380697, -1.6261577, 34.2918006>,
    <1.1658963, -1.6766950, 34.2917990>,
    <1.2076344, -1.6371970, 34.2882253>,
    <1.2480393, -1.6150644, 34.2904030>,
    <1.2005804, -1.6524085, 34.2917998>,
    <1.1801188, -1.6627146, 34.2903384>,
    <1.2349245, -1.6197961, 34.2888876>,
    <1.2144116, -1.6387605, 34.2903601>,
    <1.2468513, -1.6021747, 34.2859504>,
    <1.2791854, -1.5874741, 34.2888882>,
    <1.2688008, -1.5901987, 34.2873495>,
    <1.2774291, -1.5985973, 34.2918014>,
    <1.2805598, -1.5913785, 34.2903612>,
    <1.2334280, -1.5806717, 34.2989756>,
    <1.1893007, -1.6102577, 34.2975521>,
    <1.2111844, -1.6087857, 34.3035582>,
    <1.2156199, -1.5922656, 34.2980080>,
    <1.1590966, -1.6402523, 34.3007100>,
    <1.1685442, -1.6406537, 34.3035582>,
    <1.2238643, -1.5929501, 34.3008727>,
    <1.1902346, -1.6180750, 34.3007914>,
    <1.2538245, -1.5769177, 34.3035582>,
    <1.2604359, -1.5568814, 34.2980080>,
    <1.2601996, -1.5642732, 34.3007914>,
    <1.2201688, -1.5781520, 34.2937748>,
    <1.2483946, -1.5599952, 34.2951914>,
    <1.0357851, 1.7604331, 34.2894172>,
    <1.0459037, 1.7607143, 34.2918011>,
    <1.0771469, 1.7388383, 34.2918019>,
    <1.0560845, 1.7446026, 34.2886791>,
    <1.0401208, 1.7606509, 34.2904035>,
    <1.0595862, 1.7511341, 34.2918015>,
    <1.0674582, 1.7415424, 34.2903193>,
    <1.0427405, 1.7545040, 34.2889150>,
    <1.0526456, 1.7520306, 34.2903614>,
    <1.0048244, 1.7605513, 34.2830970>,
    <1.0079306, 1.7742503, 34.2886786>,
    <1.0413409, 1.7483751, 34.2867237>,
    <1.0044242, 1.7705349, 34.2867235>,
    <1.0245982, 1.7658774, 34.2889147>,
    <1.0269066, 1.7601313, 34.2874561>,
    <1.0128023, 1.7764431, 34.2903183>,
    <1.0348065, 1.7684842, 34.2918006>,
    <1.0282198, 1.7680693, 34.2903608>,
    <1.0986169, 1.7171476, 34.2894178>,
    <1.1266380, 1.7041844, 34.2918021>,
    <1.0763629, 1.7312277, 34.2889154>,
    <1.0998783, 1.7229217, 34.2918020>,
    <1.1090738, 1.7126361, 34.2904043>,
    <1.0862223, 1.7285203, 34.2903618>,
    <1.1314925, 1.6907875, 34.2882665>,
    <1.1562835, 1.6834261, 34.2918019>,
    <1.1666639, 1.6721359, 34.2903405>,
    <1.1105681, 1.7072770, 34.2889155>,
    <1.1361485, 1.6935615, 34.2903618>,
    <1.0853654, 1.7163490, 34.2861105>,
    <1.0740968, 1.7281526, 34.2874565>,
    <1.1672121, 1.6611963, 34.2863461>,
    <1.1516232, 1.6742080, 34.2872643>,
    <1.1907576, 1.6468143, 34.2872375>,
    <1.1778004, 1.6604329, 34.2889215>,
    <1.1432035, 1.6674063, 34.2816852>,
    <1.2043557, 1.6242773, 34.2818097>,
    <1.1584987, 1.6627144, 34.2844823>,
    <1.2046978, 1.6308761, 34.2848967>,
    <1.0834768, 1.7082877, 34.2819691>,
    <1.1161103, 1.6928708, 34.2850030>,
    <1.1635319, -1.6637579, 34.2863450>,
    <1.1194206, -1.6994102, 34.2882644>,
    <1.1821082, -1.6527229, 34.2872364>,
    <1.1474514, -1.6855888, 34.2903380>,
    <1.1424639, -1.6807346, 34.2872627>,
    <1.1618073, -1.6716316, 34.2889197>,
    <1.0251129, -1.7488804, 34.2830965>,
    <1.1761189, -1.6443067, 34.2816848>,
    <1.0849597, -1.7173122, 34.2861091>,
    <1.1144083, -1.6878859, 34.2819686>,
    <1.1668418, -1.6568379, 34.2844816>,
    <1.1212795, -1.6897041, 34.2850020>,
    <1.2357658, -1.6008194, 34.2818094>,
    <1.2107820, -1.6260246, 34.2848961>,
    <1.0856593, -1.7262709, 34.2894147>,
    <1.1079255, -1.7172870, 34.2917976>,
    <1.0975594, -1.7164990, 34.2889128>,
    <1.1349526, -1.6983623, 34.2917982>,
    <1.0934499, -1.7235761, 34.2904005>,
    <1.1182791, -1.7060738, 34.2903586>,
    <1.0663270, -1.7464146, 34.2917974>,
    <1.0502898, -1.7488151, 34.2886767>,
    <1.0849915, -1.7333456, 34.2917973>,
    <1.0584011, -1.7478844, 34.2903158>,
    <1.0669281, -1.7379473, 34.2889125>,
    <1.0737897, -1.7372258, 34.2903580>,
    <1.0418075, -1.7486678, 34.2867222>,
    <1.0687470, -1.7323514, 34.2874544>,
    <1.2043413, -1.6122537, 34.2751756>,
    <1.1515404, -1.6439364, 34.2713544>,
    <1.1903292, -1.6280635, 34.2782754>,
    <1.0952794, -1.6911740, 34.2765461>,
    <1.1807643, -1.6269890, 34.2735942>,
    <1.1380047, -1.6646255, 34.2779935>,
    <1.2082871, -1.5939246, 34.2658251>,
    <1.2422705, -1.5807828, 34.2735676>,
    <1.2313826, -1.5820422, 34.2692880>,
    <1.2449967, -1.5863903, 34.2778874>,
    <1.0318487, -1.7630806, 34.2894157>,
    <1.0412242, -1.7639918, 34.2917992>,
    <1.0386062, -1.7574526, 34.2889131>,
    <1.0521084, -1.7563706, 34.2917981>,
    <1.0358878, -1.7635556, 34.2904018>,
    <1.0463871, -1.7564133, 34.2903587>,
    <1.0043574, -1.7760244, 34.2886783>,
    <1.0325629, -1.7700564, 34.2918006>,
    <1.0086746, -1.7785759, 34.2903187>,
    <1.0216998, -1.7676614, 34.2889139>,
    <1.0250437, -1.7700546, 34.2903604>,
    <1.0055668, -1.7696558, 34.2867229>,
    <1.0267064, -1.7604851, 34.2874549>,
    <1.1264011, -1.6571454, 34.2989756>,
    <1.1044244, -1.6660310, 34.2967794>,
    <1.0671887, -1.7096137, 34.3035582>,
    <1.1186225, -1.6596280, 34.2980080>,
    <1.0461716, -1.7148041, 34.3007507>,
    <1.0378311, -1.7281597, 34.3035582>,
    <1.1027317, -1.6783435, 34.3008727>,
    <1.0756601, -1.6957884, 34.3007914>,
    <1.0965463, -1.6910677, 34.3035582>,
    <1.1574853, -1.6335468, 34.2980080>,
    <1.1302365, -1.6600866, 34.3007914>,
    <1.1697261, -1.6111843, 34.2926777>,
    <1.1718518, -1.6158894, 34.2951914>,
    <1.1031676, 1.6831117, 34.2751756>,
    <1.1507388, 1.6443410, 34.2713146>,
    <1.1228835, 1.6753241, 34.2782756>,
    <1.2137517, 1.6075921, 34.2763869>,
    <1.1248870, 1.6660102, 34.2735677>,
    <1.1744662, 1.6386771, 34.2778875>,
    <0.9968289, 1.7251982, 34.2582471>,
    <1.0036385, 1.7389589, 34.2713545>,
    <1.0845407, 1.6805728, 34.2658251>,
    <1.0010068, 1.7323362, 34.2658251>,
    <1.0608265, 1.7079703, 34.2735942>,
    <1.0654758, 1.6982114, 34.2692880>,
    <1.0047563, 1.7471438, 34.2765463>,
    <1.0659379, 1.7123250, 34.2779937>,
    <1.1959769, 1.6056427, 34.2672229>,
    <1.1765034, 1.6228085, 34.2690713>,
    <1.2377223, 1.5770034, 34.2690713>,
    <1.2338056, 1.5872775, 34.2733316>,
    <1.1428345, 1.6309008, 34.2582019>,
    <1.2043398, 1.5861688, 34.2582019>,
    <1.1729918, 1.6168585, 34.2634197>,
    <1.2285960, 1.5760402, 34.2639559>,
    <1.0797896, 1.6734377, 34.2582019>,
    <1.1226764, 1.6525789, 34.2639559>,
    <1.1831012, -1.5902627, 34.2481381>,
    <1.1416731, -1.6317140, 34.2582019>,
    <0.9956511, -1.7258783, 34.2582471>,
    <1.1332638, -1.6198418, 34.2427102>,
    <1.1652449, -1.6085838, 34.2526827>,
    <1.0786026, -1.6742109, 34.2582019>,
    <1.0740519, -1.6673020, 34.2497196>,
    <1.1614982, -1.6034782, 34.2458152>,
    <1.1144011, -1.6431058, 34.2520259>,
    <1.1906802, -1.5705751, 34.2353389>,
    <1.2220982, -1.5582067, 34.2458152>,
    <1.2132079, -1.5585815, 34.2399571>,
    <1.2032073, -1.5870197, 34.2582019>,
    <1.2198460, -1.5670230, 34.2520259>,
    <1.0997450, -1.6730714, 34.2672347>,
    <1.0043521, -1.7385497, 34.2713544>,
    <1.1225140, -1.6607167, 34.2690979>,
    <1.0114477, -1.7432919, 34.2765461>,
    <1.0585333, -1.7025773, 34.2690979>,
    <1.0694095, -1.7028066, 34.2734378>,
    <0.9997437, -1.7330654, 34.2658251>,
    <1.1181632, -1.6552499, 34.2634197>,
    <1.0607888, -1.6935400, 34.2639559>,
    <1.1689383, -1.6201860, 34.2639559>,
    <1.0618685, 1.6992888, 34.2989756>,
    <1.1043770, 1.6676394, 34.2975521>,
    <1.0950431, 1.6877475, 34.3035582>,
    <1.0786007, 1.6863279, 34.2980080>,
    <1.1415701, 1.6489172, 34.3007100>,
    <1.1380014, 1.6576921, 34.3035582>,
    <1.0763011, 1.6943818, 34.3008727>,
    <1.1104969, 1.6708473, 34.3007914>,
    <0.9880629, 1.7392061, 34.2967794>,
    <1.0520848, 1.7178029, 34.3035582>,
    <0.9986386, 1.7438626, 34.3007507>,
    <1.0308991, 1.7168428, 34.2980080>,
    <1.0379689, 1.7193036, 34.3007914>,
    <1.0026881, 1.7123945, 34.2867877>,
    <0.9883337, 1.7307165, 34.2926777>,
    <1.0646411, 1.6860771, 34.2937748>,
    <1.0379214, 1.7064591, 34.2951914>,
    <1.1703983, 1.6248274, 34.2989756>,
    <1.1875287, 1.6078107, 34.2967794>,
    <1.2391338, 1.5868540, 34.3035582>,
    <1.1760288, 1.6186687, 34.2980080>,
    <1.2536300, 1.5700721, 34.3007507>,
    <1.2682209, 1.5664627, 34.3035582>,
    <1.1980508, 1.6097061, 34.3008727>,
    <1.2247787, 1.5907958, 34.3007914>,
    <1.2100468, 1.6072454, 34.3035582>,
    <1.1373107, 1.6457931, 34.2980080>,
    <1.1705347, 1.6288084, 34.3007914>,
    <1.1135973, 1.6502736, 34.2926777>,
    <1.1166632, 1.6536214, 34.2951914>,
    <1.1979373, 1.5926975, 34.2933120>,
    <1.2312623, 1.5708787, 34.2949171>,
    <1.1924604, 1.6002562, 34.2949171>,
    <1.2413209, 1.5714399, 34.2980246>,
    <1.1387064, 1.6212282, 34.2854038>,
    <1.0803935, 1.6613253, 34.2856693>,
    <1.1704134, 1.6062966, 34.2900253>,
    <1.1331183, 1.6337302, 34.2908029>,
    <1.1996202, 1.5772750, 34.2856693>,
    <1.2206698, 1.5702784, 34.2908029>,
    <1.1761667, -1.5817235, 34.2753407>,
    <1.1261382, -1.6110252, 34.2695801>,
    <0.9815386, -1.7247225, 34.2867877>,
    <1.1339108, -1.6244792, 34.2854038>,
    <1.1545352, -1.5947853, 34.2729301>,
    <1.0660052, -1.6601221, 34.2772285>,
    <1.0717741, -1.6668698, 34.2856693>,
    <1.1582083, -1.6005031, 34.2800513>,
    <1.1068833, -1.6354607, 34.2795037>,
    <1.1915413, -1.5834306, 34.2856693>,
    <1.2148608, -1.5498235, 34.2729301>,
    <1.2120153, -1.5600080, 34.2795037>,
    <1.1833777, -1.5610745, 34.2614925>,
    <1.2060181, -1.5494677, 34.2665723>,
    <1.0867035, -1.6704619, 34.2933120>,
    <1.0117733, -1.7254772, 34.2967794>,
    <1.0547622, -1.6945519, 34.2949171>,
    <1.0103661, -1.7364590, 34.3007507>,
    <1.0956476, -1.6677966, 34.2949171>,
    <1.0517480, -1.7038948, 34.2980246>,
    <1.1089646, -1.6491368, 34.2900253>,
    <1.1474987, -1.6235010, 34.2908029>,
    <1.0044226, -1.7215909, 34.2926777>,
    <1.0579190, -1.6843886, 34.2908029>,
    <1.0897138, 1.6556533, 34.2481381>,
    <1.1345543, 1.6189381, 34.2427102>,
    <1.1130371, 1.6451401, 34.2526827>,
    <1.1994040, 1.5795295, 34.2497196>,
    <1.1095209, 1.6398731, 34.2458152>,
    <1.1628668, 1.6091698, 34.2520259>,
    <0.9825947, 1.7007009, 34.2254060>,
    <0.9893942, 1.7123400, 34.2427102>,
    <1.0686212, 1.6560417, 34.2353389>,
    <0.9863152, 1.7070403, 34.2353389>,
    <1.0462532, 1.6813348, 34.2458152>,
    <1.0496460, 1.6731088, 34.2399571>,
    <0.9925477, 1.7177725, 34.2497196>,
    <1.0553081, 1.6822337, 34.2520259>,
    <1.1785750, 1.5818583, 34.2371711>,
    <1.1595532, 1.5983283, 34.2396408>,
    <1.2198721, 1.5531997, 34.2396408>,
    <1.2172557, 1.5614260, 34.2454279>,
    <1.1265279, 1.6077552, 34.2253660>,
    <1.1871597, 1.5636613, 34.2253660>,
    <1.1559366, 1.5934623, 34.2321345>,
    <1.2107037, 1.5531912, 34.2328481>,
    <1.0643784, 1.6496849, 34.2253660>,
    <1.1063136, 1.6286193, 34.2328481>,
    <1.1669837, -1.5684591, 34.2126378>,
    <1.1255005, -1.6084746, 34.2253660>,
    <0.9815528, -1.7013025, 34.2254060>,
    <1.1181708, -1.5980988, 34.2059260>,
    <1.1490840, -1.5861429, 34.2183311>,
    <1.0633285, -1.6503688, 34.2253660>,
    <1.0593433, -1.6443029, 34.2146338>,
    <1.1458258, -1.5816914, 34.2097470>,
    <1.0989937, -1.6202399, 34.2175110>,
    <1.1752920, -1.5501122, 34.1969055>,
    <1.2055973, -1.5370349, 34.2097470>,
    <1.1972178, -1.5378899, 34.2025384>,
    <1.1861579, -1.5644140, 34.2253660>,
    <1.2029638, -1.5452150, 34.2175110>,
    <1.0833642, -1.6485256, 34.2371711>,
    <0.9882328, -1.7130105, 34.2427102>,
    <1.1053468, -1.6362840, 34.2396408>,
    <0.9913608, -1.7184578, 34.2497196>,
    <1.0423095, -1.6775304, 34.2396408>,
    <1.0509345, -1.6778853, 34.2454279>,
    <0.9851827, -1.7076942, 34.2353389>,
    <1.1020112, -1.6312212, 34.2321345>,
    <1.0454373, -1.6689120, 34.2328481>,
    <1.1520201, -1.5966153, 34.2328481>,
    <1.0840650, 1.6462353, 34.2753407>,
    <1.1286743, 1.6092223, 34.2695801>,
    <1.1037178, 1.6303604, 34.2729301>,
    <1.1952800, 1.5694940, 34.2772285>,
    <1.1078589, 1.6358064, 34.2800513>,
    <1.1581902, 1.5995046, 34.2795037>,
    <0.9844123, 1.7022177, 34.2695801>,
    <0.9898211, 1.7074758, 34.2772285>,
    <1.0408485, 1.6716739, 34.2729301>,
    <1.0513848, 1.6725052, 34.2795037>,
    <0.9762696, 1.6896252, 34.2505667>,
    <0.9803787, 1.6966273, 34.2614925>,
    <1.0621912, 1.6459303, 34.2614925>,
    <1.0435409, 1.6632355, 34.2665723>,
    <1.1717316, 1.5722162, 34.2635082>,
    <1.2131281, 1.5437702, 34.2662252>,
    <1.1531708, 1.5886317, 34.2662252>,
    <1.2120298, 1.5516690, 34.2725930>,
    <1.1192686, 1.5972787, 34.2505227>,
    <1.0575241, 1.6389378, 34.2505227>,
    <1.1488027, 1.5835111, 34.2579678>,
    <1.0995285, 1.6184986, 34.2587527>,
    <1.1795052, 1.5534694, 34.2505227>,
    <1.2032634, 1.5435384, 34.2587527>,
    <1.1588080, -1.5575802, 34.2365221>,
    <1.1100759, -1.5866567, 34.2291393>,
    <0.9751235, -1.6902869, 34.2505667>,
    <1.1181386, -1.5980700, 34.2505227>,
    <1.1376809, -1.5705631, 34.2333423>,
    <1.0519855, -1.6330176, 34.2387176>,
    <1.0563692, -1.6396902, 34.2505227>,
    <1.1412649, -1.5754598, 34.2427845>,
    <1.0914766, -1.6092812, 34.2418824>,
    <1.1784032, -1.5542973, 34.2505227>,
    <1.1970360, -1.5262208, 34.2333423>,
    <1.1947496, -1.5347646, 34.2418824>,
    <1.1664508, -1.5385654, 34.2192172>,
    <1.1884291, -1.5267070, 34.2254131>,
    <1.0766426, -1.6388073, 34.2635082>,
    <0.9819506, -1.7036448, 34.2695801>,
    <1.0357516, -1.6679908, 34.2662252>,
    <0.9837789, -1.7109876, 34.2772285>,
    <1.0984142, -1.6269929, 34.2662252>,
    <1.0435388, -1.6697286, 34.2725930>,
    <1.0951000, -1.6211141, 34.2579678>,
    <1.1448302, -1.5867780, 34.2587527>,
    <0.9791330, -1.6973465, 34.2614925>,
    <1.0389113, -1.6586190, 34.2587527>,
    <1.0747376, 1.6330506, 34.2126378>,
    <1.1192848, 1.5973188, 34.2059260>,
    <1.0974770, 1.6222786, 34.2183311>,
    <1.1828226, 1.5578418, 34.2146338>,
    <1.0944083, 1.6176944, 34.2097470>,
    <1.1466495, 1.5868709, 34.2175110>,
    <0.9702824, 1.6795689, 34.1849198>,
    <0.9760762, 1.6894559, 34.2059260>,
    <1.0546554, 1.6345828, 34.1969055>,
    <0.9734273, 1.6849084, 34.1969055>,
    <1.0320018, 1.6585878, 34.2097470>,
    <1.0356712, 1.6510061, 34.2025384>,
    <0.9788174, 1.6941668, 34.2146338>,
    <1.0405893, 1.6589109, 34.2175110>,
    <1.1630766, 1.5612043, 34.1991181>,
    <1.1441468, 1.5772459, 34.2021355>,
    <1.2036757, 1.5327127, 34.2021355>,
    <1.2007119, 1.5403453, 34.2092829>,
    <1.1124269, 1.5877929, 34.1848862>,
    <1.1723053, 1.5442506, 34.1848862>,
    <1.1410489, 1.5730898, 34.1929998>,
    <1.1950720, 1.5332752, 34.1938690>,
    <1.0510498, 1.6291976, 34.1848862>,
    <1.0920123, 1.6077349, 34.1938690>,
    <1.1533504, -1.5499610, 34.1698789>,
    <1.1115649, -1.5883965, 34.1848862>,
    <0.9694081, -1.6800736, 34.1849198>,
    <1.1055373, -1.5798326, 34.1620860>,
    <1.1352989, -1.5669481, 34.1765488>,
    <1.0501689, -1.6297715, 34.1848862>,
    <1.0468703, -1.6247328, 34.1722289>,
    <1.1326281, -1.5632859, 34.1665078>,
    <1.0858702, -1.6007037, 34.1755900>,
    <1.1625902, -1.5331578, 34.1516897>,
    <1.1916977, -1.5191488, 34.1665078>,
    <1.1838982, -1.5205963, 34.1581668>,
    <1.1714647, -1.5448822, 34.1848862>,
    <1.1885775, -1.5265823, 34.1755900>,
    <1.0692565, -1.6268978, 34.1991181>,
    <0.9750736, -1.6900347, 34.2059260>,
    <1.0908051, -1.6145962, 34.2021355>,
    <0.9777828, -1.6947642, 34.2146338>,
    <1.0285975, -1.6553038, 34.2021355>,
    <1.0367835, -1.6551293, 34.2092829>,
    <0.9724598, -1.6854670, 34.1969055>,
    <1.0879592, -1.6102636, 34.1929998>,
    <1.0320686, -1.6474114, 34.1938690>,
    <1.1372864, -1.5760336, 34.1938690>,
    <1.0673109, 1.6216471, 34.2365221>,
    <1.1113012, 1.5857986, 34.2291393>,
    <1.0867368, 1.6062345, 34.2333423>,
    <1.1747344, 1.5470679, 34.2387176>,
    <1.0901123, 1.6112772, 34.2427845>,
    <1.1389226, 1.5760591, 34.2418824>,
    <0.9691158, 1.6772844, 34.2291393>,
    <0.9721312, 1.6824665, 34.2387176>,
    <1.0247680, 1.6468442, 34.2333423>,
    <1.0335785, 1.6476178, 34.2418824>,
    <0.9627261, 1.6663800, 34.2060335>,
    <0.9662021, 1.6722822, 34.2192172>,
    <1.0468289, 1.6223255, 34.2192172>,
    <1.0281686, 1.6389226, 34.2254131>,
    <1.1545102, 1.5495999, 34.2216509>,
    <1.1949223, 1.5214665, 34.2249699>,
    <1.1358340, 1.5656730, 34.2249699>,
    <1.1922725, 1.5294079, 34.2328318>,
    <1.1037576, 1.5753202, 34.2059966>,
    <1.0428627, 1.6164018, 34.2059966>,
    <1.1324263, 1.5611013, 34.2149211>,
    <1.0837972, 1.5955257, 34.2158771>,
    <1.1631655, 1.5321177, 34.2059966>,
    <1.1860687, 1.5216308, 34.2158771>,
    <1.1438114, -1.5372323, 34.1894897>,
    <1.0961791, -1.5665637, 34.1809181>,
    <0.9617644, -1.6669352, 34.2060335>,
    <1.1028094, -1.5759841, 34.2059966>,
    <1.1231635, -1.5503171, 34.1857817>,
    <1.0382653, -1.6114906, 34.1920745>,
    <1.0418937, -1.6170331, 34.2059966>,
    <1.1261014, -1.5543455, 34.1968260>,
    <1.0770409, -1.5877914, 34.1957715>,
    <1.1622408, -1.5328124, 34.2059966>,
    <1.1817465, -1.5065461, 34.1857817>,
    <1.1789248, -1.5142687, 34.1957715>,
    <1.1524788, -1.5199155, 34.1694828>,
    <1.1737775, -1.5076839, 34.1766071>,
    <1.0612818, -1.6148791, 34.2216509>,
    <0.9680130, -1.6779211, 34.2291393>,
    <1.0210233, -1.6432318, 34.2249699>,
    <0.9709931, -1.6831236, 34.2387176>,
    <1.0827733, -1.6028266, 34.2249699>,
    <1.0293921, -1.6434580, 34.2328318>,
    <1.0796428, -1.5980608, 34.2149211>,
    <1.1286233, -1.5641382, 34.2158771>,
    <0.9651378, -1.6728967, 34.2192172>,
    <1.0242058, -1.6349684, 34.2158771>,
    <1.0620179, 1.6139127, 34.1698789>,
    <1.1064409, 1.5791998, 34.1620860>,
    <1.0841545, 1.6027599, 34.1765488>,
    <1.1686987, 1.5394277, 34.1722289>,
    <1.0816266, 1.5989976, 34.1665078>,
    <1.1327799, 1.5678571, 34.1755900>,
    <0.9602660, 1.6624443, 34.1380150>,
    <0.9648730, 1.6702700, 34.1620860>,
    <1.0430677, 1.6168483, 34.1516897>,
    <0.9627348, 1.6666129, 34.1516897>,
    <1.0199483, 1.6394091, 34.1665078>,
    <1.0239760, 1.6325750, 34.1581668>,
    <0.9671187, 1.6741162, 34.1722289>,
    <1.0280007, 1.6390195, 34.1755900>,
    <1.1501811, 1.5440762, 34.1542153>,
    <1.1312662, 1.5596799, 34.1576891>,
    <1.1901390, 1.5156429, 34.1576891>,
    <1.1867325, 1.5225880, 34.1659804>,
    <1.1009601, 1.5716204, 34.1379890>,
    <1.1602281, 1.5285265, 34.1379890>,
    <1.1287812, 1.5563600, 34.1472010>,
    <1.1821760, 1.5168972, 34.1481994>,
    <1.0402090, 1.6125982, 34.1379890>,
    <1.0802073, 1.5905602, 34.1481994>,
    <1.1426155, -1.5353305, 34.1211611>,
    <1.1002895, -1.5720899, 34.1379890>,
    <0.9595859, -1.6628369, 34.1380150>,
    <1.0957474, -1.5655980, 34.1125260>,
    <1.1243085, -1.5515826, 34.1286034>,
    <1.0395237, -1.6130446, 34.1379890>,
    <1.0370120, -1.6091864, 34.1237934>,
    <1.1223063, -1.5488210, 34.1174128>,
    <1.0754295, -1.5850909, 34.1275355>,
    <1.1529608, -1.5202269, 34.1010718>,
    <1.1808218, -1.5050920, 34.1174128>,
    <1.1736538, -1.5072259, 34.1081947>,
    <1.1595742, -1.5290178, 34.1379890>,
    <1.1771242, -1.5116911, 34.1275355>,
    <1.0575719, -1.6089219, 34.1542153>,
    <0.9640597, -1.6707395, 34.1620860>,
    <1.0787039, -1.5964845, 34.1576891>,
    <0.9662678, -1.6746075, 34.1722289>,
    <1.0171869, -1.6367453, 34.1576891>,
    <1.0248783, -1.6359195, 34.1659804>,
    <0.9619616, -1.6670593, 34.1516897>,
    <1.0764341, -1.5930138, 34.1472010>,
    <1.0210891, -1.6296915, 34.1481994>,
    <1.1251850, -1.5590664, 34.1481994>,
    <1.0519412, 1.5988213, 34.1211611>,
    <1.0964132, 1.5651317, 34.1125260>,
    <1.0734746, 1.5871769, 34.1286034>,
    <1.1574616, 1.5248467, 34.1237934>,
    <1.0715643, 1.5843510, 34.1174128>,
    <1.1216796, 1.5527062, 34.1275355>,
    <0.9528499, 1.6498473, 34.0861253>,
    <0.9561251, 1.6553653, 34.1125260>,
    <1.0342102, 1.6033769, 34.1010718>,
    <0.9545626, 1.6527097, 34.1010718>,
    <1.0104590, 1.6243813, 34.1174128>,
    <1.0149159, 1.6183754, 34.1081947>,
    <0.9578070, 1.6582299, 34.1237934>,
    <1.0179248, 1.6231638, 34.1275355>,
    <1.1402803, 1.5309945, 34.1038334>,
    <1.1213029, 1.5461641, 34.1076575>,
    <1.1796733, 1.5025088, 34.1076575>,
    <1.1757421, 1.5086935, 34.1168389>,
    <1.0924758, 1.5597290, 34.0861074>,
    <1.1512949, 1.5169667, 34.0861074>,
    <1.1195061, 1.5437811, 34.0961373>,
    <1.1724075, 1.5045550, 34.0972345>,
    <1.0321851, 1.6003912, 34.0861074>,
    <1.0712570, 1.5776170, 34.0972345>,
    <1.1349664, -1.5248804, 34.0680823>,
    <1.0920171, -1.5600502, 34.0861074>,
    <0.9523847, -1.6501159, 34.0861253>,
    <1.0885386, -1.5552793, 34.0592183>,
    <1.1164467, -1.5405132, 34.0759583>,
    <1.0317164, -1.6006965, 34.0861074>,
    <1.0300679, -1.5981359, 34.0708032>,
    <1.1148620, -1.5384398, 34.0642124>,
    <1.0679889, -1.5738757, 34.0748134>,
    <1.1444574, -1.5095197, 34.0484530>,
    <1.1729880, -1.4949953, 34.0642124>,
    <1.1655478, -1.4969999, 34.0551646>,
    <1.1508477, -1.5173027, 34.0861074>,
    <1.1689519, -1.5009938, 34.0748134>,
    <1.0486654, -1.5951439, 34.1038334>,
    <0.9555259, -1.6557113, 34.1125260>,
    <1.0694108, -1.5824993, 34.1076575>,
    <0.9571657, -1.6586002, 34.1237934>,
    <1.0084244, -1.6224186, 34.1076575>,
    <1.0155806, -1.6208397, 34.1168389>,
    <0.9540072, -1.6530303, 34.1010718>,
    <1.0677861, -1.5799959, 34.0961373>,
    <1.0128322, -1.6162908, 34.0972345>,
    <1.1160835, -1.5462291, 34.0972345>,
    <1.0533193, 1.6005956, 34.1894897>,
    <1.0971731, 1.5658678, 34.1809181>,
    <1.0726770, 1.5856681, 34.1857817>,
    <1.1591982, 1.5268124, 34.1920745>,
    <1.0754576, 1.5898066, 34.1968260>,
    <1.1236662, 1.5551440, 34.1957715>,
    <0.9567923, 1.6561800, 34.1809181>,
    <0.9592626, 1.6604108, 34.1920745>,
    <1.0115092, 1.6257476, 34.1857817>,
    <1.0197311, 1.6257373, 34.1957715>,
    <0.9517080, 1.6475429, 34.1544411>,
    <0.9544404, 1.6521571, 34.1694828>,
    <1.0340824, 1.6028176, 34.1694828>,
    <1.0153039, 1.6186483, 34.1766071>,
    <1.1403252, 1.5307590, 34.1722608>,
    <1.1800319, 1.5026896, 34.1760819>,
    <1.1216654, 1.5463505, 34.1760819>,
    <1.1768952, 1.5098749, 34.1852017>,
    <1.0911441, 1.5575303, 34.1544124>,
    <1.0309377, 1.5981425, 34.1544124>,
    <1.1189318, 1.5426985, 34.1645454>,
    <1.0708116, 1.5766335, 34.1656437>,
    <1.1498805, 1.5148211, 34.1544124>,
    <1.1718831, 1.5036150, 34.1656437>,
    <1.1320029, -1.5211387, 34.1359011>,
    <1.0854101, -1.5509057, 34.1264018>,
    <0.9509600, -1.6479748, 34.1544411>,
    <1.0904065, -1.5580468, 34.1544124>,
    <1.1118095, -1.5344056, 34.1317777>,
    <1.0274211, -1.5943895, 34.1387967>,
    <1.0301839, -1.5986335, 34.1544124>,
    <1.1140119, -1.5374434, 34.1440880>,
    <1.0655561, -1.5706173, 34.1429132>,
    <1.1491612, -1.5153615, 34.1544124>,
    <1.1697830, -1.4910836, 34.1317777>,
    <1.1663261, -1.4978883, 34.1429132>,
    <1.1418864, -1.5056916, 34.1138015>,
    <1.1625086, -1.4929766, 34.1216372>,
    <1.0484287, -1.5951056, 34.1722608>,
    <0.9558978, -1.6566965, 34.1809181>,
    <1.0084717, -1.6228174, 34.1760819>,
    <0.9583266, -1.6609512, 34.1920745>,
    <1.0694619, -1.5829037, 34.1760819>,
    <1.0162964, -1.6223273, 34.1852017>,
    <1.0669652, -1.5790859, 34.1645454>,
    <1.1153117, -1.5454742, 34.1656437>,
    <0.9535898, -1.6526482, 34.1694828>,
    <1.0121283, -1.6154765, 34.1656437>,
    <1.0447293, 1.5880592, 34.0680823>,
    <1.0891488, 1.5548279, 34.0592183>,
    <1.0657616, 1.5760032, 34.0759583>,
    <1.1494525, 1.5145418, 34.0708032>,
    <1.0643369, 1.5738046, 34.0642124>,
    <1.1136857, 1.5418784, 34.0748134>,
    <0.9422796, 1.6337248, 34.0361559>,
    <0.9497628, 1.6444704, 34.0592183>,
    <1.0269230, 1.5917218, 34.0484530>,
    <0.9478172, 1.6407241, 34.0484530>,
    <1.0036321, 1.6135663, 34.0642124>,
    <1.0080053, 1.6072594, 34.0551646>,
    <0.9511653, 1.6469907, 34.0708032>,
    <1.0106677, 1.6118256, 34.0748134>,
    <1.1327088, 1.5207228, 34.0506060>,
    <1.1140811, 1.5362268, 34.0541438>,
    <1.1720536, 1.4928648, 34.0541438>,
    <1.1680746, 1.4990839, 34.0633523>,
    <1.0815634, 1.5441638, 34.0364647>,
    <1.1380964, 1.5026393, 34.0364059>,
    <1.1113317, 1.5320594, 34.0438443>,
    <1.1638914, 1.4932445, 34.0448606>,
    <1.0222185, 1.5838575, 34.0364059>,
    <1.0635203, 1.5657701, 34.0448606>,
    <1.1178982, -1.4940860, 34.0264558>,
    <1.0809859, -1.5448716, 34.0364647>,
    <0.9435248, -1.6333121, 34.0361559>,
    <1.0787679, -1.5056798, 34.0228405>,
    <1.1017441, -1.5186442, 34.0303723>,
    <1.0226262, -1.5838043, 34.0364059>,
    <1.0222057, -1.5618407, 34.0277741>,
    <1.1024098, -1.4990218, 34.0246615>,
    <1.0587783, -1.5453940, 34.0296825>,
    <1.1326779, -1.4471083, 34.0186848>,
    <1.1489158, -1.4638267, 34.0246615>,
    <1.1424126, -1.4543611, 34.0213137>,
    <1.1385791, -1.5026928, 34.0364059>,
    <1.1500040, -1.4794418, 34.0296825>,
    <1.0415770, -1.5845911, 34.0506060>,
    <0.9492574, -1.6447863, 34.0592183>,
    <1.0625292, -1.5723541, 34.0541438>,
    <0.9507531, -1.6472287, 34.0708032>,
    <1.0019544, -1.6119998, 34.0541438>,
    <1.0091731, -1.6103480, 34.0633523>,
    <0.9469428, -1.6413254, 34.0484530>,
    <1.0595091, -1.5684745, 34.0438443>,
    <1.0050619, -1.6045791, 34.0448606>,
    <1.1075427, -1.5350663, 34.0448606>,
    <1.0204223, 1.5614655, 34.0264558>,
    <1.0441422, 1.5286501, 34.0228405>,
    <1.0494459, 1.5546929, 34.0303723>,
    <1.1168830, 1.4947188, 34.0277741>,
    <1.0301347, 1.5485952, 34.0246615>,
    <1.0891776, 1.5234654, 34.0296825>,
    <0.9257303, 1.6037878, 34.0228405>,
    <0.9699529, 1.5592630, 34.0186848>,
    <0.9163740, 1.5916746, 34.0186848>,
    <0.9811564, 1.5802590, 34.0246615>,
    <0.9739677, 1.5709010, 34.0213137>,
    <0.9322540, 1.6173641, 34.0277741>,
    <0.9960020, 1.5866325, 34.0296825>,
    <1.0951000, 1.4805786, 34.0204813>,
    <1.0720057, 1.5026578, 34.0215203>,
    <1.1387148, 1.4532009, 34.0215203>,
    <1.1342481, 1.4702220, 34.0248083>,
    <1.0437097, 1.4916342, 34.0159774>,
    <1.1090064, 1.4459132, 34.0159774>,
    <1.0742778, 1.4854750, 34.0185671>,
    <1.1277248, 1.4468816, 34.0186456>,
    <0.9784130, 1.5373553, 34.0159774>,
    <1.0221202, 1.5230240, 34.0186456>,
    <1.0160425, -1.5374841, 34.0204813>,
    <0.9252964, -1.6053130, 34.0228405>,
    <1.0447448, -1.5231718, 34.0215203>,
    <0.9340581, -1.6171506, 34.0277741>,
    <0.9754542, -1.5689431, 34.0215203>,
    <0.9931254, -1.5701339, 34.0248083>,
    <1.0437235, -1.4938029, 34.0159774>,
    <0.9191794, -1.5918415, 34.0186848>,
    <0.9784263, -1.5395250, 34.0159774>,
    <1.0276500, -1.5199280, 34.0185671>,
    <0.9731088, -1.5569377, 34.0186456>,
    <1.1090207, -1.4480809, 34.0159774>,
    <1.0807791, -1.4837430, 34.0186456>,
    <1.0422350, 1.5839949, 34.1359011>,
    <1.0861425, 1.5503928, 34.1264018>,
    <1.0616084, 1.5695568, 34.1317777>,
    <1.1468373, 1.5107733, 34.1387967>,
    <1.0637097, 1.5726653, 34.1440880>,
    <1.1114558, 1.5384779, 34.1429132>,
    <0.9471696, 1.6397848, 34.1264018>,
    <0.9490198, 1.6429359, 34.1387967>,
    <1.0010710, 1.6092170, 34.1317777>,
    <1.0086476, 1.6082960, 34.1429132>,
    <0.9435503, 1.6336862, 34.0973598>,
    <0.9454509, 1.6368636, 34.1138015>,
    <1.0243391, 1.5879990, 34.1138015>,
    <1.0053377, 1.6030287, 34.1216372>,
    <1.1294343, 1.5163691, 34.1168394>,
    <1.1685196, 1.4882421, 34.1210460>,
    <1.1107057, 1.5314829, 34.1210460>,
    <1.1648057, 1.4945908, 34.1311462>,
    <1.0818114, 1.5444498, 34.0973402>,
    <1.0221115, 1.5847147, 34.0973402>,
    <1.1087293, 1.5288617, 34.1083733>,
    <1.0609663, 1.5623959, 34.1095803>,
    <1.1400540, 1.5021053, 34.0973402>,
    <1.1611377, 1.4900385, 34.1095803>,
    <1.1236043, -1.5096581, 34.0775018>,
    <1.0775422, -1.5396158, 34.0677166>,
    <0.9430386, -1.6339816, 34.0973598>,
    <1.0813069, -1.5448031, 34.0973402>,
    <1.1036550, -1.5230191, 34.0732308>,
    <1.0197825, -1.5822339, 34.0805061>,
    <1.0215958, -1.5850506, 34.0973402>,
    <1.1053638, -1.5252670, 34.0861763>,
    <1.0573714, -1.5582806, 34.0849170>,
    <1.1395620, -1.5024749, 34.0973402>,
    <1.1612002, -1.4800100, 34.0732308>,
    <1.1573365, -1.4861212, 34.0849170>,
    <1.1327794, -1.4941564, 34.0557354>,
    <1.1537296, -1.4818592, 34.0632019>,
    <1.0386316, -1.5799498, 34.1168394>,
    <0.9465105, -1.6401653, 34.1264018>,
    <0.9988329, -1.6070580, 34.1210460>,
    <0.9483143, -1.6433432, 34.1387967>,
    <1.0592395, -1.5675199, 34.1210460>,
    <1.0060690, -1.6057395, 34.1311462>,
    <1.0574523, -1.5647662, 34.1083733>,
    <1.1053001, -1.5313531, 34.1095803>,
    <0.9448400, -1.6372163, 34.1138015>,
    <1.0030458, -1.6007357, 34.1095803>,
    <1.0343112, 1.5721760, 34.0775018>,
    <1.0781910, 1.5391374, 34.0677166>,
    <1.0536792, 1.5579993, 34.0732308>,
    <1.1380274, 1.4994379, 34.0805061>,
    <1.0552255, 1.5603742, 34.0861763>,
    <1.1026625, 1.5265674, 34.0849170>,
    <0.9402080, 1.6278803, 34.0677166>,
    <0.9417139, 1.6305727, 34.0805061>,
    <0.9935823, 1.5973641, 34.0732308>,
    <1.0006648, 1.5958239, 34.0849170>,
    <0.9344671, 1.6168578, 34.0420193>,
    <0.9381786, 1.6239992, 34.0557354>,
    <1.0164804, 1.5754935, 34.0557354>,
    <0.9978199, 1.5909755, 34.0632019>,
    <1.1212120, 1.5052505, 34.0581798>,
    <1.1601978, 1.4777269, 34.0621232>,
    <1.1028143, 1.5206493, 34.0621232>,
    <1.1563715, 1.4840204, 34.0723106>,
    <1.0711057, 1.5281293, 34.0422290>,
    <1.0119960, 1.5680333, 34.0422290>,
    <1.0999767, 1.5163734, 34.0506039>,
    <1.0526665, 1.5497538, 34.0517365>,
    <1.1287799, 1.4861801, 34.0422290>,
    <1.1520091, 1.4779698, 34.0517365>,
    <1.1024966, -1.4850137, 34.0309239>,
    <1.0513227, -1.5085162, 34.0269467>,
    <0.9328373, -1.6180823, 34.0420193>,
    <1.0694989, -1.5295493, 34.0422290>,
    <1.0805529, -1.4957953, 34.0289414>,
    <1.0015386, -1.5575199, 34.0327086>,
    <1.0103539, -1.5693979, 34.0422290>,
    <1.0889714, -1.5052478, 34.0352527>,
    <1.0408985, -1.5369838, 34.0346796>,
    <1.1272131, -1.4876522, 34.0422290>,
    <1.1370795, -1.4536116, 34.0289414>,
    <1.1395837, -1.4658309, 34.0346796>,
    <1.0973029, -1.4599001, 34.0223261>,
    <1.1234637, -1.4506803, 34.0248676>,
    <1.0309699, -1.5684958, 34.0581798>,
    <0.9396673, -1.6282165, 34.0677166>,
    <0.9917844, -1.5956814, 34.0621232>,
    <0.9412604, -1.6308344, 34.0805061>,
    <1.0517446, -1.5564390, 34.0621232>,
    <0.9990207, -1.5941986, 34.0723106>,
    <1.0486527, -1.5524394, 34.0506039>,
    <1.0962044, -1.5193892, 34.0517365>,
    <0.9372778, -1.6246156, 34.0557354>,
    <0.9947723, -1.5881891, 34.0517365>,
    <1.0171249, 1.5439862, 34.0309239>,
    <1.0557082, 1.5042613, 34.0269467>,
    <1.0343703, 1.5271675, 34.0289414>,
    <1.1200572, 1.4738232, 34.0327086>,
    <1.0412731, 1.5381095, 34.0352527>,
    <1.0874845, 1.5037892, 34.0346796>,
    <0.9206301, 1.5913144, 34.0269467>,
    <0.9268919, 1.6030392, 34.0327086>,
    <0.9753975, 1.5658574, 34.0289414>,
    <0.9868705, 1.5721872, 34.0346796>,
    <0.9150785, 1.5796812, 34.0223261>,
    <0.9915352, 1.5321102, 34.0223261>,
    <0.9756845, 1.5526854, 34.0248676>,
    <1.0944007, 1.4638837, 34.0235018>,
    <1.1329526, 1.4397375, 34.0248897>,
    <1.0770073, 1.4816783, 34.0248897>,
    <1.1335438, 1.4528085, 34.0290881>,
    <1.0733388, 1.4698181, 34.0209641>,
    <1.0267533, 1.5035709, 34.0211848>,
    <1.1232920, 1.4336025, 34.0211848>,
    <0.9986281, -1.5323464, 34.0235018>,
    <0.9161825, -1.5949982, 34.0269467>,
    <0.9637335, -1.5594414, 34.0248897>,
    <0.9244037, -1.6051846, 34.0327086>,
    <1.0224286, -1.5212345, 34.0248897>,
    <0.9770650, -1.5633368, 34.0290881>,
    <1.0087583, -1.5166815, 34.0209641>,
    <1.0571636, -1.4841343, 34.0211848>,
    <0.9057429, -1.5866479, 34.0223261>,
    <0.9577998, -1.5508406, 34.0211848>,
    <0.9647200, 1.7972905, 34.2894172>,
    <0.9171219, 1.8167319, 34.2882663>,
    <0.8811168, 1.8424456, 34.2918019>,
    <0.9523956, 1.8092069, 34.2918011>,
    <0.9463563, 1.8046637, 34.2889150>,
    <0.8939634, 1.8328202, 34.2903405>,
    <0.9165073, 1.8259424, 34.2918015>,
    <0.9610374, 1.8016288, 34.2904035>,
    <0.9287732, 1.8166405, 34.2903614>,
    <0.9886158, 1.7923166, 34.2918006>,
    <0.9864950, 1.7855881, 34.2889147>,
    <0.9897276, 1.7879297, 34.2903608>,
    <0.9488545, 1.7961817, 34.2861103>,
    <0.9745737, 1.7873371, 34.2874561>,
    <0.9535246, -1.8025108, 34.2894166>,
    <0.9368832, -1.8164400, 34.2918006>,
    <0.8570298, -1.8536773, 34.2917990>,
    <0.9047353, -1.8223638, 34.2882651>,
    <0.9478357, -1.8078009, 34.2904030>,
    <0.8954046, -1.8357824, 34.2917998>,
    <0.8734638, -1.8423791, 34.2903384>,
    <0.9340586, -1.8103157, 34.2889141>,
    <0.9113954, -1.8247436, 34.2903601>,
    <0.9486669, -1.7956933, 34.2861096>,
    <0.9793016, -1.7889421, 34.2889145>,
    <0.9700666, -1.7891095, 34.2874555>,
    <0.9804309, -1.7961326, 34.2918014>,
    <0.9816003, -1.7917848, 34.2903610>,
    <0.9402052, -1.7708424, 34.2989756>,
    <0.8916102, -1.7923169, 34.2975521>,
    <0.9134158, -1.7946678, 34.3035582>,
    <0.9206540, -1.7791681, 34.2980080>,
    <0.8566541, -1.8166123, 34.3007100>,
    <0.8658869, -1.8186488, 34.3035582>,
    <0.9286539, -1.7812740, 34.3008727>,
    <0.8911708, -1.8001784, 34.3007914>,
    <0.9609446, -1.7706867, 34.3035582>,
    <0.9709351, -1.7521027, 34.2980080>,
    <0.9694187, -1.7593412, 34.3007914>,
    <0.9275863, -1.7660579, 34.2937748>,
    <0.9585361, -1.7530782, 34.2951914>,
    <0.7143563, 1.9135494, 34.2894164>,
    <0.7242740, 1.9155829, 34.2917999>,
    <0.7588372, 1.8994658, 34.2918015>,
    <0.7370939, 1.9014851, 34.2886788>,
    <0.7185890, 1.9145166, 34.2904025>,
    <0.7394100, 1.9085248, 34.2918008>,
    <0.7488262, 1.9004464, 34.2903190>,
    <0.7222345, 1.9089186, 34.2889144>,
    <0.7324188, 1.9082026, 34.2903608>,
    <0.6838426, 1.9082904, 34.2830969>,
    <0.6845263, 1.9223196, 34.2886777>,
    <0.7219190, 1.9026401, 34.2867235>,
    <0.6817165, 1.9180523, 34.2867230>,
    <0.7023943, 1.9169683, 34.2889138>,
    <0.7056639, 1.9117109, 34.2874556>,
    <0.6889455, 1.9253244, 34.2903168>,
    <0.7119987, 1.9213069, 34.2917988>,
    <0.7055821, 1.9197552, 34.2903595>,
    <0.7837460, 1.8818335, 34.2894178>,
    <0.8135917, 1.8739333, 34.2918021>,
    <0.7593858, 1.8918350, 34.2889153>,
    <0.7839859, 1.8877388, 34.2918019>,
    <0.7948271, 1.8792065, 34.2904042>,
    <0.7695654, 1.8908809, 34.2903617>,
    <0.8206991, 1.8615829, 34.2882666>,
    <0.8463901, 1.8586391, 34.2918020>,
    <0.8585734, 1.8493230, 34.2903406>,
    <0.7972294, 1.8741882, 34.2889154>,
    <0.8248020, 1.8651236, 34.2903619>,
    <0.7708349, 1.8787457, 34.2861105>,
    <0.7576880, 1.8884132, 34.2874564>,
    <0.8611292, 1.8386254, 34.2863580>,
    <0.8434030, 1.8487508, 34.2872643>,
    <0.8869570, 1.8285278, 34.2872642>,
    <0.8715733, 1.8397314, 34.2889216>,
    <0.8366804, 1.8405275, 34.2817250>,
    <0.9055540, 1.8084855, 34.2819691>,
    <0.8524285, 1.8385839, 34.2845089>,
    <0.9042281, 1.8151271, 34.2850030>,
    <0.7703752, 1.8704789, 34.2819691>,
    <0.8051896, 1.8609631, 34.2850030>,
    <0.8569296, -1.8405853, 34.2863568>,
    <0.8073149, -1.8679774, 34.2882644>,
    <0.8771182, -1.8330169, 34.2872630>,
    <0.8373204, -1.8592333, 34.2903380>,
    <0.8332512, -1.8535870, 34.2872627>,
    <0.8538818, -1.8479810, 34.2889197>,
    <0.7058480, -1.9003204, 34.2830964>,
    <0.8726611, -1.8237548, 34.2817246>,
    <0.7702682, -1.8796237, 34.2861090>,
    <0.8043794, -1.8557581, 34.2819686>,
    <0.8613688, -1.8344186, 34.2845081>,
    <0.8108307, -1.8587418, 34.2850020>,
    <0.9387764, -1.7918795, 34.2819687>,
    <0.9098743, -1.8120993, 34.2850022>,
    <0.9060623, -1.7969502, 34.2751874>,
    <0.8485793, -1.8189242, 34.2713544>,
    <0.8894958, -1.8101600, 34.2783020>,
    <0.7849700, -1.8556746, 34.2765461>,
    <0.8803021, -1.8073089, 34.2735942>,
    <0.8316565, -1.8369486, 34.2779935>,
    <0.9131484, -1.7795262, 34.2658251>,
    <0.9488582, -1.7726171, 34.2735942>,
    <0.9379563, -1.7718348, 34.2692880>,
    <0.9504513, -1.7790087, 34.2779935>,
    <0.7694014, -1.8885678, 34.2894146>,
    <0.7928898, -1.8835867, 34.2917976>,
    <0.7828181, -1.8810105, 34.2889127>,
    <0.8227933, -1.8696423, 34.2917982>,
    <0.7775420, -1.8872666, 34.2904005>,
    <0.8050339, -1.8743415, 34.2903586>,
    <0.7468602, -1.9050501, 34.2917969>,
    <0.7306507, -1.9046290, 34.2886763>,
    <0.7675138, -1.8954195, 34.2917971>,
    <0.7387999, -1.9051211, 34.2903154>,
    <0.7489260, -1.8968146, 34.2889123>,
    <0.7558084, -1.8972956, 34.2903578>,
    <0.7223238, -1.9030107, 34.2867219>,
    <0.7516896, -1.8916193, 34.2874543>,
    <0.7100055, -1.9154780, 34.2894146>,
    <0.7190744, -1.9180055, 34.2917976>,
    <0.7176411, -1.9111077, 34.2889123>,
    <0.7311234, -1.9123877, 34.2917971>,
    <0.7138982, -1.9166482, 34.2904005>,
    <0.7254830, -1.9114358, 34.2903578>,
    <0.6806826, -1.9234521, 34.2886770>,
    <0.7094838, -1.9224768, 34.2917982>,
    <0.6844834, -1.9267171, 34.2903167>,
    <0.6992143, -1.9182273, 34.2889127>,
    <0.7020857, -1.9211670, 34.2903586>,
    <0.6829855, -1.9173880, 34.2867222>,
    <0.7053962, -1.9120276, 34.2874543>,
    <0.8215250, -1.8275699, 34.2989756>,
    <0.7983415, -1.8325032, 34.2967794>,
    <0.7540995, -1.8689603, 34.3035582>,
    <0.8134346, -1.8286636, 34.2980080>,
    <0.7325049, -1.8704201, 34.3007507>,
    <0.7219702, -1.8821256, 34.3035582>,
    <0.7945335, -1.8443364, 34.3008727>,
    <0.7648457, -1.8568146, 34.3007914>,
    <0.7862288, -1.8557951, 34.3035582>,
    <0.8562344, -1.8097275, 34.2980080>,
    <0.8247890, -1.8311336, 34.3007914>,
    <0.8721752, -1.7898287, 34.2926777>,
    <0.8734503, -1.7948322, 34.2951914>,
    <0.7942534, 1.8490860, 34.2751874>,
    <0.8481068, 1.8191211, 34.2713545>,
    <0.8151654, 1.8448173, 34.2783022>,
    <0.9177050, 1.7936852, 34.2765463>,
    <0.8187558, 1.8359928, 34.2735942>,
    <0.8731023, 1.8175594, 34.2779937>,
    <0.6821073, 1.8720861, 34.2582471>,
    <0.6864239, 1.8868202, 34.2713545>,
    <0.7762357, 1.8433696, 34.2658251>,
    <0.6849823, 1.8798411, 34.2658251>,
    <0.7481243, 1.8662330, 34.2735942>,
    <0.7543975, 1.8574297, 34.2692880>,
    <0.6861035, 1.8950748, 34.2765462>,
    <0.7524018, 1.8714091, 34.2779937>,
    <0.8991051, 1.7889101, 34.2672347>,
    <0.8770900, 1.8024104, 34.2690979>,
    <0.9453328, 1.7679318, 34.2690979>,
    <0.9404657, 1.7772448, 34.2734378>,
    <0.8422693, 1.8045749, 34.2582019>,
    <0.9106078, 1.7712027, 34.2582019>,
    <0.8744069, 1.7959826, 34.2634197>,
    <0.9362543, 1.7654401, 34.2639559>,
    <0.7727957, 1.8355179, 34.2582019>,
    <0.8186531, 1.8224232, 34.2639559>,
    <0.8889809, -1.7715464, 34.2481381>,
    <0.8409843, -1.8051741, 34.2582019>,
    <0.6808293, -1.8725513, 34.2582471>,
    <0.8347644, -1.7920219, 34.2427102>,
    <0.8682146, -1.7864884, 34.2526827>,
    <0.7714926, -1.8360732, 34.2582019>,
    <0.7682107, -1.8284790, 34.2497196>,
    <0.8654114, -1.7808098, 34.2458152>,
    <0.8121485, -1.8116570, 34.2520259>,
    <0.8998635, -1.7534739, 34.2353389>,
    <0.9329520, -1.7467492, 34.2458152>,
    <0.9241317, -1.7455745, 34.2399571>,
    <0.9093448, -1.7718440, 34.2582019>,
    <0.9292031, -1.7550404, 34.2520259>,
    <0.7925116, -1.8386224, 34.2672347>,
    <0.6871977, -1.8865412, 34.2713544>,
    <0.8170800, -1.8304092, 34.2690979>,
    <0.6933617, -1.8924435, 34.2765461>,
    <0.7468023, -1.8605237, 34.2690979>,
    <0.7574733, -1.8626382, 34.2734378>,
    <0.6836117, -1.8803399, 34.2658251>,
    <0.8137446, -1.8242699, 34.2634197>,
    <0.7505929, -1.8520154, 34.2639559>,
    <0.8698371, -1.7985557, 34.2639559>,
    <0.7516423, 1.8588800, 34.2989756>,
    <0.7991648, 1.8352618, 34.2975521>,
    <0.7868048, 1.8537780, 34.3035582>,
    <0.7704742, 1.8491278, 34.2980080>,
    <0.8397202, 1.8239801, 34.3007100>,
    <0.8350654, 1.8323976, 34.3035582>,
    <0.7669195, 1.8567721, 34.3008727>,
    <0.8051117, 1.8399758, 34.3007914>,
    <0.6713868, 1.8847129, 34.2967794>,
    <0.7385443, 1.8751584, 34.3035582>,
    <0.6808759, 1.8910079, 34.3007507>,
    <0.7177846, 1.8704691, 34.2980080>,
    <0.7243515, 1.8741532, 34.3007914>,
    <0.6902460, 1.8606442, 34.2867877>,
    <0.6730908, 1.8763631, 34.2926777>,
    <0.7563047, 1.8459766, 34.2937748>,
    <0.7264693, 1.8614273, 34.2951914>,
    <0.8714532, 1.8043953, 34.2989756>,
    <0.8906565, 1.7899665, 34.2967794>,
    <0.9462262, 1.7794377, 34.3035582>,
    <0.8777570, 1.7989875, 34.2980080>,
    <0.9622432, 1.7642017, 34.3007507>,
    <0.9776763, 1.7636480, 34.3035582>,
    <0.9015231, 1.7945240, 34.3008727>,
    <0.9306381, 1.7800361, 34.3007914>,
    <0.9147761, 1.7952275, 34.3035582>,
    <0.8353310, 1.8194035, 34.2980080>,
    <0.8715373, 1.8090007, 34.3007914>,
    <0.8104200, 1.8188939, 34.2926777>,
    <0.8131898, 1.8230655, 34.2951914>,
    <0.9033811, 1.7766937, 34.2933120>,
    <0.9401323, 1.7610843, 34.2949171>,
    <0.8966607, 1.7832013, 34.2949171>,
    <0.9498904, 1.7633695, 34.2980246>,
    <0.8399311, 1.7943698, 34.2854038>,
    <0.7755562, 1.8237588, 34.2856693>,
    <0.8737971, 1.7852105, 34.2900253>,
    <0.8323277, 1.8057961, 34.2908029>,
    <0.9076322, 1.7617095, 34.2856693>,
    <0.9297124, 1.7585755, 34.2908029>,
    <0.8836358, -1.7619393, 34.2753407>,
    <0.8292818, -1.7821239, 34.2695801>,
    <0.6671918, -1.8693091, 34.2867877>,
    <0.8346001, -1.7967233, 34.2854038>,
    <0.8600661, -1.7710544, 34.2729301>,
    <0.7615481, -1.8200983, 34.2772285>,
    <0.7660576, -1.8277455, 34.2856693>,
    <0.8626906, -1.7773233, 34.2800513>,
    <0.8060826, -1.8028809, 34.2795037>,
    <0.8984791, -1.7662841, 34.2856693>,
    <0.9272803, -1.7372366, 34.2729301>,
    <0.9227094, -1.7467723, 34.2795037>,
    <0.8943218, -1.7428497, 34.2614925>,
    <0.9186337, -1.7353506, 34.2665723>,
    <0.7801223, -1.8337953, 34.2933120>,
    <0.6967812, -1.8749919, 34.2967794>,
    <0.7444843, -1.8519810, 34.2949171>,
    <0.6934829, -1.8855283, 34.3007507>,
    <0.7893920, -1.8327174, 34.2949171>,
    <0.7398911, -1.8606443, 34.2980246>,
    <0.8057498, -1.8166675, 34.2900253>,
    <0.8481473, -1.7980982, 34.2908029>,
    <0.6902351, -1.8699914, 34.2926777>,
    <0.7493657, -1.8425635, 34.2908029>,
    <0.7856574, 1.8197270, 34.2481381>,
    <0.8361922, 1.7913561, 34.2427102>,
    <0.8104520, 1.8134236, 34.2526827>,
    <0.9068999, 1.7638072, 34.2497196>,
    <0.8079038, 1.8076260, 34.2458152>,
    <0.8657708, 1.7866525, 34.2520259>,
    <0.6723433, 1.8454892, 34.2254060>,
    <0.6770184, 1.8581322, 34.2427102>,
    <0.7648178, 1.8164468, 34.2353389>,
    <0.6749064, 1.8523784, 34.2353389>,
    <0.7383975, 1.8374715, 34.2458152>,
    <0.7431672, 1.8299596, 34.2399571>,
    <0.6791806, 1.8640298, 34.2497196>,
    <0.7471588, 1.8399291, 34.2520259>,
    <0.8859829, 1.7624837, 34.2371711>,
    <0.8643902, 1.7754004, 34.2396408>,
    <0.9316292, 1.7414317, 34.2396408>,
    <0.9276240, 1.7490786, 34.2454279>,
    <0.8302296, 1.7789493, 34.2253660>,
    <0.8975971, 1.7460539, 34.2253660>,
    <0.8616734, 1.7699803, 34.2321345>,
    <0.9226015, 1.7398312, 34.2328481>,
    <0.7617433, 1.8094498, 34.2253660>,
    <0.8066994, 1.7959863, 34.2328481>,
    <0.8768945, -1.7472753, 34.2126378>,
    <0.8290929, -1.7794793, 34.2253660>,
    <0.6712128, -1.8459007, 34.2254060>,
    <0.8236763, -1.7679884, 34.2059260>,
    <0.8561960, -1.7615822, 34.2183311>,
    <0.7605906, -1.8099411, 34.2253660>,
    <0.7577193, -1.8032753, 34.2146338>,
    <0.8537603, -1.7566325, 34.2097470>,
    <0.8009458, -1.7864630, 34.2175110>,
    <0.8882625, -1.7306498, 34.1969055>,
    <0.9203783, -1.7230336, 34.2097470>,
    <0.9119776, -1.7224206, 34.2025384>,
    <0.8964799, -1.7466212, 34.2253660>,
    <0.9163643, -1.7306322, 34.2175110>,
    <0.7806420, -1.8116050, 34.2371711>,
    <0.6757582, -1.8585908, 34.2427102>,
    <0.8044163, -1.8033667, 34.2396408>,
    <0.6778927, -1.8644986, 34.2497196>,
    <0.7351744, -1.8330401, 34.2396408>,
    <0.7436067, -1.8348873, 34.2454279>,
    <0.6736775, -1.8528256, 34.2353389>,
    <0.8020106, -1.7978016, 34.2321345>,
    <0.7397512, -1.8250957, 34.2328481>,
    <0.8572689, -1.7724053, 34.2328481>,
    <0.7817382, 1.8094776, 34.2753407>,
    <0.8321073, 1.7807784, 34.2695801>,
    <0.8038531, 1.7972578, 34.2729301>,
    <0.9046557, 1.7532542, 34.2772285>,
    <0.8069922, 1.8033470, 34.2800513>,
    <0.8628933, 1.7763529, 34.2795037>,
    <0.6738797, 1.8473088, 34.2695801>,
    <0.6783229, 1.8534567, 34.2772285>,
    <0.7347591, 1.8270257, 34.2729301>,
    <0.7450107, 1.8296942, 34.2795037>,
    <0.6680375, 1.8334834, 34.2505667>,
    <0.6708683, 1.8410927, 34.2614925>,
    <0.7602413, 1.8053724, 34.2614925>,
    <0.7388693, 1.8191762, 34.2665723>,
    <0.8809234, 1.7518032, 34.2635082>,
    <0.9266374, 1.7309821, 34.2662252>,
    <0.8598010, 1.7647505, 34.2662252>,
    <0.9242215, 1.7385932, 34.2725930>,
    <0.8248999, 1.7673714, 34.2505227>,
    <0.7568593, 1.7976758, 34.2505227>,
    <0.8563760, 1.7589415, 34.2579678>,
    <0.8017749, 1.7848411, 34.2587527>,
    <0.8918287, 1.7346876, 34.2505227>,
    <0.9169505, 1.7290331, 34.2587527>,
    <0.8707321, -1.7351420, 34.2365221>,
    <0.8176913, -1.7553144, 34.2291393>,
    <0.6667940, -1.8339361, 34.2505667>,
    <0.8236496, -1.7679544, 34.2505227>,
    <0.8476715, -1.7442589, 34.2333423>,
    <0.7524329, -1.7908838, 34.2387176>,
    <0.7555913, -1.7982162, 34.2505227>,
    <0.8503508, -1.7497036, 34.2427845>,
    <0.7954459, -1.7743655, 34.2418824>,
    <0.8905998, -1.7353116, 34.2505227>,
    <0.9138249, -1.7108972, 34.2333423>,
    <0.9100896, -1.7189142, 34.2418824>,
    <0.8815607, -1.7177432, 34.2192172>,
    <0.9052643, -1.7098814, 34.2254131>,
    <0.7757111, -1.8008736, 34.2635082>,
    <0.6712037, -1.8483111, 34.2695801>,
    <0.7303752, -1.8225212, 34.2662252>,
    <0.6717471, -1.8559635, 34.2772285>,
    <0.7992050, -1.7930275, 34.2662252>,
    <0.7377498, -1.8256286, 34.2725930>,
    <0.7969594, -1.7866479, 34.2579678>,
    <0.8518966, -1.7614689, 34.2587527>,
    <0.6695166, -1.8415847, 34.2614925>,
    <0.7351117, -1.8138259, 34.2587527>,
    <0.7748336, 1.7948671, 34.2126378>,
    <0.8249088, 1.7674137, 34.2059260>,
    <0.7990981, 1.7882074, 34.2183311>,
    <0.8943364, 1.7395697, 34.2146338>,
    <0.7968721, 1.7831600, 34.2097470>,
    <0.8536720, 1.7618764, 34.2175110>,
    <0.6638875, 1.8225403, 34.1849198>,
    <0.6678764, 1.8332831, 34.2059260>,
    <0.7547905, 1.7928888, 34.1969055>,
    <0.6660575, 1.8283447, 34.1969055>,
    <0.7283126, 1.8125954, 34.2097470>,
    <0.7332428, 1.8057661, 34.2025384>,
    <0.6697580, 1.8383985, 34.2146338>,
    <0.7367135, 1.8144048, 34.2175110>,
    <0.8743066, 1.7394522, 34.1991181>,
    <0.8528788, 1.7519630, 34.2021355>,
    <0.9192364, 1.7184435, 34.2021355>,
    <0.9149922, 1.7254455, 34.2092829>,
    <0.8198093, 1.7568417, 34.1848862>,
    <0.8863390, 1.7243587, 34.1848862>,
    <0.8505496, 1.7473321, 34.1929998>,
    <0.9106658, 1.7175034, 34.1938690>,
    <0.7521748, 1.7869593, 34.1848862>,
    <0.7962420, 1.7729357, 34.1938690>,
    <0.8666805, -1.7266909, 34.1698789>,
    <0.8188555, -1.7572864, 34.1848862>,
    <0.6629389, -1.8228855, 34.1849198>,
    <0.8144067, -1.7478059, 34.1620860>,
    <0.8459535, -1.7402853, 34.1765488>,
    <0.7512076, -1.7873715, 34.1848862>,
    <0.7488341, -1.7818367, 34.1722289>,
    <0.8439592, -1.7362150, 34.1665078>,
    <0.7914141, -1.7649448, 34.1755900>,
    <0.8786978, -1.7117473, 34.1516897>,
    <0.9097957, -1.7030057, 34.1665078>,
    <0.9018634, -1.7030768, 34.1581668>,
    <0.8854016, -1.7248347, 34.1848862>,
    <0.9054321, -1.7097845, 34.1755900>,
    <0.7705043, -1.7878560, 34.1991181>,
    <0.6667886, -1.8336790, 34.2059260>,
    <0.7938616, -1.7794832, 34.2021355>,
    <0.6686354, -1.8388071, 34.2146338>,
    <0.7255303, -1.8087701, 34.2021355>,
    <0.7336222, -1.8100197, 34.2092829>,
    <0.6650077, -1.8287269, 34.1969055>,
    <0.7918113, -1.7747222, 34.1929998>,
    <0.7303192, -1.8016003, 34.1938690>,
    <0.8463331, -1.7495779, 34.1938690>,
    <0.7695000, 1.7823473, 34.2365221>,
    <0.8190470, 1.7546822, 34.2291393>,
    <0.7913071, 1.7705421, 34.2333423>,
    <0.8882420, 1.7275550, 34.2387176>,
    <0.7937557, 1.7760943, 34.2427845>,
    <0.8479400, 1.7498871, 34.2418824>,
    <0.6631354, 1.8200879, 34.2291393>,
    <0.6652051, 1.8257149, 34.2387176>,
    <0.7232280, 1.7997740, 34.2333423>,
    <0.7317703, 1.8020658, 34.2418824>,
    <0.6587362, 1.8082396, 34.2060335>,
    <0.6611346, 1.8146557, 34.2192172>,
    <0.7492113, 1.7794587, 34.2192172>,
    <0.7279525, 1.7925633, 34.2254131>,
    <0.8678854, 1.7265366, 34.2216509>,
    <0.9125688, 1.7058480, 34.2249699>,
    <0.8467019, 1.7391225, 34.2249699>,
    <0.9085803, 1.7132088, 34.2328318>,
    <0.8134376, 1.7430530, 34.2059966>,
    <0.7463341, 1.7729363, 34.2059966>,
    <0.8441398, 1.7340285, 34.2149211>,
    <0.7902718, 1.7594855, 34.2158771>,
    <0.8794449, 1.7108229, 34.2059966>,
    <0.9038212, 1.7044724, 34.2158771>,
    <0.8594967, -1.7124991, 34.1894897>,
    <0.8074947, -1.7331137, 34.1809181>,
    <0.6576928, -1.8086194, 34.2060335>,
    <0.8123885, -1.7435422, 34.2059966>,
    <0.8368904, -1.7217996, 34.1857817>,
    <0.7426593, -1.7673013, 34.1920745>,
    <0.7452701, -1.7733897, 34.2059966>,
    <0.8390841, -1.7262770, 34.1968260>,
    <0.7849611, -1.7506955, 34.1957715>,
    <0.8784137, -1.7113465, 34.2059966>,
    <0.9021841, -1.6888665, 34.1857817>,
    <0.8980642, -1.6959817, 34.1957715>,
    <0.8710395, -1.6969504, 34.1694828>,
    <0.8941386, -1.6886032, 34.1766071>,
    <0.7647378, -1.7746351, 34.2216509>,
    <0.6619388, -1.8205234, 34.2291393>,
    <0.7201675, -1.7955663, 34.2249699>,
    <0.6639702, -1.8261643, 34.2387176>,
    <0.7879956, -1.7664977, 34.2249699>,
    <0.7283699, -1.7972423, 34.2328318>,
    <0.7857403, -1.7612606, 34.2149211>,
    <0.8398672, -1.7363588, 34.2158771>,
    <0.6599797, -1.8150761, 34.2192172>,
    <0.7247366, -1.7879810, 34.2158771>,
    <0.7656304, 1.7738112, 34.1698789>,
    <0.8154064, 1.7473397, 34.1620860>,
    <0.7893674, 1.7666718, 34.1765488>,
    <0.8836247, 1.7189827, 34.1722289>,
    <0.7875312, 1.7625277, 34.1665078>,
    <0.8433149, 1.7407430, 34.1755900>,
    <0.6569970, 1.8039364, 34.1380150>,
    <0.6601750, 1.8124433, 34.1620860>,
    <0.7464584, 1.7734115, 34.1516897>,
    <0.6587044, 1.8084704, 34.1516897>,
    <0.7197726, 1.7916149, 34.1665078>,
    <0.7249259, 1.7855841, 34.1581668>,
    <0.6617188, 1.8166211, 34.1722289>,
    <0.7277703, 1.7926295, 34.1755900>,
    <0.8645812, 1.7203451, 34.1542153>,
    <0.8432442, 1.7324272, 34.1576891>,
    <0.9088695, 1.6992823, 34.1576891>,
    <0.9043087, 1.7055304, 34.1659804>,
    <0.8113250, 1.7389236, 34.1379890>,
    <0.8771758, 1.7067763, 34.1379890>,
    <0.8413734, 1.7287262, 34.1472010>,
    <0.9008097, 1.6991349, 34.1481994>,
    <0.7443811, 1.7687296, 34.1379890>,
    <0.7875986, 1.7539720, 34.1481994>,
    <0.8586492, -1.7104185, 34.1211611>,
    <0.8105831, -1.7392696, 34.1379890>,
    <0.6562591, -1.8042050, 34.1380150>,
    <0.8072373, -1.7320875, 34.1125260>,
    <0.8377982, -1.7232447, 34.1286034>,
    <0.7436287, -1.7690502, 34.1379890>,
    <0.7418252, -1.7648144, 34.1237934>,
    <0.8363060, -1.7201774, 34.1174128>,
    <0.7838432, -1.7477561, 34.1275355>,
    <0.8714600, -1.6973408, 34.1010718>,
    <0.9015260, -1.6872738, 34.1174128>,
    <0.8940963, -1.6881306, 34.1081947>,
    <0.8764465, -1.7071465, 34.1379890>,
    <0.8967387, -1.6931306, 34.1275355>,
    <0.7621186, -1.7681242, 34.1542153>,
    <0.6592926, -1.8127644, 34.1620860>,
    <0.7850893, -1.7595453, 34.1576891>,
    <0.6607955, -1.8169571, 34.1722289>,
    <0.7175157, -1.7885121, 34.1576891>,
    <0.7252336, -1.7890345, 34.1659804>,
    <0.6578655, -1.8087758, 34.1516897>,
    <0.7834567, -1.7557332, 34.1472010>,
    <0.7225835, -1.7822431, 34.1481994>,
    <0.8373618, -1.7307670, 34.1481994>,
    <0.7583275, 1.7571993, 34.1211611>,
    <0.8079739, 1.7317440, 34.1125260>,
    <0.7815557, 1.7494710, 34.1286034>,
    <0.8750903, 1.7026720, 34.1237934>,
    <0.7801652, 1.7463563, 34.1174128>,
    <0.8350142, 1.7238947, 34.1275355>,
    <0.6518810, 1.7902431, 34.0861253>,
    <0.6541482, 1.7962460, 34.1125260>,
    <0.7400748, 1.7586068, 34.1010718>,
    <0.6530706, 1.7933593, 34.1010718>,
    <0.7130370, 1.7751677, 34.1174128>,
    <0.7184691, 1.7700269, 34.1081947>,
    <0.6553072, 1.7993591, 34.1237934>,
    <0.7206008, 1.7752651, 34.1275355>,
    <0.8571025, 1.7057428, 34.1038334>,
    <0.8357792, 1.7173866, 34.1076575>,
    <0.9008435, 1.6845304, 34.1076575>,
    <0.8958980, 1.6899385, 34.1168389>,
    <0.8050345, 1.7257397, 34.0861074>,
    <0.8703857, 1.6938408, 34.0861074>,
    <0.8344235, 1.7147278, 34.0961373>,
    <0.8933328, 1.6852839, 34.0972345>,
    <0.7385989, 1.7553147, 34.0861074>,
    <0.7810319, 1.7396713, 34.0972345>,
    <0.8529315, -1.6987996, 34.0680823>,
    <0.8045271, -1.7259763, 34.0861074>,
    <0.6513763, -1.7904268, 34.0861253>,
    <0.8019317, -1.7206769, 34.0592183>,
    <0.8319780, -1.7109783, 34.0759583>,
    <0.7380842, -1.7555340, 34.0861074>,
    <0.7369055, -1.7527260, 34.0708032>,
    <0.8307785, -1.7086628, 34.0642124>,
    <0.7784631, -1.7354194, 34.0748134>,
    <0.8649526, -1.6853318, 34.0484530>,
    <0.8955655, -1.6759718, 34.0642124>,
    <0.8878933, -1.6766591, 34.0551646>,
    <0.8698869, -1.6940941, 34.0861074>,
    <0.8905481, -1.6811767, 34.0748134>,
    <0.7557400, -1.7530089, 34.1038334>,
    <0.6534980, -1.7964826, 34.1125260>,
    <0.7783659, -1.7441588, 34.1076575>,
    <0.6546113, -1.7996124, 34.1237934>,
    <0.7113741, -1.7728814, 34.1076575>,
    <0.7186958, -1.7725692, 34.1168389>,
    <0.6524680, -1.7935787, 34.1010718>,
    <0.7772006, -1.7414113, 34.0961373>,
    <0.7167791, -1.7676122, 34.0972345>,
    <0.8306279, -1.7165443, 34.0972345>,
    <0.7593766, 1.7591859, 34.1894897>,
    <0.8085945, 1.7326008, 34.1809181>,
    <0.7810322, 1.7478467, 34.1857817>,
    <0.8764592, 1.7049094, 34.1920745>,
    <0.7830520, 1.7524052, 34.1968260>,
    <0.8365472, 1.7266405, 34.1957715>,
    <0.6546639, 1.7971641, 34.1809181>,
    <0.6563620, 1.8017597, 34.1920745>,
    <0.7138340, 1.7766956, 34.1857817>,
    <0.7219328, 1.7781131, 34.1957715>,
    <0.6511566, 1.7877754, 34.1544411>,
    <0.6530462, 1.7927940, 34.1694828>,
    <0.7400460, 1.7580337, 34.1694828>,
    <0.7188039, 1.7703631, 34.1766071>,
    <0.8571876, 1.7055187, 34.1722608>,
    <0.9011652, 1.6847708, 34.1760819>,
    <0.8361039, 1.7176331, 34.1760819>,
    <0.8968285, 1.6913022, 34.1852017>,
    <0.8041049, 1.7233432, 34.1544124>,
    <0.7377609, 1.7528836, 34.1544124>,
    <0.8340460, 1.7135619, 34.1645454>,
    <0.7807641, 1.7386254, 34.1656437>,
    <0.8693653, 1.6914822, 34.1544124>,
    <0.8929795, 1.6842671, 34.1656437>,
    <0.8506623, -1.6945994, 34.1359011>,
    <0.7996083, -1.7158234, 34.1264018>,
    <0.6503449, -1.7880708, 34.1544411>,
    <0.8032888, -1.7237237, 34.1544124>,
    <0.8284719, -1.7041582, 34.1317777>,
    <0.7349494, -1.7485769, 34.1387967>,
    <0.7369333, -1.7532363, 34.1544124>,
    <0.8301133, -1.7075323, 34.1440880>,
    <0.7766331, -1.7317879, 34.1429132>,
    <0.8685631, -1.6918895, 34.1544124>,
    <0.8930874, -1.6715614, 34.1317777>,
    <0.8885014, -1.6776624, 34.1429132>,
    <0.8630780, -1.6811032, 34.1138015>,
    <0.8855948, -1.6721624, 34.1216372>,
    <0.7555136, -1.7529301, 34.1722608>,
    <0.6536932, -1.7975174, 34.1809181>,
    <0.7113514, -1.7732824, 34.1760819>,
    <0.6553464, -1.8021293, 34.1920745>,
    <0.7783461, -1.7445660, 34.1760819>,
    <0.7191424, -1.7741586, 34.1852017>,
    <0.7765502, -1.7403726, 34.1645454>,
    <0.8299988, -1.7156668, 34.1656437>,
    <0.6521233, -1.7931299, 34.1694828>,
    <0.7162273, -1.7666880, 34.1656437>,
    <0.7530933, 1.7453490, 34.0680823>,
    <0.8026068, 1.7203380, 34.0592183>,
    <0.7759002, 1.7371278, 34.0759583>,
    <0.8689923, 1.6911329, 34.0708032>,
    <0.7748776, 1.7347166, 34.0642124>,
    <0.8290219, 1.7118433, 34.0748134>,
    <0.6429644, 1.7726103, 34.0360984>,
    <0.6497721, 1.7844145, 34.0592183>,
    <0.7349126, 1.7458740, 34.0484530>,
    <0.6484994, 1.7803954, 34.0484530>,
    <0.7081905, 1.7633330, 34.0642124>,
    <0.7135886, 1.7578858, 34.0551646>,
    <0.6507181, 1.7871373, 34.0708032>,
    <0.7154228, 1.7628390, 34.0748134>,
    <0.8514241, 1.6943188, 34.0506060>,
    <0.8303897, 1.7063496, 34.0541438>,
    <0.8950113, 1.6737132, 34.0541438>,
    <0.8900157, 1.6791435, 34.0633523>,
    <0.7969614, 1.7085499, 34.0364647>,
    <0.8598455, 1.6774739, 34.0364059>,
    <0.8283963, 1.7017790, 34.0438443>,
    <0.8868984, 1.6726798, 34.0448606>,
    <0.7316243, 1.7373364, 34.0364059>,
    <0.7754581, 1.7266744, 34.0448606>,
    <0.8415371, -1.6656189, 34.0264558>,
    <0.7963226, -1.7091511, 34.0364647>,
    <0.6455925, -1.7723786, 34.0361559>,
    <0.8010190, -1.6702923, 34.0228405>,
    <0.8213405, -1.6869606, 34.0303723>,
    <0.7320897, -1.7373593, 34.0364059>,
    <0.7355293, -1.7157217, 34.0277741>,
    <0.8254394, -1.6678103, 34.0246615>,
    <0.7743880, -1.7058521, 34.0296825>,
    <0.8643205, -1.6220366, 34.0186848>,
    <0.8773502, -1.6412257, 34.0246615>,
    <0.8726185, -1.6308217, 34.0213137>,
    <0.8603657, -1.6776152, 34.0364059>,
    <0.8756802, -1.6567431, 34.0296825>,
    <0.7505962, -1.7413928, 34.0506060>,
    <0.6492238, -1.7846382, 34.0592183>,
    <0.7733529, -1.7329766, 34.0541438>,
    <0.6502708, -1.7873001, 34.0708032>,
    <0.7068140, -1.7615013, 34.0541438>,
    <0.7142075, -1.7611242, 34.0633523>,
    <0.6475508, -1.7808371, 34.0484530>,
    <0.7710599, -1.7286439, 34.0438443>,
    <0.7111699, -1.7547444, 34.0448606>,
    <0.8241645, -1.7040833, 34.0448606>,
    <0.7336894, 1.7150354, 34.0264558>,
    <0.7627091, 1.6868819, 34.0228405>,
    <0.7634775, 1.7133717, 34.0303723>,
    <0.8402802, 1.6660475, 34.0277741>,
    <0.7454738, 1.7040649, 34.0246615>,
    <0.8080214, 1.6895259, 34.0296825>,
    <0.6325685, 1.7403337, 34.0228190>,
    <0.6842811, 1.7042041, 34.0186848>,
    <0.6258870, 1.7268197, 34.0186848>,
    <0.6917408, 1.7267429, 34.0246615>,
    <0.6862504, 1.7163202, 34.0213137>,
    <0.6352430, 1.7548386, 34.0276880>,
    <0.7052920, 1.7355537, 34.0296825>,
    <0.8212150, 1.6484194, 34.0204813>,
    <0.7946489, 1.6661394, 34.0215203>,
    <0.8689336, 1.6290173, 34.0215203>,
    <0.8616100, 1.6449679, 34.0248083>,
    <0.7686254, 1.6504531, 34.0159774>,
    <0.8408709, 1.6167647, 34.0159774>,
    <0.7998344, 1.6496540, 34.0185671>,
    <0.8591732, 1.6209262, 34.0186456>,
    <0.6963800, 1.6841415, 34.0159774>,
    <0.7419491, 1.6775746, 34.0186456>,
    <0.7337448, -1.6907561, 34.0204813>,
    <0.6325776, -1.7417622, 34.0228405>,
    <0.7644870, -1.6816297, 34.0215203>,
    <0.6391162, -1.7548848, 34.0277741>,
    <0.6883007, -1.7146736, 34.0215203>,
    <0.7054714, -1.7188732, 34.0248083>,
    <0.7686390, -1.6526249, 34.0159774>,
    <0.6289322, -1.7274981, 34.0186848>,
    <0.6963940, -1.6863139, 34.0159774>,
    <0.7482442, -1.6755146, 34.0185671>,
    <0.6881039, -1.7024898, 34.0186456>,
    <0.8408840, -1.6189360, 34.0159774>,
    <0.8068489, -1.6491035, 34.0186456>,
    <0.7513433, 1.7409127, 34.1359011>,
    <0.8004187, 1.7154455, 34.1264018>,
    <0.7729295, 1.7300581, 34.1317777>,
    <0.8670712, 1.6869675, 34.1387967>,
    <0.7744591, 1.7334843, 34.1440880>,
    <0.8274164, 1.7081073, 34.1429132>,
    <0.6480343, 1.7793470, 34.1264018>,
    <0.6493092, 1.7827716, 34.1387967>,
    <0.7064248, 1.7586036, 34.1317777>,
    <0.7140463, 1.7590122, 34.1429132>,
    <0.6455290, 1.7727126, 34.0973598>,
    <0.6468490, 1.7761717, 34.1138015>,
    <0.7330240, 1.7417484, 34.1138015>,
    <0.7117014, 1.7532502, 34.1216372>,
    <0.8489609, 1.6894562, 34.1168394>,
    <0.8923366, 1.6685436, 34.1210460>,
    <0.8278923, 1.7010883, 34.1210460>,
    <0.8875767, 1.6741510, 34.1311462>,
    <0.7971854, 1.7088407, 34.0973402>,
    <0.7314005, 1.7381271, 34.0973402>,
    <0.8264011, 1.6981637, 34.1083733>,
    <0.7735407, 1.7228945, 34.1095803>,
    <0.8618962, 1.6772532, 34.0973402>,
    <0.8847549, 1.6690309, 34.1095803>,
    <0.8443853, -1.6818356, 34.0775018>,
    <0.7938222, -1.7033419, 34.0677166>,
    <0.6449738, -1.7729147, 34.0973598>,
    <0.7966271, -1.7091010, 34.0973402>,
    <0.8224196, -1.6915303, 34.0732308>,
    <0.7295377, -1.7352795, 34.0805061>,
    <0.7308344, -1.7383683, 34.0973402>,
    <0.8237110, -1.6940391, 34.0861763>,
    <0.7707149, -1.7182174, 34.0849170>,
    <0.8613475, -1.6775318, 34.0973402>,
    <0.8865589, -1.6591673, 34.0732308>,
    <0.8816917, -1.6645131, 34.0849170>,
    <0.8561198, -1.6681742, 34.0557354>,
    <0.8788837, -1.6596962, 34.0632019>,
    <0.7484970, -1.7363033, 34.1168394>,
    <0.6473192, -1.7796073, 34.1264018>,
    <0.7045957, -1.7560887, 34.1210460>,
    <0.6485438, -1.7830501, 34.1387967>,
    <0.7709503, -1.7276408, 34.1210460>,
    <0.7119508, -1.7560467, 34.1311462>,
    <0.7696685, -1.7246185, 34.1083733>,
    <0.8225914, -1.7000218, 34.1095803>,
    <0.6461862, -1.7764130, 34.1138015>,
    <0.7098424, -1.7505940, 34.1095803>,
    <0.7455916, 1.7278980, 34.0775018>,
    <0.7945401, 1.7029830, 34.0677166>,
    <0.7671263, 1.7173008, 34.0732308>,
    <0.8603635, 1.6742745, 34.0805061>,
    <0.7682381, 1.7199066, 34.0861763>,
    <0.8208249, 1.6948507, 34.0849170>,
    <0.6432433, 1.7664173, 34.0677166>,
    <0.6442612, 1.7693275, 34.0805061>,
    <0.7011069, 1.7456318, 34.0732308>,
    <0.7083505, 1.7453434, 34.0849170>,
    <0.6394781, 1.7545944, 34.0420193>,
    <0.6419115, 1.7622508, 34.0557354>,
    <0.7274467, 1.7280790, 34.0557354>,
    <0.7063855, 1.7400805, 34.0632019>,
    <0.8427888, 1.6770852, 34.0581798>,
    <0.8859643, 1.6567465, 34.0621232>,
    <0.8219992, 1.6890523, 34.0621232>,
    <0.8811062, 1.6622765, 34.0723106>,
    <0.7894481, 1.6909419, 34.0422290>,
    <0.7243069, 1.7199754, 34.0422290>,
    <0.8199378, 1.6843596, 34.0506039>,
    <0.7675506, 1.7090167, 34.0517365>,
    <0.8535305, 1.6596451, 34.0422290>,
    <0.8778492, 1.6555738, 34.0517365>,
    <0.8278767, -1.6540268, 34.0309239>,
    <0.7730856, -1.6684842, 34.0269467>,
    <0.6377102, -1.7555215, 34.0420193>,
    <0.7876699, -1.6920660, 34.0422290>,
    <0.8043290, -1.6608854, 34.0289414>,
    <0.7159168, -1.7078631, 34.0327086>,
    <0.7225038, -1.7210388, 34.0422290>,
    <0.8110848, -1.6715459, 34.0352527>,
    <0.7582344, -1.6944568, 34.0346796>,
    <0.8517826, -1.6608274, 34.0422290>,
    <0.8673218, -1.6291584, 34.0289414>,
    <0.8677758, -1.6415214, 34.0346796>,
    <0.8256459, -1.6292008, 34.0223261>,
    <0.8540422, -1.6241393, 34.0248676>,
    <0.7429451, -1.7237002, 34.0581798>,
    <0.6426567, -1.7666549, 34.0677166>,
    <0.6996321, -1.7436648, 34.0621232>,
    <0.6437691, -1.7695066, 34.0805061>,
    <0.7654957, -1.7154305, 34.0621232>,
    <0.7070136, -1.7434572, 34.0723106>,
    <0.7631529, -1.7109674, 34.0506039>,
    <0.8157207, -1.6866755, 34.0517365>,
    <0.6409343, -1.7627029, 34.0557354>,
    <0.7038826, -1.7368168, 34.0517365>,
    <0.7334610, 1.6972615, 34.0309305>,
    <0.7782137, 1.6649537, 34.0269691>,
    <0.7533197, 1.6837363, 34.0289563>,
    <0.8470463, 1.6460074, 34.0327086>,
    <0.7583126, 1.6956171, 34.0352527>,
    <0.8097780, 1.6698469, 34.0346796>,
    <0.6301716, 1.7271914, 34.0269691>,
    <0.6343763, 1.7397176, 34.0327086>,
    <0.6885240, 1.7115979, 34.0289563>,
    <0.6988149, 1.7197345, 34.0346796>,
    <0.6265752, 1.7150095, 34.0224156>,
    <0.7097255, 1.6815856, 34.0224156>,
    <0.6908837, 1.6988700, 34.0249273>,
    <0.8228719, 1.6321165, 34.0235084>,
    <0.8653781, 1.6148506, 34.0248897>,
    <0.8029750, 1.6464756, 34.0249046>,
    <0.8639527, 1.6276821, 34.0290881>,
    <0.8003681, 1.6346746, 34.0209790>,
    <0.7488812, 1.6597796, 34.0212444>,
    <0.8562035, 1.6074930, 34.0211848>,
    <0.7150806, -1.6837748, 34.0235181>,
    <0.6243419, -1.7304929, 34.0270017>,
    <0.6770532, -1.7038961, 34.0249264>,
    <0.6316774, -1.7414091, 34.0327086>,
    <0.7419174, -1.6762570, 34.0248897>,
    <0.6908246, -1.7093735, 34.0290881>,
    <0.7248020, -1.6715381, 34.0210008>,
    <0.7798419, -1.6470796, 34.0211848>,
    <0.6124276, -1.7219898, 34.0225462>,
    <0.6686982, -1.6963389, 34.0213315>,
    <0.6379709, 1.9375065, 34.2894164>,
    <0.5877178, 1.9483878, 34.2882660>,
    <0.5477950, 1.9674584, 34.2918015>,
    <0.6237662, 1.9471011, 34.2917999>,
    <0.6186048, 1.9415791, 34.2889144>,
    <0.5621177, 1.9602101, 34.2903401>,
    <0.5855150, 1.9573510, 34.2918008>,
    <0.6335916, 1.9411391, 34.2904025>,
    <0.5992094, 1.9503205, 34.2903608>,
    <0.6623714, 1.9367563, 34.2917988>,
    <0.6614474, 1.9297629, 34.2889138>,
    <0.6642261, 1.9326297, 34.2903595>,
    <0.6225365, 1.9336603, 34.2861101>,
    <0.6494020, 1.9294157, 34.2874556>,
    <0.6260245, -1.9407084, 34.2894156>,
    <0.6072112, -1.9515383, 34.2917990>,
    <0.5221169, -1.9743393, 34.2917985>,
    <0.5745360, -1.9517852, 34.2882647>,
    <0.6195009, -1.9449312, 34.2904017>,
    <0.5630109, -1.9633818, 34.2917988>,
    <0.5402634, -1.9660663, 34.2903380>,
    <0.6055024, -1.9450133, 34.2889134>,
    <0.5806770, -1.9552870, 34.2903593>,
    <0.6224324, -1.9331481, 34.2861093>,
    <0.6537650, -1.9318223, 34.2889133>,
    <0.6446464, -1.9303818, 34.2874548>,
    <0.6536158, -1.9391043, 34.2917990>,
    <0.6555291, -1.9350232, 34.2903593>,
    <0.6184390, -1.9073486, 34.2989756>,
    <0.5669649, -1.9207014, 34.2975521>,
    <0.5878928, -1.9260189, 34.3035582>,
    <0.5977697, -1.9123305, 34.2980080>,
    <0.5282938, -1.9384180, 34.3007100>,
    <0.5369187, -1.9413829, 34.3035582>,
    <0.6052351, -1.9155250, 34.3008727>,
    <0.5650636, -1.9277863, 34.3007914>,
    <0.6388669, -1.9106548, 34.3035582>,
    <0.6519440, -1.8941527, 34.2980080>,
    <0.6491823, -1.9009528, 34.3007914>,
    <0.6069470, -1.9010344, 34.2937748>,
    <0.6395983, -1.8931563, 34.2951914>,
    <0.3712196, 2.0085248, 34.2894179>,
    <0.3806338, 2.0122494, 34.2918022>,
    <0.4174706, 2.0023790, 34.2918022>,
    <0.3957067, 2.0005921, 34.2886794>,
    <0.3752202, 2.0102122, 34.2904043>,
    <0.3967655, 2.0079269, 34.2918022>,
    <0.4074413, 2.0016064, 34.2903196>,
    <0.3797823, 2.0053323, 34.2889155>,
    <0.3899364, 2.0063957, 34.2903620>,
    <0.3420823, 1.9980472, 34.2830970>,
    <0.3403197, 2.0119819, 34.2886794>,
    <0.3805617, 1.9990945, 34.2867239>,
    <0.3382935, 2.0072915, 34.2867239>,
    <0.3588456, 2.0098145, 34.2889155>,
    <0.3629784, 2.0052048, 34.2874565>,
    <0.3441501, 2.0157083, 34.2903196>,
    <0.3675510, 2.0157550, 34.2918022>,
    <0.3615012, 2.0131127, 34.2903620>,
    <0.4450625, 1.9893401, 34.2894179>,
    <0.4758268, 1.9867425, 34.2918021>,
    <0.4193356, 1.9949596, 34.2889155>,
    <0.4442735, 1.9951972, 34.2918022>,
    <0.4564315, 1.9886772, 34.2904043>,
    <0.4295264, 1.9957876, 34.2903620>,
    <0.4849706, 1.9758140, 34.2882666>,
    <0.5107831, 1.9773760, 34.2918019>,
    <0.5243989, 1.9703170, 34.2903405>,
    <0.4596685, 1.9841524, 34.2889155>,
    <0.4883966, 1.9800133, 34.2903618>,
    <0.4328835, 1.9840574, 34.2861106>,
    <0.4182576, 1.9912950, 34.2874565>,
    <0.5287730, 1.9602260, 34.2863579>,
    <0.5095578, 1.9671195, 34.2872643>,
    <0.5559621, 1.9547667, 34.2872641>,
    <0.5388668, 1.9631287, 34.2889215>,
    <0.5043651, 1.9578538, 34.2817250>,
    <0.5777566, 1.9382583, 34.2819690>,
    <0.5202115, 1.9586743, 34.2845089>,
    <0.5752977, 1.9445687, 34.2850029>,
    <0.4338662, 1.9758363, 34.2819691>,
    <0.4698041, 1.9725105, 34.2850030>,
    <0.5242959, -1.9614272, 34.2863567>,
    <0.4706789, -1.9797875, 34.2882644>,
    <0.5454910, -1.9574799, 34.2872628>,
    <0.5017449, -1.9763873, 34.2903378>,
    <0.4987199, -1.9701195, 34.2872627>,
    <0.5200089, -1.9681818, 34.2889195>,
    <0.3651386, -1.9940193, 34.2830967>,
    <0.5427117, -1.9475839, 34.2817246>,
    <0.4321735, -1.9848236, 34.2861091>,
    <0.4699104, -1.9672439, 34.2819686>,
    <0.5297390, -1.9561248, 34.2845081>,
    <0.4757455, -1.9713025, 34.2850020>,
    <0.6133571, -1.9276739, 34.2819686>,
    <0.5813823, -1.9425679, 34.2850021>,
    <0.5802600, -1.9269866, 34.2751874>,
    <0.5198346, -1.9386449, 34.2713545>,
    <0.5616514, -1.9371190, 34.2783020>,
    <0.4508104, -1.9637913, 34.2765462>,
    <0.5530925, -1.9327147, 34.2735942>,
    <0.5000392, -1.9534568, 34.2779935>,
    <0.5902641, -1.9110578, 34.2658251>,
    <0.6266312, -1.9104546, 34.2735942>,
    <0.6160308, -1.9077911, 34.2692880>,
    <0.6270900, -1.9170258, 34.2779935>,
    <0.4297669, -1.9934813, 34.2894147>,
    <0.4537628, -1.9926547, 34.2917976>,
    <0.4442915, -1.9883687, 34.2889127>,
    <0.4856314, -1.9841155, 34.2917981>,
    <0.4380093, -1.9936135, 34.2904005>,
    <0.4673268, -1.9856591, 34.2903585>,
    <0.4047101, -2.0057983, 34.2917974>,
    <0.3888192, -2.0025690, 34.2886767>,
    <0.4267195, -1.9999009, 34.2917973>,
    <0.3967596, -2.0044686, 34.2903158>,
    <0.4081715, -1.9980471, 34.2889125>,
    <0.4148661, -1.9997159, 34.2903580>,
    <0.3808989, -1.9995294, 34.2867223>,
    <0.4117948, -1.9934107, 34.2874544>,
    <0.3666101, -2.0096672, 34.2894157>,
    <0.3751077, -2.0137302, 34.2917992>,
    <0.3748855, -2.0066897, 34.2889131>,
    <0.3879431, -2.0102910, 34.2917981>,
    <0.3702428, -2.0114951, 34.2904018>,
    <0.3825524, -2.0083743, 34.2903587>,
    <0.3363496, -2.0124279, 34.2886787>,
    <0.3648935, -2.0164670, 34.2918006>,
    <0.3395327, -2.0163022, 34.2903190>,
    <0.3555064, -2.0105006, 34.2889140>,
    <0.3578293, -2.0138934, 34.2903605>,
    <0.3396650, -2.0068568, 34.2867232>,
    <0.3626662, -2.0054693, 34.2874551>,
    <0.4920903, -1.9447771, 34.2989756>,
    <0.4685340, -1.9462676, 34.2967794>,
    <0.4186648, -1.9747748, 34.3035582>,
    <0.4840037, -1.9448471, 34.2980080>,
    <0.3974478, -1.9738473, 34.3007507>,
    <0.3850248, -1.9837888, 34.3035582>,
    <0.4626636, -1.9569859, 34.3008727>,
    <0.4314546, -1.9652216, 34.3007914>,
    <0.4523047, -1.9657609, 34.3035582>,
    <0.5292354, -1.9324607, 34.2980080>,
    <0.4945519, -1.9481013, 34.3007914>,
    <0.5484170, -1.9157716, 34.2926777>,
    <0.5487917, -1.9208580, 34.2951914>,
    <0.4610965, 1.9589149, 34.2751874>,
    <0.5193351, 1.9387567, 34.2713545>,
    <0.4824320, 1.9583424, 34.2783022>,
    <0.5922929, 1.9257929, 34.2765462>,
    <0.4875003, 1.9502754, 34.2735942>,
    <0.5442221, 1.9415592, 34.2779937>,
    <0.3466602, 1.9620916, 34.2582471>,
    <0.3483527, 1.9773514, 34.2713545>,
    <0.4443452, 1.9501566, 34.2658251>,
    <0.3481448, 1.9702280, 34.2658251>,
    <0.4126906, 1.9677911, 34.2735942>,
    <0.4203972, 1.9602109, 34.2692880>,
    <0.3466038, 1.9854250, 34.2765463>,
    <0.4160043, 1.9736314, 34.2779937>,
    <0.5748047, 1.9178605, 34.2672347>,
    <0.5507798, 1.9273328, 34.2690979>,
    <0.6239729, 1.9052282, 34.2690979>,
    <0.6175627, 1.9135546, 34.2734378>,
    <0.5161122, 1.9234179, 34.2582019>,
    <0.5892076, 1.9024196, 34.2582019>,
    <0.5492536, 1.9205368, 34.2634197>,
    <0.6154651, 1.9011979, 34.2639559>,
    <0.4423209, 1.9418268, 34.2582019>,
    <0.4897554, 1.9368941, 34.2639559>,
    <0.5678495, -1.8990026, 34.2481381>,
    <0.5147427, -1.9237848, 34.2582019>,
    <0.3453208, -1.9623278, 34.2582471>,
    <0.5109011, -1.9097524, 34.2427102>,
    <0.5448040, -1.9101115, 34.2526827>,
    <0.4409411, -1.9421474, 34.2582019>,
    <0.4390278, -1.9340987, 34.2497196>,
    <0.5430294, -1.9040324, 34.2458152>,
    <0.4852192, -1.9251620, 34.2520259>,
    <0.5817050, -1.8830944, 34.2353389>,
    <0.6154586, -1.8822176, 34.2458152>,
    <0.6069763, -1.8795291, 34.2399571>,
    <0.5878523, -1.9028318, 34.2582019>,
    <0.6103268, -1.8897319, 34.2520259>,
    <0.4611982, -1.9483078, 34.2672347>,
    <0.3491632, -1.9772110, 34.2713545>,
    <0.4868196, -1.9444856, 34.2690979>,
    <0.3542090, -1.9840940, 34.2765462>,
    <0.4123802, -1.9619390, 34.2690979>,
    <0.4225221, -1.9658744, 34.2734378>,
    <0.3467085, -1.9704813, 34.2658251>,
    <0.4846009, -1.9378604, 34.2634197>,
    <0.4175906, -1.9542182, 34.2639559>,
    <0.5443064, -1.9222772, 34.2639559>,
    <0.4167702, 1.9606827, 34.2989756>,
    <0.4674605, 1.9450218, 34.2975521>,
    <0.4519458, 1.9614662, 34.3035582>,
    <0.4368864, 1.9539942, 34.2980080>,
    <0.5088126, 1.9401063, 34.3007100>,
    <0.5025134, 1.9474261, 34.3035582>,
    <0.4320330, 1.9611226, 34.3008727>,
    <0.4721594, 1.9503613, 34.3007914>,
    <0.3337837, 1.9731337, 34.2967794>,
    <0.4013783, 1.9755064, 34.3035582>,
    <0.3421905, 1.9815844, 34.3007507>,
    <0.3816830, 1.9667058, 34.2980080>,
    <0.3875427, 1.9717628, 34.3007914>,
    <0.3565648, 1.9521678, 34.2867877>,
    <0.3368818, 1.9648760, 34.2926777>,
    <0.4238074, 1.9487418, 34.2937748>,
    <0.3917751, 1.9590221, 34.2951914>,
    <0.5441075, 1.9271798, 34.2989756>,
    <0.5660307, 1.9170350, 34.2967794>,
    <0.6216823, 1.9149623, 34.3035582>,
    <0.5514980, 1.9232959, 34.2980080>,
    <0.6411021, 1.9042239, 34.3007507>,
    <0.6559830, 1.9057506, 34.3035582>,
    <0.5752612, 1.9224006, 34.3008727>,
    <0.6068380, 1.9137579, 34.3007914>,
    <0.5873816, 1.9241741, 34.3035582>,
    <0.5058549, 1.9356176, 34.2980080>,
    <0.5428830, 1.9309847, 34.3007914>,
    <0.4820226, 1.9316641, 34.2926777>,
    <0.4837681, 1.9358951, 34.2951914>,
    <0.5811506, 1.9065644, 34.2933120>,
    <0.6201669, 1.8977040, 34.2949171>,
    <0.5732975, 1.9116705, 34.2949171>,
    <0.6292726, 1.9015128, 34.2980246>,
    <0.5155861, 1.9129660, 34.2854038>,
    <0.4470363, 1.9306777, 34.2856693>,
    <0.5505305, 1.9098224, 34.2900253>,
    <0.5060186, 1.9227711, 34.2908029>,
    <0.5879881, 1.8926184, 34.2856693>,
    <0.6103329, 1.8934240, 34.2908029>,
    <0.5642846, -1.8887451, 34.2753407>,
    <0.5072428, -1.8990304, 34.2695801>,
    <0.3327510, -1.9562639, 34.2867877>,
    <0.5100893, -1.9150777, 34.2854038>,
    <0.5394816, -1.8935246, 34.2729301>,
    <0.4340102, -1.9245994, 34.2772285>,
    <0.4372645, -1.9334008, 34.2856693>,
    <0.5410246, -1.9004231, 34.2800513>,
    <0.4808580, -1.9155763, 34.2795037>,
    <0.5782448, -1.8962017, 34.2856693>,
    <0.6115363, -1.8719301, 34.2729301>,
    <0.6054132, -1.8807236, 34.2795037>,
    <0.5780924, -1.8716692, 34.2614925>,
    <0.6033372, -1.8685059, 34.2665723>,
    <0.4503452, -1.9434222, 34.2933120>,
    <0.3617001, -1.9688649, 34.2967794>,
    <0.4122904, -1.9551585, 34.2949171>,
    <0.3567588, -1.9809187, 34.3007507>,
    <0.4596621, -1.9445569, 34.2949171>,
    <0.4063665, -1.9642323, 34.2980246>,
    <0.4783676, -1.9303970, 34.2900253>,
    <0.5233080, -1.9196798, 34.2908029>,
    <0.3558243, -1.9616253, 34.2926777>,
    <0.4184992, -1.9457381, 34.2908029>,
    <0.4577292, 1.9285092, 34.2481381>,
    <0.5124229, 1.9093447, 34.2427102>,
    <0.4832417, 1.9266071, 34.2526827>,
    <0.5868402, 1.8944925, 34.2497196>,
    <0.4817389, 1.9204552, 34.2458152>,
    <0.5423689, 1.9098488, 34.2520259>,
    <0.3416631, 1.9342033, 34.2254060>,
    <0.3440717, 1.9474660, 34.2427102>,
    <0.4377759, 1.9216601, 34.2353389>,
    <0.3429909, 1.9414328, 34.2353389>,
    <0.4081060, 1.9377775, 34.2458152>,
    <0.4141077, 1.9312080, 34.2399571>,
    <0.3451770, 1.9536495, 34.2497196>,
    <0.4163074, 1.9417192, 34.2520259>,
    <0.5664708, 1.8895570, 34.2371711>,
    <0.5429631, 1.8985278, 34.2396408>,
    <0.6150792, 1.8767512, 34.2396408>,
    <0.6098070, 1.8835864, 34.2454279>,
    <0.5087052, 1.8960909, 34.2253660>,
    <0.5807615, 1.8753935, 34.2253660>,
    <0.5412288, 1.8927184, 34.2321345>,
    <0.6064666, 1.8736074, 34.2328481>,
    <0.4359630, 1.9142356, 34.2253660>,
    <0.4825741, 1.9087831, 34.2328481>,
    <0.5601613, -1.8730014, 34.2126378>,
    <0.5074938, -1.8964155, 34.2253660>,
    <0.3404783, -1.9344122, 34.2254060>,
    <0.5041548, -1.8841586, 34.2059260>,
    <0.5372929, -1.8834967, 34.2183311>,
    <0.4347425, -1.9145192, 34.2253660>,
    <0.4330724, -1.9074561, 34.2146338>,
    <0.5357537, -1.8781993, 34.2097470>,
    <0.4785615, -1.8984054, 34.2175110>,
    <0.5742436, -1.8586026, 34.1969055>,
    <0.6071940, -1.8566789, 34.2097470>,
    <0.5990274, -1.8546165, 34.2025384>,
    <0.5795627, -1.8757581, 34.2253660>,
    <0.6019216, -1.8634650, 34.2175110>,
    <0.4542004, -1.9196397, 34.2371711>,
    <0.3427510, -1.9476989, 34.2427102>,
    <0.4790441, -1.9156549, 34.2396408>,
    <0.3438272, -1.9538875, 34.2497196>,
    <0.4057014, -1.9328538, 34.2396408>,
    <0.4136848, -1.9361372, 34.2454279>,
    <0.3417031, -1.9416599, 34.2353389>,
    <0.4776413, -1.9097566, 34.2321345>,
    <0.4115882, -1.9258249, 34.2328481>,
    <0.5364701, -1.8943417, 34.2328481>,
    <0.4556503, 1.9177365, 34.2753407>,
    <0.5102466, 1.8982284, 34.2695801>,
    <0.4795568, 1.9095478, 34.2729301>,
    <0.5865020, 1.8837508, 34.2772285>,
    <0.4815864, 1.9160862, 34.2800513>,
    <0.5413498, 1.8992331, 34.2795037>,
    <0.3428535, 1.9362568, 34.2695801>,
    <0.3461415, 1.9430673, 34.2772285>,
    <0.4063323, 1.9268551, 34.2729301>,
    <0.4159514, 1.9312530, 34.2795037>,
    <0.3395075, 1.9216322, 34.2505667>,
    <0.3409740, 1.9296174, 34.2614925>,
    <0.4351919, 1.9099593, 34.2614925>,
    <0.4117476, 1.9198421, 34.2665723>,
    <0.5633457, 1.8781631, 34.2635082>,
    <0.6119844, 1.8656002, 34.2662252>,
    <0.5402995, 1.8872497, 34.2662252>,
    <0.6083032, 1.8726965, 34.2725930>,
    <0.5054670, 1.8837634, 34.2505227>,
    <0.4331978, 1.9017923, 34.2505227>,
    <0.5379288, 1.8809273, 34.2579678>,
    <0.4796597, 1.8969521, 34.2587527>,
    <0.5770545, 1.8631983, 34.2505227>,
    <0.6027766, 1.8619920, 34.2587527>,
    <0.5561995, -1.8599823, 34.2365221>,
    <0.5004616, -1.8706379, 34.2291393>,
    <0.3382042, -1.9218620, 34.2505667>,
    <0.5041344, -1.8841205, 34.2505227>,
    <0.5319061, -1.8649563, 34.2333423>,
    <0.4300181, -1.8943348, 34.2387176>,
    <0.4318553, -1.9021043, 34.2505227>,
    <0.5335993, -1.8707835, 34.2427845>,
    <0.4752460, -1.8855366, 34.2418824>,
    <0.5757359, -1.8635994, 34.2505227>,
    <0.6028477, -1.8435889, 34.2333423>,
    <0.5977770, -1.8508354, 34.2418824>,
    <0.5698849, -1.8447282, 34.2192172>,
    <0.5945935, -1.8411020, 34.2254131>,
    <0.4512138, -1.9082048, 34.2635082>,
    <0.3400707, -1.9367430, 34.2695801>,
    <0.4028149, -1.9216380, 34.2662252>,
    <0.3393367, -1.9442492, 34.2772285>,
    <0.4757206, -1.9045445, 34.2662252>,
    <0.4095777, -1.9259088, 34.2725930>,
    <0.4746037, -1.8978952, 34.2579678>,
    <0.5330785, -1.8826386, 34.2587527>,
    <0.3395573, -1.9298672, 34.2614925>,
    <0.4089762, -1.9139206, 34.2587527>,
    <0.4513868, 1.9021475, 34.2126378>,
    <0.5054684, 1.8838066, 34.2059260>,
    <0.4764390, 1.8998025, 34.2183311>,
    <0.5786764, 1.8684416, 34.2146338>,
    <0.4751233, 1.8944451, 34.2097470>,
    <0.5347562, 1.8833481, 34.2175110>,
    <0.3373208, 1.9101346, 34.1849198>,
    <0.3393836, 1.9214069, 34.2059260>,
    <0.4319917, 1.8967188, 34.1969055>,
    <0.3384499, 1.9162277, 34.1969055>,
    <0.4024940, 1.9115281, 34.2097470>,
    <0.4085352, 1.9056587, 34.2025384>,
    <0.3403483, 1.9267714, 34.2146338>,
    <0.4104531, 1.9147688, 34.2175110>,
    <0.5589712, 1.8648478, 34.1991181>,
    <0.5356964, 1.8734476, 34.2021355>,
    <0.6068665, 1.8519602, 34.2021355>,
    <0.6014710, 1.8581188, 34.2092829>,
    <0.5022822, 1.8725097, 34.1848862>,
    <0.5734418, 1.8520730, 34.1848862>,
    <0.5342068, 1.8684826, 34.1929998>,
    <0.5985894, 1.8495461, 34.1938690>,
    <0.4304454, 1.8904252, 34.1848862>,
    <0.4762782, 1.8842668, 34.1938690>,
    <0.5536769, -1.8509560, 34.1698789>,
    <0.5012657, -1.8727821, 34.1848862>,
    <0.3363267, -1.9103099, 34.1849198>,
    <0.4985307, -1.8626730, 34.1620860>,
    <0.5309042, -1.8607447, 34.1765488>,
    <0.4294213, -1.8906632, 34.1848862>,
    <0.4280450, -1.8848002, 34.1722289>,
    <0.5296470, -1.8563899, 34.1665078>,
    <0.4729113, -1.8755589, 34.1755900>,
    <0.5681066, -1.8383263, 34.1516897>,
    <0.6002501, -1.8351176, 34.1665078>,
    <0.5924259, -1.8338101, 34.1581668>,
    <0.5724359, -1.8523790, 34.1848862>,
    <0.5947756, -1.8410356, 34.1755900>,
    <0.4483406, -1.8944912, 34.1991181>,
    <0.3382436, -1.9216080, 34.2059260>,
    <0.4727971, -1.8903015, 34.2021355>,
    <0.3391718, -1.9269788, 34.2146338>,
    <0.4004182, -1.9072779, 34.2021355>,
    <0.4081702, -1.9099136, 34.2092829>,
    <0.3373496, -1.9164218, 34.1969055>,
    <0.4716046, -1.8852568, 34.1929998>,
    <0.4063794, -1.9010486, 34.1938690>,
    <0.5296644, -1.8699621, 34.1938690>,
    <0.4483082, 1.8888917, 34.2365221>,
    <0.5019065, 1.8702507, 34.2291393>,
    <0.4718339, 1.8810526, 34.2333423>,
    <0.5747609, 1.8555511, 34.2387176>,
    <0.4732812, 1.8869457, 34.2427845>,
    <0.5311932, 1.8705456, 34.2418824>,
    <0.3370059, 1.9075889, 34.2291393>,
    <0.3380671, 1.9134898, 34.2387176>,
    <0.3997130, 1.8980186, 34.2333423>,
    <0.4077276, 1.9017590, 34.2418824>,
    <0.3347310, 1.8951567, 34.2060335>,
    <0.3359788, 1.9018918, 34.2192172>,
    <0.4288293, 1.8825239, 34.2192172>,
    <0.4056179, 1.8917378, 34.2254131>,
    <0.5548904, 1.8510133, 34.2216509>,
    <0.6024874, 1.8383983, 34.2249699>,
    <0.5318431, 1.8597295, 34.2249699>,
    <0.5972814, 1.8449546, 34.2328318>,
    <0.4984017, 1.8578241, 34.2059966>,
    <0.4271284, 1.8756009, 34.2059966>,
    <0.5302045, 1.8542680, 34.2149211>,
    <0.4727343, 1.8699842, 34.2158771>,
    <0.5690029, 1.8375457, 34.2059966>,
    <0.5941116, 1.8355246, 34.2158771>,
    <0.5490667, -1.8357324, 34.1894897>,
    <0.4942750, -1.8470037, 34.1809181>,
    <0.3336375, -1.8953495, 34.2060335>,
    <0.4972835, -1.8581237, 34.2059966>,
    <0.5251888, -1.8409661, 34.1857817>,
    <0.4244880, -1.8694134, 34.1920745>,
    <0.4260019, -1.8758627, 34.2059966>,
    <0.5265717, -1.8457564, 34.1968260>,
    <0.4690307, -1.8604055, 34.1957715>,
    <0.5678964, -1.8378823, 34.2059966>,
    <0.5952093, -1.8198714, 34.1857817>,
    <0.5899165, -1.8261631, 34.1957715>,
    <0.5631342, -1.8224244, 34.1694828>,
    <0.5873318, -1.8182150, 34.1766071>,
    <0.4449575, -1.8804698, 34.2216509>,
    <0.3357519, -1.9078101, 34.2291393>,
    <0.3974297, -1.8933433, 34.2249699>,
    <0.3367729, -1.9137180, 34.2387176>,
    <0.4692751, -1.8764946, 34.2249699>,
    <0.4052164, -1.8964182, 34.2328318>,
    <0.4679634, -1.8709455, 34.2149211>,
    <0.5255922, -1.8558210, 34.2158771>,
    <0.3347685, -1.9021052, 34.2192172>,
    <0.4032465, -1.8866667, 34.2158771>,
    <0.4459797, 1.8798134, 34.1698789>,
    <0.4995962, 1.8623875, 34.1620860>,
    <0.4705958, 1.8769043, 34.1765488>,
    <0.5717023, 1.8463074, 34.1722289>,
    <0.4695072, 1.8725044, 34.1665078>,
    <0.5282262, 1.8607374, 34.1755900>,
    <0.3337654, 1.8906169, 34.1380150>,
    <0.3354180, 1.8995464, 34.1620860>,
    <0.4271684, 1.8760906, 34.1516897>,
    <0.3346597, 1.8953785, 34.1516897>,
    <0.3977270, 1.8893835, 34.1665078>,
    <0.4038492, 1.8843391, 34.1581668>,
    <0.3362128, 1.9039288, 34.1722289>,
    <0.4054270, 1.8917715, 34.1755900>,
    <0.5527115, 1.8443421, 34.1542153>,
    <0.5296006, 1.8525356, 34.1576891>,
    <0.5999844, 1.8312899, 34.1576891>,
    <0.5944080, 1.8366511, 34.1659804>,
    <0.4970382, 1.8533906, 34.1379890>,
    <0.5674709, 1.8331664, 34.1379890>,
    <0.5284009, 1.8485659, 34.1472010>,
    <0.5920727, 1.8297451, 34.1481994>,
    <0.4259356, 1.8711191, 34.1379890>,
    <0.4710592, 1.8640903, 34.1481994>,
    <0.5485933, -1.8335362, 34.1211611>,
    <0.4962476, -1.8536025, 34.1379890>,
    <0.3329921, -1.8907533, 34.1380150>,
    <0.4941997, -1.8459485, 34.1125260>,
    <0.5258319, -1.8425469, 34.1286034>,
    <0.4251390, -1.8713042, 34.1379890>,
    <0.4240984, -1.8668196, 34.1237934>,
    <0.5248950, -1.8392670, 34.1174128>,
    <0.4684402, -1.8573167, 34.1275355>,
    <0.5634805, -1.8228818, 34.1010718>,
    <0.5948378, -1.8181887, 34.1174128>,
    <0.5873721, -1.8177423, 34.1081947>,
    <0.5666885, -1.8334044, 34.1379890>,
    <0.5891061, -1.8231252, 34.1275355>,
    <0.4435088, -1.8736029, 34.1542153>,
    <0.3344933, -1.8997094, 34.1620860>,
    <0.4676202, -1.8691432, 34.1576891>,
    <0.3352453, -1.9040994, 34.1722289>,
    <0.3960432, -1.8859358, 34.1576891>,
    <0.4035531, -1.8877905, 34.1659804>,
    <0.3337804, -1.8955336, 34.1516897>,
    <0.4666744, -1.8651054, 34.1472010>,
    <0.4021226, -1.8806421, 34.1481994>,
    <0.5240959, -1.8498791, 34.1481994>,
    <0.4416723, 1.8621856, 34.1211611>,
    <0.4949848, 1.8457381, 34.1125260>,
    <0.4658897, 1.8586083, 34.1286034>,
    <0.5661298, 1.8287624, 34.1237934>,
    <0.4650611, 1.8552995, 34.1174128>,
    <0.5229772, 1.8427036, 34.1275355>,
    <0.3311050, 1.8762432, 34.0861253>,
    <0.3322954, 1.8825486, 34.1125260>,
    <0.4234525, 1.8604022, 34.1010718>,
    <0.3317354, 1.8795187, 34.1010718>,
    <0.3939497, 1.8720165, 34.1174128>,
    <0.4001920, 1.8678971, 34.1081947>,
    <0.3328962, 1.8858157, 34.1237934>,
    <0.4013817, 1.8734258, 34.1275355>,
    <0.5478820, 1.8286630, 34.1038334>,
    <0.5248608, 1.8364271, 34.1076575>,
    <0.5946421, 1.8153685, 34.1076575>,
    <0.5888326, 1.8198356, 34.1168389>,
    <0.4931327, 1.8393146, 34.0861074>,
    <0.5630302, 1.8192485, 34.0861074>,
    <0.5239874, 1.8335734, 34.0961373>,
    <0.5871146, 1.8148062, 34.0972345>,
    <0.4225707, 1.8569039, 34.0861074>,
    <0.4670755, 1.8488665, 34.0972345>,
    <0.5449806, -1.8211018, 34.0680823>,
    <0.4925919, -1.8394595, 34.0861074>,
    <0.3305760, -1.8763365, 34.0861253>,
    <0.4909580, -1.8337930, 34.0592183>,
    <0.5222301, -1.8294561, 34.0759583>,
    <0.4220258, -1.8570305, 34.0861074>,
    <0.4213525, -1.8540605, 34.0708032>,
    <0.5214519, -1.8269693, 34.0642124>,
    <0.4652840, -1.8442331, 34.0748134>,
    <0.5591646, -1.8099375, 34.0484530>,
    <0.5909314, -1.8060251, 34.0642124>,
    <0.5832595, -1.8053746, 34.0551646>,
    <0.5624950, -1.8194113, 34.0861074>,
    <0.5850854, -1.8102779, 34.0748134>,
    <0.4398518, -1.8576097, 34.1038334>,
    <0.3316140, -1.8826688, 34.1125260>,
    <0.4636708, -1.8528229, 34.1076575>,
    <0.3321669, -1.8859443, 34.1237934>,
    <0.3927091, -1.8694762, 34.1076575>,
    <0.3999738, -1.8704401, 34.1168389>,
    <0.3311039, -1.8796301, 34.1010718>,
    <0.4630003, -1.8499148, 34.0961373>,
    <0.3989470, -1.8652256, 34.0972345>,
    <0.5199340, -1.8347031, 34.0972345>,
    <0.4423605, 1.8643242, 34.1894897>,
    <0.4954471, 1.8466897, 34.1809181>,
    <0.4656562, 1.8569178, 34.1857817>,
    <0.5670894, 1.8312035, 34.1920745>,
    <0.4668537, 1.8617577, 34.1968260>,
    <0.5240102, 1.8456738, 34.1957715>,
    <0.3326438, 1.8835423, 34.1809181>,
    <0.3335181, 1.8883629, 34.1920745>,
    <0.3944693, 1.8736595, 34.1857817>,
    <0.4021989, 1.8764619, 34.1957715>,
    <0.3308202, 1.8736872, 34.1544411>,
    <0.3318096, 1.8789577, 34.1694828>,
    <0.4235237, 1.8598328, 34.1694828>,
    <0.4004633, 1.8682863, 34.1766071>,
    <0.5480048, 1.8284571, 34.1722608>,
    <0.5949172, 1.8156610, 34.1760819>,
    <0.5251377, 1.8367263, 34.1760819>,
    <0.5895121, 1.8213401, 34.1852017>,
    <0.4926333, 1.8367930, 34.1544124>,
    <0.4221677, 1.8543641, 34.1544124>,
    <0.5238180, 1.8323596, 34.1645454>,
    <0.4669934, 1.8477900, 34.1656437>,
    <0.5624349, 1.8167485, 34.1544124>,
    <0.5869433, 1.8137435, 34.1656437>,
    <0.5434748, -1.8165706, 34.1359011>,
    <0.4895109, -1.8286067, 34.1264018>,
    <0.3299695, -1.8738371, 34.1544411>,
    <0.4917636, -1.8370261, 34.1544124>,
    <0.5199616, -1.8221308, 34.1317777>,
    <0.4201467, -1.8496347, 34.1387967>,
    <0.4212914, -1.8545678, 34.1544124>,
    <0.5209922, -1.8257387, 34.1440880>,
    <0.4641125, -1.8403391, 34.1429132>,
    <0.5615742, -1.8170103, 34.1544124>,
    <0.5892558, -1.8012496, 34.1317777>,
    <0.5836801, -1.8064616, 34.1429132>,
    <0.5580454, -1.8054354, 34.1138015>,
    <0.5817727, -1.8005404, 34.1216372>,
    <0.4396425, -1.8574927, 34.1722608>,
    <0.3316265, -1.8837217, 34.1809181>,
    <0.3926172, -1.8698671, 34.1760819>,
    <0.3324537, -1.8885506, 34.1920745>,
    <0.4635806, -1.8532205, 34.1760819>,
    <0.4001376, -1.8720829, 34.1852017>,
    <0.4625401, -1.8487790, 34.1645454>,
    <0.5194669, -1.8337298, 34.1656437>,
    <0.3308424, -1.8791282, 34.1694828>,
    <0.3985640, -1.8642196, 34.1656437>,
    <0.4385749, 1.8496072, 34.0680823>,
    <0.4916775, 1.8335761, 34.0592183>,
    <0.4624635, 1.8454706, 34.0759583>,
    <0.5621283, 1.8163397, 34.0708032>,
    <0.4618738, 1.8429199, 34.0642124>,
    <0.5191688, 1.8297948, 34.0748134>,
    <0.3254977, 1.8571113, 34.0360499>,
    <0.3300379, 1.8701397, 34.0592183>,
    <0.4205703, 1.8469773, 34.0484530>,
    <0.3294754, 1.8659687, 34.0484530>,
    <0.3912306, 1.8595215, 34.0642124>,
    <0.3974887, 1.8550988, 34.0551646>,
    <0.3304991, 1.8729827, 34.0708032>,
    <0.3984402, 1.8602894, 34.0748134>,
    <0.5442680, 1.8164330, 34.0506060>,
    <0.5214667, 1.8246254, 34.0541438>,
    <0.5907739, 1.8037062, 34.0541438>,
    <0.5849142, 1.8081832, 34.0633523>,
    <0.4876378, 1.8209299, 34.0364216>,
    <0.5535467, 1.8014040, 34.0363197>,
    <0.5202874, 1.8197891, 34.0438443>,
    <0.5829545, 1.8012899, 34.0448606>,
    <0.4187111, 1.8376006, 34.0363197>,
    <0.4638313, 1.8351128, 34.0448606>,
    <0.5395877, -1.7865566, 34.0264558>,
    <0.4874570, -1.8215037, 34.0364647>,
    <0.3280371, -1.8575971, 34.0361559>,
    <0.4989035, -1.7841742, 34.0228405>,
    <0.5159687, -1.8040286, 34.0303723>,
    <0.4193020, -1.8381306, 34.0364059>,
    <0.4264857, -1.8174846, 34.0277741>,
    <0.5233660, -1.7859398, 34.0246615>,
    <0.4664542, -1.8144890, 34.0296825>,
    <0.5696627, -1.7477086, 34.0186848>,
    <0.5791051, -1.7687732, 34.0246615>,
    <0.5762802, -1.7577528, 34.0213137>,
    <0.5560040, -1.8015689, 34.0364059>,
    <0.5747357, -1.7837152, 34.0296825>,
    <0.4368076, -1.8452841, 34.0506060>,
    <0.3294632, -1.8702651, 34.0592183>,
    <0.4606780, -1.8409439, 34.0541438>,
    <0.3300303, -1.8730653, 34.0708032>,
    <0.3901967, -1.8574809, 34.0541438>,
    <0.3975410, -1.8583897, 34.0633523>,
    <0.3284812, -1.8662404, 34.0484530>,
    <0.4591798, -1.8362914, 34.0438443>,
    <0.3956666, -1.8515946, 34.0448606>,
    <0.5157419, -1.8213244, 34.0448606>,
    <0.4206662, 1.8151803, 34.0259962>,
    <0.4453660, 1.7931389, 34.0220434>,
    <0.4523012, 1.8196294, 34.0302000>,
    <0.5266395, 1.7871570, 34.0272571>,
    <0.4295991, 1.8069233, 34.0240583>,
    <0.4946408, 1.8045181, 34.0293378>,
    <0.3240927, 1.8189976, 34.0220547>,
    <0.3901727, 1.7897835, 34.0178631>,
    <0.3426281, 1.7993310, 34.0179808>,
    <0.3819072, 1.8174709, 34.0240583>,
    <0.3817841, 1.8049103, 34.0206243>,
    <0.3205890, 1.8360912, 34.0271844>,
    <0.3928096, 1.8300439, 34.0293378>,
    <0.5185828, 1.7659754, 34.0202515>,
    <0.4846567, 1.7785787, 34.0210033>,
    <0.5708022, 1.7553861, 34.0214341>,
    <0.5551087, 1.7699933, 34.0244636>,
    <0.4761959, 1.7574692, 34.0159774>,
    <0.5471349, 1.7384615, 34.0159774>,
    <0.5021617, 1.7629408, 34.0184809>,
    <0.5644740, 1.7456949, 34.0186456>,
    <0.4173781, 1.7732292, 34.0159774>,
    <0.4436549, 1.7781560, 34.0183009>,
    <0.4291168, -1.7926804, 34.0204813>,
    <0.3206074, -1.8253096, 34.0228405>,
    <0.4609683, -1.7890150, 34.0215203>,
    <0.3247354, -1.8393111, 34.0277741>,
    <0.3801998, -1.8083277, 34.0215203>,
    <0.3963566, -1.8154031, 34.0248083>,
    <0.4701494, -1.7612679, 34.0159774>,
    <0.3195312, -1.8106947, 34.0186848>,
    <0.3931496, -1.7819005, 34.0159774>,
    <0.4460617, -1.7802207, 34.0185671>,
    <0.3821484, -1.7963418, 34.0186456>,
    <0.5471492, -1.7406354, 34.0159774>,
    <0.5083630, -1.7643855, 34.0186456>,
    <0.4376224, 1.8449337, 34.1359011>,
    <0.4903745, 1.8283753, 34.1264018>,
    <0.4607655, 1.8379924, 34.1317777>,
    <0.5609596, 1.8119040, 34.1387967>,
    <0.4616769, 1.8416321, 34.1440880>,
    <0.5182364, 1.8258366, 34.1429132>,
    <0.3292089, 1.8648447, 34.1264018>,
    <0.3298697, 1.8684386, 34.1387967>,
    <0.3903144, 1.8545558, 34.1317777>,
    <0.3977491, 1.8562816, 34.1429132>,
    <0.3278937, 1.8578761, 34.0973598>,
    <0.3285929, 1.8615118, 34.1138015>,
    <0.4194362, 1.8425756, 34.1138015>,
    <0.3964403, 1.8502000, 34.1216372>,
    <0.5426923, 1.8112101, 34.1168394>,
    <0.5890405, 1.7981473, 34.1210460>,
    <0.5199239, 1.8190069, 34.1210460>,
    <0.5833791, 1.8028430, 34.1311462>,
    <0.4883372, 1.8213094, 34.0973402>,
    <0.4184663, 1.8387274, 34.0973402>,
    <0.5189632, 1.8158678, 34.1083733>,
    <0.4626114, 1.8310438, 34.1095803>,
    <0.5575501, 1.8014387, 34.0973402>,
    <0.5814894, 1.7973107, 34.1095803>,
    <0.5395099, -1.8029115, 34.0775018>,
    <0.4859819, -1.8153131, 34.0677166>,
    <0.3273118, -1.8579787, 34.0973598>,
    <0.4877423, -1.8214688, 34.0973402>,
    <0.5161950, -1.8086455, 34.0732308>,
    <0.4171262, -1.8355996, 34.0805061>,
    <0.4178668, -1.8388667, 34.0973402>,
    <0.5170302, -1.8113388, 34.0861763>,
    <0.4606407, -1.8259471, 34.0849170>,
    <0.5569613, -1.8016177, 34.0973402>,
    <0.5849797, -1.7879118, 34.0732308>,
    <0.5792572, -1.7923295, 34.0849170>,
    <0.5534454, -1.7915067, 34.0557354>,
    <0.5773323, -1.7871050, 34.0632019>,
    <0.4356198, -1.8399001, 34.1168394>,
    <0.3284593, -1.8649769, 34.1264018>,
    <0.3889497, -1.8517615, 34.1210460>,
    <0.3290675, -1.8685800, 34.1387967>,
    <0.4592362, -1.8352681, 34.1210460>,
    <0.3962004, -1.8529974, 34.1311462>,
    <0.4584986, -1.8320692, 34.1083733>,
    <0.5148887, -1.8170361, 34.1095803>,
    <0.3278982, -1.8616343, 34.1138015>,
    <0.3950708, -1.8472614, 34.1095803>,
    <0.4342174, 1.8311186, 34.0775018>,
    <0.4867469, 1.8150841, 34.0677166>,
    <0.4572645, 1.8244227, 34.0732308>,
    <0.5565579, 1.7982390, 34.0805061>,
    <0.4579081, 1.8271805, 34.0861763>,
    <0.5140470, 1.8116369, 34.0849170>,
    <0.3267335, 1.8512822, 34.0677166>,
    <0.3272329, 1.8543222, 34.0805061>,
    <0.3873284, 1.8408591, 34.0732308>,
    <0.3945134, 1.8418315, 34.0849170>,
    <0.3219696, 1.8385839, 34.0418241>,
    <0.3261383, 1.8469558, 34.0557354>,
    <0.4163078, 1.8281562, 34.0557354>,
    <0.3934869, 1.8363133, 34.0632019>,
    <0.5387564, 1.7979616, 34.0581798>,
    <0.5848104, 1.7854263, 34.0621232>,
    <0.5162073, 1.8061339, 34.0621232>,
    <0.5790689, 1.7900253, 34.0723106>,
    <0.4837957, 1.8023721, 34.0422290>,
    <0.4146027, 1.8196528, 34.0422290>,
    <0.5149821, 1.8011655, 34.0506039>,
    <0.4591099, 1.8163502, 34.0517365>,
    <0.5523394, 1.7826785, 34.0422290>,
    <0.5770131, 1.7828724, 34.0517365>,
    <0.5278914, -1.7728757, 34.0309402>,
    <0.4710613, -1.7778671, 34.0270017>,
    <0.3232003, -1.8396244, 34.0420193>,
    <0.4819021, -1.8031745, 34.0422290>,
    <0.5032080, -1.7757065, 34.0289781>,
    <0.4085272, -1.8063244, 34.0327086>,
    <0.4126948, -1.8203912, 34.0422290>,
    <0.5085434, -1.7870626, 34.0352527>,
    <0.4525201, -1.8004530, 34.0346796>,
    <0.5504654, -1.7835436, 34.0422290>,
    <0.5707534, -1.7554000, 34.0289781>,
    <0.5695898, -1.7673434, 34.0346796>,
    <0.5277732, -1.7493997, 34.0225462>,
    <0.5568873, -1.7489989, 34.0250143>,
    <0.4323451, -1.8265316, 34.0581798>,
    <0.3261187, -1.8514147, 34.0677166>,
    <0.3862212, -1.8386684, 34.0621232>,
    <0.3267172, -1.8544131, 34.0805061>,
    <0.4559871, -1.8223001, 34.0621232>,
    <0.3935243, -1.8397418, 34.0723106>,
    <0.4544625, -1.8175103, 34.0506039>,
    <0.5104493, -1.8027149, 34.0517365>,
    <0.3251142, -1.8472328, 34.0557354>,
    <0.3916033, -1.8326739, 34.0517365>,
    <0.4279563, 1.7988741, 34.0309402>,
    <0.4787141, 1.7747218, 34.0270017>,
    <0.4504036, 1.7889497, 34.0289781>,
    <0.5482807, 1.7681683, 34.0327086>,
    <0.4522967, 1.8015968, 34.0352527>,
    <0.5074516, 1.7851591, 34.0346796>,
    <0.3202044, 1.8102209, 34.0269285>,
    <0.3179442, 1.8228799, 34.0324158>,
    <0.3817543, 1.8051365, 34.0289781>,
    <0.3895115, 1.8150203, 34.0346796>,
    <0.3222826, 1.7974450, 34.0225462>,
    <0.4129858, 1.7786663, 34.0225462>,
    <0.3892490, 1.7926854, 34.0250143>,
    <0.5277939, 1.7501879, 34.0235247>,
    <0.5718397, 1.7407280, 34.0249046>,
    <0.5059487, 1.7608631, 34.0249264>,
    <0.5680884, 1.7530850, 34.0290881>,
    <0.5063836, 1.7486015, 34.0210157>,
    <0.4539549, 1.7640783, 34.0213315>,
    <0.5644994, 1.7319160, 34.0212444>,
    <0.4142445, -1.7819895, 34.0235181>,
    <0.3157728, -1.8124334, 34.0269467>,
    <0.3725671, -1.7953394, 34.0248897>,
    <0.3197413, -1.8247331, 34.0327086>,
    <0.4399362, -1.7798313, 34.0249264>,
    <0.3835723, -1.8034868, 34.0290881>,
    <0.4288439, -1.7709632, 34.0210008>,
    <0.4831930, -1.7578618, 34.0213315>,
    <0.3095401, -1.8010674, 34.0223261>,
    <0.3704234, -1.7852817, 34.0211848>,
    <0.2918339, 2.0188538, 34.2894179>,
    <0.2404546, 2.0208435, 34.2882666>,
    <0.1978263, 2.0326918, 34.2918022>,
    <0.2761789, 2.0258360, 34.2918022>,
    <0.2720547, 2.0195016, 34.2889155>,
    <0.2131902, 2.0280407, 34.2903408>,
    <0.2367286, 2.0292879, 34.2918022>,
    <0.2868904, 2.0216707, 34.2904043>,
    <0.2514360, 2.0247423, 34.2903620>,
    <0.3159944, 2.0223520, 34.2918022>,
    <0.3162987, 2.0153045, 34.2889155>,
    <0.3185374, 2.0186102, 34.2903620>,
    <0.2773019, 2.0123859, 34.2861106>,
    <0.3044964, 2.0128709, 34.2874565>,
    <0.2793964, -2.0199421, 34.2894177>,
    <0.2585474, -2.0273788, 34.2918022>,
    <0.1656088, -2.0355106, 34.2918022>,
    <0.2263856, -2.0219435, 34.2882666>,
    <0.2720815, -2.0229815, 34.2904043>,
    <0.2112336, -2.0315186, 34.2918022>,
    <0.1880734, -2.0302383, 34.2903408>,
    <0.2582759, -2.0206324, 34.2889154>,
    <0.2311837, -2.0265143, 34.2903620>,
    <0.2772919, -2.0118630, 34.2861104>,
    <0.3083870, -2.0159969, 34.2889152>,
    <0.2996523, -2.0129955, 34.2874563>,
    <0.3069871, -2.0231404, 34.2918022>,
    <0.3095740, -2.0194546, 34.2903618>,
    <0.2800692, -1.9835018, 34.2989756>,
    <0.2275888, -1.9852416, 34.2975521>,
    <0.1536156, -2.0004924, 34.3035582>,
    <0.2484863, -1.9955517, 34.3035582>,
    <0.2591613, -1.9835531, 34.2980080>,
    <0.1897657, -1.9933853, 34.3007100>,
    <0.1995457, -1.9976111, 34.3035582>,
    <0.2663374, -1.9887857, 34.3008727>,
    <0.2266543, -1.9910908, 34.3007914>,
    <0.2994338, -1.9940403, 34.3035582>,
    <0.3146963, -1.9781414, 34.2980080>,
    <0.3110376, -1.9853331, 34.3007914>,
    <0.2687579, -1.9750246, 34.2937748>,
    <0.3024648, -1.9739808, 34.2951914>,
    <0.2368714, -1.9984304, 34.2751756>,
    <0.1963508, -2.0121010, 34.2816852>,
    <0.0152142, -2.0251450, 34.2825385>,
    <0.1754451, -1.9993190, 34.2713146>,
    <0.2168416, -2.0051249, 34.2782756>,
    <0.1214763, -2.0184135, 34.2818098>,
    <0.1035530, -2.0116716, 34.2763869>,
    <0.2091774, -1.9993013, 34.2735677>,
    <0.1536284, -2.0102318, 34.2778875>,
    <0.2494450, -1.9845228, 34.2658251>,
    <0.2853643, -1.9902438, 34.2735942>,
    <0.2753875, -1.9857800, 34.2692880>,
    <0.2693025, -2.0048964, 34.2819690>,
    <0.2846753, -1.9967949, 34.2779936>,
    <0.1748849, -2.0227076, 34.2863462>,
    <0.1148452, -2.0316751, 34.2882268>,
    <0.1967190, -2.0225148, 34.2872643>,
    <0.1455707, -2.0339569, 34.2903408>,
    <0.1471271, -2.0268718, 34.2872378>,
    <0.1680436, -2.0287797, 34.2889218>,
    <0.0766670, -2.0293071, 34.2859512>,
    <0.1818271, -2.0183255, 34.2844823>,
    <0.1254570, -2.0236883, 34.2848968>,
    <0.2352278, -2.0140117, 34.2850030>,
    <0.0603594, -2.0385336, 34.2894060>,
    <0.0805524, -2.0429524, 34.2918022>,
    <0.0822230, -2.0358360, 34.2888889>,
    <0.1222361, -2.0393054, 34.2918022>,
    <0.0677476, -2.0406416, 34.2904043>,
    <0.1054714, -2.0375132, 34.2903620>,
    <-0.0031790, -2.0388168, 34.2886392>,
    <0.0399947, -2.0465008, 34.2918022>,
    <-0.0035646, -2.0435630, 34.2903193>,
    <0.0317585, -2.0389115, 34.2888888>,
    <0.0322033, -2.0428517, 34.2903619>,
    <0.0006043, -2.0335589, 34.2865643>,
    <0.0460070, -2.0343890, 34.2873502>,
    <0.1487614, -1.9951464, 34.2989756>,
    <0.1240259, -1.9949519, 34.2967794>,
    <0.0727938, -2.0092683, 34.3035582>,
    <0.1400421, -1.9949117, 34.2980080>,
    <0.0490552, -2.0093258, 34.3007507>,
    <0.0358952, -2.0146150, 34.3035582>,
    <0.1182700, -2.0008679, 34.3008727>,
    <0.0847937, -2.0050861, 34.3007914>,
    <0.1116994, -2.0044694, 34.3035582>,
    <0.1879593, -1.9896344, 34.2980080>,
    <0.1534491, -1.9968060, 34.3007914>,
    <0.2079414, -1.9797552, 34.2926777>,
    <0.2079903, -1.9834464, 34.2951914>,
    <0.2294643, -1.9687585, 34.2481381>,
    <0.1728608, -1.9839423, 34.2582019>,
    <-0.0006800, -1.9924800, 34.2582471>,
    <0.1715144, -1.9694560, 34.2427102>,
    <0.2048398, -1.9756969, 34.2526827>,
    <0.0969918, -1.9892105, 34.2582019>,
    <0.0965052, -1.9809518, 34.2497196>,
    <0.2041478, -1.9694020, 34.2458152>,
    <0.1435468, -1.9801719, 34.2520259>,
    <0.2458717, -1.9554980, 34.2353389>,
    <0.2792647, -1.9604957, 34.2458152>,
    <0.2713781, -1.9563751, 34.2399571>,
    <0.2484982, -1.9760030, 34.2582019>,
    <0.2729061, -1.9670047, 34.2520259>,
    <0.1159159, -1.9987528, 34.2672229>,
    <0.0006696, -2.0076623, 34.2713146>,
    <0.1418673, -1.9993852, 34.2690713>,
    <0.0048937, -2.0148912, 34.2763869>,
    <0.0655281, -2.0036472, 34.2690713>,
    <0.0751327, -2.0090001, 34.2733316>,
    <-0.0007292, -2.0007505, 34.2658251>,
    <0.1407328, -1.9925700, 34.2634197>,
    <0.0719000, -1.9970431, 34.2639559>,
    <0.2022373, -1.9875913, 34.2639559>,
    <0.2277412, -1.9579520, 34.2753407>,
    <0.1697754, -1.9582332, 34.2695801>,
    <-0.0119740, -1.9839767, 34.2867877>,
    <0.1698215, -1.9740880, 34.2854038>,
    <0.2024799, -1.9583972, 34.2729301>,
    <0.0932215, -1.9706118, 34.2772285>,
    <0.0948982, -1.9795429, 34.2856693>,
    <0.2028148, -1.9653063, 34.2800513>,
    <0.1409218, -1.9698125, 34.2795037>,
    <0.2403051, -1.9672313, 34.2856693>,
    <0.2772017, -1.9496343, 34.2729301>,
    <0.2696844, -1.9570834, 34.2795037>,
    <0.2442979, -1.9436190, 34.2614925>,
    <0.2697085, -1.9448874, 34.2665723>,
    <0.1061387, -1.9906256, 34.2933120>,
    <0.0143300, -2.0001946, 34.2967794>,
    <0.0665568, -1.9955572, 34.2949171>,
    <0.0073950, -2.0102550, 34.3007507>,
    <0.1152486, -1.9928008, 34.2949171>,
    <0.0592583, -2.0025991, 34.2980246>,
    <0.1359425, -1.9832174, 34.2900253>,
    <0.1822120, -1.9800744, 34.2908029>,
    <0.0098003, -1.9926886, 34.2926777>,
    <0.0742733, -1.9879982, 34.2908029>,
    <0.2264080, -1.9418173, 34.2126378>,
    <0.1704748, -1.9557301, 34.2253660>,
    <-0.0006015, -1.9641476, 34.2254060>,
    <0.1693149, -1.9430796, 34.2059260>,
    <0.2020645, -1.9481821, 34.2183311>,
    <0.0956851, -1.9609256, 34.2253660>,
    <0.0952667, -1.9536797, 34.2146338>,
    <0.2014685, -1.9426979, 34.2097470>,
    <0.1416365, -1.9526657, 34.2175110>,
    <0.2427766, -1.9300825, 34.1969055>,
    <0.2755605, -1.9339099, 34.2097470>,
    <0.2678761, -1.9304607, 34.2025384>,
    <0.2450359, -1.9479012, 34.2253660>,
    <0.2691897, -1.9396774, 34.2175110>,
    <0.1139581, -1.9693472, 34.2371711>,
    <-0.0006705, -1.9776270, 34.2427102>,
    <0.1391163, -1.9697369, 34.2396408>,
    <-0.0006853, -1.9839085, 34.2497196>,
    <0.0639013, -1.9739387, 34.2396408>,
    <0.0711933, -1.9785585, 34.2454279>,
    <-0.0006539, -1.9714979, 34.2353389>,
    <0.1387591, -1.9636846, 34.2321345>,
    <0.0709193, -1.9680388, 34.2328481>,
    <0.1993710, -1.9587194, 34.2328481>,
    <0.2247671, -1.9283080, 34.2365221>,
    <0.1680256, -1.9291229, 34.2291393>,
    <-0.0006617, -1.9513931, 34.2505667>,
    <0.1693014, -1.9430385, 34.2505227>,
    <0.1999790, -1.9289880, 34.2333423>,
    <0.0945373, -1.9402275, 34.2387176>,
    <0.0949975, -1.9481979, 34.2505227>,
    <0.2006346, -1.9350206, 34.2427845>,
    <0.1406059, -1.9394167, 34.2418824>,
    <0.2433785, -1.9352626, 34.2505227>,
    <0.2735532, -1.9202640, 34.2333423>,
    <0.2673013, -1.9265199, 34.2418824>,
    <0.2408933, -1.9156621, 34.2192172>,
    <0.2658563, -1.9163816, 34.2254131>,
    <0.1130032, -1.9575608, 34.2635082>,
    <-0.0014045, -1.9663438, 34.2695801>,
    <0.0630077, -1.9623775, 34.2662252>,
    <-0.0034213, -1.9735236, 34.2772285>,
    <0.1377740, -1.9582036, 34.2662252>,
    <0.0689301, -1.9677138, 34.2725930>,
    <0.1378274, -1.9514760, 34.2579678>,
    <0.1980631, -1.9466051, 34.2587527>,
    <-0.0007192, -1.9595117, 34.2614925>,
    <0.0704141, -1.9558618, 34.2587527>,
    <0.2238502, -1.9189808, 34.1698789>,
    <0.1684452, -1.9313742, 34.1848862>,
    <-0.0005048, -1.9396905, 34.1849198>,
    <0.1675071, -1.9209438, 34.1620860>,
    <0.1997236, -1.9246664, 34.1765488>,
    <0.0945872, -1.9365079, 34.1848862>,
    <0.0942499, -1.9304951, 34.1722289>,
    <0.1992418, -1.9201594, 34.1665078>,
    <0.1400394, -1.9291851, 34.1755900>,
    <0.2402538, -1.9090487, 34.1516897>,
    <0.2724661, -1.9114703, 34.1665078>,
    <0.2649878, -1.9088241, 34.1581668>,
    <0.2420771, -1.9236396, 34.1848862>,
    <0.2660472, -1.9163479, 34.1755900>,
    <0.1125544, -1.9435631, 34.1991181>,
    <-0.0005788, -1.9511498, 34.2059260>,
    <0.1373668, -1.9436839, 34.2021355>,
    <-0.0005973, -1.9566002, 34.2146338>,
    <0.0631397, -1.9478339, 34.2021355>,
    <0.0703162, -1.9517757, 34.2092829>,
    <-0.0005586, -1.9458871, 34.1969055>,
    <0.1370685, -1.9385088, 34.1929998>,
    <0.0700920, -1.9427344, 34.1938690>,
    <0.1969021, -1.9335284, 34.1938690>,
    <0.2219536, -1.9031879, 34.1894897>,
    <0.1660371, -1.9047735, 34.1809181>,
    <-0.0005552, -1.9244904, 34.2060335>,
    <0.1670689, -1.9162470, 34.2059966>,
    <0.1975296, -1.9041957, 34.1857817>,
    <0.0934188, -1.9147244, 34.1920745>,
    <0.0937898, -1.9213386, 34.2059966>,
    <0.1980596, -1.9091534, 34.1968260>,
    <0.1388491, -1.9135881, 34.1957715>,
    <0.2401239, -1.9085749, 34.2059966>,
    <0.2701494, -1.8955805, 34.1857817>,
    <0.2638445, -1.9008575, 34.1957715>,
    <0.2381182, -1.8925248, 34.1694828>,
    <0.2626791, -1.8925813, 34.1766071>,
    <0.1116575, -1.9291673, 34.2216509>,
    <-0.0006367, -1.9371288, 34.2291393>,
    <0.0626162, -1.9335922, 34.2249699>,
    <-0.0006571, -1.9431243, 34.2387176>,
    <0.1362959, -1.9294752, 34.2249699>,
    <0.0697507, -1.9379725, 34.2328318>,
    <0.1359677, -1.9237826, 34.2149211>,
    <0.1953473, -1.9188950, 34.2158771>,
    <-0.0006145, -1.9313399, 34.2192172>,
    <0.0695041, -1.9280270, 34.2158771>,
    <0.2218688, -1.9009429, 34.1211611>,
    <0.1668337, -1.9116146, 34.1379890>,
    <-0.0003926, -1.9198519, 34.1380150>,
    <0.1661461, -1.9037213, 34.1125260>,
    <0.1978884, -1.9058642, 34.1286034>,
    <0.0937316, -1.9166995, 34.1379890>,
    <0.0934856, -1.9121023, 34.1237934>,
    <0.1975353, -1.9024715, 34.1174128>,
    <0.1388039, -1.9104437, 34.1275355>,
    <0.2383798, -1.8930355, 34.1010718>,
    <0.2700757, -1.8938588, 34.1174128>,
    <0.2628010, -1.8921228, 34.1081947>,
    <0.2397119, -1.9039553, 34.1379890>,
    <0.2635739, -1.8977250, 34.1275355>,
    <0.1114232, -1.9221531, 34.1542153>,
    <-0.0004695, -1.9289327, 34.1620860>,
    <0.1359427, -1.9219481, 34.1576891>,
    <-0.0004913, -1.9333865, 34.1722289>,
    <0.0625371, -1.9260564, 34.1576891>,
    <0.0696109, -1.9291870, 34.1659804>,
    <-0.0004464, -1.9246965, 34.1516897>,
    <0.1357124, -1.9178074, 34.1472010>,
    <0.0694433, -1.9218988, 34.1481994>,
    <0.1949056, -1.9127836, 34.1481994>,
    <0.2204705, -1.8880708, 34.0680823>,
    <0.1656895, -1.8970517, 34.0861074>,
    <-0.0002686, -1.9052346, 34.0861253>,
    <0.1650663, -1.8911906, 34.0592183>,
    <0.1966146, -1.8923469, 34.0759583>,
    <0.0931443, -1.9021020, 34.0861074>,
    <0.0929970, -1.8990602, 34.0708032>,
    <0.1962810, -1.8897643, 34.0642124>,
    <0.1379676, -1.8970108, 34.0748134>,
    <0.2363845, -1.8795507, 34.0484530>,
    <0.2683419, -1.8812033, 34.0642124>,
    <0.2609024, -1.8792356, 34.0551646>,
    <0.2380120, -1.8894466, 34.0861074>,
    <0.2618451, -1.8843747, 34.0748134>,
    <0.1105989, -1.9057679, 34.1038334>,
    <-0.0003459, -1.9116509, 34.1125260>,
    <0.1348873, -1.9051900, 34.1076575>,
    <-0.0003703, -1.9149728, 34.1237934>,
    <0.0621118, -1.9092679, 34.1076575>,
    <0.0690988, -1.9114787, 34.1168389>,
    <-0.0003206, -1.9085698, 34.1010718>,
    <0.1347319, -1.9022096, 34.0961373>,
    <0.0689930, -1.9061650, 34.0972345>,
    <0.1934422, -1.8971155, 34.0972345>,
    <0.2197740, -1.8833462, 34.1359011>,
    <0.1645399, -1.8858287, 34.1264018>,
    <-0.0004319, -1.9026680, 34.1544411>,
    <0.1652963, -1.8945113, 34.1544124>,
    <0.1956524, -1.8847389, 34.1317777>,
    <0.0925780, -1.8944923, 34.1387967>,
    <0.0928487, -1.8995492, 34.1544124>,
    <0.1960409, -1.8884709, 34.1440880>,
    <0.1374901, -1.8929725, 34.1429132>,
    <0.2375221, -1.8869221, 34.1544124>,
    <0.2675199, -1.8762078, 34.1317777>,
    <0.2611239, -1.8803723, 34.1429132>,
    <0.2360568, -1.8749103, 34.1138015>,
    <0.2602736, -1.8742099, 34.1216372>,
    <0.1104131, -1.9056163, 34.1722608>,
    <-0.0005165, -1.9126901, 34.1809181>,
    <0.0619534, -1.9096369, 34.1760819>,
    <-0.0005404, -1.9175893, 34.1920745>,
    <0.1347294, -1.9055658, 34.1760819>,
    <0.0689749, -1.9131249, 34.1852017>,
    <0.1344760, -1.9010111, 34.1645454>,
    <0.1931512, -1.8960757, 34.1656437>,
    <-0.0004910, -1.9080302, 34.1694828>,
    <0.0687906, -1.9051078, 34.1656437>,
    <0.2212218, -1.8532248, 34.0264558>,
    <0.1637728, -1.8785158, 34.0364647>,
    <0.0005032, -1.8861441, 34.0361074>,
    <0.1815975, -1.8437773, 34.0228223>,
    <0.1949055, -1.8662913, 34.0303723>,
    <0.0937668, -1.8830562, 34.0364059>,
    <0.1044576, -1.8636860, 34.0277014>,
    <0.2053654, -1.8498211, 34.0246615>,
    <0.1443322, -1.8680039, 34.0296825>,
    <0.2576525, -1.8203062, 34.0186848>,
    <0.2632387, -1.8425942, 34.0246615>,
    <0.2623976, -1.8312984, 34.0213137>,
    <0.2347409, -1.8707880, 34.0364059>,
    <0.2563125, -1.8565005, 34.0296825>,
    <0.1097455, -1.8931082, 34.0506060>,
    <-0.0003084, -1.8990654, 34.0592183>,
    <0.1340050, -1.8929756, 34.0541438>,
    <-0.0002380, -1.9019184, 34.0708032>,
    <0.0617228, -1.8970224, 34.0541438>,
    <0.0687955, -1.8991888, 34.0633523>,
    <-0.0005712, -1.8949405, 34.0484530>,
    <0.1333446, -1.8881462, 34.0438443>,
    <0.0681384, -1.8921869, 34.0448606>,
    <0.1916459, -1.8832275, 34.0448606>,
    <0.1128834, -1.8390921, 34.0202873>,
    <0.0042158, -1.8497628, 34.0221676>,
    <0.1434045, -1.8417129, 34.0214475>,
    <0.0004282, -1.8657564, 34.0273376>,
    <0.0638162, -1.8446588, 34.0210838>,
    <0.0751467, -1.8553850, 34.0245173>,
    <0.1640111, -1.8158438, 34.0159774>,
    <0.0328984, -1.8334583, 34.0179745>,
    <0.1046480, -1.8210375, 34.0159774>,
    <0.1336218, -1.8302194, 34.0184943>,
    <0.0778828, -1.8330650, 34.0183546>,
    <0.2367392, -1.8094807, 34.0159774>,
    <0.1943900, -1.8260856, 34.0186456>,
    <0.2182417, -1.8692069, 34.0775018>,
    <0.1633748, -1.8721274, 34.0677166>,
    <-0.0002954, -1.8865889, 34.0973598>,
    <0.1640376, -1.8784922, 34.0973402>,
    <0.1942858, -1.8708062, 34.0732308>,
    <0.0920406, -1.8801460, 34.0805061>,
    <0.0922026, -1.8834920, 34.0973402>,
    <0.1946396, -1.8736019, 34.0861763>,
    <0.1365701, -1.8781963, 34.0849170>,
    <0.2356522, -1.8709624, 34.0973402>,
    <0.2656259, -1.8623318, 34.0732308>,
    <0.2592222, -1.8656870, 34.0849170>,
    <0.2339527, -1.8604068, 34.0557354>,
    <0.2582378, -1.8602143, 34.0632019>,
    <0.1095064, -1.8875924, 34.1168394>,
    <-0.0003805, -1.8936801, 34.1264018>,
    <0.0614856, -1.8911695, 34.1210460>,
    <-0.0004073, -1.8973341, 34.1387967>,
    <0.1335684, -1.8871318, 34.1210460>,
    <0.0684116, -1.8936457, 34.1311462>,
    <0.1333975, -1.8838534, 34.1083733>,
    <0.1915414, -1.8788407, 34.1095803>,
    <-0.0003527, -1.8902909, 34.1138015>,
    <0.0682952, -1.8878007, 34.1095803>,
    <0.2124051, -1.8376288, 34.0309239>,
    <0.1563858, -1.8325270, 34.0269467>,
    <-0.0011361, -1.8678356, 34.0420193>,
    <0.1614847, -1.8594993, 34.0422290>,
    <0.1880305, -1.8360470, 34.0289414>,
    <0.0887085, -1.8499126, 34.0327086>,
    <0.0903392, -1.8644367, 34.0422290>,
    <0.1905368, -1.8482893, 34.0352527>,
    <0.1330423, -1.8517527, 34.0346796>,
    <0.2324153, -1.8520724, 34.0422290>,
    <0.2580761, -1.8277781, 34.0289414>,
    <0.2540829, -1.8394750, 34.0346796>,
    <0.2205785, -1.8135842, 34.0223261>,
    <0.2478028, -1.8185706, 34.0248676>,
    <0.1086072, -1.8738657, 34.0581798>,
    <-0.0003287, -1.8799205, 34.0677166>,
    <0.0610745, -1.8778053, 34.0621232>,
    <-0.0002618, -1.8829743, 34.0805061>,
    <0.1326228, -1.8738005, 34.0621232>,
    <0.0680780, -1.8801268, 34.0723106>,
    <0.1319602, -1.8688312, 34.0506039>,
    <0.1896652, -1.8639816, 34.0517365>,
    <-0.0005864, -1.8756370, 34.0557354>,
    <0.0674224, -1.8728481, 34.0517365>,
    <0.0987176, -1.8269601, 34.0235181>,
    <-0.0044517, -1.8399084, 34.0270017>,
    <0.0547230, -1.8329476, 34.0249264>,
    <-0.0019244, -1.8526239, 34.0327086>,
    <0.1250324, -1.8291697, 34.0248897>,
    <0.0646447, -1.8428167, 34.0290881>,
    <0.1151538, -1.8185819, 34.0210008>,
    <0.1737185, -1.8145510, 34.0211848>,
    <-0.0109388, -1.8277952, 34.0225462>,
    <0.0528154, -1.8227881, 34.0213315>,
    <0.1940339, 1.8140225, 34.0227124>,
    <0.1129875, 1.8241132, 34.0241543>,
    <0.2543212, 1.8132038, 34.0246336>,
    <0.2050927, 1.8327214, 34.0309519>,
    <0.1565873, 1.8178932, 34.0230769>,
    <0.2364432, 1.8226257, 34.0279170>,
    <0.0011677, 1.8111481, 34.0186526>,
    <0.1692174, 1.8102662, 34.0206518>,
    <0.0899558, 1.8123178, 34.0197890>,
    <0.2477992, 1.8043069, 34.0213315>,
    <0.2183532, 1.8642070, 34.0581798>,
    <0.1641638, 1.8720342, 34.0677166>,
    <0.2658869, 1.8598563, 34.0621232>,
    <0.2358416, 1.8675650, 34.0805061>,
    <0.1947302, 1.8683365, 34.0621232>,
    <0.2594369, 1.8633851, 34.0723106>,
    <-0.0009128, 1.8663222, 34.0417158>,
    <0.1622776, 1.8586099, 34.0420827>,
    <0.0925180, 1.8726843, 34.0557354>,
    <0.0922755, 1.8629881, 34.0419363>,
    <0.1943770, 1.8632419, 34.0506039>,
    <0.1367176, 1.8684929, 34.0517365>,
    <0.2297359, 1.8508960, 34.0419363>,
    <0.2586428, 1.8559974, 34.0517365>,
    <0.0942967, 1.8411672, 34.0293375>,
    <0.0998288, 1.8345724, 34.0268358>,
    <0.1278843, 1.8511337, 34.0346672>,
    <0.1711975, 1.8436397, 34.0335085>,
    <-0.0073087, 1.8279828, 34.0240730>,
    <-0.0016445, 1.8448296, 34.0307895>,
    <0.0524318, 1.8365784, 34.0268358>,
    <0.0682800, 1.8509559, 34.0335085>,
    <-0.0441158, 1.8109125, 34.0184901>,
    <0.0324311, 1.8240377, 34.0223007>,
    <0.2199342, 1.8779313, 34.1168394>,
    <0.1654306, 1.8857508, 34.1264018>,
    <0.2678466, 1.8731152, 34.1210460>,
    <0.2378036, 1.8817867, 34.1387967>,
    <0.1961578, 1.8816560, 34.1210460>,
    <0.2614559, 1.8767565, 34.1311462>,
    <0.0002954, 1.8865889, 34.0973598>,
    <0.1646512, 1.8784385, 34.0973402>,
    <0.0931042, 1.8874171, 34.1138015>,
    <0.0928171, 1.8834589, 34.0973402>,
    <0.1957569, 1.8783977, 34.1083733>,
    <0.1376258, 1.8835577, 34.1095803>,
    <0.2362631, 1.8708883, 34.0973402>,
    <0.2605555, 1.8709801, 34.1095803>,
    <0.1096497, 1.8787015, 34.0775018>,
    <0.1335087, 1.8761102, 34.0732308>,
    <0.1336649, 1.8789365, 34.0861763>,
    <0.1916500, 1.8733774, 34.0849170>,
    <0.0002956, 1.8798964, 34.0677166>,
    <0.0002618, 1.8829743, 34.0805061>,
    <0.0617809, 1.8801527, 34.0732308>,
    <0.0686891, 1.8823565, 34.0849170>,
    <0.0004538, 1.8755405, 34.0557354>,
    <0.0686315, 1.8767497, 34.0632019>,
    <0.2050952, 1.8292220, 34.0203714>,
    <0.1251078, 1.8441830, 34.0221755>,
    <0.1671219, 1.8363967, 34.0211153>,
    <0.2099073, 1.8513811, 34.0272515>,
    <0.2602573, 1.8251089, 34.0210482>,
    <0.2400626, 1.8381014, 34.0241726>,
    <0.1898631, 1.8251224, 34.0191144>,
    <0.2653917, 1.8141133, 34.0187717>,
    <0.0460834, 1.8339275, 34.0180922>,
    <0.1176588, 1.8312995, 34.0188254>,
    <0.2205736, 1.8833548, 34.0506060>,
    <0.1658083, 1.8911016, 34.0592183>,
    <0.1966987, 1.8874604, 34.0541438>,
    <0.2381842, 1.8863580, 34.0708032>,
    <0.2685855, 1.8788940, 34.0541438>,
    <0.2620403, 1.8822821, 34.0633523>,
    <0.1640731, 1.8780049, 34.0364283>,
    <0.2325912, 1.8702363, 34.0363331>,
    <0.1963677, 1.8825038, 34.0438443>,
    <0.2612958, 1.8751668, 34.0448606>,
    <-0.0009340, 1.8858307, 34.0361074>,
    <0.0932244, 1.8824948, 34.0363331>,
    <0.0934474, 1.8919597, 34.0484530>,
    <0.1381091, 1.8877904, 34.0448606>,
    <0.0983860, 1.8611654, 34.0260678>,
    <0.1296947, 1.8707009, 34.0302268>,
    <0.1078468, 1.8547826, 34.0241522>,
    <0.1748913, 1.8632383, 34.0293915>,
    <-0.0010905, 1.8488288, 34.0221676>,
    <-0.0046362, 1.8342684, 34.0179745>,
    <0.0575763, 1.8570171, 34.0241522>,
    <0.0511082, 1.8454787, 34.0207317>,
    <-0.0016536, 1.8648649, 34.0273376>,
    <0.0689976, 1.8707965, 34.0293915>,
    <0.2221711, 1.8958387, 34.1722608>,
    <0.1672459, 1.9046678, 34.1809181>,
    <0.2705928, 1.8913833, 34.1760819>,
    <0.2404889, 1.9018574, 34.1920745>,
    <0.1982155, 1.9000115, 34.1760819>,
    <0.2642837, 1.8960376, 34.1852017>,
    <0.0004319, 1.9026680, 34.1544411>,
    <0.1661933, 1.8944329, 34.1544124>,
    <0.0941328, 1.9051219, 34.1694828>,
    <0.0937470, 1.8995008, 34.1544124>,
    <0.1976741, 1.8954820, 34.1645454>,
    <0.1390333, 1.9008104, 34.1656437>,
    <0.2384152, 1.8868138, 34.1544124>,
    <0.2630730, 1.8881103, 34.1656437>,
    <0.1106046, 1.8928973, 34.1359011>,
    <0.1346014, 1.8900802, 34.1317777>,
    <0.1348669, 1.8938230, 34.1440880>,
    <0.1933100, 1.8880889, 34.1429132>,
    <0.0003805, 1.8936801, 34.1264018>,
    <0.0004073, 1.8973341, 34.1387967>,
    <0.0623444, 1.8941583, 34.1317777>,
    <0.0693664, 1.8971489, 34.1429132>,
    <0.0003527, 1.8902909, 34.1138015>,
    <0.0691336, 1.8909325, 34.1216372>,
    <0.2220145, 1.8960203, 34.1038334>,
    <0.1669558, 1.9036504, 34.1125260>,
    <0.1979947, 1.8996688, 34.1076575>,
    <0.2399678, 1.8992868, 34.1237934>,
    <0.2703727, 1.8910474, 34.1076575>,
    <0.2638758, 1.8944379, 34.1168389>,
    <0.1662473, 1.8970029, 34.0861074>,
    <0.2385673, 1.8893792, 34.0861074>,
    <0.1976302, 1.8967067, 34.0961373>,
    <0.2630572, 1.8891866, 34.0972345>,
    <0.0002686, 1.9052346, 34.0861253>,
    <0.0937029, 1.9020720, 34.0861074>,
    <0.0939639, 1.9056703, 34.1010718>,
    <0.1389273, 1.9018849, 34.0972345>,
    <0.1107305, 1.8976659, 34.0680823>,
    <0.1349750, 1.8977397, 34.0759583>,
    <0.1348359, 1.8951269, 34.0642124>,
    <0.1935409, 1.8921488, 34.0748134>,
    <0.0002752, 1.8990412, 34.0592183>,
    <0.0004386, 1.8948441, 34.0484530>,
    <0.0623832, 1.8992092, 34.0642124>,
    <0.0693104, 1.8959449, 34.0551646>,
    <0.0002380, 1.9019184, 34.0708032>,
    <0.0693511, 1.9012158, 34.0748134>,
    <0.2240480, 1.9122998, 34.1542153>,
    <0.1686061, 1.9208476, 34.1620860>,
    <0.1998654, 1.9163556, 34.1576891>,
    <0.2424089, 1.9175329, 34.1722289>,
    <0.2728692, 1.9076547, 34.1576891>,
    <0.2664465, 1.9119661, 34.1659804>,
    <0.1676492, 1.9115432, 34.1379890>,
    <0.2405237, 1.9038568, 34.1379890>,
    <0.1993732, 1.9122379, 34.1472010>,
    <0.2653459, 1.9047596, 34.1481994>,
    <0.0003926, 1.9198519, 34.1380150>,
    <0.0945483, 1.9166555, 34.1379890>,
    <0.0948990, 1.9217656, 34.1516897>,
    <0.1402069, 1.9175691, 34.1481994>,
    <0.1115972, 1.9105904, 34.1211611>,
    <0.1360678, 1.9112728, 34.1286034>,
    <0.1358264, 1.9078703, 34.1174128>,
    <0.1950499, 1.9055228, 34.1275355>,
    <0.0003459, 1.9116509, 34.1125260>,
    <0.0003206, 1.9085698, 34.1010718>,
    <0.0628925, 1.9119850, 34.1174128>,
    <0.0697552, 1.9090121, 34.1081947>,
    <0.0003703, 1.9149728, 34.1237934>,
    <0.0699668, 1.9146634, 34.1275355>,
    <0.2250352, 1.9192480, 34.2216509>,
    <0.1695158, 1.9289925, 34.2291393>,
    <0.2740998, 1.9150897, 34.2249699>,
    <0.2438159, 1.9271673, 34.2387176>,
    <0.2008246, 1.9238297, 34.2249699>,
    <0.2678344, 1.9206424, 34.2328318>,
    <0.0005552, 1.9244904, 34.2060335>,
    <0.1682221, 1.9161461, 34.2059966>,
    <0.0954176, 1.9283896, 34.2192172>,
    <0.0949447, 1.9212764, 34.2059966>,
    <0.2001593, 1.9181666, 34.2149211>,
    <0.1408331, 1.9236644, 34.2158771>,
    <0.2412720, 1.9084355, 34.2059966>,
    <0.2663502, 1.9108052, 34.2158771>,
    <0.1119035, 1.9128161, 34.1894897>,
    <0.1361314, 1.9095674, 34.1857817>,
    <0.1364703, 1.9145417, 34.1968260>,
    <0.1955514, 1.9086273, 34.1957715>,
    <0.0005165, 1.9126901, 34.1809181>,
    <0.0005404, 1.9175893, 34.1920745>,
    <0.0631189, 1.9136933, 34.1857817>,
    <0.0702444, 1.9177953, 34.1957715>,
    <0.0004910, 1.9080302, 34.1694828>,
    <0.0699548, 1.9094425, 34.1766071>,
    <0.2266517, 1.9335809, 34.1991181>,
    <0.1706696, 1.9429610, 34.2059260>,
    <0.2022373, 1.9380084, 34.2021355>,
    <0.2454335, 1.9405419, 34.2146338>,
    <0.2760574, 1.9292060, 34.2021355>,
    <0.2696744, 1.9343342, 34.2092829>,
    <0.1694935, 1.9312824, 34.1848862>,
    <0.2431209, 1.9235129, 34.1848862>,
    <0.2016324, 1.9328602, 34.1929998>,
    <0.2683252, 1.9253913, 34.1938690>,
    <0.0005048, 1.9396905, 34.1849198>,
    <0.0956371, 1.9364514, 34.1848862>,
    <0.0960670, 1.9429179, 34.1969055>,
    <0.1418430, 1.9383454, 34.1938690>,
    <0.1127781, 1.9286984, 34.1698789>,
    <0.1375254, 1.9301080, 34.1765488>,
    <0.1372173, 1.9255858, 34.1665078>,
    <0.1970877, 1.9241941, 34.1755900>,
    <0.0004695, 1.9289327, 34.1620860>,
    <0.0004464, 1.9246965, 34.1516897>,
    <0.0635966, 1.9297440, 34.1665078>,
    <0.0705018, 1.9258394, 34.1581668>,
    <0.0004913, 1.9333865, 34.1722289>,
    <0.0707650, 1.9334328, 34.1755900>,
    <0.2286456, 1.9474520, 34.2635082>,
    <0.1728649, 1.9579921, 34.2695801>,
    <0.2787245, 1.9435241, 34.2662252>,
    <0.2504577, 1.9569719, 34.2772285>,
    <0.2043692, 1.9523967, 34.2662252>,
    <0.2738535, 1.9498630, 34.2725930>,
    <0.0006617, 1.9513931, 34.2505667>,
    <0.1706757, 1.9429182, 34.2505227>,
    <0.0969194, 1.9565130, 34.2614925>,
    <0.0963738, 1.9481238, 34.2505227>,
    <0.2031368, 1.9457622, 34.2579678>,
    <0.1429704, 1.9514251, 34.2587527>,
    <0.2447468, 1.9350965, 34.2505227>,
    <0.2702875, 1.9383752, 34.2587527>,
    <0.1134948, 1.9380431, 34.2365221>,
    <0.1380244, 1.9344083, 34.2333423>,
    <0.1384264, 1.9404632, 34.2427845>,
    <0.1983064, 1.9343685, 34.2418824>,
    <0.0006367, 1.9371288, 34.2291393>,
    <0.0006571, 1.9431243, 34.2387176>,
    <0.0640530, 1.9385929, 34.2333423>,
    <0.0712963, 1.9436681, 34.2418824>,
    <0.0006145, 1.9313399, 34.2192172>,
    <0.0709589, 1.9334329, 34.2254131>,
    <0.2297467, 1.9592170, 34.2371711>,
    <0.1730838, 1.9693187, 34.2427102>,
    <0.2050384, 1.9639695, 34.2396408>,
    <0.2489496, 1.9676146, 34.2497196>,
    <0.2798404, 1.9550465, 34.2396408>,
    <0.2734613, 1.9608624, 34.2454279>,
    <0.1717241, 1.9556208, 34.2253660>,
    <0.2462798, 1.9477503, 34.2253660>,
    <0.2043392, 1.9579471, 34.2321345>,
    <0.2719045, 1.9504549, 34.2328481>,
    <0.0006015, 1.9641476, 34.2254060>,
    <0.0969363, 1.9608582, 34.2253660>,
    <0.0974323, 1.9684847, 34.2353389>,
    <0.1437860, 1.9635825, 34.2328481>,
    <0.1142247, 1.9516320, 34.2126378>,
    <0.1393036, 1.9536730, 34.2183311>,
    <0.1389382, 1.9481685, 34.2097470>,
    <0.1995921, 1.9475952, 34.2175110>,
    <0.0005788, 1.9511498, 34.2059260>,
    <0.0005586, 1.9458871, 34.1969055>,
    <0.0644458, 1.9523800, 34.2097470>,
    <0.0714145, 1.9476488, 34.2025384>,
    <0.0005973, 1.9566002, 34.2146338>,
    <0.0717213, 1.9569536, 34.2175110>,
    <0.1999462, 1.9905014, 34.2989756>,
    <0.2242854, 1.9861608, 34.2967794>,
    <0.2772091, 1.9912815, 34.3035582>,
    <0.2084941, 1.9888572, 34.2980080>,
    <0.3006417, 1.9873747, 34.3007507>,
    <0.3144799, 1.9902437, 34.3035582>,
    <0.2309666, 1.9909054, 34.3008727>,
    <0.2646697, 1.9893501, 34.3007914>,
    <0.1960875, 1.9957422, 34.3035582>,
    <0.1205959, 1.9937272, 34.2975521>,
    <0.2380583, 1.9930007, 34.3035582>,
    <0.1592555, 1.9950894, 34.3007100>,
    <0.1603862, 1.9916703, 34.2980080>,
    <0.1956148, 1.9927034, 34.3007914>,
    <0.0120052, 1.9839741, 34.2867877>,
    <0.0782809, 1.9909460, 34.2937748>,
    <0.1389968, 1.9856474, 34.2926777>,
    <0.1395875, 1.9891654, 34.2951914>,
    <0.2412462, 1.9789628, 34.2933120>,
    <0.2812135, 1.9771455, 34.2949171>,
    <0.2325849, 1.9825795, 34.2949171>,
    <0.2895378, 1.9826856, 34.2980246>,
    <0.1755820, 1.9736058, 34.2854038>,
    <0.1049515, 1.9789849, 34.2856693>,
    <0.2105535, 1.9767531, 34.2900253>,
    <0.1643919, 1.9815750, 34.2908029>,
    <0.2503945, 1.9661135, 34.2856693>,
    <0.2722624, 1.9709865, 34.2908029>,
    <0.1157186, 1.9677548, 34.2753407>,
    <0.1406800, 1.9638235, 34.2729301>,
    <0.1415499, 1.9706710, 34.2800513>,
    <0.2033200, 1.9644311, 34.2795037>,
    <0.0014076, 1.9663500, 34.2695801>,
    <0.0034337, 1.9735483, 34.2772285>,
    <0.0655600, 1.9681358, 34.2729301>,
    <0.0742565, 1.9741222, 34.2795037>,
    <0.0007192, 1.9595117, 34.2614925>,
    <0.0721152, 1.9621746, 34.2665723>,
    <0.2330391, 1.9885377, 34.2672347>,
    <0.1747836, 1.9994842, 34.2713545>,
    <0.2077344, 1.9936942, 34.2690979>,
    <0.2488842, 1.9993864, 34.2765463>,
    <0.2836539, 1.9846353, 34.2690979>,
    <0.2758953, 1.9917220, 34.2734379>,
    <0.1742733, 1.9838188, 34.2582019>,
    <0.2499045, 1.9758323, 34.2582019>,
    <0.2074114, 1.9867364, 34.2634197>,
    <0.2759752, 1.9791889, 34.2639559>,
    <0.0006800, 1.9924800, 34.2582471>,
    <0.0984063, 1.9891343, 34.2582019>,
    <0.0989534, 1.9976891, 34.2658251>,
    <0.1459768, 1.9925135, 34.2639559>,
    <0.1158931, 1.9786947, 34.2481381>,
    <0.1413484, 1.9812516, 34.2526827>,
    <0.1409367, 1.9749322, 34.2458152>,
    <0.2024873, 1.9750153, 34.2520259>,
    <0.0006705, 1.9776270, 34.2427102>,
    <0.0006539, 1.9714979, 34.2353389>,
    <0.0654144, 1.9792052, 34.2458152>,
    <0.0724657, 1.9737777, 34.2399571>,
    <0.0006853, 1.9839085, 34.2497196>,
    <0.0728068, 1.9845111, 34.2520259>,
    <0.0686122, 1.9996292, 34.2989756>,
    <0.1018057, 2.0049733, 34.3035582>,
    <0.0892105, 1.9968047, 34.2980080>,
    <0.1503566, 1.9998466, 34.3035582>,
    <0.0830520, 2.0020300, 34.3008727>,
    <0.1225300, 1.9984084, 34.3007914>,
    <-0.0143111, 1.9987301, 34.2967794>,
    <0.0513748, 2.0107814, 34.3035582>,
    <-0.0073360, 2.0080047, 34.3007507>,
    <0.0335826, 1.9999818, 34.2980080>,
    <0.0384349, 2.0053239, 34.3007914>,
    <-0.0097869, 1.9919043, 34.2926777>,
    <0.0449053, 1.9948703, 34.2951914>,
    <0.0928547, 2.0364018, 34.2894179>,
    <0.0422936, 2.0389125, 34.2886794>,
    <0.0634161, 2.0444516, 34.2918022>,
    <0.1236027, 2.0391859, 34.2918022>,
    <0.0665426, 2.0374686, 34.2889155>,
    <0.0536735, 2.0419491, 34.2903196>,
    <0.0910601, 2.0420330, 34.2918022>,
    <0.1041662, 2.0377232, 34.2904043>,
    <0.0764346, 2.0400536, 34.2903620>,
    <0.1345056, 2.0300112, 34.2882666>,
    <0.1596545, 2.0360316, 34.2918022>,
    <0.1742894, 2.0314443, 34.2903408>,
    <0.1081400, 2.0338292, 34.2889155>,
    <0.1371502, 2.0347416, 34.2903620>,
    <-0.0100725, 2.0270943, 34.2830970>,
    <0.0817784, 2.0290845, 34.2861106>,
    <0.0276393, 2.0348077, 34.2867239>,
    <0.0661177, 2.0336724, 34.2874565>,
    <0.1803496, 2.0222662, 34.2863581>,
    <0.1602292, 2.0257182, 34.2872643>,
    <0.2080737, 2.0216111, 34.2872643>,
    <0.1897858, 2.0268775, 34.2889218>,
    <0.1567247, 2.0156917, 34.2817251>,
    <0.2324040, 2.0091382, 34.2819691>,
    <0.1721878, 2.0192514, 34.2845089>,
    <0.2288865, 2.0149257, 34.2850030>,
    <0.0841741, 2.0211590, 34.2819691>,
    <0.1201435, 2.0241243, 34.2850030>,
    <0.1139293, 2.0092231, 34.2751874>,
    <0.1350401, 2.0123642, 34.2783022>,
    <0.1414323, 2.0052998, 34.2735942>,
    <0.1988059, 2.0065657, 34.2779937>,
    <-0.0003031, 2.0078018, 34.2713545>,
    <0.0007292, 2.0007505, 34.2658251>,
    <0.0647175, 2.0095589, 34.2735942>,
    <0.0736234, 2.0034321, 34.2692880>,
    <-0.0034275, 2.0154491, 34.2765463>,
    <0.0669666, 2.0158859, 34.2779937>,
    <0.0167983, 2.0424728, 34.2894179>,
    <0.0254201, 2.0477759, 34.2918022>,
    <0.0204440, 2.0448294, 34.2904043>,
    <0.0420601, 2.0463200, 34.2918022>,
    <0.0257867, 2.0408156, 34.2889155>,
    <0.0356013, 2.0436261, 34.2903620>,
    <-0.0142332, 2.0405117, 34.2886794>,
    <-0.0154115, 2.0355405, 34.2867239>,
    <0.0043880, 2.0415943, 34.2889155>,
    <0.0092606, 2.0377720, 34.2874565>,
    <-0.0111113, 2.0448470, 34.2903196>,
    <0.0119241, 2.0489566, 34.2918022>,
    <0.0064279, 2.0453037, 34.2903620>,
    <-0.0631748, 2.0388597, 34.2894179>,
    <-0.1141161, 2.0318970, 34.2882666>,
    <-0.1581546, 2.0361631, 34.2918022>,
    <-0.0798070, 2.0430176, 34.2918022>,
    <-0.0827645, 2.0360630, 34.2889155>,
    <-0.1422163, 2.0342506, 34.2903408>,
    <-0.1192544, 2.0395664, 34.2918022>,
    <-0.0685335, 2.0407756, 34.2904043>,
    <-0.1039806, 2.0376437, 34.2903620>,
    <-0.0399947, 2.0465008, 34.2918022>,
    <-0.0384658, 2.0396126, 34.2889155>,
    <-0.0368377, 2.0432571, 34.2903620>,
    <-0.0763595, 2.0299663, 34.2861106>,
    <-0.0496640, 2.0351664, 34.2874565>,
    <-0.0728719, -2.0375162, 34.2894050>,
    <-0.0968630, -2.0415254, 34.2918006>,
    <-0.1846307, -2.0338468, 34.2917990>,
    <-0.1272689, -2.0304182, 34.2882253>,
    <-0.0820940, -2.0394357, 34.2904030>,
    <-0.1424523, -2.0375369, 34.2917998>,
    <-0.1647493, -2.0322792, 34.2903384>,
    <-0.0951798, -2.0346301, 34.2888876>,
    <-0.1230839, -2.0359724, 34.2903601>,
    <-0.0747151, -2.0287976, 34.2859504>,
    <-0.0404998, -2.0383206, 34.2888882>,
    <-0.0502042, -2.0337325, 34.2873495>,
    <-0.0490000, -2.0457129, 34.2918014>,
    <-0.0419590, -2.0421951, 34.2903612>,
    <-0.0685961, -2.0007323, 34.2989756>,
    <-0.1205183, -1.9937338, 34.2975521>,
    <-0.1959959, -1.9957500, 34.3035582>,
    <-0.1017946, -2.0066268, 34.3035582>,
    <-0.0891764, -1.9974273, 34.2980080>,
    <-0.1591700, -1.9950967, 34.3007100>,
    <-0.1503190, -2.0006761, 34.3035582>,
    <-0.0830412, -2.0033736, 34.3008727>,
    <-0.1224926, -1.9991001, 34.3007914>,
    <-0.0513719, -2.0132605, 34.3035582>,
    <-0.0335751, -2.0013251, 34.2980080>,
    <-0.0384326, -2.0072521, 34.3007914>,
    <-0.0782151, -1.9909516, 34.2937748>,
    <-0.0448809, -1.9955609, 34.2951914>,
    <-0.1141921, 1.8179449, 34.0218046>,
    <-0.1814388, 1.8232205, 34.0252457>,
    <-0.0659445, 1.8231642, 34.0227519>,
    <-0.1045077, 1.8433764, 34.0314410>,
    <-0.1438627, 1.8209106, 34.0234034>,
    <-0.0759187, 1.8344775, 34.0272671>,
    <-0.1667717, 1.7944305, 34.0159774>,
    <-0.2573878, 1.7994273, 34.0197144>,
    <-0.2372259, 1.7882664, 34.0159774>,
    <-0.1354527, 1.8090318, 34.0194217>,
    <-0.1947968, 1.8051395, 34.0196603>,
    <-0.1125584, 1.7991737, 34.0159774>,
    <-0.0825952, 1.8113053, 34.0191391>,
    <-0.1086857, 1.8738086, 34.0581798>,
    <-0.1634079, 1.8721033, 34.0677166>,
    <-0.0611161, 1.8777751, 34.0621232>,
    <-0.0920406, 1.8801460, 34.0805061>,
    <-0.1326644, 1.8737702, 34.0621232>,
    <-0.0680780, 1.8801268, 34.0723106>,
    <-0.3250603, 1.8381516, 34.0418026>,
    <-0.1624851, 1.8588619, 34.0421478>,
    <-0.2340852, 1.8603103, 34.0557354>,
    <-0.2327330, 1.8512045, 34.0420666>,
    <-0.1321370, 1.8687026, 34.0506039>,
    <-0.1898316, 1.8638606, 34.0517365>,
    <-0.0932119, 1.8633451, 34.0420666>,
    <-0.0675888, 1.8727270, 34.0517365>,
    <-0.2201050, 1.8330734, 34.0300324>,
    <-0.2046297, 1.8295093, 34.0277479>,
    <-0.1936545, 1.8463828, 34.0349278>,
    <-0.1437014, 1.8479918, 34.0340297>,
    <-0.3189939, 1.8049762, 34.0252783>,
    <-0.3224822, 1.8193753, 34.0315713>,
    <-0.2619002, 1.8223581, 34.0277479>,
    <-0.2545220, 1.8366083, 34.0340297>,
    <-0.3186176, 1.7899169, 34.0197144>,
    <-0.2615695, 1.8107400, 34.0233431>,
    <-0.2350388, -1.8121759, 34.0227124>,
    <-0.3266395, -1.8007002, 34.0241543>,
    <-0.3253375, -1.8386300, 34.0418241>,
    <-0.1661866, -1.8316533, 34.0269285>,
    <-0.2713668, -1.8072672, 34.0230769>,
    <-0.3225944, -1.8182240, 34.0309519>,
    <-0.2336599, -1.8363007, 34.0324158>,
    <-0.2000489, -1.8218156, 34.0246336>,
    <-0.2556311, -1.8221607, 34.0279170>,
    <-0.1060056, -1.8242114, 34.0225462>,
    <-0.2370670, -1.8063824, 34.0206518>,
    <-0.1671179, -1.8156058, 34.0213315>,
    <-0.3575907, -1.7792935, 34.0186526>,
    <-0.2958323, -1.7945114, 34.0197890>,
    <-0.1100955, -1.8467049, 34.0309402>,
    <-0.1638447, -1.8593283, 34.0422290>,
    <-0.1341057, -1.8409444, 34.0289781>,
    <-0.2347666, -1.8518364, 34.0422290>,
    <-0.1332688, -1.8533642, 34.0352527>,
    <-0.1904882, -1.8467959, 34.0346796>,
    <-0.0927022, -1.8643313, 34.0422290>,
    <-0.0636889, -1.8449645, 34.0289781>,
    <-0.0691549, -1.8557233, 34.0346796>,
    <-0.0737509, -1.8342291, 34.0250143>,
    <-0.1095064, 1.8875924, 34.1168394>,
    <-0.1645399, 1.8858287, 34.1264018>,
    <-0.0614856, 1.8911695, 34.1210460>,
    <-0.0925780, 1.8944923, 34.1387967>,
    <-0.1335684, 1.8871318, 34.1210460>,
    <-0.0684116, 1.8936457, 34.1311462>,
    <-0.3273118, 1.8579787, 34.0973598>,
    <-0.1640376, 1.8784922, 34.0973402>,
    <-0.2360568, 1.8749103, 34.1138015>,
    <-0.2356522, 1.8709624, 34.0973402>,
    <-0.1333975, 1.8838534, 34.1083733>,
    <-0.1915414, 1.8788407, 34.1095803>,
    <-0.0922026, 1.8834920, 34.0973402>,
    <-0.0682952, 1.8878007, 34.1095803>,
    <-0.2182498, 1.8692010, 34.0775018>,
    <-0.1943040, 1.8707929, 34.0732308>,
    <-0.1946396, 1.8736019, 34.0861763>,
    <-0.1365701, 1.8781963, 34.0849170>,
    <-0.3261519, 1.8513906, 34.0677166>,
    <-0.3267172, 1.8544131, 34.0805061>,
    <-0.2656441, 1.8623186, 34.0732308>,
    <-0.2592222, 1.8656870, 34.0849170>,
    <-0.3252468, 1.8471364, 34.0557354>,
    <-0.2583106, 1.8601613, 34.0632019>,
    <-0.2184318, -1.8642642, 34.0581798>,
    <-0.3267667, -1.8513063, 34.0677166>,
    <-0.3278937, -1.8578761, 34.0973598>,
    <-0.1641970, -1.8720584, 34.0677166>,
    <-0.2659285, -1.8598865, 34.0621232>,
    <-0.3272329, -1.8543222, 34.0805061>,
    <-0.2358416, -1.8675650, 34.0805061>,
    <-0.1947718, -1.8683667, 34.0621232>,
    <-0.2594369, -1.8633851, 34.0723106>,
    <-0.0926506, -1.8727807, 34.0557354>,
    <-0.1945538, -1.8633705, 34.0506039>,
    <-0.1368840, -1.8686139, 34.0517365>,
    <-0.3262709, -1.8470523, 34.0557354>,
    <-0.2588092, -1.8561185, 34.0517365>,
    <-0.1096578, -1.8787074, 34.0775018>,
    <-0.1646512, -1.8784385, 34.0973402>,
    <-0.1335269, -1.8761235, 34.0732308>,
    <-0.2362631, -1.8708883, 34.0973402>,
    <-0.1336649, -1.8789365, 34.0861763>,
    <-0.1916500, -1.8733774, 34.0849170>,
    <-0.0928171, -1.8834589, 34.0973402>,
    <-0.0617991, -1.8801659, 34.0732308>,
    <-0.0686891, -1.8823565, 34.0849170>,
    <-0.0687042, -1.8768027, 34.0632019>,
    <-0.1135664, 1.8376448, 34.0202873>,
    <-0.1833539, 1.8424995, 34.0228223>,
    <-0.1453792, 1.8402764, 34.0214475>,
    <-0.1056107, 1.8628471, 34.0277014>,
    <-0.0625219, 1.8434619, 34.0210838>,
    <-0.0767124, 1.8542460, 34.0245173>,
    <-0.1603234, 1.8142497, 34.0159774>,
    <-0.0809128, 1.8211974, 34.0159774>,
    <-0.1327751, 1.8286969, 34.0184943>,
    <-0.0670401, 1.8323993, 34.0183546>,
    <-0.2397341, 1.8073020, 34.0159774>,
    <-0.2601093, 1.8185189, 34.0186848>,
    <-0.1968545, 1.8242927, 34.0186456>,
    <-0.1098241, 1.8930510, 34.0506060>,
    <-0.1650994, 1.8911665, 34.0592183>,
    <-0.1340466, 1.8929453, 34.0541438>,
    <-0.0929970, 1.8990602, 34.0708032>,
    <-0.0617644, 1.8969922, 34.0541438>,
    <-0.0687955, 1.8991888, 34.0633523>,
    <-0.1641901, 1.8782123, 34.0364647>,
    <-0.0941958, 1.8827441, 34.0364059>,
    <-0.1335214, 1.8880176, 34.0438443>,
    <-0.0683048, 1.8920659, 34.0448606>,
    <-0.3284583, 1.8572907, 34.0361559>,
    <-0.2351698, 1.8704759, 34.0364059>,
    <-0.2365171, 1.8794542, 34.0484530>,
    <-0.1918123, 1.8831065, 34.0448606>,
    <-0.2224234, 1.8523507, 34.0264558>,
    <-0.1956906, 1.8657202, 34.0303723>,
    <-0.2067875, 1.8487866, 34.0246615>,
    <-0.1452161, 1.8673609, 34.0296825>,
    <-0.3223602, 1.8240344, 34.0228405>,
    <-0.3219879, 1.8089075, 34.0186848>,
    <-0.2646607, 1.8415597, 34.0246615>,
    <-0.2643317, 1.8298913, 34.0213137>,
    <-0.3258741, 1.8384827, 34.0277741>,
    <-0.2571964, 1.8558574, 34.0296825>,
    <-0.2058546, -1.8306321, 34.0203714>,
    <-0.1219809, -1.8451159, 34.0221755>,
    <-0.3259399, -1.8574330, 34.0360499>,
    <-0.3263161, -1.8203022, 34.0220547>,
    <-0.1658213, -1.8375889, 34.0211153>,
    <-0.2111498, -1.8522850, 34.0272515>,
    <-0.3218449, -1.8370049, 34.0271844>,
    <-0.2625209, -1.8265470, 34.0210482>,
    <-0.2416968, -1.8392902, 34.0241726>,
    <-0.3472083, -1.8006886, 34.0179808>,
    <-0.1891028, -1.8264990, 34.0191144>,
    <-0.2686695, -1.8156634, 34.0187717>,
    <-0.0177978, -1.8331005, 34.0180922>,
    <-0.1067225, -1.8318971, 34.0188254>,
    <-0.0981798, -1.8619658, 34.0260678>,
    <-0.1644975, -1.8783137, 34.0364283>,
    <-0.1305088, -1.8712931, 34.0302268>,
    <-0.2330346, -1.8705589, 34.0363331>,
    <-0.1060288, -1.8555984, 34.0241522>,
    <-0.1758330, -1.8639234, 34.0293915>,
    <-0.0557583, -1.8578330, 34.0241522>,
    <-0.0397930, -1.8458007, 34.0207317>,
    <-0.0936678, -1.8828174, 34.0363331>,
    <-0.0699393, -1.8714816, 34.0293915>,
    <-0.1104131, 1.9056163, 34.1722608>,
    <-0.1660371, 1.9047735, 34.1809181>,
    <-0.0619534, 1.9096369, 34.1760819>,
    <-0.0934188, 1.9147244, 34.1920745>,
    <-0.1347294, 1.9055658, 34.1760819>,
    <-0.0689749, 1.9131249, 34.1852017>,
    <-0.3299695, 1.8738371, 34.1544411>,
    <-0.1652963, 1.8945113, 34.1544124>,
    <-0.2381182, 1.8925248, 34.1694828>,
    <-0.2375221, 1.8869221, 34.1544124>,
    <-0.1344760, 1.9010111, 34.1645454>,
    <-0.1931512, 1.8960757, 34.1656437>,
    <-0.0928487, 1.8995492, 34.1544124>,
    <-0.0687906, 1.9051078, 34.1656437>,
    <-0.2197740, 1.8833462, 34.1359011>,
    <-0.1956524, 1.8847389, 34.1317777>,
    <-0.1960409, 1.8884709, 34.1440880>,
    <-0.1374901, 1.8929725, 34.1429132>,
    <-0.3284593, 1.8649769, 34.1264018>,
    <-0.3290675, 1.8685800, 34.1387967>,
    <-0.2675199, 1.8762078, 34.1317777>,
    <-0.2611239, 1.8803723, 34.1429132>,
    <-0.3278982, 1.8616343, 34.1138015>,
    <-0.2602736, 1.8742099, 34.1216372>,
    <-0.2199342, -1.8779313, 34.1168394>,
    <-0.3292089, -1.8648447, 34.1264018>,
    <-0.3308202, -1.8736872, 34.1544411>,
    <-0.1654306, -1.8857508, 34.1264018>,
    <-0.2678466, -1.8731152, 34.1210460>,
    <-0.3298697, -1.8684386, 34.1387967>,
    <-0.2378036, -1.8817867, 34.1387967>,
    <-0.1961578, -1.8816560, 34.1210460>,
    <-0.2614559, -1.8767565, 34.1311462>,
    <-0.0931042, -1.8874171, 34.1138015>,
    <-0.1957569, -1.8783977, 34.1083733>,
    <-0.1376258, -1.8835577, 34.1095803>,
    <-0.3285929, -1.8615118, 34.1138015>,
    <-0.2605555, -1.8709801, 34.1095803>,
    <-0.1106046, -1.8928973, 34.1359011>,
    <-0.1661933, -1.8944329, 34.1544124>,
    <-0.1346014, -1.8900802, 34.1317777>,
    <-0.2384152, -1.8868138, 34.1544124>,
    <-0.1348669, -1.8938230, 34.1440880>,
    <-0.1933100, -1.8880889, 34.1429132>,
    <-0.0937470, -1.8995008, 34.1544124>,
    <-0.0623444, -1.8941583, 34.1317777>,
    <-0.0693664, -1.8971489, 34.1429132>,
    <-0.0691336, -1.8909325, 34.1216372>,
    <-0.1105989, 1.9057679, 34.1038334>,
    <-0.1661461, 1.9037213, 34.1125260>,
    <-0.1348873, 1.9051900, 34.1076575>,
    <-0.0934856, 1.9121023, 34.1237934>,
    <-0.0621118, 1.9092679, 34.1076575>,
    <-0.0690988, 1.9114787, 34.1168389>,
    <-0.1656895, 1.8970517, 34.0861074>,
    <-0.0931443, 1.9021020, 34.0861074>,
    <-0.1347319, 1.9022096, 34.0961373>,
    <-0.0689930, 1.9061650, 34.0972345>,
    <-0.3305760, 1.8763365, 34.0861253>,
    <-0.2380120, 1.8894466, 34.0861074>,
    <-0.2383798, 1.8930355, 34.1010718>,
    <-0.1934422, 1.8971155, 34.0972345>,
    <-0.2204786, 1.8880649, 34.0680823>,
    <-0.1966146, 1.8923469, 34.0759583>,
    <-0.1962992, 1.8897511, 34.0642124>,
    <-0.1379676, 1.8970108, 34.0748134>,
    <-0.3294964, 1.8702410, 34.0592183>,
    <-0.3286138, 1.8661440, 34.0484530>,
    <-0.2683601, 1.8811901, 34.0642124>,
    <-0.2609752, 1.8791827, 34.0551646>,
    <-0.3300303, 1.8730653, 34.0708032>,
    <-0.2618451, 1.8843747, 34.0748134>,
    <-0.2206522, -1.8834120, 34.0506060>,
    <-0.1658415, -1.8911257, 34.0592183>,
    <-0.3311050, -1.8762432, 34.0861253>,
    <-0.3300711, -1.8701638, 34.0592183>,
    <-0.1967403, -1.8874906, 34.0541438>,
    <-0.2381842, -1.8863580, 34.0708032>,
    <-0.3304991, -1.8729827, 34.0708032>,
    <-0.2686271, -1.8789243, 34.0541438>,
    <-0.2620403, -1.8822821, 34.0633523>,
    <-0.3296080, -1.8660652, 34.0484530>,
    <-0.1965445, -1.8826324, 34.0438443>,
    <-0.2614622, -1.8752879, 34.0448606>,
    <-0.0935800, -1.8920561, 34.0484530>,
    <-0.1382755, -1.8879114, 34.0448606>,
    <-0.1107386, -1.8976718, 34.0680823>,
    <-0.1662473, -1.8970029, 34.0861074>,
    <-0.1349750, -1.8977397, 34.0759583>,
    <-0.2385673, -1.8893792, 34.0861074>,
    <-0.1348541, -1.8951401, 34.0642124>,
    <-0.1935409, -1.8921488, 34.0748134>,
    <-0.0624014, -1.8992224, 34.0642124>,
    <-0.0693832, -1.8959978, 34.0551646>,
    <-0.0937029, -1.9020720, 34.0861074>,
    <-0.0693511, -1.9012158, 34.0748134>,
    <-0.1114232, 1.9221531, 34.1542153>,
    <-0.1675071, 1.9209438, 34.1620860>,
    <-0.1359427, 1.9219481, 34.1576891>,
    <-0.0942499, 1.9304951, 34.1722289>,
    <-0.0625371, 1.9260564, 34.1576891>,
    <-0.0696109, 1.9291870, 34.1659804>,
    <-0.1668337, 1.9116146, 34.1379890>,
    <-0.0937316, 1.9166995, 34.1379890>,
    <-0.1357124, 1.9178074, 34.1472010>,
    <-0.0694433, 1.9218988, 34.1481994>,
    <-0.3329921, 1.8907533, 34.1380150>,
    <-0.2397119, 1.9039553, 34.1379890>,
    <-0.2402538, 1.9090487, 34.1516897>,
    <-0.1949056, 1.9127836, 34.1481994>,
    <-0.2218688, 1.9009429, 34.1211611>,
    <-0.1978884, 1.9058642, 34.1286034>,
    <-0.1975353, 1.9024715, 34.1174128>,
    <-0.1388039, 1.9104437, 34.1275355>,
    <-0.3316140, 1.8826688, 34.1125260>,
    <-0.3311039, 1.8796301, 34.1010718>,
    <-0.2700757, 1.8938588, 34.1174128>,
    <-0.2628010, 1.8921228, 34.1081947>,
    <-0.3321669, 1.8859443, 34.1237934>,
    <-0.2635739, 1.8977250, 34.1275355>,
    <-0.2220145, -1.8960203, 34.1038334>,
    <-0.1669558, -1.9036504, 34.1125260>,
    <-0.3337654, -1.8906169, 34.1380150>,
    <-0.3322954, -1.8825486, 34.1125260>,
    <-0.1979947, -1.8996688, 34.1076575>,
    <-0.2399678, -1.8992868, 34.1237934>,
    <-0.3328962, -1.8858157, 34.1237934>,
    <-0.2703727, -1.8910474, 34.1076575>,
    <-0.2638758, -1.8944379, 34.1168389>,
    <-0.3317354, -1.8795187, 34.1010718>,
    <-0.1976302, -1.8967067, 34.0961373>,
    <-0.2630572, -1.8891866, 34.0972345>,
    <-0.0939639, -1.9056703, 34.1010718>,
    <-0.1389273, -1.9018849, 34.0972345>,
    <-0.1115972, -1.9105904, 34.1211611>,
    <-0.1676492, -1.9115432, 34.1379890>,
    <-0.1360678, -1.9112728, 34.1286034>,
    <-0.2405237, -1.9038568, 34.1379890>,
    <-0.1358264, -1.9078703, 34.1174128>,
    <-0.1950499, -1.9055228, 34.1275355>,
    <-0.0628925, -1.9119850, 34.1174128>,
    <-0.0697552, -1.9090121, 34.1081947>,
    <-0.0945483, -1.9166555, 34.1379890>,
    <-0.0699668, -1.9146634, 34.1275355>,
    <-0.1116575, 1.9291673, 34.2216509>,
    <-0.1680256, 1.9291229, 34.2291393>,
    <-0.0626162, 1.9335922, 34.2249699>,
    <-0.0945373, 1.9402275, 34.2387176>,
    <-0.1362959, 1.9294752, 34.2249699>,
    <-0.0697507, 1.9379725, 34.2328318>,
    <-0.3336375, 1.8953495, 34.2060335>,
    <-0.1670689, 1.9162470, 34.2059966>,
    <-0.2408933, 1.9156621, 34.2192172>,
    <-0.2401239, 1.9085749, 34.2059966>,
    <-0.1359677, 1.9237826, 34.2149211>,
    <-0.1953473, 1.9188950, 34.2158771>,
    <-0.0937898, 1.9213386, 34.2059966>,
    <-0.0695041, 1.9280270, 34.2158771>,
    <-0.2219536, 1.9031879, 34.1894897>,
    <-0.1975296, 1.9041957, 34.1857817>,
    <-0.1980596, 1.9091534, 34.1968260>,
    <-0.1388491, 1.9135881, 34.1957715>,
    <-0.3316265, 1.8837217, 34.1809181>,
    <-0.3324537, 1.8885506, 34.1920745>,
    <-0.2701494, 1.8955805, 34.1857817>,
    <-0.2638445, 1.9008575, 34.1957715>,
    <-0.3308424, 1.8791282, 34.1694828>,
    <-0.2626791, 1.8925813, 34.1766071>,
    <-0.2221711, -1.8958387, 34.1722608>,
    <-0.3326438, -1.8835423, 34.1809181>,
    <-0.3347310, -1.8951567, 34.2060335>,
    <-0.1672459, -1.9046678, 34.1809181>,
    <-0.2705928, -1.8913833, 34.1760819>,
    <-0.3335181, -1.8883629, 34.1920745>,
    <-0.2404889, -1.9018574, 34.1920745>,
    <-0.1982155, -1.9000115, 34.1760819>,
    <-0.2642837, -1.8960376, 34.1852017>,
    <-0.0941328, -1.9051219, 34.1694828>,
    <-0.1976741, -1.8954820, 34.1645454>,
    <-0.1390333, -1.9008104, 34.1656437>,
    <-0.3318096, -1.8789577, 34.1694828>,
    <-0.2630730, -1.8881103, 34.1656437>,
    <-0.1119035, -1.9128161, 34.1894897>,
    <-0.1682221, -1.9161461, 34.2059966>,
    <-0.1361314, -1.9095674, 34.1857817>,
    <-0.2412720, -1.9084355, 34.2059966>,
    <-0.1364703, -1.9145417, 34.1968260>,
    <-0.1955514, -1.9086273, 34.1957715>,
    <-0.0949447, -1.9212764, 34.2059966>,
    <-0.0631189, -1.9136933, 34.1857817>,
    <-0.0702444, -1.9177953, 34.1957715>,
    <-0.0699548, -1.9094425, 34.1766071>,
    <-0.1125544, 1.9435631, 34.1991181>,
    <-0.1693149, 1.9430796, 34.2059260>,
    <-0.1373668, 1.9436839, 34.2021355>,
    <-0.0952667, 1.9536797, 34.2146338>,
    <-0.0631397, 1.9478339, 34.2021355>,
    <-0.0703162, 1.9517757, 34.2092829>,
    <-0.1684452, 1.9313742, 34.1848862>,
    <-0.0945872, 1.9365079, 34.1848862>,
    <-0.1370685, 1.9385088, 34.1929998>,
    <-0.0700920, 1.9427344, 34.1938690>,
    <-0.3363267, 1.9103099, 34.1849198>,
    <-0.2420771, 1.9236396, 34.1848862>,
    <-0.2427766, 1.9300825, 34.1969055>,
    <-0.1969021, 1.9335284, 34.1938690>,
    <-0.2238502, 1.9189808, 34.1698789>,
    <-0.1997236, 1.9246664, 34.1765488>,
    <-0.1992418, 1.9201594, 34.1665078>,
    <-0.1400394, 1.9291851, 34.1755900>,
    <-0.3344933, 1.8997094, 34.1620860>,
    <-0.3337804, 1.8955336, 34.1516897>,
    <-0.2724661, 1.9114703, 34.1665078>,
    <-0.2649878, 1.9088241, 34.1581668>,
    <-0.3352453, 1.9040994, 34.1722289>,
    <-0.2660472, 1.9163479, 34.1755900>,
    <-0.2240480, -1.9122998, 34.1542153>,
    <-0.1686061, -1.9208476, 34.1620860>,
    <-0.3373208, -1.9101346, 34.1849198>,
    <-0.3354180, -1.8995464, 34.1620860>,
    <-0.1998654, -1.9163556, 34.1576891>,
    <-0.2424089, -1.9175329, 34.1722289>,
    <-0.3362128, -1.9039288, 34.1722289>,
    <-0.2728692, -1.9076547, 34.1576891>,
    <-0.2664465, -1.9119661, 34.1659804>,
    <-0.3346597, -1.8953785, 34.1516897>,
    <-0.1993732, -1.9122379, 34.1472010>,
    <-0.2653459, -1.9047596, 34.1481994>,
    <-0.0948990, -1.9217656, 34.1516897>,
    <-0.1402069, -1.9175691, 34.1481994>,
    <-0.1127781, -1.9286984, 34.1698789>,
    <-0.1694935, -1.9312824, 34.1848862>,
    <-0.1375254, -1.9301080, 34.1765488>,
    <-0.2431209, -1.9235129, 34.1848862>,
    <-0.1372173, -1.9255858, 34.1665078>,
    <-0.1970877, -1.9241941, 34.1755900>,
    <-0.0635966, -1.9297440, 34.1665078>,
    <-0.0705018, -1.9258394, 34.1581668>,
    <-0.0956371, -1.9364514, 34.1848862>,
    <-0.0707650, -1.9334328, 34.1755900>,
    <-0.1130026, 1.9575608, 34.2635082>,
    <-0.1697735, 1.9582266, 34.2695801>,
    <-0.0630064, 1.9623773, 34.2662252>,
    <-0.0932136, 1.9705853, 34.2772285>,
    <-0.1377727, 1.9582035, 34.2662252>,
    <-0.0689249, 1.9677133, 34.2725930>,
    <-0.3382042, 1.9218620, 34.2505667>,
    <-0.1693014, 1.9430385, 34.2505227>,
    <-0.2442979, 1.9436190, 34.2614925>,
    <-0.2433785, 1.9352626, 34.2505227>,
    <-0.1378274, 1.9514760, 34.2579678>,
    <-0.1980631, 1.9466051, 34.2587527>,
    <-0.0949975, 1.9481979, 34.2505227>,
    <-0.0704141, 1.9558618, 34.2587527>,
    <-0.2247671, 1.9283080, 34.2365221>,
    <-0.1999790, 1.9289880, 34.2333423>,
    <-0.2006346, 1.9350206, 34.2427845>,
    <-0.1406059, 1.9394167, 34.2418824>,
    <-0.3357519, 1.9078101, 34.2291393>,
    <-0.3367729, 1.9137180, 34.2387176>,
    <-0.2735532, 1.9202640, 34.2333423>,
    <-0.2673013, 1.9265199, 34.2418824>,
    <-0.3347685, 1.9021052, 34.2192172>,
    <-0.2658563, 1.9163816, 34.2254131>,
    <-0.2250352, -1.9192480, 34.2216509>,
    <-0.3370059, -1.9075889, 34.2291393>,
    <-0.3395075, -1.9216322, 34.2505667>,
    <-0.1695158, -1.9289925, 34.2291393>,
    <-0.2740998, -1.9150897, 34.2249699>,
    <-0.3380671, -1.9134898, 34.2387176>,
    <-0.2438159, -1.9271673, 34.2387176>,
    <-0.2008246, -1.9238297, 34.2249699>,
    <-0.2678344, -1.9206424, 34.2328318>,
    <-0.0954176, -1.9283896, 34.2192172>,
    <-0.2001593, -1.9181666, 34.2149211>,
    <-0.1408331, -1.9236644, 34.2158771>,
    <-0.3359788, -1.9018918, 34.2192172>,
    <-0.2663502, -1.9108052, 34.2158771>,
    <-0.1134948, -1.9380431, 34.2365221>,
    <-0.1706757, -1.9429182, 34.2505227>,
    <-0.1380244, -1.9344083, 34.2333423>,
    <-0.2447468, -1.9350965, 34.2505227>,
    <-0.1384264, -1.9404632, 34.2427845>,
    <-0.1983064, -1.9343685, 34.2418824>,
    <-0.0963738, -1.9481238, 34.2505227>,
    <-0.0640530, -1.9385929, 34.2333423>,
    <-0.0712963, -1.9436681, 34.2418824>,
    <-0.0709589, -1.9334329, 34.2254131>,
    <-0.1139581, 1.9693472, 34.2371711>,
    <-0.1715144, 1.9694560, 34.2427102>,
    <-0.1391163, 1.9697369, 34.2396408>,
    <-0.0965052, 1.9809518, 34.2497196>,
    <-0.0639013, 1.9739387, 34.2396408>,
    <-0.0711933, 1.9785585, 34.2454279>,
    <-0.1704748, 1.9557301, 34.2253660>,
    <-0.0956851, 1.9609256, 34.2253660>,
    <-0.1387591, 1.9636846, 34.2321345>,
    <-0.0709193, 1.9680388, 34.2328481>,
    <-0.3404783, 1.9344122, 34.2254060>,
    <-0.2450359, 1.9479012, 34.2253660>,
    <-0.2458717, 1.9554980, 34.2353389>,
    <-0.1993710, 1.9587194, 34.2328481>,
    <-0.2264080, 1.9418173, 34.2126378>,
    <-0.2020645, 1.9481821, 34.2183311>,
    <-0.2014685, 1.9426979, 34.2097470>,
    <-0.1416365, 1.9526657, 34.2175110>,
    <-0.3382436, 1.9216080, 34.2059260>,
    <-0.3373496, 1.9164218, 34.1969055>,
    <-0.2755605, 1.9339099, 34.2097470>,
    <-0.2678761, 1.9304607, 34.2025384>,
    <-0.3391718, 1.9269788, 34.2146338>,
    <-0.2691897, 1.9396774, 34.2175110>,
    <-0.2266517, -1.9335809, 34.1991181>,
    <-0.1706696, -1.9429610, 34.2059260>,
    <-0.3416631, -1.9342033, 34.2254060>,
    <-0.3393836, -1.9214069, 34.2059260>,
    <-0.2022373, -1.9380084, 34.2021355>,
    <-0.2454335, -1.9405419, 34.2146338>,
    <-0.3403483, -1.9267714, 34.2146338>,
    <-0.2760574, -1.9292060, 34.2021355>,
    <-0.2696744, -1.9343342, 34.2092829>,
    <-0.3384499, -1.9162277, 34.1969055>,
    <-0.2016324, -1.9328602, 34.1929998>,
    <-0.2683252, -1.9253913, 34.1938690>,
    <-0.0960670, -1.9429179, 34.1969055>,
    <-0.1418430, -1.9383454, 34.1938690>,
    <-0.1142247, -1.9516320, 34.2126378>,
    <-0.1717241, -1.9556208, 34.2253660>,
    <-0.1393036, -1.9536730, 34.2183311>,
    <-0.2462798, -1.9477503, 34.2253660>,
    <-0.1389382, -1.9481685, 34.2097470>,
    <-0.1995921, -1.9475952, 34.2175110>,
    <-0.0644458, -1.9523800, 34.2097470>,
    <-0.0714145, -1.9476488, 34.2025384>,
    <-0.0969363, -1.9608582, 34.2253660>,
    <-0.0717213, -1.9569536, 34.2175110>,
    <-0.1059787, 1.9898919, 34.2933120>,
    <-0.1231659, 1.9958231, 34.2967794>,
    <-0.0664977, 1.9943484, 34.2949171>,
    <-0.0484535, 2.0086215, 34.3007507>,
    <-0.1148916, 1.9924155, 34.2949171>,
    <-0.0590314, 2.0013106, 34.2980246>,
    <-0.3323359, 1.9567516, 34.2867877>,
    <-0.1697771, 1.9737761, 34.2854038>,
    <-0.2071650, 1.9809037, 34.2926777>,
    <-0.2401370, 1.9672068, 34.2856693>,
    <-0.1358656, 1.9826263, 34.2900253>,
    <-0.1819122, 1.9800172, 34.2908029>,
    <-0.0948900, 1.9792151, 34.2856693>,
    <-0.0742672, 1.9872058, 34.2908029>,
    <-0.1461096, 2.0006134, 34.2989756>,
    <-0.0681953, 2.0175772, 34.3035582>,
    <-0.1383849, 1.9981539, 34.2980080>,
    <-0.0340957, 2.0172537, 34.3035582>,
    <-0.1148384, 2.0076279, 34.3008727>,
    <-0.0830697, 2.0080624, 34.3007914>,
    <-0.2238955, 1.9918375, 34.2975521>,
    <-0.1022949, 2.0179007, 34.3035582>,
    <-0.1821883, 2.0042795, 34.3007100>,
    <-0.1847460, 1.9959579, 34.2980080>,
    <-0.1474383, 2.0065644, 34.3007914>,
    <-0.2671111, 1.9782469, 34.2937748>,
    <-0.2063823, 1.9868107, 34.2951914>,
    <-0.2277323, 1.9578936, 34.2753407>,
    <-0.2024786, 1.9583713, 34.2729301>,
    <-0.2027947, 1.9651750, 34.2800513>,
    <-0.1409164, 1.9697087, 34.2795037>,
    <-0.3400428, 1.9367722, 34.2695801>,
    <-0.3392251, 1.9443660, 34.2772285>,
    <-0.2771831, 1.9496322, 34.2729301>,
    <-0.2696100, 1.9570752, 34.2795037>,
    <-0.3395573, 1.9298672, 34.2614925>,
    <-0.2697085, 1.9448874, 34.2665723>,
    <-0.2286404, -1.9474419, 34.2635082>,
    <-0.3428358, -1.9362224, 34.2695801>,
    <-0.3563015, -1.9516492, 34.2867877>,
    <-0.1728460, -1.9579514, 34.2695801>,
    <-0.2787126, -1.9435012, 34.2662252>,
    <-0.3460706, -1.9429299, 34.2772285>,
    <-0.2503823, -1.9568091, 34.2772285>,
    <-0.2043574, -1.9523738, 34.2662252>,
    <-0.2738063, -1.9497713, 34.2725930>,
    <-0.0969194, -1.9565130, 34.2614925>,
    <-0.2031368, -1.9457622, 34.2579678>,
    <-0.1429704, -1.9514251, 34.2587527>,
    <-0.3409740, -1.9296174, 34.2614925>,
    <-0.2702875, -1.9383752, 34.2587527>,
    <-0.1157007, -1.9676768, 34.2753407>,
    <-0.1754849, -1.9731764, 34.2854038>,
    <-0.1406636, -1.9637751, 34.2729301>,
    <-0.2502291, -1.9655991, 34.2856693>,
    <-0.1415094, -1.9704956, 34.2800513>,
    <-0.2032546, -1.9642378, 34.2795037>,
    <-0.1048860, -1.9786634, 34.2856693>,
    <-0.0655542, -1.9681104, 34.2729301>,
    <-0.0742331, -1.9740209, 34.2795037>,
    <-0.0721152, -1.9621746, 34.2665723>,
    <-0.1158073, 1.9987941, 34.2672347>,
    <-0.1750785, 1.9994584, 34.2713545>,
    <-0.1416230, 1.9994782, 34.2690979>,
    <-0.1020869, 2.0122295, 34.2765463>,
    <-0.0652837, 2.0037402, 34.2690979>,
    <-0.0741552, 2.0093720, 34.2734379>,
    <-0.1728608, 1.9839423, 34.2582019>,
    <-0.0969918, 1.9892105, 34.2582019>,
    <-0.1407328, 1.9925700, 34.2634197>,
    <-0.0719000, 1.9970431, 34.2639559>,
    <-0.3453208, 1.9623278, 34.2582471>,
    <-0.2484982, 1.9760030, 34.2582019>,
    <-0.2494450, 1.9845228, 34.2658251>,
    <-0.2022373, 1.9875913, 34.2639559>,
    <-0.2294643, 1.9687585, 34.2481381>,
    <-0.2048398, 1.9756969, 34.2526827>,
    <-0.2041478, 1.9694020, 34.2458152>,
    <-0.1435468, 1.9801719, 34.2520259>,
    <-0.3427510, 1.9476989, 34.2427102>,
    <-0.3417031, 1.9416599, 34.2353389>,
    <-0.2792647, 1.9604957, 34.2458152>,
    <-0.2713781, 1.9563751, 34.2399571>,
    <-0.3438272, 1.9538875, 34.2497196>,
    <-0.2729061, 1.9670047, 34.2520259>,
    <-0.2297467, -1.9592170, 34.2371711>,
    <-0.1730838, -1.9693187, 34.2427102>,
    <-0.3466602, -1.9620916, 34.2582471>,
    <-0.3440717, -1.9474660, 34.2427102>,
    <-0.2050384, -1.9639695, 34.2396408>,
    <-0.2489496, -1.9676146, 34.2497196>,
    <-0.3451770, -1.9536495, 34.2497196>,
    <-0.2798404, -1.9550465, 34.2396408>,
    <-0.2734613, -1.9608624, 34.2454279>,
    <-0.3429909, -1.9414328, 34.2353389>,
    <-0.2043392, -1.9579471, 34.2321345>,
    <-0.2719045, -1.9504549, 34.2328481>,
    <-0.0974323, -1.9684847, 34.2353389>,
    <-0.1437860, -1.9635825, 34.2328481>,
    <-0.1158931, -1.9786947, 34.2481381>,
    <-0.1742733, -1.9838188, 34.2582019>,
    <-0.1413484, -1.9812516, 34.2526827>,
    <-0.2499045, -1.9758323, 34.2582019>,
    <-0.1409367, -1.9749322, 34.2458152>,
    <-0.2024873, -1.9750153, 34.2520259>,
    <-0.0654144, -1.9792052, 34.2458152>,
    <-0.0724657, -1.9737777, 34.2399571>,
    <-0.0984063, -1.9891343, 34.2582019>,
    <-0.0728068, -1.9845111, 34.2520259>,
    <-0.2770395, 1.9878987, 34.2989756>,
    <-0.2433207, 2.0022554, 34.3035582>,
    <-0.2557354, 1.9892746, 34.2980080>,
    <-0.1898576, 2.0102398, 34.3035582>,
    <-0.2624451, 1.9942413, 34.3008727>,
    <-0.2204072, 2.0001804, 34.3007914>,
    <-0.3603217, 1.9682890, 34.2967794>,
    <-0.2967838, 1.9942710, 34.3035582>,
    <-0.3553209, 1.9779291, 34.3007507>,
    <-0.3125783, 1.9800794, 34.2980080>,
    <-0.3086521, 1.9864367, 34.3007914>,
    <-0.3547792, 1.9620129, 34.2926777>,
    <-0.3006206, 1.9766763, 34.2951914>,
    <-0.2409359, -1.9776536, 34.2933120>,
    <-0.3329568, -1.9708039, 34.2967794>,
    <-0.2240080, -1.9846658, 34.2967794>,
    <-0.2807397, -1.9754461, 34.2949171>,
    <-0.3413732, -1.9786265, 34.3007507>,
    <-0.3001802, -1.9849460, 34.3007507>,
    <-0.2323056, -1.9811768, 34.2949171>,
    <-0.2890508, -1.9805675, 34.2980246>,
    <-0.1388463, -1.9848769, 34.2926777>,
    <-0.2103671, -1.9759125, 34.2900253>,
    <-0.1642471, -1.9807954, 34.2908029>,
    <-0.3362389, -1.9633029, 34.2926777>,
    <-0.2719283, -1.9698959, 34.2908029>,
    <-0.1997372, -1.9894174, 34.2989756>,
    <-0.2769088, -1.9896544, 34.3035582>,
    <-0.2082516, -1.9875351, 34.2980080>,
    <-0.3140432, -1.9878020, 34.3035582>,
    <-0.2307209, -1.9895836, 34.3008727>,
    <-0.2643300, -1.9874510, 34.3007914>,
    <-0.2378761, -1.9921899, 34.3035582>,
    <-0.1602436, -1.9910627, 34.2980080>,
    <-0.1954568, -1.9920283, 34.3007914>,
    <-0.1394426, -1.9884891, 34.2951914>,
    <-0.2621735, 2.0215884, 34.2894178>,
    <-0.3124020, 2.0152810, 34.2886791>,
    <-0.2925622, 2.0244038, 34.2918019>,
    <-0.2323763, 2.0296695, 34.2918021>,
    <-0.2882709, 2.0180698, 34.2889154>,
    <-0.3017223, 2.0202475, 34.2903193>,
    <-0.2649186, 2.0268224, 34.2918020>,
    <-0.2512634, 2.0248540, 34.2904043>,
    <-0.2789781, 2.0223333, 34.2903618>,
    <-0.2200458, 2.0225275, 34.2882666>,
    <-0.1963251, 2.0328236, 34.2918022>,
    <-0.1811161, 2.0308473, 34.2903408>,
    <-0.2466738, 2.0217092, 34.2889155>,
    <-0.2182631, 2.0276453, 34.2903620>,
    <-0.3619206, 1.9945491, 34.2830970>,
    <-0.2718107, 2.0124588, 34.2861105>,
    <-0.3261210, 2.0086939, 34.2867237>,
    <-0.2880302, 2.0142576, 34.2874565>,
    <-0.1735535, 2.0228609, 34.2863581>,
    <-0.1939676, 2.0227666, 34.2872643>,
    <-0.1461373, 2.0270300, 34.2872643>,
    <-0.1650619, 2.0290407, 34.2889218>,
    <-0.1956775, 2.0122837, 34.2817251>,
    <-0.1200102, 2.0189714, 34.2819691>,
    <-0.1810676, 2.0184746, 34.2845089>,
    <-0.1244795, 2.0240602, 34.2850030>,
    <-0.2680752, 2.0050697, 34.2819691>,
    <-0.2331673, 2.0142360, 34.2850030>,
    <-0.2366995, 1.9984821, 34.2751874>,
    <-0.2164548, 2.0052413, 34.2783022>,
    <-0.2089331, 1.9993943, 34.2735942>,
    <-0.1526510, 2.0106038, 34.2779937>,
    <-0.3489496, 1.9772462, 34.2713545>,
    <-0.3467085, 1.9704813, 34.2658251>,
    <-0.2852219, 1.9902673, 34.2735942>,
    <-0.2753875, 1.9857800, 34.2692880>,
    <-0.3533544, 1.9842347, 34.2765463>,
    <-0.2841056, 1.9968887, 34.2779937>,
    <-0.2329760, -1.9885495, 34.2672347>,
    <-0.1745708, -1.9995243, 34.2713544>,
    <-0.3388765, -1.9986500, 34.2830965>,
    <-0.3481399, -1.9773914, 34.2713544>,
    <-0.2075925, -1.9937209, 34.2690979>,
    <-0.2480329, -1.9995465, 34.2765461>,
    <-0.3457525, -1.9855851, 34.2765461>,
    <-0.2835121, -1.9846619, 34.2690979>,
    <-0.2753277, -1.9918287, 34.2734378>,
    <-0.3481448, -1.9702280, 34.2658251>,
    <-0.2074114, -1.9867364, 34.2634197>,
    <-0.2759752, -1.9791889, 34.2639559>,
    <-0.0989534, -1.9976891, 34.2658251>,
    <-0.1459768, -1.9925135, 34.2639559>,
    <-0.1137577, -2.0091936, 34.2751756>,
    <-0.1559804, -2.0156067, 34.2816848>,
    <-0.1346539, -2.0122979, 34.2782754>,
    <-0.2312656, -2.0093234, 34.2819686>,
    <-0.1412904, -2.0053265, 34.2735942>,
    <-0.1982384, -2.0066724, 34.2779935>,
    <-0.0644732, -2.0094659, 34.2735676>,
    <-0.0736234, -2.0034321, 34.2692880>,
    <-0.0823353, -2.0206337, 34.2818094>,
    <-0.0659892, -2.0155140, 34.2778874>,
    <-0.1781253, -2.0224164, 34.2863450>,
    <-0.2348331, -2.0213734, 34.2882644>,
    <-0.1568021, -2.0259038, 34.2872364>,
    <-0.2044763, -2.0288036, 34.2903380>,
    <-0.2051765, -2.0218790, 34.2872627>,
    <-0.1845076, -2.0273395, 34.2889197>,
    <-0.2727391, -2.0129361, 34.2861091>,
    <-0.1711418, -2.0192429, 34.2844816>,
    <-0.2271704, -2.0151330, 34.2850020>,
    <-0.1176755, -2.0238828, 34.2848961>,
    <-0.2779615, -2.0202486, 34.2894147>,
    <-0.2551298, -2.0276790, 34.2917976>,
    <-0.2625642, -2.0204121, 34.2889128>,
    <-0.2222615, -2.0305545, 34.2917982>,
    <-0.2702613, -2.0231919, 34.2904005>,
    <-0.2399908, -2.0257444, 34.2903586>,
    <-0.3057195, -2.0232530, 34.2917974>,
    <-0.3195477, -2.0147833, 34.2886767>,
    <-0.2830207, -2.0252388, 34.2917973>,
    <-0.3127358, -2.0192842, 34.2903158>,
    <-0.2998161, -2.0171530, 34.2889125>,
    <-0.2940960, -2.0210108, 34.2903580>,
    <-0.3259509, -2.0092182, 34.2867222>,
    <-0.2948257, -2.0140355, 34.2874544>,
    <-0.3381274, 2.0143597, 34.2894172>,
    <-0.3305568, 2.0210792, 34.2918011>,
    <-0.3349460, 2.0173135, 34.2904035>,
    <-0.3139176, 2.0225352, 34.2918015>,
    <-0.3289882, 2.0142886, 34.2889150>,
    <-0.3198107, 2.0187607, 34.2903614>,
    <-0.3683465, 2.0070399, 34.2886786>,
    <-0.3686444, 2.0019398, 34.2867235>,
    <-0.3501964, 2.0113395, 34.2889147>,
    <-0.3447347, 2.0084216, 34.2874561>,
    <-0.3660240, 2.0118511, 34.2903183>,
    <-0.3440519, 2.0198982, 34.2918006>,
    <-0.3488310, 2.0153466, 34.2903608>,
    <-0.3428442, -2.0138576, 34.2894157>,
    <-0.3362478, -2.0205821, 34.2917992>,
    <-0.3340500, -2.0138900, 34.2889131>,
    <-0.3230113, -2.0217401, 34.2917981>,
    <-0.3400554, -2.0168178, 34.2904018>,
    <-0.3274215, -2.0180953, 34.2903587>,
    <-0.3722239, -2.0061021, 34.2886783>,
    <-0.3467808, -2.0196605, 34.2918006>,
    <-0.3705566, -2.0108317, 34.2903187>,
    <-0.3535632, -2.0108431, 34.2889139>,
    <-0.3525399, -2.0148259, 34.2903604>,
    <-0.3672039, -2.0020008, 34.2867229>,
    <-0.3451151, -2.0085640, 34.2874549>,
    <-0.4162576, 1.9969145, 34.2894172>,
    <-0.4652166, 1.9812120, 34.2882663>,
    <-0.5093265, 1.9777661, 34.2918019>,
    <-0.4333583, 1.9981210, 34.2918011>,
    <-0.4350644, 1.9907587, 34.2889150>,
    <-0.4932984, 1.9786503, 34.2903405>,
    <-0.4716078, 1.9878725, 34.2918015>,
    <-0.4218672, 1.9978707, 34.2904035>,
    <-0.4562324, 1.9886312, 34.2903614>,
    <-0.3947551, 2.0084642, 34.2918006>,
    <-0.3920548, 2.0019466, 34.2889147>,
    <-0.3910836, 2.0058182, 34.2903608>,
    <-0.4276987, 1.9858669, 34.2861103>,
    <-0.4023114, 1.9956235, 34.2874561>,
    <-0.4281892, -1.9937171, 34.2894166>,
    <-0.4498907, -1.9936906, 34.2918006>,
    <-0.5349979, -1.9708873, 34.2917990>,
    <-0.4783254, -1.9775643, 34.2882651>,
    <-0.4359476, -1.9941129, 34.2904030>,
    <-0.4940983, -1.9818458, 34.2917998>,
    <-0.5151464, -1.9727960, 34.2903384>,
    <-0.4481180, -1.9871836, 34.2889141>,
    <-0.4747531, -1.9836684, 34.2903601>,
    <-0.4275283, -1.9853722, 34.2861096>,
    <-0.3997211, -1.9998921, 34.2889145>,
    <-0.4069032, -1.9940842, 34.2874555>,
    <-0.4034778, -2.0061262, 34.2918014>,
    <-0.3997873, -2.0035473, 34.2903610>,
    <-0.4147929, -1.9572879, 34.2989756>,
    <-0.4648935, -1.9422483, 34.2975521>,
    <-0.5395838, -1.9310771, 34.3035582>,
    <-0.4484202, -1.9568044, 34.3035582>,
    <-0.4345687, -1.9508700, 34.2980080>,
    <-0.5031990, -1.9368504, 34.3007100>,
    <-0.4953198, -1.9432359, 34.3035582>,
    <-0.4294384, -1.9571626, 34.3008727>,
    <-0.4676615, -1.9466522, 34.3007914>,
    <-0.3997636, -1.9713128, 34.3035582>,
    <-0.3803626, -1.9637472, 34.2980080>,
    <-0.3860741, -1.9681847, 34.3007914>,
    <-0.4227463, -1.9468953, 34.2937748>,
    <-0.3906067, -1.9566905, 34.2951914>,
    <-0.4267338, 1.7723676, 34.0221521>,
    <-0.4954253, 1.7642720, 34.0252783>,
    <-0.3781649, 1.7879950, 34.0235337>,
    <-0.4231725, 1.7977768, 34.0315713>,
    <-0.4580872, 1.7688850, 34.0235337>,
    <-0.3937137, 1.7953907, 34.0277883>,
    <-0.4681779, 1.7405618, 34.0159774>,
    <-0.5661220, 1.7275933, 34.0197144>,
    <-0.5443665, 1.7201467, 34.0159774>,
    <-0.4438420, 1.7597442, 34.0195520>,
    <-0.5054736, 1.7440885, 34.0196603>,
    <-0.3919893, 1.7609768, 34.0159774>,
    <-0.3805849, 1.7757085, 34.0196603>,
    <-0.4324237, 1.8264745, 34.0581798>,
    <-0.4860151, 1.8152890, 34.0677166>,
    <-0.3862628, 1.8386381, 34.0621232>,
    <-0.4171262, 1.8355996, 34.0805061>,
    <-0.4560287, 1.8222698, 34.0621232>,
    <-0.3935243, 1.8397418, 34.0723106>,
    <-0.6393436, 1.7538140, 34.0418026>,
    <-0.4828346, 1.8024401, 34.0421478>,
    <-0.5535779, 1.7914103, 34.0557354>,
    <-0.5506864, 1.7827015, 34.0420666>,
    <-0.4546391, 1.8173818, 34.0506039>,
    <-0.5106156, 1.8025939, 34.0517365>,
    <-0.4153932, 1.8188853, 34.0420666>,
    <-0.3917696, 1.8325529, 34.0517365>,
    <-0.5351576, 1.7671011, 34.0300324>,
    <-0.5193144, 1.7662962, 34.0277479>,
    <-0.5113901, 1.7847677, 34.0349278>,
    <-0.4624823, 1.7950345, 34.0340297>,
    <-0.6277044, 1.7223036, 34.0252783>,
    <-0.6335958, 1.7358286, 34.0315713>,
    <-0.5744730, 1.7493087, 34.0277479>,
    <-0.5696425, 1.7645802, 34.0340297>,
    <-0.6247700, 1.7075951, 34.0197144>,
    <-0.5721669, 1.7379658, 34.0233431>,
    <-0.5152608, -1.7489568, 34.0218046>,
    <-0.6276729, -1.7234249, 34.0252457>,
    <-0.6366636, -1.7546543, 34.0417158>,
    <-0.4424131, -1.7754533, 34.0240730>,
    <-0.5666267, -1.7384581, 34.0234034>,
    <-0.6296231, -1.7374408, 34.0314410>,
    <-0.5213372, -1.7695138, 34.0307895>,
    <-0.4815075, -1.7612473, 34.0227519>,
    <-0.5501825, -1.7527031, 34.0272671>,
    <-0.4760417, -1.7406334, 34.0159774>,
    <-0.3968826, -1.7703619, 34.0184901>,
    <-0.4234743, -1.7547185, 34.0159774>,
    <-0.5001400, -1.7459987, 34.0194217>,
    <-0.4445592, -1.7603446, 34.0191391>,
    <-0.5443573, -1.7223286, 34.0159774>,
    <-0.6217691, -1.7104750, 34.0197144>,
    <-0.5610078, -1.7291573, 34.0196603>,
    <-0.4175063, -1.7970214, 34.0293375>,
    <-0.4830063, -1.8024653, 34.0420827>,
    <-0.4265177, -1.7889425, 34.0268358>,
    <-0.5481227, -1.7831679, 34.0419363>,
    <-0.4482547, -1.8013265, 34.0346672>,
    <-0.4897527, -1.7865116, 34.0335085>,
    <-0.4148501, -1.8189461, 34.0419363>,
    <-0.3801886, -1.7991487, 34.0268358>,
    <-0.3896688, -1.8115882, 34.0335085>,
    <-0.3828659, -1.7863784, 34.0223007>,
    <-0.4356198, 1.8399001, 34.1168394>,
    <-0.4895109, 1.8286067, 34.1264018>,
    <-0.3889497, 1.8517615, 34.1210460>,
    <-0.4201467, 1.8496347, 34.1387967>,
    <-0.4592362, 1.8352681, 34.1210460>,
    <-0.3962004, 1.8529974, 34.1311462>,
    <-0.6449738, 1.7729147, 34.0973598>,
    <-0.4877423, 1.8214688, 34.0973402>,
    <-0.5580454, 1.8054354, 34.1138015>,
    <-0.5569613, 1.8016177, 34.0973402>,
    <-0.4584986, 1.8320692, 34.1083733>,
    <-0.5148887, 1.8170361, 34.1095803>,
    <-0.4178668, 1.8388667, 34.0973402>,
    <-0.3950708, 1.8472614, 34.1095803>,
    <-0.5395180, 1.8029056, 34.0775018>,
    <-0.5162132, 1.8086323, 34.0732308>,
    <-0.5170302, 1.8113388, 34.0861763>,
    <-0.4606407, 1.8259471, 34.0849170>,
    <-0.6426898, 1.7666308, 34.0677166>,
    <-0.6437691, 1.7695066, 34.0805061>,
    <-0.5849979, 1.7878986, 34.0732308>,
    <-0.5792572, 1.7923295, 34.0849170>,
    <-0.6410668, 1.7626065, 34.0557354>,
    <-0.5774051, 1.7870520, 34.0632019>,
    <-0.5388350, -1.7980188, 34.0581798>,
    <-0.6432765, -1.7664414, 34.0677166>,
    <-0.6455290, -1.7727126, 34.0973598>,
    <-0.4867801, -1.8151082, 34.0677166>,
    <-0.5848521, -1.7854565, 34.0621232>,
    <-0.6442612, -1.7693275, 34.0805061>,
    <-0.5565579, -1.7982390, 34.0805061>,
    <-0.5162489, -1.8061641, 34.0621232>,
    <-0.5790689, -1.7900253, 34.0723106>,
    <-0.4164405, -1.8282527, 34.0557354>,
    <-0.5151590, -1.8012941, 34.0506039>,
    <-0.4592764, -1.8164712, 34.0517365>,
    <-0.6420441, -1.7623472, 34.0557354>,
    <-0.5771796, -1.7829935, 34.0517365>,
    <-0.4342255, -1.8311245, 34.0775018>,
    <-0.4883372, -1.8213094, 34.0973402>,
    <-0.4572827, -1.8244359, 34.0732308>,
    <-0.5575501, -1.8014387, 34.0973402>,
    <-0.4579081, -1.8271805, 34.0861763>,
    <-0.5140470, -1.8116369, 34.0849170>,
    <-0.4184663, -1.8387274, 34.0973402>,
    <-0.3873466, -1.8408724, 34.0732308>,
    <-0.3945134, -1.8418315, 34.0849170>,
    <-0.3935597, -1.8363662, 34.0632019>,
    <-0.4312463, 1.7911312, 34.0204813>,
    <-0.5006564, 1.7828990, 34.0228405>,
    <-0.4629285, 1.7875890, 34.0215203>,
    <-0.4276244, 1.8166562, 34.0277741>,
    <-0.3821600, 1.8069017, 34.0215203>,
    <-0.3978644, 1.8143061, 34.0248083>,
    <-0.4731443, 1.7590892, 34.0159774>,
    <-0.3961445, 1.7797217, 34.0159774>,
    <-0.4485418, 1.7784164, 34.0185671>,
    <-0.3846129, 1.7945488, 34.0186456>,
    <-0.5501441, 1.7384566, 34.0159774>,
    <-0.5721194, 1.7459214, 34.0186848>,
    <-0.5108275, 1.7625926, 34.0186456>,
    <-0.4368862, 1.8452269, 34.0506060>,
    <-0.4909912, 1.8337689, 34.0592183>,
    <-0.4607196, 1.8409137, 34.0541438>,
    <-0.4213525, 1.8540605, 34.0708032>,
    <-0.3902383, 1.8574507, 34.0541438>,
    <-0.3975410, 1.8583897, 34.0633523>,
    <-0.4878743, 1.8212002, 34.0364647>,
    <-0.4197310, 1.8378185, 34.0364059>,
    <-0.4593566, 1.8361628, 34.0438443>,
    <-0.3958330, 1.8514735, 34.0448606>,
    <-0.6460136, 1.7720722, 34.0361559>,
    <-0.5564330, 1.8012569, 34.0364059>,
    <-0.5592972, 1.8098411, 34.0484530>,
    <-0.5159083, 1.8212034, 34.0448606>,
    <-0.5407893, 1.7856824, 34.0264558>,
    <-0.5167538, 1.8034574, 34.0303723>,
    <-0.5247880, 1.7849053, 34.0246615>,
    <-0.4673381, 1.8138460, 34.0296825>,
    <-0.6343304, 1.7404871, 34.0228405>,
    <-0.6313889, 1.7257109, 34.0186848>,
    <-0.5805270, 1.7677387, 34.0246615>,
    <-0.5782144, 1.7563457, 34.0213137>,
    <-0.6402548, 1.7540565, 34.0277741>,
    <-0.5756196, 1.7830722, 34.0296825>,
    <-0.5208503, -1.7675330, 34.0202515>,
    <-0.4475914, -1.7944452, 34.0220434>,
    <-0.6433969, -1.7729250, 34.0360984>,
    <-0.6343246, -1.7416124, 34.0228190>,
    <-0.4869288, -1.7800235, 34.0210033>,
    <-0.5278807, -1.7880602, 34.0272571>,
    <-0.6363983, -1.7556796, 34.0276880>,
    <-0.5727787, -1.7568249, 34.0214341>,
    <-0.5566845, -1.7711402, 34.0244636>,
    <-0.4796089, -1.7595360, 34.0159774>,
    <-0.6283422, -1.7286074, 34.0186848>,
    <-0.5501282, -1.7406408, 34.0159774>,
    <-0.5048677, -1.7647016, 34.0184809>,
    <-0.5669373, -1.7474882, 34.0186456>,
    <-0.4220491, -1.7749588, 34.0159774>,
    <-0.3947762, -1.7911581, 34.0178631>,
    <-0.4470258, -1.7797743, 34.0183009>,
    <-0.4220523, -1.8160960, 34.0259962>,
    <-0.4880636, -1.8212397, 34.0364216>,
    <-0.4531206, -1.8202255, 34.0302000>,
    <-0.5539927, -1.8017285, 34.0363197>,
    <-0.4313505, -1.8079889, 34.0240583>,
    <-0.4955931, -1.8052110, 34.0293378>,
    <-0.3836587, -1.8185365, 34.0240583>,
    <-0.3846936, -1.8061925, 34.0206243>,
    <-0.4191572, -1.8379251, 34.0363197>,
    <-0.3937620, -1.8307367, 34.0293378>,
    <-0.4396425, 1.8574927, 34.1722608>,
    <-0.4942750, 1.8470037, 34.1809181>,
    <-0.3926172, 1.8698671, 34.1760819>,
    <-0.4244880, 1.8694134, 34.1920745>,
    <-0.4635806, 1.8532205, 34.1760819>,
    <-0.4001376, 1.8720829, 34.1852017>,
    <-0.6503449, 1.7880708, 34.1544411>,
    <-0.4917636, 1.8370261, 34.1544124>,
    <-0.5631342, 1.8224244, 34.1694828>,
    <-0.5615742, 1.8170103, 34.1544124>,
    <-0.4625401, 1.8487790, 34.1645454>,
    <-0.5194669, 1.8337298, 34.1656437>,
    <-0.4212914, 1.8545678, 34.1544124>,
    <-0.3985640, 1.8642196, 34.1656437>,
    <-0.5434748, 1.8165706, 34.1359011>,
    <-0.5199616, 1.8221308, 34.1317777>,
    <-0.5209922, 1.8257387, 34.1440880>,
    <-0.4641125, 1.8403391, 34.1429132>,
    <-0.6473192, 1.7796073, 34.1264018>,
    <-0.6485438, 1.7830501, 34.1387967>,
    <-0.5892558, 1.8012496, 34.1317777>,
    <-0.5836801, 1.8064616, 34.1429132>,
    <-0.6461862, 1.7764130, 34.1138015>,
    <-0.5817727, 1.8005404, 34.1216372>,
    <-0.5426923, -1.8112101, 34.1168394>,
    <-0.6480343, -1.7793470, 34.1264018>,
    <-0.6511566, -1.7877754, 34.1544411>,
    <-0.4903745, -1.8283753, 34.1264018>,
    <-0.5890405, -1.7981473, 34.1210460>,
    <-0.6493092, -1.7827716, 34.1387967>,
    <-0.5609596, -1.8119040, 34.1387967>,
    <-0.5199239, -1.8190069, 34.1210460>,
    <-0.5833791, -1.8028430, 34.1311462>,
    <-0.4194362, -1.8425756, 34.1138015>,
    <-0.5189632, -1.8158678, 34.1083733>,
    <-0.4626114, -1.8310438, 34.1095803>,
    <-0.6468490, -1.7761717, 34.1138015>,
    <-0.5814894, -1.7973107, 34.1095803>,
    <-0.4376224, -1.8449337, 34.1359011>,
    <-0.4926333, -1.8367930, 34.1544124>,
    <-0.4607655, -1.8379924, 34.1317777>,
    <-0.5624349, -1.8167485, 34.1544124>,
    <-0.4616769, -1.8416321, 34.1440880>,
    <-0.5182364, -1.8258366, 34.1429132>,
    <-0.4221677, -1.8543641, 34.1544124>,
    <-0.3903144, -1.8545558, 34.1317777>,
    <-0.3977491, -1.8562816, 34.1429132>,
    <-0.3964403, -1.8502000, 34.1216372>,
    <-0.4398518, 1.8576097, 34.1038334>,
    <-0.4941997, 1.8459485, 34.1125260>,
    <-0.4636708, 1.8528229, 34.1076575>,
    <-0.4240984, 1.8668196, 34.1237934>,
    <-0.3927091, 1.8694762, 34.1076575>,
    <-0.3999738, 1.8704401, 34.1168389>,
    <-0.4925919, 1.8394595, 34.0861074>,
    <-0.4220258, 1.8570305, 34.0861074>,
    <-0.4630003, 1.8499148, 34.0961373>,
    <-0.3989470, 1.8652256, 34.0972345>,
    <-0.6513763, 1.7904268, 34.0861253>,
    <-0.5624950, 1.8194113, 34.0861074>,
    <-0.5634805, 1.8228818, 34.1010718>,
    <-0.5199340, 1.8347031, 34.0972345>,
    <-0.5449886, 1.8210959, 34.0680823>,
    <-0.5222301, 1.8294561, 34.0759583>,
    <-0.5214701, 1.8269560, 34.0642124>,
    <-0.4652840, 1.8442331, 34.0748134>,
    <-0.6492569, 1.7846141, 34.0592183>,
    <-0.6476834, 1.7807406, 34.0484530>,
    <-0.5909496, 1.8060118, 34.0642124>,
    <-0.5833323, 1.8053217, 34.0551646>,
    <-0.6502708, 1.7873001, 34.0708032>,
    <-0.5850854, 1.8102779, 34.0748134>,
    <-0.5443466, -1.8164901, 34.0506060>,
    <-0.4917106, -1.8336002, 34.0592183>,
    <-0.6518810, -1.7902431, 34.0861253>,
    <-0.6498052, -1.7844386, 34.0592183>,
    <-0.5215083, -1.8246556, 34.0541438>,
    <-0.5621283, -1.8163397, 34.0708032>,
    <-0.6507181, -1.7871373, 34.0708032>,
    <-0.5908154, -1.8037364, 34.0541438>,
    <-0.5849142, -1.8081832, 34.0633523>,
    <-0.6486319, -1.7804918, 34.0484530>,
    <-0.5204642, -1.8199177, 34.0438443>,
    <-0.5831209, -1.8014109, 34.0448606>,
    <-0.4207029, -1.8470738, 34.0484530>,
    <-0.4639976, -1.8352339, 34.0448606>,
    <-0.4385830, -1.8496131, 34.0680823>,
    <-0.4931327, -1.8393146, 34.0861074>,
    <-0.4624635, -1.8454706, 34.0759583>,
    <-0.5630302, -1.8192485, 34.0861074>,
    <-0.4618920, -1.8429332, 34.0642124>,
    <-0.5191688, -1.8297948, 34.0748134>,
    <-0.3912488, -1.8595347, 34.0642124>,
    <-0.3975615, -1.8551518, 34.0551646>,
    <-0.4225707, -1.8569039, 34.0861074>,
    <-0.3984402, -1.8602894, 34.0748134>,
    <-0.4435088, 1.8736029, 34.1542153>,
    <-0.4985307, 1.8626730, 34.1620860>,
    <-0.4676202, 1.8691432, 34.1576891>,
    <-0.4280450, 1.8848002, 34.1722289>,
    <-0.3960432, 1.8859358, 34.1576891>,
    <-0.4035531, 1.8877905, 34.1659804>,
    <-0.4962476, 1.8536025, 34.1379890>,
    <-0.4251390, 1.8713042, 34.1379890>,
    <-0.4666744, 1.8651054, 34.1472010>,
    <-0.4021226, 1.8806421, 34.1481994>,
    <-0.6562591, 1.8042050, 34.1380150>,
    <-0.5666885, 1.8334044, 34.1379890>,
    <-0.5681066, 1.8383263, 34.1516897>,
    <-0.5240959, 1.8498791, 34.1481994>,
    <-0.5485933, 1.8335362, 34.1211611>,
    <-0.5258319, 1.8425469, 34.1286034>,
    <-0.5248950, 1.8392670, 34.1174128>,
    <-0.4684402, 1.8573167, 34.1275355>,
    <-0.6534980, 1.7964826, 34.1125260>,
    <-0.6524680, 1.7935787, 34.1010718>,
    <-0.5948378, 1.8181887, 34.1174128>,
    <-0.5873721, 1.8177423, 34.1081947>,
    <-0.6546113, 1.7996124, 34.1237934>,
    <-0.5891061, 1.8231252, 34.1275355>,
    <-0.5478820, -1.8286630, 34.1038334>,
    <-0.4949848, -1.8457381, 34.1125260>,
    <-0.6569970, -1.8039364, 34.1380150>,
    <-0.6541482, -1.7962460, 34.1125260>,
    <-0.5248608, -1.8364271, 34.1076575>,
    <-0.5661298, -1.8287624, 34.1237934>,
    <-0.6553072, -1.7993591, 34.1237934>,
    <-0.5946421, -1.8153685, 34.1076575>,
    <-0.5888326, -1.8198356, 34.1168389>,
    <-0.6530706, -1.7933593, 34.1010718>,
    <-0.5239874, -1.8335734, 34.0961373>,
    <-0.5871146, -1.8148062, 34.0972345>,
    <-0.4234525, -1.8604022, 34.1010718>,
    <-0.4670755, -1.8488665, 34.0972345>,
    <-0.4416723, -1.8621856, 34.1211611>,
    <-0.4970382, -1.8533906, 34.1379890>,
    <-0.4658897, -1.8586083, 34.1286034>,
    <-0.5674709, -1.8331664, 34.1379890>,
    <-0.4650611, -1.8552995, 34.1174128>,
    <-0.5229772, -1.8427036, 34.1275355>,
    <-0.3939497, -1.8720165, 34.1174128>,
    <-0.4001920, -1.8678971, 34.1081947>,
    <-0.4259356, -1.8711191, 34.1379890>,
    <-0.4013817, -1.8734258, 34.1275355>,
    <-0.4449575, 1.8804698, 34.2216509>,
    <-0.5004616, 1.8706379, 34.2291393>,
    <-0.3974297, 1.8933433, 34.2249699>,
    <-0.4300181, 1.8943348, 34.2387176>,
    <-0.4692751, 1.8764946, 34.2249699>,
    <-0.4052164, 1.8964182, 34.2328318>,
    <-0.6576928, 1.8086194, 34.2060335>,
    <-0.4972835, 1.8581237, 34.2059966>,
    <-0.5698849, 1.8447282, 34.2192172>,
    <-0.5678964, 1.8378823, 34.2059966>,
    <-0.4679634, 1.8709455, 34.2149211>,
    <-0.5255922, 1.8558210, 34.2158771>,
    <-0.4260019, 1.8758627, 34.2059966>,
    <-0.4032465, 1.8866667, 34.2158771>,
    <-0.5490667, 1.8357324, 34.1894897>,
    <-0.5251888, 1.8409661, 34.1857817>,
    <-0.5265717, 1.8457564, 34.1968260>,
    <-0.4690307, 1.8604055, 34.1957715>,
    <-0.6536932, 1.7975174, 34.1809181>,
    <-0.6553464, 1.8021293, 34.1920745>,
    <-0.5952093, 1.8198714, 34.1857817>,
    <-0.5899165, 1.8261631, 34.1957715>,
    <-0.6521233, 1.7931299, 34.1694828>,
    <-0.5873318, 1.8182150, 34.1766071>,
    <-0.5480048, -1.8284571, 34.1722608>,
    <-0.6546639, -1.7971641, 34.1809181>,
    <-0.6587362, -1.8082396, 34.2060335>,
    <-0.4954471, -1.8466897, 34.1809181>,
    <-0.5949172, -1.8156610, 34.1760819>,
    <-0.6563620, -1.8017597, 34.1920745>,
    <-0.5670894, -1.8312035, 34.1920745>,
    <-0.5251377, -1.8367263, 34.1760819>,
    <-0.5895121, -1.8213401, 34.1852017>,
    <-0.4235237, -1.8598328, 34.1694828>,
    <-0.5238180, -1.8323596, 34.1645454>,
    <-0.4669934, -1.8477900, 34.1656437>,
    <-0.6530462, -1.7927940, 34.1694828>,
    <-0.5869433, -1.8137435, 34.1656437>,
    <-0.4423605, -1.8643242, 34.1894897>,
    <-0.4984017, -1.8578241, 34.2059966>,
    <-0.4656562, -1.8569178, 34.1857817>,
    <-0.5690029, -1.8375457, 34.2059966>,
    <-0.4668537, -1.8617577, 34.1968260>,
    <-0.5240102, -1.8456738, 34.1957715>,
    <-0.4271284, -1.8756009, 34.2059966>,
    <-0.3944693, -1.8736595, 34.1857817>,
    <-0.4021989, -1.8764619, 34.1957715>,
    <-0.4004633, -1.8682863, 34.1766071>,
    <-0.4483406, 1.8944912, 34.1991181>,
    <-0.5041548, 1.8841586, 34.2059260>,
    <-0.4727971, 1.8903015, 34.2021355>,
    <-0.4330724, 1.9074561, 34.2146338>,
    <-0.4004182, 1.9072779, 34.2021355>,
    <-0.4081702, 1.9099136, 34.2092829>,
    <-0.5012657, 1.8727821, 34.1848862>,
    <-0.4294213, 1.8906632, 34.1848862>,
    <-0.4716046, 1.8852568, 34.1929998>,
    <-0.4063794, 1.9010486, 34.1938690>,
    <-0.6629389, 1.8228855, 34.1849198>,
    <-0.5724359, 1.8523790, 34.1848862>,
    <-0.5742436, 1.8586026, 34.1969055>,
    <-0.5296644, 1.8699621, 34.1938690>,
    <-0.5536769, 1.8509560, 34.1698789>,
    <-0.5309042, 1.8607447, 34.1765488>,
    <-0.5296470, 1.8563899, 34.1665078>,
    <-0.4729113, 1.8755589, 34.1755900>,
    <-0.6592926, 1.8127644, 34.1620860>,
    <-0.6578655, 1.8087758, 34.1516897>,
    <-0.6002501, 1.8351176, 34.1665078>,
    <-0.5924259, 1.8338101, 34.1581668>,
    <-0.6607955, 1.8169571, 34.1722289>,
    <-0.5947756, 1.8410356, 34.1755900>,
    <-0.5527115, -1.8443421, 34.1542153>,
    <-0.4995962, -1.8623875, 34.1620860>,
    <-0.6638875, -1.8225403, 34.1849198>,
    <-0.6601750, -1.8124433, 34.1620860>,
    <-0.5296006, -1.8525356, 34.1576891>,
    <-0.5717023, -1.8463074, 34.1722289>,
    <-0.6617188, -1.8166211, 34.1722289>,
    <-0.5999844, -1.8312899, 34.1576891>,
    <-0.5944080, -1.8366511, 34.1659804>,
    <-0.6587044, -1.8084704, 34.1516897>,
    <-0.5284009, -1.8485659, 34.1472010>,
    <-0.5920727, -1.8297451, 34.1481994>,
    <-0.4271684, -1.8760906, 34.1516897>,
    <-0.4710592, -1.8640903, 34.1481994>,
    <-0.4459797, -1.8798134, 34.1698789>,
    <-0.5022822, -1.8725097, 34.1848862>,
    <-0.4705958, -1.8769043, 34.1765488>,
    <-0.5734418, -1.8520730, 34.1848862>,
    <-0.4695072, -1.8725044, 34.1665078>,
    <-0.5282262, -1.8607374, 34.1755900>,
    <-0.3977270, -1.8893835, 34.1665078>,
    <-0.4038492, -1.8843391, 34.1581668>,
    <-0.4304454, -1.8904252, 34.1848862>,
    <-0.4054270, -1.8917715, 34.1755900>,
    <-0.4512056, 1.9082154, 34.2635082>,
    <-0.5072126, 1.8990534, 34.2695801>,
    <-0.4027963, 1.9216618, 34.2662252>,
    <-0.4338897, 1.9246912, 34.2772285>,
    <-0.4757020, 1.9045683, 34.2662252>,
    <-0.4095033, 1.9260039, 34.2725930>,
    <-0.6667940, 1.8339361, 34.2505667>,
    <-0.5041344, 1.8841205, 34.2505227>,
    <-0.5780924, 1.8716692, 34.2614925>,
    <-0.5757359, 1.8635994, 34.2505227>,
    <-0.4746037, 1.8978952, 34.2579678>,
    <-0.5330785, 1.8826386, 34.2587527>,
    <-0.4318553, 1.9021043, 34.2505227>,
    <-0.4089762, 1.9139206, 34.2587527>,
    <-0.5561995, 1.8599823, 34.2365221>,
    <-0.5319061, 1.8649563, 34.2333423>,
    <-0.5335993, 1.8707835, 34.2427845>,
    <-0.4752460, 1.8855366, 34.2418824>,
    <-0.6619388, 1.8205234, 34.2291393>,
    <-0.6639702, 1.8261643, 34.2387176>,
    <-0.6028477, 1.8435889, 34.2333423>,
    <-0.5977770, 1.8508354, 34.2418824>,
    <-0.6599797, 1.8150761, 34.2192172>,
    <-0.5945935, 1.8411020, 34.2254131>,
    <-0.5548904, -1.8510133, 34.2216509>,
    <-0.6631354, -1.8200879, 34.2291393>,
    <-0.6680375, -1.8334834, 34.2505667>,
    <-0.5019065, -1.8702507, 34.2291393>,
    <-0.6024874, -1.8383983, 34.2249699>,
    <-0.6652051, -1.8257149, 34.2387176>,
    <-0.5747609, -1.8555511, 34.2387176>,
    <-0.5318431, -1.8597295, 34.2249699>,
    <-0.5972814, -1.8449546, 34.2328318>,
    <-0.4288293, -1.8825239, 34.2192172>,
    <-0.5302045, -1.8542680, 34.2149211>,
    <-0.4727343, -1.8699842, 34.2158771>,
    <-0.6611346, -1.8146557, 34.2192172>,
    <-0.5941116, -1.8355246, 34.2158771>,
    <-0.4483082, -1.8888917, 34.2365221>,
    <-0.5054670, -1.8837634, 34.2505227>,
    <-0.4718339, -1.8810526, 34.2333423>,
    <-0.5770545, -1.8631983, 34.2505227>,
    <-0.4732812, -1.8869457, 34.2427845>,
    <-0.5311932, -1.8705456, 34.2418824>,
    <-0.4331978, -1.9017923, 34.2505227>,
    <-0.3997130, -1.8980186, 34.2333423>,
    <-0.4077276, -1.9017590, 34.2418824>,
    <-0.4056179, -1.8917378, 34.2254131>,
    <-0.4542004, 1.9196397, 34.2371711>,
    <-0.5109011, 1.9097524, 34.2427102>,
    <-0.4790441, 1.9156549, 34.2396408>,
    <-0.4390278, 1.9340987, 34.2497196>,
    <-0.4057014, 1.9328538, 34.2396408>,
    <-0.4136848, 1.9361372, 34.2454279>,
    <-0.5074938, 1.8964155, 34.2253660>,
    <-0.4347425, 1.9145192, 34.2253660>,
    <-0.4776413, 1.9097566, 34.2321345>,
    <-0.4115882, 1.9258249, 34.2328481>,
    <-0.6712128, 1.8459007, 34.2254060>,
    <-0.5795627, 1.8757581, 34.2253660>,
    <-0.5817050, 1.8830944, 34.2353389>,
    <-0.5364701, 1.8943417, 34.2328481>,
    <-0.5601613, 1.8730014, 34.2126378>,
    <-0.5372929, 1.8834967, 34.2183311>,
    <-0.5357537, 1.8781993, 34.2097470>,
    <-0.4785615, 1.8984054, 34.2175110>,
    <-0.6667886, 1.8336790, 34.2059260>,
    <-0.6650077, 1.8287269, 34.1969055>,
    <-0.6071940, 1.8566789, 34.2097470>,
    <-0.5990274, 1.8546165, 34.2025384>,
    <-0.6686354, 1.8388071, 34.2146338>,
    <-0.6019216, 1.8634650, 34.2175110>,
    <-0.5589712, -1.8648478, 34.1991181>,
    <-0.5054684, -1.8838066, 34.2059260>,
    <-0.6723433, -1.8454892, 34.2254060>,
    <-0.6678764, -1.8332831, 34.2059260>,
    <-0.5356964, -1.8734476, 34.2021355>,
    <-0.5786764, -1.8684416, 34.2146338>,
    <-0.6697580, -1.8383985, 34.2146338>,
    <-0.6068665, -1.8519602, 34.2021355>,
    <-0.6014710, -1.8581188, 34.2092829>,
    <-0.6660575, -1.8283447, 34.1969055>,
    <-0.5342068, -1.8684826, 34.1929998>,
    <-0.5985894, -1.8495461, 34.1938690>,
    <-0.4319917, -1.8967188, 34.1969055>,
    <-0.4762782, -1.8842668, 34.1938690>,
    <-0.4513868, -1.9021475, 34.2126378>,
    <-0.5087052, -1.8960909, 34.2253660>,
    <-0.4764390, -1.8998025, 34.2183311>,
    <-0.5807615, -1.8753935, 34.2253660>,
    <-0.4751233, -1.8944451, 34.2097470>,
    <-0.5347562, -1.8833481, 34.2175110>,
    <-0.4024940, -1.9115281, 34.2097470>,
    <-0.4085352, -1.9056587, 34.2025384>,
    <-0.4359630, -1.9142356, 34.2253660>,
    <-0.4104531, -1.9147688, 34.2175110>,
    <-0.4913012, 1.9448767, 34.2989756>,
    <-0.4678584, 1.9441608, 34.2967794>,
    <-0.4175055, 1.9750860, 34.3035582>,
    <-0.4832644, 1.9437802, 34.2980080>,
    <-0.3964635, 1.9698508, 34.3007507>,
    <-0.3838762, 1.9806863, 34.3035582>,
    <-0.4617163, 1.9571976, 34.3008727>,
    <-0.4305079, 1.9631308, 34.3007914>,
    <-0.5664206, 1.9228509, 34.2975521>,
    <-0.4511349, 1.9694857, 34.3035582>,
    <-0.5274934, 1.9423210, 34.3007100>,
    <-0.5285518, 1.9336173, 34.2980080>,
    <-0.4936414, 1.9505202, 34.3007914>,
    <-0.6670967, 1.8693812, 34.2867877>,
    <-0.6066194, 1.9019510, 34.2937748>,
    <-0.5480092, 1.9148620, 34.2926777>,
    <-0.5482702, 1.9208398, 34.2951914>,
    <-0.4497577, 1.9417020, 34.2933120>,
    <-0.4114545, 1.9534996, 34.2949171>,
    <-0.4590752, 1.9423576, 34.2949171>,
    <-0.4054413, 1.9612941, 34.2980246>,
    <-0.5099054, 1.9144099, 34.2854038>,
    <-0.5780978, 1.8956377, 34.2856693>,
    <-0.4780128, 1.9291135, 34.2900253>,
    <-0.5229817, 1.9183584, 34.2908029>,
    <-0.4369842, 1.9330585, 34.2856693>,
    <-0.4179276, 1.9449118, 34.2908029>,
    <-0.5642508, 1.8886217, 34.2753407>,
    <-0.5394541, 1.8934975, 34.2729301>,
    <-0.5409485, 1.9001456, 34.2800513>,
    <-0.4807481, 1.9154678, 34.2795037>,
    <-0.6711952, 1.8483046, 34.2695801>,
    <-0.6717131, 1.8559376, 34.2772285>,
    <-0.6115232, 1.8718834, 34.2729301>,
    <-0.6053609, 1.8805367, 34.2795037>,
    <-0.6695166, 1.8415847, 34.2614925>,
    <-0.6033372, 1.8685059, 34.2665723>,
    <-0.5633370, -1.8781541, 34.2635082>,
    <-0.6738503, -1.8472782, 34.2695801>,
    <-0.6898123, -1.8601943, 34.2867877>,
    <-0.5102172, -1.8981979, 34.2695801>,
    <-0.6119648, -1.8655799, 34.2662252>,
    <-0.6782051, -1.8533346, 34.2772285>,
    <-0.5863842, -1.8836287, 34.2772285>,
    <-0.5402799, -1.8872293, 34.2662252>,
    <-0.6082247, -1.8726151, 34.2725930>,
    <-0.4351919, -1.9099593, 34.2614925>,
    <-0.5379288, -1.8809273, 34.2579678>,
    <-0.4796597, -1.8969521, 34.2587527>,
    <-0.6708683, -1.8410927, 34.2614925>,
    <-0.6027766, -1.8619920, 34.2587527>,
    <-0.4556364, -1.9177173, 34.2753407>,
    <-0.5155125, -1.9128696, 34.2854038>,
    <-0.4795372, -1.9095275, 34.2729301>,
    <-0.5878016, -1.8924249, 34.2856693>,
    <-0.4815549, -1.9160429, 34.2800513>,
    <-0.5412713, -1.8991517, 34.2795037>,
    <-0.4469286, -1.9304855, 34.2856693>,
    <-0.4063205, -1.9268322, 34.2729301>,
    <-0.4159041, -1.9311614, 34.2795037>,
    <-0.4117476, -1.9198421, 34.2665723>,
    <-0.4611349, 1.9483182, 34.2672347>,
    <-0.5196210, 1.9386801, 34.2713545>,
    <-0.4866772, 1.9445091, 34.2690979>,
    <-0.4499559, 1.9639320, 34.2765463>,
    <-0.4122377, 1.9619625, 34.2690979>,
    <-0.4219524, 1.9659682, 34.2734378>,
    <-0.5147427, 1.9237848, 34.2582019>,
    <-0.4409411, 1.9421474, 34.2582019>,
    <-0.4846009, 1.9378604, 34.2634197>,
    <-0.4175906, 1.9542182, 34.2639559>,
    <-0.6808293, 1.8725513, 34.2582471>,
    <-0.5878523, 1.9028318, 34.2582019>,
    <-0.5902641, 1.9110578, 34.2658251>,
    <-0.5443064, 1.9222772, 34.2639559>,
    <-0.5678495, 1.8990026, 34.2481381>,
    <-0.5448040, 1.9101115, 34.2526827>,
    <-0.5430294, 1.9040324, 34.2458152>,
    <-0.4852192, 1.9251620, 34.2520259>,
    <-0.6757582, 1.8585908, 34.2427102>,
    <-0.6736775, 1.8528256, 34.2353389>,
    <-0.6154586, 1.8822176, 34.2458152>,
    <-0.6069763, 1.8795291, 34.2399571>,
    <-0.6778927, 1.8644986, 34.2497196>,
    <-0.6103268, 1.8897319, 34.2520259>,
    <-0.5664708, -1.8895570, 34.2371711>,
    <-0.5124229, -1.9093447, 34.2427102>,
    <-0.6821073, -1.8720861, 34.2582471>,
    <-0.6770184, -1.8581322, 34.2427102>,
    <-0.5429631, -1.8985278, 34.2396408>,
    <-0.5868402, -1.8944925, 34.2497196>,
    <-0.6791806, -1.8640298, 34.2497196>,
    <-0.6150792, -1.8767512, 34.2396408>,
    <-0.6098070, -1.8835864, 34.2454279>,
    <-0.6749064, -1.8523784, 34.2353389>,
    <-0.5412288, -1.8927184, 34.2321345>,
    <-0.6064666, -1.8736074, 34.2328481>,
    <-0.4377759, -1.9216601, 34.2353389>,
    <-0.4825741, -1.9087831, 34.2328481>,
    <-0.4577292, -1.9285092, 34.2481381>,
    <-0.5161122, -1.9234179, 34.2582019>,
    <-0.4832417, -1.9266071, 34.2526827>,
    <-0.5892076, -1.9024196, 34.2582019>,
    <-0.4817389, -1.9204552, 34.2458152>,
    <-0.5423689, -1.9098488, 34.2520259>,
    <-0.4081060, -1.9377775, 34.2458152>,
    <-0.4141077, -1.9312080, 34.2399571>,
    <-0.4423209, -1.9418268, 34.2582019>,
    <-0.4163074, -1.9417192, 34.2520259>,
    <-0.6181768, 1.9100362, 34.2989756>,
    <-0.5875240, 1.9302121, 34.3035582>,
    <-0.5973825, 1.9149429, 34.2980080>,
    <-0.5361441, 1.9470488, 34.3035582>,
    <-0.6049300, 1.9188909, 34.3008727>,
    <-0.5644824, 1.9318227, 34.3007914>,
    <-0.6968390, 1.8763784, 34.2967794>,
    <-0.6389038, 1.9133755, 34.3035582>,
    <-0.6937074, 1.8870332, 34.3007507>,
    <-0.6518468, 1.8962401, 34.2980080>,
    <-0.6491578, 1.9033911, 34.3007914>,
    <-0.6902019, 1.8709217, 34.2926777>,
    <-0.6394062, 1.8947556, 34.2951914>,
    <-0.5808553, -1.9062092, 34.2933120>,
    <-0.6703348, -1.8836175, 34.2967794>,
    <-0.5654517, -1.9161689, 34.2967794>,
    <-0.6196983, -1.8972014, 34.2949171>,
    <-0.6801062, -1.8901930, 34.3007507>,
    <-0.6406407, -1.9035687, 34.3007507>,
    <-0.5729962, -1.9112478, 34.2949171>,
    <-0.6288505, -1.9010088, 34.2980246>,
    <-0.4815177, -1.9308625, 34.2926777>,
    <-0.5503936, -1.9096531, 34.2900253>,
    <-0.5058241, -1.9224605, 34.2908029>,
    <-0.6721715, -1.8754095, 34.2926777>,
    <-0.6099796, -1.8930575, 34.2908029>,
    <-0.5423243, -1.9248703, 34.2989756>,
    <-0.6184479, -1.9119284, 34.3035582>,
    <-0.5504141, -1.9216598, 34.2980080>,
    <-0.6548051, -1.9039987, 34.3035582>,
    <-0.5729032, -1.9197632, 34.3008727>,
    <-0.6057091, -1.9120790, 34.3007914>,
    <-0.5803336, -1.9207979, 34.3035582>,
    <-0.5036464, -1.9331039, 34.2980080>,
    <-0.5385064, -1.9279539, 34.3007914>,
    <-0.4827210, -1.9342418, 34.2951914>,
    <-0.6092350, 1.9453503, 34.2894178>,
    <-0.6576044, 1.9304169, 34.2886789>,
    <-0.6396499, 1.9428464, 34.2918015>,
    <-0.5812937, 1.9584829, 34.2918021>,
    <-0.6343248, 1.9373535, 34.2889153>,
    <-0.6479492, 1.9371626, 34.2903190>,
    <-0.6128470, 1.9500282, 34.2918019>,
    <-0.5990577, 1.9504607, 34.2904042>,
    <-0.6259135, 1.9431659, 34.2903617>,
    <-0.5679104, 1.9535904, 34.2882666>,
    <-0.5463377, 1.9678492, 34.2918020>,
    <-0.5310165, 1.9685439, 34.2903406>,
    <-0.5939918, 1.9481606, 34.2889155>,
    <-0.5670434, 1.9589400, 34.2903619>,
    <-0.7027716, 1.9014008, 34.2830969>,
    <-0.6171407, 1.9346858, 34.2861105>,
    <-0.6699714, 1.9215475, 34.2867235>,
    <-0.6334259, 1.9336408, 34.2874564>,
    <-0.5221824, 1.9619920, 34.2863580>,
    <-0.5422700, 1.9583543, 34.2872643>,
    <-0.4959066, 1.9708585, 34.2872642>,
    <-0.5148927, 1.9695525, 34.2889216>,
    <-0.5421339, 1.9477337, 34.2817250>,
    <-0.4687775, 1.9674592, 34.2819691>,
    <-0.5288209, 1.9563675, 34.2845089>,
    <-0.4740623, 1.9716946, 34.2850030>,
    <-0.6121790, 1.9280575, 34.2819691>,
    <-0.5793930, 1.9431463, 34.2850030>,
    <-0.5801362, 1.9270183, 34.2751874>,
    <-0.5613728, 1.9371902, 34.2783022>,
    <-0.5529501, 1.9327382, 34.2735942>,
    <-0.4994695, 1.9535506, 34.2779937>,
    <-0.6869934, 1.8866129, 34.2713545>,
    <-0.6836117, 1.8803399, 34.2658251>,
    <-0.6264950, 1.9105024, 34.2735942>,
    <-0.6160308, 1.9077911, 34.2692880>,
    <-0.6925448, 1.8927304, 34.2765462>,
    <-0.6265454, 1.9172171, 34.2779937>,
    <-0.6245520, -1.9412887, 34.2894146>,
    <-0.5822737, -1.9498857, 34.2882644>,
    <-0.6033572, -1.9525709, 34.2917976>,
    <-0.6094167, -1.9441235, 34.2889127>,
    <-0.5536676, -1.9624745, 34.2903380>,
    <-0.5714868, -1.9611104, 34.2917982>,
    <-0.6174797, -1.9455245, 34.2904005>,
    <-0.5881118, -1.9532947, 34.2903586>,
    <-0.6524118, -1.9394268, 34.2917970>,
    <-0.6645588, -1.9286848, 34.2886764>,
    <-0.6304015, -1.9453245, 34.2917971>,
    <-0.6586322, -1.9343000, 34.2903155>,
    <-0.6455374, -1.9344450, 34.2889124>,
    <-0.6405743, -1.9392375, 34.2903579>,
    <-0.6807908, -1.9094405, 34.2830964>,
    <-0.6698978, -1.9220924, 34.2867220>,
    <-0.6181389, -1.9349943, 34.2861090>,
    <-0.6400812, -1.9322415, 34.2874543>,
    <-0.5747446, -1.9178831, 34.2672347>,
    <-0.5191325, -1.9388331, 34.2713544>,
    <-0.6862213, -1.8868966, 34.2713544>,
    <-0.5506447, -1.9273837, 34.2690979>,
    <-0.5914826, -1.9260983, 34.2765461>,
    <-0.6852932, -1.8953802, 34.2765461>,
    <-0.6238379, -1.9052791, 34.2690979>,
    <-0.6170224, -1.9137582, 34.2734378>,
    <-0.6849823, -1.8798411, 34.2658251>,
    <-0.5492536, -1.9205368, 34.2634197>,
    <-0.6154651, -1.9011979, 34.2639559>,
    <-0.4443452, -1.9501566, 34.2658251>,
    <-0.4897554, -1.9368941, 34.2639559>,
    <-0.5266593, -1.9607938, 34.2863568>,
    <-0.5063291, -1.9679731, 34.2872630>,
    <-0.5531553, -1.9555335, 34.2872627>,
    <-0.5337480, -1.9645002, 34.2889197>,
    <-0.5037898, -1.9580130, 34.2817246>,
    <-0.5766678, -1.9386384, 34.2819686>,
    <-0.5192948, -1.9589233, 34.2845081>,
    <-0.5736438, -1.9450708, 34.2850020>,
    <-0.4326535, -1.9760932, 34.2819687>,
    <-0.4677909, -1.9730045, 34.2850022>,
    <-0.4609734, -1.9589493, 34.2751874>,
    <-0.4821551, -1.9584199, 34.2783020>,
    <-0.4873653, -1.9503263, 34.2735942>,
    <-0.5436819, -1.9417628, 34.2779935>,
    <-0.4125487, -1.9678178, 34.2735942>,
    <-0.4203972, -1.9602109, 34.2692880>,
    <-0.4154368, -1.9737381, 34.2779935>,
    <-0.6827770, 1.9250433, 34.2894165>,
    <-0.6764866, 1.9329760, 34.2918000>,
    <-0.6801562, 1.9285049, 34.2904026>,
    <-0.6603550, 1.9372985, 34.2918009>,
    <-0.6737653, 1.9265599, 34.2889145>,
    <-0.6655035, 1.9325578, 34.2903608>,
    <-0.7112655, 1.9125873, 34.2886778>,
    <-0.7106750, 1.9075123, 34.2867231>,
    <-0.6941380, 1.9199733, 34.2889140>,
    <-0.6882540, 1.9180475, 34.2874556>,
    <-0.7098114, 1.9177298, 34.2903170>,
    <-0.6895692, 1.9294705, 34.2917990>,
    <-0.6934873, 1.9241574, 34.2903597>,
    <-0.6873438, -1.9237269, 34.2894150>,
    <-0.6820182, -1.9314938, 34.2917981>,
    <-0.6786872, -1.9252862, 34.2889126>,
    <-0.6691806, -1.9349336, 34.2917974>,
    <-0.6851126, -1.9271260, 34.2904009>,
    <-0.6728902, -1.9305785, 34.2903581>,
    <-0.7149312, -1.9109873, 34.2886775>,
    <-0.6922349, -1.9287563, 34.2917990>,
    <-0.7141143, -1.9159335, 34.2903174>,
    <-0.6973770, -1.9188967, 34.2889131>,
    <-0.6970637, -1.9229959, 34.2903592>,
    <-0.7092724, -1.9078208, 34.2867225>,
    <-0.6886590, -1.9181198, 34.2874545>,
    <-0.7566910, 1.8942959, 34.2894165>,
    <-0.8021815, 1.8703294, 34.2882661>,
    <-0.8450226, 1.8592764, 34.2918015>,
    <-0.7737396, 1.8925153, 34.2918000>,
    <-0.7741441, 1.8849674, 34.2889145>,
    <-0.8293916, 1.8629304, 34.2903402>,
    <-0.8096303, 1.8757797, 34.2918009>,
    <-0.7623806, 1.8942637, 34.2904026>,
    <-0.7946207, 1.8791967, 34.2903608>,
    <-0.7375166, 1.9094057, 34.2917990>,
    <-0.7337293, 1.9034544, 34.2889140>,
    <-0.7334434, 1.9074367, 34.2903597>,
    <-0.7660422, 1.8814285, 34.2861101>,
    <-0.7427336, 1.8954458, 34.2874556>,
    <-0.7485298, -1.8559712, 34.2989756>,
    <-0.7951526, -1.8321795, 34.2975521>,
    <-0.8667735, -1.8082399, 34.3035582>,
    <-0.7816320, -1.8498514, 34.3035582>,
    <-0.7668376, -1.8460752, 34.2980080>,
    <-0.8319423, -1.8202297, 34.3007100>,
    <-0.8253665, -1.8280939, 34.3035582>,
    <-0.7629590, -1.8533835, 34.3008727>,
    <-0.7987050, -1.8362086, 34.3007914>,
    <-0.7363458, -1.8728779, 34.3035582>,
    <-0.7157726, -1.8683821, 34.2980080>,
    <-0.7222446, -1.8719677, 34.3007914>,
    <-0.7544464, -1.8440490, 34.2937748>,
    <-0.7245587, -1.8594455, 34.2951914>,
    <-0.7678948, -1.8890724, 34.2894159>,
    <-0.7892648, -1.8852772, 34.2917995>,
    <-0.8691135, -1.8480431, 34.2917987>,
    <-0.8144610, -1.8644598, 34.2882648>,
    <-0.7756052, -1.8881146, 34.2904021>,
    <-0.8307407, -1.8659366, 34.2917992>,
    <-0.8498948, -1.8533700, 34.2903381>,
    <-0.7863846, -1.8791780, 34.2889136>,
    <-0.8120052, -1.8710909, 34.2903596>,
    <-0.7657911, -1.8809700, 34.2861094>,
    <-0.7409319, -1.9000969, 34.2889137>,
    <-0.7469940, -1.8931307, 34.2874550>,
    <-0.7457202, -1.9055823, 34.2917998>,
    <-0.7416348, -1.9036843, 34.2903599>,
    <-0.7281708, 1.6715127, 34.0221521>,
    <-0.7943850, 1.6515819, 34.0252783>,
    <-0.6830420, 1.6953225, 34.0235337>,
    <-0.7290048, 1.6970741, 34.0315713>,
    <-0.7584304, 1.6626250, 34.0235337>,
    <-0.6996060, 1.6998694, 34.0277883>,
    <-0.7635238, 1.6330636, 34.0159774>,
    <-0.8576875, 1.6032418, 34.0197144>,
    <-0.8350082, 1.5997296, 34.0159774>,
    <-0.7428520, 1.6561387, 34.0195520>,
    <-0.8008264, 1.6300180, 34.0196603>,
    <-0.6920395, 1.6663977, 34.0159774>,
    <-0.6833282, 1.6828432, 34.0196603>,
    <-0.7430236, 1.7236430, 34.0581798>,
    <-0.7938554, 1.7033178, 34.0677166>,
    <-0.6996737, 1.7436346, 34.0621232>,
    <-0.7295377, 1.7352795, 34.0805061>,
    <-0.7655373, 1.7154003, 34.0621232>,
    <-0.7070136, 1.7434572, 34.0723106>,
    <-0.9342067, 1.6161830, 34.0418026>,
    <-0.7885190, 1.6912477, 34.0421478>,
    <-0.8562523, 1.6680778, 34.0557354>,
    <-0.8519132, 1.6600276, 34.0420666>,
    <-0.7633296, 1.7108388, 34.0506039>,
    <-0.8158870, 1.6865545, 34.0517365>,
    <-0.7249588, 1.7191550, 34.0420666>,
    <-0.7040489, 1.7366958, 34.0517365>,
    <-0.8339656, 1.6474238, 34.0300324>,
    <-0.8182389, 1.6494002, 34.0277479>,
    <-0.8135977, 1.6689152, 34.0349278>,
    <-0.7672229, 1.6875268, 34.0340297>,
    <-0.9173661, 1.5872813, 34.0252783>,
    <-0.9254735, 1.5995276, 34.0315713>,
    <-0.8696095, 1.6230927, 34.0277479>,
    <-0.8674665, 1.6389271, 34.0340297>,
    <-0.9119714, 1.5733634, 34.0197144>,
    <-0.8654048, 1.6123644, 34.0233431>,
    <-0.8147384, -1.6326951, 34.0221521>,
    <-0.9178092, -1.5883008, 34.0252783>,
    <-0.9330010, -1.6171857, 34.0418026>,
    <-0.7564953, -1.6705259, 34.0252783>,
    <-0.8617990, -1.6133930, 34.0235337>,
    <-0.9237075, -1.6013758, 34.0315713>,
    <-0.8326931, -1.6495521, 34.0315713>,
    <-0.7882937, -1.6501261, 34.0235337>,
    <-0.8541376, -1.6289074, 34.0277883>,
    <-0.7635130, -1.6352480, 34.0159774>,
    <-0.6795505, -1.6880965, 34.0197144>,
    <-0.6920300, -1.6685811, 34.0159774>,
    <-0.7939104, -1.6341345, 34.0195520>,
    <-0.7366194, -1.6617518, 34.0196603>,
    <-0.8349960, -1.6019150, 34.0159774>,
    <-0.9092020, -1.5767495, 34.0197144>,
    <-0.8526101, -1.6056989, 34.0196603>,
    <-0.7272611, -1.6980555, 34.0300324>,
    <-0.7891804, -1.6912429, 34.0421478>,
    <-0.7391268, -1.6873258, 34.0277479>,
    <-0.8514272, -1.6604940, 34.0420666>,
    <-0.7563578, -1.6961780, 34.0349278>,
    <-0.8005330, -1.6726373, 34.0340297>,
    <-0.7245282, -1.7197404, 34.0420666>,
    <-0.6859537, -1.7097678, 34.0277479>,
    <-0.6988680, -1.7181891, 34.0340297>,
    <-0.6810025, -1.6997604, 34.0233431>,
    <-0.7484970, 1.7363033, 34.1168394>,
    <-0.7996083, 1.7158234, 34.1264018>,
    <-0.7045957, 1.7560887, 34.1210460>,
    <-0.7349494, 1.7485769, 34.1387967>,
    <-0.7709503, 1.7276408, 34.1210460>,
    <-0.7119508, 1.7560467, 34.1311462>,
    <-0.9430386, 1.6339816, 34.0973598>,
    <-0.7966271, 1.7091010, 34.0973402>,
    <-0.8630780, 1.6811032, 34.1138015>,
    <-0.8613475, 1.6775318, 34.0973402>,
    <-0.7696685, 1.7246185, 34.1083733>,
    <-0.8225914, 1.7000218, 34.1095803>,
    <-0.7308344, 1.7383683, 34.0973402>,
    <-0.7098424, 1.7505940, 34.1095803>,
    <-0.8443934, 1.6818297, 34.0775018>,
    <-0.8224378, 1.6915171, 34.0732308>,
    <-0.8237110, 1.6940391, 34.0861763>,
    <-0.7707149, 1.7182174, 34.0849170>,
    <-0.9397005, 1.6281924, 34.0677166>,
    <-0.9412604, 1.6308344, 34.0805061>,
    <-0.8865771, 1.6591541, 34.0732308>,
    <-0.8816917, 1.6645131, 34.0849170>,
    <-0.9374103, 1.6245192, 34.0557354>,
    <-0.8789565, 1.6596433, 34.0632019>,
    <-0.8428674, -1.6771423, 34.0581798>,
    <-0.9402412, -1.6279044, 34.0677166>,
    <-0.9435503, -1.6336862, 34.0973598>,
    <-0.7945732, -1.7030071, 34.0677166>,
    <-0.8860059, -1.6567767, 34.0621232>,
    <-0.9417139, -1.6305727, 34.0805061>,
    <-0.8603635, -1.6742745, 34.0805061>,
    <-0.8220408, -1.6890826, 34.0621232>,
    <-0.8811062, -1.6622765, 34.0723106>,
    <-0.7275793, -1.7281754, 34.0557354>,
    <-0.8201146, -1.6844882, 34.0506039>,
    <-0.7677170, -1.7091377, 34.0517365>,
    <-0.9383111, -1.6240957, 34.0557354>,
    <-0.8780155, -1.6556949, 34.0517365>,
    <-0.7455997, -1.7279039, 34.0775018>,
    <-0.7971854, -1.7088407, 34.0973402>,
    <-0.7671446, -1.7173140, 34.0732308>,
    <-0.8618962, -1.6772532, 34.0973402>,
    <-0.7682381, -1.7199066, 34.0861763>,
    <-0.8208249, -1.6948507, 34.0849170>,
    <-0.7314005, -1.7381271, 34.0973402>,
    <-0.7011251, -1.7456450, 34.0732308>,
    <-0.7083505, -1.7453434, 34.0849170>,
    <-0.7064583, -1.7401335, 34.0632019>,
    <-0.7358740, 1.6892072, 34.0204813>,
    <-0.8027715, 1.6690174, 34.0228405>,
    <-0.7664468, 1.6802039, 34.0215203>,
    <-0.7366677, 1.7148934, 34.0277741>,
    <-0.6902607, 1.7132477, 34.0215203>,
    <-0.7069790, 1.7177764, 34.0248083>,
    <-0.7716334, 1.6504465, 34.0159774>,
    <-0.6993886, 1.6841353, 34.0159774>,
    <-0.7507240, 1.6737106, 34.0185671>,
    <-0.6905682, 1.7006970, 34.0186456>,
    <-0.8438782, 1.6167577, 34.0159774>,
    <-0.8667766, 1.6202498, 34.0186848>,
    <-0.8093129, 1.6473109, 34.0186456>,
    <-0.7506747, 1.7413357, 34.0506060>,
    <-0.8019649, 1.7206528, 34.0592183>,
    <-0.7733945, 1.7329463, 34.0541438>,
    <-0.7369055, 1.7527260, 34.0708032>,
    <-0.7068556, 1.7614710, 34.0541438>,
    <-0.7142075, 1.7611242, 34.0633523>,
    <-0.7967398, 1.7088477, 34.0364647>,
    <-0.7325185, 1.7370474, 34.0364059>,
    <-0.7712367, 1.7285154, 34.0438443>,
    <-0.7113362, 1.7546233, 34.0448606>,
    <-0.9439460, 1.6330057, 34.0361559>,
    <-0.8607946, 1.6773032, 34.0364059>,
    <-0.8650852, 1.6852354, 34.0484530>,
    <-0.8243308, 1.7039622, 34.0448606>,
    <-0.8427384, 1.6647449, 34.0264558>,
    <-0.8221254, 1.6863896, 34.0303723>,
    <-0.8268610, 1.6667761, 34.0246615>,
    <-0.7752716, 1.7052092, 34.0296825>,
    <-0.9270490, 1.6040380, 34.0228405>,
    <-0.9216356, 1.5900546, 34.0186848>,
    <-0.8787720, 1.6401914, 34.0246615>,
    <-0.8745521, 1.6294149, 34.0213137>,
    <-0.9351966, 1.6163222, 34.0277741>,
    <-0.8765639, 1.6561002, 34.0296825>,
    <-0.8233415, -1.6499698, 34.0204813>,
    <-0.7644603, -1.6881577, 34.0228405>,
    <-0.9427002, -1.6340314, 34.0361559>,
    <-0.9274800, -1.6050644, 34.0228405>,
    <-0.7966067, -1.6675664, 34.0215203>,
    <-0.8414176, -1.6668764, 34.0277741>,
    <-0.9333908, -1.6181934, 34.0277741>,
    <-0.8708907, -1.6304447, 34.0215203>,
    <-0.8631158, -1.6460657, 34.0248083>,
    <-0.7716162, -1.6526337, 34.0159774>,
    <-0.9188260, -1.5934640, 34.0186848>,
    <-0.8438606, -1.6189458, 34.0159774>,
    <-0.8023111, -1.6514597, 34.0185671>,
    <-0.8616336, -1.6227210, 34.0186456>,
    <-0.6993717, -1.6863215, 34.0159774>,
    <-0.6867358, -1.7059921, 34.0186848>,
    <-0.7444109, -1.6793686, 34.0186456>,
    <-0.7348901, -1.7159098, 34.0264558>,
    <-0.7973783, -1.7088535, 34.0364647>,
    <-0.7642620, -1.7139431, 34.0303723>,
    <-0.8602741, -1.6777861, 34.0364059>,
    <-0.7468947, -1.7050999, 34.0246615>,
    <-0.8089045, -1.6901692, 34.0296825>,
    <-0.6931619, -1.7277777, 34.0246615>,
    <-0.6881832, -1.7177278, 34.0213137>,
    <-0.7320530, -1.7376485, 34.0364059>,
    <-0.7061754, -1.7361969, 34.0296825>,
    <-0.7555136, 1.7529301, 34.1722608>,
    <-0.8074947, 1.7331137, 34.1809181>,
    <-0.7113514, 1.7732824, 34.1760819>,
    <-0.7426593, 1.7673013, 34.1920745>,
    <-0.7783461, 1.7445660, 34.1760819>,
    <-0.7191424, 1.7741586, 34.1852017>,
    <-0.9509600, 1.6479748, 34.1544411>,
    <-0.8032888, 1.7237237, 34.1544124>,
    <-0.8710395, 1.6969504, 34.1694828>,
    <-0.8685631, 1.6918895, 34.1544124>,
    <-0.7765502, 1.7403726, 34.1645454>,
    <-0.8299988, 1.7156668, 34.1656437>,
    <-0.7369333, 1.7532363, 34.1544124>,
    <-0.7162273, 1.7666880, 34.1656437>,
    <-0.8506623, 1.6945994, 34.1359011>,
    <-0.8284719, 1.7041582, 34.1317777>,
    <-0.8301133, 1.7075323, 34.1440880>,
    <-0.7766331, 1.7317879, 34.1429132>,
    <-0.9465105, 1.6401653, 34.1264018>,
    <-0.9483143, 1.6433432, 34.1387967>,
    <-0.8930874, 1.6715614, 34.1317777>,
    <-0.8885014, 1.6776624, 34.1429132>,
    <-0.9448400, 1.6372163, 34.1138015>,
    <-0.8855948, 1.6721624, 34.1216372>,
    <-0.8489609, -1.6894562, 34.1168394>,
    <-0.9471696, -1.6397848, 34.1264018>,
    <-0.9517080, -1.6475429, 34.1544411>,
    <-0.8004187, -1.7154455, 34.1264018>,
    <-0.8923366, -1.6685436, 34.1210460>,
    <-0.9490198, -1.6429359, 34.1387967>,
    <-0.8670712, -1.6869675, 34.1387967>,
    <-0.8278923, -1.7010883, 34.1210460>,
    <-0.8875767, -1.6741510, 34.1311462>,
    <-0.7330240, -1.7417484, 34.1138015>,
    <-0.8264011, -1.6981637, 34.1083733>,
    <-0.7735407, -1.7228945, 34.1095803>,
    <-0.9454509, -1.6368636, 34.1138015>,
    <-0.8847549, -1.6690309, 34.1095803>,
    <-0.7513433, -1.7409127, 34.1359011>,
    <-0.8041049, -1.7233432, 34.1544124>,
    <-0.7729295, -1.7300581, 34.1317777>,
    <-0.8693653, -1.6914822, 34.1544124>,
    <-0.7744591, -1.7334843, 34.1440880>,
    <-0.8274164, -1.7081073, 34.1429132>,
    <-0.7377609, -1.7528836, 34.1544124>,
    <-0.7064248, -1.7586036, 34.1317777>,
    <-0.7140463, -1.7590122, 34.1429132>,
    <-0.7117014, -1.7532502, 34.1216372>,
    <-0.7557400, 1.7530089, 34.1038334>,
    <-0.8072373, 1.7320875, 34.1125260>,
    <-0.7783659, 1.7441588, 34.1076575>,
    <-0.7418252, 1.7648144, 34.1237934>,
    <-0.7113741, 1.7728814, 34.1076575>,
    <-0.7186958, 1.7725692, 34.1168389>,
    <-0.8045271, 1.7259763, 34.0861074>,
    <-0.7380842, 1.7555340, 34.0861074>,
    <-0.7772006, 1.7414113, 34.0961373>,
    <-0.7167791, 1.7676122, 34.0972345>,
    <-0.9523847, 1.6501159, 34.0861253>,
    <-0.8698869, 1.6940941, 34.0861074>,
    <-0.8714600, 1.6973408, 34.1010718>,
    <-0.8306279, 1.7165443, 34.0972345>,
    <-0.8529396, 1.6987937, 34.0680823>,
    <-0.8319780, 1.7109783, 34.0759583>,
    <-0.8307966, 1.7086496, 34.0642124>,
    <-0.7784631, 1.7354194, 34.0748134>,
    <-0.9492905, 1.6447622, 34.0592183>,
    <-0.9470754, 1.6412289, 34.0484530>,
    <-0.8955837, 1.6759586, 34.0642124>,
    <-0.8879661, 1.6766061, 34.0551646>,
    <-0.9507531, 1.6472287, 34.0708032>,
    <-0.8905481, 1.6811767, 34.0748134>,
    <-0.8515026, -1.6943760, 34.0506060>,
    <-0.8026399, -1.7203621, 34.0592183>,
    <-0.9528499, -1.6498473, 34.0861253>,
    <-0.9497959, -1.6444945, 34.0592183>,
    <-0.8304313, -1.7063799, 34.0541438>,
    <-0.8689923, -1.6911329, 34.0708032>,
    <-0.9511653, -1.6469907, 34.0708032>,
    <-0.8950529, -1.6737434, 34.0541438>,
    <-0.8900157, -1.6791435, 34.0633523>,
    <-0.9479496, -1.6408207, 34.0484530>,
    <-0.8285729, -1.7019077, 34.0438443>,
    <-0.8870646, -1.6728009, 34.0448606>,
    <-0.7350451, -1.7459705, 34.0484530>,
    <-0.7756244, -1.7267955, 34.0448606>,
    <-0.7531014, -1.7453549, 34.0680823>,
    <-0.8050345, -1.7257397, 34.0861074>,
    <-0.7759002, -1.7371278, 34.0759583>,
    <-0.8703857, -1.6938408, 34.0861074>,
    <-0.7748958, -1.7347298, 34.0642124>,
    <-0.8290219, -1.7118433, 34.0748134>,
    <-0.7082087, -1.7633462, 34.0642124>,
    <-0.7136613, -1.7579387, 34.0551646>,
    <-0.7385989, -1.7553147, 34.0861074>,
    <-0.7154228, -1.7628390, 34.0748134>,
    <-0.7621186, 1.7681242, 34.1542153>,
    <-0.8144067, 1.7478059, 34.1620860>,
    <-0.7850893, 1.7595453, 34.1576891>,
    <-0.7488341, 1.7818367, 34.1722289>,
    <-0.7175157, 1.7885121, 34.1576891>,
    <-0.7252336, 1.7890345, 34.1659804>,
    <-0.8105831, 1.7392696, 34.1379890>,
    <-0.7436287, 1.7690502, 34.1379890>,
    <-0.7834567, 1.7557332, 34.1472010>,
    <-0.7225835, 1.7822431, 34.1481994>,
    <-0.9595859, 1.6628369, 34.1380150>,
    <-0.8764465, 1.7071465, 34.1379890>,
    <-0.8786978, 1.7117473, 34.1516897>,
    <-0.8373618, 1.7307670, 34.1481994>,
    <-0.8586492, 1.7104185, 34.1211611>,
    <-0.8377982, 1.7232447, 34.1286034>,
    <-0.8363060, 1.7201774, 34.1174128>,
    <-0.7838432, 1.7477561, 34.1275355>,
    <-0.9555259, 1.6557113, 34.1125260>,
    <-0.9540072, 1.6530303, 34.1010718>,
    <-0.9015260, 1.6872738, 34.1174128>,
    <-0.8940963, 1.6881306, 34.1081947>,
    <-0.9571657, 1.6586002, 34.1237934>,
    <-0.8967387, 1.6931306, 34.1275355>,
    <-0.8571025, -1.7057428, 34.1038334>,
    <-0.8079739, -1.7317440, 34.1125260>,
    <-0.9602660, -1.6624443, 34.1380150>,
    <-0.9561251, -1.6553653, 34.1125260>,
    <-0.8357792, -1.7173866, 34.1076575>,
    <-0.8750903, -1.7026720, 34.1237934>,
    <-0.9578070, -1.6582299, 34.1237934>,
    <-0.9008435, -1.6845304, 34.1076575>,
    <-0.8958980, -1.6899385, 34.1168389>,
    <-0.9545626, -1.6527097, 34.1010718>,
    <-0.8344235, -1.7147278, 34.0961373>,
    <-0.8933328, -1.6852839, 34.0972345>,
    <-0.7400748, -1.7586068, 34.1010718>,
    <-0.7810319, -1.7396713, 34.0972345>,
    <-0.7583275, -1.7571993, 34.1211611>,
    <-0.8113250, -1.7389236, 34.1379890>,
    <-0.7815557, -1.7494710, 34.1286034>,
    <-0.8771758, -1.7067763, 34.1379890>,
    <-0.7801652, -1.7463563, 34.1174128>,
    <-0.8350142, -1.7238947, 34.1275355>,
    <-0.7130370, -1.7751677, 34.1174128>,
    <-0.7184691, -1.7700269, 34.1081947>,
    <-0.7443811, -1.7687296, 34.1379890>,
    <-0.7206008, -1.7752651, 34.1275355>,
    <-0.7647378, 1.7746351, 34.2216509>,
    <-0.8176913, 1.7553144, 34.2291393>,
    <-0.7201675, 1.7955663, 34.2249699>,
    <-0.7524329, 1.7908838, 34.2387176>,
    <-0.7879956, 1.7664977, 34.2249699>,
    <-0.7283699, 1.7972423, 34.2328318>,
    <-0.9617644, 1.6669352, 34.2060335>,
    <-0.8123885, 1.7435422, 34.2059966>,
    <-0.8815607, 1.7177432, 34.2192172>,
    <-0.8784137, 1.7113465, 34.2059966>,
    <-0.7857403, 1.7612606, 34.2149211>,
    <-0.8398672, 1.7363588, 34.2158771>,
    <-0.7452701, 1.7733897, 34.2059966>,
    <-0.7247366, 1.7879810, 34.2158771>,
    <-0.8594967, 1.7124991, 34.1894897>,
    <-0.8368904, 1.7217996, 34.1857817>,
    <-0.8390841, 1.7262770, 34.1968260>,
    <-0.7849611, 1.7506955, 34.1957715>,
    <-0.9558978, 1.6566965, 34.1809181>,
    <-0.9583266, 1.6609512, 34.1920745>,
    <-0.9021841, 1.6888665, 34.1857817>,
    <-0.8980642, 1.6959817, 34.1957715>,
    <-0.9535898, 1.6526482, 34.1694828>,
    <-0.8941386, 1.6886032, 34.1766071>,
    <-0.8571876, -1.7055187, 34.1722608>,
    <-0.9567923, -1.6561800, 34.1809181>,
    <-0.9627261, -1.6663800, 34.2060335>,
    <-0.8085945, -1.7326008, 34.1809181>,
    <-0.9011652, -1.6847708, 34.1760819>,
    <-0.9592626, -1.6604108, 34.1920745>,
    <-0.8764592, -1.7049094, 34.1920745>,
    <-0.8361039, -1.7176331, 34.1760819>,
    <-0.8968285, -1.6913022, 34.1852017>,
    <-0.7400460, -1.7580337, 34.1694828>,
    <-0.8340460, -1.7135619, 34.1645454>,
    <-0.7807641, -1.7386254, 34.1656437>,
    <-0.9544404, -1.6521571, 34.1694828>,
    <-0.8929795, -1.6842671, 34.1656437>,
    <-0.7593766, -1.7591859, 34.1894897>,
    <-0.8134376, -1.7430530, 34.2059966>,
    <-0.7810322, -1.7478467, 34.1857817>,
    <-0.8794449, -1.7108229, 34.2059966>,
    <-0.7830520, -1.7524052, 34.1968260>,
    <-0.8365472, -1.7266405, 34.1957715>,
    <-0.7463341, -1.7729363, 34.2059966>,
    <-0.7138340, -1.7766956, 34.1857817>,
    <-0.7219328, -1.7781131, 34.1957715>,
    <-0.7188039, -1.7703631, 34.1766071>,
    <-0.7705043, 1.7878560, 34.1991181>,
    <-0.8236763, 1.7679884, 34.2059260>,
    <-0.7938616, 1.7794832, 34.2021355>,
    <-0.7577193, 1.8032753, 34.2146338>,
    <-0.7255303, 1.8087701, 34.2021355>,
    <-0.7336222, 1.8100197, 34.2092829>,
    <-0.8188555, 1.7572864, 34.1848862>,
    <-0.7512076, 1.7873715, 34.1848862>,
    <-0.7918113, 1.7747222, 34.1929998>,
    <-0.7303192, 1.8016003, 34.1938690>,
    <-0.9694081, 1.6800736, 34.1849198>,
    <-0.8854016, 1.7248347, 34.1848862>,
    <-0.8882625, 1.7306498, 34.1969055>,
    <-0.8463331, 1.7495779, 34.1938690>,
    <-0.8666805, 1.7266909, 34.1698789>,
    <-0.8459535, 1.7402853, 34.1765488>,
    <-0.8439592, 1.7362150, 34.1665078>,
    <-0.7914141, 1.7649448, 34.1755900>,
    <-0.9640597, 1.6707395, 34.1620860>,
    <-0.9619616, 1.6670593, 34.1516897>,
    <-0.9097957, 1.7030057, 34.1665078>,
    <-0.9018634, 1.7030768, 34.1581668>,
    <-0.9662678, 1.6746075, 34.1722289>,
    <-0.9054321, 1.7097845, 34.1755900>,
    <-0.8645812, -1.7203451, 34.1542153>,
    <-0.8154064, -1.7473397, 34.1620860>,
    <-0.9702824, -1.6795689, 34.1849198>,
    <-0.9648730, -1.6702700, 34.1620860>,
    <-0.8432442, -1.7324272, 34.1576891>,
    <-0.8836247, -1.7189827, 34.1722289>,
    <-0.9671187, -1.6741162, 34.1722289>,
    <-0.9088695, -1.6992823, 34.1576891>,
    <-0.9043087, -1.7055304, 34.1659804>,
    <-0.9627348, -1.6666129, 34.1516897>,
    <-0.8413734, -1.7287262, 34.1472010>,
    <-0.9008097, -1.6991349, 34.1481994>,
    <-0.7464584, -1.7734115, 34.1516897>,
    <-0.7875986, -1.7539720, 34.1481994>,
    <-0.7656304, -1.7738112, 34.1698789>,
    <-0.8198093, -1.7568417, 34.1848862>,
    <-0.7893674, -1.7666718, 34.1765488>,
    <-0.8863390, -1.7243587, 34.1848862>,
    <-0.7875312, -1.7625277, 34.1665078>,
    <-0.8433149, -1.7407430, 34.1755900>,
    <-0.7197726, -1.7916149, 34.1665078>,
    <-0.7249259, -1.7855841, 34.1581668>,
    <-0.7521748, -1.7869593, 34.1848862>,
    <-0.7277703, -1.7926295, 34.1755900>,
    <-0.7757093, 1.8008755, 34.2635082>,
    <-0.8292764, 1.7821326, 34.2695801>,
    <-0.7303710, 1.8225254, 34.2662252>,
    <-0.7615264, 1.8201331, 34.2772285>,
    <-0.7992008, 1.7930316, 34.2662252>,
    <-0.7377330, 1.8256453, 34.2725930>,
    <-0.9751235, 1.6902869, 34.2505667>,
    <-0.8236496, 1.7679544, 34.2505227>,
    <-0.8943218, 1.7428497, 34.2614925>,
    <-0.8905998, 1.7353116, 34.2505227>,
    <-0.7969594, 1.7866479, 34.2579678>,
    <-0.8518966, 1.7614689, 34.2587527>,
    <-0.7555913, 1.7982162, 34.2505227>,
    <-0.7351117, 1.8138259, 34.2587527>,
    <-0.8707321, 1.7351420, 34.2365221>,
    <-0.8476715, 1.7442589, 34.2333423>,
    <-0.8503508, 1.7497036, 34.2427845>,
    <-0.7954459, 1.7743655, 34.2418824>,
    <-0.9680130, 1.6779211, 34.2291393>,
    <-0.9709931, 1.6831236, 34.2387176>,
    <-0.9138249, 1.7108972, 34.2333423>,
    <-0.9100896, 1.7189142, 34.2418824>,
    <-0.9651378, 1.6728967, 34.2192172>,
    <-0.9052643, 1.7098814, 34.2254131>,
    <-0.8678854, -1.7265366, 34.2216509>,
    <-0.9691158, -1.6772844, 34.2291393>,
    <-0.9762696, -1.6896252, 34.2505667>,
    <-0.8190470, -1.7546822, 34.2291393>,
    <-0.9125688, -1.7058480, 34.2249699>,
    <-0.9721312, -1.6824665, 34.2387176>,
    <-0.8882420, -1.7275550, 34.2387176>,
    <-0.8467019, -1.7391225, 34.2249699>,
    <-0.9085803, -1.7132088, 34.2328318>,
    <-0.7492113, -1.7794587, 34.2192172>,
    <-0.8441398, -1.7340285, 34.2149211>,
    <-0.7902718, -1.7594855, 34.2158771>,
    <-0.9662021, -1.6722822, 34.2192172>,
    <-0.9038212, -1.7044724, 34.2158771>,
    <-0.7695000, -1.7823473, 34.2365221>,
    <-0.8248999, -1.7673714, 34.2505227>,
    <-0.7913071, -1.7705421, 34.2333423>,
    <-0.8918287, -1.7346876, 34.2505227>,
    <-0.7937557, -1.7760943, 34.2427845>,
    <-0.8479400, -1.7498871, 34.2418824>,
    <-0.7568593, -1.7976758, 34.2505227>,
    <-0.7232280, -1.7997740, 34.2333423>,
    <-0.7317703, -1.8020658, 34.2418824>,
    <-0.7279525, -1.7925633, 34.2254131>,
    <-0.7806420, 1.8116050, 34.2371711>,
    <-0.8347644, 1.7920219, 34.2427102>,
    <-0.8044163, 1.8033667, 34.2396408>,
    <-0.7682107, 1.8284790, 34.2497196>,
    <-0.7351744, 1.8330401, 34.2396408>,
    <-0.7436067, 1.8348873, 34.2454279>,
    <-0.8290929, 1.7794793, 34.2253660>,
    <-0.7605906, 1.8099411, 34.2253660>,
    <-0.8020106, 1.7978016, 34.2321345>,
    <-0.7397512, 1.8250957, 34.2328481>,
    <-0.9815528, 1.7013025, 34.2254060>,
    <-0.8964799, 1.7466212, 34.2253660>,
    <-0.8998635, 1.7534739, 34.2353389>,
    <-0.8572689, 1.7724053, 34.2328481>,
    <-0.8768945, 1.7472753, 34.2126378>,
    <-0.8561960, 1.7615822, 34.2183311>,
    <-0.8537603, 1.7566325, 34.2097470>,
    <-0.8009458, 1.7864630, 34.2175110>,
    <-0.9750736, 1.6900347, 34.2059260>,
    <-0.9724598, 1.6854670, 34.1969055>,
    <-0.9203783, 1.7230336, 34.2097470>,
    <-0.9119776, 1.7224206, 34.2025384>,
    <-0.9777828, 1.6947642, 34.2146338>,
    <-0.9163643, 1.7306322, 34.2175110>,
    <-0.8743066, -1.7394522, 34.1991181>,
    <-0.8249088, -1.7674137, 34.2059260>,
    <-0.9825947, -1.7007009, 34.2254060>,
    <-0.9760762, -1.6894559, 34.2059260>,
    <-0.8528788, -1.7519630, 34.2021355>,
    <-0.8943364, -1.7395697, 34.2146338>,
    <-0.9788174, -1.6941668, 34.2146338>,
    <-0.9192364, -1.7184435, 34.2021355>,
    <-0.9149922, -1.7254455, 34.2092829>,
    <-0.9734273, -1.6849084, 34.1969055>,
    <-0.8505496, -1.7473321, 34.1929998>,
    <-0.9106658, -1.7175034, 34.1938690>,
    <-0.7547905, -1.7928888, 34.1969055>,
    <-0.7962420, -1.7729357, 34.1938690>,
    <-0.7748336, -1.7948671, 34.2126378>,
    <-0.8302296, -1.7789493, 34.2253660>,
    <-0.7990981, -1.7882074, 34.2183311>,
    <-0.8975971, -1.7460539, 34.2253660>,
    <-0.7968721, -1.7831600, 34.2097470>,
    <-0.8536720, -1.7618764, 34.2175110>,
    <-0.7283126, -1.8125954, 34.2097470>,
    <-0.7332428, -1.8057661, 34.2025384>,
    <-0.7617433, -1.8094498, 34.2253660>,
    <-0.7367135, -1.8144048, 34.2175110>,
    <-0.7802538, 1.8343902, 34.2933120>,
    <-0.7985466, 1.8330978, 34.2967794>,
    <-0.7446082, 1.8528366, 34.2949171>,
    <-0.7328185, 1.8713859, 34.3007507>,
    <-0.7895686, 1.8332952, 34.2949171>,
    <-0.7401125, 1.8615955, 34.2980246>,
    <-0.9815973, 1.7248496, 34.2867877>,
    <-0.8346471, 1.7968978, 34.2854038>,
    <-0.8723036, 1.7901752, 34.2926777>,
    <-0.8985377, 1.7664396, 34.2856693>,
    <-0.8058427, 1.8170253, 34.2900253>,
    <-0.8482633, 1.7984185, 34.2908029>,
    <-0.7660671, 1.8279499, 34.2856693>,
    <-0.7494181, 1.8431023, 34.2908029>,
    <-0.8216967, 1.8280382, 34.2989756>,
    <-0.7543209, 1.8695844, 34.3035582>,
    <-0.8136256, 1.8291946, 34.2980080>,
    <-0.7223023, 1.8830616, 34.3035582>,
    <-0.7947220, 1.8448621, 34.3008727>,
    <-0.7651040, 1.8575427, 34.3007914>,
    <-0.8917435, 1.7926052, 34.2975521>,
    <-0.7863395, 1.8561071, 34.3035582>,
    <-0.8567635, 1.8168490, 34.3007100>,
    <-0.8563717, 1.8100790, 34.2980080>,
    <-0.8249158, 1.8314684, 34.3007914>,
    <-0.9277105, 1.7663266, 34.2937748>,
    <-0.8735870, 1.7951883, 34.2951914>,
    <-0.8836443, 1.7619695, 34.2753407>,
    <-0.8600654, 1.7710683, 34.2729301>,
    <-0.8627097, 1.7773913, 34.2800513>,
    <-0.8060797, 1.8029366, 34.2795037>,
    <-0.9819552, 1.7036552, 34.2695801>,
    <-0.9837971, 1.7110294, 34.2772285>,
    <-0.9272862, 1.7372517, 34.2729301>,
    <-0.9227331, 1.7468327, 34.2795037>,
    <-0.9791330, 1.6973465, 34.2614925>,
    <-0.9186337, 1.7353506, 34.2665723>,
    <-0.8809179, -1.7517998, 34.2635082>,
    <-0.9843962, -1.7022091, 34.2695801>,
    <-1.0024187, -1.7122302, 34.2867877>,
    <-0.8320887, -1.7807668, 34.2695801>,
    <-0.9266250, -1.7309744, 34.2662252>,
    <-0.9897566, -1.7074415, 34.2772285>,
    <-0.9045812, -1.7532080, 34.2772285>,
    <-0.8597886, -1.7647428, 34.2662252>,
    <-0.9241718, -1.7385624, 34.2725930>,
    <-0.7602413, -1.8053724, 34.2614925>,
    <-0.8563760, -1.7589415, 34.2579678>,
    <-0.8017749, -1.7848411, 34.2587527>,
    <-0.9803787, -1.6966273, 34.2614925>,
    <-0.9169505, -1.7290331, 34.2587527>,
    <-0.7817240, -1.8094651, 34.2753407>,
    <-0.8398526, -1.7943002, 34.2854038>,
    <-0.8038407, -1.7972501, 34.2729301>,
    <-0.9075044, -1.7616245, 34.2856693>,
    <-0.8069602, -1.8033189, 34.2800513>,
    <-0.8628436, -1.7763221, 34.2795037>,
    <-0.7753697, -1.8235653, 34.2856693>,
    <-0.7347394, -1.8270053, 34.2729301>,
    <-0.7449321, -1.8296128, 34.2795037>,
    <-0.7388693, -1.8191762, 34.2665723>,
    <-0.7924511, 1.8386437, 34.2672347>,
    <-0.8483750, 1.8189960, 34.2713545>,
    <-0.8169439, 1.8304570, 34.2690979>,
    <-0.7841531, 1.8559615, 34.2765462>,
    <-0.7466661, 1.8605715, 34.2690979>,
    <-0.7569287, 1.8628295, 34.2734378>,
    <-0.8409843, 1.8051741, 34.2582019>,
    <-0.7714926, 1.8360732, 34.2582019>,
    <-0.8137446, 1.8242699, 34.2634197>,
    <-0.7505929, 1.8520154, 34.2639559>,
    <-0.9956511, 1.7258783, 34.2582471>,
    <-0.9093448, 1.7718440, 34.2582019>,
    <-0.9131484, 1.7795262, 34.2658251>,
    <-0.8698371, 1.7985557, 34.2639559>,
    <-0.8889809, 1.7715464, 34.2481381>,
    <-0.8682146, 1.7864884, 34.2526827>,
    <-0.8654114, 1.7808098, 34.2458152>,
    <-0.8121485, 1.8116570, 34.2520259>,
    <-0.9882328, 1.7130105, 34.2427102>,
    <-0.9851827, 1.7076942, 34.2353389>,
    <-0.9329520, 1.7467492, 34.2458152>,
    <-0.9241317, 1.7455745, 34.2399571>,
    <-0.9913608, 1.7184578, 34.2497196>,
    <-0.9292031, 1.7550404, 34.2520259>,
    <-0.8859829, -1.7624837, 34.2371711>,
    <-0.8361922, -1.7913561, 34.2427102>,
    <-0.9968289, -1.7251982, 34.2582471>,
    <-0.9893942, -1.7123400, 34.2427102>,
    <-0.8643902, -1.7754004, 34.2396408>,
    <-0.9068999, -1.7638072, 34.2497196>,
    <-0.9925477, -1.7177725, 34.2497196>,
    <-0.9316292, -1.7414317, 34.2396408>,
    <-0.9276240, -1.7490786, 34.2454279>,
    <-0.9863152, -1.7070403, 34.2353389>,
    <-0.8616734, -1.7699803, 34.2321345>,
    <-0.9226015, -1.7398312, 34.2328481>,
    <-0.7648178, -1.8164468, 34.2353389>,
    <-0.8066994, -1.7959863, 34.2328481>,
    <-0.7856574, -1.8197270, 34.2481381>,
    <-0.8422693, -1.8045749, 34.2582019>,
    <-0.8104520, -1.8134236, 34.2526827>,
    <-0.9106078, -1.7712027, 34.2582019>,
    <-0.8079038, -1.8076260, 34.2458152>,
    <-0.8657708, -1.7866525, 34.2520259>,
    <-0.7383975, -1.8374715, 34.2458152>,
    <-0.7431672, -1.8299596, 34.2399571>,
    <-0.7727957, -1.8355179, 34.2582019>,
    <-0.7471588, -1.8399291, 34.2520259>,
    <-0.9404502, 1.7712758, 34.2989756>,
    <-0.9137471, 1.7952395, 34.3035582>,
    <-0.9208325, 1.7795000, 34.2980080>,
    <-0.8660526, 1.8189347, 34.3035582>,
    <-0.9289318, 1.7817573, 34.3008727>,
    <-0.8913434, 1.8004914, 34.3007914>,
    <-1.0120833, 1.7260242, 34.2967794>,
    <-0.9614417, 1.7715444, 34.3035582>,
    <-1.0108597, 1.7373484, 34.3007507>,
    <-0.9712154, 1.7525913, 34.2980080>,
    <-0.9698053, 1.7600083, 34.3007914>,
    <-1.0046031, 1.7219126, 34.2926777>,
    <-0.9587186, 1.7534125, 34.2951914>,
    <-0.9030412, -1.7763877, 34.2933120>,
    <-0.9872420, -1.7386072, 34.2967794>,
    <-0.8896004, -1.7888750, 34.2967794>,
    <-0.9397307, -1.7607725, 34.2949171>,
    <-0.9980003, -1.7433774, 34.3007507>,
    <-0.9614569, -1.7634027, 34.3007507>,
    <-0.8961754, -1.7827145, 34.2949171>,
    <-0.9494020, -1.7629291, 34.2980246>,
    <-0.8095007, -1.8179403, 34.2926777>,
    <-0.8736430, -1.7850724, 34.2900253>,
    <-0.8319744, -1.8054296, 34.2908029>,
    <-0.9876462, -1.7302294, 34.2926777>,
    <-0.9294491, -1.7583894, 34.2908029>,
    <-0.8683407, -1.8014865, 34.2989756>,
    <-0.9410533, -1.7755112, 34.3035582>,
    <-0.8757449, -1.7969004, 34.2980080>,
    <-0.9754778, -1.7613675, 34.3035582>,
    <-0.8975626, -1.7911353, 34.3008727>,
    <-0.9285312, -1.7778506, 34.3007914>,
    <-0.9050772, -1.7909238, 34.3035582>,
    <-0.8316944, -1.8163509, 34.2980080>,
    <-0.8651305, -1.8052335, 34.3007914>,
    <-0.8112792, -1.8210836, 34.2951914>,
    <-0.9377858, 1.8100035, 34.2894179>,
    <-0.9828274, 1.7868977, 34.2886794>,
    <-0.9673041, 1.8022561, 34.2918022>,
    <-0.9125494, 1.8277886, 34.2918021>,
    <-0.9611059, 1.7977714, 34.2889155>,
    <-0.9744903, 1.7952175, 34.2903196>,
    <-0.9421554, 1.8139832, 34.2918022>,
    <-0.9286506, 1.8168036, 34.2904043>,
    <-0.9538317, 1.8049561, 34.2903620>,
    <-0.8985199, 1.8252944, 34.2882666>,
    <-0.8797504, 1.8430829, 34.2918019>,
    <-0.8647825, 1.8464275, 34.2903405>,
    <-0.9232622, 1.8154182, 34.2889155>,
    <-0.8985947, 1.8307134, 34.2903618>,
    <-1.0222697, 1.7504792, 34.2830970>,
    <-0.9437196, 1.7981283, 34.2861106>,
    <-0.9934663, 1.7760155, 34.2867239>,
    <-0.9595760, 1.7942712, 34.2874565>,
    <-0.8549453, 1.8415090, 34.2863580>,
    <-0.8740961, 1.8344384, 34.2872643>,
    <-0.8306080, 1.8548037, 34.2872641>,
    <-0.8490789, 1.8502207, 34.2889215>,
    <-0.8721181, 1.8240027, 34.2817251>,
    <-0.8033012, 1.8561668, 34.2819690>,
    <-0.8605064, 1.8348171, 34.2845089>,
    <-0.8092410, 1.8594203, 34.2850029>,
    <-0.9376823, 1.7924622, 34.2819691>,
    <-0.9080145, 1.8130150, 34.2850030>,
    <-0.9059458, 1.7970029, 34.2751874>,
    <-0.8892338, 1.8102786, 34.2783022>,
    <-0.8801659, 1.8073568, 34.2735942>,
    <-0.8311119, 1.8371399, 34.2779937>,
    <-1.0041634, 1.7386559, 34.2713545>,
    <-0.9997437, 1.7330654, 34.2658251>,
    <-0.9487324, 1.7726878, 34.2735942>,
    <-0.9379563, 1.7718348, 34.2692880>,
    <-1.0106927, 1.7437164, 34.2765463>,
    <-0.9499480, 1.7792918, 34.2779937>,
    <-0.9521647, -1.8033440, 34.2894147>,
    <-0.9120219, -1.8191518, 34.2882644>,
    <-0.9332514, -1.8181351, 34.2917976>,
    <-0.9377518, -1.8087639, 34.2889127>,
    <-0.8860373, -1.8365165, 34.2903378>,
    <-0.9033488, -1.8320789, 34.2917981>,
    <-0.9459356, -1.8087434, 34.2904005>,
    <-0.9183636, -1.8214951, 34.2903586>,
    <-0.9792769, -1.7966730, 34.2917974>,
    <-0.9893742, -1.7839848, 34.2886767>,
    <-0.9586259, -1.8063028, 34.2917973>,
    <-0.9845126, -1.7905440, 34.2903158>,
    <-0.9716426, -1.7929603, 34.2889125>,
    <-0.9675871, -1.7985418, 34.2903580>,
    <-1.0020187, -1.7622139, 34.2830965>,
    <-0.9934875, -1.7765654, 34.2867222>,
    <-0.9447561, -1.7982588, 34.2861091>,
    <-0.9658868, -1.7917377, 34.2874544>,
    <-0.8990499, -1.7889428, 34.2672347>,
    <-0.8479205, -1.8192314, 34.2713544>,
    <-1.0034522, -1.7390693, 34.2713544>,
    <-0.8769659, -1.8024840, 34.2690979>,
    <-0.9169600, -1.7941267, 34.2765461>,
    <-1.0040113, -1.7475853, 34.2765461>,
    <-0.9452086, -1.7680053, 34.2690979>,
    <-0.9399691, -1.7775391, 34.2734378>,
    <-1.0010068, -1.7323362, 34.2658251>,
    <-0.8744069, -1.7959826, 34.2634197>,
    <-0.9362543, -1.7654401, 34.2639559>,
    <-0.7762357, -1.8433696, 34.2658251>,
    <-0.8186531, -1.8224232, 34.2639559>,
    <-0.8591468, -1.8395515, 34.2863567>,
    <-0.8403725, -1.8501519, 34.2872628>,
    <-0.8843266, -1.8297702, 34.2872627>,
    <-0.8667719, -1.8419705, 34.2889196>,
    <-0.8361415, -1.8407842, 34.2817246>,
    <-0.9045478, -1.8090488, 34.2819686>,
    <-0.8515691, -1.8389883, 34.2845081>,
    <-0.9026867, -1.8159086, 34.2850020>,
    <-0.7692258, -1.8709424, 34.2819686>,
    <-0.8032933, -1.8617990, 34.2850021>,
    <-0.7941381, -1.8491413, 34.2751874>,
    <-0.8149061, -1.8449418, 34.2783020>,
    <-0.8186317, -1.8360663, 34.2735942>,
    <-0.8726056, -1.8178537, 34.2779935>,
    <-0.7479892, -1.8662839, 34.2735942>,
    <-0.7543975, -1.8574297, 34.2692880>,
    <-0.7518615, -1.8716127, 34.2779935>,
    <-1.0109502, -1.7751465, 34.2894157>,
    <-1.0070526, -1.7837211, 34.2917992>,
    <-1.0026968, -1.7781850, 34.2889131>,
    <-0.9950093, -1.7893369, 34.2917981>,
    <-1.0093425, -1.7788818, 34.2904018>,
    <-0.9979066, -1.7844036, 34.2903587>,
    <-1.0359059, -1.7578101, 34.2886783>,
    <-1.0166365, -1.7792520, 34.2918006>,
    <-1.0359581, -1.7628241, 34.2903187>,
    <-1.0199919, -1.7686476, 34.2889139>,
    <-1.0203935, -1.7727398, 34.2903604>,
    <-1.0297849, -1.7556736, 34.2867229>,
    <-1.0112729, -1.7693957, 34.2874549>,
    <-1.0066848, 1.7772344, 34.2894179>,
    <-1.0018677, 1.7861388, 34.2918022>,
    <-1.0047050, 1.7810985, 34.2904043>,
    <-0.9867315, 1.7931970, 34.2918022>,
    <-0.9980732, 1.7802929, 34.2889155>,
    <-0.9909785, 1.7876343, 34.2903620>,
    <-1.0325775, 1.7600207, 34.2886794>,
    <-1.0311144, 1.7551254, 34.2867239>,
    <-1.0169928, 1.7702686, 34.2889155>,
    <-1.0108636, 1.7693939, 34.2874565>,
    <-1.0320388, 1.7653374, 34.2903196>,
    <-1.0141432, 1.7804147, 34.2918022>,
    <-1.0170788, 1.7745020, 34.2903620>,
    <-1.0741363, 1.7341193, 34.2894179>,
    <-1.1147736, 1.7026178, 34.2882666>,
    <-1.1550444, 1.6842936, 34.2918022>,
    <-1.0906168, 1.7294053, 34.2918022>,
    <-1.0897042, 1.7219020, 34.2889155>,
    <-1.1402854, 1.6906063, 34.2903408>,
    <-1.1230558, 1.7066918, 34.2918022>,
    <-1.0797340, 1.7330996, 34.2904043>,
    <-1.1088676, 1.7126632, 34.2903620>,
    <-1.0578777, 1.7523288, 34.2918022>,
    <-1.0531140, 1.7471258, 34.2889155>,
    <-1.0535242, 1.7510971, 34.2903620>,
    <-1.0811108, 1.7198236, 34.2861106>,
    <-1.0605906, 1.7376754, 34.2874565>,
    <-1.0594705, -1.6978351, 34.2989756>,
    <-1.1013895, -1.6664720, 34.2975521>,
    <-1.1677904, -1.6304987, 34.3035582>,
    <-1.0909922, -1.6860466, 34.3035582>,
    <-1.0758217, -1.6849587, 34.2980080>,
    <-1.1355597, -1.6483375, 34.3007100>,
    <-1.1303415, -1.6570982, 34.3035582>,
    <-1.0732176, -1.6927669, 34.3008727>,
    <-1.1054964, -1.6697181, 34.3007914>,
    <-1.0503760, -1.7165609, 34.3035582>,
    <-1.0293481, -1.7157214, 34.2980080>,
    <-1.0363314, -1.7181134, 34.3007914>,
    <-1.0633400, -1.6851980, 34.2937748>,
    <-1.0364877, -1.7054408, 34.2951914>,
    <-1.0842604, -1.7270306, 34.2894166>,
    <-1.1046453, -1.7195828, 34.2918006>,
    <-1.1768190, -1.6690470, 34.2917990>,
    <-1.1258473, -1.6947048, 34.2882651>,
    <-1.0916868, -1.7247487, 34.2904030>,
    <-1.1421349, -1.6933328, 34.2917998>,
    <-1.1588173, -1.6776303, 34.2903384>,
    <-1.1007522, -1.7140753, 34.2889141>,
    <-1.1245792, -1.7016621, 34.2903601>,
    <-1.0807836, -1.7194157, 34.2861096>,
    <-1.0596210, -1.7425699, 34.2889145>,
    <-1.0643827, -1.7346563, 34.2874555>,
    <-1.0652856, -1.7471422, 34.2918014>,
    <-1.0609345, -1.7459816, 34.2903610>,
    <-1.0075133, 1.5198468, 34.0221521>,
    <-1.0692344, 1.4886899, 34.0252783>,
    <-0.9671925, 1.5511177, 34.0235337>,
    <-1.0127037, 1.5447941, 34.0315713>,
    <-1.0357582, 1.5058257, 34.0235337>,
    <-0.9842628, 1.5526822, 34.0277883>,
    <-1.0357136, 1.4759134, 34.0159774>,
    <-1.1232310, 1.4301489, 34.0197144>,
    <-1.1003241, 1.4306723, 34.0159774>,
    <-1.0193265, 1.5021856, 34.0195520>,
    <-1.0718836, 1.4663930, 34.0196603>,
    <-0.9711031, 1.5211545, 34.0159774>,
    <-0.9653427, 1.5388195, 34.0196603>,
    <-1.0310485, 1.5684387, 34.0581798>,
    <-1.0775753, 1.5395917, 34.0677166>,
    <-0.9918260, 1.5956512, 34.0621232>,
    <-1.0197825, 1.5822339, 34.0805061>,
    <-1.0517862, 1.5564087, 34.0621232>,
    <-0.9990207, 1.5941986, 34.0723106>,
    <-1.2006911, 1.4294405, 34.0418026>,
    <-1.0702512, 1.5286628, 34.0421478>,
    <-1.1329119, 1.4940600, 34.0557354>,
    <-1.1272619, 1.4869097, 34.0420666>,
    <-1.0488294, 1.5523109, 34.0506039>,
    <-1.0963707, 1.5192682, 34.0517365>,
    <-1.0125035, 1.5671843, 34.0420666>,
    <-0.9949386, 1.5880681, 34.0517365>,
    <-1.1074529, 1.4776769, 34.0300324>,
    <-1.0923239, 1.4823721, 34.0277479>,
    <-1.0910969, 1.5023447, 34.0349278>,
    <-1.0486654, 1.5287345, 34.0340297>,
    <-1.1791819, 1.4040104, 34.0252783>,
    <-1.1892492, 1.4146129, 34.0315713>,
    <-1.1383459, 1.4475438, 34.0277479>,
    <-1.1389470, 1.4634659, 34.0340297>,
    <-1.1715021, 1.3912980, 34.0197144>,
    <-1.1323783, 1.4377503, 34.0233431>,
    <-1.0857544, -1.4666107, 34.0221521>,
    <-1.1795735, -1.4049569, 34.0252783>,
    <-1.1996241, -1.4306422, 34.0418026>,
    <-1.0349852, -1.5139464, 34.0252783>,
    <-1.1287588, -1.4394136, 34.0235337>,
    <-1.1876865, -1.4167525, 34.0315713>,
    <-1.1064191, -1.4800022, 34.0315713>,
    <-1.0627471, -1.4883536, 34.0235337>,
    <-1.1239326, -1.4559812, 34.0277883>,
    <-1.0357015, -1.4781003, 34.0159774>,
    <-0.9622190, -1.5446776, 34.0197144>,
    <-0.9710903, -1.5233411, 34.0159774>,
    <-1.0654729, -1.4716775, 34.0195520>,
    <-1.0138473, -1.5088231, 34.0196603>,
    <-1.1003128, -1.4328595, 34.0159774>,
    <-1.1690527, -1.3951403, 34.0197144>,
    <-1.1183456, -1.4334785, 34.0196603>,
    <-1.0110071, -1.5460830, 34.0300324>,
    <-1.0708480, -1.5285484, 34.0421478>,
    <-1.0208165, -1.5334764, 34.0277479>,
    <-1.1268091, -1.4874587, 34.0420666>,
    <-1.0393597, -1.5391425, 34.0349278>,
    <-1.0787704, -1.5082977, 34.0340297>,
    <-1.0121262, -1.5678407, 34.0420666>,
    <-0.9723485, -1.5648109, 34.0277479>,
    <-0.9865602, -1.5708114, 34.0340297>,
    <-0.9657048, -1.5558632, 34.0233431>,
    <-1.0386316, 1.5799498, 34.1168394>,
    <-1.0854101, 1.5509057, 34.1264018>,
    <-0.9988329, 1.6070580, 34.1210460>,
    <-1.0274211, 1.5943895, 34.1387967>,
    <-1.0592395, 1.5675199, 34.1210460>,
    <-1.0060690, 1.6057395, 34.1311462>,
    <-1.2124497, 1.4454009, 34.0973598>,
    <-1.0813069, 1.5448031, 34.0973402>,
    <-1.1418864, 1.5056916, 34.1138015>,
    <-1.1395620, 1.5024749, 34.0973402>,
    <-1.0574523, 1.5647662, 34.1083733>,
    <-1.1053001, 1.5313531, 34.1095803>,
    <-1.0215958, 1.5850506, 34.0973402>,
    <-1.0030458, 1.6007357, 34.1095803>,
    <-1.1236124, 1.5096523, 34.0775018>,
    <-1.1036732, 1.5230058, 34.0732308>,
    <-1.1053638, 1.5252670, 34.0861763>,
    <-1.0573714, 1.5582806, 34.0849170>,
    <-1.2081593, 1.4402820, 34.0677166>,
    <-1.2101520, 1.4426103, 34.0805061>,
    <-1.1612184, 1.4799968, 34.0732308>,
    <-1.1573365, 1.4861212, 34.0849170>,
    <-1.2052732, 1.4370703, 34.0557354>,
    <-1.1538023, 1.4818063, 34.0632019>,
    <-1.1212905, -1.5053077, 34.0581798>,
    <-1.2086375, -1.4399048, 34.0677166>,
    <-1.2129023, -1.4450211, 34.0973598>,
    <-1.0782241, -1.5391615, 34.0677166>,
    <-1.1602393, -1.4777572, 34.0621232>,
    <-1.2105531, -1.4422737, 34.0805061>,
    <-1.1380274, -1.4994379, 34.0805061>,
    <-1.1028559, -1.5206796, 34.0621232>,
    <-1.1563715, -1.4840204, 34.0723106>,
    <-1.0166128, -1.5755900, 34.0557354>,
    <-1.1001533, -1.5165022, 34.0506039>,
    <-1.0528327, -1.5498749, 34.0517365>,
    <-1.2060697, -1.4364983, 34.0557354>,
    <-1.1521753, -1.4780909, 34.0517365>,
    <-1.0343192, -1.5721819, 34.0775018>,
    <-1.0818114, -1.5444498, 34.0973402>,
    <-1.0536973, -1.5580126, 34.0732308>,
    <-1.1400540, -1.5021053, 34.0973402>,
    <-1.0552255, -1.5603742, 34.0861763>,
    <-1.1026625, -1.5265674, 34.0849170>,
    <-1.0221115, -1.5847147, 34.0973402>,
    <-0.9936005, -1.5973773, 34.0732308>,
    <-1.0006648, -1.5958239, 34.0849170>,
    <-0.9978926, -1.5910284, 34.0632019>,
    <-1.0181721, 1.5359348, 34.0204813>,
    <-1.0805212, 1.5044041, 34.0228405>,
    <-1.0467053, 1.5217454, 34.0215203>,
    <-1.0233446, 1.5610121, 34.0277741>,
    <-0.9774142, 1.5675170, 34.0215203>,
    <-0.9946333, 1.5690368, 34.0248083>,
    <-1.0467185, 1.4916239, 34.0159774>,
    <-0.9814207, 1.5373464, 34.0159774>,
    <-1.0301303, 1.5181235, 34.0185671>,
    <-0.9755730, 1.5551448, 34.0186456>,
    <-1.1120162, 1.4459014, 34.0159774>,
    <-1.1351354, 1.4453203, 34.0186848>,
    <-1.0832441, 1.4819496, 34.0186456>,
    <-1.0416556, 1.5845340, 34.0506060>,
    <-1.0885718, 1.5552552, 34.0592183>,
    <-1.0625708, 1.5723238, 34.0541438>,
    <-1.0300679, 1.5981359, 34.0708032>,
    <-1.0019960, 1.6119695, 34.0541438>,
    <-1.0091731, 1.6103480, 34.0633523>,
    <-1.0814033, 1.5445680, 34.0364647>,
    <-1.0230553, 1.5834921, 34.0364059>,
    <-1.0596859, 1.5683459, 34.0438443>,
    <-1.0052283, 1.6044580, 34.0448606>,
    <-1.2132036, 1.4443165, 34.0361559>,
    <-1.1390082, 1.5023807, 34.0364059>,
    <-1.1445900, 1.5094232, 34.0484530>,
    <-1.1077091, 1.5349452, 34.0448606>,
    <-1.1191003, 1.4932114, 34.0264558>,
    <-1.1025295, 1.5180728, 34.0303723>,
    <-1.1038323, 1.4979868, 34.0246615>,
    <-1.0596625, 1.5447507, 34.0296825>,
    <-1.1916273, 1.4188313, 34.0228405>,
    <-1.1839177, 1.4060576, 34.0186848>,
    <-1.1503383, 1.4627917, 34.0246615>,
    <-1.1443475, 1.4529534, 34.0213137>,
    <-1.2017408, 1.4294641, 34.0277741>,
    <-1.1508882, 1.4787985, 34.0296825>,
    <-1.0972277, -1.4821285, 34.0204813>,
    <-1.0458924, -1.5299266, 34.0228405>,
    <-1.2121014, -1.4455477, 34.0361559>,
    <-1.1920086, -1.4197864, 34.0228405>,
    <-1.0739636, -1.5040848, 34.0215203>,
    <-1.1180201, -1.4955478, 34.0277741>,
    <-1.2001433, -1.4316330, 34.0277741>,
    <-1.1406741, -1.4546272, 34.0215203>,
    <-1.1357547, -1.4713194, 34.0248083>,
    <-1.0467021, -1.4938140, 34.0159774>,
    <-1.1814331, -1.4099296, 34.0186848>,
    <-1.1120007, -1.4480920, 34.0159774>,
    <-1.0767558, -1.4872801, 34.0185671>,
    <-1.1301886, -1.4486747, 34.0186456>,
    <-0.9814036, -1.5395360, 34.0159774>,
    <-0.9724052, -1.5610523, 34.0186848>,
    <-1.0245814, -1.5248184, 34.0186456>,
    <-1.0216217, -1.5623408, 34.0264558>,
    <-1.0819799, -1.5444678, 34.0364647>,
    <-1.0502295, -1.5552648, 34.0303723>,
    <-1.1385247, -1.5029516, 34.0364059>,
    <-1.0315542, -1.5496309, 34.0246615>,
    <-1.0900599, -1.5241091, 34.0296825>,
    <-0.9825758, -1.5812948, 34.0246615>,
    <-0.9758982, -1.5723098, 34.0213137>,
    <-1.0226467, -1.5841699, 34.0364059>,
    <-0.9968842, -1.5872763, 34.0296825>,
    <-1.0484287, 1.5951056, 34.1722608>,
    <-1.0961791, 1.5665637, 34.1809181>,
    <-1.0084717, 1.6228174, 34.1760819>,
    <-1.0382653, 1.6114906, 34.1920745>,
    <-1.0694619, 1.5829037, 34.1760819>,
    <-1.0162964, 1.6223273, 34.1852017>,
    <-1.2226806, 1.4578058, 34.1544411>,
    <-1.0904065, 1.5580468, 34.1544124>,
    <-1.1524788, 1.5199155, 34.1694828>,
    <-1.1491612, 1.5153615, 34.1544124>,
    <-1.0669652, 1.5790859, 34.1645454>,
    <-1.1153117, 1.5454742, 34.1656437>,
    <-1.0301839, 1.5986335, 34.1544124>,
    <-1.0121283, 1.6154765, 34.1656437>,
    <-1.1320029, 1.5211387, 34.1359011>,
    <-1.1118095, 1.5344056, 34.1317777>,
    <-1.1140119, 1.5374434, 34.1440880>,
    <-1.0655561, 1.5706173, 34.1429132>,
    <-1.2169426, 1.4508877, 34.1264018>,
    <-1.2192709, 1.4537040, 34.1387967>,
    <-1.1697830, 1.4910836, 34.1317777>,
    <-1.1663261, 1.4978883, 34.1429132>,
    <-1.2147854, 1.4482735, 34.1138015>,
    <-1.1625086, 1.4929766, 34.1216372>,
    <-1.1294343, -1.5163691, 34.1168394>,
    <-1.2175256, -1.4503985, 34.1264018>,
    <-1.2233422, -1.4572506, 34.1544411>,
    <-1.0861425, -1.5503928, 34.1264018>,
    <-1.1685196, -1.4882421, 34.1210460>,
    <-1.2198948, -1.4531804, 34.1387967>,
    <-1.1468373, -1.5107733, 34.1387967>,
    <-1.1107057, -1.5314829, 34.1210460>,
    <-1.1648057, -1.4945908, 34.1311462>,
    <-1.0243391, -1.5879990, 34.1138015>,
    <-1.1087293, -1.5288617, 34.1083733>,
    <-1.0609663, -1.5623959, 34.1095803>,
    <-1.2153258, -1.4478201, 34.1138015>,
    <-1.1611377, -1.4900385, 34.1095803>,
    <-1.0422350, -1.5839949, 34.1359011>,
    <-1.0911441, -1.5575303, 34.1544124>,
    <-1.0616084, -1.5695568, 34.1317777>,
    <-1.1498805, -1.5148211, 34.1544124>,
    <-1.0637097, -1.5726653, 34.1440880>,
    <-1.1114558, -1.5384779, 34.1429132>,
    <-1.0309377, -1.5981425, 34.1544124>,
    <-1.0010710, -1.6092170, 34.1317777>,
    <-1.0086476, -1.6082960, 34.1429132>,
    <-1.0053377, -1.6030287, 34.1216372>,
    <-1.0486654, 1.5951439, 34.1038334>,
    <-1.0957474, 1.5655980, 34.1125260>,
    <-1.0694108, 1.5824993, 34.1076575>,
    <-1.0370120, 1.6091864, 34.1237934>,
    <-1.0084244, 1.6224186, 34.1076575>,
    <-1.0155806, 1.6208397, 34.1168389>,
    <-1.0920171, 1.5600502, 34.0861074>,
    <-1.0317164, 1.6006965, 34.0861074>,
    <-1.0677861, 1.5799959, 34.0961373>,
    <-1.0128322, 1.6162908, 34.0972345>,
    <-1.2244555, 1.4596671, 34.0861253>,
    <-1.1508477, 1.5173027, 34.0861074>,
    <-1.1529608, 1.5202269, 34.1010718>,
    <-1.1160835, 1.5462291, 34.0972345>,
    <-1.1349745, 1.5248745, 34.0680823>,
    <-1.1164467, 1.5405132, 34.0759583>,
    <-1.1148802, 1.5384265, 34.0642124>,
    <-1.0679889, 1.5738757, 34.0748134>,
    <-1.2204810, 1.4549347, 34.0592183>,
    <-1.2176929, 1.4518479, 34.0484530>,
    <-1.1730062, 1.4949820, 34.0642124>,
    <-1.1656206, 1.4969470, 34.0551646>,
    <-1.2223473, 1.4571070, 34.0708032>,
    <-1.1689519, 1.5009938, 34.0748134>,
    <-1.1327872, -1.5207801, 34.0506060>,
    <-1.0891819, -1.5548520, 34.0592183>,
    <-1.2248670, -1.4593218, 34.0861253>,
    <-1.2209280, -1.4545837, 34.0592183>,
    <-1.1141226, -1.5362571, 34.0541438>,
    <-1.1494525, -1.5145418, 34.0708032>,
    <-1.2227119, -1.4568011, 34.0708032>,
    <-1.1720952, -1.4928951, 34.0541438>,
    <-1.1680746, -1.4990839, 34.0633523>,
    <-1.2184662, -1.4512955, 34.0484530>,
    <-1.1115081, -1.5321882, 34.0438443>,
    <-1.1640575, -1.4933656, 34.0448606>,
    <-1.0270553, -1.5918183, 34.0484530>,
    <-1.0636864, -1.5658913, 34.0448606>,
    <-1.0447374, -1.5880651, 34.0680823>,
    <-1.0924758, -1.5597290, 34.0861074>,
    <-1.0657616, -1.5760032, 34.0759583>,
    <-1.1512949, -1.5169667, 34.0861074>,
    <-1.0643551, -1.5738178, 34.0642124>,
    <-1.1136857, -1.5418784, 34.0748134>,
    <-1.0036503, -1.6135796, 34.0642124>,
    <-1.0080780, -1.6073124, 34.0551646>,
    <-1.0321851, -1.6003912, 34.0861074>,
    <-1.0106677, -1.6118256, 34.0748134>,
    <-1.0575719, 1.6089219, 34.1542153>,
    <-1.1055373, 1.5798326, 34.1620860>,
    <-1.0787039, 1.5964845, 34.1576891>,
    <-1.0468703, 1.6247328, 34.1722289>,
    <-1.0171869, 1.6367453, 34.1576891>,
    <-1.0248783, 1.6359195, 34.1659804>,
    <-1.1002895, 1.5720899, 34.1379890>,
    <-1.0395237, 1.6130446, 34.1379890>,
    <-1.0764341, 1.5930138, 34.1472010>,
    <-1.0210891, 1.6296915, 34.1481994>,
    <-1.2337563, 1.4709443, 34.1380150>,
    <-1.1595742, 1.5290178, 34.1379890>,
    <-1.1625902, 1.5331578, 34.1516897>,
    <-1.1251850, 1.5590664, 34.1481994>,
    <-1.1426155, 1.5353305, 34.1211611>,
    <-1.1243085, 1.5515826, 34.1286034>,
    <-1.1223063, 1.5488210, 34.1174128>,
    <-1.0754295, 1.5850909, 34.1275355>,
    <-1.2285205, 1.4646320, 34.1125260>,
    <-1.2265594, 1.4622554, 34.1010718>,
    <-1.1808218, 1.5050920, 34.1174128>,
    <-1.1736538, 1.5072259, 34.1081947>,
    <-1.2306371, 1.4671923, 34.1237934>,
    <-1.1771242, 1.5116911, 34.1275355>,
    <-1.1402803, -1.5309945, 34.1038334>,
    <-1.0964132, -1.5651317, 34.1125260>,
    <-1.2343578, -1.4704396, 34.1380150>,
    <-1.2290506, -1.4641872, 34.1125260>,
    <-1.1213029, -1.5461641, 34.1076575>,
    <-1.1574616, -1.5248467, 34.1237934>,
    <-1.2312044, -1.4667163, 34.1237934>,
    <-1.1796733, -1.5025088, 34.1076575>,
    <-1.1757421, -1.5086935, 34.1168389>,
    <-1.2270507, -1.4618432, 34.1010718>,
    <-1.1195061, -1.5437811, 34.0961373>,
    <-1.1724075, -1.5045550, 34.0972345>,
    <-1.0342102, -1.6033769, 34.1010718>,
    <-1.0712570, -1.5776170, 34.0972345>,
    <-1.0519412, -1.5988213, 34.1211611>,
    <-1.1009601, -1.5716204, 34.1379890>,
    <-1.0734746, -1.5871769, 34.1286034>,
    <-1.1602281, -1.5285265, 34.1379890>,
    <-1.0715643, -1.5843510, 34.1174128>,
    <-1.1216796, -1.5527062, 34.1275355>,
    <-1.0104590, -1.6243813, 34.1174128>,
    <-1.0149159, -1.6183754, 34.1081947>,
    <-1.0402090, -1.6125982, 34.1379890>,
    <-1.0179248, -1.6231638, 34.1275355>,
    <-1.0612818, 1.6148791, 34.2216509>,
    <-1.1100759, 1.5866567, 34.2291393>,
    <-1.0210233, 1.6432318, 34.2249699>,
    <-1.0519855, 1.6330176, 34.2387176>,
    <-1.0827733, 1.6028266, 34.2249699>,
    <-1.0293921, 1.6434580, 34.2328318>,
    <-1.2366133, 1.4746021, 34.2060335>,
    <-1.1028094, 1.5759841, 34.2059966>,
    <-1.1664508, 1.5385654, 34.2192172>,
    <-1.1622408, 1.5328124, 34.2059966>,
    <-1.0796428, 1.5980608, 34.2149211>,
    <-1.1286233, 1.5641382, 34.2158771>,
    <-1.0418937, 1.6170331, 34.2059966>,
    <-1.0242058, 1.6349684, 34.2158771>,
    <-1.1438114, 1.5372323, 34.1894897>,
    <-1.1231635, 1.5503171, 34.1857817>,
    <-1.1261014, 1.5543455, 34.1968260>,
    <-1.0770409, 1.5877914, 34.1957715>,
    <-1.2290578, 1.4655376, 34.1809181>,
    <-1.2321887, 1.4693060, 34.1920745>,
    <-1.1817465, 1.5065461, 34.1857817>,
    <-1.1789248, 1.5142687, 34.1957715>,
    <-1.2260820, 1.4619516, 34.1694828>,
    <-1.1737775, 1.5076839, 34.1766071>,
    <-1.1403252, -1.5307590, 34.1722608>,
    <-1.2298491, -1.4648736, 34.1809181>,
    <-1.2374639, -1.4738883, 34.2060335>,
    <-1.0971731, -1.5658678, 34.1809181>,
    <-1.1800319, -1.5026896, 34.1760819>,
    <-1.2330166, -1.4686113, 34.1920745>,
    <-1.1591982, -1.5268124, 34.1920745>,
    <-1.1216654, -1.5463505, 34.1760819>,
    <-1.1768952, -1.5098749, 34.1852017>,
    <-1.0340824, -1.6028176, 34.1694828>,
    <-1.1189318, -1.5426985, 34.1645454>,
    <-1.0708116, -1.5766335, 34.1656437>,
    <-1.2268344, -1.4613203, 34.1694828>,
    <-1.1718831, -1.5036150, 34.1656437>,
    <-1.0533193, -1.6005956, 34.1894897>,
    <-1.1037576, -1.5753202, 34.2059966>,
    <-1.0726770, -1.5856681, 34.1857817>,
    <-1.1631655, -1.5321177, 34.2059966>,
    <-1.0754576, -1.5898066, 34.1968260>,
    <-1.1236662, -1.5551440, 34.1957715>,
    <-1.0428627, -1.6164018, 34.2059966>,
    <-1.0115092, -1.6257476, 34.1857817>,
    <-1.0197311, -1.6257373, 34.1957715>,
    <-1.0153039, -1.6186483, 34.1766071>,
    <-1.0692565, 1.6268978, 34.1991181>,
    <-1.1181708, 1.5980988, 34.2059260>,
    <-1.0908051, 1.6145962, 34.2021355>,
    <-1.0593433, 1.6443029, 34.2146338>,
    <-1.0285975, 1.6553038, 34.2021355>,
    <-1.0367835, 1.6551293, 34.2092829>,
    <-1.1115649, 1.5883965, 34.1848862>,
    <-1.0501689, 1.6297715, 34.1848862>,
    <-1.0879592, 1.6102636, 34.1929998>,
    <-1.0320686, 1.6474114, 34.1938690>,
    <-1.2464224, 1.4862136, 34.1849198>,
    <-1.1714647, 1.5448822, 34.1848862>,
    <-1.1752920, 1.5501122, 34.1969055>,
    <-1.1372864, 1.5760336, 34.1938690>,
    <-1.1533504, 1.5499610, 34.1698789>,
    <-1.1352989, 1.5669481, 34.1765488>,
    <-1.1326281, 1.5632859, 34.1665078>,
    <-1.0858702, 1.6007037, 34.1755900>,
    <-1.2395344, 1.4779500, 34.1620860>,
    <-1.2368291, 1.4746900, 34.1516897>,
    <-1.1916977, 1.5191488, 34.1665078>,
    <-1.1838982, 1.5205963, 34.1581668>,
    <-1.2423806, 1.4813758, 34.1722289>,
    <-1.1885775, 1.5265823, 34.1755900>,
    <-1.1501811, -1.5440762, 34.1542153>,
    <-1.1064409, -1.5791998, 34.1620860>,
    <-1.2471957, -1.4855647, 34.1849198>,
    <-1.2402537, -1.4773464, 34.1620860>,
    <-1.1312662, -1.5596799, 34.1576891>,
    <-1.1686987, -1.5394277, 34.1722289>,
    <-1.2431332, -1.4807442, 34.1722289>,
    <-1.1901390, -1.5156429, 34.1576891>,
    <-1.1867325, -1.5225880, 34.1659804>,
    <-1.2375130, -1.4741161, 34.1516897>,
    <-1.1287812, -1.5563600, 34.1472010>,
    <-1.1821760, -1.5168972, 34.1481994>,
    <-1.0430677, -1.6168483, 34.1516897>,
    <-1.0802073, -1.5905602, 34.1481994>,
    <-1.0620179, -1.6139127, 34.1698789>,
    <-1.1124269, -1.5877929, 34.1848862>,
    <-1.0841545, -1.6027599, 34.1765488>,
    <-1.1723053, -1.5442506, 34.1848862>,
    <-1.0816266, -1.5989976, 34.1665078>,
    <-1.1327799, -1.5678571, 34.1755900>,
    <-1.0199483, -1.6394091, 34.1665078>,
    <-1.0239760, -1.6325750, 34.1581668>,
    <-1.0510498, -1.6291976, 34.1848862>,
    <-1.0280007, -1.6390195, 34.1755900>,
    <-1.0766437, 1.6388097, 34.2635082>,
    <-1.1261432, 1.6110355, 34.2695801>,
    <-1.0357541, 1.6679961, 34.2662252>,
    <-1.0660252, 1.6601631, 34.2772285>,
    <-1.0984167, 1.6269983, 34.2662252>,
    <-1.0435486, 1.6697500, 34.2725930>,
    <-1.2538244, 1.4952792, 34.2505667>,
    <-1.1181386, 1.5980700, 34.2505227>,
    <-1.1833777, 1.5610745, 34.2614925>,
    <-1.1784032, 1.5542973, 34.2505227>,
    <-1.0951000, 1.6211141, 34.2579678>,
    <-1.1448302, 1.5867780, 34.2587527>,
    <-1.0563692, 1.6396902, 34.2505227>,
    <-1.0389113, 1.6586190, 34.2587527>,
    <-1.1588080, 1.5575802, 34.2365221>,
    <-1.1376809, 1.5705631, 34.2333423>,
    <-1.1412649, 1.5754598, 34.2427845>,
    <-1.0914766, 1.6092812, 34.2418824>,
    <-1.2446747, 1.4843360, 34.2291393>,
    <-1.2485129, 1.4889419, 34.2387176>,
    <-1.1970360, 1.5262208, 34.2333423>,
    <-1.1947496, 1.5347646, 34.2418824>,
    <-1.2409707, 1.4798872, 34.2192172>,
    <-1.1884291, 1.5267070, 34.2254131>,
    <-1.1545102, -1.5495999, 34.2216509>,
    <-1.2456502, -1.4835175, 34.2291393>,
    <-1.2548382, -1.4944285, 34.2505667>,
    <-1.1113012, -1.5857986, 34.2291393>,
    <-1.1949223, -1.5214665, 34.2249699>,
    <-1.2495196, -1.4880972, 34.2387176>,
    <-1.1747344, -1.5470679, 34.2387176>,
    <-1.1358340, -1.5656730, 34.2249699>,
    <-1.1922725, -1.5294079, 34.2328318>,
    <-1.0468289, -1.6223255, 34.2192172>,
    <-1.1324263, -1.5611013, 34.2149211>,
    <-1.0837972, -1.5955257, 34.2158771>,
    <-1.2419121, -1.4790972, 34.2192172>,
    <-1.1860687, -1.5216308, 34.2158771>,
    <-1.0673109, -1.6216471, 34.2365221>,
    <-1.1192686, -1.5972787, 34.2505227>,
    <-1.0867368, -1.6062345, 34.2333423>,
    <-1.1795052, -1.5534694, 34.2505227>,
    <-1.0901123, -1.6112772, 34.2427845>,
    <-1.1389226, -1.5760591, 34.2418824>,
    <-1.0575241, -1.6389378, 34.2505227>,
    <-1.0247680, -1.6468442, 34.2333423>,
    <-1.0335785, -1.6476178, 34.2418824>,
    <-1.0281686, -1.6389226, 34.2254131>,
    <-1.0833642, 1.6485256, 34.2371711>,
    <-1.1332638, 1.6198418, 34.2427102>,
    <-1.1053468, 1.6362840, 34.2396408>,
    <-1.0740519, 1.6673020, 34.2497196>,
    <-1.0423095, 1.6775304, 34.2396408>,
    <-1.0509345, 1.6778853, 34.2454279>,
    <-1.1255005, 1.6084746, 34.2253660>,
    <-1.0633285, 1.6503688, 34.2253660>,
    <-1.1020112, 1.6312212, 34.2321345>,
    <-1.0454373, 1.6689120, 34.2328481>,
    <-1.2620689, 1.5050110, 34.2254060>,
    <-1.1861579, 1.5644140, 34.2253660>,
    <-1.1906802, 1.5705751, 34.2353389>,
    <-1.1520201, 1.5966153, 34.2328481>,
    <-1.1669837, 1.5684591, 34.2126378>,
    <-1.1490840, 1.5861429, 34.2183311>,
    <-1.1458258, 1.5816914, 34.2097470>,
    <-1.0989937, 1.6202399, 34.2175110>,
    <-1.2537315, 1.4950395, 34.2059260>,
    <-1.2503642, 1.4909951, 34.1969055>,
    <-1.2055973, 1.5370349, 34.2097470>,
    <-1.1972178, 1.5378899, 34.2025384>,
    <-1.2572208, 1.4992267, 34.2146338>,
    <-1.2029638, 1.5452150, 34.2175110>,
    <-1.1630766, -1.5612043, 34.1991181>,
    <-1.1192848, -1.5973188, 34.2059260>,
    <-1.2629905, -1.5042377, 34.2254060>,
    <-1.2546183, -1.4942954, 34.2059260>,
    <-1.1441468, -1.5772459, 34.2021355>,
    <-1.1828226, -1.5578418, 34.2146338>,
    <-1.2581360, -1.4984588, 34.2146338>,
    <-1.2036757, -1.5327127, 34.2021355>,
    <-1.2007119, -1.5403453, 34.2092829>,
    <-1.2512201, -1.4902769, 34.1969055>,
    <-1.1410489, -1.5730898, 34.1929998>,
    <-1.1950720, -1.5332752, 34.1938690>,
    <-1.0546554, -1.6345828, 34.1969055>,
    <-1.0920123, -1.6077349, 34.1938690>,
    <-1.0747376, -1.6330506, 34.2126378>,
    <-1.1265279, -1.6077552, 34.2253660>,
    <-1.0974770, -1.6222786, 34.2183311>,
    <-1.1871597, -1.5636613, 34.2253660>,
    <-1.0944083, -1.6176944, 34.2097470>,
    <-1.1466495, -1.5868709, 34.2175110>,
    <-1.0320018, -1.6585878, 34.2097470>,
    <-1.0356712, -1.6510061, 34.2025384>,
    <-1.0643784, -1.6496849, 34.2253660>,
    <-1.0405893, -1.6589109, 34.2175110>,
    <-1.1270801, 1.6599307, 34.2989756>,
    <-1.1048869, 1.6674013, 34.2967794>,
    <-1.0681835, 1.7137436, 34.3035582>,
    <-1.1192020, 1.6617322, 34.2980080>,
    <-1.0467654, 1.7162309, 34.3007507>,
    <-1.0386599, 1.7307964, 34.3035582>,
    <-1.1035452, 1.6817080, 34.3008727>,
    <-1.0763646, 1.6981604, 34.3007914>,
    <-1.1898982, 1.6131713, 34.2975521>,
    <-1.0977072, 1.6966907, 34.3035582>,
    <-1.1599846, 1.6447760, 34.3007100>,
    <-1.1581323, 1.6364462, 34.2980080>,
    <-1.1311278, 1.6642893, 34.3007914>,
    <-1.2662228, 1.5284889, 34.2867877>,
    <-1.2205236, 1.5797842, 34.2937748>,
    <-1.1700359, 1.6122234, 34.2926777>,
    <-1.1723047, 1.6177197, 34.2951914>,
    <-1.0869690, 1.6710257, 34.2933120>,
    <-1.0550495, 1.6950864, 34.2949171>,
    <-1.0959886, 1.6686221, 34.2949171>,
    <-1.0521760, 1.7047842, 34.2980246>,
    <-1.1340014, 1.6246627, 34.2854038>,
    <-1.1916439, 1.5837100, 34.2856693>,
    <-1.1091372, 1.6494842, 34.2900253>,
    <-1.1477167, 1.6240711, 34.2908029>,
    <-1.0718545, 1.6670150, 34.2856693>,
    <-1.0580877, 1.6846839, 34.2908029>,
    <-1.1761836, 1.5817579, 34.2753407>,
    <-1.1545428, 1.5947996, 34.2729301>,
    <-1.1582463, 1.6005805, 34.2800513>,
    <-1.1069139, 1.6355178, 34.2795037>,
    <-1.2628754, 1.5072785, 34.2695801>,
    <-1.2659749, 1.5142818, 34.2772285>,
    <-1.2148704, 1.5498509, 34.2729301>,
    <-1.2120538, 1.5601175, 34.2795037>,
    <-1.2589989, 1.5015354, 34.2614925>,
    <-1.2060181, 1.5494677, 34.2665723>,
    <-1.1717329, -1.5722177, 34.2635082>,
    <-1.2650308, -1.5054152, 34.2695801>,
    <-1.2845832, -1.5122303, 34.2867877>,
    <-1.1286810, -1.6092303, 34.2695801>,
    <-1.2131309, -1.5437736, 34.2662252>,
    <-1.2712312, -1.5096526, 34.2772285>,
    <-1.1953071, -1.5695262, 34.2772285>,
    <-1.1531737, -1.5886351, 34.2662252>,
    <-1.2120412, -1.5516826, 34.2725930>,
    <-1.0621912, -1.6459303, 34.2614925>,
    <-1.1488027, -1.5835111, 34.2579678>,
    <-1.0995285, -1.6184986, 34.2587527>,
    <-1.2601008, -1.5006107, 34.2614925>,
    <-1.2032634, -1.5435384, 34.2587527>,
    <-1.0840873, -1.6462650, 34.2753407>,
    <-1.1388281, -1.6213901, 34.2854038>,
    <-1.1037306, -1.6303756, 34.2729301>,
    <-1.1997635, -1.5774457, 34.2856693>,
    <-1.1079091, -1.6358733, 34.2800513>,
    <-1.1582414, -1.5995656, 34.2795037>,
    <-1.0803918, -1.6613906, 34.2856693>,
    <-1.0408460, -1.6716781, 34.2729301>,
    <-1.0513749, -1.6725219, 34.2795037>,
    <-1.0435409, -1.6632355, 34.2665723>,
    <-1.0996891, 1.6731029, 34.2672347>,
    <-1.1513517, 1.6440425, 34.2713545>,
    <-1.1223882, 1.6607874, 34.2690979>,
    <-1.0945244, 1.6915985, 34.2765463>,
    <-1.0584074, 1.7026481, 34.2690979>,
    <-1.0689062, 1.7030896, 34.2734379>,
    <-1.1416731, 1.6317140, 34.2582019>,
    <-1.0786026, 1.6742109, 34.2582019>,
    <-1.1181632, 1.6552499, 34.2634197>,
    <-1.0607888, 1.6935400, 34.2639559>,
    <-1.2802205, 1.5267654, 34.2582471>,
    <-1.2032073, 1.5870197, 34.2582019>,
    <-1.2082871, 1.5939246, 34.2658251>,
    <-1.1689383, 1.6201860, 34.2639559>,
    <-1.1831012, 1.5902627, 34.2481381>,
    <-1.1652449, 1.6085838, 34.2526827>,
    <-1.1614982, 1.6034782, 34.2458152>,
    <-1.1144011, 1.6431058, 34.2520259>,
    <-1.2706805, 1.5153812, 34.2427102>,
    <-1.2667535, 1.5106753, 34.2353389>,
    <-1.2220982, 1.5582067, 34.2458152>,
    <-1.2132079, 1.5585815, 34.2399571>,
    <-1.2747069, 1.5202026, 34.2497196>,
    <-1.2198460, 1.5670230, 34.2520259>,
    <-1.1785750, -1.5818583, 34.2371711>,
    <-1.1345543, -1.6189381, 34.2427102>,
    <-1.2812624, -1.5258911, 34.2582471>,
    <-1.2717078, -1.5145192, 34.2427102>,
    <-1.1595532, -1.5983283, 34.2396408>,
    <-1.1994040, -1.5795295, 34.2497196>,
    <-1.2757568, -1.5193216, 34.2497196>,
    <-1.2198721, -1.5531997, 34.2396408>,
    <-1.2172557, -1.5614260, 34.2454279>,
    <-1.2677553, -1.5098347, 34.2353389>,
    <-1.1559366, -1.5934623, 34.2321345>,
    <-1.2107037, -1.5531912, 34.2328481>,
    <-1.0686212, -1.6560417, 34.2353389>,
    <-1.1063136, -1.6286193, 34.2328481>,
    <-1.0897138, -1.6556533, 34.2481381>,
    <-1.1428345, -1.6309008, 34.2582019>,
    <-1.1130371, -1.6451401, 34.2526827>,
    <-1.2043398, -1.5861688, 34.2582019>,
    <-1.1095209, -1.6398731, 34.2458152>,
    <-1.1628668, -1.6091698, 34.2520259>,
    <-1.0462532, -1.6813348, 34.2458152>,
    <-1.0496460, -1.6731088, 34.2399571>,
    <-1.0797896, -1.6734377, 34.2582019>,
    <-1.0553081, -1.6822337, 34.2520259>,
    <-1.2338860, 1.5830758, 34.2989756>,
    <-1.2118478, 1.6123438, 34.3035582>,
    <-1.2161426, 1.5949506, 34.2980080>,
    <-1.1695393, 1.6459908, 34.3035582>,
    <-1.2244085, 1.5958500, 34.3008727>,
    <-1.1909879, 1.6220394, 34.3007914>,
    <-1.2961801, 1.5243932, 34.2967794>,
    <-1.2541562, 1.5786967, 34.3035582>,
    <-1.2966207, 1.5351167, 34.3007507>,
    <-1.2607461, 1.5585210, 34.2980080>,
    <-1.2605175, 1.5659781, 34.3007914>,
    <-1.2882680, 1.5217872, 34.2926777>,
    <-1.2487095, 1.5615872, 34.2951914>,
    <-1.1982421, -1.5931302, 34.2933120>,
    <-1.2747364, -1.5414606, 34.2967794>,
    <-1.1873051, -1.6079211, 34.2967794>,
    <-1.2317396, -1.5714724, 34.2949171>,
    <-1.2865021, -1.5446984, 34.3007507>,
    <-1.2539900, -1.5707659, 34.3007507>,
    <-1.1926555, -1.6006448, 34.2949171>,
    <-1.2418510, -1.5721709, 34.2980246>,
    <-1.1132119, -1.6501465, 34.2926777>,
    <-1.1706492, -1.6066095, 34.2900253>,
    <-1.1331605, -1.6339081, 34.2908029>,
    <-1.2734220, -1.5328326, 34.2926777>,
    <-1.2209867, -1.5706560, 34.2908029>,
    <-1.1684252, -1.6238801, 34.2989756>,
    <-1.2357203, -1.5859127, 34.3035582>,
    <-1.1749957, -1.6181646, 34.2980080>,
    <-1.2674683, -1.5663602, 34.3035582>,
    <-1.1954852, -1.6087085, 34.3008727>,
    <-1.2238849, -1.5904918, 34.3007914>,
    <-1.2027055, -1.6070313, 34.3035582>,
    <-1.1347707, -1.6447088, 34.2980080>,
    <-1.1657998, -1.6279957, 34.3007914>,
    <-1.1154951, -1.6529196, 34.2951914>,
    <-1.2378429, 1.6196604, 34.2894178>,
    <-1.2781907, 1.5890818, 34.2886790>,
    <-1.2655709, 1.6069019, 34.2918017>,
    <-1.2160779, 1.6415578, 34.2918021>,
    <-1.2586855, 1.6035638, 34.2889153>,
    <-1.2714254, 1.5987226, 34.2903192>,
    <-1.2428381, 1.6228200, 34.2918020>,
    <-1.2300270, 1.6279437, 34.2904043>,
    <-1.2527696, 1.6119025, 34.2903618>,
    <-1.2018281, 1.6415380, 34.2882666>,
    <-1.1864325, 1.6623157, 34.2918022>,
    <-1.1722729, 1.6682086, 34.2903408>,
    <-1.2244798, 1.6275151, 34.2889155>,
    <-1.2028427, 1.6468618, 34.2903620>,
    <-1.3107075, 1.5463695, 34.2830969>,
    <-1.2416243, 1.6069352, 34.2861105>,
    <-1.2867776, 1.5765181, 34.2867236>,
    <-1.2565705, 1.6003829, 34.2874564>,
    <-1.1617312, 1.6650728, 34.2863581>,
    <-1.1793632, 1.6547842, 34.2872643>,
    <-1.1400722, 1.6823918, 34.2872643>,
    <-1.1574665, 1.6746710, 34.2889218>,
    <-1.1756033, 1.6448503, 34.2817251>,
    <-1.1134172, 1.6884757, 34.2819691>,
    <-1.1660459, 1.6575169, 34.2845089>,
    <-1.1198316, 1.6906484, 34.2850030>,
    <-1.2346948, 1.6024037, 34.2819691>,
    <-1.2090464, 1.6277962, 34.2850030>,
    <-1.2042288, 1.6123866, 34.2751874>,
    <-1.1900760, 1.6283625, 34.2783022>,
    <-1.1806385, 1.6270597, 34.2735942>,
    <-1.1375014, 1.6649085, 34.2779937>,
    <-1.2908224, 1.5378706, 34.2713545>,
    <-1.2854991, 1.5331326, 34.2658251>,
    <-1.2421431, 1.5810111, 34.2735942>,
    <-1.2313826, 1.5820422, 34.2692880>,
    <-1.2981314, 1.5417203, 34.2765463>,
    <-1.2444871, 1.5873035, 34.2779937>,
    <-1.2508477, -1.6106048, 34.2894146>,
    <-1.2140595, -1.6331433, 34.2882644>,
    <-1.2347901, -1.6284556, 34.2917975>,
    <-1.2375947, -1.6184452, 34.2889127>,
    <-1.1914848, -1.6547564, 34.2903380>,
    <-1.2077628, -1.6473802, 34.2917982>,
    <-1.2456507, -1.6170040, 34.2904005>,
    <-1.2207117, -1.6343499, 34.2903586>,
    <-1.2763914, -1.5993256, 34.2917967>,
    <-1.2841315, -1.5850770, 34.2886761>,
    <-1.2577249, -1.6123963, 34.2917970>,
    <-1.2804831, -1.5923806, 34.2903152>,
    <-1.2682269, -1.5969962, 34.2889123>,
    <-1.2652023, -1.6031971, 34.2903578>,
    <-1.2928017, -1.5614426, 34.2830964>,
    <-1.2868935, -1.5770564, 34.2867218>,
    <-1.2426683, -1.6068835, 34.2861090>,
    <-1.2623460, -1.5967918, 34.2874542>,
    <-1.1960380, -1.6056464, 34.2672347>,
    <-1.1509450, -1.6443533, 34.2713544>,
    <-1.2901938, -1.5384012, 34.2713544>,
    <-1.1766409, -1.6228166, 34.2690979>,
    <-1.2145764, -1.6076413, 34.2765461>,
    <-1.2922233, -1.5466906, 34.2765461>,
    <-1.2378597, -1.5770116, 34.2690979>,
    <-1.2343554, -1.5873102, 34.2734377>,
    <-1.2866163, -1.5321951, 34.2658251>,
    <-1.1729918, -1.6168585, 34.2634197>,
    <-1.2285960, -1.5760402, 34.2639559>,
    <-1.0845407, -1.6805728, 34.2658251>,
    <-1.1226764, -1.6525789, 34.2639559>,
    <-1.1655297, -1.6624149, 34.2863568>,
    <-1.1488813, -1.6761145, 34.2872630>,
    <-1.1886287, -1.6484097, 34.2872627>,
    <-1.1734591, -1.6634730, 34.2889197>,
    <-1.1430877, -1.6676239, 34.2817246>,
    <-1.2049442, -1.6244919, 34.2819686>,
    <-1.1579692, -1.6631762, 34.2845081>,
    <-1.2043028, -1.6315706, 34.2850020>,
    <-1.0824253, -1.7089438, 34.2819687>,
    <-1.1143877, -1.6940235, 34.2850022>,
    <-1.1031735, -1.6831480, 34.2751874>,
    <-1.1228968, -1.6754059, 34.2783020>,
    <-1.1250244, -1.6660184, 34.2735942>,
    <-1.1750160, -1.6387099, 34.2779935>,
    <-1.0607024, -1.7080438, 34.2735942>,
    <-1.0654758, -1.6982114, 34.2692880>,
    <-1.0654412, -1.7126193, 34.2779935>,
    <-1.3000129, 1.5754179, 34.2894168>,
    <-1.2968197, 1.5850196, 34.2918006>,
    <-1.2987361, 1.5795654, 34.2904030>,
    <-1.2831340, 1.5946034, 34.2918012>,
    <-1.2920608, 1.5799275, 34.2889148>,
    <-1.2863495, 1.5883886, 34.2903611>,
    <-1.3225243, 1.5539685, 34.2886782>,
    <-1.3202289, 1.5494056, 34.2867233>,
    <-1.3089555, 1.5667673, 34.2889143>,
    <-1.3027637, 1.5669736, 34.2874559>,
    <-1.3229229, 1.5592928, 34.2903177>,
    <-1.3079206, 1.5772457, 34.2917998>,
    <-1.3097799, 1.5709174, 34.2903602>,
    <-1.3038485, -1.5726233, 34.2894143>,
    <-1.3015022, -1.5817417, 34.2917970>,
    <-1.2962464, -1.5770503, 34.2889121>,
    <-1.2906135, -1.5893667, 34.2917967>,
    <-1.3029152, -1.5765799, 34.2904001>,
    <-1.2926094, -1.5840058, 34.2903576>,
    <-1.3254155, -1.5512160, 34.2886766>,
    <-1.3101688, -1.5756726, 34.2917975>,
    <-1.3263417, -1.5561411, 34.2903161>,
    <-1.3116249, -1.5646526, 34.2889123>,
    <-1.3127343, -1.5686099, 34.2903581>,
    <-1.3190132, -1.5501776, 34.2867220>,
    <-1.3031656, -1.5669057, 34.2874540>,
    <-1.3589525, 1.5212454, 34.2894168>,
    <-1.3934970, 1.4831705, 34.2882662>,
    <-1.4299744, 1.4581314, 34.2918017>,
    <-1.3743684, 1.5137374, 34.2918006>,
    <-1.3721598, 1.5065125, 34.2889148>,
    <-1.4165357, 1.4669111, 34.2903403>,
    <-1.4023652, 1.4857406, 34.2918012>,
    <-1.3642900, 1.5192675, 34.2904030>,
    <-1.3894285, 1.4940858, 34.2903611>,
    <-1.3461133, 1.5419924, 34.2917998>,
    <-1.3405091, 1.5377040, 34.2889143>,
    <-1.3416072, 1.5415397, 34.2903602>,
    <-1.3633328, 1.5059608, 34.2861102>,
    <-1.3462271, 1.5271022, 34.2874559>,
    <-1.3386579, -1.4886109, 34.2989756>,
    <-1.3742055, -1.4501014, 34.2975521>,
    <-1.4333816, -1.4031807, 34.3035582>,
    <-1.3678538, -1.4717663, 34.3035582>,
    <-1.3523792, -1.4729173, 34.2980080>,
    <-1.4047250, -1.4263294, 34.3007100>,
    <-1.4013196, -1.4361162, 34.3035582>,
    <-1.3513968, -1.4813286, 34.3008727>,
    <-1.3789903, -1.4527954, 34.3007914>,
    <-1.3334522, -1.5092260, 34.3035582>,
    <-1.3121726, -1.5115438, 34.2980080>,
    <-1.3196781, -1.5129405, 34.3007914>,
    <-1.3399605, -1.4751199, 34.2937748>,
    <-1.3172047, -1.4999247, 34.2951914>,
    <-1.2562764, 1.3219768, 34.0221521>,
    <-1.3116229, 1.2805448, 34.0252783>,
    <-1.2219863, 1.3597606, 34.0235337>,
    <-1.2656499, 1.3455634, 34.0315713>,
    <-1.2816455, 1.3032502, 34.0235337>,
    <-1.2390369, 1.3583004, 34.0277883>,
    <-1.2764807, 1.2738842, 34.0159774>,
    <-1.3546836, 1.2135738, 34.0197144>,
    <-1.3322537, 1.2181107, 34.0159774>,
    <-1.2648682, 1.3025611, 34.0195520>,
    <-1.3104105, 1.2581844, 34.0196603>,
    <-1.2207076, 1.3296577, 34.0159774>,
    <-1.2180647, 1.3480115, 34.0196603>,
    <-1.2877466, 1.3655773, 34.0581798>,
    <-1.3285542, 1.3290856, 34.0677166>,
    <-1.2538428, 1.3991843, 34.0621232>,
    <-1.2790418, 1.3811128, 34.0805061>,
    <-1.3060777, 1.3501260, 34.0621232>,
    <-1.2606730, 1.3965010, 34.0723106>,
    <-1.4312569, 1.1979064, 34.0417108>,
    <-1.3194708, 1.3196257, 34.0421478>,
    <-1.3751506, 1.2746446, 34.0557354>,
    <-1.3683658, 1.2686081, 34.0420666>,
    <-1.3024638, 1.3466148, 34.0506039>,
    <-1.3435444, 1.3058179, 34.0517365>,
    <-1.2692904, 1.3675907, 34.0420666>,
    <-1.2556002, 1.3911861, 34.0517365>,
    <-1.3473093, 1.2630179, 34.0300324>,
    <-1.3332411, 1.2702867, 34.0277479>,
    <-1.3354558, 1.2901174, 34.0349278>,
    <-1.2982585, 1.3234824, 34.0340297>,
    <-1.4054045, 1.1775522, 34.0252439>,
    <-1.4177436, 1.1846722, 34.0314335>,
    <-1.3725160, 1.2279960, 34.0277479>,
    <-1.3758347, 1.2435283, 34.0340297>,
    <-1.3954749, 1.1669311, 34.0197144>,
    <-1.3649748, 1.2194290, 34.0233431>,
    <-1.3238156, -1.2559868, 34.0221521>,
    <-1.4055238, -1.1789437, 34.0252783>,
    <-1.4298041, -1.2006338, 34.0418026>,
    <-1.2820586, -1.3113843, 34.0252783>,
    <-1.3614531, -1.2217198, 34.0235337>,
    <-1.4155960, -1.1890944, 34.0315713>,
    <-1.3465468, -1.2654949, 34.0315713>,
    <-1.3049430, -1.2813788, 34.0235337>,
    <-1.3596024, -1.2388318, 34.0277883>,
    <-1.2764703, -1.2760733, 34.0159774>,
    <-1.2156957, -1.3543490, 34.0197144>,
    <-1.2206972, -1.3318460, 34.0159774>,
    <-1.3047026, -1.2645309, 34.0195520>,
    <-1.2603128, -1.3100751, 34.0196603>,
    <-1.3322434, -1.2203007, 34.0159774>,
    <-1.3934189, -1.1711684, 34.0197144>,
    <-1.3501394, -1.2177298, 34.0196603>,
    <-1.2640556, -1.3471457, 34.0300324>,
    <-1.3199860, -1.3194140, 34.0421478>,
    <-1.2715149, -1.3330475, 34.0277479>,
    <-1.3679611, -1.2692320, 34.0420666>,
    <-1.2907954, -1.3353489, 34.0349278>,
    <-1.3242458, -1.2981382, 34.0340297>,
    <-1.2689785, -1.3683074, 34.0420666>,
    <-1.2292241, -1.3723224, 34.0277479>,
    <-1.2442915, -1.3757144, 34.0340297>,
    <-1.2210995, -1.3647114, 34.0233431>,
    <-1.2972078, 1.3755904, 34.1168394>,
    <-1.3382322, 1.3388644, 34.1264018>,
    <-1.2627211, 1.4091977, 34.1210460>,
    <-1.2886751, 1.3917573, 34.1387967>,
    <-1.3153443, 1.3597708, 34.1210460>,
    <-1.2696183, 1.4066426, 34.1311462>,
    <-1.4450211, 1.2129023, 34.0973598>,
    <-1.3331316, 1.3335672, 34.0973402>,
    <-1.3859992, 1.2845302, 34.1138015>,
    <-1.3831515, 1.2817661, 34.0973402>,
    <-1.3131061, 1.3573692, 34.1083733>,
    <-1.3544248, 1.3161551, 34.1095803>,
    <-1.2813167, 1.3835719, 34.0973402>,
    <-1.2657721, 1.4022399, 34.1095803>,
    <-1.3686911, 1.2916047, 34.0775018>,
    <-1.3513744, 1.3082186, 34.0732308>,
    <-1.3534307, 1.3101504, 34.0861763>,
    <-1.3119001, 1.3509962, 34.0849170>,
    <-1.4399094, 1.2086089, 34.0677166>,
    <-1.4422737, 1.2105531, 34.0805061>,
    <-1.4005769, 1.2558704, 34.0732308>,
    <-1.3978162, 1.2625744, 34.0849170>,
    <-1.4365163, 1.2059553, 34.0557354>,
    <-1.3935916, 1.2589446, 34.0632019>,
    <-1.3656451, -1.2877359, 34.0581798>,
    <-1.4403106, -1.2081548, 34.0677166>,
    <-1.4454009, -1.2124497, 34.0973598>,
    <-1.3291142, -1.3285496, 34.0677166>,
    <-1.3992202, -1.2538371, 34.0621232>,
    <-1.4426103, -1.2101520, 34.0805061>,
    <-1.3811128, -1.2790418, 34.0805061>,
    <-1.3501619, -1.3060720, 34.0621232>,
    <-1.3965010, -1.2606730, 34.0723106>,
    <-1.2747591, -1.3751326, 34.0557354>,
    <-1.3467675, -1.3024398, 34.0506039>,
    <-1.3059615, -1.3435217, 34.0517365>,
    <-1.4371848, -1.2052551, 34.0557354>,
    <-1.3913297, -1.2555776, 34.0517365>,
    <-1.2916117, -1.3686900, 34.0775018>,
    <-1.3335672, -1.3331316, 34.0973402>,
    <-1.3082343, -1.3513720, 34.0732308>,
    <-1.3835719, -1.2813167, 34.0973402>,
    <-1.3101504, -1.3534307, 34.0861763>,
    <-1.3509962, -1.3119001, 34.0849170>,
    <-1.2817661, -1.3831515, 34.0973402>,
    <-1.2558861, -1.4005744, 34.0732308>,
    <-1.2625744, -1.3978162, 34.0849170>,
    <-1.2590074, -1.3935817, 34.0632019>,
    <-1.2695666, 1.3359700, 34.0204813>,
    <-1.3254665, 1.2940610, 34.0228405>,
    <-1.2951904, 1.3170278, 34.0215203>,
    <-1.2789450, 1.3596876, 34.0277741>,
    <-1.2349002, 1.3741362, 34.0215203>,
    <-1.2520896, 1.3726061, 34.0248083>,
    <-1.2900460, 1.2874457, 34.0159774>,
    <-1.2336800, 1.3438123, 34.0159774>,
    <-1.2782750, 1.3163814, 34.0185671>,
    <-1.2309743, 1.3623127, 34.0186456>,
    <-1.3464120, 1.2310791, 34.0159774>,
    <-1.3690410, 1.2264484, 34.0186848>,
    <-1.3242992, 1.2715326, 34.0186456>,
    <-1.3676892, -1.5125086, 34.2894152>,
    <-1.3864742, -1.5016314, 34.2917984>,
    <-1.4487692, -1.4393364, 34.2917984>,
    <-1.4030271, -1.4734557, 34.2882646>,
    <-1.3746078, -1.5089706, 34.2904012>,
    <-1.4188320, -1.4692736, 34.2917985>,
    <-1.4325313, -1.4509153, 34.2903378>,
    <-1.3816789, -1.4968879, 34.2889131>,
    <-1.4029888, -1.4805254, 34.2903590>,
    <-1.3629389, -1.5056166, 34.2861092>,
    <-1.3461233, -1.5320897, 34.2889129>,
    <-1.3494357, -1.5234718, 34.2874546>,
    <-1.3525026, -1.5356030, 34.2917982>,
    <-1.3480125, -1.5352186, 34.2903587>,
    <-1.3009875, 1.3795861, 34.0506060>,
    <-1.3421035, 1.3426016, 34.0592183>,
    <-1.3194621, 1.3639266, 34.0541438>,
    <-1.2919322, 1.3949872, 34.0708032>,
    <-1.2666920, 1.4134887, 34.0541438>,
    <-1.2734755, 1.4106421, 34.0633523>,
    <-1.3332153, 1.3333528, 34.0364647>,
    <-1.2825136, 1.3818186, 34.0364059>,
    <-1.3159398, 1.3605211, 34.0438443>,
    <-1.2685796, 1.4055402, 34.0448606>,
    <-1.4458806, 1.2110699, 34.0361234>,
    <-1.3826200, 1.2818045, 34.0364059>,
    <-1.3893190, 1.2877466, 34.0484530>,
    <-1.3574327, 1.3192879, 34.0448606>,
    <-1.3614769, 1.2762944, 34.0264558>,
    <-1.3494456, 1.3036216, 34.0303723>,
    <-1.3472858, 1.2836663, 34.0246615>,
    <-1.3118694, 1.3373460, 34.0296825>,
    <-1.4201282, 1.1902449, 34.0228283>,
    <-1.4102641, 1.1793117, 34.0186848>,
    <-1.3869735, 1.2409305, 34.0246615>,
    <-1.3794016, 1.2323235, 34.0213137>,
    <-1.4322015, 1.1981583, 34.0277254>,
    <-1.3902567, 1.2565548, 34.0296825>,
    <-1.3378094, -1.2692763, 34.0204813>,
    <-1.2955751, -1.3252277, 34.0228405>,
    <-1.4446803, -1.2131462, 34.0361559>,
    <-1.4203454, -1.1913883, 34.0228405>,
    <-1.3187209, -1.2949232, 34.0215203>,
    <-1.3606711, -1.2787899, 34.0277741>,
    <-1.4304477, -1.2015856, 34.0277741>,
    <-1.3758294, -1.2346330, 34.0215203>,
    <-1.3739085, -1.2518840, 34.0248083>,
    <-1.2900327, -1.2896378, 34.0159774>,
    <-1.4081798, -1.1835828, 34.0186848>,
    <-1.3463994, -1.2332717, 34.0159774>,
    <-1.3185237, -1.2779369, 34.0185671>,
    <-1.3644416, -1.2306383, 34.0186456>,
    <-1.2336660, -1.3460039, 34.0159774>,
    <-1.2285704, -1.3687062, 34.0186848>,
    <-1.2736614, -1.3239633, 34.0186456>,
    <-1.2773322, -1.3613132, 34.0264558>,
    <-1.3337132, -1.3331584, 34.0364647>,
    <-1.3042997, -1.3493387, 34.0303723>,
    <-1.3821891, -1.2824552, 34.0364059>,
    <-1.2848946, -1.3470920, 34.0246615>,
    <-1.3381095, -1.3117490, 34.0296825>,
    <-1.2421585, -1.3867799, 34.0246615>,
    <-1.2339940, -1.3791381, 34.0213137>,
    <-1.2821748, -1.3825617, 34.0364059>,
    <-1.2573179, -1.3901364, 34.0296825>,
    <-1.3094879, 1.3888146, 34.1722608>,
    <-1.3515566, 1.3524146, 34.1809181>,
    <-1.2749500, 1.4230439, 34.1760819>,
    <-1.3023241, 1.4067156, 34.1920745>,
    <-1.3280828, 1.3731457, 34.1760819>,
    <-1.2825708, 1.4212025, 34.1852017>,
    <-1.4572506, 1.2233422, 34.1544411>,
    <-1.3443928, 1.3450295, 34.1544124>,
    <-1.3989006, 1.2966987, 34.1694828>,
    <-1.3948426, 1.2927900, 34.1544124>,
    <-1.3249609, 1.3698195, 34.1645454>,
    <-1.3667364, 1.3283231, 34.1656437>,
    <-1.2921329, 1.3954571, 34.1544124>,
    <-1.2772763, 1.4151795, 34.1656437>,
    <-1.3789482, 1.3014589, 34.1359011>,
    <-1.3613653, 1.3180308, 34.1317777>,
    <-1.3640618, 1.3206400, 34.1440880>,
    <-1.3221027, 1.3617241, 34.1429132>,
    <-1.4503985, 1.2175256, 34.1264018>,
    <-1.4531804, 1.2198948, 34.1387967>,
    <-1.4109353, 1.2653001, 34.1317777>,
    <-1.4087125, 1.2726016, 34.1429132>,
    <-1.4478201, 1.2153258, 34.1138015>,
    <-1.4041001, 1.2684274, 34.1216372>,
    <-1.3755904, -1.2972078, 34.1168394>,
    <-1.4508877, -1.2169426, 34.1264018>,
    <-1.4578058, -1.2226806, 34.1544411>,
    <-1.3388644, -1.3382322, 34.1264018>,
    <-1.4091977, -1.2627211, 34.1210460>,
    <-1.4537040, -1.2192709, 34.1387967>,
    <-1.3917573, -1.2886751, 34.1387967>,
    <-1.3597708, -1.3153443, 34.1210460>,
    <-1.4066426, -1.2696183, 34.1311462>,
    <-1.2845302, -1.3859992, 34.1138015>,
    <-1.3573692, -1.3131061, 34.1083733>,
    <-1.3161551, -1.3544248, 34.1095803>,
    <-1.4482735, -1.2147854, 34.1138015>,
    <-1.4022399, -1.2657721, 34.1095803>,
    <-1.3014589, -1.3789482, 34.1359011>,
    <-1.3450295, -1.3443928, 34.1544124>,
    <-1.3180308, -1.3613653, 34.1317777>,
    <-1.3954571, -1.2921329, 34.1544124>,
    <-1.3206400, -1.3640618, 34.1440880>,
    <-1.3617241, -1.3221027, 34.1429132>,
    <-1.2927900, -1.3948426, 34.1544124>,
    <-1.2653001, -1.4109353, 34.1317777>,
    <-1.2726016, -1.4087125, 34.1429132>,
    <-1.2684274, -1.4041001, 34.1216372>,
    <-1.3097276, 1.3888113, 34.1038334>,
    <-1.3509637, 1.3515385, 34.1125260>,
    <-1.3279622, 1.3727563, 34.1076575>,
    <-1.3006898, 1.4046640, 34.1237934>,
    <-1.2748342, 1.4226594, 34.1076575>,
    <-1.2816076, 1.4198618, 34.1168389>,
    <-1.3463268, 1.3467228, 34.0861074>,
    <-1.2940003, 1.3972227, 34.0861074>,
    <-1.3259274, 1.3705731, 34.0961373>,
    <-1.2781110, 1.4158593, 34.0972345>,
    <-1.4593218, 1.2248670, 34.0861253>,
    <-1.3968406, 1.2944089, 34.0861074>,
    <-1.3994293, 1.2969218, 34.1010718>,
    <-1.3676276, 1.3289325, 34.0972345>,
    <-1.3825240, 1.3046226, 34.0680823>,
    <-1.3669926, 1.3232404, 34.0759583>,
    <-1.3650889, 1.3214590, 34.0642124>,
    <-1.3250644, 1.3645107, 34.0748134>,
    <-1.4545882, 1.2208994, 34.0592183>,
    <-1.4513135, 1.2183518, 34.0484530>,
    <-1.4147878, 1.2685810, 34.0642124>,
    <-1.4078595, 1.2718031, 34.0551646>,
    <-1.4568011, 1.2227119, 34.0708032>,
    <-1.4118377, 1.2752040, 34.0748134>,
    <-1.3796540, -1.3009768, 34.0506060>,
    <-1.3426302, -1.3420990, 34.0592183>,
    <-1.4596671, -1.2244555, 34.0861253>,
    <-1.4549633, -1.2204765, 34.0592183>,
    <-1.3639625, -1.3194564, 34.0541438>,
    <-1.3949872, -1.2919322, 34.0708032>,
    <-1.4571070, -1.2223473, 34.0708032>,
    <-1.4135246, -1.2666863, 34.0541438>,
    <-1.4106421, -1.2734755, 34.0633523>,
    <-1.4519624, -1.2176749, 34.0484530>,
    <-1.3606737, -1.3159157, 34.0438443>,
    <-1.4056839, -1.2685569, 34.0448606>,
    <-1.2878610, -1.3893010, 34.0484530>,
    <-1.3194315, -1.3574101, 34.0448606>,
    <-1.3046296, -1.3825229, 34.0680823>,
    <-1.3467228, -1.3463268, 34.0861074>,
    <-1.3232404, -1.3669926, 34.0759583>,
    <-1.3972227, -1.2940003, 34.0861074>,
    <-1.3214747, -1.3650864, 34.0642124>,
    <-1.3645107, -1.3250644, 34.0748134>,
    <-1.2685967, -1.4147853, 34.0642124>,
    <-1.2718659, -1.4078496, 34.0551646>,
    <-1.2944089, -1.3968406, 34.0861074>,
    <-1.2752040, -1.4118377, 34.0748134>,
    <-1.3208914, 1.4008333, 34.1542153>,
    <-1.3630768, 1.3638568, 34.1620860>,
    <-1.3395426, 1.3849154, 34.1576891>,
    <-1.3130979, 1.4182624, 34.1722289>,
    <-1.2859514, 1.4352467, 34.1576891>,
    <-1.2933825, 1.4330980, 34.1659804>,
    <-1.3565642, 1.3571431, 34.1379890>,
    <-1.3038333, 1.4080275, 34.1379890>,
    <-1.3367046, 1.3818915, 34.1472010>,
    <-1.2885694, 1.4276226, 34.1481994>,
    <-1.4704396, 1.2343578, 34.1380150>,
    <-1.4074689, 1.3044306, 34.1379890>,
    <-1.4111579, 1.3079840, 34.1516897>,
    <-1.3788199, 1.3399944, 34.1481994>,
    <-1.3918639, 1.3135923, 34.1211611>,
    <-1.3766572, 1.3327765, 34.1286034>,
    <-1.3742059, 1.3304045, 34.1174128>,
    <-1.3343395, 1.3742634, 34.1275355>,
    <-1.4641872, 1.2290506, 34.1125260>,
    <-1.4618432, 1.2270507, 34.1010718>,
    <-1.4242390, 1.2771787, 34.1174128>,
    <-1.4175503, 1.2805250, 34.1081947>,
    <-1.4667163, 1.2312044, 34.1237934>,
    <-1.4217435, 1.2843197, 34.1275355>,
    <-1.3888113, -1.3097276, 34.1038334>,
    <-1.3515385, -1.3509637, 34.1125260>,
    <-1.4709443, -1.2337563, 34.1380150>,
    <-1.4646320, -1.2285205, 34.1125260>,
    <-1.3727563, -1.3279622, 34.1076575>,
    <-1.4046640, -1.3006898, 34.1237934>,
    <-1.4671923, -1.2306371, 34.1237934>,
    <-1.4226594, -1.2748342, 34.1076575>,
    <-1.4198618, -1.2816076, 34.1168389>,
    <-1.4622554, -1.2265594, 34.1010718>,
    <-1.3705731, -1.3259274, 34.0961373>,
    <-1.4158593, -1.2781110, 34.0972345>,
    <-1.2969218, -1.3994293, 34.1010718>,
    <-1.3289325, -1.3676276, 34.0972345>,
    <-1.3135923, -1.3918639, 34.1211611>,
    <-1.3571431, -1.3565642, 34.1379890>,
    <-1.3327765, -1.3766572, 34.1286034>,
    <-1.4080275, -1.3038333, 34.1379890>,
    <-1.3304045, -1.3742059, 34.1174128>,
    <-1.3742634, -1.3343395, 34.1275355>,
    <-1.2771787, -1.4242390, 34.1174128>,
    <-1.2805250, -1.4175503, 34.1081947>,
    <-1.3044306, -1.4074689, 34.1379890>,
    <-1.2843197, -1.4217435, 34.1275355>,
    <-1.3255794, 1.4060558, 34.2216509>,
    <-1.3687313, 1.3697891, 34.2291393>,
    <-1.2908559, 1.4409686, 34.2249699>,
    <-1.3195740, 1.4255331, 34.2387176>,
    <-1.3446514, 1.3904544, 34.2249699>,
    <-1.2991368, 1.4397381, 34.2328318>,
    <-1.4738883, 1.2374639, 34.2060335>,
    <-1.3597220, 1.3605405, 34.2059966>,
    <-1.4158989, 1.3126390, 34.2192172>,
    <-1.4107538, 1.3077045, 34.2059966>,
    <-1.3407409, 1.3863046, 34.2149211>,
    <-1.3830867, 1.3443920, 34.2158771>,
    <-1.3068598, 1.4115438, 34.2059966>,
    <-1.2925551, 1.4322780, 34.2158771>,
    <-1.3933719, 1.3152576, 34.1894897>,
    <-1.3753099, 1.3317290, 34.1857817>,
    <-1.3789026, 1.3351861, 34.1968260>,
    <-1.3363953, 1.3766431, 34.1957715>,
    <-1.4648736, 1.2298491, 34.1809181>,
    <-1.4686113, 1.2330166, 34.1920745>,
    <-1.4254021, 1.2784502, 34.1857817>,
    <-1.4239642, 1.2865454, 34.1957715>,
    <-1.4613203, 1.2268344, 34.1694828>,
    <-1.4177517, 1.2809545, 34.1766071>,
    <-1.3888146, -1.3094879, 34.1722608>,
    <-1.4655376, -1.2290578, 34.1809181>,
    <-1.4746021, -1.2366133, 34.2060335>,
    <-1.3524146, -1.3515566, 34.1809181>,
    <-1.4230439, -1.2749500, 34.1760819>,
    <-1.4693060, -1.2321887, 34.1920745>,
    <-1.4067156, -1.3023241, 34.1920745>,
    <-1.3731457, -1.3280828, 34.1760819>,
    <-1.4212025, -1.2825708, 34.1852017>,
    <-1.2966987, -1.3989006, 34.1694828>,
    <-1.3698195, -1.3249609, 34.1645454>,
    <-1.3283231, -1.3667364, 34.1656437>,
    <-1.4619516, -1.2260820, 34.1694828>,
    <-1.4151795, -1.2772763, 34.1656437>,
    <-1.3152576, -1.3933719, 34.1894897>,
    <-1.3605405, -1.3597220, 34.2059966>,
    <-1.3317290, -1.3753099, 34.1857817>,
    <-1.4115438, -1.3068598, 34.2059966>,
    <-1.3351861, -1.3789026, 34.1968260>,
    <-1.3766431, -1.3363953, 34.1957715>,
    <-1.3077045, -1.4107538, 34.2059966>,
    <-1.2784502, -1.4254021, 34.1857817>,
    <-1.2865454, -1.4239642, 34.1957715>,
    <-1.2809545, -1.4177517, 34.1766071>,
    <-1.3355199, 1.4165071, 34.1991181>,
    <-1.3786902, 1.3796518, 34.2059260>,
    <-1.3546050, 1.4006505, 34.2021355>,
    <-1.3287797, 1.4353692, 34.2146338>,
    <-1.3004113, 1.4515419, 34.2021355>,
    <-1.3084426, 1.4499486, 34.2092829>,
    <-1.3704999, 1.3712440, 34.1848862>,
    <-1.3172213, 1.4226517, 34.1848862>,
    <-1.3510500, 1.3968780, 34.1929998>,
    <-1.3024592, 1.4431666, 34.1938690>,
    <-1.4855647, 1.2471957, 34.1849198>,
    <-1.4219335, 1.3179892, 34.1848862>,
    <-1.4266108, 1.3224752, 34.1969055>,
    <-1.3936838, 1.3546024, 34.1938690>,
    <-1.4049763, 1.3261364, 34.1698789>,
    <-1.3901489, 1.3460001, 34.1765488>,
    <-1.3868827, 1.3428573, 34.1665078>,
    <-1.3473327, 1.3878260, 34.1755900>,
    <-1.4773464, 1.2402537, 34.1620860>,
    <-1.4741161, 1.2375130, 34.1516897>,
    <-1.4373906, 1.2891334, 34.1665078>,
    <-1.4299609, 1.2919132, 34.1581668>,
    <-1.4807442, 1.2431332, 34.1722289>,
    <-1.4356086, 1.2969958, 34.1755900>,
    <-1.4008333, -1.3208914, 34.1542153>,
    <-1.3638568, -1.3630768, 34.1620860>,
    <-1.4862136, -1.2464224, 34.1849198>,
    <-1.4779500, -1.2395344, 34.1620860>,
    <-1.3849154, -1.3395426, 34.1576891>,
    <-1.4182624, -1.3130979, 34.1722289>,
    <-1.4813758, -1.2423806, 34.1722289>,
    <-1.4352467, -1.2859514, 34.1576891>,
    <-1.4330980, -1.2933825, 34.1659804>,
    <-1.4746900, -1.2368291, 34.1516897>,
    <-1.3818915, -1.3367046, 34.1472010>,
    <-1.4276226, -1.2885694, 34.1481994>,
    <-1.3079840, -1.4111579, 34.1516897>,
    <-1.3399944, -1.3788199, 34.1481994>,
    <-1.3261364, -1.4049763, 34.1698789>,
    <-1.3712440, -1.3704999, 34.1848862>,
    <-1.3460001, -1.3901489, 34.1765488>,
    <-1.4226517, -1.3172213, 34.1848862>,
    <-1.3428573, -1.3868827, 34.1665078>,
    <-1.3878260, -1.3473327, 34.1755900>,
    <-1.2891334, -1.4373906, 34.1665078>,
    <-1.2919132, -1.4299609, 34.1581668>,
    <-1.3179892, -1.4219335, 34.1848862>,
    <-1.2969958, -1.4356086, 34.1755900>,
    <-1.3448638, 1.4269613, 34.2635082>,
    <-1.3887880, 1.3910259, 34.2695801>,
    <-1.3096643, 1.4628123, 34.2662252>,
    <-1.3381141, 1.4499018, 34.2772285>,
    <-1.3642557, 1.4115561, 34.2662252>,
    <-1.3176483, 1.4632268, 34.2725930>,
    <-1.4944285, 1.2548382, 34.2505667>,
    <-1.3786535, 1.3796290, 34.2505227>,
    <-1.4364773, 1.3318669, 34.2614925>,
    <-1.4304015, 1.3260564, 34.2505227>,
    <-1.3599665, 1.4063236, 34.2579678>,
    <-1.4029788, 1.3638736, 34.2587527>,
    <-1.3250498, 1.4313430, 34.2505227>,
    <-1.3111441, 1.4530158, 34.2587527>,
    <-1.4116741, 1.3326922, 34.2365221>,
    <-1.3931224, 1.3491465, 34.2333423>,
    <-1.3975023, 1.3533464, 34.2427845>,
    <-1.3543434, 1.3952996, 34.2418824>,
    <-1.4835175, 1.2456502, 34.2291393>,
    <-1.4880972, 1.2495196, 34.2387176>,
    <-1.4438758, 1.2951710, 34.2333423>,
    <-1.4431078, 1.3039820, 34.2418824>,
    <-1.4790972, 1.2419121, 34.2192172>,
    <-1.4354840, 1.2971443, 34.2254131>,
    <-1.4060558, -1.3255794, 34.2216509>,
    <-1.4843360, -1.2446747, 34.2291393>,
    <-1.4952792, -1.2538244, 34.2505667>,
    <-1.3697891, -1.3687313, 34.2291393>,
    <-1.4409686, -1.2908559, 34.2249699>,
    <-1.4889419, -1.2485129, 34.2387176>,
    <-1.4255331, -1.3195740, 34.2387176>,
    <-1.3904544, -1.3446514, 34.2249699>,
    <-1.4397381, -1.2991368, 34.2328318>,
    <-1.3126390, -1.4158989, 34.2192172>,
    <-1.3863046, -1.3407409, 34.2149211>,
    <-1.3443920, -1.3830867, 34.2158771>,
    <-1.4798872, -1.2409707, 34.2192172>,
    <-1.4322780, -1.2925551, 34.2158771>,
    <-1.3326922, -1.4116741, 34.2365221>,
    <-1.3796290, -1.3786535, 34.2505227>,
    <-1.3491465, -1.3931224, 34.2333423>,
    <-1.4313430, -1.3250498, 34.2505227>,
    <-1.3533464, -1.3975023, 34.2427845>,
    <-1.3952996, -1.3543434, 34.2418824>,
    <-1.3260564, -1.4304015, 34.2505227>,
    <-1.2951710, -1.4438758, 34.2333423>,
    <-1.3039820, -1.4431078, 34.2418824>,
    <-1.2971443, -1.4354840, 34.2254131>,
    <-1.3531690, 1.4353566, 34.2371711>,
    <-1.3973296, 1.3984436, 34.2427102>,
    <-1.3726918, 1.4194838, 34.2396408>,
    <-1.3472586, 1.4554648, 34.2497196>,
    <-1.3177746, 1.4710498, 34.2396408>,
    <-1.3263302, 1.4699016, 34.2454279>,
    <-1.3877103, 1.3885971, 34.2253660>,
    <-1.3337577, 1.4406510, 34.2253660>,
    <-1.3685278, 1.4150771, 34.2321345>,
    <-1.3193583, 1.4620192, 34.2328481>,
    <-1.5042377, 1.2629905, 34.2254060>,
    <-1.4397951, 1.3346729, 34.2253660>,
    <-1.4453186, 1.3399551, 34.2353389>,
    <-1.4117676, 1.3723130, 34.2328481>,
    <-1.4216146, 1.3419861, 34.2126378>,
    <-1.4070577, 1.3625095, 34.2183311>,
    <-1.4030759, 1.3586914, 34.2097470>,
    <-1.3636492, 1.4047865, 34.2175110>,
    <-1.4942954, 1.2546183, 34.2059260>,
    <-1.4902769, 1.2512201, 34.1969055>,
    <-1.4541849, 1.3043341, 34.2097470>,
    <-1.4460812, 1.3066312, 34.2025384>,
    <-1.4984588, 1.2581360, 34.2146338>,
    <-1.4530119, 1.3128473, 34.2175110>,
    <-1.4165071, -1.3355199, 34.1991181>,
    <-1.3796518, -1.3786902, 34.2059260>,
    <-1.5050110, -1.2620689, 34.2254060>,
    <-1.4950395, -1.2537315, 34.2059260>,
    <-1.4006505, -1.3546050, 34.2021355>,
    <-1.4353692, -1.3287797, 34.2146338>,
    <-1.4992267, -1.2572208, 34.2146338>,
    <-1.4515419, -1.3004113, 34.2021355>,
    <-1.4499486, -1.3084426, 34.2092829>,
    <-1.4909951, -1.2503642, 34.1969055>,
    <-1.3968780, -1.3510500, 34.1929998>,
    <-1.4431666, -1.3024592, 34.1938690>,
    <-1.3224752, -1.4266108, 34.1969055>,
    <-1.3546024, -1.3936838, 34.1938690>,
    <-1.3419861, -1.4216146, 34.2126378>,
    <-1.3885971, -1.3877103, 34.2253660>,
    <-1.3625095, -1.4070577, 34.2183311>,
    <-1.4406510, -1.3337577, 34.2253660>,
    <-1.3586914, -1.4030759, 34.2097470>,
    <-1.4047865, -1.3636492, 34.2175110>,
    <-1.3043341, -1.4541849, 34.2097470>,
    <-1.3066312, -1.4460812, 34.2025384>,
    <-1.3346729, -1.4397951, 34.2253660>,
    <-1.3128473, -1.4530119, 34.2175110>,
    <-1.3955896, 1.4317839, 34.2989756>,
    <-1.3763591, 1.4473602, 34.2967794>,
    <-1.3461645, 1.4910546, 34.3035582>,
    <-1.3886759, 1.4370947, 34.2980080>,
    <-1.3276352, 1.5060149, 34.3007507>,
    <-1.3208785, 1.5183062, 34.3035582>,
    <-1.3758002, 1.4556262, 34.3008727>,
    <-1.3525648, 1.4799986, 34.3007914>,
    <-1.4028414, 1.4329948, 34.3035582>,
    <-1.4498168, 1.3738749, 34.2975521>,
    <-1.3731947, 1.4627868, 34.3035582>,
    <-1.4260141, 1.4043622, 34.3007100>,
    <-1.4222357, 1.4025885, 34.2980080>,
    <-1.4003392, 1.4301860, 34.3007914>,
    <-1.5121171, 1.2844489, 34.2867877>,
    <-1.4748794, 1.3396781, 34.2937748>,
    <-1.4312540, 1.3822173, 34.2926777>,
    <-1.4336365, 1.3849977, 34.2951914>,
    <-1.3601875, 1.4562429, 34.2933120>,
    <-1.3330210, 1.4858963, 34.2949171>,
    <-1.3683772, 1.4515979, 34.2949171>,
    <-1.3315298, 1.4951741, 34.2980246>,
    <-1.3987627, 1.4028751, 34.2854038>,
    <-1.4483245, 1.3522076, 34.2856693>,
    <-1.3784558, 1.4314558, 34.2900253>,
    <-1.4118009, 1.3990510, 34.2908029>,
    <-1.3449776, 1.4556007, 34.2856693>,
    <-1.3343974, 1.4753890, 34.2908029>,
    <-1.4329609, 1.3534512, 34.2753407>,
    <-1.4139312, 1.3700924, 34.2729301>,
    <-1.4185357, 1.3750601, 34.2800513>,
    <-1.3740799, 1.4184798, 34.2795037>,
    <-1.5054039, 1.2650174, 34.2695801>,
    <-1.5096075, 1.2711775, 34.2772285>,
    <-1.4655226, 1.3152944, 34.2729301>,
    <-1.4644715, 1.3257420, 34.2795037>,
    <-1.5006107, 1.2601008, 34.2614925>,
    <-1.4567582, 1.3165050, 34.2665723>,
    <-1.4269415, -1.3448613, 34.2635082>,
    <-1.5072095, -1.2628656, 34.2695801>,
    <-1.5275110, -1.2661032, 34.2867877>,
    <-1.3909641, -1.3887836, 34.2695801>,
    <-1.4627678, -1.3096586, 34.2662252>,
    <-1.5140059, -1.2659357, 34.2772285>,
    <-1.4496546, -1.3380967, 34.2772285>,
    <-1.4115116, -1.3642500, 34.2662252>,
    <-1.4630488, -1.3176256, 34.2725930>,
    <-1.3318669, -1.4364773, 34.2614925>,
    <-1.4063236, -1.3599665, 34.2579678>,
    <-1.3638736, -1.4029788, 34.2587527>,
    <-1.5015354, -1.2589989, 34.2614925>,
    <-1.4530158, -1.3111441, 34.2587527>,
    <-1.3534869, -1.4330047, 34.2753407>,
    <-1.4030731, -1.3990019, 34.2854038>,
    <-1.3700678, -1.4139421, 34.2729301>,
    <-1.4554187, -1.3451221, 34.2856693>,
    <-1.3751404, -1.4186341, 34.2800513>,
    <-1.4183812, -1.3741235, 34.2795037>,
    <-1.3524929, -1.4485628, 34.2856693>,
    <-1.3153199, -1.4655439, 34.2729301>,
    <-1.3258440, -1.4645568, 34.2795037>,
    <-1.3165050, -1.4567582, 34.2665723>,
    <-1.3735136, 1.4567257, 34.2672347>,
    <-1.4193451, 1.4191357, 34.2713545>,
    <-1.3937294, 1.4406557, 34.2690979>,
    <-1.3716394, 1.4758370, 34.2765463>,
    <-1.3379896, 1.4929905, 34.2690979>,
    <-1.3484057, 1.4916021, 34.2734378>,
    <-1.4076727, 1.4086752, 34.2582019>,
    <-1.3529399, 1.4614785, 34.2582019>,
    <-1.3886069, 1.4359359, 34.2634197>,
    <-1.3387532, 1.4836073, 34.2639559>,
    <-1.5258911, 1.2812624, 34.2582471>,
    <-1.4605109, 1.3539745, 34.2582019>,
    <-1.4667126, 1.3598925, 34.2658251>,
    <-1.4325218, 1.3925877, 34.2639559>,
    <-1.4412734, 1.3606598, 34.2481381>,
    <-1.4268699, 1.3818032, 34.2526827>,
    <-1.4222935, 1.3774257, 34.2458152>,
    <-1.3827932, 1.4246296, 34.2520259>,
    <-1.5145192, 1.2717078, 34.2427102>,
    <-1.5098347, 1.2677553, 34.2353389>,
    <-1.4741116, 1.3223190, 34.2458152>,
    <-1.4654214, 1.3242318, 34.2399571>,
    <-1.5193216, 1.2757568, 34.2497196>,
    <-1.4734245, 1.3313924, 34.2520259>,
    <-1.4353566, -1.3531690, 34.2371711>,
    <-1.3984436, -1.3973296, 34.2427102>,
    <-1.5267654, -1.2802205, 34.2582471>,
    <-1.5153812, -1.2706805, 34.2427102>,
    <-1.4194838, -1.3726918, 34.2396408>,
    <-1.4554648, -1.3472586, 34.2497196>,
    <-1.5202026, -1.2747069, 34.2497196>,
    <-1.4710498, -1.3177746, 34.2396408>,
    <-1.4699016, -1.3263302, 34.2454279>,
    <-1.5106753, -1.2667535, 34.2353389>,
    <-1.4150771, -1.3685278, 34.2321345>,
    <-1.4620192, -1.3193583, 34.2328481>,
    <-1.3399551, -1.4453186, 34.2353389>,
    <-1.3723130, -1.4117676, 34.2328481>,
    <-1.3606598, -1.4412734, 34.2481381>,
    <-1.4086752, -1.4076727, 34.2582019>,
    <-1.3818032, -1.4268699, 34.2526827>,
    <-1.4614785, -1.3529399, 34.2582019>,
    <-1.3774257, -1.4222935, 34.2458152>,
    <-1.4246296, -1.3827932, 34.2520259>,
    <-1.3223190, -1.4741116, 34.2458152>,
    <-1.3242318, -1.4654214, 34.2399571>,
    <-1.3539745, -1.4605109, 34.2582019>,
    <-1.3313924, -1.4734245, 34.2520259>,
    <-1.4885539, 1.3385990, 34.2989756>,
    <-1.4717283, 1.3678218, 34.3035582>,
    <-1.4727928, 1.3522401, 34.2980080>,
    <-1.4359766, 1.4011705, 34.3035582>,
    <-1.4812914, 1.3513635, 34.3008727>,
    <-1.4526574, 1.3788390, 34.3007914>,
    <-1.5414487, 1.2747254, 34.2967794>,
    <-1.5092243, 1.3334571, 34.3035582>,
    <-1.5446987, 1.2865044, 34.3007507>,
    <-1.5115204, 1.3121511, 34.2980080>,
    <-1.5129386, 1.3196825, 34.3007914>,
    <-1.5327868, 1.2733701, 34.2926777>,
    <-1.4998373, 1.3171061, 34.2951914>,
    <-1.4566813, -1.3608548, 34.2933120>,
    <-1.5230277, -1.2966786, 34.2967794>,
    <-1.4484874, -1.3773285, 34.2967794>,
    <-1.4859043, -1.3337058, 34.2949171>,
    <-1.5351925, -1.2978333, 34.3007507>,
    <-1.5077010, -1.3291504, 34.3007507>,
    <-1.4524890, -1.3692289, 34.2949171>,
    <-1.4959901, -1.3326417, 34.2980246>,
    <-1.3828722, -1.4318025, 34.2926777>,
    <-1.4318461, -1.3789205, 34.2900253>,
    <-1.3996822, -1.4123281, 34.2908029>,
    <-1.5201890, -1.2883835, 34.2926777>,
    <-1.4751534, -1.3347577, 34.2908029>,
    <-1.4326909, -1.3963537, 34.2989756>,
    <-1.4923586, -1.3472630, 34.3035582>,
    <-1.4381497, -1.3895610, 34.2980080>,
    <-1.5202094, -1.3224711, 34.3035582>,
    <-1.4566931, -1.3766991, 34.3008727>,
    <-1.4814783, -1.3538041, 34.3007914>,
    <-1.4635720, -1.3738646, 34.3035582>,
    <-1.4032047, -1.4227580, 34.2980080>,
    <-1.4308673, -1.4009191, 34.3007914>,
    <-1.3856263, -1.4341658, 34.2951914>,
    <-1.5002879, 1.3801057, 34.2894178>,
    <-1.5347117, 1.3429869, 34.2886791>,
    <-1.5253778, 1.3627281, 34.2918019>,
    <-1.4826563, 1.4054496, 34.2918021>,
    <-1.5180183, 1.3606349, 34.2889154>,
    <-1.5297231, 1.3536563, 34.2903193>,
    <-1.5057554, 1.3823505, 34.2918020>,
    <-1.4940292, 1.3896202, 34.2904043>,
    <-1.5136402, 1.3698742, 34.2903618>,
    <-1.4686196, 1.4079043, 34.2882666>,
    <-1.4570670, 1.4310388, 34.2918020>,
    <-1.4441460, 1.4393009, 34.2903406>,
    <-1.4884919, 1.3901613, 34.2889155>,
    <-1.4705437, 1.4129707, 34.2903619>,
    <-1.5593187, 1.2952754, 34.2830970>,
    <-1.5018021, 1.3669171, 34.2861105>,
    <-1.5409868, 1.3291225, 34.2867237>,
    <-1.5153833, 1.3578693, 34.2874565>,
    <-1.4332190, 1.4380440, 34.2863580>,
    <-1.4487963, 1.4248501, 34.2872643>,
    <-1.4148973, 1.4588602, 34.2872642>,
    <-1.4306866, 1.4482363, 34.2889216>,
    <-1.4433685, 1.4157200, 34.2817250>,
    <-1.3897029, 1.4694809, 34.2819690>,
    <-1.4361558, 1.4298538, 34.2845089>,
    <-1.3963976, 1.4705064, 34.2850029>,
    <-1.4941912, 1.3636574, 34.2819691>,
    <-1.4733418, 1.3931180, 34.2850030>,
    <-1.4659218, 1.3787787, 34.2751874>,
    <-1.4547582, 1.3969696, 34.2783022>,
    <-1.4452379, 1.3973253, 34.2735942>,
    <-1.4093286, 1.4420897, 34.2779937>,
    <-1.5382602, 1.2903580, 34.2713545>,
    <-1.5321951, 1.2866163, 34.2658251>,
    <-1.4978118, 1.3412961, 34.2735942>,
    <-1.4873938, 1.3441801, 34.2692880>,
    <-1.5461266, 1.2928802, 34.2765463>,
    <-1.5012127, 1.3470860, 34.2779937>,
    <-1.5115223, -1.3689293, 34.2894147>,
    <-1.4792070, -1.3975134, 34.2882644>,
    <-1.4988086, -1.3892970, 34.2917975>,
    <-1.4998323, -1.3789518, 34.2889127>,
    <-1.4607291, -1.4227174, 34.2903377>,
    <-1.4754789, -1.4126266, 34.2917980>,
    <-1.5075156, -1.3761336, 34.2904005>,
    <-1.4859680, -1.3975461, 34.2903585>,
    <-1.5347176, -1.3533880, 34.2917974>,
    <-1.5398662, -1.3380116, 34.2886767>,
    <-1.5186057, -1.3694999, 34.2917973>,
    <-1.5375412, -1.3458379, 34.2903158>,
    <-1.5262740, -1.3525101, 34.2889125>,
    <-1.5243720, -1.3591421, 34.2903580>,
    <-1.5443021, -1.3132289, 34.2830965>,
    <-1.5411939, -1.3296327, 34.2867222>,
    <-1.5028210, -1.3666849, 34.2861091>,
    <-1.5204471, -1.3533298, 34.2874544>,
    <-1.4566850, -1.3735632, 34.2672347>,
    <-1.4189985, -1.4195125, 34.2713544>,
    <-1.5377333, -1.2909897, 34.2713544>,
    <-1.4405642, -1.3938409, 34.2690979>,
    <-1.4752880, -1.3723089, 34.2765461>,
    <-1.5411713, -1.2988010, 34.2765461>,
    <-1.4928990, -1.3381012, 34.2690979>,
    <-1.4912361, -1.3488520, 34.2734378>,
    <-1.5331326, -1.2854991, 34.2658251>,
    <-1.4359359, -1.3886069, 34.2634197>,
    <-1.4836073, -1.3387532, 34.2639559>,
    <-1.3598925, -1.4667126, 34.2658251>,
    <-1.3925877, -1.4325218, 34.2639559>,
    <-1.4364979, -1.4347671, 34.2863567>,
    <-1.4224817, -1.4511491, 34.2872627>,
    <-1.4568137, -1.4169637, 34.2872627>,
    <-1.4444909, -1.4344318, 34.2889195>,
    <-1.4153013, -1.4437940, 34.2817246>,
    <-1.4687281, -1.3905762, 34.2819686>,
    <-1.4291843, -1.4368298, 34.2845080>,
    <-1.4693254, -1.3976588, 34.2850020>,
    <-1.3627360, -1.4950198, 34.2819686>,
    <-1.3916220, -1.4747758, 34.2850020>,
    <-1.3786893, -1.4660132, 34.2751874>,
    <-1.3967685, -1.4549638, 34.2783020>,
    <-1.3972338, -1.4453495, 34.2735942>,
    <-1.4417237, -1.4097750, 34.2779935>,
    <-1.3411866, -1.4979058, 34.2735942>,
    <-1.3441801, -1.4873938, 34.2692880>,
    <-1.3466481, -1.5015888, 34.2779935>,
    <-1.5538273, 1.3257446, 34.2894172>,
    <-1.5523479, 1.3357579, 34.2918011>,
    <-1.5532892, 1.3300520, 34.2904035>,
    <-1.5405366, 1.3475692, 34.2918015>,
    <-1.5467802, 1.3315649, 34.2889150>,
    <-1.5426245, 1.3408898, 34.2903614>,
    <-1.5722714, 1.3007129, 34.2886786>,
    <-1.5692207, 1.2966148, 34.2867235>,
    <-1.5611315, 1.3156731, 34.2889147>,
    <-1.5550713, 1.3169488, 34.2874561>,
    <-1.5735858, 1.3058909, 34.2903183>,
    <-1.5619274, 1.3261783, 34.2918006>,
    <-1.5626619, 1.3196200, 34.2903608>,
    <-1.5571178, -1.3223273, 34.2894157>,
    <-1.5563876, -1.3317180, 34.2917992>,
    <-1.5504016, -1.3280051, 34.2889131>,
    <-1.5469918, -1.3411139, 34.2917981>,
    <-1.5568845, -1.3263873, 34.2904018>,
    <-1.5480271, -1.3354871, 34.2903587>,
    <-1.5746388, -1.2975014, 34.2886783>,
    <-1.5638646, -1.3242411, 34.2918006>,
    <-1.5764024, -1.3021955, 34.2903187>,
    <-1.5633913, -1.3131280, 34.2889139>,
    <-1.5651680, -1.3168363, 34.2903604>,
    <-1.5681565, -1.2975869, 34.2867229>,
    <-1.5554543, -1.3168128, 34.2874549>,
    <-1.4682841, 1.0797083, 34.0217848>,
    <-1.5187525, 1.0192072, 34.0240042>,
    <-1.4405164, 1.1250355, 34.0233960>,
    <-1.4851743, 1.0932492, 34.0307448>,
    <-1.4917338, 1.0515869, 34.0227072>,
    <-1.4595311, 1.1145063, 34.0272373>,
    <-1.4747001, 1.0385541, 34.0159774>,
    <-1.5329913, 0.9694786, 34.0184328>,
    <-1.5085190, 0.9902556, 34.0159774>,
    <-1.4709472, 1.0640199, 34.0194142>,
    <-1.5048884, 1.0144705, 34.0191093>,
    <-1.4332670, 1.0977271, 34.0159774>,
    <-1.4338137, 1.1162180, 34.0196603>,
    <-1.5053184, 1.1212227, 34.0581798>,
    <-1.5391660, 1.0781955, 34.0677166>,
    <-1.4777628, 1.1602034, 34.0621232>,
    <-1.4994379, 1.1380274, 34.0805061>,
    <-1.5206852, 1.1028200, 34.0621232>,
    <-1.4840204, 1.1563715, 34.0723106>,
    <-1.6171228, 0.9317724, 34.0416659>,
    <-1.5287114, 1.0699178, 34.0420789>,
    <-1.5756080, 1.0164984, 34.0557354>,
    <-1.5674880, 1.0115060, 34.0419288>,
    <-1.5165261, 1.1000008, 34.0506039>,
    <-1.5498975, 1.0526892, 34.0517365>,
    <-1.4883531, 1.1244079, 34.0419288>,
    <-1.4781135, 1.1520318, 34.0517365>,
    <-1.5465343, 1.0050952, 34.0292978>,
    <-1.5363724, 1.0098710, 34.0267837>,
    <-1.5396744, 1.0364012, 34.0346523>,
    <-1.5117626, 1.0698830, 34.0334787>,
    <-1.5821482, 0.9179763, 34.0240280>,
    <-1.5992959, 0.9201766, 34.0306775>,
    <-1.5614712, 0.9703083, 34.0267837>,
    <-1.5692878, 0.9847971, 34.0334787>,
    <-1.5563627, 0.9320477, 34.0185953>,
    <-1.5502128, 0.9657854, 34.0222412>,
    <-1.5216848, -1.0072247, 34.0221521>,
    <-1.5887943, -0.9171288, 34.0252783>,
    <-1.6165466, -0.9341496, 34.0418026>,
    <-1.4902029, -1.0689966, 34.0252783>,
    <-1.5528096, -0.9669270, 34.0235337>,
    <-1.6005105, -0.9253193, 34.0315713>,
    <-1.5457770, -1.0125493, 34.0315713>,
    <-1.5075177, -1.0354924, 34.0235337>,
    <-1.5539837, -0.9840584, 34.0277883>,
    <-1.4784985, -1.0353077, 34.0159774>,
    <-1.4322697, -1.1228976, 34.0197144>,
    <-1.4332575, -1.0999178, 34.0159774>,
    <-1.5043263, -1.0189904, 34.0195520>,
    <-1.4685204, -1.0715494, 34.0196603>,
    <-1.5237394, -0.9706975, 34.0159774>,
    <-1.5754838, -0.9116389, 34.0197144>,
    <-1.5409467, -0.9650089, 34.0196603>,
    <-1.4787142, -1.1072898, 34.0300324>,
    <-1.5290230, -1.0701946, 34.0421478>,
    <-1.4835997, -1.0921309, 34.0277479>,
    <-1.5675546, -1.0124453, 34.0420666>,
    <-1.5030225, -1.0909903, 34.0349278>,
    <-1.5294975, -1.0485455, 34.0340297>,
    <-1.4872800, -1.1272036, 34.0420666>,
    <-1.4487714, -1.1381528, 34.0277479>,
    <-1.4642290, -1.1388270, 34.0340297>,
    <-1.4394200, -1.1321157, 34.0233431>,
    <-1.5163691, 1.1294343, 34.1168394>,
    <-1.5503928, 1.0861425, 34.1264018>,
    <-1.4882421, 1.1685196, 34.1210460>,
    <-1.5107733, 1.1468373, 34.1387967>,
    <-1.5314829, 1.1107057, 34.1210460>,
    <-1.4945908, 1.1648057, 34.1311462>,
    <-1.6336862, 0.9435503, 34.0973598>,
    <-1.5444498, 1.0818114, 34.0973402>,
    <-1.5879990, 1.0243391, 34.1138015>,
    <-1.5847147, 1.0221115, 34.0973402>,
    <-1.5288617, 1.1087293, 34.1083733>,
    <-1.5623959, 1.0609663, 34.1095803>,
    <-1.5021053, 1.1400540, 34.0973402>,
    <-1.4900385, 1.1611377, 34.1095803>,
    <-1.5721830, 1.0343123, 34.0775018>,
    <-1.5580150, 1.0536816, 34.0732308>,
    <-1.5603742, 1.0552255, 34.0861763>,
    <-1.5265674, 1.1026625, 34.0849170>,
    <-1.6279089, 0.9402125, 34.0677166>,
    <-1.6305727, 0.9417139, 34.0805061>,
    <-1.5973798, 0.9935848, 34.0732308>,
    <-1.5958239, 1.0006648, 34.0849170>,
    <-1.6241137, 0.9381966, 34.0557354>,
    <-1.5910383, 0.9978298, 34.0632019>,
    <-1.5685065, -1.0310378, 34.0581798>,
    <-1.6282211, -0.9396960, 34.0677166>,
    <-1.6339816, -0.9430386, 34.0973598>,
    <-1.5396203, -1.0775708, 34.0677166>,
    <-1.5956871, -0.9918203, 34.0621232>,
    <-1.6308344, -0.9412604, 34.0805061>,
    <-1.5822339, -1.0197825, 34.0805061>,
    <-1.5564446, -1.0517805, 34.0621232>,
    <-1.5941986, -0.9990207, 34.0723106>,
    <-1.4941745, -1.1328939, 34.0557354>,
    <-1.5524635, -1.0488054, 34.0506039>,
    <-1.5194118, -1.0963481, 34.0517365>,
    <-1.6246336, -0.9373924, 34.0557354>,
    <-1.5882118, -0.9949161, 34.0517365>,
    <-1.5096592, -1.1236113, 34.0775018>,
    <-1.5448031, -1.0813069, 34.0973402>,
    <-1.5230215, -1.1036708, 34.0732308>,
    <-1.5850506, -1.0215958, 34.0973402>,
    <-1.5252670, -1.1053638, 34.0861763>,
    <-1.5582806, -1.0573714, 34.0849170>,
    <-1.5024749, -1.1395620, 34.0973402>,
    <-1.4800125, -1.1612159, 34.0732308>,
    <-1.4861212, -1.1573365, 34.0849170>,
    <-1.4818692, -1.1537924, 34.0632019>,
    <-1.4835207, 1.0927181, 34.0203512>,
    <-1.5338369, 1.0353303, 34.0223895>,
    <-1.5068329, 1.0662597, 34.0212277>,
    <-1.4981845, 1.1110248, 34.0274816>,
    <-1.4553072, 1.1379803, 34.0214715>,
    <-1.4731789, 1.1304449, 34.0246132>,
    <-1.4942204, 1.0441188, 34.0159774>,
    <-1.4484992, 1.1094156, 34.0159774>,
    <-1.4880304, 1.0736142, 34.0185183>,
    <-1.4490097, 1.1280615, 34.0186456>,
    <-1.5399415, 0.9788219, 34.0159774>,
    <-1.5649294, 0.9610410, 34.0181888>,
    <-1.5268071, 1.0184476, 34.0184505>,
    <-1.5207907, 1.1327195, 34.0506060>,
    <-1.5548565, 1.0891533, 34.0592183>,
    <-1.5362627, 1.1140868, 34.0541438>,
    <-1.5145418, 1.1494525, 34.0708032>,
    <-1.4929007, 1.1720593, 34.0541438>,
    <-1.4990839, 1.1680746, 34.0633523>,
    <-1.5445771, 1.0813391, 34.0364403>,
    <-1.5034234, 1.1371527, 34.0363571>,
    <-1.5322121, 1.1113558, 34.0438443>,
    <-1.4933882, 1.1639141, 34.0448606>,
    <-1.6341867, 0.9412026, 34.0360749>,
    <-1.5840260, 1.0221541, 34.0363571>,
    <-1.5918363, 1.0269410, 34.0484530>,
    <-1.5659138, 1.0635430, 34.0448606>,
    <-1.5630679, 1.0175857, 34.0261958>,
    <-1.5555827, 1.0484278, 34.0302748>,
    <-1.5521037, 1.0241921, 34.0243202>,
    <-1.5258836, 1.0852891, 34.0294875>,
    <-1.6037879, 0.9242215, 34.0224007>,
    <-1.5931703, 0.9147063, 34.0183066>,
    <-1.5806890, 0.9796105, 34.0243202>,
    <-1.5734184, 0.9697307, 34.0209236>,
    <-1.6174849, 0.9300928, 34.0274088>,
    <-1.5865879, 0.9956308, 34.0294875>,
    <-1.5377743, -1.0178817, 34.0204813>,
    <-1.5059183, -1.0802821, 34.0228405>,
    <-1.6333695, -0.9438886, 34.0361559>,
    <-1.6055522, -0.9268099, 34.0228405>,
    <-1.5234387, -1.0464380, 34.0215203>,
    <-1.5619957, -1.0231893, 34.0277741>,
    <-1.6173059, -0.9350413, 34.0277741>,
    <-1.5692103, -0.9771469, 34.0215203>,
    <-1.5703393, -0.9944277, 34.0248083>,
    <-1.4942110, -1.0463101, 34.0159774>,
    <-1.5921768, -0.9213005, 34.0186848>,
    <-1.5399335, -0.9810123, 34.0159774>,
    <-1.5202660, -1.0297920, 34.0185671>,
    <-1.5572738, -0.9752369, 34.0186456>,
    <-1.4484886, -1.1116078, 34.0159774>,
    <-1.4474425, -1.1348004, 34.0186848>,
    <-1.4840785, -1.0829080, 34.0186456>,
    <-1.4942495, -1.1189364, 34.0264558>,
    <-1.5449284, -1.0813464, 34.0364647>,
    <-1.5187510, -1.1024224, 34.0303723>,
    <-1.5838627, -1.0229968, 34.0364059>,
    <-1.4992152, -1.1036384, 34.0246615>,
    <-1.5455143, -1.0595419, 34.0296825>,
    <-1.4640202, -1.1501444, 34.0246615>,
    <-1.4546242, -1.1440837, 34.0213137>,
    <-1.5027512, -1.1389497, 34.0364059>,
    <-1.4795620, -1.1507677, 34.0296825>,
    <-1.5307590, 1.1403252, 34.1722608>,
    <-1.5658678, 1.0971731, 34.1809181>,
    <-1.5026896, 1.1800319, 34.1760819>,
    <-1.5268124, 1.1591982, 34.1920745>,
    <-1.5463505, 1.1216654, 34.1760819>,
    <-1.5098749, 1.1768952, 34.1852017>,
    <-1.6475429, 0.9517080, 34.1544411>,
    <-1.5575303, 1.0911441, 34.1544124>,
    <-1.6028176, 1.0340824, 34.1694828>,
    <-1.5981425, 1.0309377, 34.1544124>,
    <-1.5426985, 1.1189318, 34.1645454>,
    <-1.5766335, 1.0708116, 34.1656437>,
    <-1.5148211, 1.1498805, 34.1544124>,
    <-1.5036150, 1.1718831, 34.1656437>,
    <-1.5839949, 1.0422350, 34.1359011>,
    <-1.5695568, 1.0616084, 34.1317777>,
    <-1.5726653, 1.0637097, 34.1440880>,
    <-1.5384779, 1.1114558, 34.1429132>,
    <-1.6397848, 0.9471696, 34.1264018>,
    <-1.6429359, 0.9490198, 34.1387967>,
    <-1.6092170, 1.0010710, 34.1317777>,
    <-1.6082960, 1.0086476, 34.1429132>,
    <-1.6368636, 0.9454509, 34.1138015>,
    <-1.6030287, 1.0053377, 34.1216372>,
    <-1.5799498, -1.0386316, 34.1168394>,
    <-1.6401653, -0.9465105, 34.1264018>,
    <-1.6479748, -0.9509600, 34.1544411>,
    <-1.5509057, -1.0854101, 34.1264018>,
    <-1.6070580, -0.9988329, 34.1210460>,
    <-1.6433432, -0.9483143, 34.1387967>,
    <-1.5943895, -1.0274211, 34.1387967>,
    <-1.5675199, -1.0592395, 34.1210460>,
    <-1.6057395, -1.0060690, 34.1311462>,
    <-1.5056916, -1.1418864, 34.1138015>,
    <-1.5647662, -1.0574523, 34.1083733>,
    <-1.5313531, -1.1053001, 34.1095803>,
    <-1.6372163, -0.9448400, 34.1138015>,
    <-1.6007357, -1.0030458, 34.1095803>,
    <-1.5211387, -1.1320029, 34.1359011>,
    <-1.5580468, -1.0904065, 34.1544124>,
    <-1.5344056, -1.1118095, 34.1317777>,
    <-1.5986335, -1.0301839, 34.1544124>,
    <-1.5374434, -1.1140119, 34.1440880>,
    <-1.5706173, -1.0655561, 34.1429132>,
    <-1.5153615, -1.1491612, 34.1544124>,
    <-1.4910836, -1.1697830, 34.1317777>,
    <-1.4978883, -1.1663261, 34.1429132>,
    <-1.4929766, -1.1625086, 34.1216372>,
    <-1.5309945, 1.1402803, 34.1038334>,
    <-1.5651317, 1.0964132, 34.1125260>,
    <-1.5461641, 1.1213029, 34.1076575>,
    <-1.5248467, 1.1574616, 34.1237934>,
    <-1.5025088, 1.1796733, 34.1076575>,
    <-1.5086935, 1.1757421, 34.1168389>,
    <-1.5597290, 1.0924758, 34.0861074>,
    <-1.5169667, 1.1512949, 34.0861074>,
    <-1.5437811, 1.1195061, 34.0961373>,
    <-1.5045550, 1.1724075, 34.0972345>,
    <-1.6498473, 0.9528499, 34.0861253>,
    <-1.6003912, 1.0321851, 34.0861074>,
    <-1.6033769, 1.0342102, 34.1010718>,
    <-1.5776170, 1.0712570, 34.0972345>,
    <-1.5880662, 1.0447304, 34.0680823>,
    <-1.5760032, 1.0657616, 34.0759583>,
    <-1.5738203, 1.0643394, 34.0642124>,
    <-1.5418784, 1.1136857, 34.0748134>,
    <-1.6444990, 0.9497673, 34.0592183>,
    <-1.6408387, 0.9478353, 34.0484530>,
    <-1.6135820, 1.0036346, 34.0642124>,
    <-1.6073223, 1.0080153, 34.0551646>,
    <-1.6469907, 0.9511653, 34.0708032>,
    <-1.6118256, 1.0106677, 34.0748134>,
    <-1.5846018, -1.0416449, 34.0506060>,
    <-1.5552838, -1.0885673, 34.0592183>,
    <-1.6501159, -0.9523847, 34.0861253>,
    <-1.6447908, -0.9492860, 34.0592183>,
    <-1.5723597, -1.0625651, 34.0541438>,
    <-1.5981359, -1.0300679, 34.0708032>,
    <-1.6472287, -0.9507531, 34.0708032>,
    <-1.6120055, -1.0019904, 34.0541438>,
    <-1.6103480, -1.0091731, 34.0633523>,
    <-1.6413435, -0.9470573, 34.0484530>,
    <-1.5684986, -1.0596618, 34.0438443>,
    <-1.6046017, -1.0052056, 34.0448606>,
    <-1.5095377, -1.1445719, 34.0484530>,
    <-1.5350890, -1.1076864, 34.0448606>,
    <-1.5248815, -1.1349734, 34.0680823>,
    <-1.5600502, -1.0920171, 34.0861074>,
    <-1.5405132, -1.1164467, 34.0759583>,
    <-1.6006965, -1.0317164, 34.0861074>,
    <-1.5384423, -1.1148777, 34.0642124>,
    <-1.5738757, -1.0679889, 34.0748134>,
    <-1.4949977, -1.1730038, 34.0642124>,
    <-1.4970098, -1.1656107, 34.0551646>,
    <-1.5173027, -1.1508477, 34.0861074>,
    <-1.5009938, -1.1689519, 34.0748134>,
    <-1.5767432, -1.2334989, 34.2989756>,
    <-1.6047561, -1.1892253, 34.2975521>,
    <-1.6548166, -1.1327022, 34.3035582>,
    <-1.6025986, -1.2118565, 34.3035582>,
    <-1.5874399, -1.2156089, 34.2980080>,
    <-1.6306450, -1.1604925, 34.3007100>,
    <-1.6292304, -1.1708593, 34.3035582>,
    <-1.5880518, -1.2241312, 34.3008727>,
    <-1.6101365, -1.1911625, 34.3007914>,
    <-1.5752697, -1.2547470, 34.3035582>,
    <-1.5546864, -1.2607077, 34.2980080>,
    <-1.5623495, -1.2607966, 34.3007914>,
    <-1.5754329, -1.2198431, 34.2937748>,
    <-1.5575376, -1.2483415, 34.2951914>,
    <-1.6024645, 1.2621603, 34.2894172>,
    <-1.6298750, 1.2186617, 34.2882663>,
    <-1.6614499, 1.1876693, 34.2918019>,
    <-1.6163404, 1.2520924, 34.2918011>,
    <-1.6129140, 1.2453561, 34.2889150>,
    <-1.6497400, 1.1986491, 34.2903405>,
    <-1.6390526, 1.2196560, 34.2918015>,
    <-1.6073765, 1.2592869, 34.2904035>,
    <-1.6277620, 1.2301201, 34.2903614>,
    <-1.5934182, 1.2848285, 34.2918006>,
    <-1.5871589, 1.2815720, 34.2889147>,
    <-1.5889042, 1.2851619, 34.2903608>,
    <-1.6041269, 1.2463433, 34.2861103>,
    <-1.5909509, 1.2701358, 34.2874561>,
    <-1.5440762, 1.1501811, 34.1542153>,
    <-1.5791998, 1.1064409, 34.1620860>,
    <-1.5596799, 1.1312662, 34.1576891>,
    <-1.5394277, 1.1686987, 34.1722289>,
    <-1.5156429, 1.1901390, 34.1576891>,
    <-1.5225880, 1.1867325, 34.1659804>,
    <-1.5716204, 1.1009601, 34.1379890>,
    <-1.5285265, 1.1602281, 34.1379890>,
    <-1.5563600, 1.1287812, 34.1472010>,
    <-1.5168972, 1.1821760, 34.1481994>,
    <-1.6624443, 0.9602660, 34.1380150>,
    <-1.6125982, 1.0402090, 34.1379890>,
    <-1.6168483, 1.0430677, 34.1516897>,
    <-1.5905602, 1.0802073, 34.1481994>,
    <-1.5988213, 1.0519412, 34.1211611>,
    <-1.5871769, 1.0734746, 34.1286034>,
    <-1.5843510, 1.0715643, 34.1174128>,
    <-1.5527062, 1.1216796, 34.1275355>,
    <-1.6553653, 0.9561251, 34.1125260>,
    <-1.6527097, 0.9545626, 34.1010718>,
    <-1.6243813, 1.0104590, 34.1174128>,
    <-1.6183754, 1.0149159, 34.1081947>,
    <-1.6582299, 0.9578070, 34.1237934>,
    <-1.6231638, 1.0179248, 34.1275355>,
    <-1.5951439, -1.0486654, 34.1038334>,
    <-1.5655980, -1.0957474, 34.1125260>,
    <-1.6628369, -0.9595859, 34.1380150>,
    <-1.6557113, -0.9555259, 34.1125260>,
    <-1.5824993, -1.0694108, 34.1076575>,
    <-1.6091864, -1.0370120, 34.1237934>,
    <-1.6586002, -0.9571657, 34.1237934>,
    <-1.6224186, -1.0084244, 34.1076575>,
    <-1.6208397, -1.0155806, 34.1168389>,
    <-1.6530303, -0.9540072, 34.1010718>,
    <-1.5799959, -1.0677861, 34.0961373>,
    <-1.6162908, -1.0128322, 34.0972345>,
    <-1.5202269, -1.1529608, 34.1010718>,
    <-1.5462291, -1.1160835, 34.0972345>,
    <-1.5353305, -1.1426155, 34.1211611>,
    <-1.5720899, -1.1002895, 34.1379890>,
    <-1.5515826, -1.1243085, 34.1286034>,
    <-1.6130446, -1.0395237, 34.1379890>,
    <-1.5488210, -1.1223063, 34.1174128>,
    <-1.5850909, -1.0754295, 34.1275355>,
    <-1.5050920, -1.1808218, 34.1174128>,
    <-1.5072259, -1.1736538, 34.1081947>,
    <-1.5290178, -1.1595742, 34.1379890>,
    <-1.5116911, -1.1771242, 34.1275355>,
    <-1.5495999, 1.1545102, 34.2216509>,
    <-1.5857986, 1.1113012, 34.2291393>,
    <-1.5214665, 1.1949223, 34.2249699>,
    <-1.5470679, 1.1747344, 34.2387176>,
    <-1.5656730, 1.1358340, 34.2249699>,
    <-1.5294079, 1.1922725, 34.2328318>,
    <-1.6663800, 0.9627261, 34.2060335>,
    <-1.5753202, 1.1037576, 34.2059966>,
    <-1.6223255, 1.0468289, 34.2192172>,
    <-1.6164018, 1.0428627, 34.2059966>,
    <-1.5611013, 1.1324263, 34.2149211>,
    <-1.5955257, 1.0837972, 34.2158771>,
    <-1.5321177, 1.1631655, 34.2059966>,
    <-1.5216308, 1.1860687, 34.2158771>,
    <-1.6005956, 1.0533193, 34.1894897>,
    <-1.5856681, 1.0726770, 34.1857817>,
    <-1.5898066, 1.0754576, 34.1968260>,
    <-1.5551440, 1.1236662, 34.1957715>,
    <-1.6561800, 0.9567923, 34.1809181>,
    <-1.6604108, 0.9592626, 34.1920745>,
    <-1.6257476, 1.0115092, 34.1857817>,
    <-1.6257373, 1.0197311, 34.1957715>,
    <-1.6521571, 0.9544404, 34.1694828>,
    <-1.6186483, 1.0153039, 34.1766071>,
    <-1.5951056, -1.0484287, 34.1722608>,
    <-1.6566965, -0.9558978, 34.1809181>,
    <-1.6669352, -0.9617644, 34.2060335>,
    <-1.5665637, -1.0961791, 34.1809181>,
    <-1.6228174, -1.0084717, 34.1760819>,
    <-1.6609512, -0.9583266, 34.1920745>,
    <-1.6114906, -1.0382653, 34.1920745>,
    <-1.5829037, -1.0694619, 34.1760819>,
    <-1.6223273, -1.0162964, 34.1852017>,
    <-1.5199155, -1.1524788, 34.1694828>,
    <-1.5790859, -1.0669652, 34.1645454>,
    <-1.5454742, -1.1153117, 34.1656437>,
    <-1.6526482, -0.9535898, 34.1694828>,
    <-1.6154765, -1.0121283, 34.1656437>,
    <-1.5372323, -1.1438114, 34.1894897>,
    <-1.5759841, -1.1028094, 34.2059966>,
    <-1.5503171, -1.1231635, 34.1857817>,
    <-1.6170331, -1.0418937, 34.2059966>,
    <-1.5543455, -1.1261014, 34.1968260>,
    <-1.5877914, -1.0770409, 34.1957715>,
    <-1.5328124, -1.1622408, 34.2059966>,
    <-1.5065461, -1.1817465, 34.1857817>,
    <-1.5142687, -1.1789248, 34.1957715>,
    <-1.5076839, -1.1737775, 34.1766071>,
    <-1.6095496, -1.2520403, 34.2894166>,
    <-1.6261574, -1.2380701, 34.2918006>,
    <-1.6766945, -1.1658969, 34.2917990>,
    <-1.6375727, -1.2074402, 34.2882651>,
    <-1.6157475, -1.2473563, 34.2904030>,
    <-1.6524081, -1.2005809, 34.2917998>,
    <-1.6627142, -1.1801193, 34.2903384>,
    <-1.6206159, -1.2342256, 34.2889141>,
    <-1.6387602, -1.2144120, 34.2903601>,
    <-1.6036786, -1.2460732, 34.2861096>,
    <-1.5917110, -1.2750695, 34.2889145>,
    <-1.5934792, -1.2660042, 34.2874555>,
    <-1.5985972, -1.2774293, 34.2918014>,
    <-1.5941118, -1.2778264, 34.2903610>,
    <-1.5612043, 1.1630766, 34.1991181>,
    <-1.5973188, 1.1192848, 34.2059260>,
    <-1.5772459, 1.1441468, 34.2021355>,
    <-1.5578418, 1.1828226, 34.2146338>,
    <-1.5327127, 1.2036757, 34.2021355>,
    <-1.5403453, 1.2007119, 34.2092829>,
    <-1.5877929, 1.1124269, 34.1848862>,
    <-1.5442506, 1.1723053, 34.1848862>,
    <-1.5730898, 1.1410489, 34.1929998>,
    <-1.5332752, 1.1950720, 34.1938690>,
    <-1.6795689, 0.9702824, 34.1849198>,
    <-1.6291976, 1.0510498, 34.1848862>,
    <-1.6345828, 1.0546554, 34.1969055>,
    <-1.6077349, 1.0920123, 34.1938690>,
    <-1.6139127, 1.0620179, 34.1698789>,
    <-1.6027599, 1.0841545, 34.1765488>,
    <-1.5989976, 1.0816266, 34.1665078>,
    <-1.5678571, 1.1327799, 34.1755900>,
    <-1.6702700, 0.9648730, 34.1620860>,
    <-1.6666129, 0.9627348, 34.1516897>,
    <-1.6394091, 1.0199483, 34.1665078>,
    <-1.6325750, 1.0239760, 34.1581668>,
    <-1.6741162, 0.9671187, 34.1722289>,
    <-1.6390195, 1.0280007, 34.1755900>,
    <-1.6089219, -1.0575719, 34.1542153>,
    <-1.5798326, -1.1055373, 34.1620860>,
    <-1.6800736, -0.9694081, 34.1849198>,
    <-1.6707395, -0.9640597, 34.1620860>,
    <-1.5964845, -1.0787039, 34.1576891>,
    <-1.6247328, -1.0468703, 34.1722289>,
    <-1.6746075, -0.9662678, 34.1722289>,
    <-1.6367453, -1.0171869, 34.1576891>,
    <-1.6359195, -1.0248783, 34.1659804>,
    <-1.6670593, -0.9619616, 34.1516897>,
    <-1.5930138, -1.0764341, 34.1472010>,
    <-1.6296915, -1.0210891, 34.1481994>,
    <-1.5331578, -1.1625902, 34.1516897>,
    <-1.5590664, -1.1251850, 34.1481994>,
    <-1.5499610, -1.1533504, 34.1698789>,
    <-1.5883965, -1.1115649, 34.1848862>,
    <-1.5669481, -1.1352989, 34.1765488>,
    <-1.6297715, -1.0501689, 34.1848862>,
    <-1.5632859, -1.1326281, 34.1665078>,
    <-1.6007037, -1.0858702, 34.1755900>,
    <-1.5191488, -1.1916977, 34.1665078>,
    <-1.5205963, -1.1838982, 34.1581668>,
    <-1.5448822, -1.1714647, 34.1848862>,
    <-1.5265823, -1.1885775, 34.1755900>,
    <-1.5722156, 1.1717304, 34.2635082>,
    <-1.6092232, 1.1286726, 34.2695801>,
    <-1.5437689, 1.2131253, 34.2662252>,
    <-1.5694977, 1.1952732, 34.2772285>,
    <-1.5886304, 1.1531680, 34.2662252>,
    <-1.5516635, 1.2120186, 34.2725930>,
    <-1.6896252, 0.9762696, 34.2505667>,
    <-1.5972787, 1.1192686, 34.2505227>,
    <-1.6459303, 1.0621912, 34.2614925>,
    <-1.6389378, 1.0575241, 34.2505227>,
    <-1.5835111, 1.1488027, 34.2579678>,
    <-1.6184986, 1.0995285, 34.2587527>,
    <-1.5534694, 1.1795052, 34.2505227>,
    <-1.5435384, 1.2032634, 34.2587527>,
    <-1.6216471, 1.0673109, 34.2365221>,
    <-1.6062345, 1.0867368, 34.2333423>,
    <-1.6112772, 1.0901123, 34.2427845>,
    <-1.5760591, 1.1389226, 34.2418824>,
    <-1.6772844, 0.9691158, 34.2291393>,
    <-1.6824665, 0.9721312, 34.2387176>,
    <-1.6468442, 1.0247680, 34.2333423>,
    <-1.6476178, 1.0335785, 34.2418824>,
    <-1.6722822, 0.9662021, 34.2192172>,
    <-1.6389226, 1.0281686, 34.2254131>,
    <-1.6148791, -1.0612818, 34.2216509>,
    <-1.6779211, -0.9680130, 34.2291393>,
    <-1.6902869, -0.9751235, 34.2505667>,
    <-1.5866567, -1.1100759, 34.2291393>,
    <-1.6432318, -1.0210233, 34.2249699>,
    <-1.6831236, -0.9709931, 34.2387176>,
    <-1.6330176, -1.0519855, 34.2387176>,
    <-1.6028266, -1.0827733, 34.2249699>,
    <-1.6434580, -1.0293921, 34.2328318>,
    <-1.5385654, -1.1664508, 34.2192172>,
    <-1.5980608, -1.0796428, 34.2149211>,
    <-1.5641382, -1.1286233, 34.2158771>,
    <-1.6728967, -0.9651378, 34.2192172>,
    <-1.6349684, -1.0242058, 34.2158771>,
    <-1.5575802, -1.1588080, 34.2365221>,
    <-1.5980700, -1.1181386, 34.2505227>,
    <-1.5705631, -1.1376809, 34.2333423>,
    <-1.6396902, -1.0563692, 34.2505227>,
    <-1.5754598, -1.1412649, 34.2427845>,
    <-1.6092812, -1.0914766, 34.2418824>,
    <-1.5542973, -1.1784032, 34.2505227>,
    <-1.5262208, -1.1970360, 34.2333423>,
    <-1.5347646, -1.1947496, 34.2418824>,
    <-1.5267070, -1.1884291, 34.2254131>,
    <-1.5818583, 1.1785750, 34.2371711>,
    <-1.6189381, 1.1345543, 34.2427102>,
    <-1.5983283, 1.1595532, 34.2396408>,
    <-1.5795295, 1.1994040, 34.2497196>,
    <-1.5531997, 1.2198721, 34.2396408>,
    <-1.5614260, 1.2172557, 34.2454279>,
    <-1.6077552, 1.1265279, 34.2253660>,
    <-1.5636613, 1.1871597, 34.2253660>,
    <-1.5934623, 1.1559366, 34.2321345>,
    <-1.5531912, 1.2107037, 34.2328481>,
    <-1.7007009, 0.9825947, 34.2254060>,
    <-1.6496849, 1.0643784, 34.2253660>,
    <-1.6560417, 1.0686212, 34.2353389>,
    <-1.6286193, 1.1063136, 34.2328481>,
    <-1.6330506, 1.0747376, 34.2126378>,
    <-1.6222786, 1.0974770, 34.2183311>,
    <-1.6176944, 1.0944083, 34.2097470>,
    <-1.5868709, 1.1466495, 34.2175110>,
    <-1.6894559, 0.9760762, 34.2059260>,
    <-1.6849084, 0.9734273, 34.1969055>,
    <-1.6585878, 1.0320018, 34.2097470>,
    <-1.6510061, 1.0356712, 34.2025384>,
    <-1.6941668, 0.9788174, 34.2146338>,
    <-1.6589109, 1.0405893, 34.2175110>,
    <-1.6268978, -1.0692565, 34.1991181>,
    <-1.5980988, -1.1181708, 34.2059260>,
    <-1.7013025, -0.9815528, 34.2254060>,
    <-1.6900347, -0.9750736, 34.2059260>,
    <-1.6145962, -1.0908051, 34.2021355>,
    <-1.6443029, -1.0593433, 34.2146338>,
    <-1.6947642, -0.9777828, 34.2146338>,
    <-1.6553038, -1.0285975, 34.2021355>,
    <-1.6551293, -1.0367835, 34.2092829>,
    <-1.6854670, -0.9724598, 34.1969055>,
    <-1.6102636, -1.0879592, 34.1929998>,
    <-1.6474114, -1.0320686, 34.1938690>,
    <-1.5501122, -1.1752920, 34.1969055>,
    <-1.5760336, -1.1372864, 34.1938690>,
    <-1.5684591, -1.1669837, 34.2126378>,
    <-1.6084746, -1.1255005, 34.2253660>,
    <-1.5861429, -1.1490840, 34.2183311>,
    <-1.6503688, -1.0633285, 34.2253660>,
    <-1.5816914, -1.1458258, 34.2097470>,
    <-1.6202399, -1.0989937, 34.2175110>,
    <-1.5370349, -1.2055973, 34.2097470>,
    <-1.5378899, -1.1972178, 34.2025384>,
    <-1.5644140, -1.1861579, 34.2253660>,
    <-1.5452150, -1.2029638, 34.2175110>,
    <-1.5931284, 1.1982405, 34.2933120>,
    <-1.6079218, 1.1873058, 34.2967794>,
    <-1.5714678, 1.2317353, 34.2949171>,
    <-1.5707671, 1.2539912, 34.3007507>,
    <-1.6006454, 1.1926562, 34.2949171>,
    <-1.5721715, 1.2418523, 34.2980246>,
    <-1.7122303, 1.0024188, 34.2867877>,
    <-1.6213832, 1.1388199, 34.2854038>,
    <-1.6501470, 1.1132123, 34.2926777>,
    <-1.6613908, 1.0803919, 34.2856693>,
    <-1.6066051, 1.1706441, 34.2900253>,
    <-1.6339086, 1.1331609, 34.2908029>,
    <-1.5774172, 1.1997299, 34.2856693>,
    <-1.5706370, 1.2209649, 34.2908029>,
    <-1.6238807, 1.1684257, 34.2989756>,
    <-1.5859136, 1.2357211, 34.3035582>,
    <-1.6181653, 1.1749963, 34.2980080>,
    <-1.5663615, 1.2674694, 34.3035582>,
    <-1.6087092, 1.1954858, 34.3008727>,
    <-1.5904928, 1.2238857, 34.3007914>,
    <-1.6304990, 1.1677906, 34.3035582>,
    <-1.6664722, 1.1013897, 34.2975521>,
    <-1.6070318, 1.2027060, 34.3035582>,
    <-1.6483377, 1.1355599, 34.3007100>,
    <-1.6447093, 1.1347711, 34.2980080>,
    <-1.6279961, 1.1658002, 34.3007914>,
    <-1.6851982, 1.0633402, 34.2937748>,
    <-1.6529201, 1.1154954, 34.2951914>,
    <-1.6462630, 1.0840848, 34.2753407>,
    <-1.6303709, 1.1037249, 34.2729301>,
    <-1.6358687, 1.1079035, 34.2800513>,
    <-1.5995467, 1.1582189, 34.2795037>,
    <-1.7022091, 0.9843962, 34.2695801>,
    <-1.7074415, 0.9897567, 34.2772285>,
    <-1.6716781, 1.0408460, 34.2729301>,
    <-1.6725220, 1.0513750, 34.2795037>,
    <-1.6966273, 0.9803787, 34.2614925>,
    <-1.6632355, 1.0435409, 34.2665723>,
    <-1.6388073, -1.0766426, 34.2635082>,
    <-1.7036448, -0.9819506, 34.2695801>,
    <-1.7247225, -0.9815386, 34.2867877>,
    <-1.6110252, -1.1261382, 34.2695801>,
    <-1.6679908, -1.0357516, 34.2662252>,
    <-1.7109876, -0.9837789, 34.2772285>,
    <-1.6601221, -1.0660052, 34.2772285>,
    <-1.6269929, -1.0984142, 34.2662252>,
    <-1.6697286, -1.0435388, 34.2725930>,
    <-1.5610745, -1.1833777, 34.2614925>,
    <-1.6211141, -1.0951000, 34.2579678>,
    <-1.5867780, -1.1448302, 34.2587527>,
    <-1.6973465, -0.9791330, 34.2614925>,
    <-1.6586190, -1.0389113, 34.2587527>,
    <-1.5817119, -1.1761662, 34.2753407>,
    <-1.6244123, -1.1339037, 34.2854038>,
    <-1.5947853, -1.1545352, 34.2729301>,
    <-1.6668698, -1.0717741, 34.2856693>,
    <-1.6004770, -1.1582071, 34.2800513>,
    <-1.6354607, -1.1068833, 34.2795037>,
    <-1.5831632, -1.1915131, 34.2856693>,
    <-1.5497975, -1.2148596, 34.2729301>,
    <-1.5599037, -1.2120104, 34.2795037>,
    <-1.5494677, -1.2060181, 34.2665723>,
    <-1.6056046, 1.1960866, 34.2672347>,
    <-1.6442123, 1.1511092, 34.2713545>,
    <-1.6227227, 1.1767504, 34.2690979>,
    <-1.6070773, 1.2152332, 34.2765463>,
    <-1.5769176, 1.2379692, 34.2690979>,
    <-1.5869343, 1.2347933, 34.2734378>,
    <-1.6309008, 1.1428345, 34.2582019>,
    <-1.5861688, 1.2043398, 34.2582019>,
    <-1.6168585, 1.1729918, 34.2634197>,
    <-1.5760402, 1.2285960, 34.2639559>,
    <-1.7251982, 0.9968289, 34.2582471>,
    <-1.6734377, 1.0797896, 34.2582019>,
    <-1.6805728, 1.0845407, 34.2658251>,
    <-1.6525789, 1.1226764, 34.2639559>,
    <-1.6556533, 1.0897138, 34.2481381>,
    <-1.6451401, 1.1130371, 34.2526827>,
    <-1.6398731, 1.1095209, 34.2458152>,
    <-1.6091698, 1.1628668, 34.2520259>,
    <-1.7123400, 0.9893942, 34.2427102>,
    <-1.7070403, 0.9863152, 34.2353389>,
    <-1.6813348, 1.0462532, 34.2458152>,
    <-1.6731088, 1.0496460, 34.2399571>,
    <-1.7177725, 0.9925477, 34.2497196>,
    <-1.6822337, 1.0553081, 34.2520259>,
    <-1.6485256, -1.0833642, 34.2371711>,
    <-1.6198418, -1.1332638, 34.2427102>,
    <-1.7258783, -0.9956511, 34.2582471>,
    <-1.7130105, -0.9882328, 34.2427102>,
    <-1.6362840, -1.1053468, 34.2396408>,
    <-1.6673020, -1.0740519, 34.2497196>,
    <-1.7184578, -0.9913608, 34.2497196>,
    <-1.6775304, -1.0423095, 34.2396408>,
    <-1.6778853, -1.0509345, 34.2454279>,
    <-1.7076942, -0.9851827, 34.2353389>,
    <-1.6312212, -1.1020112, 34.2321345>,
    <-1.6689120, -1.0454373, 34.2328481>,
    <-1.5705751, -1.1906802, 34.2353389>,
    <-1.5966153, -1.1520201, 34.2328481>,
    <-1.5902627, -1.1831012, 34.2481381>,
    <-1.6317140, -1.1416731, 34.2582019>,
    <-1.6085838, -1.1652449, 34.2526827>,
    <-1.6742109, -1.0786026, 34.2582019>,
    <-1.6034782, -1.1614982, 34.2458152>,
    <-1.6431058, -1.1144011, 34.2520259>,
    <-1.5582067, -1.2220982, 34.2458152>,
    <-1.5585815, -1.2132079, 34.2399571>,
    <-1.5870197, -1.2032073, 34.2582019>,
    <-1.5670230, -1.2198460, 34.2520259>,
    <-1.6523694, -1.1257656, 34.2989756>,
    <-1.6643583, -1.1041192, 34.2967794>,
    <-1.7021553, -1.0668012, 34.3035582>,
    <-1.6564002, -1.1180333, 34.2980080>,
    <-1.7136191, -1.0459493, 34.3007507>,
    <-1.7246048, -1.0371640, 34.3035582>,
    <-1.6724123, -1.1021376, 34.3008727>,
    <-1.6923816, -1.0750208, 34.3007914>,
    <-1.6790087, -1.0983317, 34.3035582>,
    <-1.6282443, -1.1570770, 34.2980080>,
    <-1.6516185, -1.1307228, 34.3007914>,
    <-1.6097517, -1.1694921, 34.2926777>,
    <-1.6129022, -1.1713572, 34.2951914>,
    <-1.6978351, 1.0594705, 34.2989756>,
    <-1.6860466, 1.0909922, 34.3035582>,
    <-1.6849588, 1.0758217, 34.2980080>,
    <-1.6570983, 1.1303416, 34.3035582>,
    <-1.6927669, 1.0732177, 34.3008727>,
    <-1.6697182, 1.1054965, 34.3007914>,
    <-1.7386251, 0.9872592, 34.2967794>,
    <-1.7165609, 1.0503761, 34.3035582>,
    <-1.7434486, 0.9980690, 34.3007507>,
    <-1.7157214, 1.0293481, 34.2980080>,
    <-1.7181134, 1.0363314, 34.3007914>,
    <-1.7302294, 0.9876463, 34.2926777>,
    <-1.7054409, 1.0364877, 34.2951914>,
    <-1.6701541, -1.0866474, 34.2933120>,
    <-1.7254494, -1.0117681, 34.2967794>,
    <-1.6944409, -1.0547414, 34.2949171>,
    <-1.7363479, -1.0103452, 34.3007507>,
    <-1.6671040, -1.0955212, 34.2949171>,
    <-1.7034504, -1.0516646, 34.2980246>,
    <-1.6489996, -1.1089426, 34.2900253>,
    <-1.6229524, -1.1474104, 34.2908029>,
    <-1.7215909, -1.0044226, 34.2926777>,
    <-1.6843886, -1.0579190, 34.2908029>,
    <-1.7171477, 1.0986168, 34.2894178>,
    <-1.7446026, 1.0560845, 34.2886791>,
    <-1.7388383, 1.0771469, 34.2918019>,
    <-1.7041847, 1.1266377, 34.2918021>,
    <-1.7312277, 1.0763629, 34.2889154>,
    <-1.7415424, 1.0674582, 34.2903193>,
    <-1.7229217, 1.0998783, 34.2918020>,
    <-1.7126363, 1.1090737, 34.2904043>,
    <-1.7285203, 1.0862223, 34.2903618>,
    <-1.6907878, 1.1314923, 34.2882666>,
    <-1.6834273, 1.1562823, 34.2918020>,
    <-1.6721372, 1.1666626, 34.2903406>,
    <-1.7072771, 1.1105680, 34.2889155>,
    <-1.6935621, 1.1361479, 34.2903619>,
    <-1.7605513, 1.0048244, 34.2830970>,
    <-1.7163490, 1.0853654, 34.2861105>,
    <-1.7483751, 1.0413409, 34.2867237>,
    <-1.7281526, 1.0740968, 34.2874565>,
    <-1.6611586, 1.1673214, 34.2863580>,
    <-1.6742082, 1.1516229, 34.2872643>,
    <-1.6467295, 1.1910034, 34.2872642>,
    <-1.6604341, 1.1777992, 34.2889216>,
    <-1.6672776, 1.1435738, 34.2817251>,
    <-1.6237626, 1.2058371, 34.2819691>,
    <-1.6626287, 1.1587454, 34.2845089>,
    <-1.6305335, 1.2056848, 34.2850030>,
    <-1.7082877, 1.0834768, 34.2819691>,
    <-1.6928708, 1.1161103, 34.2850030>,
    <-1.6830735, 1.1032773, 34.2751874>,
    <-1.6752383, 1.1231304, 34.2783022>,
    <-1.6659244, 1.1251339, 34.2735942>,
    <-1.6383339, 1.1754539, 34.2779937>,
    <-1.7389589, 1.0036385, 34.2713545>,
    <-1.7323362, 1.0010068, 34.2658251>,
    <-1.7079703, 1.0608265, 34.2735942>,
    <-1.6982114, 1.0654758, 34.2692880>,
    <-1.7471438, 1.0047563, 34.2765463>,
    <-1.7123250, 1.0659379, 34.2779937>,
    <-1.7262707, -1.0856596, 34.2894147>,
    <-1.6994099, -1.1194209, 34.2882644>,
    <-1.7172867, -1.1079259, 34.2917976>,
    <-1.7164987, -1.0975597, 34.2889128>,
    <-1.6855884, -1.1474519, 34.2903380>,
    <-1.6983619, -1.1349531, 34.2917982>,
    <-1.7235758, -1.0934503, 34.2904005>,
    <-1.7060735, -1.1182796, 34.2903586>,
    <-1.7464146, -1.0663272, 34.2917974>,
    <-1.7488151, -1.0502899, 34.2886767>,
    <-1.7333454, -1.0849918, 34.2917973>,
    <-1.7478843, -1.0584013, 34.2903158>,
    <-1.7379471, -1.0669283, 34.2889125>,
    <-1.7372256, -1.0737899, 34.2903580>,
    <-1.7488804, -1.0251129, 34.2830965>,
    <-1.7486677, -1.0418076, 34.2867222>,
    <-1.7173121, -1.0849599, 34.2861091>,
    <-1.7323512, -1.0687472, 34.2874544>,
    <-1.6730714, -1.0997450, 34.2672347>,
    <-1.6439364, -1.1515404, 34.2713544>,
    <-1.7385497, -1.0043521, 34.2713544>,
    <-1.6607167, -1.1225140, 34.2690979>,
    <-1.6911740, -1.0952794, 34.2765461>,
    <-1.7432919, -1.0114477, 34.2765461>,
    <-1.7025773, -1.0585333, 34.2690979>,
    <-1.7028066, -1.0694095, 34.2734378>,
    <-1.7330654, -0.9997437, 34.2658251>,
    <-1.6552499, -1.1181632, 34.2634197>,
    <-1.6935400, -1.0607888, 34.2639559>,
    <-1.5939246, -1.2082871, 34.2658251>,
    <-1.6201860, -1.1689383, 34.2639559>,
    <-1.6638185, -1.1635251, 34.2863568>,
    <-1.6528594, -1.1820927, 34.2872630>,
    <-1.6807343, -1.1424643, 34.2872627>,
    <-1.6716312, -1.1618078, 34.2889197>,
    <-1.6445118, -1.1760952, 34.2817246>,
    <-1.6878858, -1.1144084, 34.2819686>,
    <-1.6569745, -1.1668261, 34.2845081>,
    <-1.6897039, -1.1212797, 34.2850020>,
    <-1.6016401, -1.2356709, 34.2819687>,
    <-1.6265716, -1.2107189, 34.2850022>,
    <-1.6123144, -1.2043343, 34.2751874>,
    <-1.6282003, -1.1903134, 34.2783020>,
    <-1.6269890, -1.1807643, 34.2735942>,
    <-1.6646255, -1.1380047, 34.2779935>,
    <-1.5809196, -1.2422547, 34.2735942>,
    <-1.5820422, -1.2313826, 34.2692880>,
    <-1.5869375, -1.2449335, 34.2779935>,
    <-1.6305482, 0.8172874, 34.0220386>,
    <-1.6725796, 0.7460927, 34.0246619>,
    <-1.6091049, 0.8627674, 34.0228024>,
    <-1.6506805, 0.8251747, 34.0310297>,
    <-1.6509499, 0.7825559, 34.0231546>,
    <-1.6283917, 0.8476454, 34.0269681>,
    <-1.6898777, 0.6703012, 34.0191924>,
    <-1.6298905, 0.8081289, 34.0203218>,
    <-1.6613451, 0.7402603, 34.0200410>,
    <-1.5951108, 0.8703163, 34.0197592>,
    <-1.6771530, 0.8427995, 34.0581798>,
    <-1.7030117, 0.7945446, 34.0677166>,
    <-1.6567824, 0.8859699, 34.0621232>,
    <-1.6742745, 0.8603635, 34.0805061>,
    <-1.6890882, 0.8220049, 34.0621232>,
    <-1.6622765, 0.8811062, 34.0723106>,
    <-1.7545627, 0.6363530, 34.0416785>,
    <-1.6913029, 0.7885370, 34.0421142>,
    <-1.7281935, 0.7274648, 34.0557354>,
    <-1.7195806, 0.7240730, 34.0419993>,
    <-1.6845123, 0.8199619, 34.0506039>,
    <-1.7091604, 0.7675732, 34.0517365>,
    <-1.6607832, 0.8500093, 34.0419993>,
    <-1.6557175, 0.8778719, 34.0517365>,
    <-1.6982525, 0.7232039, 34.0296735>,
    <-1.6886855, 0.7315288, 34.0272768>,
    <-1.6962974, 0.7545475, 34.0347932>,
    <-1.6736806, 0.7955796, 34.0337605>,
    <-1.7217559, 0.6251756, 34.0246260>,
    <-1.7362813, 0.6282957, 34.0310485>,
    <-1.7088828, 0.6831696, 34.0272768>,
    <-1.7174366, 0.6977656, 34.0337605>,
    <-1.7094082, 0.6178694, 34.0190299>,
    <-1.7000738, 0.6748030, 34.0228047>,
    <-1.6733513, -0.7278817, 34.0221521>,
    <-1.7238174, -0.6274659, 34.0252783>,
    <-1.7541776, -0.6392864, 34.0418026>,
    <-1.6530950, -0.7941475, 34.0252783>,
    <-1.6970151, -0.6827756, 34.0235337>,
    <-1.7368119, -0.6334410, 34.0315713>,
    <-1.6980571, -0.7288504, 34.0315713>,
    <-1.6643173, -0.7581646, 34.0235337>,
    <-1.7011713, -0.6994013, 34.0277883>,
    <-1.6356494, -0.7631172, 34.0159774>,
    <-1.6053623, -0.8573549, 34.0197144>,
    <-1.6023149, -0.8346023, 34.0159774>,
    <-1.6582801, -0.7425153, 34.0195520>,
    <-1.6321455, -0.8004923, 34.0196603>,
    <-1.6689839, -0.6916321, 34.0159774>,
    <-1.7097168, -0.6244354, 34.0197144>,
    <-1.6849714, -0.6829931, 34.0196603>,
    <-1.6484610, -0.8338029, 34.0300324>,
    <-1.6916078, -0.7884625, 34.0421478>,
    <-1.6506277, -0.8180464, 34.0277479>,
    <-1.7195253, -0.7249007, 34.0420666>,
    <-1.6695928, -0.8134914, 34.0349278>,
    <-1.6882898, -0.7671032, 34.0340297>,
    <-1.6603978, -0.8518552, 34.0420666>,
    <-1.6243201, -0.8694170, 34.0277479>,
    <-1.6396900, -0.8673469, 34.0340297>,
    <-1.6140339, -0.8651430, 34.0233431>,
    <-1.7604331, 1.0357851, 34.2894172>,
    <-1.7607143, 1.0459037, 34.2918011>,
    <-1.7606509, 1.0401208, 34.2904035>,
    <-1.7511341, 1.0595862, 34.2918015>,
    <-1.7545040, 1.0427405, 34.2889150>,
    <-1.7520306, 1.0526456, 34.2903614>,
    <-1.7742503, 1.0079306, 34.2886786>,
    <-1.7705349, 1.0044242, 34.2867235>,
    <-1.7658774, 1.0245982, 34.2889147>,
    <-1.7601313, 1.0269066, 34.2874561>,
    <-1.7764431, 1.0128023, 34.2903183>,
    <-1.7684842, 1.0348065, 34.2918006>,
    <-1.7680693, 1.0282198, 34.2903608>,
    <-1.7630806, -1.0318487, 34.2894157>,
    <-1.7639918, -1.0412242, 34.2917992>,
    <-1.7574526, -1.0386063, 34.2889131>,
    <-1.7563706, -1.0521085, 34.2917981>,
    <-1.7635557, -1.0358879, 34.2904018>,
    <-1.7564133, -1.0463871, 34.2903587>,
    <-1.7760244, -1.0043574, 34.2886783>,
    <-1.7700565, -1.0325629, 34.2918006>,
    <-1.7785759, -1.0086746, 34.2903187>,
    <-1.7676614, -1.0216998, 34.2889139>,
    <-1.7700547, -1.0250437, 34.2903604>,
    <-1.7696558, -1.0055668, 34.2867229>,
    <-1.7604851, -1.0267064, 34.2874549>,
    <-1.6894562, 0.8489609, 34.1168394>,
    <-1.7154455, 0.8004187, 34.1264018>,
    <-1.6685436, 0.8923366, 34.1210460>,
    <-1.6869675, 0.8670712, 34.1387967>,
    <-1.7010883, 0.8278923, 34.1210460>,
    <-1.6741510, 0.8875767, 34.1311462>,
    <-1.7727126, 0.6455290, 34.0973598>,
    <-1.7088407, 0.7971854, 34.0973402>,
    <-1.7417484, 0.7330240, 34.1138015>,
    <-1.7381271, 0.7314005, 34.0973402>,
    <-1.6981637, 0.8264011, 34.1083733>,
    <-1.7228945, 0.7735407, 34.1095803>,
    <-1.6772532, 0.8618962, 34.0973402>,
    <-1.6690309, 0.8847549, 34.1095803>,
    <-1.7279050, 0.7455927, 34.0775018>,
    <-1.7173165, 0.7671288, 34.0732308>,
    <-1.7199066, 0.7682381, 34.0861763>,
    <-1.6948507, 0.8208249, 34.0849170>,
    <-1.7664459, 0.6432478, 34.0677166>,
    <-1.7693275, 0.6442612, 34.0805061>,
    <-1.7456475, 0.7011093, 34.0732308>,
    <-1.7453434, 0.7083505, 34.0849170>,
    <-1.7623653, 0.6419296, 34.0557354>,
    <-1.7401434, 0.7063955, 34.0632019>,
    <-1.7237108, -0.7430130, 34.0581798>,
    <-1.7666594, -0.6426853, 34.0677166>,
    <-1.7729147, -0.6449738, 34.0973598>,
    <-1.7033464, -0.7938509, 34.0677166>,
    <-1.7436705, -0.6996681, 34.0621232>,
    <-1.7695066, -0.6437691, 34.0805061>,
    <-1.7352795, -0.7295377, 34.0805061>,
    <-1.7154362, -0.7655317, 34.0621232>,
    <-1.7434572, -0.7070136, 34.0723106>,
    <-1.6681922, -0.8562343, 34.0557354>,
    <-1.7109914, -0.7633056, 34.0506039>,
    <-1.6866981, -0.8158645, 34.0517365>,
    <-1.7627209, -0.6410489, 34.0557354>,
    <-1.7368394, -0.7040264, 34.0517365>,
    <-1.6818367, -0.8443923, 34.0775018>,
    <-1.7091010, -0.7966271, 34.0973402>,
    <-1.6915328, -0.8224353, 34.0732308>,
    <-1.7383683, -0.7308344, 34.0973402>,
    <-1.6940391, -0.8237110, 34.0861763>,
    <-1.7182174, -0.7707149, 34.0849170>,
    <-1.6775318, -0.8613475, 34.0973402>,
    <-1.6591698, -0.8865746, 34.0732308>,
    <-1.6645131, -0.8816917, 34.0849170>,
    <-1.6597061, -0.8789466, 34.0632019>,
    <-1.6518608, 0.8170084, 34.0204711>,
    <-1.6915203, 0.7486804, 34.0221848>,
    <-1.6701796, 0.7853359, 34.0211528>,
    <-1.6689246, 0.8308398, 34.0272889>,
    <-1.6303012, 0.8668998, 34.0212727>,
    <-1.6468593, 0.8550088, 34.0243222>,
    <-1.6546646, 0.7985629, 34.0191518>,
    <-1.6240609, 0.8590789, 34.0189214>,
    <-1.7094605, 0.6707805, 34.0180922>,
    <-1.6829145, 0.7360313, 34.0188254>,
    <-1.6943867, 0.8514348, 34.0506060>,
    <-1.7203666, 0.8026113, 34.0592183>,
    <-1.7063855, 0.8303954, 34.0541438>,
    <-1.6911329, 0.8689923, 34.0708032>,
    <-1.6737491, 0.8950170, 34.0541438>,
    <-1.6791435, 0.8900157, 34.0633523>,
    <-1.7089157, 0.7965918, 34.0364283>,
    <-1.6781937, 0.8583252, 34.0363331>,
    <-1.7019317, 0.8284204, 34.0438443>,
    <-1.6728235, 0.8869211, 34.0448606>,
    <-1.7727655, 0.6429386, 34.0360499>,
    <-1.7373792, 0.7315556, 34.0363331>,
    <-1.7459885, 0.7349307, 34.0484530>,
    <-1.7268182, 0.7754808, 34.0448606>,
    <-1.7161310, 0.7293040, 34.0260678>,
    <-1.7140715, 0.7618785, 34.0302268>,
    <-1.7070612, 0.7360678, 34.0241522>,
    <-1.6916864, 0.8018268, 34.0293915>,
    <-1.7389901, 0.6312688, 34.0221460>,
    <-1.7269765, 0.6235997, 34.0179745>,
    <-1.7263546, 0.6895928, 34.0241522>,
    <-1.7180774, 0.6796903, 34.0207317>,
    <-1.7538712, 0.6346376, 34.0272515>,
    <-1.7350067, 0.7049038, 34.0293915>,
    <-1.6910466, -0.7355837, 34.0204813>,
    <-1.6705315, -0.8025324, 34.0228405>,
    <-1.7724360, -0.6459562, 34.0361559>,
    <-1.7420011, -0.6340915, 34.0228405>,
    <-1.6818971, -0.7661795, 34.0215203>,
    <-1.7158770, -0.7365125, 34.0277741>,
    <-1.7550400, -0.6400996, 34.0277741>,
    <-1.7149409, -0.6899935, 34.0215203>,
    <-1.7190788, -0.7067734, 34.0248083>,
    <-1.6530334, -0.7712252, 34.0159774>,
    <-1.7278329, -0.6310541, 34.0186848>,
    <-1.6867222, -0.6989805, 34.0159774>,
    <-1.6758529, -0.7503859, 34.0185671>,
    <-1.7028258, -0.6902323, 34.0186456>,
    <-1.6193447, -0.8434699, 34.0159774>,
    <-1.6223720, -0.8664416, 34.0186848>,
    <-1.6494398, -0.8089769, 34.0186456>,
    <-1.6657829, -0.8425746, 34.0264558>,
    <-1.7092081, -0.7966829, 34.0364647>,
    <-1.6870678, -0.8220183, 34.0303723>,
    <-1.7374179, -0.7324600, 34.0364059>,
    <-1.6680045, -0.8266671, 34.0246615>,
    <-1.7059728, -0.7751511, 34.0296825>,
    <-1.6414198, -0.8785780, 34.0246615>,
    <-1.6310857, -0.8742884, 34.0213137>,
    <-1.6776737, -0.8607361, 34.0364059>,
    <-1.6568637, -0.8764433, 34.0296825>,
    <-1.7055187, 0.8571876, 34.1722608>,
    <-1.7326008, 0.8085945, 34.1809181>,
    <-1.6847708, 0.9011652, 34.1760819>,
    <-1.7049094, 0.8764592, 34.1920745>,
    <-1.7176331, 0.8361039, 34.1760819>,
    <-1.6913022, 0.8968285, 34.1852017>,
    <-1.7877754, 0.6511566, 34.1544411>,
    <-1.7233432, 0.8041049, 34.1544124>,
    <-1.7580337, 0.7400460, 34.1694828>,
    <-1.7528836, 0.7377609, 34.1544124>,
    <-1.7135619, 0.8340460, 34.1645454>,
    <-1.7386254, 0.7807641, 34.1656437>,
    <-1.6914822, 0.8693653, 34.1544124>,
    <-1.6842671, 0.8929795, 34.1656437>,
    <-1.7409127, 0.7513433, 34.1359011>,
    <-1.7300581, 0.7729295, 34.1317777>,
    <-1.7334843, 0.7744591, 34.1440880>,
    <-1.7081073, 0.8274164, 34.1429132>,
    <-1.7793470, 0.6480343, 34.1264018>,
    <-1.7827716, 0.6493092, 34.1387967>,
    <-1.7586036, 0.7064248, 34.1317777>,
    <-1.7590122, 0.7140463, 34.1429132>,
    <-1.7761717, 0.6468490, 34.1138015>,
    <-1.7532502, 0.7117014, 34.1216372>,
    <-1.7363033, -0.7484970, 34.1168394>,
    <-1.7796073, -0.6473192, 34.1264018>,
    <-1.7880708, -0.6503449, 34.1544411>,
    <-1.7158234, -0.7996083, 34.1264018>,
    <-1.7560887, -0.7045957, 34.1210460>,
    <-1.7830501, -0.6485438, 34.1387967>,
    <-1.7485769, -0.7349494, 34.1387967>,
    <-1.7276408, -0.7709503, 34.1210460>,
    <-1.7560467, -0.7119508, 34.1311462>,
    <-1.6811032, -0.8630780, 34.1138015>,
    <-1.7246185, -0.7696685, 34.1083733>,
    <-1.7000218, -0.8225914, 34.1095803>,
    <-1.7764130, -0.6461862, 34.1138015>,
    <-1.7505940, -0.7098424, 34.1095803>,
    <-1.6945994, -0.8506623, 34.1359011>,
    <-1.7237237, -0.8032888, 34.1544124>,
    <-1.7041582, -0.8284719, 34.1317777>,
    <-1.7532363, -0.7369333, 34.1544124>,
    <-1.7075323, -0.8301133, 34.1440880>,
    <-1.7317879, -0.7766331, 34.1429132>,
    <-1.6918895, -0.8685631, 34.1544124>,
    <-1.6715614, -0.8930874, 34.1317777>,
    <-1.6776624, -0.8885014, 34.1429132>,
    <-1.6721624, -0.8855948, 34.1216372>,
    <-1.7057428, 0.8571025, 34.1038334>,
    <-1.7317440, 0.8079739, 34.1125260>,
    <-1.7173866, 0.8357792, 34.1076575>,
    <-1.7026720, 0.8750903, 34.1237934>,
    <-1.6845304, 0.9008435, 34.1076575>,
    <-1.6899385, 0.8958980, 34.1168389>,
    <-1.7257397, 0.8050345, 34.0861074>,
    <-1.6938408, 0.8703857, 34.0861074>,
    <-1.7147278, 0.8344235, 34.0961373>,
    <-1.6852839, 0.8933328, 34.0972345>,
    <-1.7902431, 0.6518810, 34.0861253>,
    <-1.7553147, 0.7385989, 34.0861074>,
    <-1.7586068, 0.7400748, 34.1010718>,
    <-1.7396713, 0.7810319, 34.0972345>,
    <-1.7453560, 0.7530944, 34.0680823>,
    <-1.7371278, 0.7759002, 34.0759583>,
    <-1.7347323, 0.7748801, 34.0642124>,
    <-1.7118433, 0.8290219, 34.0748134>,
    <-1.7844431, 0.6497766, 34.0592183>,
    <-1.7805099, 0.6485175, 34.0484530>,
    <-1.7633487, 0.7081930, 34.0642124>,
    <-1.7579487, 0.7135985, 34.0551646>,
    <-1.7871373, 0.6507181, 34.0708032>,
    <-1.7628390, 0.7154228, 34.0748134>,
    <-1.7414035, -0.7506640, 34.0506060>,
    <-1.7206814, -0.8019603, 34.0592183>,
    <-1.7904268, -0.6513763, 34.0861253>,
    <-1.7846427, -0.6492524, 34.0592183>,
    <-1.7329822, -0.7733888, 34.0541438>,
    <-1.7527260, -0.7369055, 34.0708032>,
    <-1.7873001, -0.6502708, 34.0708032>,
    <-1.7615070, -0.7068499, 34.0541438>,
    <-1.7611242, -0.7142075, 34.0633523>,
    <-1.7808552, -0.6476653, 34.0484530>,
    <-1.7286681, -0.7712126, 34.0438443>,
    <-1.7547671, -0.7113135, 34.0448606>,
    <-1.6853499, -0.8650671, 34.0484530>,
    <-1.7041060, -0.8243082, 34.0448606>,
    <-1.6988007, -0.8529385, 34.0680823>,
    <-1.7259763, -0.8045271, 34.0861074>,
    <-1.7109783, -0.8319780, 34.0759583>,
    <-1.7555340, -0.7380842, 34.0861074>,
    <-1.7086653, -0.8307942, 34.0642124>,
    <-1.7354194, -0.7784631, 34.0748134>,
    <-1.6759743, -0.8955812, 34.0642124>,
    <-1.6766690, -0.8879562, 34.0551646>,
    <-1.6940941, -0.8698869, 34.0861074>,
    <-1.6811767, -0.8905481, 34.0748134>,
    <-1.7203451, 0.8645812, 34.1542153>,
    <-1.7473397, 0.8154064, 34.1620860>,
    <-1.7324272, 0.8432442, 34.1576891>,
    <-1.7189827, 0.8836247, 34.1722289>,
    <-1.6992823, 0.9088695, 34.1576891>,
    <-1.7055304, 0.9043087, 34.1659804>,
    <-1.7389236, 0.8113250, 34.1379890>,
    <-1.7067763, 0.8771758, 34.1379890>,
    <-1.7287262, 0.8413734, 34.1472010>,
    <-1.6991349, 0.9008097, 34.1481994>,
    <-1.8039364, 0.6569970, 34.1380150>,
    <-1.7687296, 0.7443811, 34.1379890>,
    <-1.7734115, 0.7464584, 34.1516897>,
    <-1.7539720, 0.7875986, 34.1481994>,
    <-1.7571993, 0.7583275, 34.1211611>,
    <-1.7494710, 0.7815557, 34.1286034>,
    <-1.7463563, 0.7801652, 34.1174128>,
    <-1.7238947, 0.8350142, 34.1275355>,
    <-1.7962460, 0.6541482, 34.1125260>,
    <-1.7933593, 0.6530706, 34.1010718>,
    <-1.7751677, 0.7130370, 34.1174128>,
    <-1.7700269, 0.7184691, 34.1081947>,
    <-1.7993591, 0.6553072, 34.1237934>,
    <-1.7752651, 0.7206008, 34.1275355>,
    <-1.7530089, -0.7557400, 34.1038334>,
    <-1.7320875, -0.8072373, 34.1125260>,
    <-1.8042050, -0.6562591, 34.1380150>,
    <-1.7964826, -0.6534980, 34.1125260>,
    <-1.7441588, -0.7783659, 34.1076575>,
    <-1.7648144, -0.7418252, 34.1237934>,
    <-1.7996124, -0.6546113, 34.1237934>,
    <-1.7728814, -0.7113741, 34.1076575>,
    <-1.7725692, -0.7186958, 34.1168389>,
    <-1.7935787, -0.6524680, 34.1010718>,
    <-1.7414113, -0.7772006, 34.0961373>,
    <-1.7676122, -0.7167791, 34.0972345>,
    <-1.6973408, -0.8714600, 34.1010718>,
    <-1.7165443, -0.8306279, 34.0972345>,
    <-1.7104185, -0.8586492, 34.1211611>,
    <-1.7392696, -0.8105831, 34.1379890>,
    <-1.7232447, -0.8377982, 34.1286034>,
    <-1.7690502, -0.7436287, 34.1379890>,
    <-1.7201774, -0.8363060, 34.1174128>,
    <-1.7477561, -0.7838432, 34.1275355>,
    <-1.6872738, -0.9015260, 34.1174128>,
    <-1.6881306, -0.8940963, 34.1081947>,
    <-1.7071465, -0.8764465, 34.1379890>,
    <-1.6931306, -0.8967387, 34.1275355>,
    <-1.7265366, 0.8678854, 34.2216509>,
    <-1.7546822, 0.8190470, 34.2291393>,
    <-1.7058480, 0.9125688, 34.2249699>,
    <-1.7275550, 0.8882420, 34.2387176>,
    <-1.7391225, 0.8467019, 34.2249699>,
    <-1.7132088, 0.9085803, 34.2328318>,
    <-1.8082396, 0.6587362, 34.2060335>,
    <-1.7430530, 0.8134376, 34.2059966>,
    <-1.7794587, 0.7492113, 34.2192172>,
    <-1.7729363, 0.7463341, 34.2059966>,
    <-1.7340285, 0.8441398, 34.2149211>,
    <-1.7594855, 0.7902718, 34.2158771>,
    <-1.7108229, 0.8794449, 34.2059966>,
    <-1.7044724, 0.9038212, 34.2158771>,
    <-1.7591859, 0.7593766, 34.1894897>,
    <-1.7478467, 0.7810322, 34.1857817>,
    <-1.7524052, 0.7830520, 34.1968260>,
    <-1.7266405, 0.8365472, 34.1957715>,
    <-1.7971641, 0.6546639, 34.1809181>,
    <-1.8017597, 0.6563620, 34.1920745>,
    <-1.7766956, 0.7138340, 34.1857817>,
    <-1.7781131, 0.7219328, 34.1957715>,
    <-1.7927940, 0.6530462, 34.1694828>,
    <-1.7703631, 0.7188039, 34.1766071>,
    <-1.7529301, -0.7555136, 34.1722608>,
    <-1.7975174, -0.6536932, 34.1809181>,
    <-1.8086194, -0.6576928, 34.2060335>,
    <-1.7331137, -0.8074947, 34.1809181>,
    <-1.7732824, -0.7113514, 34.1760819>,
    <-1.8021293, -0.6553464, 34.1920745>,
    <-1.7673013, -0.7426593, 34.1920745>,
    <-1.7445660, -0.7783461, 34.1760819>,
    <-1.7741586, -0.7191424, 34.1852017>,
    <-1.6969504, -0.8710395, 34.1694828>,
    <-1.7403726, -0.7765502, 34.1645454>,
    <-1.7156668, -0.8299988, 34.1656437>,
    <-1.7931299, -0.6521233, 34.1694828>,
    <-1.7666880, -0.7162273, 34.1656437>,
    <-1.7124991, -0.8594967, 34.1894897>,
    <-1.7435422, -0.8123885, 34.2059966>,
    <-1.7217996, -0.8368904, 34.1857817>,
    <-1.7733897, -0.7452701, 34.2059966>,
    <-1.7262770, -0.8390841, 34.1968260>,
    <-1.7506955, -0.7849611, 34.1957715>,
    <-1.7113465, -0.8784137, 34.2059966>,
    <-1.6888665, -0.9021841, 34.1857817>,
    <-1.6959817, -0.8980642, 34.1957715>,
    <-1.6886032, -0.8941386, 34.1766071>,
    <-1.7708424, -0.9402052, 34.2989756>,
    <-1.7923169, -0.8916102, 34.2975521>,
    <-1.7946678, -0.9134158, 34.3035582>,
    <-1.7791681, -0.9206540, 34.2980080>,
    <-1.8166123, -0.8566541, 34.3007100>,
    <-1.8186488, -0.8658869, 34.3035582>,
    <-1.7812740, -0.9286539, 34.3008727>,
    <-1.8001784, -0.8911708, 34.3007914>,
    <-1.7706868, -0.9609446, 34.3035582>,
    <-1.7521027, -0.9709351, 34.2980080>,
    <-1.7593413, -0.9694187, 34.3007914>,
    <-1.7660579, -0.9275863, 34.2937748>,
    <-1.7530782, -0.9585361, 34.2951914>,
    <-1.7394522, 0.8743066, 34.1991181>,
    <-1.7674137, 0.8249088, 34.2059260>,
    <-1.7519630, 0.8528788, 34.2021355>,
    <-1.7395697, 0.8943364, 34.2146338>,
    <-1.7184435, 0.9192364, 34.2021355>,
    <-1.7254455, 0.9149922, 34.2092829>,
    <-1.7568417, 0.8198093, 34.1848862>,
    <-1.7243587, 0.8863390, 34.1848862>,
    <-1.7473321, 0.8505496, 34.1929998>,
    <-1.7175034, 0.9106658, 34.1938690>,
    <-1.8225403, 0.6638875, 34.1849198>,
    <-1.7869593, 0.7521748, 34.1848862>,
    <-1.7928888, 0.7547905, 34.1969055>,
    <-1.7729357, 0.7962420, 34.1938690>,
    <-1.7738112, 0.7656304, 34.1698789>,
    <-1.7666718, 0.7893674, 34.1765488>,
    <-1.7625277, 0.7875312, 34.1665078>,
    <-1.7407430, 0.8433149, 34.1755900>,
    <-1.8124433, 0.6601750, 34.1620860>,
    <-1.8084704, 0.6587044, 34.1516897>,
    <-1.7916149, 0.7197726, 34.1665078>,
    <-1.7855841, 0.7249259, 34.1581668>,
    <-1.8166211, 0.6617188, 34.1722289>,
    <-1.7926295, 0.7277703, 34.1755900>,
    <-1.7681242, -0.7621186, 34.1542153>,
    <-1.7478059, -0.8144067, 34.1620860>,
    <-1.8228855, -0.6629389, 34.1849198>,
    <-1.8127644, -0.6592926, 34.1620860>,
    <-1.7595453, -0.7850893, 34.1576891>,
    <-1.7818367, -0.7488341, 34.1722289>,
    <-1.8169571, -0.6607955, 34.1722289>,
    <-1.7885121, -0.7175157, 34.1576891>,
    <-1.7890345, -0.7252336, 34.1659804>,
    <-1.8087758, -0.6578655, 34.1516897>,
    <-1.7557332, -0.7834567, 34.1472010>,
    <-1.7822431, -0.7225835, 34.1481994>,
    <-1.7117473, -0.8786978, 34.1516897>,
    <-1.7307670, -0.8373618, 34.1481994>,
    <-1.7266909, -0.8666805, 34.1698789>,
    <-1.7572864, -0.8188555, 34.1848862>,
    <-1.7402853, -0.8459535, 34.1765488>,
    <-1.7873715, -0.7512076, 34.1848862>,
    <-1.7362150, -0.8439592, 34.1665078>,
    <-1.7649448, -0.7914141, 34.1755900>,
    <-1.7030057, -0.9097957, 34.1665078>,
    <-1.7030768, -0.9018634, 34.1581668>,
    <-1.7248347, -0.8854016, 34.1848862>,
    <-1.7097845, -0.9054321, 34.1755900>,
    <-1.7517998, 0.8809179, 34.2635082>,
    <-1.7807668, 0.8320887, 34.2695801>,
    <-1.7309744, 0.9266250, 34.2662252>,
    <-1.7532080, 0.9045813, 34.2772285>,
    <-1.7647429, 0.8597886, 34.2662252>,
    <-1.7385624, 0.9241718, 34.2725930>,
    <-1.8334834, 0.6680375, 34.2505667>,
    <-1.7673714, 0.8248999, 34.2505227>,
    <-1.8053724, 0.7602413, 34.2614925>,
    <-1.7976758, 0.7568593, 34.2505227>,
    <-1.7589415, 0.8563760, 34.2579678>,
    <-1.7848411, 0.8017749, 34.2587527>,
    <-1.7346876, 0.8918287, 34.2505227>,
    <-1.7290331, 0.9169505, 34.2587527>,
    <-1.7823473, 0.7695000, 34.2365221>,
    <-1.7705421, 0.7913071, 34.2333423>,
    <-1.7760943, 0.7937557, 34.2427845>,
    <-1.7498871, 0.8479400, 34.2418824>,
    <-1.8200879, 0.6631354, 34.2291393>,
    <-1.8257149, 0.6652051, 34.2387176>,
    <-1.7997740, 0.7232280, 34.2333423>,
    <-1.8020658, 0.7317703, 34.2418824>,
    <-1.8146557, 0.6611346, 34.2192172>,
    <-1.7925633, 0.7279525, 34.2254131>,
    <-1.7746351, -0.7647378, 34.2216509>,
    <-1.8205234, -0.6619388, 34.2291393>,
    <-1.8339361, -0.6667940, 34.2505667>,
    <-1.7553144, -0.8176913, 34.2291393>,
    <-1.7955663, -0.7201675, 34.2249699>,
    <-1.8261643, -0.6639702, 34.2387176>,
    <-1.7908838, -0.7524329, 34.2387176>,
    <-1.7664977, -0.7879956, 34.2249699>,
    <-1.7972423, -0.7283699, 34.2328318>,
    <-1.7177432, -0.8815607, 34.2192172>,
    <-1.7612606, -0.7857403, 34.2149211>,
    <-1.7363588, -0.8398672, 34.2158771>,
    <-1.8150761, -0.6599797, 34.2192172>,
    <-1.7879810, -0.7247366, 34.2158771>,
    <-1.7351420, -0.8707321, 34.2365221>,
    <-1.7679544, -0.8236496, 34.2505227>,
    <-1.7442589, -0.8476715, 34.2333423>,
    <-1.7982162, -0.7555913, 34.2505227>,
    <-1.7497036, -0.8503508, 34.2427845>,
    <-1.7743655, -0.7954459, 34.2418824>,
    <-1.7353116, -0.8905998, 34.2505227>,
    <-1.7108972, -0.9138249, 34.2333423>,
    <-1.7189142, -0.9100896, 34.2418824>,
    <-1.7098814, -0.9052643, 34.2254131>,
    <-1.7972905, 0.9647200, 34.2894172>,
    <-1.8167319, 0.9171219, 34.2882663>,
    <-1.8424455, 0.8811169, 34.2918019>,
    <-1.8092069, 0.9523956, 34.2918011>,
    <-1.8046637, 0.9463563, 34.2889150>,
    <-1.8328201, 0.8939634, 34.2903405>,
    <-1.8259423, 0.9165073, 34.2918015>,
    <-1.8016288, 0.9610374, 34.2904035>,
    <-1.8166405, 0.9287732, 34.2903614>,
    <-1.7923166, 0.9886158, 34.2918006>,
    <-1.7855881, 0.9864950, 34.2889147>,
    <-1.7879297, 0.9897276, 34.2903608>,
    <-1.7961817, 0.9488545, 34.2861103>,
    <-1.7873371, 0.9745737, 34.2874561>,
    <-1.7487381, 0.5133092, 34.0216554>,
    <-1.7758948, 0.4412592, 34.0241612>,
    <-1.7374104, 0.5645898, 34.0230110>,
    <-1.7694195, 0.5212558, 34.0307903>,
    <-1.7614608, 0.4799853, 34.0227527>,
    <-1.7520147, 0.5491992, 34.0270433>,
    <-1.7414332, 0.4719925, 34.0159774>,
    <-1.7727108, 0.3883842, 34.0185802>,
    <-1.7566940, 0.4150376, 34.0159774>,
    <-1.7463091, 0.4973464, 34.0193657>,
    <-1.7614433, 0.4401635, 34.0191845>,
    <-1.7227366, 0.5417705, 34.0159774>,
    <-1.7286201, 0.5585402, 34.0193911>,
    <-1.7624837, 0.8859829, 34.2371711>,
    <-1.7913561, 0.8361922, 34.2427102>,
    <-1.7754004, 0.8643902, 34.2396408>,
    <-1.7638072, 0.9068999, 34.2497196>,
    <-1.7414317, 0.9316292, 34.2396408>,
    <-1.7490786, 0.9276240, 34.2454279>,
    <-1.7789493, 0.8302296, 34.2253660>,
    <-1.7460539, 0.8975971, 34.2253660>,
    <-1.7699803, 0.8616734, 34.2321345>,
    <-1.7398312, 0.9226015, 34.2328481>,
    <-1.8454892, 0.6723433, 34.2254060>,
    <-1.8094498, 0.7617433, 34.2253660>,
    <-1.8164468, 0.7648178, 34.2353389>,
    <-1.7959863, 0.8066994, 34.2328481>,
    <-1.7948671, 0.7748336, 34.2126378>,
    <-1.7882074, 0.7990981, 34.2183311>,
    <-1.7831600, 0.7968721, 34.2097470>,
    <-1.7618764, 0.8536720, 34.2175110>,
    <-1.8332831, 0.6678764, 34.2059260>,
    <-1.8283447, 0.6660575, 34.1969055>,
    <-1.8125954, 0.7283126, 34.2097470>,
    <-1.8057661, 0.7332428, 34.2025384>,
    <-1.8383985, 0.6697580, 34.2146338>,
    <-1.8144048, 0.7367135, 34.2175110>,
    <-1.7878560, -0.7705043, 34.1991181>,
    <-1.7679884, -0.8236763, 34.2059260>,
    <-1.8459007, -0.6712128, 34.2254060>,
    <-1.8336790, -0.6667886, 34.2059260>,
    <-1.7794832, -0.7938616, 34.2021355>,
    <-1.8032753, -0.7577193, 34.2146338>,
    <-1.8388071, -0.6686354, 34.2146338>,
    <-1.8087701, -0.7255303, 34.2021355>,
    <-1.8100197, -0.7336222, 34.2092829>,
    <-1.8287269, -0.6650077, 34.1969055>,
    <-1.7747222, -0.7918113, 34.1929998>,
    <-1.8016003, -0.7303192, 34.1938690>,
    <-1.7306498, -0.8882625, 34.1969055>,
    <-1.7495779, -0.8463331, 34.1938690>,
    <-1.7472753, -0.8768945, 34.2126378>,
    <-1.7794793, -0.8290929, 34.2253660>,
    <-1.7615822, -0.8561960, 34.2183311>,
    <-1.8099411, -0.7605906, 34.2253660>,
    <-1.7566325, -0.8537603, 34.2097470>,
    <-1.7864630, -0.8009458, 34.2175110>,
    <-1.7230336, -0.9203783, 34.2097470>,
    <-1.7224206, -0.9119776, 34.2025384>,
    <-1.7466212, -0.8964799, 34.2253660>,
    <-1.7306322, -0.9163643, 34.2175110>,
    <-1.7980295, 0.5387671, 34.0581798>,
    <-1.8151127, 0.4867515, 34.0677166>,
    <-1.7854622, 0.5848161, 34.0621232>,
    <-1.7982390, 0.5565579, 34.0805061>,
    <-1.8061698, 0.5162130, 34.0621232>,
    <-1.7900253, 0.5790689, 34.0723106>,
    <-1.8387127, 0.3249814, 34.0418316>,
    <-1.8025311, 0.4826848, 34.0420883>,
    <-1.8282707, 0.4163260, 34.0557354>,
    <-1.8190457, 0.4144710, 34.0419476>,
    <-1.8013182, 0.5150063, 34.0506039>,
    <-1.8164939, 0.4591327, 34.0517365>,
    <-1.7832211, 0.5479167, 34.0419476>,
    <-1.7830161, 0.5770359, 34.0517365>,
    <-1.7973681, 0.4165590, 34.0293980>,
    <-1.7893422, 0.4255364, 34.0269153>,
    <-1.8014694, 0.4477324, 34.0346899>,
    <-1.7866112, 0.4896472, 34.0335539>,
    <-1.8016044, 0.3239591, 34.0242593>,
    <-1.8186230, 0.3215792, 34.0310201>,
    <-1.7997802, 0.3783417, 34.0269153>,
    <-1.8118734, 0.3888707, 34.0335539>,
    <-1.7818630, 0.3479304, 34.0187427>,
    <-1.7875696, 0.3788936, 34.0223916>,
    <-1.7735964, -0.4263432, 34.0219726>,
    <-1.8043493, -0.3186710, 34.0246558>,
    <-1.8383627, -0.3249778, 34.0417578>,
    <-1.7657287, -0.4951771, 34.0252615>,
    <-1.7883143, -0.3776717, 34.0231299>,
    <-1.8189851, -0.3221010, 34.0311675>,
    <-1.7985314, -0.4229796, 34.0315040>,
    <-1.7703491, -0.4577825, 34.0234664>,
    <-1.7957772, -0.3933575, 34.0275191>,
    <-1.7431485, -0.4677698, 34.0159774>,
    <-1.7297152, -0.5657873, 34.0197144>,
    <-1.7227335, -0.5439584, 34.0159774>,
    <-1.7616574, -0.4434664, 34.0194847>,
    <-1.7462172, -0.5051378, 34.0196603>,
    <-1.7635636, -0.3915812, 34.0159774>,
    <-1.7899608, -0.3191020, 34.0190299>,
    <-1.7769214, -0.3800984, 34.0193911>,
    <-1.7681389, -0.5349939, 34.0300324>,
    <-1.8028005, -0.4827778, 34.0421478>,
    <-1.7675244, -0.5191207, 34.0277479>,
    <-1.8192558, -0.4153348, 34.0420666>,
    <-1.7854458, -0.5112831, 34.0349278>,
    <-1.7957980, -0.4623619, 34.0340297>,
    <-1.7830720, -0.5506280, 34.0420666>,
    <-1.7505369, -0.5742794, 34.0277479>,
    <-1.7653436, -0.5695222, 34.0340297>,
    <-1.7396364, -0.5719035, 34.0233431>,
    <-1.8025108, -0.9535246, 34.2894166>,
    <-1.8164400, -0.9368832, 34.2918006>,
    <-1.8536773, -0.8570298, 34.2917990>,
    <-1.8223638, -0.9047353, 34.2882651>,
    <-1.8078009, -0.9478357, 34.2904030>,
    <-1.8357824, -0.8954046, 34.2917998>,
    <-1.8423791, -0.8734638, 34.2903384>,
    <-1.8103157, -0.9340586, 34.2889141>,
    <-1.8247436, -0.9113954, 34.2903601>,
    <-1.7956933, -0.9486669, 34.2861096>,
    <-1.7889421, -0.9793016, 34.2889145>,
    <-1.7891095, -0.9700666, 34.2874555>,
    <-1.7961326, -0.9804309, 34.2918014>,
    <-1.7917848, -0.9816003, 34.2903610>,
    <-1.8112101, 0.5426923, 34.1168394>,
    <-1.8283753, 0.4903745, 34.1264018>,
    <-1.7981473, 0.5890405, 34.1210460>,
    <-1.8119040, 0.5609596, 34.1387967>,
    <-1.8190069, 0.5199239, 34.1210460>,
    <-1.8028430, 0.5833791, 34.1311462>,
    <-1.8578761, 0.3278937, 34.0973598>,
    <-1.8213094, 0.4883372, 34.0973402>,
    <-1.8425756, 0.4194362, 34.1138015>,
    <-1.8387274, 0.4184663, 34.0973402>,
    <-1.8158678, 0.5189632, 34.1083733>,
    <-1.8310438, 0.4626114, 34.1095803>,
    <-1.8014387, 0.5575501, 34.0973402>,
    <-1.7973107, 0.5814894, 34.1095803>,
    <-1.8311256, 0.4342185, 34.0775018>,
    <-1.8244384, 0.4572670, 34.0732308>,
    <-1.8271805, 0.4579081, 34.0861763>,
    <-1.8116369, 0.5140470, 34.0849170>,
    <-1.8513108, 0.3267380, 34.0677166>,
    <-1.8543222, 0.3272329, 34.0805061>,
    <-1.8408748, 0.3873309, 34.0732308>,
    <-1.8418315, 0.3945134, 34.0849170>,
    <-1.8470703, 0.3261564, 34.0557354>,
    <-1.8363761, 0.3934969, 34.0632019>,
    <-1.8265423, -0.4324130, 34.0581798>,
    <-1.8514192, -0.3261473, 34.0677166>,
    <-1.8579787, -0.3273118, 34.0973598>,
    <-1.8153177, -0.4860106, 34.0677166>,
    <-1.8386740, -0.3862571, 34.0621232>,
    <-1.8544131, -0.3267172, 34.0805061>,
    <-1.8355996, -0.4171262, 34.0805061>,
    <-1.8223058, -0.4560230, 34.0621232>,
    <-1.8397418, -0.3935243, 34.0723106>,
    <-1.7915248, -0.5535599, 34.0557354>,
    <-1.8175344, -0.4546150, 34.0506039>,
    <-1.8027376, -0.5105929, 34.0517365>,
    <-1.8472509, -0.3252287, 34.0557354>,
    <-1.8326966, -0.3917469, 34.0517365>,
    <-1.8029126, -0.5395169, 34.0775018>,
    <-1.8214688, -0.4877423, 34.0973402>,
    <-1.8086480, -0.5162107, 34.0732308>,
    <-1.8388667, -0.4178668, 34.0973402>,
    <-1.8113388, -0.5170302, 34.0861763>,
    <-1.8259471, -0.4606407, 34.0849170>,
    <-1.8016177, -0.5569613, 34.0973402>,
    <-1.7879143, -0.5849954, 34.0732308>,
    <-1.7923295, -0.5792572, 34.0849170>,
    <-1.7871149, -0.5773952, 34.0632019>,
    <-1.7765868, 0.9032332, 34.2933120>,
    <-1.7899568, 0.8906432, 34.2967794>,
    <-1.7608438, 0.9397995, 34.2949171>,
    <-1.7641628, 0.9621898, 34.3007507>,
    <-1.7831625, 0.8966073, 34.2949171>,
    <-1.7632142, 0.9496768, 34.2980246>,
    <-1.8606442, 0.6902460, 34.2867877>,
    <-1.7943485, 0.8398992, 34.2854038>,
    <-1.8188939, 0.8104200, 34.2926777>,
    <-1.8237588, 0.7755562, 34.2856693>,
    <-1.7851640, 0.8737313, 34.2900253>,
    <-1.8057961, 0.8323277, 34.2908029>,
    <-1.7616245, 0.9075044, 34.2856693>,
    <-1.7583894, 0.9294491, 34.2908029>,
    <-1.8043953, 0.8714532, 34.2989756>,
    <-1.7794377, 0.9462262, 34.3035582>,
    <-1.7989875, 0.8777569, 34.2980080>,
    <-1.7636480, 0.9776763, 34.3035582>,
    <-1.7945239, 0.9015231, 34.3008727>,
    <-1.7800361, 0.9306381, 34.3007914>,
    <-1.8352618, 0.7991648, 34.2975521>,
    <-1.7952274, 0.9147761, 34.3035582>,
    <-1.8239800, 0.8397202, 34.3007100>,
    <-1.8194035, 0.8353310, 34.2980080>,
    <-1.8090007, 0.8715372, 34.3007914>,
    <-1.8459765, 0.7563047, 34.2937748>,
    <-1.8230655, 0.8131898, 34.2951914>,
    <-1.8094742, 0.7817327, 34.2753407>,
    <-1.7972501, 0.8038407, 34.2729301>,
    <-1.8033393, 0.8069798, 34.2800513>,
    <-1.7763221, 0.8628436, 34.2795037>,
    <-1.8473088, 0.6738797, 34.2695801>,
    <-1.8534567, 0.6783229, 34.2772285>,
    <-1.8270257, 0.7347591, 34.2729301>,
    <-1.8296942, 0.7450107, 34.2795037>,
    <-1.8410927, 0.6708683, 34.2614925>,
    <-1.8191762, 0.7388693, 34.2665723>,
    <-1.8008704, -0.7757106, 34.2635082>,
    <-1.8482938, -0.6712007, 34.2695801>,
    <-1.8691360, -0.6671613, 34.2867877>,
    <-1.7821130, -0.8292799, 34.2695801>,
    <-1.8225139, -0.7303739, 34.2662252>,
    <-1.8558945, -0.6717350, 34.2772285>,
    <-1.8200547, -0.7615404, 34.2772285>,
    <-1.7930202, -0.7992037, 34.2662252>,
    <-1.8255995, -0.7377447, 34.2725930>,
    <-1.7428497, -0.8943218, 34.2614925>,
    <-1.7866479, -0.7969594, 34.2579678>,
    <-1.7614689, -0.8518966, 34.2587527>,
    <-1.8415847, -0.6695166, 34.2614925>,
    <-1.8138259, -0.7351117, 34.2587527>,
    <-1.7619360, -0.8836353, 34.2753407>,
    <-1.7967124, -0.8345981, 34.2854038>,
    <-1.7710471, -0.8600649, 34.2729301>,
    <-1.8277019, -0.7660499, 34.2856693>,
    <-1.7773160, -0.8626893, 34.2800513>,
    <-1.8028519, -0.8060775, 34.2795037>,
    <-1.7662841, -0.8984791, 34.2856693>,
    <-1.7372366, -0.9272803, 34.2729301>,
    <-1.7467723, -0.9227094, 34.2795037>,
    <-1.7353506, -0.9186337, 34.2665723>,
    <-1.7669555, 0.5186333, 34.0200575>,
    <-1.7946236, 0.4459090, 34.0220252>,
    <-1.7799768, 0.4850203, 34.0209305>,
    <-1.7879017, 0.5266815, 34.0271844>,
    <-1.7551283, 0.5703087, 34.0209976>,
    <-1.7700443, 0.5548148, 34.0241726>,
    <-1.7599437, 0.4770232, 34.0159774>,
    <-1.7410483, 0.5475430, 34.0159774>,
    <-1.7647140, 0.5025844, 34.0184082>,
    <-1.7465131, 0.5643012, 34.0183546>,
    <-1.7753667, 0.4194630, 34.0159774>,
    <-1.7915150, 0.3925134, 34.0178631>,
    <-1.7801192, 0.4448384, 34.0183009>,
    <-1.8165008, 0.5442787, 34.0506060>,
    <-1.8336047, 0.4916820, 34.0592183>,
    <-1.8246613, 0.5214724, 34.0541438>,
    <-1.8163397, 0.5621283, 34.0708032>,
    <-1.8037421, 0.5907795, 34.0541438>,
    <-1.8081832, 0.5849142, 34.0633523>,
    <-1.8212977, 0.4876958, 34.0364216>,
    <-1.8017893, 0.5536075, 34.0363197>,
    <-1.8199418, 0.5203115, 34.0438443>,
    <-1.8014336, 0.5829772, 34.0448606>,
    <-1.8574932, 0.3255579, 34.0360499>,
    <-1.8379859, 0.4187719, 34.0363197>,
    <-1.8470918, 0.4205884, 34.0484530>,
    <-1.8352565, 0.4638539, 34.0448606>,
    <-1.8162721, 0.4209355, 34.0259962>,
    <-1.8203372, 0.4524129, 34.0302000>,
    <-1.8081989, 0.4300188, 34.0240583>,
    <-1.8053408, 0.4947705, 34.0293378>,
    <-1.8205623, 0.3246672, 34.0220547>,
    <-1.8010423, 0.3449656, 34.0179808>,
    <-1.8187466, 0.3823269, 34.0240583>,
    <-1.8064747, 0.3829047, 34.0206243>,
    <-1.8371760, 0.3207602, 34.0271844>,
    <-1.8308665, 0.3929394, 34.0293378>,
    <-1.7929706, -0.4309558, 34.0204813>,
    <-1.7844130, -0.5004175, 34.0228405>,
    <-1.8576545, -0.3284008, 34.0361559>,
    <-1.8255485, -0.3221210, 34.0228405>,
    <-1.7892821, -0.4626612, 34.0215203>,
    <-1.8176397, -0.4274691, 34.0277741>,
    <-1.8394663, -0.3257187, 34.0277741>,
    <-1.8085949, -0.3818926, 34.0215203>,
    <-1.8156085, -0.3976587, 34.0248083>,
    <-1.7616761, -0.4727358, 34.0159774>,
    <-1.8110296, -0.3216526, 34.0186848>,
    <-1.7823087, -0.3957358, 34.0159774>,
    <-1.7805587, -0.4482036, 34.0185671>,
    <-1.7966776, -0.3842767, 34.0186456>,
    <-1.7410435, -0.5497358, 34.0159774>,
    <-1.7480434, -0.5717846, 34.0186848>,
    <-1.7647214, -0.5104916, 34.0186456>,
    <-1.7867203, -0.5406255, 34.0264558>,
    <-1.8215606, -0.4878174, 34.0364647>,
    <-1.8041355, -0.5166468, 34.0303723>,
    <-1.8381891, -0.4196725, 34.0364059>,
    <-1.7861336, -0.5245942, 34.0246615>,
    <-1.8146095, -0.4672177, 34.0296825>,
    <-1.7689670, -0.5803333, 34.0246615>,
    <-1.7580164, -0.5779508, 34.0213137>,
    <-1.8016274, -0.5563745, 34.0364059>,
    <-1.7838356, -0.5754991, 34.0296825>,
    <-1.7889101, 0.8991051, 34.2672347>,
    <-1.8191211, 0.8481068, 34.2713545>,
    <-1.8024104, 0.8770900, 34.2690979>,
    <-1.7936852, 0.9177050, 34.2765463>,
    <-1.7679318, 0.9453328, 34.2690979>,
    <-1.7772448, 0.9404657, 34.2734378>,
    <-1.8045749, 0.8422693, 34.2582019>,
    <-1.7712027, 0.9106078, 34.2582019>,
    <-1.7959826, 0.8744069, 34.2634197>,
    <-1.7654401, 0.9362543, 34.2639559>,
    <-1.8720861, 0.6821073, 34.2582471>,
    <-1.8355179, 0.7727957, 34.2582019>,
    <-1.8433696, 0.7762357, 34.2658251>,
    <-1.8224232, 0.8186531, 34.2639559>,
    <-1.8197270, 0.7856574, 34.2481381>,
    <-1.8134236, 0.8104520, 34.2526827>,
    <-1.8076260, 0.8079038, 34.2458152>,
    <-1.7866525, 0.8657708, 34.2520259>,
    <-1.8581322, 0.6770184, 34.2427102>,
    <-1.8523784, 0.6749064, 34.2353389>,
    <-1.8374715, 0.7383975, 34.2458152>,
    <-1.8299596, 0.7431672, 34.2399571>,
    <-1.8640298, 0.6791806, 34.2497196>,
    <-1.8399291, 0.7471588, 34.2520259>,
    <-1.8116050, -0.7806420, 34.2371711>,
    <-1.7920219, -0.8347644, 34.2427102>,
    <-1.8725513, -0.6808293, 34.2582471>,
    <-1.8585908, -0.6757582, 34.2427102>,
    <-1.8033667, -0.8044163, 34.2396408>,
    <-1.8284790, -0.7682107, 34.2497196>,
    <-1.8644986, -0.6778927, 34.2497196>,
    <-1.8330401, -0.7351744, 34.2396408>,
    <-1.8348873, -0.7436067, 34.2454279>,
    <-1.8528256, -0.6736775, 34.2353389>,
    <-1.7978016, -0.8020106, 34.2321345>,
    <-1.8250957, -0.7397512, 34.2328481>,
    <-1.7534739, -0.8998635, 34.2353389>,
    <-1.7724053, -0.8572689, 34.2328481>,
    <-1.7715464, -0.8889809, 34.2481381>,
    <-1.8051741, -0.8409843, 34.2582019>,
    <-1.7864884, -0.8682146, 34.2526827>,
    <-1.8360732, -0.7714926, 34.2582019>,
    <-1.7808098, -0.8654114, 34.2458152>,
    <-1.8116570, -0.8121485, 34.2520259>,
    <-1.7467492, -0.9329520, 34.2458152>,
    <-1.7455745, -0.9241317, 34.2399571>,
    <-1.7718440, -0.9093448, 34.2582019>,
    <-1.7550404, -0.9292031, 34.2520259>,
    <-1.8126827, 0.2325351, 34.0227427>,
    <-1.8318648, 0.1649323, 34.0269314>,
    <-1.8079860, 0.2687594, 34.0231450>,
    <-1.8364779, 0.2327890, 34.0324272>,
    <-1.8221092, 0.1983922, 34.0246450>,
    <-1.8225182, 0.2543749, 34.0279625>,
    <-1.8244722, 0.1044464, 34.0225462>,
    <-1.8070178, 0.2333720, 34.0206632>,
    <-1.8159465, 0.1647654, 34.0213315>,
    <-1.7958430, 0.2901384, 34.0198344>,
    <-1.8284571, 0.5480048, 34.1722608>,
    <-1.8466897, 0.4954471, 34.1809181>,
    <-1.8156610, 0.5949172, 34.1760819>,
    <-1.8312035, 0.5670894, 34.1920745>,
    <-1.8367263, 0.5251377, 34.1760819>,
    <-1.8213401, 0.5895121, 34.1852017>,
    <-1.8736872, 0.3308202, 34.1544411>,
    <-1.8367930, 0.4926333, 34.1544124>,
    <-1.8598328, 0.4235237, 34.1694828>,
    <-1.8543641, 0.4221677, 34.1544124>,
    <-1.8323596, 0.5238180, 34.1645454>,
    <-1.8477900, 0.4669934, 34.1656437>,
    <-1.8167485, 0.5624349, 34.1544124>,
    <-1.8137435, 0.5869433, 34.1656437>,
    <-1.8449337, 0.4376224, 34.1359011>,
    <-1.8379924, 0.4607655, 34.1317777>,
    <-1.8416321, 0.4616769, 34.1440880>,
    <-1.8258366, 0.5182364, 34.1429132>,
    <-1.8648447, 0.3292089, 34.1264018>,
    <-1.8684386, 0.3298697, 34.1387967>,
    <-1.8545558, 0.3903144, 34.1317777>,
    <-1.8562816, 0.3977491, 34.1429132>,
    <-1.8615118, 0.3285929, 34.1138015>,
    <-1.8502000, 0.3964403, 34.1216372>,
    <-1.8399001, -0.4356198, 34.1168394>,
    <-1.8649769, -0.3284593, 34.1264018>,
    <-1.8738371, -0.3299695, 34.1544411>,
    <-1.8286067, -0.4895109, 34.1264018>,
    <-1.8517615, -0.3889497, 34.1210460>,
    <-1.8685800, -0.3290675, 34.1387967>,
    <-1.8496347, -0.4201467, 34.1387967>,
    <-1.8352681, -0.4592362, 34.1210460>,
    <-1.8529974, -0.3962004, 34.1311462>,
    <-1.8054354, -0.5580454, 34.1138015>,
    <-1.8320692, -0.4584986, 34.1083733>,
    <-1.8170361, -0.5148887, 34.1095803>,
    <-1.8616343, -0.3278982, 34.1138015>,
    <-1.8472614, -0.3950708, 34.1095803>,
    <-1.8165706, -0.5434748, 34.1359011>,
    <-1.8370261, -0.4917636, 34.1544124>,
    <-1.8221308, -0.5199616, 34.1317777>,
    <-1.8545678, -0.4212914, 34.1544124>,
    <-1.8257387, -0.5209922, 34.1440880>,
    <-1.8403391, -0.4641125, 34.1429132>,
    <-1.8170103, -0.5615742, 34.1544124>,
    <-1.8012496, -0.5892558, 34.1317777>,
    <-1.8064616, -0.5836801, 34.1429132>,
    <-1.8005404, -0.5817727, 34.1216372>,
    <-1.8286630, 0.5478820, 34.1038334>,
    <-1.8457381, 0.4949848, 34.1125260>,
    <-1.8364271, 0.5248608, 34.1076575>,
    <-1.8287624, 0.5661298, 34.1237934>,
    <-1.8153685, 0.5946421, 34.1076575>,
    <-1.8198356, 0.5888326, 34.1168389>,
    <-1.8393146, 0.4931327, 34.0861074>,
    <-1.8192485, 0.5630302, 34.0861074>,
    <-1.8335734, 0.5239874, 34.0961373>,
    <-1.8148062, 0.5871146, 34.0972345>,
    <-1.8762432, 0.3311050, 34.0861253>,
    <-1.8569039, 0.4225707, 34.0861074>,
    <-1.8604022, 0.4234525, 34.1010718>,
    <-1.8488665, 0.4670755, 34.0972345>,
    <-1.8496142, 0.4385760, 34.0680823>,
    <-1.8454706, 0.4624635, 34.0759583>,
    <-1.8429357, 0.4618763, 34.0642124>,
    <-1.8297948, 0.5191688, 34.0748134>,
    <-1.8701683, 0.3300424, 34.0592183>,
    <-1.8660833, 0.3294935, 34.0484530>,
    <-1.8595372, 0.3912331, 34.0642124>,
    <-1.8551617, 0.3974987, 34.0551646>,
    <-1.8729827, 0.3304991, 34.0708032>,
    <-1.8602894, 0.3984402, 34.0748134>,
    <-1.8452948, -0.4368755, 34.0506060>,
    <-1.8337975, -0.4909866, 34.0592183>,
    <-1.8763365, -0.3305760, 34.0861253>,
    <-1.8702696, -0.3294919, 34.0592183>,
    <-1.8409496, -0.4607140, 34.0541438>,
    <-1.8540605, -0.4213525, 34.0708032>,
    <-1.8730653, -0.3300303, 34.0708032>,
    <-1.8574866, -0.3902326, 34.0541438>,
    <-1.8583897, -0.3975410, 34.0633523>,
    <-1.8662585, -0.3285957, 34.0484530>,
    <-1.8363155, -0.4593325, 34.0438443>,
    <-1.8516172, -0.3958103, 34.0448606>,
    <-1.8099556, -0.5592791, 34.0484530>,
    <-1.8213471, -0.5158856, 34.0448606>,
    <-1.8211029, -0.5449875, 34.0680823>,
    <-1.8394595, -0.4925919, 34.0861074>,
    <-1.8294561, -0.5222301, 34.0759583>,
    <-1.8570305, -0.4220258, 34.0861074>,
    <-1.8269718, -0.5214676, 34.0642124>,
    <-1.8442331, -0.4652840, 34.0748134>,
    <-1.8060275, -0.5909472, 34.0642124>,
    <-1.8053846, -0.5833224, 34.0551646>,
    <-1.8194113, -0.5624950, 34.0861074>,
    <-1.8102779, -0.5850854, 34.0748134>,
    <-1.8642749, 0.2183640, 34.0581798>,
    <-1.8720629, 0.1641683, 34.0677166>,
    <-1.8598922, 0.2658926, 34.0621232>,
    <-1.8675650, 0.2358416, 34.0805061>,
    <-1.8683724, 0.1947359, 34.0621232>,
    <-1.8633851, 0.2594369, 34.0723106>,
    <-1.8671569, -0.0015239, 34.0418661>,
    <-1.8593836, 0.1634944, 34.0422290>,
    <-1.8727988, 0.0925361, 34.0557354>,
    <-1.8643865, 0.0923519, 34.0422290>,
    <-1.8633946, 0.1944011, 34.0506039>,
    <-1.8686366, 0.1367403, 34.0517365>,
    <-1.8518916, 0.2344163, 34.0422290>,
    <-1.8561411, 0.2586655, 34.0517365>,
    <-1.8468483, 0.1091989, 34.0309402>,
    <-1.8411085, 0.1330941, 34.0289781>,
    <-1.8534648, 0.1326311, 34.0352527>,
    <-1.8469036, 0.1898056, 34.0346796>,
    <-1.8397498, 0.0015640, 34.0269443>,
    <-1.8516589, -0.0024023, 34.0324788>,
    <-1.8451285, 0.0626773, 34.0289781>,
    <-1.8558310, 0.0684723, 34.0346796>,
    <-1.8277176, 0.0063016, 34.0225462>,
    <-1.8344375, 0.0725429, 34.0250143>,
    <-1.8233115, -0.1185977, 34.0228804>,
    <-1.8221724, -0.1907830, 34.0247370>,
    <-1.8317606, -0.0629134, 34.0246966>,
    <-1.8434585, -0.1104584, 34.0313299>,
    <-1.8222305, -0.1513467, 34.0234549>,
    <-1.8386053, -0.0797240, 34.0281690>,
    <-1.7989067, -0.2679390, 34.0191924>,
    <-1.8155787, -0.1406669, 34.0207148>,
    <-1.8080948, -0.2051246, 34.0200410>,
    <-1.8217755, -0.0674799, 34.0213315>,
    <-1.8326433, -0.2225624, 34.0296735>,
    <-1.8590847, -0.1626739, 34.0421142>,
    <-1.8285794, -0.2105220, 34.0272768>,
    <-1.8633941, -0.0941741, 34.0419993>,
    <-1.8465104, -0.1945304, 34.0347932>,
    <-1.8474691, -0.1476634, 34.0337605>,
    <-1.8513460, -0.2326369, 34.0419993>,
    <-1.8218911, -0.2625009, 34.0272768>,
    <-1.8364559, -0.2542508, 34.0337605>,
    <-1.8102086, -0.2652377, 34.0228047>,
    <-1.8275699, -0.8215250, 34.2989756>,
    <-1.8325031, -0.7983415, 34.2967794>,
    <-1.8689603, -0.7540995, 34.3035582>,
    <-1.8286635, -0.8134346, 34.2980080>,
    <-1.8704200, -0.7325049, 34.3007507>,
    <-1.8821255, -0.7219702, 34.3035582>,
    <-1.8443364, -0.7945335, 34.3008727>,
    <-1.8568146, -0.7648457, 34.3007914>,
    <-1.8557951, -0.7862288, 34.3035582>,
    <-1.8097275, -0.8562344, 34.2980080>,
    <-1.8311336, -0.8247890, 34.3007914>,
    <-1.7898287, -0.8721752, 34.2926777>,
    <-1.7948322, -0.8734503, 34.2951914>,
    <-1.8588799, 0.7516423, 34.2989756>,
    <-1.8537779, 0.7868048, 34.3035582>,
    <-1.8491278, 0.7704742, 34.2980080>,
    <-1.8323975, 0.8350654, 34.3035582>,
    <-1.8567720, 0.7669195, 34.3008727>,
    <-1.8399758, 0.8051117, 34.3007914>,
    <-1.8847128, 0.6713868, 34.2967794>,
    <-1.8751583, 0.7385442, 34.3035582>,
    <-1.8910078, 0.6808758, 34.3007507>,
    <-1.8704691, 0.7177845, 34.2980080>,
    <-1.8741531, 0.7243515, 34.3007914>,
    <-1.8763631, 0.6730908, 34.2926777>,
    <-1.8614273, 0.7264693, 34.2951914>,
    <-1.8337920, -0.7801217, 34.2933120>,
    <-1.8749746, -0.6967781, 34.2967794>,
    <-1.8519737, -0.7444830, 34.2949171>,
    <-1.8855283, -0.6934828, 34.3007507>,
    <-1.8327173, -0.7893920, 34.2949171>,
    <-1.8606443, -0.7398910, 34.2980246>,
    <-1.8166602, -0.8057486, 34.2900253>,
    <-1.7980982, -0.8481473, 34.2908029>,
    <-1.8699223, -0.6902229, 34.2926777>,
    <-1.8425344, -0.7493606, 34.2908029>,
    <-1.8779313, 0.2199342, 34.1168394>,
    <-1.8857508, 0.1654306, 34.1264018>,
    <-1.8731152, 0.2678466, 34.1210460>,
    <-1.8817867, 0.2378036, 34.1387967>,
    <-1.8816560, 0.1961578, 34.1210460>,
    <-1.8767565, 0.2614559, 34.1311462>,
    <-1.8865889, 0.0002954, 34.0973598>,
    <-1.8784385, 0.1646512, 34.0973402>,
    <-1.8874171, 0.0931042, 34.1138015>,
    <-1.8834589, 0.0928171, 34.0973402>,
    <-1.8783977, 0.1957569, 34.1083733>,
    <-1.8835577, 0.1376258, 34.1095803>,
    <-1.8708883, 0.2362631, 34.0973402>,
    <-1.8709801, 0.2605555, 34.1095803>,
    <-1.8787085, 0.1096508, 34.0775018>,
    <-1.8761259, 0.1335112, 34.0732308>,
    <-1.8789365, 0.1336649, 34.0861763>,
    <-1.8733774, 0.1916500, 34.0849170>,
    <-1.8799250, 0.0003001, 34.0677166>,
    <-1.8829743, 0.0002618, 34.0805061>,
    <-1.8801684, 0.0617834, 34.0732308>,
    <-1.8823565, 0.0686891, 34.0849170>,
    <-1.8756550, 0.0004719, 34.0557354>,
    <-1.8768126, 0.0686414, 34.0632019>,
    <-1.8738764, -0.1086750, 34.0581798>,
    <-1.8721319, -0.1634034, 34.0677166>,
    <-1.8778110, -0.0611104, 34.0621232>,
    <-1.8801460, -0.0920406, 34.0805061>,
    <-1.8738061, -0.1326587, 34.0621232>,
    <-1.8801268, -0.0680780, 34.0723106>,
    <-1.8604249, -0.2340672, 34.0557354>,
    <-1.8688553, -0.1321129, 34.0506039>,
    <-1.8640043, -0.1898089, 34.0517365>,
    <-1.8728707, -0.0675661, 34.0517365>,
    <-1.8692080, -0.2182487, 34.0775018>,
    <-1.8784922, -0.1640376, 34.0973402>,
    <-1.8708087, -0.1943015, 34.0732308>,
    <-1.8834920, -0.0922026, 34.0973402>,
    <-1.8736019, -0.1946396, 34.0861763>,
    <-1.8781963, -0.1365701, 34.0849170>,
    <-1.8709624, -0.2356522, 34.0973402>,
    <-1.8623343, -0.2656416, 34.0732308>,
    <-1.8656870, -0.2592222, 34.0849170>,
    <-1.8602242, -0.2583007, 34.0632019>,
    <-1.8443421, 0.5527115, 34.1542153>,
    <-1.8623875, 0.4995962, 34.1620860>,
    <-1.8525356, 0.5296006, 34.1576891>,
    <-1.8463074, 0.5717023, 34.1722289>,
    <-1.8312899, 0.5999844, 34.1576891>,
    <-1.8366511, 0.5944080, 34.1659804>,
    <-1.8533906, 0.4970382, 34.1379890>,
    <-1.8331664, 0.5674709, 34.1379890>,
    <-1.8485659, 0.5284009, 34.1472010>,
    <-1.8297451, 0.5920727, 34.1481994>,
    <-1.8906169, 0.3337654, 34.1380150>,
    <-1.8711191, 0.4259356, 34.1379890>,
    <-1.8760906, 0.4271684, 34.1516897>,
    <-1.8640903, 0.4710592, 34.1481994>,
    <-1.8621856, 0.4416723, 34.1211611>,
    <-1.8586083, 0.4658897, 34.1286034>,
    <-1.8552995, 0.4650611, 34.1174128>,
    <-1.8427036, 0.5229772, 34.1275355>,
    <-1.8825486, 0.3322954, 34.1125260>,
    <-1.8795187, 0.3317354, 34.1010718>,
    <-1.8720165, 0.3939497, 34.1174128>,
    <-1.8678971, 0.4001920, 34.1081947>,
    <-1.8858157, 0.3328962, 34.1237934>,
    <-1.8734258, 0.4013817, 34.1275355>,
    <-1.8576097, -0.4398518, 34.1038334>,
    <-1.8459485, -0.4941997, 34.1125260>,
    <-1.8907533, -0.3329921, 34.1380150>,
    <-1.8826688, -0.3316140, 34.1125260>,
    <-1.8528229, -0.4636708, 34.1076575>,
    <-1.8668196, -0.4240984, 34.1237934>,
    <-1.8859443, -0.3321669, 34.1237934>,
    <-1.8694762, -0.3927091, 34.1076575>,
    <-1.8704401, -0.3999738, 34.1168389>,
    <-1.8796301, -0.3311039, 34.1010718>,
    <-1.8499148, -0.4630003, 34.0961373>,
    <-1.8652256, -0.3989470, 34.0972345>,
    <-1.8228818, -0.5634805, 34.1010718>,
    <-1.8347031, -0.5199340, 34.0972345>,
    <-1.8335362, -0.5485933, 34.1211611>,
    <-1.8536025, -0.4962476, 34.1379890>,
    <-1.8425469, -0.5258319, 34.1286034>,
    <-1.8713042, -0.4251390, 34.1379890>,
    <-1.8392670, -0.5248950, 34.1174128>,
    <-1.8573167, -0.4684402, 34.1275355>,
    <-1.8181887, -0.5948378, 34.1174128>,
    <-1.8177423, -0.5873721, 34.1081947>,
    <-1.8334044, -0.5666885, 34.1379890>,
    <-1.8231252, -0.5891061, 34.1275355>,
    <-1.8310552, 0.2054814, 34.0203714>,
    <-1.8458112, 0.1253646, 34.0221755>,
    <-1.8381593, 0.1674000, 34.0211153>,
    <-1.8524543, 0.2100766, 34.0272515>,
    <-1.8268269, 0.2607468, 34.0210482>,
    <-1.8395129, 0.2402852, 34.0241726>,
    <-1.8271144, 0.1903958, 34.0191144>,
    <-1.8159957, 0.2665625, 34.0187717>,
    <-1.8361512, 0.0464342, 34.0180922>,
    <-1.8333974, 0.1179897, 34.0188254>,
    <-1.8510133, 0.5548904, 34.2216509>,
    <-1.8702507, 0.5019065, 34.2291393>,
    <-1.8383983, 0.6024874, 34.2249699>,
    <-1.8555511, 0.5747609, 34.2387176>,
    <-1.8597295, 0.5318431, 34.2249699>,
    <-1.8449546, 0.5972814, 34.2328318>,
    <-1.8951567, 0.3347310, 34.2060335>,
    <-1.8578241, 0.4984017, 34.2059966>,
    <-1.8825239, 0.4288293, 34.2192172>,
    <-1.8756009, 0.4271284, 34.2059966>,
    <-1.8542680, 0.5302045, 34.2149211>,
    <-1.8699842, 0.4727343, 34.2158771>,
    <-1.8375457, 0.5690029, 34.2059966>,
    <-1.8355246, 0.5941116, 34.2158771>,
    <-1.8643242, 0.4423605, 34.1894897>,
    <-1.8569178, 0.4656562, 34.1857817>,
    <-1.8617577, 0.4668537, 34.1968260>,
    <-1.8456738, 0.5240102, 34.1957715>,
    <-1.8835423, 0.3326438, 34.1809181>,
    <-1.8883629, 0.3335181, 34.1920745>,
    <-1.8736595, 0.3944693, 34.1857817>,
    <-1.8764619, 0.4021989, 34.1957715>,
    <-1.8789577, 0.3318096, 34.1694828>,
    <-1.8682863, 0.4004633, 34.1766071>,
    <-1.8574927, -0.4396425, 34.1722608>,
    <-1.8837217, -0.3316265, 34.1809181>,
    <-1.8953495, -0.3336375, 34.2060335>,
    <-1.8470037, -0.4942750, 34.1809181>,
    <-1.8698671, -0.3926172, 34.1760819>,
    <-1.8885506, -0.3324537, 34.1920745>,
    <-1.8694134, -0.4244880, 34.1920745>,
    <-1.8532205, -0.4635806, 34.1760819>,
    <-1.8720829, -0.4001376, 34.1852017>,
    <-1.8224244, -0.5631342, 34.1694828>,
    <-1.8487790, -0.4625401, 34.1645454>,
    <-1.8337298, -0.5194669, 34.1656437>,
    <-1.8791282, -0.3308424, 34.1694828>,
    <-1.8642196, -0.3985640, 34.1656437>,
    <-1.8357324, -0.5490667, 34.1894897>,
    <-1.8581237, -0.4972835, 34.2059966>,
    <-1.8409661, -0.5251888, 34.1857817>,
    <-1.8758627, -0.4260019, 34.2059966>,
    <-1.8457564, -0.5265717, 34.1968260>,
    <-1.8604055, -0.4690307, 34.1957715>,
    <-1.8378823, -0.5678964, 34.2059966>,
    <-1.8198714, -0.5952093, 34.1857817>,
    <-1.8261631, -0.5899165, 34.1957715>,
    <-1.8182150, -0.5873318, 34.1766071>,
    <-1.8834227, 0.2205843, 34.0506060>,
    <-1.8911302, 0.1658128, 34.0592183>,
    <-1.8874963, 0.1967044, 34.0541438>,
    <-1.8863580, 0.2381842, 34.0708032>,
    <-1.8789300, 0.2685911, 34.0541438>,
    <-1.8822821, 0.2620403, 34.0633523>,
    <-1.8783716, 0.1641309, 34.0364283>,
    <-1.8706193, 0.2326516, 34.0363331>,
    <-1.8826565, 0.1963918, 34.0438443>,
    <-1.8753105, 0.2613185, 34.0448606>,
    <-1.8862028, -0.0008753, 34.0361074>,
    <-1.8828778, 0.0932848, 34.0363331>,
    <-1.8920742, 0.0934655, 34.0484530>,
    <-1.8879341, 0.1381318, 34.0448606>,
    <-1.8622700, 0.0985603, 34.0260678>,
    <-1.8714040, 0.1298056, 34.0302268>,
    <-1.8560983, 0.1080543, 34.0241522>,
    <-1.8640517, 0.1750196, 34.0293915>,
    <-1.8504584, -0.0008333, 34.0221676>,
    <-1.8365123, -0.0042822, 34.0179745>,
    <-1.8583329, 0.0577839, 34.0241522>,
    <-1.8472493, 0.0513875, 34.0207317>,
    <-1.8659234, -0.0014865, 34.0273376>,
    <-1.8716099, 0.0691259, 34.0293915>,
    <-1.8395174, -0.1132707, 34.0202873>,
    <-1.8440167, -0.1831143, 34.0228223>,
    <-1.8419820, -0.1451098, 34.0214475>,
    <-1.8638431, -0.1054534, 34.0277014>,
    <-1.8452300, -0.0622428, 34.0210838>,
    <-1.8555983, -0.0764988, 34.0245173>,
    <-1.8168366, -0.1599150, 34.0159774>,
    <-1.8237843, -0.0805045, 34.0159774>,
    <-1.8308517, -0.1324349, 34.0184943>,
    <-1.8345781, -0.0666963, 34.0183546>,
    <-1.8098889, -0.2393254, 34.0159774>,
    <-1.8206410, -0.2597739, 34.0186848>,
    <-1.8264215, -0.1965182, 34.0186456>,
    <-1.8533886, -0.2222594, 34.0264558>,
    <-1.8785727, -0.1641331, 34.0364647>,
    <-1.8663983, -0.1955834, 34.0303723>,
    <-1.8831146, -0.0941372, 34.0364059>,
    <-1.8500149, -0.2065934, 34.0246615>,
    <-1.8681244, -0.1450954, 34.0296825>,
    <-1.8427880, -0.2644666, 34.0246615>,
    <-1.8315620, -0.2640677, 34.0213137>,
    <-1.8708464, -0.2351113, 34.0364059>,
    <-1.8566209, -0.2570757, 34.0296825>,
    <-1.8818334, 0.7837462, 34.2894178>,
    <-1.9014850, 0.7370941, 34.2886788>,
    <-1.8994656, 0.7588377, 34.2918015>,
    <-1.8739332, 0.8135920, 34.2918021>,
    <-1.8918349, 0.7593860, 34.2889153>,
    <-1.9004462, 0.7488265, 34.2903190>,
    <-1.8877386, 0.7839864, 34.2918019>,
    <-1.8792064, 0.7948274, 34.2904042>,
    <-1.8908807, 0.7695657, 34.2903617>,
    <-1.8615828, 0.8206992, 34.2882666>,
    <-1.8586390, 0.8463903, 34.2918020>,
    <-1.8493229, 0.8585735, 34.2903406>,
    <-1.8741882, 0.7972295, 34.2889154>,
    <-1.8651235, 0.8248021, 34.2903619>,
    <-1.9082904, 0.6838425, 34.2830969>,
    <-1.8787457, 0.7708350, 34.2861105>,
    <-1.9026400, 0.7219191, 34.2867235>,
    <-1.8884131, 0.7576881, 34.2874564>,
    <-1.8386254, 0.8611292, 34.2863580>,
    <-1.8487508, 0.8434030, 34.2872643>,
    <-1.8285278, 0.8869570, 34.2872642>,
    <-1.8397314, 0.8715733, 34.2889216>,
    <-1.8405275, 0.8366804, 34.2817250>,
    <-1.8084855, 0.9055540, 34.2819691>,
    <-1.8385839, 0.8524285, 34.2845089>,
    <-1.8151271, 0.9042281, 34.2850030>,
    <-1.8704789, 0.7703752, 34.2819691>,
    <-1.8609630, 0.8051896, 34.2850030>,
    <-1.8490860, 0.7942534, 34.2751874>,
    <-1.8448173, 0.8151653, 34.2783022>,
    <-1.8359928, 0.8187558, 34.2735942>,
    <-1.8175594, 0.8731023, 34.2779937>,
    <-1.8868202, 0.6864239, 34.2713545>,
    <-1.8798411, 0.6849823, 34.2658251>,
    <-1.8662330, 0.7481243, 34.2735942>,
    <-1.8574297, 0.7543975, 34.2692880>,
    <-1.8950748, 0.6861035, 34.2765462>,
    <-1.8714091, 0.7524018, 34.2779937>,
    <-1.8386224, -0.7925116, 34.2672347>,
    <-1.8189242, -0.8485793, 34.2713544>,
    <-1.9003204, -0.7058480, 34.2830964>,
    <-1.8865412, -0.6871977, 34.2713544>,
    <-1.8304092, -0.8170800, 34.2690979>,
    <-1.8556746, -0.7849700, 34.2765461>,
    <-1.8924435, -0.6933617, 34.2765461>,
    <-1.8605237, -0.7468023, 34.2690979>,
    <-1.8626382, -0.7574733, 34.2734378>,
    <-1.8803399, -0.6836117, 34.2658251>,
    <-1.8242699, -0.8137446, 34.2634197>,
    <-1.8520154, -0.7505929, 34.2639559>,
    <-1.7795262, -0.9131484, 34.2658251>,
    <-1.7985557, -0.8698371, 34.2639559>,
    <-1.8405853, -0.8569296, 34.2863568>,
    <-1.8679774, -0.8073149, 34.2882644>,
    <-1.8330169, -0.8771182, 34.2872630>,
    <-1.8592333, -0.8373204, 34.2903380>,
    <-1.8535870, -0.8332512, 34.2872627>,
    <-1.8479810, -0.8538818, 34.2889197>,
    <-1.8237548, -0.8726611, 34.2817246>,
    <-1.8796237, -0.7702682, 34.2861090>,
    <-1.8557581, -0.8043794, 34.2819686>,
    <-1.8344186, -0.8613688, 34.2845081>,
    <-1.8587418, -0.8108307, 34.2850020>,
    <-1.7918795, -0.9387764, 34.2819687>,
    <-1.8120993, -0.9098743, 34.2850022>,
    <-1.7969502, -0.9060623, 34.2751874>,
    <-1.8101600, -0.8894958, 34.2783020>,
    <-1.8073089, -0.8803021, 34.2735942>,
    <-1.8369486, -0.8316565, 34.2779935>,
    <-1.7726171, -0.9488582, 34.2735942>,
    <-1.7718348, -0.9379563, 34.2692880>,
    <-1.7790087, -0.9504513, 34.2779935>,
    <-1.8958387, 0.2221711, 34.1722608>,
    <-1.9046678, 0.1672459, 34.1809181>,
    <-1.8913833, 0.2705928, 34.1760819>,
    <-1.9018574, 0.2404889, 34.1920745>,
    <-1.9000115, 0.1982155, 34.1760819>,
    <-1.8960376, 0.2642837, 34.1852017>,
    <-1.9026680, 0.0004319, 34.1544411>,
    <-1.8944329, 0.1661933, 34.1544124>,
    <-1.9051219, 0.0941328, 34.1694828>,
    <-1.8995008, 0.0937470, 34.1544124>,
    <-1.8954820, 0.1976741, 34.1645454>,
    <-1.9008104, 0.1390333, 34.1656437>,
    <-1.8868138, 0.2384152, 34.1544124>,
    <-1.8881103, 0.2630730, 34.1656437>,
    <-1.8928973, 0.1106046, 34.1359011>,
    <-1.8900802, 0.1346014, 34.1317777>,
    <-1.8938230, 0.1348669, 34.1440880>,
    <-1.8880889, 0.1933100, 34.1429132>,
    <-1.8936801, 0.0003805, 34.1264018>,
    <-1.8973341, 0.0004073, 34.1387967>,
    <-1.8941583, 0.0623444, 34.1317777>,
    <-1.8971489, 0.0693664, 34.1429132>,
    <-1.8902909, 0.0003527, 34.1138015>,
    <-1.8909325, 0.0691336, 34.1216372>,
    <-1.8875924, -0.1095064, 34.1168394>,
    <-1.8858287, -0.1645399, 34.1264018>,
    <-1.8911695, -0.0614856, 34.1210460>,
    <-1.8944923, -0.0925780, 34.1387967>,
    <-1.8871318, -0.1335684, 34.1210460>,
    <-1.8936457, -0.0684116, 34.1311462>,
    <-1.8749103, -0.2360568, 34.1138015>,
    <-1.8838534, -0.1333975, 34.1083733>,
    <-1.8788407, -0.1915414, 34.1095803>,
    <-1.8878007, -0.0682952, 34.1095803>,
    <-1.8833462, -0.2197740, 34.1359011>,
    <-1.8945113, -0.1652963, 34.1544124>,
    <-1.8847389, -0.1956524, 34.1317777>,
    <-1.8995492, -0.0928487, 34.1544124>,
    <-1.8884709, -0.1960409, 34.1440880>,
    <-1.8929725, -0.1374901, 34.1429132>,
    <-1.8869221, -0.2375221, 34.1544124>,
    <-1.8762078, -0.2675199, 34.1317777>,
    <-1.8803723, -0.2611239, 34.1429132>,
    <-1.8742099, -0.2602736, 34.1216372>,
    <-1.8885678, -0.7694014, 34.2894146>,
    <-1.8835867, -0.7928898, 34.2917976>,
    <-1.8810105, -0.7828181, 34.2889127>,
    <-1.8696423, -0.8227933, 34.2917982>,
    <-1.8872666, -0.7775420, 34.2904005>,
    <-1.8743415, -0.8050339, 34.2903586>,
    <-1.9050501, -0.7468602, 34.2917969>,
    <-1.9046290, -0.7306507, 34.2886763>,
    <-1.8954195, -0.7675138, 34.2917971>,
    <-1.9051211, -0.7387999, 34.2903154>,
    <-1.8968146, -0.7489260, 34.2889123>,
    <-1.8972956, -0.7558084, 34.2903578>,
    <-1.9030107, -0.7223238, 34.2867219>,
    <-1.8916193, -0.7516896, 34.2874543>,
    <-1.8960203, 0.2220145, 34.1038334>,
    <-1.9036504, 0.1669558, 34.1125260>,
    <-1.8996688, 0.1979947, 34.1076575>,
    <-1.8992868, 0.2399678, 34.1237934>,
    <-1.8910474, 0.2703727, 34.1076575>,
    <-1.8944379, 0.2638758, 34.1168389>,
    <-1.8970029, 0.1662473, 34.0861074>,
    <-1.8893792, 0.2385673, 34.0861074>,
    <-1.8967067, 0.1976302, 34.0961373>,
    <-1.8891866, 0.2630572, 34.0972345>,
    <-1.9052346, 0.0002686, 34.0861253>,
    <-1.9020720, 0.0937029, 34.0861074>,
    <-1.9056703, 0.0939639, 34.1010718>,
    <-1.9018849, 0.1389273, 34.0972345>,
    <-1.8976729, 0.1107316, 34.0680823>,
    <-1.8977397, 0.1349750, 34.0759583>,
    <-1.8951426, 0.1348384, 34.0642124>,
    <-1.8921488, 0.1935409, 34.0748134>,
    <-1.8990699, 0.0002798, 34.0592183>,
    <-1.8949586, 0.0004567, 34.0484530>,
    <-1.8992249, 0.0623857, 34.0642124>,
    <-1.8960077, 0.0693203, 34.0551646>,
    <-1.9019184, 0.0002380, 34.0708032>,
    <-1.9012158, 0.0693511, 34.0748134>,
    <-1.8931189, -0.1098133, 34.0506060>,
    <-1.8911951, -0.1650949, 34.0592183>,
    <-1.8929813, -0.1340409, 34.0541438>,
    <-1.8990602, -0.0929970, 34.0708032>,
    <-1.8970281, -0.0617587, 34.0541438>,
    <-1.8991888, -0.0687955, 34.0633523>,
    <-1.8881703, -0.1334972, 34.0438443>,
    <-1.8922096, -0.0682821, 34.0448606>,
    <-1.8795688, -0.2364990, 34.0484530>,
    <-1.8832502, -0.1917896, 34.0448606>,
    <-1.8880719, -0.2204775, 34.0680823>,
    <-1.8970517, -0.1656895, 34.0861074>,
    <-1.8923469, -0.1966146, 34.0759583>,
    <-1.9021020, -0.0931443, 34.0861074>,
    <-1.8897668, -0.1962967, 34.0642124>,
    <-1.8970108, -0.1379676, 34.0748134>,
    <-1.8812058, -0.2683576, 34.0642124>,
    <-1.8792456, -0.2609653, 34.0551646>,
    <-1.8894466, -0.2380120, 34.0861074>,
    <-1.8843747, -0.2618451, 34.0748134>,
    <-1.8648478, 0.5589712, 34.1991181>,
    <-1.8838066, 0.5054684, 34.2059260>,
    <-1.8734476, 0.5356964, 34.2021355>,
    <-1.8684416, 0.5786764, 34.2146338>,
    <-1.8519602, 0.6068665, 34.2021355>,
    <-1.8581188, 0.6014710, 34.2092829>,
    <-1.8725097, 0.5022822, 34.1848862>,
    <-1.8520730, 0.5734418, 34.1848862>,
    <-1.8684826, 0.5342068, 34.1929998>,
    <-1.8495461, 0.5985894, 34.1938690>,
    <-1.9101346, 0.3373208, 34.1849198>,
    <-1.8904252, 0.4304454, 34.1848862>,
    <-1.8967188, 0.4319917, 34.1969055>,
    <-1.8842668, 0.4762782, 34.1938690>,
    <-1.8798134, 0.4459797, 34.1698789>,
    <-1.8769043, 0.4705958, 34.1765488>,
    <-1.8725044, 0.4695072, 34.1665078>,
    <-1.8607374, 0.5282262, 34.1755900>,
    <-1.8995464, 0.3354180, 34.1620860>,
    <-1.8953785, 0.3346597, 34.1516897>,
    <-1.8893835, 0.3977270, 34.1665078>,
    <-1.8843391, 0.4038492, 34.1581668>,
    <-1.9039288, 0.3362128, 34.1722289>,
    <-1.8917715, 0.4054270, 34.1755900>,
    <-1.8736029, -0.4435088, 34.1542153>,
    <-1.8626730, -0.4985307, 34.1620860>,
    <-1.9103099, -0.3363267, 34.1849198>,
    <-1.8997094, -0.3344933, 34.1620860>,
    <-1.8691432, -0.4676202, 34.1576891>,
    <-1.8848002, -0.4280450, 34.1722289>,
    <-1.9040994, -0.3352453, 34.1722289>,
    <-1.8859358, -0.3960432, 34.1576891>,
    <-1.8877905, -0.4035531, 34.1659804>,
    <-1.8955336, -0.3337804, 34.1516897>,
    <-1.8651054, -0.4666744, 34.1472010>,
    <-1.8806421, -0.4021226, 34.1481994>,
    <-1.8383263, -0.5681066, 34.1516897>,
    <-1.8498791, -0.5240959, 34.1481994>,
    <-1.8509560, -0.5536769, 34.1698789>,
    <-1.8727821, -0.5012657, 34.1848862>,
    <-1.8607447, -0.5309042, 34.1765488>,
    <-1.8906632, -0.4294213, 34.1848862>,
    <-1.8563899, -0.5296470, 34.1665078>,
    <-1.8755589, -0.4729113, 34.1755900>,
    <-1.8351176, -0.6002501, 34.1665078>,
    <-1.8338101, -0.5924259, 34.1581668>,
    <-1.8523790, -0.5724359, 34.1848862>,
    <-1.8410356, -0.5947756, 34.1755900>,
    <-1.9135493, 0.7143564, 34.2894164>,
    <-1.9155827, 0.7242743, 34.2917999>,
    <-1.9145164, 0.7185892, 34.2904025>,
    <-1.9085246, 0.7394105, 34.2918008>,
    <-1.9089184, 0.7222347, 34.2889144>,
    <-1.9082025, 0.7324192, 34.2903608>,
    <-1.9223196, 0.6845262, 34.2886777>,
    <-1.9180523, 0.6817165, 34.2867230>,
    <-1.9169682, 0.7023944, 34.2889138>,
    <-1.9117108, 0.7056640, 34.2874556>,
    <-1.9253243, 0.6889454, 34.2903168>,
    <-1.9213068, 0.7119988, 34.2917988>,
    <-1.9197551, 0.7055823, 34.2903595>,
    <-1.9154780, -0.7100055, 34.2894146>,
    <-1.9180055, -0.7190744, 34.2917976>,
    <-1.9111077, -0.7176411, 34.2889123>,
    <-1.9123877, -0.7311234, 34.2917971>,
    <-1.9166482, -0.7138982, 34.2904005>,
    <-1.9114358, -0.7254830, 34.2903578>,
    <-1.9234520, -0.6806825, 34.2886770>,
    <-1.9224768, -0.7094838, 34.2917982>,
    <-1.9267171, -0.6844834, 34.2903167>,
    <-1.9182273, -0.6992143, 34.2889127>,
    <-1.9211670, -0.7020857, 34.2903586>,
    <-1.9173880, -0.6829855, 34.2867222>,
    <-1.9120276, -0.7053962, 34.2874543>,
    <-1.9122998, 0.2240480, 34.1542153>,
    <-1.9208476, 0.1686061, 34.1620860>,
    <-1.9163556, 0.1998654, 34.1576891>,
    <-1.9175329, 0.2424089, 34.1722289>,
    <-1.9076547, 0.2728692, 34.1576891>,
    <-1.9119661, 0.2664465, 34.1659804>,
    <-1.9115432, 0.1676492, 34.1379890>,
    <-1.9038568, 0.2405237, 34.1379890>,
    <-1.9122379, 0.1993732, 34.1472010>,
    <-1.9047596, 0.2653459, 34.1481994>,
    <-1.9198519, 0.0003926, 34.1380150>,
    <-1.9166555, 0.0945483, 34.1379890>,
    <-1.9217656, 0.0948990, 34.1516897>,
    <-1.9175691, 0.1402069, 34.1481994>,
    <-1.9105904, 0.1115972, 34.1211611>,
    <-1.9112728, 0.1360678, 34.1286034>,
    <-1.9078703, 0.1358264, 34.1174128>,
    <-1.9055228, 0.1950499, 34.1275355>,
    <-1.9116509, 0.0003459, 34.1125260>,
    <-1.9085698, 0.0003206, 34.1010718>,
    <-1.9119850, 0.0628925, 34.1174128>,
    <-1.9090121, 0.0697552, 34.1081947>,
    <-1.9149728, 0.0003703, 34.1237934>,
    <-1.9146634, 0.0699668, 34.1275355>,
    <-1.9057679, -0.1105989, 34.1038334>,
    <-1.9037213, -0.1661461, 34.1125260>,
    <-1.9051900, -0.1348873, 34.1076575>,
    <-1.9121023, -0.0934856, 34.1237934>,
    <-1.9092679, -0.0621118, 34.1076575>,
    <-1.9114787, -0.0690988, 34.1168389>,
    <-1.9022096, -0.1347319, 34.0961373>,
    <-1.9061650, -0.0689930, 34.0972345>,
    <-1.8930355, -0.2383798, 34.1010718>,
    <-1.8971155, -0.1934422, 34.0972345>,
    <-1.9009429, -0.2218688, 34.1211611>,
    <-1.9116146, -0.1668337, 34.1379890>,
    <-1.9058642, -0.1978884, 34.1286034>,
    <-1.9166995, -0.0937316, 34.1379890>,
    <-1.9024715, -0.1975353, 34.1174128>,
    <-1.9104437, -0.1388039, 34.1275355>,
    <-1.8938588, -0.2700757, 34.1174128>,
    <-1.8921228, -0.2628010, 34.1081947>,
    <-1.9039553, -0.2397119, 34.1379890>,
    <-1.8977250, -0.2635739, 34.1275355>,
    <-1.8781631, 0.5633457, 34.2635082>,
    <-1.8982284, 0.5102466, 34.2695801>,
    <-1.8656002, 0.6119844, 34.2662252>,
    <-1.8837508, 0.5865020, 34.2772285>,
    <-1.8872497, 0.5402995, 34.2662252>,
    <-1.8726965, 0.6083032, 34.2725930>,
    <-1.9216322, 0.3395075, 34.2505667>,
    <-1.8837634, 0.5054670, 34.2505227>,
    <-1.9099593, 0.4351919, 34.2614925>,
    <-1.9017923, 0.4331978, 34.2505227>,
    <-1.8809273, 0.5379288, 34.2579678>,
    <-1.8969521, 0.4796597, 34.2587527>,
    <-1.8631983, 0.5770545, 34.2505227>,
    <-1.8619920, 0.6027766, 34.2587527>,
    <-1.8888917, 0.4483082, 34.2365221>,
    <-1.8810526, 0.4718339, 34.2333423>,
    <-1.8869457, 0.4732812, 34.2427845>,
    <-1.8705456, 0.5311932, 34.2418824>,
    <-1.9075889, 0.3370059, 34.2291393>,
    <-1.9134898, 0.3380671, 34.2387176>,
    <-1.8980186, 0.3997130, 34.2333423>,
    <-1.9017590, 0.4077276, 34.2418824>,
    <-1.9018918, 0.3359788, 34.2192172>,
    <-1.8917378, 0.4056179, 34.2254131>,
    <-1.8804698, -0.4449575, 34.2216509>,
    <-1.9078101, -0.3357519, 34.2291393>,
    <-1.9218620, -0.3382042, 34.2505667>,
    <-1.8706379, -0.5004616, 34.2291393>,
    <-1.8933433, -0.3974297, 34.2249699>,
    <-1.9137180, -0.3367729, 34.2387176>,
    <-1.8943348, -0.4300181, 34.2387176>,
    <-1.8764946, -0.4692751, 34.2249699>,
    <-1.8964182, -0.4052164, 34.2328318>,
    <-1.8447282, -0.5698849, 34.2192172>,
    <-1.8709455, -0.4679634, 34.2149211>,
    <-1.8558210, -0.5255922, 34.2158771>,
    <-1.9021052, -0.3347685, 34.2192172>,
    <-1.8866667, -0.4032465, 34.2158771>,
    <-1.8599823, -0.5561995, 34.2365221>,
    <-1.8841205, -0.5041344, 34.2505227>,
    <-1.8649563, -0.5319061, 34.2333423>,
    <-1.9021043, -0.4318553, 34.2505227>,
    <-1.8707835, -0.5335993, 34.2427845>,
    <-1.8855366, -0.4752460, 34.2418824>,
    <-1.8635994, -0.5757359, 34.2505227>,
    <-1.8435889, -0.6028477, 34.2333423>,
    <-1.8508354, -0.5977770, 34.2418824>,
    <-1.8411020, -0.5945935, 34.2254131>,
    <-1.9192480, 0.2250352, 34.2216509>,
    <-1.9289925, 0.1695158, 34.2291393>,
    <-1.9150897, 0.2740998, 34.2249699>,
    <-1.9271673, 0.2438159, 34.2387176>,
    <-1.9238297, 0.2008246, 34.2249699>,
    <-1.9206424, 0.2678344, 34.2328318>,
    <-1.9244904, 0.0005552, 34.2060335>,
    <-1.9161461, 0.1682221, 34.2059966>,
    <-1.9283896, 0.0954176, 34.2192172>,
    <-1.9212764, 0.0949447, 34.2059966>,
    <-1.9181666, 0.2001593, 34.2149211>,
    <-1.9236644, 0.1408331, 34.2158771>,
    <-1.9084355, 0.2412720, 34.2059966>,
    <-1.9108052, 0.2663502, 34.2158771>,
    <-1.9128161, 0.1119035, 34.1894897>,
    <-1.9095674, 0.1361314, 34.1857817>,
    <-1.9145417, 0.1364703, 34.1968260>,
    <-1.9086273, 0.1955514, 34.1957715>,
    <-1.9126901, 0.0005165, 34.1809181>,
    <-1.9175893, 0.0005404, 34.1920745>,
    <-1.9136933, 0.0631189, 34.1857817>,
    <-1.9177953, 0.0702444, 34.1957715>,
    <-1.9080302, 0.0004910, 34.1694828>,
    <-1.9094425, 0.0699548, 34.1766071>,
    <-1.9056163, -0.1104131, 34.1722608>,
    <-1.9047735, -0.1660371, 34.1809181>,
    <-1.9096369, -0.0619534, 34.1760819>,
    <-1.9147244, -0.0934188, 34.1920745>,
    <-1.9055658, -0.1347294, 34.1760819>,
    <-1.9131249, -0.0689749, 34.1852017>,
    <-1.8925248, -0.2381182, 34.1694828>,
    <-1.9010111, -0.1344760, 34.1645454>,
    <-1.8960757, -0.1931512, 34.1656437>,
    <-1.9051078, -0.0687906, 34.1656437>,
    <-1.9031879, -0.2219536, 34.1894897>,
    <-1.9162470, -0.1670689, 34.2059966>,
    <-1.9041957, -0.1975296, 34.1857817>,
    <-1.9213386, -0.0937898, 34.2059966>,
    <-1.9091534, -0.1980596, 34.1968260>,
    <-1.9135881, -0.1388491, 34.1957715>,
    <-1.9085749, -0.2401239, 34.2059966>,
    <-1.8955805, -0.2701494, 34.1857817>,
    <-1.9008575, -0.2638445, 34.1957715>,
    <-1.8925813, -0.2626791, 34.1766071>,
    <-1.8895570, 0.5664708, 34.2371711>,
    <-1.9093447, 0.5124229, 34.2427102>,
    <-1.8985278, 0.5429631, 34.2396408>,
    <-1.8944925, 0.5868402, 34.2497196>,
    <-1.8767512, 0.6150792, 34.2396408>,
    <-1.8835864, 0.6098070, 34.2454279>,
    <-1.8960909, 0.5087052, 34.2253660>,
    <-1.8753935, 0.5807615, 34.2253660>,
    <-1.8927184, 0.5412288, 34.2321345>,
    <-1.8736074, 0.6064666, 34.2328481>,
    <-1.9342033, 0.3416631, 34.2254060>,
    <-1.9142356, 0.4359630, 34.2253660>,
    <-1.9216601, 0.4377759, 34.2353389>,
    <-1.9087831, 0.4825741, 34.2328481>,
    <-1.9021475, 0.4513868, 34.2126378>,
    <-1.8998025, 0.4764390, 34.2183311>,
    <-1.8944451, 0.4751233, 34.2097470>,
    <-1.8833481, 0.5347562, 34.2175110>,
    <-1.9214069, 0.3393836, 34.2059260>,
    <-1.9162277, 0.3384499, 34.1969055>,
    <-1.9115281, 0.4024940, 34.2097470>,
    <-1.9056587, 0.4085352, 34.2025384>,
    <-1.9267714, 0.3403483, 34.2146338>,
    <-1.9147688, 0.4104531, 34.2175110>,
    <-1.8944912, -0.4483406, 34.1991181>,
    <-1.8841586, -0.5041548, 34.2059260>,
    <-1.9344122, -0.3404783, 34.2254060>,
    <-1.9216080, -0.3382436, 34.2059260>,
    <-1.8903015, -0.4727971, 34.2021355>,
    <-1.9074561, -0.4330724, 34.2146338>,
    <-1.9269788, -0.3391718, 34.2146338>,
    <-1.9072779, -0.4004182, 34.2021355>,
    <-1.9099136, -0.4081702, 34.2092829>,
    <-1.9164218, -0.3373496, 34.1969055>,
    <-1.8852568, -0.4716046, 34.1929998>,
    <-1.9010486, -0.4063794, 34.1938690>,
    <-1.8586026, -0.5742436, 34.1969055>,
    <-1.8699621, -0.5296644, 34.1938690>,
    <-1.8730014, -0.5601613, 34.2126378>,
    <-1.8964155, -0.5074938, 34.2253660>,
    <-1.8834967, -0.5372929, 34.2183311>,
    <-1.9145192, -0.4347425, 34.2253660>,
    <-1.8781993, -0.5357537, 34.2097470>,
    <-1.8984054, -0.4785615, 34.2175110>,
    <-1.8566789, -0.6071940, 34.2097470>,
    <-1.8546165, -0.5990274, 34.2025384>,
    <-1.8757581, -0.5795627, 34.2253660>,
    <-1.8634650, -0.6019216, 34.2175110>,
    <-1.9072775, -0.6184264, 34.2989756>,
    <-1.9203089, -0.5668956, 34.2975521>,
    <-1.9260189, -0.5878926, 34.3035582>,
    <-1.9121706, -0.5977414, 34.2980080>,
    <-1.9380958, -0.5282368, 34.3007100>,
    <-1.9413829, -0.5369185, 34.3035582>,
    <-1.9154996, -0.6052305, 34.3008727>,
    <-1.9276846, -0.5650455, 34.3007914>,
    <-1.9106548, -0.6388668, 34.3035582>,
    <-1.8941200, -0.6519382, 34.2980080>,
    <-1.9009528, -0.6491822, 34.3007914>,
    <-1.9006686, -0.6068824, 34.2937748>,
    <-1.8930255, -0.6395752, 34.2951914>,
    <-1.9335809, 0.2266517, 34.1991181>,
    <-1.9429610, 0.1706696, 34.2059260>,
    <-1.9380084, 0.2022373, 34.2021355>,
    <-1.9405419, 0.2454335, 34.2146338>,
    <-1.9292060, 0.2760574, 34.2021355>,
    <-1.9343342, 0.2696744, 34.2092829>,
    <-1.9312824, 0.1694935, 34.1848862>,
    <-1.9235129, 0.2431209, 34.1848862>,
    <-1.9328602, 0.2016324, 34.1929998>,
    <-1.9253913, 0.2683252, 34.1938690>,
    <-1.9396905, 0.0005048, 34.1849198>,
    <-1.9364514, 0.0956371, 34.1848862>,
    <-1.9429179, 0.0960670, 34.1969055>,
    <-1.9383454, 0.1418430, 34.1938690>,
    <-1.9286984, 0.1127781, 34.1698789>,
    <-1.9301080, 0.1375254, 34.1765488>,
    <-1.9255858, 0.1372173, 34.1665078>,
    <-1.9241941, 0.1970877, 34.1755900>,
    <-1.9289327, 0.0004695, 34.1620860>,
    <-1.9246965, 0.0004464, 34.1516897>,
    <-1.9297440, 0.0635966, 34.1665078>,
    <-1.9258394, 0.0705018, 34.1581668>,
    <-1.9333865, 0.0004913, 34.1722289>,
    <-1.9334328, 0.0707650, 34.1755900>,
    <-1.9221531, -0.1114232, 34.1542153>,
    <-1.9209438, -0.1675071, 34.1620860>,
    <-1.9219481, -0.1359427, 34.1576891>,
    <-1.9304951, -0.0942499, 34.1722289>,
    <-1.9260564, -0.0625371, 34.1576891>,
    <-1.9291870, -0.0696109, 34.1659804>,
    <-1.9178074, -0.1357124, 34.1472010>,
    <-1.9218988, -0.0694433, 34.1481994>,
    <-1.9090487, -0.2402538, 34.1516897>,
    <-1.9127836, -0.1949056, 34.1481994>,
    <-1.9189808, -0.2238502, 34.1698789>,
    <-1.9313742, -0.1684452, 34.1848862>,
    <-1.9246664, -0.1997236, 34.1765488>,
    <-1.9365079, -0.0945872, 34.1848862>,
    <-1.9201594, -0.1992418, 34.1665078>,
    <-1.9291851, -0.1400394, 34.1755900>,
    <-1.9114703, -0.2724661, 34.1665078>,
    <-1.9088241, -0.2649878, 34.1581668>,
    <-1.9236396, -0.2420771, 34.1848862>,
    <-1.9163479, -0.2660472, 34.1755900>,
    <-1.9380431, 0.1134948, 34.2365221>,
    <-1.9429182, 0.1706757, 34.2505227>,
    <-1.9344083, 0.1380244, 34.2333423>,
    <-1.9350965, 0.2447468, 34.2505227>,
    <-1.9404632, 0.1384264, 34.2427845>,
    <-1.9343685, 0.1983064, 34.2418824>,
    <-1.9513931, 0.0006617, 34.2505667>,
    <-1.9371288, 0.0006367, 34.2291393>,
    <-1.9481238, 0.0963738, 34.2505227>,
    <-1.9431243, 0.0006571, 34.2387176>,
    <-1.9385929, 0.0640530, 34.2333423>,
    <-1.9436681, 0.0712963, 34.2418824>,
    <-1.9313399, 0.0006145, 34.2192172>,
    <-1.9334329, 0.0709589, 34.2254131>,
    <-1.9291673, -0.1116575, 34.2216509>,
    <-1.9291229, -0.1680256, 34.2291393>,
    <-1.9335922, -0.0626162, 34.2249699>,
    <-1.9402275, -0.0945373, 34.2387176>,
    <-1.9294752, -0.1362959, 34.2249699>,
    <-1.9379725, -0.0697507, 34.2328318>,
    <-1.9156621, -0.2408933, 34.2192172>,
    <-1.9237826, -0.1359677, 34.2149211>,
    <-1.9188950, -0.1953473, 34.2158771>,
    <-1.9280270, -0.0695041, 34.2158771>,
    <-1.9283080, -0.2247671, 34.2365221>,
    <-1.9430385, -0.1693014, 34.2505227>,
    <-1.9289880, -0.1999790, 34.2333423>,
    <-1.9481979, -0.0949975, 34.2505227>,
    <-1.9350206, -0.2006346, 34.2427845>,
    <-1.9394167, -0.1406059, 34.2418824>,
    <-1.9352626, -0.2433785, 34.2505227>,
    <-1.9202640, -0.2735532, 34.2333423>,
    <-1.9265199, -0.2673013, 34.2418824>,
    <-1.9163816, -0.2658563, 34.2254131>,
    <-1.9065624, 0.5811503, 34.2933120>,
    <-1.9170245, 0.5660291, 34.2967794>,
    <-1.8977040, 0.6201669, 34.2949171>,
    <-1.9042237, 0.6411022, 34.3007507>,
    <-1.9116660, 0.5732968, 34.2949171>,
    <-1.9015127, 0.6292726, 34.2980246>,
    <-1.9520638, 0.3565468, 34.2867877>,
    <-1.9129595, 0.5155849, 34.2854038>,
    <-1.9316225, 0.4820155, 34.2926777>,
    <-1.9306515, 0.4470318, 34.2856693>,
    <-1.9098180, 0.5505298, 34.2900253>,
    <-1.9227536, 0.5060156, 34.2908029>,
    <-1.8926184, 0.5879881, 34.2856693>,
    <-1.8934239, 0.6103329, 34.2908029>,
    <-1.9271369, 0.5441005, 34.2989756>,
    <-1.9149620, 0.6216830, 34.3035582>,
    <-1.9232760, 0.5514949, 34.2980080>,
    <-1.9057503, 0.6559833, 34.3035582>,
    <-1.9223850, 0.5752591, 34.3008727>,
    <-1.9137577, 0.6068383, 34.3007914>,
    <-1.9447858, 0.4674201, 34.2975521>,
    <-1.9241736, 0.5873826, 34.3035582>,
    <-1.9399123, 0.5087799, 34.3007100>,
    <-1.9355213, 0.5058387, 34.2980080>,
    <-1.9309232, 0.5428731, 34.3007914>,
    <-1.9485220, 0.4237696, 34.2937748>,
    <-1.9358164, 0.4837547, 34.2951914>,
    <-1.9177346, 0.4556500, 34.2753407>,
    <-1.9095478, 0.4795568, 34.2729301>,
    <-1.9160818, 0.4815856, 34.2800513>,
    <-1.8992331, 0.5413498, 34.2795037>,
    <-1.9362502, 0.3428524, 34.2695801>,
    <-1.9430411, 0.3461370, 34.2772285>,
    <-1.9268508, 0.4063315, 34.2729301>,
    <-1.9312356, 0.4159483, 34.2795037>,
    <-1.9296174, 0.3409740, 34.2614925>,
    <-1.9198421, 0.4117476, 34.2665723>,
    <-1.9474501, 0.2286453, 34.2635082>,
    <-1.9579817, 0.1728631, 34.2695801>,
    <-1.9435197, 0.2787237, 34.2662252>,
    <-1.9569305, 0.2504505, 34.2772285>,
    <-1.9523923, 0.2043685, 34.2662252>,
    <-1.9498455, 0.2738505, 34.2725930>,
    <-1.9565130, 0.0969194, 34.2614925>,
    <-1.9457622, 0.2031368, 34.2579678>,
    <-1.9514251, 0.1429704, 34.2587527>,
    <-1.9383752, 0.2702875, 34.2587527>,
    <-1.9082186, -0.4512061, 34.2635082>,
    <-1.9367831, -0.3400447, 34.2695801>,
    <-1.9569248, -0.3323658, 34.2867877>,
    <-1.8990707, -0.5072156, 34.2695801>,
    <-1.9216691, -0.4027976, 34.2662252>,
    <-1.9444097, -0.3392327, 34.2772285>,
    <-1.9247603, -0.4339017, 34.2772285>,
    <-1.9045756, -0.4757033, 34.2662252>,
    <-1.9260330, -0.4095084, 34.2725930>,
    <-1.8716692, -0.5780924, 34.2614925>,
    <-1.8978952, -0.4746037, 34.2579678>,
    <-1.8826386, -0.5330785, 34.2587527>,
    <-1.9298672, -0.3395573, 34.2614925>,
    <-1.9139206, -0.4089762, 34.2587527>,
    <-1.8886878, -0.5642644, 34.2753407>,
    <-1.9147717, -0.5099800, 34.2854038>,
    <-1.8935302, -0.5394598, 34.2729301>,
    <-1.9334248, -0.4370476, 34.2856693>,
    <-1.9002943, -0.5409791, 34.2800513>,
    <-1.9155987, -0.4807708, 34.2795037>,
    <-1.8958359, -0.5781803, 34.2856693>,
    <-1.8718974, -0.6115305, 34.2729301>,
    <-1.8805928, -0.6053901, 34.2795037>,
    <-1.8685059, -0.6033372, 34.2665723>,
    <-1.9375066, 0.6379704, 34.2894164>,
    <-1.9483879, 0.5877173, 34.2882660>,
    <-1.9674586, 0.5477941, 34.2918015>,
    <-1.9471012, 0.6237656, 34.2917999>,
    <-1.9415792, 0.6186043, 34.2889144>,
    <-1.9602102, 0.5621169, 34.2903401>,
    <-1.9573511, 0.5855142, 34.2918008>,
    <-1.9411392, 0.6335911, 34.2904025>,
    <-1.9503206, 0.5992088, 34.2903608>,
    <-1.9367563, 0.6623711, 34.2917988>,
    <-1.9297629, 0.6614472, 34.2889138>,
    <-1.9326297, 0.6642258, 34.2903595>,
    <-1.9336603, 0.6225362, 34.2861101>,
    <-1.9294157, 0.6494017, 34.2874556>,
    <-1.9178605, 0.5748047, 34.2672347>,
    <-1.9387567, 0.5193351, 34.2713545>,
    <-1.9273328, 0.5507798, 34.2690979>,
    <-1.9257929, 0.5922929, 34.2765462>,
    <-1.9052282, 0.6239729, 34.2690979>,
    <-1.9135546, 0.6175627, 34.2734378>,
    <-1.9234179, 0.5161122, 34.2582019>,
    <-1.9024196, 0.5892076, 34.2582019>,
    <-1.9205368, 0.5492536, 34.2634197>,
    <-1.9011979, 0.6154651, 34.2639559>,
    <-1.9620916, 0.3466602, 34.2582471>,
    <-1.9418268, 0.4423209, 34.2582019>,
    <-1.9501566, 0.4443452, 34.2658251>,
    <-1.9368941, 0.4897554, 34.2639559>,
    <-1.9285092, 0.4577292, 34.2481381>,
    <-1.9266071, 0.4832417, 34.2526827>,
    <-1.9204552, 0.4817389, 34.2458152>,
    <-1.9098488, 0.5423689, 34.2520259>,
    <-1.9474660, 0.3440717, 34.2427102>,
    <-1.9414328, 0.3429909, 34.2353389>,
    <-1.9377775, 0.4081060, 34.2458152>,
    <-1.9312080, 0.4141077, 34.2399571>,
    <-1.9536495, 0.3451770, 34.2497196>,
    <-1.9417192, 0.4163074, 34.2520259>,
    <-1.9196397, -0.4542004, 34.2371711>,
    <-1.9097524, -0.5109011, 34.2427102>,
    <-1.9623278, -0.3453208, 34.2582471>,
    <-1.9476989, -0.3427510, 34.2427102>,
    <-1.9156549, -0.4790441, 34.2396408>,
    <-1.9340987, -0.4390278, 34.2497196>,
    <-1.9538875, -0.3438272, 34.2497196>,
    <-1.9328538, -0.4057014, 34.2396408>,
    <-1.9361372, -0.4136848, 34.2454279>,
    <-1.9416599, -0.3417031, 34.2353389>,
    <-1.9097566, -0.4776413, 34.2321345>,
    <-1.9258249, -0.4115882, 34.2328481>,
    <-1.8830944, -0.5817050, 34.2353389>,
    <-1.8943417, -0.5364701, 34.2328481>,
    <-1.8990026, -0.5678495, 34.2481381>,
    <-1.9237848, -0.5147427, 34.2582019>,
    <-1.9101115, -0.5448040, 34.2526827>,
    <-1.9421474, -0.4409411, 34.2582019>,
    <-1.9040324, -0.5430294, 34.2458152>,
    <-1.9251620, -0.4852192, 34.2520259>,
    <-1.8822176, -0.6154586, 34.2458152>,
    <-1.8795291, -0.6069763, 34.2399571>,
    <-1.9028318, -0.5878523, 34.2582019>,
    <-1.8897319, -0.6103268, 34.2520259>,
    <-1.9592170, 0.2297467, 34.2371711>,
    <-1.9693187, 0.1730838, 34.2427102>,
    <-1.9639695, 0.2050384, 34.2396408>,
    <-1.9676146, 0.2489496, 34.2497196>,
    <-1.9550465, 0.2798404, 34.2396408>,
    <-1.9608624, 0.2734613, 34.2454279>,
    <-1.9556208, 0.1717241, 34.2253660>,
    <-1.9477503, 0.2462798, 34.2253660>,
    <-1.9579471, 0.2043392, 34.2321345>,
    <-1.9504549, 0.2719045, 34.2328481>,
    <-1.9641476, 0.0006015, 34.2254060>,
    <-1.9608582, 0.0969363, 34.2253660>,
    <-1.9684847, 0.0974323, 34.2353389>,
    <-1.9635825, 0.1437860, 34.2328481>,
    <-1.9516320, 0.1142247, 34.2126378>,
    <-1.9536730, 0.1393036, 34.2183311>,
    <-1.9481685, 0.1389382, 34.2097470>,
    <-1.9475952, 0.1995921, 34.2175110>,
    <-1.9511498, 0.0005788, 34.2059260>,
    <-1.9458871, 0.0005586, 34.1969055>,
    <-1.9523800, 0.0644458, 34.2097470>,
    <-1.9476488, 0.0714145, 34.2025384>,
    <-1.9566002, 0.0005973, 34.2146338>,
    <-1.9569536, 0.0717213, 34.2175110>,
    <-1.9435631, -0.1125544, 34.1991181>,
    <-1.9430796, -0.1693149, 34.2059260>,
    <-1.9436839, -0.1373668, 34.2021355>,
    <-1.9536797, -0.0952667, 34.2146338>,
    <-1.9478339, -0.0631397, 34.2021355>,
    <-1.9517757, -0.0703162, 34.2092829>,
    <-1.9385088, -0.1370685, 34.1929998>,
    <-1.9427344, -0.0700920, 34.1938690>,
    <-1.9300825, -0.2427766, 34.1969055>,
    <-1.9335284, -0.1969021, 34.1938690>,
    <-1.9418173, -0.2264080, 34.2126378>,
    <-1.9557301, -0.1704748, 34.2253660>,
    <-1.9481821, -0.2020645, 34.2183311>,
    <-1.9609256, -0.0956851, 34.2253660>,
    <-1.9426979, -0.2014685, 34.2097470>,
    <-1.9526657, -0.1416365, 34.2175110>,
    <-1.9339099, -0.2755605, 34.2097470>,
    <-1.9304607, -0.2678761, 34.2025384>,
    <-1.9479012, -0.2450359, 34.2253660>,
    <-1.9396774, -0.2691897, 34.2175110>,
    <-1.9407084, -0.6260244, 34.2894156>,
    <-1.9515383, -0.6072111, 34.2917990>,
    <-1.9743394, -0.5221166, 34.2917985>,
    <-1.9517852, -0.5745359, 34.2882647>,
    <-1.9449312, -0.6195007, 34.2904017>,
    <-1.9633818, -0.5630107, 34.2917988>,
    <-1.9660664, -0.5402632, 34.2903380>,
    <-1.9450133, -0.6055022, 34.2889134>,
    <-1.9552870, -0.5806768, 34.2903593>,
    <-1.9331481, -0.6224323, 34.2861093>,
    <-1.9318223, -0.6537650, 34.2889133>,
    <-1.9303818, -0.6446463, 34.2874548>,
    <-1.9391042, -0.6536157, 34.2917990>,
    <-1.9350232, -0.6555290, 34.2903593>,
    <-1.9599878, 0.4166503, 34.2989756>,
    <-1.9604880, 0.4517770, 34.3035582>,
    <-1.9535312, 0.4368066, 34.2980080>,
    <-1.9469366, 0.5024296, 34.3035582>,
    <-1.9603125, 0.4318931, 34.3008727>,
    <-1.9498924, 0.4720789, 34.3007914>,
    <-1.9722332, 0.3336277, 34.2967794>,
    <-1.9740394, 0.4011243, 34.3035582>,
    <-1.9801582, 0.3419433, 34.3007507>,
    <-1.9658915, 0.3815422, 34.2980080>,
    <-1.9706218, 0.3873453, 34.3007914>,
    <-1.9643710, 0.3367944, 34.2926777>,
    <-1.9585359, 0.3916912, 34.2951914>,
    <-1.9427060, -0.4499838, 34.2933120>,
    <-1.9697759, -0.3605836, 34.2967794>,
    <-1.9448085, -0.4682556, 34.2967794>,
    <-1.9548009, -0.4116985, 34.2949171>,
    <-1.9802504, -0.3557413, 34.3007507>,
    <-1.9716330, -0.3969730, 34.3007507>,
    <-1.9433613, -0.4593669, 34.2949171>,
    <-1.9629726, -0.4058070, 34.2980246>,
    <-1.9149310, -0.5482687, 34.2926777>,
    <-1.9298176, -0.4781583, 34.2900253>,
    <-1.9188706, -0.5231653, 34.2908029>,
    <-1.9628545, -0.3549248, 34.2926777>,
    <-1.9457219, -0.4180677, 34.2908029>,
    <-1.9436207, -0.4918863, 34.2989756>,
    <-1.9731468, -0.4183775, 34.3035582>,
    <-1.9434916, -0.4837647, 34.2980080>,
    <-1.9813467, -0.3845941, 34.3035582>,
    <-1.9556377, -0.4624258, 34.3008727>,
    <-1.9633221, -0.4311196, 34.3007914>,
    <-1.9649469, -0.4521610, 34.3035582>,
    <-1.9316903, -0.5290995, 34.2980080>,
    <-1.9473212, -0.4944142, 34.3007914>,
    <-1.9200489, -0.5486489, 34.2951914>,
    <-1.9782662, 0.2411255, 34.2933120>,
    <-1.9852604, 0.2241293, 34.2967794>,
    <-1.9763312, 0.2810724, 34.2949171>,
    <-1.9859485, 0.3003945, 34.3007507>,
    <-1.9817653, 0.2324437, 34.2949171>,
    <-1.9815447, 0.2893400, 34.2980246>,
    <-1.9838701, 0.0119872, 34.2867877>,
    <-1.9733635, 0.1755400, 34.2854038>,
    <-1.9851424, 0.1389092, 34.2926777>,
    <-1.9787652, 0.1049134, 34.2856693>,
    <-1.9762859, 0.2104725, 34.2900253>,
    <-1.9810889, 0.1643076, 34.2908029>,
    <-1.9658938, 0.2503564, 34.2856693>,
    <-1.9705005, 0.2721782, 34.2908029>,
    <-1.9677102, 0.1157109, 34.2753407>,
    <-1.9638038, 0.1406766, 34.2729301>,
    <-1.9705706, 0.1415325, 34.2800513>,
    <-1.9643525, 0.2033064, 34.2795037>,
    <-1.9663396, 0.0014058, 34.2695801>,
    <-1.9735069, 0.0034265, 34.2772285>,
    <-1.9681161, 0.0655566, 34.2729301>,
    <-1.9740436, 0.0742429, 34.2795037>,
    <-1.9595117, 0.0007192, 34.2614925>,
    <-1.9621746, 0.0721152, 34.2665723>,
    <-1.9575588, -0.1130030, 34.2635082>,
    <-1.9582201, -0.1697746, 34.2695801>,
    <-1.9623730, -0.0630071, 34.2662252>,
    <-1.9705591, -0.0932181, 34.2772285>,
    <-1.9581991, -0.1377734, 34.2662252>,
    <-1.9676959, -0.0689279, 34.2725930>,
    <-1.9436190, -0.2442979, 34.2614925>,
    <-1.9514760, -0.1378274, 34.2579678>,
    <-1.9466051, -0.1980631, 34.2587527>,
    <-1.9558618, -0.0704141, 34.2587527>,
    <-1.9578949, -0.2277332, 34.2753407>,
    <-1.9737805, -0.1697801, 34.2854038>,
    <-1.9583669, -0.2024793, 34.2729301>,
    <-1.9791889, -0.0948945, 34.2856693>,
    <-1.9651779, -0.2027967, 34.2800513>,
    <-1.9696913, -0.1409194, 34.2795037>,
    <-1.9672504, -0.2401446, 34.2856693>,
    <-1.9496395, -0.2771843, 34.2729301>,
    <-1.9571043, -0.2696150, 34.2795037>,
    <-1.9448874, -0.2697085, 34.2665723>,
    <-1.9898000, 0.1998246, 34.2989756>,
    <-1.9902730, 0.2770343, 34.3035582>,
    <-1.9880430, 0.2083529, 34.2980080>,
    <-1.9887768, 0.3142257, 34.3035582>,
    <-1.9900802, 0.2308236, 34.3008727>,
    <-1.9882092, 0.2644720, 34.3007914>,
    <-1.9954366, 0.1960345, 34.3035582>,
    <-1.9934685, 0.1205510, 34.2975521>,
    <-1.9923895, 0.2379524, 34.3035582>,
    <-1.9948042, 0.1592060, 34.3007100>,
    <-1.9911922, 0.1603033, 34.2980080>,
    <-1.9921737, 0.1955229, 34.3007914>,
    <-1.9907262, 0.0782429, 34.2937748>,
    <-1.9886793, 0.1395033, 34.2951914>,
    <-1.9890564, -0.2772397, 34.2989756>,
    <-1.9922304, -0.2239635, 34.2975521>,
    <-2.0038854, -0.2436026, 34.3035582>,
    <-1.9900459, -0.2558688, 34.2980080>,
    <-2.0046021, -0.1822441, 34.3007100>,
    <-2.0110548, -0.1899985, 34.3035582>,
    <-1.9955911, -0.2626786, 34.3008727>,
    <-2.0009614, -0.2205423, 34.3007914>,
    <-1.9967160, -0.2972067, 34.3035582>,
    <-1.9814365, -0.3128130, 34.2980080>,
    <-1.9883383, -0.3089810, 34.3007914>,
    <-1.9786132, -0.2671745, 34.2937748>,
    <-1.9774864, -0.3007607, 34.2951914>,
    <-1.9786947, 0.1158931, 34.2481381>,
    <-1.9838188, 0.1742733, 34.2582019>,
    <-1.9812516, 0.1413484, 34.2526827>,
    <-1.9758323, 0.2499045, 34.2582019>,
    <-1.9749322, 0.1409367, 34.2458152>,
    <-1.9750153, 0.2024873, 34.2520259>,
    <-1.9776270, 0.0006705, 34.2427102>,
    <-1.9714979, 0.0006539, 34.2353389>,
    <-1.9792052, 0.0654144, 34.2458152>,
    <-1.9737777, 0.0724657, 34.2399571>,
    <-1.9924800, 0.0006800, 34.2582471>,
    <-1.9839085, 0.0006853, 34.2497196>,
    <-1.9891343, 0.0984063, 34.2582019>,
    <-1.9845111, 0.0728068, 34.2520259>,
    <-1.9693472, -0.1139581, 34.2371711>,
    <-1.9694560, -0.1715144, 34.2427102>,
    <-1.9697369, -0.1391163, 34.2396408>,
    <-1.9809518, -0.0965052, 34.2497196>,
    <-1.9739387, -0.0639013, 34.2396408>,
    <-1.9785585, -0.0711933, 34.2454279>,
    <-1.9636846, -0.1387591, 34.2321345>,
    <-1.9680388, -0.0709193, 34.2328481>,
    <-1.9554980, -0.2458717, 34.2353389>,
    <-1.9587194, -0.1993710, 34.2328481>,
    <-1.9687585, -0.2294643, 34.2481381>,
    <-1.9839423, -0.1728608, 34.2582019>,
    <-1.9756969, -0.2048398, 34.2526827>,
    <-1.9892105, -0.0969918, 34.2582019>,
    <-1.9694020, -0.2041478, 34.2458152>,
    <-1.9801719, -0.1435468, 34.2520259>,
    <-1.9604957, -0.2792647, 34.2458152>,
    <-1.9563751, -0.2713781, 34.2399571>,
    <-1.9760030, -0.2484982, 34.2582019>,
    <-1.9670047, -0.2729061, 34.2520259>,
    <-1.9602261, 0.5287726, 34.2863579>,
    <-1.9758141, 0.4849700, 34.2882666>,
    <-1.9671196, 0.5095573, 34.2872643>,
    <-1.9703171, 0.5243982, 34.2903405>,
    <-1.9547667, 0.5559616, 34.2872641>,
    <-1.9631287, 0.5388661, 34.2889215>,
    <-1.9578538, 0.5043650, 34.2817250>,
    <-1.9382583, 0.5777565, 34.2819690>,
    <-1.9586744, 0.5202112, 34.2845089>,
    <-1.9445687, 0.5752974, 34.2850029>,
    <-1.9980472, 0.3420822, 34.2830970>,
    <-1.9758363, 0.4338660, 34.2819691>,
    <-1.9840574, 0.4328831, 34.2861106>,
    <-1.9725106, 0.4698038, 34.2850030>,
    <-1.9589149, 0.4610964, 34.2751874>,
    <-1.9583424, 0.4824319, 34.2783022>,
    <-1.9502754, 0.4875003, 34.2735942>,
    <-1.9415592, 0.5442221, 34.2779937>,
    <-1.9773514, 0.3483527, 34.2713545>,
    <-1.9702280, 0.3481448, 34.2658251>,
    <-1.9677911, 0.4126906, 34.2735942>,
    <-1.9602109, 0.4203972, 34.2692880>,
    <-1.9854250, 0.3466037, 34.2765463>,
    <-1.9736314, 0.4160042, 34.2779937>,
    <-1.9885377, 0.2330391, 34.2672347>,
    <-1.9994842, 0.1747836, 34.2713545>,
    <-1.9936942, 0.2077344, 34.2690979>,
    <-1.9993864, 0.2488842, 34.2765463>,
    <-1.9846353, 0.2836539, 34.2690979>,
    <-1.9917220, 0.2758952, 34.2734379>,
    <-1.9867364, 0.2074114, 34.2634197>,
    <-1.9791889, 0.2759752, 34.2639559>,
    <-1.9976891, 0.0989534, 34.2658251>,
    <-1.9925135, 0.1459768, 34.2639559>,
    <-1.9483078, -0.4611982, 34.2672347>,
    <-1.9386449, -0.5198347, 34.2713545>,
    <-1.9940193, -0.3651388, 34.2830967>,
    <-1.9772110, -0.3491632, 34.2713545>,
    <-1.9444856, -0.4868196, 34.2690979>,
    <-1.9637913, -0.4508104, 34.2765462>,
    <-1.9840940, -0.3542090, 34.2765462>,
    <-1.9619390, -0.4123802, 34.2690979>,
    <-1.9658744, -0.4225221, 34.2734378>,
    <-1.9704813, -0.3467085, 34.2658251>,
    <-1.9378604, -0.4846009, 34.2634197>,
    <-1.9542182, -0.4175906, 34.2639559>,
    <-1.9110578, -0.5902641, 34.2658251>,
    <-1.9222772, -0.5443064, 34.2639559>,
    <-1.9614273, -0.5242958, 34.2863567>,
    <-1.9797876, -0.4706787, 34.2882644>,
    <-1.9574800, -0.5454909, 34.2872628>,
    <-1.9763874, -0.5017447, 34.2903378>,
    <-1.9701196, -0.4987198, 34.2872627>,
    <-1.9681818, -0.5200087, 34.2889195>,
    <-1.9475839, -0.5427117, 34.2817246>,
    <-1.9848236, -0.4321735, 34.2861091>,
    <-1.9672439, -0.4699104, 34.2819686>,
    <-1.9561249, -0.5297390, 34.2845081>,
    <-1.9713026, -0.4757455, 34.2850020>,
    <-1.9276739, -0.6133571, 34.2819686>,
    <-1.9425680, -0.5813822, 34.2850021>,
    <-1.9269866, -0.5802600, 34.2751874>,
    <-1.9371190, -0.5616514, 34.2783020>,
    <-1.9327147, -0.5530925, 34.2735942>,
    <-1.9534568, -0.5000392, 34.2779935>,
    <-1.9104546, -0.6266312, 34.2735942>,
    <-1.9077911, -0.6160308, 34.2692880>,
    <-1.9170258, -0.6270900, 34.2779935>,
    <-1.9893402, 0.4450620, 34.2894179>,
    <-2.0005922, 0.3957062, 34.2886794>,
    <-2.0023792, 0.4174701, 34.2918022>,
    <-1.9867426, 0.4758262, 34.2918021>,
    <-1.9949597, 0.4193352, 34.2889155>,
    <-2.0016065, 0.4074408, 34.2903196>,
    <-1.9951973, 0.4442730, 34.2918022>,
    <-1.9886773, 0.4564310, 34.2904043>,
    <-1.9957877, 0.4295259, 34.2903620>,
    <-1.9773761, 0.5107824, 34.2918019>,
    <-1.9841525, 0.4596680, 34.2889155>,
    <-1.9800134, 0.4883959, 34.2903618>,
    <-1.9990946, 0.3805613, 34.2867239>,
    <-1.9912950, 0.4182573, 34.2874565>,
    <-1.9934814, -0.4297667, 34.2894147>,
    <-1.9926549, -0.4537624, 34.2917976>,
    <-1.9883688, -0.4442913, 34.2889127>,
    <-1.9841157, -0.4856310, 34.2917981>,
    <-1.9936136, -0.4380091, 34.2904005>,
    <-1.9856592, -0.4673265, 34.2903585>,
    <-2.0057983, -0.4047106, 34.2917974>,
    <-2.0025689, -0.3888196, 34.2886767>,
    <-1.9999010, -0.4267194, 34.2917973>,
    <-2.0044685, -0.3967601, 34.2903158>,
    <-1.9980471, -0.4081716, 34.2889125>,
    <-1.9997159, -0.4148661, 34.2903580>,
    <-1.9995293, -0.3808993, 34.2867223>,
    <-1.9934107, -0.4117948, 34.2874544>,
    <-1.9995798, 0.0686037, 34.2989756>,
    <-2.0049427, 0.1018004, 34.3035582>,
    <-1.9966934, 0.0891912, 34.2980080>,
    <-1.9997244, 0.1503354, 34.3035582>,
    <-2.0019994, 0.0830467, 34.3008727>,
    <-1.9982861, 0.1225088, 34.3007914>,
    <-1.9987197, -0.0143129, 34.2967794>,
    <-2.0107814, 0.0513748, 34.3035582>,
    <-2.0080047, -0.0073360, 34.3007507>,
    <-1.9999621, 0.0335792, 34.2980080>,
    <-2.0053239, 0.0384349, 34.3007914>,
    <-1.9918628, -0.0097941, 34.2926777>,
    <-1.9947917, 0.0448916, 34.2951914>,
    <-1.9898932, -0.1059796, 34.2933120>,
    <-1.9958404, -0.1231689, 34.2967794>,
    <-1.9943440, -0.0664985, 34.2949171>,
    <-2.0086215, -0.0484535, 34.3007507>,
    <-1.9924228, -0.1148928, 34.2949171>,
    <-2.0013106, -0.0590314, 34.2980246>,
    <-1.9809728, -0.2071770, 34.2926777>,
    <-1.9826292, -0.1358676, 34.2900253>,
    <-1.9800463, -0.1819172, 34.2908029>,
    <-1.9871883, -0.0742702, 34.2908029>,
    <-2.0006846, -0.1461219, 34.2989756>,
    <-2.0175772, -0.0681953, 34.3035582>,
    <-1.9981866, -0.1383905, 34.2980080>,
    <-2.0172537, -0.0340957, 34.3035582>,
    <-2.0076533, -0.1148428, 34.3008727>,
    <-2.0080624, -0.0830697, 34.3007914>,
    <-2.0179007, -0.1022949, 34.3035582>,
    <-1.9961180, -0.1847737, 34.2980080>,
    <-2.0066663, -0.1474559, 34.3007914>,
    <-1.9869417, -0.2064049, 34.2951914>,
    <-2.0085250, 0.3712188, 34.2894179>,
    <-2.0122497, 0.3806326, 34.2918022>,
    <-2.0102124, 0.3752193, 34.2904043>,
    <-2.0079271, 0.3967648, 34.2918022>,
    <-2.0053325, 0.3797817, 34.2889155>,
    <-2.0063958, 0.3899357, 34.2903620>,
    <-2.0119821, 0.3403188, 34.2886794>,
    <-2.0072916, 0.3382930, 34.2867239>,
    <-2.0098148, 0.3588448, 34.2889155>,
    <-2.0052049, 0.3629779, 34.2874565>,
    <-2.0157087, 0.3441487, 34.2903196>,
    <-2.0157554, 0.3675493, 34.2918022>,
    <-2.0131130, 0.3615000, 34.2903620>,
    <-2.0096668, -0.3666118, 34.2894157>,
    <-2.0137296, -0.3751103, 34.2917992>,
    <-2.0066894, -0.3748866, 34.2889131>,
    <-2.0102907, -0.3879444, 34.2917981>,
    <-2.0114946, -0.3702449, 34.2904018>,
    <-2.0083740, -0.3825536, 34.2903587>,
    <-2.0124274, -0.3363516, 34.2886787>,
    <-2.0164660, -0.3648976, 34.2918006>,
    <-2.0163014, -0.3395360, 34.2903190>,
    <-2.0105001, -0.3555083, 34.2889140>,
    <-2.0138927, -0.3578322, 34.2903605>,
    <-2.0068565, -0.3396660, 34.2867232>,
    <-2.0054691, -0.3626672, 34.2874551>,
    <-2.0092231, 0.1139293, 34.2751874>,
    <-2.0156917, 0.1567247, 34.2817251>,
    <-2.0123642, 0.1350401, 34.2783022>,
    <-2.0091382, 0.2324040, 34.2819691>,
    <-2.0052998, 0.1414323, 34.2735942>,
    <-2.0065657, 0.1988059, 34.2779937>,
    <-2.0078018, -0.0003031, 34.2713545>,
    <-2.0007505, 0.0007292, 34.2658251>,
    <-2.0095589, 0.0647175, 34.2735942>,
    <-2.0034321, 0.0736234, 34.2692880>,
    <-2.0270943, -0.0100725, 34.2830970>,
    <-2.0154491, -0.0034275, 34.2765463>,
    <-2.0211590, 0.0841741, 34.2819691>,
    <-2.0158859, 0.0669666, 34.2779937>,
    <-1.9987941, -0.1158073, 34.2672347>,
    <-1.9994584, -0.1750785, 34.2713545>,
    <-1.9994782, -0.1416230, 34.2690979>,
    <-2.0122295, -0.1020869, 34.2765463>,
    <-2.0037402, -0.0652837, 34.2690979>,
    <-2.0093720, -0.0741552, 34.2734379>,
    <-1.9925700, -0.1407328, 34.2634197>,
    <-1.9970431, -0.0719000, 34.2639559>,
    <-1.9845228, -0.2494450, 34.2658251>,
    <-1.9875913, -0.2022373, 34.2639559>,
    <-1.9984717, -0.2367627, 34.2751874>,
    <-2.0122404, -0.1959842, 34.2817250>,
    <-2.0052179, -0.2165972, 34.2783022>,
    <-2.0189714, -0.1200101, 34.2819691>,
    <-1.9993943, -0.2089330, 34.2735942>,
    <-2.0106038, -0.1526510, 34.2779937>,
    <-1.9902438, -0.2853643, 34.2735942>,
    <-1.9857800, -0.2753875, 34.2692880>,
    <-2.0048964, -0.2693024, 34.2819690>,
    <-1.9967949, -0.2846753, 34.2779936>,
    <-2.0188540, 0.2918331, 34.2894179>,
    <-2.0208436, 0.2404543, 34.2882666>,
    <-2.0326919, 0.1978258, 34.2918022>,
    <-2.0258363, 0.2761777, 34.2918022>,
    <-2.0195018, 0.2720542, 34.2889155>,
    <-2.0280408, 0.2131898, 34.2903408>,
    <-2.0292881, 0.2367279, 34.2918022>,
    <-2.0216710, 0.2868894, 34.2904043>,
    <-2.0247424, 0.2514353, 34.2903620>,
    <-2.0223525, 0.3159927, 34.2918022>,
    <-2.0153047, 0.3162978, 34.2889155>,
    <-2.0186105, 0.3185362, 34.2903620>,
    <-2.0123859, 0.2773017, 34.2861106>,
    <-2.0128710, 0.3044959, 34.2874565>,
    <-2.0222662, 0.1803496, 34.2863581>,
    <-2.0300112, 0.1345054, 34.2882666>,
    <-2.0257182, 0.1602291, 34.2872643>,
    <-2.0314443, 0.1742891, 34.2903408>,
    <-2.0216111, 0.2080735, 34.2872643>,
    <-2.0268775, 0.1897856, 34.2889218>,
    <-2.0192514, 0.1721878, 34.2845089>,
    <-2.0149257, 0.2288864, 34.2850030>,
    <-2.0290845, 0.0817783, 34.2861106>,
    <-2.0241243, 0.1201434, 34.2850030>,
    <-2.0227490, -0.1747760, 34.2863580>,
    <-2.0219434, -0.2263858, 34.2882666>,
    <-2.0355106, -0.1656089, 34.2918022>,
    <-2.0318400, -0.1147679, 34.2882666>,
    <-2.0225148, -0.1967188, 34.2872643>,
    <-2.0302382, -0.1880735, 34.2903408>,
    <-2.0339570, -0.1455704, 34.2903408>,
    <-2.0269648, -0.1468823, 34.2872643>,
    <-2.0287798, -0.1680433, 34.2889218>,
    <-2.0299664, -0.0763592, 34.2861106>,
    <-2.0184185, -0.1815825, 34.2845089>,
    <-2.0240603, -0.1244792, 34.2850030>,
    <-2.0118629, -0.2772922, 34.2861104>,
    <-2.0140117, -0.2352277, 34.2850030>,
    <-2.0199417, -0.2793978, 34.2894177>,
    <-2.0273782, -0.2585497, 34.2918022>,
    <-2.0229810, -0.2720833, 34.2904043>,
    <-2.0315183, -0.2112346, 34.2918022>,
    <-2.0206322, -0.2582768, 34.2889154>,
    <-2.0265140, -0.2311846, 34.2903620>,
    <-2.0159964, -0.3083887, 34.2889152>,
    <-2.0129953, -0.2996532, 34.2874563>,
    <-2.0231394, -0.3069910, 34.2918022>,
    <-2.0194538, -0.3095768, 34.2903618>,
    <-2.0364019, 0.0928544, 34.2894179>,
    <-2.0389126, 0.0422933, 34.2886794>,
    <-2.0444517, 0.0634154, 34.2918022>,
    <-2.0391859, 0.1236021, 34.2918022>,
    <-2.0374686, 0.0665422, 34.2889155>,
    <-2.0419492, 0.0536730, 34.2903196>,
    <-2.0420331, 0.0910594, 34.2918022>,
    <-2.0377233, 0.1041658, 34.2904043>,
    <-2.0400537, 0.0764341, 34.2903620>,
    <-2.0360317, 0.1596541, 34.2918022>,
    <-2.0338293, 0.1081397, 34.2889155>,
    <-2.0347416, 0.1371499, 34.2903620>,
    <-2.0348078, 0.0276391, 34.2867239>,
    <-2.0336724, 0.0661175, 34.2874565>,
    <-2.0388454, -0.0633401, 34.2894179>,
    <-2.0429526, -0.0805519, 34.2918022>,
    <-2.0360305, -0.0831368, 34.2889155>,
    <-2.0393055, -0.1222357, 34.2918022>,
    <-2.0407431, -0.0689058, 34.2904043>,
    <-2.0375133, -0.1054710, 34.2903620>,
    <-2.0405118, -0.0142331, 34.2886794>,
    <-2.0465010, -0.0399944, 34.2918022>,
    <-2.0448471, -0.0111113, 34.2903196>,
    <-2.0396128, -0.0384656, 34.2889155>,
    <-2.0432573, -0.0368375, 34.2903620>,
    <-2.0355406, -0.0154115, 34.2867239>,
    <-2.0351665, -0.0496638, 34.2874565>,
    <-2.0424729, 0.0167980, 34.2894179>,
    <-2.0477760, 0.0254196, 34.2918022>,
    <-2.0448295, 0.0204436, 34.2904043>,
    <-2.0463202, 0.0420595, 34.2918022>,
    <-2.0408157, 0.0257863, 34.2889155>,
    <-2.0436262, 0.0356007, 34.2903620>,
    <-2.0415944, 0.0043878, 34.2889155>,
    <-2.0377721, 0.0092604, 34.2874565>,
    <-2.0489568, 0.0119238, 34.2918022>,
    <-2.0453038, 0.0064277, 34.2903620>
  }
  normal_vectors {
    21503,
    <0.3416183, 0.0147852, 0.9397225>,
    <0.3466933, 0.0138200, 0.9378767>,
    <0.3405267, -0.0021576, 0.9402324>,
    <0.3423084, -0.0094622, 0.9395400>,
    <0.3349948, -0.0293084, 0.9417640>,
    <0.2741229, -0.0239828, 0.9613956>,
    <0.2741229, -0.0239828, 0.9613956>,
    <0.3529206, 0.0286748, 0.9352138>,
    <0.3556484, 0.0286512, 0.9341805>,
    <0.3613360, 0.0272391, 0.9320377>,
    <0.3675894, 0.0021411, 0.9299857>,
    <0.3475443, -0.0146075, 0.9375498>,
    <0.3797487, 0.0241587, 0.9247742>,
    <0.2808393, -0.0013043, 0.9597539>,
    <0.3752891, -0.0215471, 0.9266573>,
    <0.3585454, -0.0273398, 0.9331118>,
    <0.3564061, -0.0258603, 0.9339732>,
    <0.3635294, -0.0313067, 0.9310565>,
    <0.3671647, -0.0321229, 0.9296011>,
    <0.3630869, -0.0317661, 0.9312136>,
    <0.3630869, -0.0317661, 0.9312136>,
    <0.3349948, -0.0293084, 0.9417640>,
    <0.3589680, -0.0321416, 0.9327963>,
    <0.3634254, -0.0322297, 0.9310656>,
    <0.3620113, -0.0324794, 0.9316077>,
    <0.3590680, -0.0326447, 0.9327403>,
    <0.3532760, -0.0329329, 0.9349393>,
    <0.3517534, -0.0323002, 0.9355353>,
    <0.3503046, -0.0306477, 0.9361343>,
    <0.3614987, -0.0316271, 0.9318360>,
    <0.3614987, -0.0316271, 0.9318360>,
    <0.3652988, -0.0319596, 0.9303415>,
    <0.3657215, -0.0320668, 0.9301718>,
    <0.3626044, -0.0315475, 0.9314090>,
    <0.3652988, -0.0319596, 0.9303415>,
    <0.3669390, -0.0321031, 0.9296909>,
    <0.3669390, -0.0321031, 0.9296909>,
    <0.3671647, -0.0321229, 0.9296011>,
    <0.3626679, -0.0316010, 0.9313825>,
    <0.2808393, -0.0013043, 0.9597539>,
    <0.3555035, -0.0331863, 0.9340856>,
    <0.3671441, 0.0320504, 0.9296117>,
    <0.3678102, 0.0318953, 0.9293537>,
    <0.3673401, 0.0317070, 0.9295461>,
    <0.3665380, 0.0318521, 0.9298577>,
    <0.3659099, 0.0320135, 0.9300995>,
    <0.3670242, 0.0321118, 0.9296569>,
    <0.3670242, 0.0321118, 0.9296569>,
    <0.3671821, 0.0321276, 0.9295941>,
    <0.3671818, 0.0321065, 0.9295949>,
    <0.3675536, 0.0320581, 0.9294496>,
    <0.3715191, 0.0309375, 0.9279097>,
    <0.3664026, 0.0308487, 0.9299449>,
    <0.3697357, 0.0318871, 0.9285896>,
    <0.2808393, -0.0013043, 0.9597539>,
    <0.3638576, 0.0312745, 0.9309294>,
    <0.3529206, 0.0286748, 0.9352138>,
    <0.3627109, 0.0317332, 0.9313613>,
    <0.3627109, 0.0317332, 0.9313613>,
    <0.3659099, 0.0320135, 0.9300995>,
    <0.3296048, 0.0707882, 0.9414615>,
    <0.3328311, 0.0693700, 0.9404314>,
    <0.3320007, 0.0524563, 0.9418194>,
    <0.3367878, 0.0464359, 0.9404348>,
    <0.3355152, 0.0293732, 0.9415768>,
    <0.2733339, 0.0239650, 0.9616206>,
    <0.2733339, 0.0239650, 0.9616206>,
    <0.3424264, 0.0894946, 0.9352726>,
    <0.3438882, 0.0895313, 0.9347326>,
    <0.3472128, 0.0878166, 0.9336657>,
    <0.3591172, 0.0607598, 0.9313125>,
    <0.3444084, 0.0430398, 0.9378328>,
    <0.3697975, 0.0874939, 0.9249836>,
    <0.2973842, 0.0532904, 0.9532695>,
    <0.3734519, 0.0411562, 0.9267361>,
    <0.3600384, 0.0352281, 0.9322721>,
    <0.3557836, 0.0350961, 0.9339092>,
    <0.3642170, 0.0325213, 0.9307461>,
    <0.3671821, 0.0321276, 0.9295941>,
    <0.3633108, 0.0317937, 0.9311254>,
    <0.3633108, 0.0317937, 0.9311254>,
    <0.3355152, 0.0293732, 0.9415768>,
    <0.3668605, 0.0322036, 0.9297184>,
    <0.3659105, 0.0327136, 0.9300749>,
    <0.3671933, 0.0321231, 0.9295898>,
    <0.3672999, 0.0321102, 0.9295481>,
    <0.3671821, 0.0321276, 0.9295941>,
    <0.3677383, 0.0331461, 0.9293384>,
    <0.3671948, 0.0321227, 0.9295892>,
    <0.2973842, 0.0532904, 0.9532695>,
    <0.3714855, 0.0324976, 0.9278698>,
    <0.3714855, 0.0324976, 0.9278698>,
    <0.3671968, 0.0321224, 0.9295884>,
    <0.3674640, 0.0321138, 0.9294832>,
    <0.3671968, 0.0321224, 0.9295884>,
    <0.3673518, 0.0321359, 0.9295267>,
    <0.3673518, 0.0321359, 0.9295267>,
    <0.2808393, -0.0013043, 0.9597539>,
    <0.3470276, -0.0326212, 0.9372874>,
    <0.3481939, -0.0330406, 0.9368401>,
    <0.3456404, -0.0330017, 0.9377865>,
    <0.3442630, -0.0328669, 0.9382978>,
    <0.3418404, -0.0323635, 0.9392006>,
    <0.3447059, -0.0319062, 0.9381683>,
    <0.3503046, -0.0306477, 0.9361343>,
    <0.3480712, -0.0333981, 0.9368730>,
    <0.3446633, -0.0331567, 0.9381406>,
    <0.2808393, -0.0013043, 0.9597539>,
    <0.3468961, -0.0336218, 0.9373007>,
    <0.3468961, -0.0336218, 0.9373007>,
    <0.3438856, -0.0333300, 0.9384198>,
    <0.3423949, -0.0330293, 0.9389754>,
    <0.3438856, -0.0333300, 0.9384198>,
    <0.3419070, -0.0331382, 0.9391493>,
    <0.3419070, -0.0331382, 0.9391493>,
    <0.2475075, -0.0443526, 0.9678703>,
    <0.3403691, -0.0330311, 0.9397116>,
    <0.3322769, -0.0308240, 0.9426781>,
    <0.3363831, -0.0305172, 0.9412306>,
    <0.3369671, -0.0314737, 0.9409902>,
    <0.3340482, -0.0328388, 0.9419838>,
    <0.3277252, -0.0394835, 0.9439477>,
    <0.3246725, -0.0352742, 0.9451685>,
    <0.3226523, -0.0344546, 0.9458903>,
    <0.3312594, -0.0289813, 0.9430945>,
    <0.3312594, -0.0289813, 0.9430945>,
    <0.3353469, -0.0293390, 0.9416378>,
    <0.3401641, -0.0308296, 0.9398606>,
    <0.3389471, -0.0316940, 0.9402714>,
    <0.3353469, -0.0293390, 0.9416378>,
    <0.3396141, -0.0297124, 0.9400955>,
    <0.3396141, -0.0297124, 0.9400955>,
    <0.3503046, -0.0306477, 0.9361343>,
    <0.3376072, -0.0338925, 0.9406767>,
    <0.2475075, -0.0443526, 0.9678703>,
    <0.3363789, -0.0464954, 0.9405782>,
    <0.3157521, -0.0572788, 0.9471113>,
    <0.3178661, -0.0585699, 0.9463248>,
    <0.3166624, -0.0727985, 0.9457406>,
    <0.3176822, -0.0771830, 0.9450507>,
    <0.3163084, -0.0847333, 0.9448647>,
    <0.2971890, -0.0795855, 0.9514961>,
    <0.2971890, -0.0795855, 0.9514961>,
    <0.3226523, -0.0344546, 0.9458903>,
    <0.3263305, -0.0706488, 0.9426119>,
    <0.3196832, -0.0799602, 0.9441446>,
    <0.2475075, -0.0443526, 0.9678703>,
    <0.3284245, -0.0836150, 0.9408219>,
    <0.3232441, -0.0852346, 0.9424693>,
    <0.3220944, -0.0846636, 0.9429143>,
    <0.3239122, -0.0866266, 0.9421129>,
    <0.3246469, -0.0869848, 0.9418270>,
    <0.3236477, -0.0867115, 0.9421960>,
    <0.3236477, -0.0867115, 0.9421960>,
    <0.3163084, -0.0847333, 0.9448647>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.3274511, -0.0874557, 0.9408120>,
    <0.3259114, -0.0871619, 0.9413738>,
    <0.3264128, -0.0871514, 0.9412010>,
    <0.3274487, -0.0872620, 0.9408308>,
    <0.3295538, -0.0874996, 0.9400735>,
    <0.3300765, -0.0878357, 0.9398587>,
    <0.3305099, -0.0885658, 0.9396378>,
    <0.3265305, -0.0874963, 0.9411282>,
    <0.3265305, -0.0874963, 0.9411282>,
    <0.3252572, -0.0871530, 0.9416008>,
    <0.3249280, -0.0869720, 0.9417312>,
    <0.3254005, -0.0867392, 0.9415895>,
    <0.3252572, -0.0871530, 0.9416008>,
    <0.3247186, -0.0870068, 0.9418002>,
    <0.3247186, -0.0870068, 0.9418002>,
    <0.3246469, -0.0869848, 0.9418270>,
    <0.3270717, -0.0866848, 0.9410153>,
    <0.2475075, -0.0443526, 0.9678703>,
    <0.3292950, -0.0871716, 0.9401946>,
    <0.3510976, 0.0943741, 0.9315707>,
    <0.3516277, 0.0945558, 0.9313523>,
    <0.3533560, 0.0946146, 0.9306920>,
    <0.3534538, 0.0946776, 0.9306485>,
    <0.3537775, 0.0948000, 0.9305130>,
    <0.3526130, 0.0944881, 0.9309866>,
    <0.3526130, 0.0944881, 0.9309866>,
    <0.3461313, 0.0927518, 0.9335900>,
    <0.3460377, 0.0935576, 0.9335443>,
    <0.3469716, 0.0939935, 0.9331538>,
    <0.3570348, 0.0944125, 0.9293075>,
    <0.3532245, 0.0935113, 0.9308534>,
    <0.3501041, 0.0946184, 0.9319198>,
    <0.2973842, 0.0532904, 0.9532695>,
    <0.3522918, 0.0938702, 0.9311707>,
    <0.3424264, 0.0894946, 0.9352726>,
    <0.3515898, 0.0942138, 0.9314013>,
    <0.3515898, 0.0942138, 0.9314013>,
    <0.3537775, 0.0948000, 0.9305130>,
    <0.2969344, 0.1208557, 0.9472190>,
    <0.3003740, 0.1203953, 0.9461926>,
    <0.3028887, 0.1048807, 0.9472373>,
    <0.3082224, 0.0997725, 0.9460679>,
    <0.3097394, 0.0830038, 0.9471916>,
    <0.2538711, 0.0680399, 0.9648420>,
    <0.2538711, 0.0680399, 0.9648420>,
    <0.3047234, 0.1397908, 0.9421264>,
    <0.3061728, 0.1401162, 0.9416080>,
    <0.3097228, 0.1392024, 0.9405820>,
    <0.3248161, 0.1166138, 0.9385605>,
    <0.3158504, 0.0983586, 0.9436970>,
    <0.3295463, 0.1422055, 0.9333686>,
    <0.2735233, 0.1009981, 0.9565482>,
    <0.3407398, 0.1013006, 0.9346842>,
    <0.3316404, 0.0940980, 0.9387013>,
    <0.3284806, 0.0926693, 0.9399537>,
    <0.3383520, 0.0924835, 0.9364640>,
    <0.3461313, 0.0927518, 0.9335900>,
    <0.3362802, 0.0901131, 0.9374408>,
    <0.3362802, 0.0901131, 0.9374408>,
    <0.3097394, 0.0830038, 0.9471916>,
    <0.3417184, 0.0930630, 0.9351833>,
    <0.3380785, 0.0930440, 0.9365072>,
    <0.3400763, 0.0928458, 0.9358033>,
    <0.3425247, 0.0932881, 0.9348658>,
    <0.3461313, 0.0927518, 0.9335900>,
    <0.3376302, 0.0933737, 0.9366361>,
    <0.3387187, 0.0926389, 0.9363160>,
    <0.2735233, 0.1009981, 0.9565482>,
    <0.3403157, 0.0932388, 0.9356772>,
    <0.3403157, 0.0932388, 0.9356772>,
    <0.3376448, 0.0925071, 0.9367168>,
    <0.3417943, 0.0933285, 0.9351291>,
    <0.3376448, 0.0925071, 0.9367168>,
    <0.3399771, 0.0931461, 0.9358095>,
    <0.3399771, 0.0931461, 0.9358095>,
    <0.2973842, 0.0532904, 0.9532695>,
    <0.3318787, -0.0880136, 0.9392072>,
    <0.3314659, -0.0877718, 0.9393756>,
    <0.3324471, -0.0879488, 0.9390122>,
    <0.3329722, -0.0881236, 0.9388098>,
    <0.3338223, -0.0886059, 0.9384624>,
    <0.3326495, -0.0884491, 0.9388935>,
    <0.3305099, -0.0885658, 0.9396378>,
    <0.3315334, -0.0876397, 0.9393641>,
    <0.3328369, -0.0879495, 0.9388740>,
    <0.2475075, -0.0443526, 0.9678703>,
    <0.3319977, -0.0876254, 0.9392014>,
    <0.3319977, -0.0876254, 0.9392014>,
    <0.3331536, -0.0879305, 0.9387635>,
    <0.3338352, -0.0882238, 0.9384938>,
    <0.3331536, -0.0879305, 0.9387635>,
    <0.3341263, -0.0881872, 0.9383936>,
    <0.3341263, -0.0881872, 0.9383936>,
    <0.2342519, -0.0847678, 0.9684733>,
    <0.3352337, -0.0892616, 0.9378970>,
    <0.3341384, -0.0892578, 0.9382881>,
    <0.3345367, -0.0894401, 0.9381288>,
    <0.3345240, -0.0900394, 0.9380760>,
    <0.3346443, -0.0898930, 0.9380471>,
    <0.3348537, -0.0897386, 0.9379872>,
    <0.3344655, -0.0896301, 0.9381361>,
    <0.3344655, -0.0896301, 0.9381361>,
    <0.3305099, -0.0885658, 0.9396378>,
    <0.3354056, -0.0918272, 0.9375878>,
    <0.3329524, -0.0916943, 0.9384747>,
    <0.2342519, -0.0847678, 0.9684733>,
    <0.3342579, -0.1063337, 0.9364640>,
    <0.3266353, -0.0984571, 0.9400083>,
    <0.3327980, -0.0906661, 0.9386294>,
    <0.3246830, -0.0942853, 0.9411117>,
    <0.3228742, -0.0932014, 0.9418417>,
    <0.3326316, -0.0891468, 0.9388339>,
    <0.3326316, -0.0891468, 0.9388339>,
    <0.3348537, -0.0897386, 0.9379872>,
    <0.3116454, -0.1152013, 0.9431891>,
    <0.3135381, -0.1167307, 0.9423735>,
    <0.3099507, -0.1312575, 0.9416486>,
    <0.3102411, -0.1359429, 0.9408879>,
    <0.3074589, -0.1434134, 0.9406921>,
    <0.2882244, -0.1345066, 0.9480689>,
    <0.2882244, -0.1345066, 0.9480689>,
    <0.3228742, -0.0932014, 0.9418417>,
    <0.3201827, -0.1306254, 0.9383070>,
    <0.3118030, -0.1391519, 0.9399019>,
    <0.2342519, -0.0847678, 0.9684733>,
    <0.3196485, -0.1444860, 0.9364554>,
    <0.3143333, -0.1451650, 0.9381480>,
    <0.3135794, -0.1444363, 0.9385127>,
    <0.3150896, -0.1467669, 0.9376449>,
    <0.3158831, -0.1473031, 0.9372938>,
    <0.3148625, -0.1468392, 0.9377099>,
    <0.3148625, -0.1468392, 0.9377099>,
    <0.3074589, -0.1434134, 0.9406921>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0038041, -0.0002297, -0.9999927>,
    <-0.8572828, -0.0750059, -0.5093528>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0013831, 0.0000541, -0.9999990>,
    <-0.0081779, 0.0001713, -0.9999665>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0064447, 0.0004598, -0.9999791>,
    <-0.0399919, 0.0012233, -0.9991993>,
    <-0.0140036, -0.0002464, -0.9999019>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.1271572, -0.0008463, -0.9918822>,
    <-0.8572828, -0.0750059, -0.5093528>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.8572828, -0.0750059, -0.5093528>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.5477053, -0.0479181, 0.8352980>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.5477053, -0.0479181, 0.8352980>,
    <-0.0415622, 0.0020196, -0.9991339>,
    <-0.2044128, 0.0136941, -0.9787890>,
    <-0.5518593, 0.0311301, -0.8333560>,
    <-0.2044131, 0.0083746, -0.9788489>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0184959, 0.0009210, -0.9998285>,
    <-0.0831167, 0.0069603, -0.9965155>,
    <-0.8840386, 0.0842908, -0.4597509>,
    <-0.8652982, 0.0473879, 0.4990124>,
    <-0.2600466, 0.0306123, -0.9651107>,
    <-0.5627052, 0.1112441, 0.8191383>,
    <-0.4204274, 0.0470233, 0.9061068>,
    <-0.3966157, 0.0226447, 0.9177054>,
    <-0.9680960, 0.0167502, 0.2500191>,
    <-0.3745814, 0.0067121, 0.9271698>,
    <-0.8572828, -0.0750059, -0.5093528>,
    <-0.0093472, 0.0010102, -0.9999558>,
    <-0.0437823, 0.0055690, -0.9990256>,
    <-0.0295779, 0.0033367, -0.9995569>,
    <-0.0071071, 0.0007351, -0.9999745>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0118872, 0.0025790, -0.9999260>,
    <-0.0538517, 0.0111413, -0.9984868>,
    <-0.1139638, 0.0148885, -0.9933733>,
    <-0.0516443, 0.0060098, -0.9986475>,
    <-0.1789700, 0.0342428, -0.9832584>,
    <-0.0117341, 0.0013059, -0.9999303>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.5477053, -0.0479181, 0.8352980>,
    <-0.0049395, -0.0006642, -0.9999876>,
    <-0.0115672, 0.0028801, -0.9999289>,
    <-0.0544482, 0.0135121, -0.9984252>,
    <-0.0327734, 0.0084769, -0.9994269>,
    <-0.0073417, 0.0019304, -0.9999712>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0135994, 0.0036408, -0.9999009>,
    <-0.0597489, 0.0159031, -0.9980868>,
    <-0.1312175, 0.0324849, -0.9908212>,
    <-0.0491393, 0.0128762, -0.9987089>,
    <-0.2049576, 0.0534080, -0.9773126>,
    <-0.0100262, 0.0027614, -0.9999459>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.3158823, -0.1472933, 0.9372956>,
    <0.3158852, -0.1472966, 0.9372941>,
    <0.3158831, -0.1472972, 0.9372947>,
    <0.3158810, -0.1472955, 0.9372957>,
    <0.3158698, -0.1472913, 0.9373002>,
    <0.3158660, -0.1472867, 0.9373022>,
    <0.3158631, -0.1472767, 0.9373047>,
    <0.3158907, -0.1472941, 0.9372926>,
    <0.3158907, -0.1472941, 0.9372926>,
    <0.3158899, -0.1472971, 0.9372925>,
    <0.3158058, -0.1472323, 0.9373309>,
    <0.3156000, -0.1469233, 0.9374488>,
    <0.3158899, -0.1472971, 0.9372925>,
    <0.3158880, -0.1472997, 0.9372927>,
    <0.3158880, -0.1472997, 0.9372927>,
    <0.3158831, -0.1473031, 0.9372938>,
    <0.3163512, -0.1470464, 0.9371762>,
    <0.2342519, -0.0847678, 0.9684733>,
    <0.3161105, -0.1472946, 0.9372185>,
    <-0.0017991, -0.0003437, -0.9999983>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0105695, -0.0019431, -0.9999423>,
    <-0.0463727, -0.0090027, -0.9988836>,
    <-0.0064865, -0.0015655, -0.9999777>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0194457, -0.0030314, -0.9998063>,
    <-0.5477053, -0.0479181, 0.8352980>,
    <-0.2002168, -0.0324221, -0.9792150>,
    <-0.0094547, 0.0027325, -0.9999516>,
    <-0.0074508, 0.0019964, -0.9999702>,
    <-0.0331296, 0.0088769, -0.9994116>,
    <-0.0471843, 0.0133030, -0.9987976>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0138149, 0.0034074, -0.9998988>,
    <-0.0650114, 0.0165182, -0.9977478>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0145503, 0.0046579, -0.9998833>,
    <-0.0847864, 0.0234513, -0.9961231>,
    <-0.1480230, 0.0390493, -0.9882127>,
    <-0.4032903, 0.1039188, -0.9091523>,
    <0.3130069, 0.1461189, 0.9384434>,
    <0.3134951, 0.1463046, 0.9382515>,
    <0.3144296, 0.1464143, 0.9379216>,
    <0.3142577, 0.1464290, 0.9379769>,
    <0.3142570, 0.1465245, 0.9379622>,
    <0.3138815, 0.1463496, 0.9381152>,
    <0.3138815, 0.1463496, 0.9381152>,
    <0.3101563, 0.1446128, 0.9396224>,
    <0.3100049, 0.1451101, 0.9395957>,
    <0.3106314, 0.1455035, 0.9393279>,
    <0.3179028, 0.1467755, 0.9366935>,
    <0.3141950, 0.1452803, 0.9381765>,
    <0.3131513, 0.1463893, 0.9383530>,
    <0.2735233, 0.1009981, 0.9565482>,
    <0.3129453, 0.1453581, 0.9385821>,
    <0.3047234, 0.1397908, 0.9421264>,
    <0.3121419, 0.1455382, 0.9388216>,
    <0.3121419, 0.1455382, 0.9388216>,
    <0.3142570, 0.1465245, 0.9379622>,
    <0.2622487, 0.1647399, 0.9508346>,
    <0.2656284, 0.1647474, 0.9498946>,
    <0.2704237, 0.1502702, 0.9509416>,
    <0.2762570, 0.1463163, 0.9498808>,
    <0.2806665, 0.1308639, 0.9508422>,
    <0.2314544, 0.1079208, 0.9668412>,
    <0.2314544, 0.1079208, 0.9668412>,
    <0.2662481, 0.1839817, 0.9461832>,
    <0.2676866, 0.1845780, 0.9456611>,
    <0.2718375, 0.1844618, 0.9444989>,
    <0.2892330, 0.1648536, 0.9429568>,
    <0.2835445, 0.1459788, 0.9477830>,
    <0.2910037, 0.1905389, 0.9375563>,
    <0.2555724, 0.1466070, 0.9556093>,
    <0.3065131, 0.1525867, 0.9395568>,
    <0.2987927, 0.1441723, 0.9433649>,
    <0.2959145, 0.1424992, 0.9445256>,
    <0.3045509, 0.1434750, 0.9416282>,
    <0.3101563, 0.1446128, 0.9396224>,
    <0.3033818, 0.1414545, 0.9423111>,
    <0.3033818, 0.1414545, 0.9423111>,
    <0.2806665, 0.1308639, 0.9508422>,
    <0.3072952, 0.1443502, 0.9406023>,
    <0.3047212, 0.1440126, 0.9414910>,
    <0.3063943, 0.1440511, 0.9409420>,
    <0.3078946, 0.1445921, 0.9403691>,
    <0.3101563, 0.1446128, 0.9396224>,
    <0.3048277, 0.1444651, 0.9413872>,
    <0.3055717, 0.1437783, 0.9412512>,
    <0.2555724, 0.1466070, 0.9556093>,
    <0.3075572, 0.1448264, 0.9404434>,
    <0.3075572, 0.1448264, 0.9404434>,
    <0.3049156, 0.1435825, 0.9414938>,
    <0.3074784, 0.1445596, 0.9405102>,
    <0.3049156, 0.1435825, 0.9414938>,
    <0.3063357, 0.1442512, 0.9409304>,
    <0.3063357, 0.1442512, 0.9409304>,
    <0.2735233, 0.1009981, 0.9565482>,
    <0.3158480, -0.1472841, 0.9373086>,
    <0.3158589, -0.1472871, 0.9373045>,
    <0.3158544, -0.1472849, 0.9373063>,
    <0.3158376, -0.1473021, 0.9373093>,
    <0.3157511, -0.1473674, 0.9373282>,
    <0.3157768, -0.1472652, 0.9373356>,
    <0.3158631, -0.1472767, 0.9373047>,
    <0.3158620, -0.1472900, 0.9373030>,
    <0.3158549, -0.1472863, 0.9373059>,
    <0.2342519, -0.0847678, 0.9684733>,
    <0.3158616, -0.1472905, 0.9373030>,
    <0.3158616, -0.1472905, 0.9373030>,
    <0.3158540, -0.1472870, 0.9373061>,
    <0.3159085, -0.1473475, 0.9372783>,
    <0.3158540, -0.1472870, 0.9373061>,
    <0.3159746, -0.1473432, 0.9372566>,
    <0.3159746, -0.1473432, 0.9372566>,
    <0.2210589, -0.1268086, 0.9669812>,
    <0.3161842, -0.1480466, 0.9370751>,
    <0.3121780, -0.1472357, 0.9385449>,
    <0.3147889, -0.1472818, 0.9376652>,
    <0.3147633, -0.1477030, 0.9376076>,
    <0.3124729, -0.1487375, 0.9382099>,
    <0.3047033, -0.1538827, 0.9399340>,
    <0.3034035, -0.1492053, 0.9411079>,
    <0.3017749, -0.1477786, 0.9418564>,
    <0.3121369, -0.1455218, 0.9388258>,
    <0.3121369, -0.1455218, 0.9388258>,
    <0.3147713, -0.1467553, 0.9377536>,
    <0.3155670, -0.1472633, 0.9374065>,
    <0.3153955, -0.1475583, 0.9374179>,
    <0.3147713, -0.1467553, 0.9377536>,
    <0.3157067, -0.1471977, 0.9373698>,
    <0.3157067, -0.1471977, 0.9373698>,
    <0.3158631, -0.1472767, 0.9373047>,
    <0.3151003, -0.1498166, 0.9371589>,
    <0.2210589, -0.1268086, 0.9669812>,
    <0.3109024, -0.1632512, 0.9363166>,
    <0.2868883, -0.1674865, 0.9432091>,
    <0.2884840, -0.1693876, 0.9423825>,
    <0.2823840, -0.1830055, 0.9416838>,
    <0.2818684, -0.1876689, 0.9409201>,
    <0.2778475, -0.1945362, 0.9407212>,
    <0.2605356, -0.1823972, 0.9480783>,
    <0.2605356, -0.1823972, 0.9480783>,
    <0.3017749, -0.1477786, 0.9418564>,
    <0.2927869, -0.1842707, 0.9382538>,
    <0.2829399, -0.1911355, 0.9399001>,
    <0.2210589, -0.1268086, 0.9669812>,
    <0.2907218, -0.1979962, 0.9360974>,
    <0.2847994, -0.1976775, 0.9379834>,
    <0.2836756, -0.1966263, 0.9385447>,
    <0.2848429, -0.1992423, 0.9376391>,
    <0.2854151, -0.1998470, 0.9373363>,
    <0.2845073, -0.1992075, 0.9377484>,
    <0.2845073, -0.1992075, 0.9377484>,
    <0.2778475, -0.1945362, 0.9407212>,
    <-0.0113876, -0.0035052, -0.9999290>,
    <-0.0520326, -0.0169788, -0.9985010>,
    <-0.0309433, -0.0100169, -0.9994709>,
    <-0.0069033, -0.0020792, -0.9999740>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0134002, -0.0036188, -0.9999037>,
    <-0.0570309, -0.0161414, -0.9982419>,
    <-0.1235238, -0.0434887, -0.9913882>,
    <-0.0451372, -0.0155847, -0.9988592>,
    <-0.1885482, -0.0575640, -0.9803754>,
    <-0.5247037, -0.1847738, 0.8309902>,
    <-0.1752099, -0.0722061, -0.9818797>,
    <-0.0505130, -0.0207686, -0.9985074>,
    <-0.0084793, -0.0026561, -0.9999605>,
    <-0.0101807, -0.0041650, -0.9999395>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0092456, -0.0020897, -0.9999551>,
    <-0.0074122, -0.0019861, -0.9999706>,
    <-0.0323813, -0.0086767, -0.9994379>,
    <-0.0459786, -0.0113465, -0.9988780>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0125931, -0.0037318, -0.9999137>,
    <-0.0592409, -0.0169283, -0.9981002>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0175542, -0.0036566, -0.9998392>,
    <-0.0875801, -0.0222966, -0.9959079>,
    <-0.1347807, -0.0373947, -0.9901696>,
    <-0.3330529, -0.0937886, -0.9382321>,
    <-0.0411213, -0.0086975, -0.9991163>,
    <-0.2425336, -0.0505700, -0.9688241>,
    <-0.7400441, -0.1674046, -0.6513912>,
    <-0.2238770, -0.0528887, -0.9731813>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.5923234, -0.1092560, 0.7982582>,
    <-0.6167550, -0.1385444, 0.7748669>,
    <-0.5477053, -0.0479181, 0.8352980>,
    <-0.3029093, -0.0543355, 0.9514692>,
    <-0.3250947, -0.0722358, 0.9429186>,
    <-0.9662267, -0.2561793, 0.0278958>,
    <-0.3638463, -0.1000239, 0.9260729>,
    <-0.0077086, 0.0018239, -0.9999686>,
    <-0.0343850, 0.0085732, -0.9993719>,
    <-0.0241451, 0.0064696, -0.9996875>,
    <-0.0057777, 0.0015481, -0.9999821>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0103481, 0.0027843, -0.9999426>,
    <-0.0406478, 0.0112284, -0.9991104>,
    <-0.0939223, 0.0264831, -0.9952272>,
    <-0.0452754, 0.0131679, -0.9988878>,
    <-0.1172833, 0.0343676, -0.9925036>,
    <-0.5781499, 0.2243026, 0.7844941>,
    <-0.2640280, 0.0792777, -0.9612514>,
    <-0.0718700, 0.0194969, -0.9972234>,
    <-0.0099582, 0.0029654, -0.9999460>,
    <-0.0153736, 0.0035281, -0.9998756>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0389952, 0.0108247, -0.9991808>,
    <-0.1701227, 0.0453713, -0.9843778>,
    <-0.3932802, 0.1084055, -0.9130054>,
    <-0.1740609, 0.0497364, -0.9834781>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.9576783, 0.2780867, -0.0742976>,
    <-0.7633561, 0.2109337, 0.6105690>,
    <-0.3791381, 0.1162284, 0.9180116>,
    <-0.3627136, 0.1014491, 0.9263622>,
    <-0.9486776, 0.2510205, 0.1923526>,
    <-0.3655933, 0.0938008, 0.9260361>,
    <-0.0071818, 0.0021123, -0.9999720>,
    <-0.0345227, 0.0112786, -0.9993403>,
    <-0.0234371, 0.0073928, -0.9996980>,
    <-0.0055139, 0.0016358, -0.9999835>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0089300, 0.0036648, -0.9999534>,
    <-0.0410282, 0.0167763, -0.9990171>,
    <-0.0849573, 0.0284869, -0.9959773>,
    <-0.0372648, 0.0120540, -0.9992327>,
    <-0.1359297, 0.0550185, -0.9891896>,
    <-0.0085936, 0.0026973, -0.9999594>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0085303, 0.0037947, -0.9999564>,
    <-0.0389222, 0.0172785, -0.9990928>,
    <-0.0237099, 0.0108063, -0.9996605>,
    <-0.0054147, 0.0024942, -0.9999822>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0099663, 0.0046448, -0.9999395>,
    <-0.0421889, 0.0195879, -0.9989176>,
    <-0.0923886, 0.0413522, -0.9948640>,
    <-0.0354412, 0.0163913, -0.9992373>,
    <-0.1404049, 0.0643151, -0.9880031>,
    <-0.0073703, 0.0035022, -0.9999667>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0116260, -0.0051992, -0.9999189>,
    <-0.0066754, -0.0030726, -0.9999730>,
    <-0.0285743, -0.0130246, -0.9995068>,
    <-0.0528433, -0.0236156, -0.9983235>,
    <-0.0761289, -0.0355610, -0.9964636>,
    <-0.0149711, -0.0075634, -0.9998593>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0088180, -0.0040885, -0.9999528>,
    <-0.0422403, -0.0191644, -0.9989237>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.1181192, -0.0523620, -0.9916179>,
    <-0.3203331, -0.1405379, -0.9368222>,
    <-0.0069189, 0.0033926, -0.9999703>,
    <-0.0054887, 0.0025594, -0.9999817>,
    <-0.0238840, 0.0111373, -0.9996527>,
    <-0.0334317, 0.0161222, -0.9993110>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0105996, 0.0046666, -0.9999329>,
    <-0.0493945, 0.0220904, -0.9985350>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0120905, 0.0062581, -0.9999073>,
    <-0.0716418, 0.0334725, -0.9968686>,
    <-0.1073313, 0.0491606, -0.9930072>,
    <-0.3296092, 0.1473287, -0.9325514>,
    <0.2893989, -0.2021144, 0.9356271>,
    <0.2872273, -0.2008146, 0.9365757>,
    <0.2879885, -0.2010815, 0.9362846>,
    <0.2894960, -0.2018280, 0.9356589>,
    <0.2925631, -0.2033695, 0.9343702>,
    <0.2931828, -0.2041632, 0.9340028>,
    <0.2934619, -0.2054910, 0.9336239>,
    <0.2879889, -0.2016553, 0.9361611>,
    <0.2879889, -0.2016553, 0.9361611>,
    <0.2862483, -0.2004343, 0.9369568>,
    <0.2858792, -0.2000244, 0.9371570>,
    <0.2867847, -0.2001169, 0.9368606>,
    <0.2862483, -0.2004343, 0.9369568>,
    <0.2855139, -0.1999182, 0.9372911>,
    <0.2855139, -0.1999182, 0.9372911>,
    <0.2854151, -0.1998470, 0.9373363>,
    <0.2889670, -0.2008467, 0.9360335>,
    <0.2210589, -0.1268086, 0.9669812>,
    <0.2922187, -0.2027154, 0.9346201>,
    <-0.0083767, -0.0042408, -0.9999559>,
    <-0.0374427, -0.0193534, -0.9991113>,
    <-0.0227783, -0.0115089, -0.9996743>,
    <-0.0052294, -0.0025527, -0.9999831>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0098718, -0.0046161, -0.9999406>,
    <-0.0408162, -0.0194184, -0.9989780>,
    <-0.0870904, -0.0460660, -0.9951348>,
    <-0.0334088, -0.0172143, -0.9992935>,
    <-0.1294870, -0.0639126, -0.9895192>,
    <-0.5449390, -0.3157124, 0.7767672>,
    <-0.1247782, -0.0749294, -0.9893513>,
    <-0.0372599, -0.0222749, -0.9990573>,
    <-0.0067551, -0.0032797, -0.9999718>,
    <-0.0077646, -0.0046316, -0.9999591>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0068833, -0.0028964, -0.9999721>,
    <-0.0054667, -0.0025492, -0.9999818>,
    <-0.0234767, -0.0109476, -0.9996644>,
    <-0.0331251, -0.0146090, -0.9993444>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0098244, -0.0049144, -0.9999397>,
    <-0.0454849, -0.0224175, -0.9987135>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0138311, -0.0058295, -0.9998874>,
    <-0.0705508, -0.0329456, -0.9969640>,
    <-0.0990264, -0.0476355, -0.9939440>,
    <-0.2734867, -0.1353399, -0.9523068>,
    <-0.0370226, -0.0174715, -0.9991617>,
    <-0.1608608, -0.0763741, -0.9840177>,
    <-0.3703919, -0.1725717, -0.9127041>,
    <-0.1659948, -0.0761664, -0.9831808>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.9025228, -0.4029631, 0.1518988>,
    <-0.7154708, -0.3309995, 0.6152568>,
    <-0.3441164, -0.1464872, 0.9274295>,
    <-0.3361269, -0.1534177, 0.9292372>,
    <-0.9010203, -0.4329084, -0.0274350>,
    <-0.3469026, -0.1688180, 0.9225828>,
    <-0.0072743, 0.0031346, -0.9999686>,
    <-0.0323602, 0.0144077, -0.9993724>,
    <-0.0226482, 0.0105610, -0.9996877>,
    <-0.0054208, 0.0025277, -0.9999821>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0097062, 0.0045384, -0.9999426>,
    <-0.0380602, 0.0181065, -0.9991114>,
    <-0.0877884, 0.0423382, -0.9952390>,
    <-0.0422762, 0.0208177, -0.9988891>,
    <-0.1093621, 0.0541267, -0.9925272>,
    <-0.5339618, 0.3234384, 0.7811993>,
    <-0.2454090, 0.1234990, -0.9615209>,
    <-0.0673311, 0.0316521, -0.9972285>,
    <-0.0092910, 0.0046491, -0.9999460>,
    <-0.0145252, 0.0061432, -0.9998756>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0360660, 0.0169018, -0.9992065>,
    <-0.1578151, 0.0731184, -0.9847579>,
    <-0.3563407, 0.1678829, -0.9191500>,
    <-0.1574715, 0.0752312, -0.9846537>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.8923448, 0.4382685, -0.1078959>,
    <-0.7338389, 0.3473033, 0.5838329>,
    <-0.3553321, 0.1812327, 0.9170026>,
    <-0.3420070, 0.1635862, 0.9253490>,
    <-0.9024699, 0.4128891, 0.1227627>,
    <-0.3456316, 0.1563796, 0.9252482>,
    <-0.0067052, 0.0033270, -0.9999720>,
    <-0.0320242, 0.0170939, -0.9993409>,
    <-0.0217902, 0.0113467, -0.9996982>,
    <-0.0051457, 0.0025683, -0.9999835>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0081568, 0.0051591, -0.9999534>,
    <-0.0374685, 0.0236312, -0.9990184>,
    <-0.0786263, 0.0427561, -0.9959869>,
    <-0.0345875, 0.0183324, -0.9992335>,
    <-0.1240617, 0.0776308, -0.9892331>,
    <-0.0079937, 0.0041480, -0.9999594>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0076430, -0.0051376, -0.9999576>,
    <-0.0048060, -0.0033014, -0.9999830>,
    <-0.0207222, -0.0140111, -0.9996871>,
    <-0.0336962, -0.0224615, -0.9991797>,
    <-0.0357346, -0.0248498, -0.9990523>,
    <-0.0088519, -0.0061929, -0.9999416>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0063133, -0.0043843, -0.9999705>,
    <-0.0305471, -0.0205458, -0.9993221>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0770751, -0.0509546, -0.9957224>,
    <-0.1087466, -0.0742864, -0.9912899>,
    <-0.0077405, 0.0052175, -0.9999564>,
    <-0.0353087, 0.0237599, -0.9990940>,
    <-0.0214649, 0.0147534, -0.9996607>,
    <-0.0048988, 0.0033961, -0.9999822>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0090066, 0.0063036, -0.9999396>,
    <-0.0381204, 0.0265978, -0.9989191>,
    <-0.0836847, 0.0566856, -0.9948787>,
    <-0.0320382, 0.0222838, -0.9992382>,
    <-0.1268282, 0.0875283, -0.9880554>,
    <-0.0066494, 0.0047282, -0.9999667>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.2816595, 0.1964657, 0.9391854>,
    <0.2824819, 0.1963347, 0.9389657>,
    <0.2793419, 0.1944613, 0.9402941>,
    <0.2775304, 0.1937546, 0.9409761>,
    <0.2757503, 0.1930826, 0.9416373>,
    <0.2792878, 0.1955644, 0.9400813>,
    <0.2792878, 0.1955644, 0.9400813>,
    <0.2880550, 0.2017147, 0.9361279>,
    <0.2886716, 0.2004722, 0.9362049>,
    <0.2883397, 0.1996403, 0.9364849>,
    <0.2838993, 0.1954902, 0.9387144>,
    <0.2770055, 0.1920053, 0.9414892>,
    <0.2896478, 0.1995715, 0.9360958>,
    <0.2555724, 0.1466070, 0.9556093>,
    <0.2737836, 0.1909538, 0.9426448>,
    <0.2662481, 0.1839817, 0.9461832>,
    <0.2723418, 0.1906938, 0.9431150>,
    <0.2723418, 0.1906938, 0.9431150>,
    <0.2757503, 0.1930826, 0.9416373>,
    <0.2495507, 0.2252904, 0.9417901>,
    <0.2527891, 0.2248709, 0.9410265>,
    <0.2600964, 0.2089646, 0.9427002>,
    <0.2670949, 0.2065005, 0.9412852>,
    <0.2746119, 0.1923926, 0.9421111>,
    <0.2248109, 0.1576866, 0.9615586>,
    <0.2248109, 0.1576866, 0.9615586>,
    <0.2518664, 0.2487811, 0.9352386>,
    <0.2529491, 0.2493538, 0.9347938>,
    <0.2564886, 0.2491379, 0.9338865>,
    <0.2808696, 0.2303799, 0.9316852>,
    <0.2752926, 0.2062839, 0.9389680>,
    <0.2770742, 0.2604918, 0.9248643>,
    <0.2296635, 0.1919841, 0.9541471>,
    <0.3036759, 0.2193890, 0.9271728>,
    <0.2921280, 0.2059039, 0.9339512>,
    <0.2872323, 0.2044266, 0.9357924>,
    <0.2931584, 0.2037348, 0.9341040>,
    <0.2880550, 0.2017147, 0.9361279>,
    <0.2941303, 0.2059962, 0.9333022>,
    <0.2941303, 0.2059962, 0.9333022>,
    <0.2746119, 0.1923926, 0.9421111>,
    <0.2943092, 0.2034529, 0.9338035>,
    <0.2973800, 0.2055190, 0.9323771>,
    <0.2977019, 0.2049834, 0.9323923>,
    <0.2942414, 0.2029748, 0.9339289>,
    <0.2880550, 0.2017147, 0.9361279>,
    <0.3019474, 0.2085968, 0.9302232>,
    <0.2998428, 0.2061235, 0.9314544>,
    <0.2296635, 0.1919841, 0.9541471>,
    <0.3068048, 0.2105710, 0.9281867>,
    <0.3068048, 0.2105710, 0.9281867>,
    <0.3015886, 0.2069909, 0.9306982>,
    <0.2957876, 0.2035329, 0.9333188>,
    <0.3015886, 0.2069909, 0.9306982>,
    <0.2983607, 0.2047755, 0.9322274>,
    <0.2983607, 0.2047755, 0.9322274>,
    <0.2555724, 0.1466070, 0.9556093>,
    <0.2958430, -0.2054550, 0.9328800>,
    <0.2953351, -0.2048611, 0.9331715>,
    <0.2967445, -0.2056852, 0.9325429>,
    <0.2974637, -0.2062349, 0.9321923>,
    <0.2985612, -0.2074088, 0.9315808>,
    <0.2968270, -0.2065538, 0.9323247>,
    <0.2934619, -0.2054910, 0.9336239>,
    <0.2955085, -0.2047046, 0.9331510>,
    <0.2973427, -0.2059106, 0.9323026>,
    <0.2210589, -0.1268086, 0.9669812>,
    <0.2962267, -0.2049491, 0.9328696>,
    <0.2962267, -0.2049491, 0.9328696>,
    <0.2978386, -0.2060644, 0.9321103>,
    <0.2987014, -0.2068497, 0.9316602>,
    <0.2978386, -0.2060644, 0.9321103>,
    <0.2991327, -0.2069597, 0.9314974>,
    <0.2991327, -0.2069597, 0.9314974>,
    <0.1927193, -0.1623222, 0.9677349>,
    <0.3002124, -0.2088049, 0.9307379>,
    <0.2987916, -0.2086261, 0.9312350>,
    <0.2994224, -0.2089930, 0.9309501>,
    <0.2994336, -0.2098626, 0.9307509>,
    <0.2996441, -0.2099252, 0.9306690>,
    <0.3000111, -0.2100871, 0.9305142>,
    <0.2990214, -0.2093889, 0.9309900>,
    <0.2990214, -0.2093889, 0.9309900>,
    <0.2934619, -0.2054910, 0.9336239>,
    <0.2998545, -0.2119199, 0.9301490>,
    <0.2974476, -0.2111172, 0.9311039>,
    <0.1927193, -0.1623222, 0.9677349>,
    <0.2938042, -0.2264201, 0.9286620>,
    <0.2887402, -0.2156866, 0.9327960>,
    <0.2977758, -0.2102932, 0.9311854>,
    <0.2882182, -0.2108712, 0.9340576>,
    <0.2867488, -0.2091093, 0.9349056>,
    <0.2981884, -0.2088149, 0.9313861>,
    <0.2981884, -0.2088149, 0.9313861>,
    <0.3000111, -0.2100871, 0.9305142>,
    <0.2675487, -0.2267829, 0.9364760>,
    <0.2689518, -0.2290247, 0.9355280>,
    <0.2602146, -0.2422372, 0.9346708>,
    <0.2588787, -0.2470573, 0.9337797>,
    <0.2534117, -0.2534625, 0.9335627>,
    <0.2368084, -0.2369414, 0.9422211>,
    <0.2368084, -0.2369414, 0.9422211>,
    <0.2867488, -0.2091093, 0.9349056>,
    <0.2706343, -0.2455092, 0.9308503>,
    <0.2591681, -0.2508123, 0.9326977>,
    <0.1927193, -0.1623222, 0.9677349>,
    <0.2637027, -0.2585471, 0.9293085>,
    <0.2589694, -0.2574013, 0.9309562>,
    <0.2593133, -0.2568978, 0.9309995>,
    <0.2598927, -0.2597090, 0.9300575>,
    <0.2607110, -0.2607111, 0.9295480>,
    <0.2598236, -0.2598395, 0.9300404>,
    <0.2598236, -0.2598395, 0.9300404>,
    <0.2534117, -0.2534625, 0.9335627>,
    <-0.0095645, -0.0063744, -0.9999339>,
    <-0.0049165, -0.0034426, -0.9999820>,
    <-0.0207722, -0.0145449, -0.9996784>,
    <-0.0430284, -0.0290499, -0.9986514>,
    <-0.0628790, -0.0438397, -0.9970578>,
    <-0.0107051, -0.0082062, -0.9999090>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0061340, -0.0044773, -0.9999712>,
    <-0.0283331, -0.0203808, -0.9993907>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0872392, -0.0599069, -0.9943845>,
    <-0.2882333, -0.1918494, -0.9381447>,
    <-0.0062237, 0.0045417, -0.9999703>,
    <-0.0049603, 0.0034732, -0.9999817>,
    <-0.0215782, 0.0151091, -0.9996530>,
    <-0.0301070, 0.0216700, -0.9993118>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0096263, 0.0064350, -0.9999330>,
    <-0.0447726, 0.0303078, -0.9985374>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0108175, 0.0082605, -0.9999074>,
    <-0.0646662, 0.0453518, -0.9968759>,
    <-0.0970005, 0.0669383, -0.9930308>,
    <-0.2975958, 0.2013628, -0.9332147>,
    <-0.0095027, -0.0071892, -0.9999290>,
    <-0.0430985, -0.0337596, -0.9985003>,
    <-0.0256553, -0.0199993, -0.9994708>,
    <-0.0057762, -0.0043152, -0.9999740>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0113556, -0.0079846, -0.9999036>,
    <-0.0480875, -0.0346858, -0.9982407>,
    <-0.1018271, -0.0836283, -0.9912808>,
    <-0.0370922, -0.0300886, -0.9988588>,
    <-0.1597453, -0.1204175, -0.9797862>,
    <-0.4212175, -0.3505214, 0.8364870>,
    <-0.1433921, -0.1309340, -0.9809664>,
    <-0.0403682, -0.0367969, -0.9985071>,
    <-0.0070600, -0.0053963, -0.9999605>,
    <-0.0081424, -0.0073961, -0.9999395>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0079740, -0.0051263, -0.9999551>,
    <-0.0062863, -0.0044017, -0.9999706>,
    <-0.0274668, -0.0192326, -0.9994377>,
    <-0.0393380, -0.0263965, -0.9988772>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0107929, -0.0080760, -0.9999091>,
    <-0.0505885, -0.0368992, -0.9980377>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0152449, -0.0095810, -0.9998379>,
    <-0.0731426, -0.0504010, -0.9960471>,
    <-0.1148279, -0.0820535, -0.9899908>,
    <-0.2924954, -0.2117220, -0.9325343>,
    <-0.0346393, -0.0238481, -0.9991153>,
    <-0.1430848, -0.1008744, -0.9845563>,
    <-0.3530353, -0.2448557, -0.9030015>,
    <-0.1632480, -0.1110029, -0.9803206>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.8063337, -0.5444886, 0.2309940>,
    <-0.6300263, -0.4370311, 0.6419273>,
    <-0.3146294, -0.2063709, 0.9265093>,
    <-0.3045968, -0.2099375, 0.9290570>,
    <-0.8123251, -0.5780968, 0.0770194>,
    <-0.3119167, -0.2259442, 0.9228527>,
    <-0.0084044, 0.0055256, -0.9999494>,
    <-0.0376605, 0.0254711, -0.9989659>,
    <-0.0262112, 0.0183532, -0.9994879>,
    <-0.0062183, 0.0043541, -0.9999712>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0111020, 0.0078061, -0.9999079>,
    <-0.0438030, 0.0315948, -0.9985405>,
    <-0.0983227, 0.0704203, -0.9926599>,
    <-0.0466566, 0.0339080, -0.9983353>,
    <-0.1294523, 0.0977942, -0.9867514>,
    <-0.4220352, 0.3670300, 0.8289603>,
    <-0.2475465, 0.1821126, -0.9516069>,
    <-0.0685475, 0.0476116, -0.9965111>,
    <-0.0102884, 0.0076002, -0.9999182>,
    <-0.0151811, 0.0097258, -0.9998375>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0341276, 0.0236715, -0.9991371>,
    <-0.1499664, 0.1033098, -0.9832788>,
    <-0.3295945, 0.2317050, -0.9152487>,
    <-0.1435186, 0.1022809, -0.9843480>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.8056801, 0.5856879, -0.0885960>,
    <-0.6637861, 0.4697544, 0.5819955>,
    <-0.3191890, 0.2411307, 0.9165012>,
    <-0.3096475, 0.2215590, 0.9246783>,
    <-0.8177960, 0.5635620, 0.1166517>,
    <-0.3147483, 0.2150993, 0.9244814>,
    <-0.0070731, 0.0056067, -0.9999593>,
    <-0.0356905, 0.0300605, -0.9989107>,
    <-0.0242727, 0.0195667, -0.9995139>,
    <-0.0056449, 0.0043371, -0.9999747>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0087863, 0.0083020, -0.9999269>,
    <-0.0416512, 0.0393378, -0.9983575>,
    <-0.0918169, 0.0774628, -0.9927584>,
    <-0.0391487, 0.0314310, -0.9987389>,
    <-0.1494839, 0.1403449, -0.9787532>,
    <-0.0089895, 0.0069573, -0.9999354>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.2544048, -0.2554339, 0.9327549>,
    <0.2577736, -0.2583780, 0.9310175>,
    <0.2565245, -0.2576580, 0.9315619>,
    <0.2541557, -0.2558858, 0.9326990>,
    <0.2495140, -0.2523680, 0.9349081>,
    <0.2487510, -0.2508970, 0.9355071>,
    <0.2487034, -0.2486872, 0.9361097>,
    <0.2566856, -0.2566723, 0.9317896>,
    <0.2566856, -0.2566723, 0.9317896>,
    <0.2593903, -0.2593797, 0.9302896>,
    <0.2597775, -0.2599669, 0.9300177>,
    <0.2579388, -0.2584525, 0.9309511>,
    <0.2593903, -0.2593797, 0.9302896>,
    <0.2605560, -0.2605490, 0.9296369>,
    <0.2605560, -0.2605490, 0.9296369>,
    <0.2607110, -0.2607111, 0.9295480>,
    <0.2562673, -0.2575558, 0.9316609>,
    <0.1927193, -0.1623222, 0.9677349>,
    <0.2504960, -0.2537823, 0.9342624>,
    <0.2568978, 0.2572987, 0.9315583>,
    <0.2572638, 0.2577210, 0.9313405>,
    <0.2587376, 0.2586417, 0.9306768>,
    <0.2587948, 0.2587477, 0.9306315>,
    <0.2590179, 0.2590179, 0.9304942>,
    <0.2581585, 0.2581585, 0.9309718>,
    <0.2581585, 0.2581585, 0.9309718>,
    <0.2533970, 0.2533970, 0.9335845>,
    <0.2529106, 0.2540503, 0.9335388>,
    <0.2535016, 0.2548965, 0.9331477>,
    <0.2620984, 0.2602955, 0.9292743>,
    <0.2591201, 0.2575267, 0.9308796>,
    <0.2559542, 0.2570344, 0.9318910>,
    <0.2296635, 0.1919841, 0.9541471>,
    <0.2581833, 0.2574547, 0.9311597>,
    <0.2518664, 0.2487811, 0.9352386>,
    <0.2574244, 0.2574244, 0.9313782>,
    <0.2574244, 0.2574244, 0.9313782>,
    <0.2590179, 0.2590179, 0.9304942>,
    <0.1967269, 0.2531304, 0.9472188>,
    <0.1999759, 0.2544750, 0.9461776>,
    <0.2098614, 0.2422648, 0.9472413>,
    <0.2170343, 0.2405057, 0.9460725>,
    <0.2267327, 0.2267325, 0.9471983>,
    <0.1858235, 0.1858230, 0.9648520>,
    <0.1858235, 0.1858230, 0.9648520>,
    <0.1940064, 0.2734288, 0.9421243>,
    <0.1951384, 0.2744778, 0.9415853>,
    <0.1988470, 0.2756090, 0.9404783>,
    <0.2230619, 0.2634275, 0.9385357>,
    <0.2243470, 0.2430964, 0.9437015>,
    <0.2148232, 0.2883023, 0.9331306>,
    <0.1891547, 0.2267065, 0.9554186>,
    <0.2444444, 0.2580933, 0.9346843>,
    <0.2401524, 0.2473033, 0.9387054>,
    <0.2381330, 0.2444847, 0.9399574>,
    <0.2467791, 0.2492657, 0.9364650>,
    <0.2533970, 0.2533970, 0.9335845>,
    <0.2461691, 0.2461690, 0.9374442>,
    <0.2461691, 0.2461690, 0.9374442>,
    <0.2267327, 0.2267325, 0.9471983>,
    <0.2494066, 0.2514540, 0.9351830>,
    <0.2462567, 0.2496122, 0.9365102>,
    <0.2480879, 0.2504413, 0.9358053>,
    <0.2499929, 0.2520534, 0.9348650>,
    <0.2533970, 0.2533970, 0.9335845>,
    <0.2456985, 0.2496693, 0.9366416>,
    <0.2470122, 0.2495807, 0.9363196>,
    <0.1891547, 0.2267065, 0.9554186>,
    <0.2480895, 0.2508936, 0.9356837>,
    <0.2480895, 0.2508936, 0.9356837>,
    <0.2461453, 0.2489274, 0.9367217>,
    <0.2493374, 0.2517218, 0.9351294>,
    <0.2461453, 0.2489274, 0.9367217>,
    <0.2478507, 0.2506521, 0.9358117>,
    <0.2478507, 0.2506521, 0.9358117>,
    <0.2296635, 0.1919841, 0.9541471>,
    <0.2449072, -0.2480922, 0.9372677>,
    <0.2455343, -0.2491694, 0.9368178>,
    <0.2435953, -0.2474911, 0.9377684>,
    <0.2426212, -0.2464960, 0.9382828>,
    <0.2410803, -0.2445404, 0.9391913>,
    <0.2435816, -0.2460400, 0.9381537>,
    <0.2487034, -0.2486872, 0.9361097>,
    <0.2452103, -0.2493669, 0.9368501>,
    <0.2427444, -0.2469807, 0.9381235>,
    <0.1927193, -0.1623222, 0.9677349>,
    <0.2441627, -0.2487812, 0.9372793>,
    <0.2441627, -0.2487812, 0.9372793>,
    <0.2420344, -0.2466126, 0.9384037>,
    <0.2410788, -0.2454152, 0.9389635>,
    <0.2420344, -0.2466126, 0.9384037>,
    <0.2406330, -0.2451847, 0.9391380>,
    <0.2406330, -0.2451847, 0.9391380>,
    <0.1591142, -0.1914245, 0.9685243>,
    <0.2395145, -0.2440996, 0.9397064>,
    <0.2347223, -0.2371693, 0.9426856>,
    <0.2380716, -0.2395861, 0.9412335>,
    <0.2379052, -0.2406999, 0.9409913>,
    <0.2347869, -0.2398613, 0.9419882>,
    <0.2256672, -0.2408771, 0.9439558>,
    <0.2260336, -0.2356848, 0.9451780>,
    <0.2250120, -0.2337568, 0.9459003>,
    <0.2351261, -0.2350998, 0.9431033>,
    <0.2351261, -0.2350998, 0.9431033>,
    <0.2380336, -0.2380102, 0.9416428>,
    <0.2407797, -0.2422734, 0.9398557>,
    <0.2392854, -0.2421517, 0.9402686>,
    <0.2380336, -0.2380102, 0.9416428>,
    <0.2410769, -0.2410571, 0.9400922>,
    <0.2410769, -0.2410571, 0.9400922>,
    <0.2487034, -0.2486872, 0.9361097>,
    <0.2368370, -0.2429669, 0.9406781>,
    <0.1591142, -0.1914245, 0.9685243>,
    <0.2277605, -0.2518101, 0.9405939>,
    <0.2050465, -0.2468053, 0.9471236>,
    <0.2058385, -0.2491556, 0.9463361>,
    <0.1957655, -0.2592821, 0.9457530>,
    <0.1937258, -0.2632976, 0.9450633>,
    <0.1878139, -0.2682005, 0.9448780>,
    <0.1764626, -0.2519595, 0.9515132>,
    <0.1764626, -0.2519595, 0.9515132>,
    <0.2250120, -0.2337568, 0.9459003>,
    <0.2044538, -0.2638142, 0.9426562>,
    <0.1934140, -0.2666738, 0.9441801>,
    <0.1591142, -0.1914245, 0.9685243>,
    <0.1972351, -0.2747678, 0.9410638>,
    <0.1925420, -0.2728154, 0.9426024>,
    <0.1922886, -0.2718610, 0.9429299>,
    <0.1923752, -0.2744820, 0.9421525>,
    <0.1927627, -0.2752888, 0.9418379>,
    <0.1921708, -0.2744367, 0.9422075>,
    <0.1921708, -0.2744367, 0.9422075>,
    <0.1878139, -0.2682005, 0.9448780>,
    <-0.0091468, -0.0088621, -0.9999189>,
    <-0.0052220, -0.0051704, -0.9999730>,
    <-0.0223971, -0.0220128, -0.9995068>,
    <-0.0415825, -0.0402678, -0.9983233>,
    <-0.0593787, -0.0594575, -0.9964632>,
    <-0.0114814, -0.0122277, -0.9998593>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0068879, -0.0068580, -0.9999528>,
    <-0.0331399, -0.0324572, -0.9989236>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0939950, -0.0904917, -0.9914516>,
    <-0.2576470, -0.2464918, -0.9342697>,
    <-0.0093084, 0.0090446, -0.9999158>,
    <-0.0439571, 0.0428633, -0.9981135>,
    <-0.0235930, 0.0233834, -0.9994481>,
    <-0.0053514, 0.0053246, -0.9999715>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0116198, 0.0123627, -0.9998561>,
    <-0.0622121, 0.0627466, -0.9960886>,
    <-0.1037902, 0.1014899, -0.9894076>,
    <-0.0355568, 0.0354388, -0.9987391>,
    <-0.2768096, 0.2699880, -0.9222163>,
    <-0.0073076, 0.0073656, -0.9999462>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0064212, -0.0068500, -0.9999559>,
    <-0.0285649, -0.0309918, -0.9991114>,
    <-0.0174684, -0.0186055, -0.9996743>,
    <-0.0040411, -0.0041873, -0.9999831>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0076978, -0.0077142, -0.9999406>,
    <-0.0317142, -0.0322083, -0.9989779>,
    <-0.0660772, -0.0730681, -0.9951356>,
    <-0.0255061, -0.0276022, -0.9992935>,
    <-0.0998186, -0.1043450, -0.9895193>,
    <-0.4045257, -0.4835661, 0.7762234>,
    <-0.0915914, -0.1130445, -0.9893594>,
    <-0.0273915, -0.0336715, -0.9990575>,
    <-0.0052260, -0.0053923, -0.9999718>,
    <-0.0057121, -0.0070078, -0.9999591>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0054778, -0.0050762, -0.9999721>,
    <-0.0042653, -0.0042653, -0.9999818>,
    <-0.0183172, -0.0183174, -0.9996644>,
    <-0.0261325, -0.0250590, -0.9993444>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0075512, -0.0079782, -0.9999397>,
    <-0.0350750, -0.0366228, -0.9987134>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0110036, -0.0102088, -0.9998873>,
    <-0.0550314, -0.0550918, -0.9969636>,
    <-0.0767653, -0.0786347, -0.9939435>,
    <-0.2107003, -0.2207109, -0.9523088>,
    <-0.0288152, -0.0290812, -0.9991616>,
    <-0.1250483, -0.1267958, -0.9840151>,
    <-0.2891013, -0.2889150, -0.9126602>,
    <-0.1299542, -0.1283666, -0.9831754>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.7095590, -0.6873592, 0.1551235>,
    <-0.5589290, -0.5555579, 0.6155922>,
    <-0.2741292, -0.2567221, 0.9267939>,
    <-0.2633104, -0.2590546, 0.9292784>,
    <-0.6986244, -0.7149719, -0.0271879>,
    <-0.2682377, -0.2772788, 0.9225860>,
    <-0.0057646, 0.0054452, -0.9999686>,
    <-0.0254561, 0.0245976, -0.9993733>,
    <-0.0176571, 0.0176570, -0.9996882>,
    <-0.0042285, 0.0042285, -0.9999821>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0075662, 0.0075820, -0.9999426>,
    <-0.0295354, 0.0299946, -0.9991136>,
    <-0.0678214, 0.0695832, -0.9952680>,
    <-0.0326942, 0.0340108, -0.9988866>,
    <-0.0839536, 0.0879512, -0.9925807>,
    <-0.3969574, 0.4937961, 0.7736862>,
    <-0.1876249, 0.1990709, -0.9618564>,
    <-0.0524273, 0.0527351, -0.9972314>,
    <-0.0072349, 0.0075769, -0.9999451>,
    <-0.0110391, 0.0103593, -0.9998854>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0286893, 0.0290938, -0.9991649>,
    <-0.1233211, 0.1229799, -0.9847171>,
    <-0.2818528, 0.2849969, -0.9161527>,
    <-0.1285342, 0.1317426, -0.9829155>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.6879094, 0.7162282, -0.1174642>,
    <-0.5733635, 0.5804005, 0.5782643>,
    <-0.2749666, 0.2950049, 0.9150768>,
    <-0.2683703, 0.2733850, 0.9237088>,
    <-0.7067759, 0.6992250, 0.1074812>,
    <-0.2756373, 0.2687421, 0.9229311>,
    <-0.0051618, 0.0054185, -0.9999720>,
    <-0.0242202, 0.0269865, -0.9993423>,
    <-0.0165832, 0.0181018, -0.9996986>,
    <-0.0039563, 0.0041726, -0.9999835>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0058985, 0.0076354, -0.9999535>,
    <-0.0270897, 0.0349735, -0.9990210>,
    <-0.0591034, 0.0668906, -0.9960082>,
    <-0.0262009, 0.0290224, -0.9992353>,
    <-0.0896339, 0.1148748, -0.9893278>,
    <-0.0060913, 0.0066301, -0.9999595>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0054876, 0.0075480, -0.9999565>,
    <-0.0250201, 0.0343583, -0.9990963>,
    <-0.0151121, 0.0211880, -0.9996613>,
    <-0.0034411, 0.0048659, -0.9999822>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0063053, 0.0090008, -0.9999396>,
    <-0.0266863, 0.0379775, -0.9989222>,
    <-0.0590679, 0.0816372, -0.9949102>,
    <-0.0224573, 0.0318591, -0.9992400>,
    <-0.0888287, 0.1250444, -0.9881667>,
    <-0.0046299, 0.0067154, -0.9999667>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0054247, -0.0074415, -0.9999576>,
    <-0.0033870, -0.0047459, -0.9999830>,
    <-0.0146789, -0.0202513, -0.9996872>,
    <-0.0239778, -0.0326262, -0.9991800>,
    <-0.0250752, -0.0355657, -0.9990527>,
    <-0.0061997, -0.0088464, -0.9999417>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0044329, -0.0062789, -0.9999705>,
    <-0.0216745, -0.0297498, -0.9993224>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0549794, -0.0742156, -0.9957255>,
    <-0.0767363, -0.1069375, -0.9913001>,
    <0.1927616, -0.2752911, 0.9418374>,
    <0.1927612, -0.2752901, 0.9418378>,
    <0.1927618, -0.2752903, 0.9418376>,
    <0.1927621, -0.2752910, 0.9418374>,
    <0.1927637, -0.2752929, 0.9418365>,
    <0.1927638, -0.2752936, 0.9418363>,
    <0.1927636, -0.2752948, 0.9418360>,
    <0.1927606, -0.2752905, 0.9418378>,
    <0.1927606, -0.2752905, 0.9418378>,
    <0.1927604, -0.2752895, 0.9418382>,
    <0.1927293, -0.2751974, 0.9418714>,
    <0.1927151, -0.2748507, 0.9419756>,
    <0.1927604, -0.2752895, 0.9418382>,
    <0.1927609, -0.2752890, 0.9418382>,
    <0.1927609, -0.2752890, 0.9418382>,
    <0.1927627, -0.2752888, 0.9418379>,
    <0.1932743, -0.2753029, 0.9417289>,
    <0.1591142, -0.1914245, 0.9685243>,
    <0.1929603, -0.2754041, 0.9417637>,
    <-0.0068072, -0.0092609, -0.9999339>,
    <-0.0034425, -0.0049164, -0.9999820>,
    <-0.0145430, -0.0207696, -0.9996785>,
    <-0.0304912, -0.0420052, -0.9986520>,
    <-0.0440769, -0.0626790, -0.9970600>,
    <-0.0072522, -0.0113717, -0.9999090>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0042325, -0.0063049, -0.9999712>,
    <-0.0196501, -0.0288368, -0.9993910>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0614594, -0.0860904, -0.9943899>,
    <-0.2049627, -0.2784913, -0.9383138>,
    <-0.0042940, 0.0063950, -0.9999703>,
    <-0.0034726, 0.0049593, -0.9999817>,
    <-0.0150972, 0.0215608, -0.9996535>,
    <-0.0208561, 0.0306256, -0.9993133>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0068425, 0.0093360, -0.9999330>,
    <-0.0316545, 0.0437212, -0.9985422>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0073369, 0.0114574, -0.9999074>,
    <-0.0451466, 0.0645786, -0.9968909>,
    <-0.0680131, 0.0957351, -0.9930806>,
    <-0.2086437, 0.2880557, -0.9346078>,
    <0.1999530, 0.2854270, 0.9373101>,
    <0.2004307, 0.2857690, 0.9371039>,
    <0.2002967, 0.2853369, 0.9372642>,
    <0.1997505, 0.2848981, 0.9375142>,
    <0.1992841, 0.2845811, 0.9377097>,
    <0.1998528, 0.2853965, 0.9373408>,
    <0.1998528, 0.2853965, 0.9373408>,
    <0.1998995, 0.2854709, 0.9373081>,
    <0.1999110, 0.2854607, 0.9373088>,
    <0.2001619, 0.2856888, 0.9371857>,
    <0.2034914, 0.2875760, 0.9358906>,
    <0.2001495, 0.2836229, 0.9378157>,
    <0.2017957, 0.2872872, 0.9363464>,
    <0.1891547, 0.2267065, 0.9554186>,
    <0.1985455, 0.2825828, 0.9384704>,
    <0.1940064, 0.2734288, 0.9421243>,
    <0.1976027, 0.2821784, 0.9387910>,
    <0.1976027, 0.2821784, 0.9387910>,
    <0.1992841, 0.2845811, 0.9377097>,
    <0.1496191, 0.2828394, 0.9474260>,
    <0.1526098, 0.2842582, 0.9465239>,
    <0.1644151, 0.2734220, 0.9477384>,
    <0.1716328, 0.2730950, 0.9465523>,
    <0.1833602, 0.2619118, 0.9475132>,
    <0.1506535, 0.2153174, 0.9648533>,
    <0.1506535, 0.2153174, 0.9648533>,
    <0.1435346, 0.3029233, 0.9421440>,
    <0.1444194, 0.3040256, 0.9416536>,
    <0.1478535, 0.3055460, 0.9406280>,
    <0.1743676, 0.2971777, 0.9387659>,
    <0.1785669, 0.2763193, 0.9443312>,
    <0.1617754, 0.3211581, 0.9331057>,
    <0.1468098, 0.2542807, 0.9559227>,
    <0.1969171, 0.2951482, 0.9349392>,
    <0.1933947, 0.2823617, 0.9396118>,
    <0.1910416, 0.2793800, 0.9409835>,
    <0.1978497, 0.2836420, 0.9382978>,
    <0.1998995, 0.2854709, 0.9373081>,
    <0.1978501, 0.2825625, 0.9386234>,
    <0.1978501, 0.2825625, 0.9386234>,
    <0.1833602, 0.2619118, 0.9475132>,
    <0.1996268, 0.2852720, 0.9374268>,
    <0.1986633, 0.2848861, 0.9377488>,
    <0.1998682, 0.2854387, 0.9373246>,
    <0.1999551, 0.2855223, 0.9372806>,
    <0.1998995, 0.2854709, 0.9373081>,
    <0.1994104, 0.2863960, 0.9371301>,
    <0.1998603, 0.2854287, 0.9373294>,
    <0.1468098, 0.2542807, 0.9559227>,
    <0.2020747, 0.2885923, 0.9358848>,
    <0.2020747, 0.2885923, 0.9358848>,
    <0.1998551, 0.2854223, 0.9373324>,
    <0.2000403, 0.2856299, 0.9372297>,
    <0.1998551, 0.2854223, 0.9373324>,
    <0.1999446, 0.2855502, 0.9372744>,
    <0.1999446, 0.2855502, 0.9372744>,
    <0.1891547, 0.2267065, 0.9554186>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.1927595, -0.2752935, 0.9418372>,
    <0.1927653, -0.2752949, 0.9418356>,
    <0.1927661, -0.2752959, 0.9418351>,
    <0.1927480, -0.2753097, 0.9418348>,
    <0.1926510, -0.2753379, 0.9418464>,
    <0.1927138, -0.2752575, 0.9418571>,
    <0.1927636, -0.2752948, 0.9418360>,
    <0.1927656, -0.2752949, 0.9418355>,
    <0.1927666, -0.2752962, 0.9418349>,
    <0.1591142, -0.1914245, 0.9685243>,
    <0.1927660, -0.2752952, 0.9418353>,
    <0.1927660, -0.2752952, 0.9418353>,
    <0.1927669, -0.2752965, 0.9418348>,
    <0.1927878, -0.2753824, 0.9418054>,
    <0.1927669, -0.2752965, 0.9418348>,
    <0.1928455, -0.2754086, 0.9417859>,
    <0.1928455, -0.2754086, 0.9417859>,
    <0.1221665, -0.2115946, 0.9696923>,
    <0.1926807, -0.2761041, 0.9416160>,
    <0.1897977, -0.2736379, 0.9429205>,
    <0.1919137, -0.2748632, 0.9421355>,
    <0.1916851, -0.2751906, 0.9420865>,
    <0.1893006, -0.2749966, 0.9426251>,
    <0.1803974, -0.2756594, 0.9441762>,
    <0.1816259, -0.2712165, 0.9452268>,
    <0.1809889, -0.2692922, 0.9458989>,
    <0.1906064, -0.2722140, 0.9431695>,
    <0.1906064, -0.2722140, 0.9431695>,
    <0.1921584, -0.2744306, 0.9422118>,
    <0.1925519, -0.2751837, 0.9419117>,
    <0.1922716, -0.2753496, 0.9419205>,
    <0.1921584, -0.2744306, 0.9422118>,
    <0.1926974, -0.2752003, 0.9418771>,
    <0.1926974, -0.2752003, 0.9418771>,
    <0.1927636, -0.2752948, 0.9418360>,
    <0.1909280, -0.2770827, 0.9416856>,
    <0.1221665, -0.2115946, 0.9696923>,
    <0.1808574, -0.2861957, 0.9409477>,
    <0.1590779, -0.2786512, 0.9471260>,
    <0.1594573, -0.2809492, 0.9463831>,
    <0.1477667, -0.2893472, 0.9457501>,
    <0.1450632, -0.2929461, 0.9450605>,
    <0.1383960, -0.2967461, 0.9448748>,
    <0.1300488, -0.2787929, 0.9515050>,
    <0.1300488, -0.2787929, 0.9515050>,
    <0.1809889, -0.2692922, 0.9458989>,
    <0.1555718, -0.2950831, 0.9427213>,
    <0.1441690, -0.2962148, 0.9441780>,
    <0.1221665, -0.2115946, 0.9696923>,
    <0.1465332, -0.3048018, 0.9410759>,
    <0.1422446, -0.3021086, 0.9426011>,
    <0.1421612, -0.3011247, 0.9429285>,
    <0.1417907, -0.3037191, 0.9421518>,
    <0.1420320, -0.3045802, 0.9418375>,
    <0.1415987, -0.3036392, 0.9422065>,
    <0.1415987, -0.3036392, 0.9422065>,
    <0.1383960, -0.2967461, 0.9448748>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0051292, -0.0078533, -0.9999560>,
    <-0.0226593, -0.0353404, -0.9991184>,
    <-0.0139363, -0.0213009, -0.9996760>,
    <-0.0032504, -0.0048221, -0.9999831>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0062330, -0.0089216, -0.9999408>,
    <-0.0255065, -0.0370324, -0.9989885>,
    <-0.0518265, -0.0826158, -0.9952330>,
    <-0.0202266, -0.0314744, -0.9992999>,
    <-0.0789295, -0.1182685, -0.9898397>,
    <-0.3152971, -0.5509622, 0.7726761>,
    <-0.0694395, -0.1256549, -0.9896408>,
    <-0.0209951, -0.0377254, -0.9990676>,
    <-0.0042057, -0.0062114, -0.9999719>,
    <-0.0044029, -0.0078845, -0.9999592>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0044965, -0.0059066, -0.9999724>,
    <-0.0034573, -0.0049375, -0.9999818>,
    <-0.0148121, -0.0211540, -0.9996665>,
    <-0.0212710, -0.0290337, -0.9993521>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0059675, -0.0091755, -0.9999401>,
    <-0.0279462, -0.0419827, -0.9987274>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0095485, -0.0124429, -0.9998770>,
    <-0.0444194, -0.0635491, -0.9969897>,
    <-0.0613023, -0.0899086, -0.9940616>,
    <-0.1660460, -0.2497318, -0.9539721>,
    <-0.0230138, -0.0328179, -0.9991964>,
    <-0.0978641, -0.1411199, -0.9851435>,
    <-0.2325614, -0.3311419, -0.9144727>,
    <-0.1056225, -0.1486255, -0.9832367>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.5746860, -0.7926729, 0.2034839>,
    <-0.4549593, -0.6462591, 0.6126673>,
    <-0.2255692, -0.3023605, 0.9261191>,
    <-0.2151602, -0.3030385, 0.9283715>,
    <-0.5625584, -0.8248409, -0.0562627>,
    <-0.2166239, -0.3213258, 0.9218589>,
    <-0.0047107, 0.0063225, -0.9999689>,
    <-0.0204222, 0.0281087, -0.9993962>,
    <-0.0141543, 0.0202144, -0.9996955>,
    <-0.0034203, 0.0048846, -0.9999822>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0061037, 0.0087363, -0.9999432>,
    <-0.0234285, 0.0340149, -0.9991467>,
    <-0.0527717, 0.0776076, -0.9955864>,
    <-0.0257601, 0.0385281, -0.9989254>,
    <-0.0640402, 0.0963145, -0.9932887>,
    <-0.2930215, 0.5417182, 0.7878323>,
    <-0.1432899, 0.2193369, -0.9650696>,
    <-0.0417290, 0.0600995, -0.9973198>,
    <-0.0056990, 0.0086380, -0.9999465>,
    <-0.0094553, 0.0125181, -0.9998769>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0226660, 0.0325313, -0.9992137>,
    <-0.0980574, 0.1396796, -0.9853296>,
    <-0.2183395, 0.3150334, -0.9236243>,
    <-0.0977038, 0.1424202, -0.9849723>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.5460575, 0.8181771, -0.1800207>,
    <-0.4745397, 0.6875385, 0.5496389>,
    <-0.2182298, 0.3382031, 0.9154204>,
    <-0.2170622, 0.3172749, 0.9231580>,
    <-0.5778738, 0.8130831, 0.0704113>,
    <-0.2245241, 0.3131355, 0.9227866>,
    <-0.0041262, 0.0062108, -0.9999722>,
    <-0.0188512, 0.0303553, -0.9993614>,
    <-0.0130719, 0.0205244, -0.9997039>,
    <-0.0031642, 0.0047850, -0.9999835>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0044685, 0.0085203, -0.9999537>,
    <-0.0202750, 0.0386808, -0.9990459>,
    <-0.0450341, 0.0738883, -0.9962492>,
    <-0.0204891, 0.0326940, -0.9992554>,
    <-0.0658430, 0.1255226, -0.9899034>,
    <-0.0048315, 0.0075623, -0.9999597>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0040137, -0.0082238, -0.9999581>,
    <-0.0025066, -0.0052565, -0.9999830>,
    <-0.0108830, -0.0224175, -0.9996895>,
    <-0.0177323, -0.0360010, -0.9991944>,
    <-0.0184681, -0.0393084, -0.9990564>,
    <-0.0045675, -0.0097859, -0.9999417>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0032742, -0.0069520, -0.9999705>,
    <-0.0161153, -0.0329705, -0.9993264>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0407592, -0.0819314, -0.9958042>,
    <-0.0565335, -0.1179757, -0.9914059>,
    <-0.0039838, 0.0082476, -0.9999581>,
    <-0.0181156, 0.0374480, -0.9991344>,
    <-0.0110979, 0.0233524, -0.9996657>,
    <-0.0025349, 0.0053795, -0.9999823>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0046435, 0.0099543, -0.9999397>,
    <-0.0196029, 0.0419159, -0.9989288>,
    <-0.0430439, 0.0893793, -0.9950671>,
    <-0.0165373, 0.0352043, -0.9992433>,
    <-0.0649088, 0.1374499, -0.9883797>,
    <-0.0033992, 0.0074231, -0.9999667>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.1420286, -0.3045872, 0.9418357>,
    <0.1420287, -0.3045831, 0.9418370>,
    <0.1420304, -0.3045837, 0.9418366>,
    <0.1420307, -0.3045858, 0.9418359>,
    <0.1420364, -0.3045956, 0.9418318>,
    <0.1420365, -0.3046029, 0.9418295>,
    <0.1420309, -0.3046144, 0.9418266>,
    <0.1420217, -0.3045802, 0.9418390>,
    <0.1420217, -0.3045802, 0.9418390>,
    <0.1420257, -0.3045801, 0.9418385>,
    <0.1420143, -0.3044850, 0.9418709>,
    <0.1420613, -0.3041422, 0.9419746>,
    <0.1420257, -0.3045801, 0.9418385>,
    <0.1420288, -0.3045800, 0.9418380>,
    <0.1420288, -0.3045800, 0.9418380>,
    <0.1420320, -0.3045802, 0.9418375>,
    <0.1425338, -0.3046853, 0.9417277>,
    <0.1221665, -0.2115946, 0.9696923>,
    <0.1422100, -0.3047348, 0.9417606>,
    <-0.0050275, -0.0102775, -0.9999345>,
    <-0.0025364, -0.0054393, -0.9999820>,
    <-0.0107139, -0.0229760, -0.9996786>,
    <-0.0225941, -0.0466361, -0.9986564>,
    <-0.0325480, -0.0694654, -0.9970532>,
    <-0.0050648, -0.0120175, -0.9999150>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0031380, -0.0070286, -0.9999704>,
    <-0.0144893, -0.0319857, -0.9993833>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0453554, -0.0952201, -0.9944225>,
    <-0.1558056, -0.3156439, -0.9359987>,
    <0.1473268, 0.3157938, 0.9373202>,
    <0.1477391, 0.3162129, 0.9371140>,
    <0.1476704, 0.3157461, 0.9372822>,
    <0.1472041, 0.3152123, 0.9375351>,
    <0.1467954, 0.3148126, 0.9377335>,
    <0.1472261, 0.3157368, 0.9373552>,
    <0.1472261, 0.3157368, 0.9373552>,
    <0.1472886, 0.3158716, 0.9373000>,
    <0.1473042, 0.3158601, 0.9373014>,
    <0.1475107, 0.3161229, 0.9371803>,
    <0.1504753, 0.3185187, 0.9358969>,
    <0.1478047, 0.3139603, 0.9378607>,
    <0.1488637, 0.3179997, 0.9363310>,
    <0.1468098, 0.2542807, 0.9559227>,
    <0.1464079, 0.3126992, 0.9385009>,
    <0.1435346, 0.3029233, 0.9421440>,
    <0.1455535, 0.3121493, 0.9388168>,
    <0.1455535, 0.3121493, 0.9388168>,
    <0.1467954, 0.3148126, 0.9377335>,
    <0.0982838, 0.3045805, 0.9474022>,
    <0.1010281, 0.3065793, 0.9464684>,
    <0.1144832, 0.2978962, 0.9477085>,
    <0.1216467, 0.2988184, 0.9465250>,
    <0.1351415, 0.2898303, 0.9474889>,
    <0.1110328, 0.2381448, 0.9648621>,
    <0.1110328, 0.2381448, 0.9648621>,
    <0.0887869, 0.3232892, 0.9421258>,
    <0.0895045, 0.3246232, 0.9415990>,
    <0.0928019, 0.3270404, 0.9404426>,
    <0.1202496, 0.3231195, 0.9386873>,
    <0.1279140, 0.3032106, 0.9442994>,
    <0.1041479, 0.3452606, 0.9327102>,
    <0.1031373, 0.2809277, 0.9541710>,
    <0.1427393, 0.3249640, 0.9348925>,
    <0.1414648, 0.3117345, 0.9395793>,
    <0.1396609, 0.3083825, 0.9409543>,
    <0.1456170, 0.3137512, 0.9382728>,
    <0.1472886, 0.3158716, 0.9373000>,
    <0.1458071, 0.3126970, 0.9385951>,
    <0.1458071, 0.3126970, 0.9385951>,
    <0.1351415, 0.2898303, 0.9474889>,
    <0.1470790, 0.3156578, 0.9374049>,
    <0.1462120, 0.3151327, 0.9377172>,
    <0.1472993, 0.3158830, 0.9372944>,
    <0.1473574, 0.3159585, 0.9372598>,
    <0.1472886, 0.3158716, 0.9373000>,
    <0.1466947, 0.3167667, 0.9370910>,
    <0.1473011, 0.3158859, 0.9372932>,
    <0.1031373, 0.2809277, 0.9541710>,
    <0.1489394, 0.3193980, 0.9358429>,
    <0.1489394, 0.3193980, 0.9358429>,
    <0.1473027, 0.3158882, 0.9372921>,
    <0.1474295, 0.3160894, 0.9372044>,
    <0.1473027, 0.3158882, 0.9372921>,
    <0.1473598, 0.3160106, 0.9372419>,
    <0.1473598, 0.3160106, 0.9372419>,
    <0.1468098, 0.2542807, 0.9559227>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.1420364, -0.3046098, 0.9418272>,
    <0.1420416, -0.3046050, 0.9418280>,
    <0.1420429, -0.3046088, 0.9418266>,
    <0.1420253, -0.3046286, 0.9418228>,
    <0.1419286, -0.3046573, 0.9418281>,
    <0.1419982, -0.3045803, 0.9418425>,
    <0.1420309, -0.3046144, 0.9418266>,
    <0.1420400, -0.3045983, 0.9418304>,
    <0.1420427, -0.3046055, 0.9418277>,
    <0.1221665, -0.2115946, 0.9696923>,
    <0.1420399, -0.3045968, 0.9418309>,
    <0.1420399, -0.3045968, 0.9418309>,
    <0.1420436, -0.3046046, 0.9418278>,
    <0.1420542, -0.3047077, 0.9417929>,
    <0.1420436, -0.3046046, 0.9418278>,
    <0.1421075, -0.3047416, 0.9417739>,
    <0.1421075, -0.3047416, 0.9417739>,
    <0.0901683, -0.2407529, 0.9663890>,
    <0.1418315, -0.3054259, 0.9415938>,
    <0.1418561, -0.3045087, 0.9418871>,
    <0.1415556, -0.3046257, 0.9418945>,
    <0.1410063, -0.3043849, 0.9420547>,
    <0.1412883, -0.3041125, 0.9421004>,
    <0.1416036, -0.3037401, 0.9421732>,
    <0.1419943, -0.3045567, 0.9418508>,
    <0.1419943, -0.3045567, 0.9418508>,
    <0.1420309, -0.3046144, 0.9418266>,
    <0.1399377, -0.3061130, 0.9416540>,
    <0.1386925, -0.3037931, 0.9425891>,
    <0.0901683, -0.2407529, 0.9663890>,
    <0.1285539, -0.3134388, 0.9408666>,
    <0.1298087, -0.3029111, 0.9441369>,
    <0.1394171, -0.3025594, 0.9428789>,
    <0.1317866, -0.2987575, 0.9451858>,
    <0.1314929, -0.2967533, 0.9458579>,
    <0.1404610, -0.3013064, 0.9431252>,
    <0.1404610, -0.3013064, 0.9431252>,
    <0.1416036, -0.3037401, 0.9421732>,
    <0.1082757, -0.3021469, 0.9470922>,
    <0.1082643, -0.3044810, 0.9463457>,
    <0.0952922, -0.3107187, 0.9457131>,
    <0.0919958, -0.3137881, 0.9450258>,
    <0.0847511, -0.3163665, 0.9448436>,
    <0.0795868, -0.2972074, 0.9514903>,
    <0.0795868, -0.2972074, 0.9514903>,
    <0.1314929, -0.2967533, 0.9458579>,
    <0.1024094, -0.3180812, 0.9425161>,
    <0.0907837, -0.3171439, 0.9440223>,
    <0.0901683, -0.2407529, 0.9663890>,
    <0.0935604, -0.3284661, 0.9398705>,
    <0.0885327, -0.3238732, 0.9419491>,
    <0.0877620, -0.3213940, 0.9428700>,
    <0.0870783, -0.3242140, 0.9419674>,
    <0.0870113, -0.3247309, 0.9417956>,
    <0.0867355, -0.3237238, 0.9421676>,
    <0.0867355, -0.3237238, 0.9421676>,
    <0.0847511, -0.3163665, 0.9448436>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0032915, 0.0072679, -0.9999682>,
    <-0.0025584, 0.0054865, -0.9999817>,
    <-0.0111193, 0.0238452, -0.9996538>,
    <-0.0156384, 0.0342546, -0.9992908>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0048925, 0.0101935, -0.9999361>,
    <-0.0231159, 0.0483486, -0.9985630>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0042449, 0.0101991, -0.9999390>,
    <-0.0319991, 0.0692725, -0.9970844>,
    <-0.0498876, 0.1057023, -0.9931456>,
    <-0.1632256, 0.3389468, -0.9265379>,
    <-0.0048337, -0.0111364, -0.9999263>,
    <-0.0221821, -0.0511644, -0.9984439>,
    <-0.0125585, -0.0284204, -0.9995172>,
    <-0.0029728, -0.0065926, -0.9999738>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0087444, -0.0171434, -0.9998148>,
    <-0.0370034, -0.0790718, -0.9961819>,
    <-0.0507806, -0.1199478, -0.9914806>,
    <-0.0183063, -0.0425342, -0.9989273>,
    <-0.1305824, -0.2992450, -0.9451988>,
    <-0.1903566, -0.5300642, 0.8263149>,
    <-0.0647468, -0.1775460, -0.9819803>,
    <-0.0180834, -0.0507151, -0.9985494>,
    <-0.0038830, -0.0086361, -0.9999552>,
    <-0.0037549, -0.0107085, -0.9999356>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0181048, -0.0382035, -0.9991060>,
    <-0.0725683, -0.1569823, -0.9849317>,
    <-0.1796841, -0.3822174, -0.9064345>,
    <-0.0855111, -0.1787548, -0.9801707>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.4224998, -0.8693109, 0.2565005>,
    <-0.3331206, -0.7090097, 0.6215593>,
    <-0.1680535, -0.3344051, 0.9273248>,
    <-0.1592764, -0.3364154, 0.9281464>,
    <-0.4117202, -0.9089519, -0.0655209>,
    <-0.1598951, -0.3611088, 0.9187132>,
    <-0.0158650, 0.0353292, -0.9992498>,
    <-0.0817104, 0.1818358, -0.9799281>,
    <-0.1592695, 0.3535870, -0.9217426>,
    <-0.0651274, 0.1453401, -0.9872359>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0074135, 0.0171723, -0.9998251>,
    <-0.0367398, 0.0888852, -0.9953641>,
    <-0.3917705, 0.9168160, -0.0772283>,
    <-0.3464915, 0.7682492, 0.5382720>,
    <-0.1641495, 0.4163087, -0.8942830>,
    <-0.1483207, 0.4500949, 0.8805768>,
    <-0.1567023, 0.3826723, 0.9104978>,
    <-0.1587538, 0.3546440, 0.9214254>,
    <-0.4217530, 0.8940965, 0.1507180>,
    <-0.1636075, 0.3425275, 0.9251527>,
    <-0.0043686, 0.0147388, -0.9998818>,
    <-0.0218968, 0.0691674, -0.9973647>,
    <-0.0129659, 0.0401332, -0.9991102>,
    <-0.0026364, 0.0087508, -0.9999582>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0047836, 0.0177393, -0.9998312>,
    <-0.0223177, 0.0794218, -0.9965912>,
    <-0.0640397, 0.1864866, -0.9803681>,
    <-0.0211334, 0.0620573, -0.9978488>,
    <-0.0950718, 0.3161701, -0.9439268>,
    <-0.0031547, 0.0105930, -0.9999389>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0032479, -0.0112550, -0.9999314>,
    <-0.0019808, -0.0071273, -0.9999726>,
    <-0.0088295, -0.0308596, -0.9994847>,
    <-0.0147372, -0.0502961, -0.9986256>,
    <-0.0148113, -0.0545453, -0.9984014>,
    <-0.0035670, -0.0132901, -0.9999053>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0025627, -0.0093784, -0.9999527>,
    <-0.0131750, -0.0451545, -0.9988931>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0347306, -0.1151555, -0.9927401>,
    <-0.0468546, -0.1668068, -0.9848757>,
    <0.0921789, -0.3384770, 0.9364488>,
    <0.0894655, -0.3307341, 0.9394737>,
    <0.0908001, -0.3329520, 0.9385618>,
    <0.0930278, -0.3379564, 0.9365529>,
    <0.0976455, -0.3484963, 0.9322101>,
    <0.0975651, -0.3519477, 0.9309210>,
    <0.0954287, -0.3561012, 0.9295619>,
    <0.0896091, -0.3343966, 0.9381626>,
    <0.0896091, -0.3343966, 0.9381626>,
    <0.0878459, -0.3278262, 0.9406450>,
    <0.0877821, -0.3263131, 0.9411770>,
    <0.0895766, -0.3291468, 0.9400204>,
    <0.0878459, -0.3278262, 0.9406450>,
    <0.0871136, -0.3251016, 0.9416582>,
    <0.0871136, -0.3251016, 0.9416582>,
    <0.0870113, -0.3247309, 0.9417956>,
    <0.0925931, -0.3339168, 0.9380437>,
    <0.0901683, -0.2407529, 0.9663890>,
    <0.0977651, -0.3455858, 0.9332805>,
    <-0.0031118, 0.0125735, -0.9999161>,
    <-0.0026218, 0.0097846, -0.9999487>,
    <-0.0118770, 0.0443249, -0.9989466>,
    <-0.0164890, 0.0642457, -0.9977979>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0049983, 0.0173658, -0.9998367>,
    <-0.0230111, 0.0824506, -0.9963295>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0036191, 0.0172966, -0.9998439>,
    <-0.0242548, 0.0968158, -0.9950067>,
    <-0.0544321, 0.1995342, -0.9783779>,
    <-0.1294377, 0.4786538, -0.8684103>,
    <-0.0039305, -0.0135072, -0.9999010>,
    <-0.0019732, -0.0073640, -0.9999709>,
    <-0.0084339, -0.0314760, -0.9994689>,
    <-0.0171981, -0.0607119, -0.9980072>,
    <-0.0211936, -0.0806739, -0.9965152>,
    <-0.0031657, -0.0147464, -0.9998863>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0023156, -0.0093760, -0.9999534>,
    <-0.0111296, -0.0437500, -0.9989805>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0348802, -0.1270146, -0.9912874>,
    <-0.1037009, -0.3612097, -0.9267004>,
    <0.0918173, 0.3410401, 0.9355540>,
    <0.0923934, 0.3415138, 0.9353244>,
    <0.0916482, 0.3391451, 0.9362592>,
    <0.0909165, 0.3378149, 0.9368113>,
    <0.0901991, 0.3365717, 0.9373279>,
    <0.0910156, 0.3396194, 0.9361489>,
    <0.0910156, 0.3396194, 0.9361489>,
    <0.0927550, 0.3461120, 0.9335968>,
    <0.0935261, 0.3457717, 0.9336460>,
    <0.0937610, 0.3453774, 0.9337683>,
    <0.0943562, 0.3428340, 0.9346452>,
    <0.0916832, 0.3362754, 0.9372903>,
    <0.0948322, 0.3467674, 0.9331448>,
    <0.1031373, 0.2809277, 0.9541710>,
    <0.0900921, 0.3338572, 0.9383085>,
    <0.0887869, 0.3232892, 0.9421258>,
    <0.0892053, 0.3328625, 0.9387465>,
    <0.0892053, 0.3328625, 0.9387465>,
    <0.0901991, 0.3365717, 0.9373279>,
    <0.0463074, 0.3332644, 0.9416955>,
    <0.0489013, 0.3353331, 0.9408296>,
    <0.0646702, 0.3282740, 0.9423661>,
    <0.0717638, 0.3308005, 0.9409681>,
    <0.0869254, 0.3243658, 0.9419293>,
    <0.0709762, 0.2648618, 0.9616707>,
    <0.0709762, 0.2648618, 0.9616707>,
    <0.0330254, 0.3523305, 0.9352927>,
    <0.0334754, 0.3535173, 0.9348288>,
    <0.0362005, 0.3555820, 0.9339438>,
    <0.0664826, 0.3573843, 0.9315882>,
    <0.0779162, 0.3362965, 0.9385274>,
    <0.0442999, 0.3768401, 0.9252184>,
    <0.0509593, 0.2921817, 0.9550042>,
    <0.0905637, 0.3638979, 0.9270256>,
    <0.0908720, 0.3474224, 0.9332952>,
    <0.0886781, 0.3432405, 0.9350520>,
    <0.0937878, 0.3480285, 0.9327808>,
    <0.0927550, 0.3461120, 0.9335968>,
    <0.0935261, 0.3489927, 0.9324468>,
    <0.0935261, 0.3489927, 0.9324468>,
    <0.0869254, 0.3243658, 0.9419293>,
    <0.0949032, 0.3492846, 0.9321983>,
    <0.0951883, 0.3511412, 0.9314714>,
    <0.0959482, 0.3514354, 0.9312825>,
    <0.0951510, 0.3491889, 0.9322089>,
    <0.0927550, 0.3461120, 0.9335968>,
    <0.0961808, 0.3550681, 0.9298795>,
    <0.0964894, 0.3527954, 0.9307122>,
    <0.0509593, 0.2921817, 0.9550042>,
    <0.0984050, 0.3591723, 0.9280688>,
    <0.0984050, 0.3591723, 0.9280688>,
    <0.0969519, 0.3538686, 0.9302566>,
    <0.0956694, 0.3501211, 0.9318061>,
    <0.0969519, 0.3538686, 0.9302566>,
    <0.0963475, 0.3516626, 0.9311555>,
    <0.0963475, 0.3516626, 0.9311555>,
    <0.1031373, 0.2809277, 0.9541710>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.1018670, -0.3614524, 0.9268092>,
    <0.1017767, -0.3586691, 0.9278998>,
    <0.1037990, -0.3641778, 0.9255271>,
    <0.1046176, -0.3673558, 0.9241780>,
    <0.1053269, -0.3732751, 0.9217223>,
    <0.1022178, -0.3669034, 0.9246261>,
    <0.0954287, -0.3561012, 0.9295619>,
    <0.1025865, -0.3586552, 0.9278160>,
    <0.1049437, -0.3662144, 0.9245939>,
    <0.0901683, -0.2407529, 0.9663890>,
    <0.1039999, -0.3609755, 0.9267582>,
    <0.1039999, -0.3609755, 0.9267582>,
    <0.1059709, -0.3678167, 0.9238404>,
    <0.1066389, -0.3717916, 0.9221709>,
    <0.1059709, -0.3678167, 0.9238404>,
    <0.1074674, -0.3730110, 0.9215821>,
    <0.1074674, -0.3730110, 0.9215821>,
    <0.0468352, -0.2585849, 0.9648525>,
    <0.1073682, -0.3790622, 0.9191213>,
    <0.1027509, -0.3878013, 0.9159981>,
    <0.1042645, -0.3853460, 0.9168628>,
    <0.1046919, -0.3839421, 0.9174029>,
    <0.1023926, -0.3859155, 0.9168342>,
    <0.0915027, -0.3856358, 0.9181026>,
    <0.0940494, -0.3819688, 0.9193772>,
    <0.0939886, -0.3795478, 0.9203856>,
    <0.1039381, -0.3878016, 0.9158640>,
    <0.1039381, -0.3878016, 0.9158640>,
    <0.1039202, -0.3877515, 0.9158872>,
    <0.1033849, -0.3778316, 0.9200842>,
    <0.1051976, -0.3802762, 0.9188708>,
    <0.1039202, -0.3877515, 0.9158872>,
    <0.1019410, -0.3803856, 0.9191925>,
    <0.1019410, -0.3803856, 0.9191925>,
    <0.0954287, -0.3561012, 0.9295619>,
    <0.1047821, -0.3863066, 0.9163994>,
    <0.0468352, -0.2585849, 0.9648525>,
    <0.0891624, -0.3984479, 0.9128468>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0652507, -0.3805078, 0.9224728>,
    <0.0649487, -0.3833223, 0.9213282>,
    <0.0481035, -0.3887475, 0.9200878>,
    <0.0435931, -0.3920721, 0.9189010>,
    <0.0344538, -0.3936016, 0.9186353>,
    <0.0320481, -0.3658712, 0.9301135>,
    <0.0320481, -0.3658712, 0.9301135>,
    <0.0939886, -0.3795478, 0.9203856>,
    <0.0548953, -0.3994595, 0.9151058>,
    <0.0411756, -0.3956768, 0.9174663>,
    <0.0468352, -0.2585849, 0.9648525>,
    <0.0396283, -0.4061690, 0.9129383>,
    <0.0363584, -0.4014820, 0.9151449>,
    <0.0370182, -0.4012961, 0.9152000>,
    <0.0355183, -0.4042864, 0.9139425>,
    <0.0355095, -0.4058343, 0.9132566>,
    <0.0353854, -0.4043619, 0.9139143>,
    <0.0353854, -0.4043619, 0.9139143>,
    <0.0344538, -0.3936016, 0.9186353>,
    <-0.0035514, -0.0157821, -0.9998691>,
    <-0.0159300, -0.0759071, -0.9969876>,
    <-0.0095734, -0.0470199, -0.9988481>,
    <-0.0022402, -0.0103652, -0.9999438>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0047496, -0.0178832, -0.9998288>,
    <-0.0205885, -0.0817759, -0.9964381>,
    <-0.0348651, -0.1914857, -0.9808760>,
    <-0.0140624, -0.0837045, -0.9963914>,
    <-0.0686982, -0.3000469, -0.9514475>,
    <-0.0980421, -0.5094945, 0.8548702>,
    <-0.0508823, -0.3922878, -0.9184341>,
    <-0.0207599, -0.2107538, -0.9773187>,
    <-0.0035847, -0.0235799, -0.9997155>,
    <-0.0090986, -0.1233643, 0.9923197>,
    <0.0790764, 0.2951176, 0.9521830>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0037223, -0.0119385, -0.9999218>,
    <-0.0026244, -0.0097947, -0.9999486>,
    <-0.0119319, -0.0445315, -0.9989367>,
    <-0.0185771, -0.0642568, -0.9977605>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0039995, -0.0169059, -0.9998491>,
    <-0.0204399, -0.0811607, -0.9964914>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0067639, -0.0204570, -0.9997679>,
    <-0.0301198, -0.1046574, -0.9940521>,
    <-0.0522908, -0.1993081, -0.9785407>,
    <-0.1255843, -0.4754200, -0.8707493>,
    <-0.0123119, -0.0439104, -0.9989596>,
    <-0.0458977, -0.1762042, -0.9832830>,
    <-0.1272217, -0.4608399, -0.8783173>,
    <-0.0637669, -0.2174542, -0.9739854>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.2644989, -0.9297080, 0.2562877>,
    <-0.1938323, -0.7024340, 0.6848471>,
    <-0.1088784, -0.3605068, 0.9263802>,
    <-0.0990627, -0.3552171, 0.9295200>,
    <-0.2485387, -0.9249688, 0.2875088>,
    <-0.0950007, -0.3714587, 0.9235764>,
    <-0.0099214, 0.0399909, -0.9991508>,
    <-0.0453786, 0.1696671, -0.9844561>,
    <-0.1015748, 0.3962764, -0.9124953>,
    <-0.0436060, 0.1810439, -0.9825078>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0046251, 0.0150573, -0.9998759>,
    <-0.0189267, 0.0715225, -0.9972594>,
    <-0.2357315, 0.9616839, -0.1399816>,
    <-0.2026386, 0.7866445, 0.5832049>,
    <-0.0619072, 0.2621514, -0.9630390>,
    <-0.0990493, 0.6401556, 0.7618333>,
    <-0.0917126, 0.3990217, 0.9123434>,
    <-0.0962295, 0.3761335, 0.9215549>,
    <-0.2527324, 0.9508016, 0.1791722>,
    <-0.1040939, 0.3747042, 0.9212824>,
    <-0.0022732, 0.0075826, -0.9999687>,
    <-0.0097377, 0.0339595, -0.9993758>,
    <-0.0064555, 0.0240921, -0.9996889>,
    <-0.0015473, 0.0057746, -0.9999821>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0027602, 0.0103441, -0.9999427>,
    <-0.0105607, 0.0406652, -0.9991170>,
    <-0.0238222, 0.0937777, -0.9953081>,
    <-0.0111876, 0.0456040, -0.9988969>,
    <-0.0285726, 0.1174955, -0.9926623>,
    <-0.0024088, 0.0100975, -0.9999461>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0017604, 0.0072710, -0.9999720>,
    <-0.0074697, 0.0354226, -0.9993445>,
    <-0.0053046, 0.0239413, -0.9996993>,
    <-0.0013396, 0.0055902, -0.9999835>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0012900, 0.0095575, -0.9999535>,
    <-0.0059618, 0.0437459, -0.9990249>,
    <-0.0176684, 0.0871281, -0.9960404>,
    <-0.0081650, 0.0381666, -0.9992380>,
    <-0.0200580, 0.1433723, -0.9894655>,
    <-0.0019593, 0.0087838, -0.9999595>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0009780, 0.0092767, -0.9999565>,
    <-0.0044803, 0.0421855, -0.9990998>,
    <-0.0024905, 0.0258755, -0.9996621>,
    <-0.0005470, 0.0059330, -0.9999823>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0009596, 0.0109423, -0.9999397>,
    <-0.0041136, 0.0461379, -0.9989266>,
    <-0.0102896, 0.0997882, -0.9949555>,
    <-0.0035129, 0.0387524, -0.9992427>,
    <-0.0143089, 0.1516844, -0.9883254>,
    <-0.0006517, 0.0081277, -0.9999668>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0005226, 0.0076878, -0.9999703>,
    <-0.0005275, 0.0060296, -0.9999817>,
    <-0.0022914, 0.0261905, -0.9996543>,
    <-0.0027473, 0.0368994, -0.9993152>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0012414, 0.0114799, -0.9999333>,
    <-0.0055185, 0.0535370, -0.9985506>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0006503, 0.0134763, -0.9999090>,
    <-0.0067856, 0.0782208, -0.9969130>,
    <-0.0109714, 0.1163006, -0.9931535>,
    <-0.0361350, 0.3488823, -0.9364697>,
    <0.0338445, -0.3961318, 0.9175697>,
    <0.0346408, -0.4014225, 0.9152377>,
    <0.0340862, -0.3997969, 0.9159697>,
    <0.0333179, -0.3963483, 0.9174955>,
    <0.0318507, -0.3895699, 0.9204460>,
    <0.0322335, -0.3876505, 0.9212427>,
    <0.0337369, -0.3856153, 0.9220427>,
    <0.0349103, -0.3990244, 0.9162755>,
    <0.0349103, -0.3990244, 0.9162755>,
    <0.0353102, -0.4035893, 0.9142586>,
    <0.0352319, -0.4044280, 0.9138910>,
    <0.0347338, -0.4016229, 0.9151462>,
    <0.0353102, -0.4035893, 0.9142586>,
    <0.0354836, -0.4055616, 0.9133787>,
    <0.0354836, -0.4055616, 0.9133787>,
    <0.0355095, -0.4058343, 0.9132566>,
    <0.0339432, -0.3995141, 0.9160985>,
    <0.0468352, -0.2585849, 0.9648525>,
    <0.0316933, -0.3916132, 0.9195839>,
    <0.0308841, 0.3588684, 0.9328771>,
    <0.0307308, 0.3594065, 0.9326750>,
    <0.0315499, 0.3624493, 0.9314693>,
    <0.0316871, 0.3631199, 0.9312034>,
    <0.0318552, 0.3640745, 0.9308249>,
    <0.0316160, 0.3613423, 0.9318971>,
    <0.0316160, 0.3613423, 0.9318971>,
    <0.0306517, 0.3503228, 0.9361274>,
    <0.0293436, 0.3506289, 0.9360547>,
    <0.0291207, 0.3520712, 0.9355201>,
    <0.0328029, 0.3654867, 0.9302384>,
    <0.0326962, 0.3627413, 0.9313161>,
    <0.0294894, 0.3556846, 0.9341407>,
    <0.0509593, 0.2921817, 0.9550042>,
    <0.0322182, 0.3627641, 0.9313239>,
    <0.0330254, 0.3523305, 0.9352927>,
    <0.0317154, 0.3624775, 0.9314527>,
    <0.0317154, 0.3624775, 0.9314527>,
    <0.0318552, 0.3640745, 0.9308249>,
    <-0.0117288, 0.3099829, 0.9506698>,
    <-0.0103240, 0.3131629, 0.9496433>,
    <0.0044384, 0.3106646, 0.9505092>,
    <0.0109793, 0.3136926, 0.9494611>,
    <0.0270655, 0.3093458, 0.9505644>,
    <0.0222657, 0.2545037, 0.9668155>,
    <0.0222657, 0.2545037, 0.9668155>,
    <-0.0262069, 0.3225463, 0.9461908>,
    <-0.0260316, 0.3240708, 0.9456746>,
    <-0.0240492, 0.3272646, 0.9446266>,
    <0.0009122, 0.3332506, 0.9428379>,
    <0.0144786, 0.3202256, 0.9472307>,
    <-0.0201863, 0.3456513, 0.9381459>,
    <-0.0013354, 0.2871748, 0.9578773>,
    <0.0195342, 0.3423717, 0.9393615>,
    <0.0232621, 0.3332211, 0.9425617>,
    <0.0240534, 0.3301867, 0.9436091>,
    <0.0273116, 0.3401815, 0.9399631>,
    <0.0306517, 0.3503228, 0.9361274>,
    <0.0294345, 0.3364143, 0.9412540>,
    <0.0294345, 0.3364143, 0.9412540>,
    <0.0270655, 0.3093458, 0.9505644>,
    <0.0278076, 0.3440234, 0.9385492>,
    <0.0262551, 0.3391001, 0.9403839>,
    <0.0271538, 0.3412649, 0.9395749>,
    <0.0278025, 0.3451046, 0.9381523>,
    <0.0306517, 0.3503228, 0.9361274>,
    <0.0255882, 0.3375244, 0.9409689>,
    <0.0267273, 0.3391348, 0.9403580>,
    <-0.0013354, 0.2871748, 0.9578773>,
    <0.0264898, 0.3393567, 0.9402847>,
    <0.0264898, 0.3393567, 0.9402847>,
    <0.0263428, 0.3374735, 0.9409664>,
    <0.0273242, 0.3439347, 0.9385959>,
    <0.0263428, 0.3374735, 0.9409664>,
    <0.0266328, 0.3411885, 0.9396175>,
    <0.0266328, 0.3411885, 0.9396175>,
    <0.0509593, 0.2921817, 0.9550042>,
    <0.0097278, 0.1032964, -0.9946030>,
    <0.0034987, 0.0376831, -0.9992836>,
    <0.0064550, 0.0647675, -0.9978795>,
    <0.0107875, 0.1019333, -0.9947327>,
    <0.0160035, 0.1447095, -0.9893448>,
    <0.0168779, 0.1510425, -0.9883832>,
    <0.0790764, 0.2951176, 0.9521830>,
    <0.0069973, 0.0852378, -0.9963361>,
    <-0.0007022, -0.0124540, -0.9999222>,
    <0.0008928, -0.0024534, -0.9999966>,
    <0.0039792, 0.0330961, -0.9994443>,
    <-0.0003245, -0.1258402, -0.9920505>,
    <0.0577420, -0.6599551, -0.7490828>,
    <0.0005103, -0.0025837, -0.9999965>,
    <0.0022194, 0.0059115, -0.9999801>,
    <0.0104019, 0.0681854, -0.9976184>,
    <0.0063989, 0.0196062, -0.9997873>,
    <-0.0492868, 0.8189163, -0.5717927>,
    <0.0169716, 0.1356342, -0.9906136>,
    <-0.0160617, -0.2070647, -0.9781954>,
    <-0.0445858, -0.5778120, -0.8149512>,
    <-0.0603304, -0.9979313, 0.0222113>,
    <-0.0402444, -0.8028584, -0.5948099>,
    <0.0790764, 0.2951176, 0.9521830>,
    <-0.0941327, -0.9782410, -0.1848882>,
    <-0.0413127, -0.7453180, 0.6654279>,
    <-0.0480987, -0.4274813, 0.9027438>,
    <-0.0219740, -0.3900566, 0.9205286>,
    <-0.0154436, -0.7131292, 0.7008625>,
    <-0.0065314, -0.3587786, 0.9333998>,
    <0.0577420, -0.6599551, -0.7490828>,
    <-0.0042599, 0.0434300, -0.9990474>,
    <-0.0178653, 0.1854502, -0.9824912>,
    <-0.0335525, 0.3910630, -0.9197521>,
    <-0.0139675, 0.1745691, -0.9845459>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0026693, 0.0211863, -0.9997720>,
    <-0.0083781, 0.0921572, -0.9957092>,
    <-0.0638413, 0.9738010, -0.2182564>,
    <-0.0685067, 0.8545253, 0.5148722>,
    <-0.0176783, 0.3215873, -0.9467149>,
    <0.0142216, 0.4736573, 0.8805944>,
    <-0.0167147, 0.4010698, 0.9158950>,
    <-0.0283832, 0.3873152, 0.9215104>,
    <-0.0940815, 0.9951711, 0.0279838>,
    <-0.0381416, 0.3893531, 0.9202985>,
    <-0.0029548, -0.0078173, -0.9999651>,
    <-0.0029079, 0.0544985, -0.9985096>,
    <-0.0026374, 0.0399910, -0.9991966>,
    <-0.0006808, 0.0095818, -0.9999539>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0004073, -0.0046545, 0.9999891>,
    <0.0004073, -0.0046545, 0.9999891>,
    <0.0614190, -0.7019994, 0.7095241>,
    <-0.0083207, -0.1298518, -0.9914985>,
    <-0.0000306, 0.0501734, -0.9987405>,
    <-0.0057231, 0.1422600, -0.9898128>,
    <-0.0043174, 0.0675871, -0.9977040>,
    <0.0076173, 0.2339777, -0.9722121>,
    <-0.0009926, 0.0155599, -0.9998784>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0309467, -0.3821537, 0.9235805>,
    <0.0307244, -0.3836087, 0.9229845>,
    <0.0302602, -0.3806001, 0.9242445>,
    <0.0301330, -0.3789557, 0.9249241>,
    <0.0301972, -0.3760114, 0.9261229>,
    <0.0312594, -0.3792820, 0.9247530>,
    <0.0337369, -0.3856153, 0.9220427>,
    <0.0303134, -0.3835360, 0.9230283>,
    <0.0298993, -0.3794838, 0.9247151>,
    <0.0468352, -0.2585849, 0.9648525>,
    <0.0298388, -0.3821997, 0.9235979>,
    <0.0298388, -0.3821997, 0.9235979>,
    <0.0295582, -0.3786060, 0.9250859>,
    <0.0295880, -0.3767966, 0.9258234>,
    <0.0295582, -0.3786060, 0.9250859>,
    <0.0293740, -0.3762465, 0.9260539>,
    <0.0293740, -0.3762465, 0.9260539>,
    <-0.0024110, -0.2597755, 0.9656660>,
    <0.0291856, -0.3744226, 0.9267987>,
    <0.0315222, -0.3737332, 0.9270004>,
    <0.0303475, -0.3724834, 0.9275425>,
    <0.0301936, -0.3701199, 0.9284932>,
    <0.0311101, -0.3692396, 0.9288134>,
    <0.0321765, -0.3677839, 0.9293544>,
    <0.0326207, -0.3728593, 0.9273143>,
    <0.0326207, -0.3728593, 0.9273143>,
    <0.0337369, -0.3856153, 0.9220427>,
    <0.0277109, -0.3713660, 0.9280729>,
    <0.0281449, -0.3669871, 0.9298002>,
    <-0.0024110, -0.2597755, 0.9656660>,
    <0.0138016, -0.3724326, 0.9279566>,
    <0.0197422, -0.3609746, 0.9323666>,
    <0.0299672, -0.3645020, 0.9307203>,
    <0.0236775, -0.3565492, 0.9339765>,
    <0.0241638, -0.3540275, 0.9349228>,
    <0.0317519, -0.3629329, 0.9312741>,
    <0.0317519, -0.3629329, 0.9312741>,
    <0.0321765, -0.3677839, 0.9293544>,
    <-0.0017339, -0.3506837, 0.9364924>,
    <-0.0027176, -0.3534122, 0.9354637>,
    <-0.0182781, -0.3549303, 0.9347141>,
    <-0.0228216, -0.3570128, 0.9338207>,
    <-0.0312281, -0.3569506, 0.9336011>,
    <-0.0291905, -0.3336754, 0.9422360>,
    <-0.0291905, -0.3336754, 0.9422360>,
    <0.0241638, -0.3540275, 0.9349228>,
    <-0.0143591, -0.3653602, 0.9307555>,
    <-0.0255269, -0.3596340, 0.9327442>,
    <-0.0024110, -0.2597755, 0.9656660>,
    <-0.0285923, -0.3681505, 0.9293265>,
    <-0.0307071, -0.3637138, 0.9310045>,
    <-0.0300931, -0.3636530, 0.9310483>,
    <-0.0318810, -0.3658955, 0.9301097>,
    <-0.0321226, -0.3671643, 0.9296013>,
    <-0.0320147, -0.3659349, 0.9300896>,
    <-0.0320147, -0.3659349, 0.9300896>,
    <-0.0312281, -0.3569506, 0.9336011>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0016786, 0.0021137, -0.9999964>,
    <0.0009853, -0.0000261, -0.9999995>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0005818, -0.0032105, -0.9999947>,
    <0.0005818, -0.0032105, -0.9999947>,
    <-0.0492868, 0.8189163, -0.5717927>,
    <0.0001738, -0.0004769, -0.9999999>,
    <0.0577420, -0.6599551, -0.7490828>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0577420, -0.6599551, -0.7490828>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0321415, -0.3589672, 0.9327966>,
    <-0.0322296, -0.3634247, 0.9310659>,
    <-0.0324792, -0.3620106, 0.9316080>,
    <-0.0326446, -0.3590672, 0.9327406>,
    <-0.0329328, -0.3532751, 0.9349396>,
    <-0.0323001, -0.3517526, 0.9355356>,
    <-0.0306477, -0.3503039, 0.9361346>,
    <-0.0316271, -0.3614979, 0.9318364>,
    <-0.0316271, -0.3614979, 0.9318364>,
    <-0.0319595, -0.3652981, 0.9303418>,
    <-0.0321565, -0.3659729, 0.9300698>,
    <-0.0321772, -0.3636007, 0.9309990>,
    <-0.0319595, -0.3652981, 0.9303418>,
    <-0.0321030, -0.3669384, 0.9296911>,
    <-0.0321030, -0.3669384, 0.9296911>,
    <-0.0321226, -0.3671643, 0.9296013>,
    <-0.0325639, -0.3617561, 0.9317039>,
    <-0.0024110, -0.2597755, 0.9656660>,
    <-0.0333822, -0.3549325, 0.9342957>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0024909, 0.0010226, -0.9999964>,
    <0.0207787, 0.1107735, -0.9936284>,
    <0.0523771, 0.3289533, -0.9428925>,
    <0.0227797, 0.1553066, -0.9876036>,
    <0.0084803, 0.0640900, -0.9979081>,
    <-0.0080247, -0.0825592, -0.9965539>,
    <-0.0976161, -0.3643092, 0.9261479>,
    <0.0004500, -0.0020833, -0.9999977>,
    <0.0055189, 0.0217018, -0.9997493>,
    <0.1331154, 0.6219369, -0.7716701>,
    <0.1466364, 0.9891263, 0.0112668>,
    <0.0214430, 0.0759571, -0.9968805>,
    <0.0725866, 0.2708977, 0.9598675>,
    <0.0869315, 0.4247909, 0.9011080>,
    <0.0585554, 0.4118420, 0.9093720>,
    <0.0960396, 0.9632310, -0.2509230>,
    <0.0337027, 0.4007515, 0.9155667>,
    <0.0344270, 0.4015008, -0.9152114>,
    <-0.0140599, -0.1384242, -0.9902732>,
    <-0.0016128, -0.0220501, -0.9997556>,
    <-0.0078855, -0.0909129, -0.9958276>,
    <-0.0141582, -0.1616060, -0.9867538>,
    <-0.0150520, -0.1671277, -0.9858204>,
    <-0.0190290, -0.1673833, -0.9857082>,
    <-0.0976161, -0.3643092, 0.9261479>,
    <0.0114820, 0.1465386, -0.9891383>,
    <-0.0026586, -0.0235729, -0.9997186>,
    <-0.0111303, -0.1618486, -0.9867528>,
    <0.0614190, -0.7019994, 0.7095241>,
    <-0.0110011, -0.1765828, -0.9842243>,
    <-0.0292265, 0.3347745, 0.9418449>,
    <-0.0290821, 0.3353081, 0.9416596>,
    <-0.0289145, 0.3349028, 0.9418089>,
    <-0.0290488, 0.3342532, 0.9420355>,
    <-0.0291993, 0.3337386, 0.9422133>,
    <-0.0292835, 0.3346815, 0.9418762>,
    <-0.0292835, 0.3346815, 0.9418762>,
    <-0.0292988, 0.3348091, 0.9418304>,
    <-0.0292781, 0.3348084, 0.9418313>,
    <-0.0292310, 0.3351189, 0.9417223>,
    <-0.0279527, 0.3384144, 0.9405819>,
    <-0.0279775, 0.3336171, 0.9422934>,
    <-0.0290112, 0.3372211, 0.9409784>,
    <-0.0013354, 0.2871748, 0.9578773>,
    <-0.0285113, 0.3318663, 0.9428955>,
    <-0.0262069, 0.3225463, 0.9461908>,
    <-0.0289585, 0.3309956, 0.9431878>,
    <-0.0289585, 0.3309956, 0.9431878>,
    <-0.0291993, 0.3337386, 0.9422133>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0293705, 0.3345303, 0.9419272>,
    <-0.0298443, 0.3336916, 0.9422098>,
    <-0.0292936, 0.3348090, 0.9418306>,
    <-0.0292808, 0.3349044, 0.9417970>,
    <-0.0292988, 0.3348091, 0.9418304>,
    <-0.0296811, 0.3323002, 0.9427065>,
    <-0.0321884, 0.3287089, 0.9438826>,
    <-0.0302239, 0.3352344, 0.9416498>,
    <-0.0292929, 0.3348070, 0.9418313>,
    <-0.0374681, 0.3399844, 0.9396844>,
    <-0.0495151, 0.2839044, 0.9575732>,
    <-0.0296082, 0.3384166, 0.9405305>,
    <-0.0296082, 0.3384166, 0.9405305>,
    <-0.0292924, 0.3348070, 0.9418313>,
    <-0.0292830, 0.3350392, 0.9417490>,
    <-0.0292924, 0.3348070, 0.9418313>,
    <-0.0293037, 0.3349365, 0.9417849>,
    <-0.0293037, 0.3349365, 0.9417849>,
    <-0.0013354, 0.2871748, 0.9578773>,
    <-0.0649770, 0.3025295, 0.9509227>,
    <-0.0636225, 0.3054090, 0.9500934>,
    <-0.0481703, 0.3047581, 0.9512109>,
    <-0.0426072, 0.3089034, 0.9501386>,
    <-0.0269873, 0.3080143, 0.9509989>,
    <-0.0223716, 0.2545535, 0.9667999>,
    <-0.0223716, 0.2545535, 0.9667999>,
    <-0.0818600, 0.3132109, 0.9461490>,
    <-0.0818869, 0.3145933, 0.9456879>,
    <-0.0802683, 0.3179839, 0.9446921>,
    <-0.0554141, 0.3278584, 0.9431003>,
    <-0.0394513, 0.3154150, 0.9481334>,
    <-0.0794552, 0.3378819, 0.9378287>,
    <-0.0495151, 0.2839044, 0.9575732>,
    <-0.0320939, 0.3251527, 0.9451168>,
    <-0.0292988, 0.3348091, 0.9418304>,
    <-0.0290228, 0.3315411, 0.9429943>,
    <-0.0290228, 0.3315411, 0.9429943>,
    <-0.0269873, 0.3080143, 0.9509989>,
    <-0.0308244, -0.3322766, 0.9426782>,
    <-0.0305174, -0.3363827, 0.9412308>,
    <-0.0314739, -0.3369667, 0.9409903>,
    <-0.0328391, -0.3340480, 0.9419838>,
    <-0.0394839, -0.3277253, 0.9439476>,
    <-0.0352749, -0.3246720, 0.9451686>,
    <-0.0344552, -0.3226514, 0.9458905>,
    <-0.0289816, -0.3312590, 0.9430947>,
    <-0.0289816, -0.3312590, 0.9430947>,
    <-0.0293392, -0.3353467, 0.9416378>,
    <-0.0308297, -0.3401636, 0.9398608>,
    <-0.0316941, -0.3389466, 0.9402716>,
    <-0.0293392, -0.3353467, 0.9416378>,
    <-0.0297125, -0.3396136, 0.9400956>,
    <-0.0297125, -0.3396136, 0.9400956>,
    <-0.0306477, -0.3503039, 0.9361346>,
    <-0.0319062, -0.3447052, 0.9381686>,
    <-0.0323635, -0.3418398, 0.9392008>,
    <-0.0338927, -0.3376070, 0.9406768>,
    <-0.0330311, -0.3403686, 0.9397117>,
    <-0.0443526, -0.2475074, 0.9678703>,
    <-0.0464956, -0.3363792, 0.9405781>,
    <-0.0326212, -0.3470268, 0.9372877>,
    <-0.0330405, -0.3481930, 0.9368404>,
    <-0.0330016, -0.3456396, 0.9377868>,
    <-0.0328669, -0.3442623, 0.9382981>,
    <-0.0306477, -0.3503039, 0.9361346>,
    <-0.0333980, -0.3480703, 0.9368733>,
    <-0.0331566, -0.3446624, 0.9381410>,
    <-0.0024110, -0.2597755, 0.9656660>,
    <-0.0336217, -0.3468952, 0.9373011>,
    <-0.0336217, -0.3468952, 0.9373011>,
    <-0.0333299, -0.3438847, 0.9384202>,
    <-0.0330292, -0.3423942, 0.9389757>,
    <-0.0333299, -0.3438847, 0.9384202>,
    <-0.0331381, -0.3419062, 0.9391496>,
    <-0.0331381, -0.3419062, 0.9391496>,
    <-0.0443526, -0.2475074, 0.9678703>,
    <-0.0572795, -0.3157519, 0.9471113>,
    <-0.0585702, -0.3178665, 0.9463247>,
    <-0.0727987, -0.3166627, 0.9457405>,
    <-0.0771833, -0.3176825, 0.9450506>,
    <-0.0847337, -0.3163084, 0.9448646>,
    <-0.0795863, -0.2971884, 0.9514962>,
    <-0.0795863, -0.2971884, 0.9514962>,
    <-0.0344552, -0.3226514, 0.9458905>,
    <-0.0706489, -0.3263309, 0.9426117>,
    <-0.0799603, -0.3196836, 0.9441445>,
    <-0.0443526, -0.2475074, 0.9678703>,
    <-0.0836151, -0.3284249, 0.9408218>,
    <-0.0852347, -0.3232445, 0.9424691>,
    <-0.0846638, -0.3220947, 0.9429141>,
    <-0.0866268, -0.3239126, 0.9421127>,
    <-0.0869849, -0.3246474, 0.9418268>,
    <-0.0867118, -0.3236481, 0.9421958>,
    <-0.0867118, -0.3236481, 0.9421958>,
    <-0.0847337, -0.3163084, 0.9448646>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0036948, 0.0098478, -0.9999447>,
    <0.0017039, 0.0037529, -0.9999915>,
    <0.0012314, 0.0028369, -0.9999952>,
    <0.0725866, 0.2708977, 0.9598675>,
    <0.0001617, -0.0009015, -0.9999996>,
    <-0.0976161, -0.3643092, 0.9261479>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0725866, 0.2708977, 0.9598675>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0725866, 0.2708977, 0.9598675>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0874558, -0.3274515, 0.9408119>,
    <-0.0871620, -0.3259118, 0.9413736>,
    <-0.0871515, -0.3264132, 0.9412008>,
    <-0.0872621, -0.3274491, 0.9408307>,
    <-0.0874996, -0.3295540, 0.9400734>,
    <-0.0878357, -0.3300768, 0.9398586>,
    <-0.0885658, -0.3305102, 0.9396378>,
    <-0.0874964, -0.3265309, 0.9411280>,
    <-0.0874964, -0.3265309, 0.9411280>,
    <-0.0871531, -0.3252576, 0.9416007>,
    <-0.0869721, -0.3249285, 0.9417310>,
    <-0.0867392, -0.3254009, 0.9415894>,
    <-0.0871531, -0.3252576, 0.9416007>,
    <-0.0870069, -0.3247191, 0.9418000>,
    <-0.0870069, -0.3247191, 0.9418000>,
    <-0.0869849, -0.3246474, 0.9418268>,
    <-0.0866848, -0.3270721, 0.9410152>,
    <-0.0443526, -0.2475074, 0.9678703>,
    <-0.0871716, -0.3292953, 0.9401945>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0874813, 0.3275675, 0.9407691>,
    <-0.0872925, 0.3281865, 0.9405709>,
    <-0.0868801, 0.3265475, 0.9411794>,
    <-0.0868737, 0.3253773, 0.9415851>,
    <-0.0869001, 0.3243010, 0.9419540>,
    <-0.0874929, 0.3265136, 0.9411344>,
    <-0.0874929, 0.3265136, 0.9411344>,
    <-0.0885860, 0.3305936, 0.9396065>,
    <-0.0880422, 0.3306555, 0.9396358>,
    <-0.0877893, 0.3306243, 0.9396705>,
    <-0.0864071, 0.3306099, 0.9398036>,
    <-0.0855531, 0.3246101, 0.9419708>,
    <-0.0876796, 0.3324301, 0.9390434>,
    <-0.0495151, 0.2839044, 0.9575732>,
    <-0.0857641, 0.3222221, 0.9427711>,
    <-0.0818600, 0.3132109, 0.9461490>,
    <-0.0860433, 0.3211031, 0.9431274>,
    <-0.0860433, 0.3211031, 0.9431274>,
    <-0.0869001, 0.3243010, 0.9419540>,
    <-0.0883956, 0.3328604, 0.9388238>,
    <-0.0889270, 0.3336208, 0.9385037>,
    <-0.0884821, 0.3344258, 0.9382592>,
    <-0.0882206, 0.3330186, 0.9387842>,
    <-0.0885860, 0.3305936, 0.9396065>,
    <-0.0885902, 0.3310755, 0.9394364>,
    <-0.0906356, 0.3284783, 0.9401528>,
    <-0.0898247, 0.3365000, 0.9373896>,
    <-0.0886083, 0.3353127, 0.9379307>,
    <-0.0983782, 0.3405981, 0.9350480>,
    <-0.0995537, 0.2751030, 0.9562465>,
    <-0.0898622, 0.3404706, 0.9359512>,
    <-0.0898622, 0.3404706, 0.9359512>,
    <-0.0886881, 0.3360219, 0.9376693>,
    <-0.0882346, 0.3337221, 0.9385330>,
    <-0.0886881, 0.3360219, 0.9376693>,
    <-0.0883432, 0.3347152, 0.9381691>,
    <-0.0883432, 0.3347152, 0.9381691>,
    <-0.0495151, 0.2839044, 0.9575732>,
    <-0.1202324, 0.2961755, 0.9475359>,
    <-0.1191870, 0.2992391, 0.9467050>,
    <-0.1030570, 0.3010690, 0.9480173>,
    <-0.0983004, 0.3063607, 0.9468264>,
    <-0.0826177, 0.3083225, 0.9476875>,
    <-0.0679889, 0.2537327, 0.9648820>,
    <-0.0679889, 0.2537327, 0.9648820>,
    <-0.1397681, 0.3046870, 0.9421416>,
    <-0.1400132, 0.3060232, 0.9416720>,
    <-0.1388830, 0.3095631, 0.9406818>,
    <-0.1149136, 0.3245537, 0.9388609>,
    <-0.0959563, 0.3136027, 0.9446935>,
    <-0.1419098, 0.3306174, 0.9330347>,
    <-0.0995537, 0.2751030, 0.9562465>,
    <-0.0902958, 0.3243806, 0.9416071>,
    <-0.0885860, 0.3305936, 0.9396065>,
    <-0.0887696, 0.3312802, 0.9393473>,
    <-0.0887696, 0.3312802, 0.9393473>,
    <-0.0826177, 0.3083225, 0.9476875>,
    <-0.0892578, -0.3341386, 0.9382881>,
    <-0.0894400, -0.3345369, 0.9381288>,
    <-0.0900392, -0.3345242, 0.9380760>,
    <-0.0898929, -0.3346445, 0.9380471>,
    <-0.0897386, -0.3348539, 0.9379871>,
    <-0.0896301, -0.3344656, 0.9381360>,
    <-0.0896301, -0.3344656, 0.9381360>,
    <-0.0885658, -0.3305102, 0.9396378>,
    <-0.0884492, -0.3326497, 0.9388935>,
    <-0.0886059, -0.3338224, 0.9384624>,
    <-0.0918267, -0.3354058, 0.9375877>,
    <-0.0916939, -0.3329530, 0.9384746>,
    <-0.0892615, -0.3352337, 0.9378970>,
    <-0.0847646, -0.2342433, 0.9684756>,
    <-0.1063311, -0.3342586, 0.9364640>,
    <-0.0984557, -0.3266371, 0.9400078>,
    <-0.0906660, -0.3327986, 0.9386292>,
    <-0.0942846, -0.3246847, 0.9411112>,
    <-0.0932008, -0.3228759, 0.9418411>,
    <-0.0891469, -0.3326322, 0.9388337>,
    <-0.0891469, -0.3326322, 0.9388337>,
    <-0.0897386, -0.3348539, 0.9379871>,
    <-0.0880137, -0.3318788, 0.9392071>,
    <-0.0877718, -0.3314660, 0.9393755>,
    <-0.0879488, -0.3324472, 0.9390122>,
    <-0.0881237, -0.3329723, 0.9388097>,
    <-0.0885658, -0.3305102, 0.9396378>,
    <-0.0876397, -0.3315336, 0.9393640>,
    <-0.0879495, -0.3328370, 0.9388740>,
    <-0.0443526, -0.2475074, 0.9678703>,
    <-0.0876255, -0.3319978, 0.9392014>,
    <-0.0876255, -0.3319978, 0.9392014>,
    <-0.0879305, -0.3331536, 0.9387635>,
    <-0.0882238, -0.3338352, 0.9384938>,
    <-0.0879305, -0.3331536, 0.9387635>,
    <-0.0881872, -0.3341263, 0.9383936>,
    <-0.0881872, -0.3341263, 0.9383936>,
    <-0.0847646, -0.2342433, 0.9684756>,
    <-0.1151983, -0.3116485, 0.9431885>,
    <-0.1167271, -0.3135419, 0.9423727>,
    <-0.1312528, -0.3099550, 0.9416478>,
    <-0.1359381, -0.3102448, 0.9408873>,
    <-0.1434090, -0.3074621, 0.9406917>,
    <-0.1345043, -0.2882259, 0.9480688>,
    <-0.1345043, -0.2882259, 0.9480688>,
    <-0.0932008, -0.3228759, 0.9418411>,
    <-0.1306203, -0.3201852, 0.9383069>,
    <-0.1391466, -0.3118068, 0.9399015>,
    <-0.0847646, -0.2342433, 0.9684756>,
    <-0.1444799, -0.3196479, 0.9364565>,
    <-0.1451590, -0.3143355, 0.9381482>,
    <-0.1444309, -0.3135835, 0.9385122>,
    <-0.1467612, -0.3150936, 0.9376445>,
    <-0.1472975, -0.3158876, 0.9372932>,
    <-0.1468339, -0.3148665, 0.9377094>,
    <-0.1468339, -0.3148665, 0.9377094>,
    <-0.1434090, -0.3074621, 0.9406917>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.1472838, -0.3158705, 0.9373011>,
    <-0.1472893, -0.3158820, 0.9372963>,
    <-0.1472891, -0.3158772, 0.9372980>,
    <-0.1472859, -0.3158691, 0.9373012>,
    <-0.1472795, -0.3158496, 0.9373088>,
    <-0.1472753, -0.3158457, 0.9373108>,
    <-0.1472673, -0.3158428, 0.9373130>,
    <-0.1472849, -0.3158797, 0.9372978>,
    <-0.1472849, -0.3158797, 0.9372978>,
    <-0.1472904, -0.3158890, 0.9372938>,
    <-0.1472262, -0.3158082, 0.9373311>,
    <-0.1469162, -0.3155981, 0.9374505>,
    <-0.1472904, -0.3158890, 0.9372938>,
    <-0.1472940, -0.3158917, 0.9372923>,
    <-0.1472940, -0.3158917, 0.9372923>,
    <-0.1472975, -0.3158876, 0.9372932>,
    <-0.1470383, -0.3163436, 0.9371801>,
    <-0.0847646, -0.2342433, 0.9684756>,
    <-0.1472833, -0.3160907, 0.9372269>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.1472061, 0.3158663, 0.9373147>,
    <-0.1472649, 0.3164527, 0.9371076>,
    <-0.1469578, 0.3161223, 0.9372673>,
    <-0.1468504, 0.3154285, 0.9375179>,
    <-0.1468093, 0.3148662, 0.9377133>,
    <-0.1472312, 0.3157708, 0.9373429>,
    <-0.1472312, 0.3157708, 0.9373429>,
    <-0.1472602, 0.3158324, 0.9373176>,
    <-0.1472512, 0.3158339, 0.9373185>,
    <-0.1473264, 0.3161686, 0.9371939>,
    <-0.1472709, 0.3200860, 0.9358719>,
    <-0.1454813, 0.3150621, 0.9378545>,
    <-0.1479063, 0.3184466, 0.9363309>,
    <-0.0995537, 0.2751030, 0.9562465>,
    <-0.1454322, 0.3132023, 0.9384848>,
    <-0.1397681, 0.3046870, 0.9421416>,
    <-0.1455659, 0.3121998, 0.9387981>,
    <-0.1455659, 0.3121998, 0.9387981>,
    <-0.1468093, 0.3148662, 0.9377133>,
    <-0.1472265, 0.3154846, 0.9374401>,
    <-0.1473719, 0.3144511, 0.9377644>,
    <-0.1472511, 0.3157747, 0.9373385>,
    <-0.1472818, 0.3158957, 0.9372929>,
    <-0.1472602, 0.3158324, 0.9373176>,
    <-0.1466980, 0.3131288, 0.9383124>,
    <-0.1478141, 0.3086225, 0.9396293>,
    <-0.1483046, 0.3158471, 0.9371480>,
    <-0.1472467, 0.3157618, 0.9373435>,
    <-0.1571213, 0.3180348, 0.9349689>,
    <-0.1454236, 0.2507987, 0.9570538>,
    <-0.1488743, 0.3192483, 0.9359044>,
    <-0.1488743, 0.3192483, 0.9359044>,
    <-0.1472436, 0.3157515, 0.9373475>,
    <-0.1473344, 0.3160252, 0.9372410>,
    <-0.1472436, 0.3157515, 0.9373475>,
    <-0.1473130, 0.3159003, 0.9372865>,
    <-0.1473130, 0.3159003, 0.9372865>,
    <-0.0995537, 0.2751030, 0.9562465>,
    <-0.1700722, 0.2709242, 0.9474574>,
    <-0.1698173, 0.2741940, 0.9465621>,
    <-0.1545458, 0.2790554, 0.9477572>,
    <-0.1506436, 0.2851350, 0.9465752>,
    <-0.1350718, 0.2896892, 0.9475420>,
    <-0.1109669, 0.2379861, 0.9649088>,
    <-0.1109669, 0.2379861, 0.9649088>,
    <-0.1905060, 0.2756898, 0.9421797>,
    <-0.1909975, 0.2769631, 0.9417066>,
    <-0.1905287, 0.2804914, 0.9407568>,
    <-0.1701351, 0.2994586, 0.9388177>,
    <-0.1499870, 0.2927601, 0.9443492>,
    <-0.1970249, 0.2999942, 0.9333727>,
    <-0.1454236, 0.2507987, 0.9570538>,
    <-0.1463988, 0.3050949, 0.9410019>,
    <-0.1472602, 0.3158324, 0.9373176>,
    <-0.1457457, 0.3125830, 0.9386427>,
    <-0.1457457, 0.3125830, 0.9386427>,
    <-0.1350718, 0.2896892, 0.9475420>,
    <-0.1472095, -0.3119864, 0.9386127>,
    <-0.1472737, -0.3147557, 0.9376776>,
    <-0.1476807, -0.3147183, 0.9376262>,
    <-0.1486848, -0.3116267, 0.9384997>,
    <-0.1540124, -0.3015077, 0.9409428>,
    <-0.1489581, -0.3023396, 0.9414894>,
    <-0.1476900, -0.3015614, 0.9419386>,
    <-0.1455092, -0.3120731, 0.9388490>,
    <-0.1455092, -0.3120731, 0.9388490>,
    <-0.1467570, -0.3147489, 0.9377609>,
    <-0.1472554, -0.3155390, 0.9374172>,
    <-0.1475381, -0.3153514, 0.9374359>,
    <-0.1467570, -0.3147489, 0.9377609>,
    <-0.1471934, -0.3156846, 0.9373779>,
    <-0.1471934, -0.3156846, 0.9373779>,
    <-0.1472673, -0.3158428, 0.9373130>,
    <-0.1472549, -0.3157499, 0.9373462>,
    <-0.1473554, -0.3157181, 0.9373412>,
    <-0.1499664, -0.3143057, 0.9374017>,
    <-0.1481268, -0.3160933, 0.9370931>,
    <-0.1278642, -0.2228974, 0.9664199>,
    <-0.1654100, -0.3082722, 0.9368072>,
    <-0.1472714, -0.3158210, 0.9373197>,
    <-0.1472732, -0.3158312, 0.9373160>,
    <-0.1472696, -0.3158218, 0.9373197>,
    <-0.1472889, -0.3158070, 0.9373217>,
    <-0.1472673, -0.3158428, 0.9373130>,
    <-0.1472743, -0.3158299, 0.9373162>,
    <-0.1472690, -0.3158179, 0.9373211>,
    <-0.0847646, -0.2342433, 0.9684756>,
    <-0.1472736, -0.3158254, 0.9373179>,
    <-0.1472736, -0.3158254, 0.9373179>,
    <-0.1472686, -0.3158148, 0.9373222>,
    <-0.1473323, -0.3158744, 0.9372921>,
    <-0.1472686, -0.3158148, 0.9373222>,
    <-0.1473248, -0.3159354, 0.9372728>,
    <-0.1473248, -0.3159354, 0.9372728>,
    <-0.1278642, -0.2228974, 0.9664199>,
    <-0.1686720, -0.2843925, 0.9437535>,
    <-0.1705446, -0.2851064, 0.9432014>,
    <-0.1842419, -0.2817398, 0.9416356>,
    <-0.1889741, -0.2820092, 0.9406166>,
    <-0.1951961, -0.2787664, 0.9403126>,
    <-0.1822628, -0.2603272, 0.9481614>,
    <-0.1822628, -0.2603272, 0.9481614>,
    <-0.1476900, -0.3015614, 0.9419386>,
    <-0.1854924, -0.2906725, 0.9386704>,
    <-0.1919896, -0.2840617, 0.9393876>,
    <-0.1278642, -0.2228974, 0.9664199>,
    <-0.1973072, -0.2899239, 0.9364902>,
    <-0.1978543, -0.2872709, 0.9371921>,
    <-0.1980084, -0.2862060, 0.9374854>,
    <-0.2011136, -0.2895400, 0.9357991>,
    <-0.2055702, -0.2935645, 0.9335742>,
    <-0.2010799, -0.2871570, 0.9365403>,
    <-0.2010799, -0.2871570, 0.9365403>,
    <-0.1951961, -0.2787664, 0.9403126>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.1981974, 0.2827790, 0.9384849>,
    <-0.1984624, 0.2832294, 0.9382930>,
    <-0.1987249, 0.2841172, 0.9379690>,
    <-0.1987079, 0.2839398, 0.9380263>,
    <-0.1987988, 0.2839150, 0.9380146>,
    <-0.1985696, 0.2835825, 0.9381637>,
    <-0.1985696, 0.2835825, 0.9381637>,
    <-0.1962549, 0.2802645, 0.9396467>,
    <-0.1967068, 0.2800378, 0.9396198>,
    <-0.1971949, 0.2805820, 0.9393550>,
    <-0.1996714, 0.2875224, 0.9367295>,
    <-0.1975151, 0.2840352, 0.9382493>,
    <-0.1985085, 0.2829363, 0.9383717>,
    <-0.1454236, 0.2507987, 0.9570538>,
    <-0.1974089, 0.2828127, 0.9386409>,
    <-0.1905060, 0.2756898, 0.9421797>,
    <-0.1974556, 0.2819990, 0.9388758>,
    <-0.1974556, 0.2819990, 0.9388758>,
    <-0.1987988, 0.2839150, 0.9380146>,
    <-0.1955045, 0.2775314, 0.9406138>,
    <-0.1947359, 0.2750763, 0.9414940>,
    <-0.1950566, 0.2767080, 0.9409493>,
    <-0.1958405, 0.2780767, 0.9403828>,
    <-0.1962549, 0.2802645, 0.9396467>,
    <-0.1941794, 0.2749872, 0.9416350>,
    <-0.1938778, 0.2692223, 0.9433614>,
    <-0.1952076, 0.2751188, 0.9413839>,
    <-0.1946479, 0.2759528, 0.9412557>,
    <-0.2035136, 0.2753839, 0.9395456>,
    <-0.1887841, 0.2262628, 0.9555970>,
    <-0.1960395, 0.2777508, 0.9404377>,
    <-0.1960395, 0.2777508, 0.9404377>,
    <-0.1943444, 0.2753492, 0.9414951>,
    <-0.1957345, 0.2776748, 0.9405236>,
    <-0.1943444, 0.2753492, 0.9414951>,
    <-0.1952366, 0.2766131, 0.9409399>,
    <-0.1952366, 0.2766131, 0.9409399>,
    <-0.1454236, 0.2507987, 0.9570538>,
    <-0.2078581, 0.2297109, 0.9508038>,
    <-0.2084162, 0.2330173, 0.9498766>,
    <-0.1949890, 0.2402476, 0.9509261>,
    <-0.1921275, 0.2466817, 0.9498606>,
    <-0.1777286, 0.2537105, 0.9508120>,
    <-0.1467979, 0.2093620, 0.9667564>,
    <-0.1467979, 0.2093620, 0.9667564>,
    <-0.2274957, 0.2303200, 0.9461492>,
    <-0.2283212, 0.2316219, 0.9456324>,
    <-0.2289078, 0.2357120, 0.9444793>,
    <-0.2126061, 0.2562409, 0.9429418>,
    <-0.1930274, 0.2539047, 0.9477726>,
    <-0.2382119, 0.2535270, 0.9375389>,
    <-0.1887841, 0.2262628, 0.9555970>,
    <-0.1917489, 0.2666726, 0.9445200>,
    <-0.1962549, 0.2802645, 0.9396467>,
    <-0.1920255, 0.2741952, 0.9423074>,
    <-0.1920255, 0.2741952, 0.9423074>,
    <-0.1777286, 0.2537105, 0.9508120>,
    <-0.2083287, -0.2979987, 0.9315556>,
    <-0.2086287, -0.2984993, 0.9313282>,
    <-0.2099247, -0.2996606, 0.9306638>,
    <-0.2099574, -0.2997685, 0.9306217>,
    <-0.2101246, -0.3000655, 0.9304882>,
    <-0.2094344, -0.2990808, 0.9309608>,
    <-0.2094344, -0.2990808, 0.9309608>,
    <-0.2055702, -0.2935645, 0.9335742>,
    <-0.2049359, -0.2940729, 0.9335536>,
    <-0.2053728, -0.2950226, 0.9331579>,
    <-0.2125941, -0.3020417, 0.9292871>,
    <-0.2108296, -0.2994188, 0.9305371>,
    <-0.2070513, -0.2972387, 0.9320831>,
    <-0.1812987, -0.2172908, 0.9591222>,
    <-0.2248034, -0.3059369, 0.9251303>,
    <-0.2111155, -0.2940797, 0.9321735>,
    <-0.2096820, -0.2985688, 0.9310693>,
    <-0.2066849, -0.2908979, 0.9341626>,
    <-0.2049836, -0.2889013, 0.9351566>,
    <-0.2088548, -0.2982516, 0.9313569>,
    <-0.2088548, -0.2982516, 0.9313569>,
    <-0.2101246, -0.3000655, 0.9304882>,
    <-0.2020955, -0.2910095, 0.9351315>,
    <-0.1999536, -0.2888993, 0.9362455>,
    <-0.2007873, -0.2896465, 0.9358362>,
    <-0.2023816, -0.2915687, 0.9348954>,
    <-0.2055702, -0.2935645, 0.9335742>,
    <-0.1988637, -0.2878023, 0.9368154>,
    <-0.1998719, -0.2886060, 0.9363535>,
    <-0.1278642, -0.2228974, 0.9664199>,
    <-0.1991945, -0.2879051, 0.9367135>,
    <-0.1991945, -0.2879051, 0.9367135>,
    <-0.1991270, -0.2878077, 0.9367578>,
    <-0.2017775, -0.2911116, 0.9351684>,
    <-0.1991270, -0.2878077, 0.9367578>,
    <-0.2005223, -0.2898243, 0.9358380>,
    <-0.2005223, -0.2898243, 0.9358380>,
    <-0.1812987, -0.2172908, 0.9591222>,
    <-0.2083418, -0.2713076, 0.9396733>,
    <-0.2122715, -0.2745251, 0.9378575>,
    <-0.2206224, -0.2595738, 0.9401847>,
    <-0.2273618, -0.2562412, 0.9394930>,
    <-0.2378617, -0.2378723, 0.9417211>,
    <-0.1946543, -0.1946599, 0.9613622>,
    <-0.1946543, -0.1946599, 0.9613622>,
    <-0.2049836, -0.2889013, 0.9351566>,
    <-0.2346874, -0.2832797, 0.9298787>,
    <-0.2347617, -0.2571308, 0.9374277>,
    <-0.1812987, -0.2172908, 0.9591222>,
    <-0.2586038, -0.2755327, 0.9258541>,
    <-0.2520313, -0.2580607, 0.9326762>,
    <-0.2489989, -0.2565237, 0.9339139>,
    <-0.2578788, -0.2586353, 0.9309169>,
    <-0.2606946, -0.2607081, 0.9295534>,
    <-0.2578004, -0.2578130, 0.9311667>,
    <-0.2578004, -0.2578130, 0.9311667>,
    <-0.2378617, -0.2378723, 0.9417211>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.2606822, -0.2606945, 0.9295607>,
    <-0.2606891, -0.2607021, 0.9295567>,
    <-0.2606875, -0.2606992, 0.9295579>,
    <-0.2606834, -0.2606938, 0.9295606>,
    <-0.2606746, -0.2606823, 0.9295663>,
    <-0.2606704, -0.2606801, 0.9295681>,
    <-0.2606639, -0.2606800, 0.9295699>,
    <-0.2606854, -0.2607006, 0.9295581>,
    <-0.2606854, -0.2607006, 0.9295581>,
    <-0.2606915, -0.2607061, 0.9295549>,
    <-0.2603627, -0.2605124, 0.9297013>,
    <-0.2590745, -0.2601788, 0.9301545>,
    <-0.2606915, -0.2607061, 0.9295549>,
    <-0.2606941, -0.2607082, 0.9295535>,
    <-0.2606941, -0.2607082, 0.9295535>,
    <-0.2606946, -0.2607081, 0.9295534>,
    <-0.2604763, -0.2625896, 0.9290849>,
    <-0.1812987, -0.2172908, 0.9591222>,
    <-0.2609974, -0.2615038, 0.9292449>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.2424357, 0.2433134, 0.9391611>,
    <-0.2424507, 0.2441439, 0.9389417>,
    <-0.2400598, 0.2413739, 0.9402712>,
    <-0.2390482, 0.2397129, 0.9409536>,
    <-0.2380778, 0.2380783, 0.9416144>,
    <-0.2411407, 0.2411422, 0.9400540>,
    <-0.2411407, 0.2411422, 0.9400540>,
    <-0.2487027, 0.2487067, 0.9361047>,
    <-0.2475926, 0.2495193, 0.9361827>,
    <-0.2467206, 0.2493372, 0.9364614>,
    <-0.2418610, 0.2456791, 0.9386933>,
    <-0.2372350, 0.2394965, 0.9414674>,
    <-0.2468814, 0.2506368, 0.9360720>,
    <-0.1887841, 0.2262628, 0.9555970>,
    <-0.2356443, 0.2365109, 0.9426210>,
    <-0.2274957, 0.2303200, 0.9461492>,
    <-0.2351387, 0.2351388, 0.9430904>,
    <-0.2351387, 0.2351388, 0.9430904>,
    <-0.2380778, 0.2380783, 0.9416144>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.2515042, 0.2545529, 0.9337818>,
    <-0.2540702, 0.2572165, 0.9323562>,
    <-0.2536071, 0.2576312, 0.9323677>,
    <-0.2510269, 0.2545689, 0.9339059>,
    <-0.2487027, 0.2487067, 0.9361047>,
    <-0.2515712, 0.2533729, 0.9340847>,
    <-0.2535224, 0.2519718, 0.9339361>,
    <-0.2578944, 0.2611763, 0.9302029>,
    <-0.2551067, 0.2595449, 0.9314274>,
    <-0.2688009, 0.2609898, 0.9271625>,
    <-0.2289309, 0.1928223, 0.9541542>,
    <-0.2606814, 0.2656125, 0.9281677>,
    <-0.2606814, 0.2656125, 0.9281677>,
    <-0.2562648, 0.2611124, 0.9306711>,
    <-0.2518527, 0.2560007, 0.9332919>,
    <-0.2562648, 0.2611124, 0.9306711>,
    <-0.2535269, 0.2583227, 0.9321982>,
    <-0.2535269, 0.2583227, 0.9321982>,
    <-0.1887841, 0.2262628, 0.9555970>,
    <-0.2650543, 0.2066134, 0.9418371>,
    <-0.2653119, 0.2099189, 0.9410333>,
    <-0.2509295, 0.2198866, 0.9427005>,
    <-0.2496832, 0.2272002, 0.9412961>,
    <-0.2370290, 0.2370520, 0.9421378>,
    <-0.1938259, 0.1938864, 0.9616858>,
    <-0.1938259, 0.1938864, 0.9616858>,
    <-0.2885539, 0.2047439, 0.9353163>,
    <-0.2893566, 0.2057460, 0.9348483>,
    <-0.2898462, 0.2093276, 0.9339010>,
    <-0.2756511, 0.2366254, 0.9316785>,
    <-0.2509536, 0.2353230, 0.9389597>,
    <-0.3046416, 0.2276502, 0.9248615>,
    <-0.2289309, 0.1928223, 0.9541542>,
    <-0.2511938, 0.2474118, 0.9357826>,
    <-0.2487027, 0.2487067, 0.9361047>,
    <-0.2539303, 0.2539398, 0.9332920>,
    <-0.2539303, 0.2539398, 0.9332920>,
    <-0.2370290, 0.2370520, 0.9421378>,
    <-0.2592108, -0.2569373, 0.9310172>,
    <-0.2602736, -0.2595935, 0.9299832>,
    <-0.2606847, -0.2594206, 0.9299164>,
    <-0.2608369, -0.2567209, 0.9306226>,
    <-0.2629928, -0.2470017, 0.9326441>,
    <-0.2577566, -0.2472795, 0.9340312>,
    <-0.2556761, -0.2461044, 0.9349130>,
    <-0.2574640, -0.2574839, 0.9313508>,
    <-0.2574640, -0.2574839, 0.9313508>,
    <-0.2597390, -0.2597578, 0.9300868>,
    <-0.2605476, -0.2603902, 0.9296838>,
    <-0.2607786, -0.2601149, 0.9296961>,
    <-0.2597390, -0.2597578, 0.9300868>,
    <-0.2605390, -0.2605564, 0.9296396>,
    <-0.2605390, -0.2605564, 0.9296396>,
    <-0.2606639, -0.2606800, 0.9295699>,
    <-0.2606203, -0.2605985, 0.9296050>,
    <-0.2607156, -0.2605399, 0.9295947>,
    <-0.2629541, -0.2590430, 0.9293825>,
    <-0.2615761, -0.2607551, 0.9292926>,
    <-0.1959704, -0.1628938, 0.9669856>,
    <-0.2748806, -0.2500036, 0.9284066>,
    <-0.2606617, -0.2606630, 0.9295753>,
    <-0.2606663, -0.2606720, 0.9295715>,
    <-0.2606619, -0.2606671, 0.9295741>,
    <-0.2606764, -0.2606466, 0.9295758>,
    <-0.2606639, -0.2606800, 0.9295699>,
    <-0.2606674, -0.2606717, 0.9295713>,
    <-0.2606611, -0.2606652, 0.9295749>,
    <-0.1812987, -0.2172908, 0.9591222>,
    <-0.2606662, -0.2606693, 0.9295723>,
    <-0.2606662, -0.2606693, 0.9295723>,
    <-0.2606603, -0.2606635, 0.9295756>,
    <-0.2607491, -0.2607035, 0.9295395>,
    <-0.2606603, -0.2606635, 0.9295756>,
    <-0.2607693, -0.2607725, 0.9295144>,
    <-0.2607693, -0.2607725, 0.9295144>,
    <-0.1959704, -0.1628938, 0.9669856>,
    <-0.2697361, -0.2241242, 0.9364885>,
    <-0.2722865, -0.2250937, 0.9355174>,
    <-0.2836572, -0.2141691, 0.9347033>,
    <-0.2881758, -0.2120303, 0.9338083>,
    <-0.2935341, -0.2055547, 0.9335872>,
    <-0.2743871, -0.1921706, 0.9422219>,
    <-0.2743871, -0.1921706, 0.9422219>,
    <-0.2556761, -0.2461044, 0.9349130>,
    <-0.2888649, -0.2238675, 0.9308278>,
    <-0.2919243, -0.2116367, 0.9327326>,
    <-0.1959704, -0.1628938, 0.9669856>,
    <-0.3003742, -0.2147602, 0.9293295>,
    <-0.2983822, -0.2102875, 0.9309926>,
    <-0.2979405, -0.2107227, 0.9310357>,
    <-0.3008085, -0.2107909, 0.9300976>,
    <-0.3019362, -0.2114218, 0.9295888>,
    <-0.3009249, -0.2107189, 0.9300762>,
    <-0.3009249, -0.2107189, 0.9300762>,
    <-0.2935341, -0.2055547, 0.9335872>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.2927179, -0.2049632, 0.9339734>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.2927179, -0.2049632, 0.9339734>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.2927179, -0.2049632, 0.9339734>,
    <0.0034505, -0.0025973, -0.9999907>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0010918, -0.0005573, -0.9999992>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0062353, -0.0035680, -0.9999742>,
    <0.0323691, -0.0173518, -0.9993254>,
    <0.0072421, -0.0033079, -0.9999683>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0108263, -0.0072632, -0.9999150>,
    <0.2927179, -0.2049632, 0.9339734>,
    <0.0797072, -0.0494478, -0.9955911>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.2956570, -0.2061251, 0.9327912>,
    <-0.2991352, -0.2089289, 0.9310569>,
    <-0.2982105, -0.2078267, 0.9316000>,
    <-0.2960579, -0.2058038, 0.9327350>,
    <-0.2917985, -0.2018528, 0.9349380>,
    <-0.2902228, -0.2013577, 0.9355350>,
    <-0.2880474, -0.2016930, 0.9361349>,
    <-0.2972680, -0.2081494, 0.9318291>,
    <-0.2972680, -0.2081494, 0.9318291>,
    <-0.3003990, -0.2103422, 0.9303314>,
    <-0.3010441, -0.2106270, 0.9300584>,
    <-0.2992378, -0.2090838, 0.9309891>,
    <-0.3003990, -0.2103422, 0.9303314>,
    <-0.3017503, -0.2112894, 0.9296793>,
    <-0.3017503, -0.2112894, 0.9296793>,
    <-0.3019362, -0.2114218, 0.9295888>,
    <-0.2980711, -0.2075984, 0.9316955>,
    <-0.1959704, -0.1628938, 0.9669856>,
    <-0.2933603, -0.2025755, 0.9342927>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0421777, -0.0200264, -0.9989094>,
    <0.1776098, -0.0911723, -0.9798686>,
    <0.6205184, -0.3018435, -0.7237730>,
    <0.2685032, -0.1227164, -0.9554301>,
    <0.0673157, -0.0265695, -0.9973779>,
    <0.0065653, -0.0025913, -0.9999751>,
    <0.0065653, -0.0025913, -0.9999751>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.7351300, -0.4122455, -0.5381798>,
    <0.8176589, -0.4036995, 0.4104395>,
    <0.2927179, -0.2049632, 0.9339734>,
    <0.3198034, -0.1782489, 0.9305660>,
    <0.3210207, -0.1602948, 0.9334084>,
    <0.8724697, -0.3857416, 0.3000001>,
    <0.3348615, -0.1513874, 0.9300267>,
    <0.4384633, -0.1407173, 0.8876647>,
    <0.3768292, -0.1487343, -0.9142636>,
    <0.3768292, -0.1487343, -0.9142636>,
    <0.0673157, -0.0265695, -0.9973779>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.2979391, 0.2082777, 0.9315861>,
    <-0.2984219, 0.2085701, 0.9313661>,
    <-0.2995840, 0.2098641, 0.9307021>,
    <-0.2996955, 0.2098977, 0.9306587>,
    <-0.2999980, 0.2100664, 0.9305231>,
    <-0.2990040, 0.2093683, 0.9310003>,
    <-0.2990040, 0.2093683, 0.9310003>,
    <-0.2934843, 0.2054981, 0.9336153>,
    <-0.2940426, 0.2049092, 0.9335691>,
    <-0.2949804, 0.2053473, 0.9331769>,
    <-0.3018181, 0.2129044, 0.9292887>,
    <-0.2985557, 0.2104420, 0.9309021>,
    <-0.2975218, 0.2073998, 0.9319153>,
    <-0.2289309, 0.1928223, 0.9541542>,
    <-0.2982972, 0.2095116, 0.9311948>,
    <-0.2885539, 0.2047439, 0.9353163>,
    <-0.2981273, 0.2087576, 0.9314185>,
    <-0.2981273, 0.2087576, 0.9314185>,
    <-0.2999980, 0.2100664, 0.9305231>,
    <-0.2908718, 0.2019033, 0.9352158>,
    <-0.2885072, 0.1991174, 0.9365447>,
    <-0.2896394, 0.2007766, 0.9358407>,
    <-0.2915634, 0.2023780, 0.9348978>,
    <-0.2934843, 0.2054981, 0.9336153>,
    <-0.2882623, 0.1996931, 0.9364975>,
    <-0.2851778, 0.1935073, 0.9387377>,
    <-0.2884629, 0.1985560, 0.9366774>,
    <-0.2886005, 0.1998638, 0.9363569>,
    <-0.2965504, 0.1958629, 0.9347169>,
    <-0.2560873, 0.1469023, 0.9554261>,
    <-0.2900828, 0.2006984, 0.9357201>,
    <-0.2900828, 0.2006984, 0.9357201>,
    <-0.2878045, 0.1991221, 0.9367598>,
    <-0.2911194, 0.2017876, 0.9351638>,
    <-0.2878045, 0.1991221, 0.9367598>,
    <-0.2898026, 0.2005046, 0.9358485>,
    <-0.2898026, 0.2005046, 0.9358485>,
    <-0.2289309, 0.1928223, 0.9541542>,
    <-0.2834084, 0.1497334, 0.9472379>,
    <-0.2852748, 0.1526957, 0.9462042>,
    <-0.2749666, 0.1645513, 0.9472678>,
    <-0.2744916, 0.1719216, 0.9460959>,
    <-0.2626386, 0.1838588, 0.9472153>,
    <-0.2153914, 0.1506990, 0.9648297>,
    <-0.2153914, 0.1506990, 0.9648297>,
    <-0.3029237, 0.1435349, 0.9421438>,
    <-0.3041458, 0.1444644, 0.9416078>,
    <-0.3058929, 0.1479170, 0.9405052>,
    <-0.2980946, 0.1738786, 0.9385659>,
    <-0.2782956, 0.1786728, 0.9437307>,
    <-0.3211662, 0.1614499, 0.9331592>,
    <-0.2560873, 0.1469023, 0.9554261>,
    <-0.2820596, 0.1920069, 0.9399871>,
    <-0.2934843, 0.2054981, 0.9336153>,
    <-0.2851162, 0.1996264, 0.9374743>,
    <-0.2851162, 0.1996264, 0.9374743>,
    <-0.2626386, 0.1838588, 0.9472153>,
    <-0.2743322, -0.1899563, 0.9426868>,
    <-0.2772829, -0.1928318, 0.9412386>,
    <-0.2783461, -0.1924742, 0.9409980>,
    <-0.2769859, -0.1895514, 0.9419921>,
    <-0.2764116, -0.1803968, 0.9439564>,
    <-0.2713670, -0.1816590, 0.9451772>,
    <-0.2692923, -0.1809882, 0.9458990>,
    <-0.2723676, -0.1907139, 0.9431034>,
    <-0.2723676, -0.1907139, 0.9431034>,
    <-0.2757303, -0.1930685, 0.9416461>,
    <-0.2803842, -0.1950252, 0.9398669>,
    <-0.2800066, -0.1935788, 0.9402784>,
    <-0.2757303, -0.1930685, 0.9416461>,
    <-0.2792431, -0.1955281, 0.9401022>,
    <-0.2792431, -0.1955281, 0.9401022>,
    <-0.2880474, -0.2016930, 0.9361349>,
    <-0.2845617, -0.1971227, 0.9381723>,
    <-0.2826573, -0.1949271, 0.9392062>,
    <-0.2803911, -0.1910314, 0.9406848>,
    <-0.2819570, -0.1934676, 0.9397183>,
    <-0.2161409, -0.1234541, 0.9685258>,
    <-0.2875343, -0.1805610, 0.9405965>,
    <-0.2868033, -0.1980687, 0.9372901>,
    <-0.2879681, -0.1984978, 0.9368420>,
    <-0.2859837, -0.1968836, 0.9377900>,
    <-0.2848402, -0.1961002, 0.9383021>,
    <-0.2880474, -0.2016930, 0.9361349>,
    <-0.2881041, -0.1981445, 0.9368750>,
    <-0.2853336, -0.1961355, 0.9381447>,
    <-0.1959704, -0.1628938, 0.9669856>,
    <-0.2873463, -0.1972162, 0.9373035>,
    <-0.2873463, -0.1972162, 0.9373035>,
    <-0.2848484, -0.1955018, 0.9384244>,
    <-0.2835111, -0.1947729, 0.9389808>,
    <-0.2848484, -0.1955018, 0.9384244>,
    <-0.2832068, -0.1943751, 0.9391551>,
    <-0.2832068, -0.1943751, 0.9391551>,
    <-0.2161409, -0.1234541, 0.9685258>,
    <-0.2786768, -0.1590687, 0.9471200>,
    <-0.2811261, -0.1594392, 0.9463336>,
    <-0.2893482, -0.1477666, 0.9457498>,
    <-0.2929470, -0.1450631, 0.9450602>,
    <-0.2967468, -0.1383962, 0.9448745>,
    <-0.2787946, -0.1300494, 0.9515045>,
    <-0.2787946, -0.1300494, 0.9515045>,
    <-0.2692923, -0.1809882, 0.9458990>,
    <-0.2953147, -0.1555317, 0.9426553>,
    <-0.2962156, -0.1441690, 0.9441778>,
    <-0.2161409, -0.1234541, 0.9685258>,
    <-0.3048453, -0.1465253, 0.9410630>,
    <-0.3021089, -0.1422447, 0.9426010>,
    <-0.3011251, -0.1421613, 0.9429283>,
    <-0.3037194, -0.1417908, 0.9421517>,
    <-0.3045804, -0.1420321, 0.9418374>,
    <-0.3036395, -0.1415988, 0.9422064>,
    <-0.3036395, -0.1415988, 0.9422064>,
    <-0.2967468, -0.1383962, 0.9448745>,
    <-0.1040085, 0.0451977, -0.9935489>,
    <-0.0562695, 0.0251741, -0.9980982>,
    <-0.0715579, 0.0336232, -0.9968696>,
    <-0.0991589, 0.0465510, -0.9939822>,
    <-0.1446756, 0.0682536, -0.9871223>,
    <-0.1674130, 0.0755767, -0.9829858>,
    <-0.1633459, 0.0878834, -0.9826467>,
    <-0.0829779, 0.0327513, -0.9960131>,
    <-0.0829779, 0.0327513, -0.9960131>,
    <-0.0345761, 0.0136472, -0.9993089>,
    <-0.0168281, 0.0077520, -0.9998283>,
    <-0.0433117, 0.0214419, -0.9988315>,
    <-0.0345761, 0.0136472, -0.9993089>,
    <-0.0049866, 0.0019682, -0.9999856>,
    <-0.0049866, 0.0019682, -0.9999856>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0037485, 0.0017490, -0.9999914>,
    <-0.0128646, 0.0073147, -0.9998905>,
    <-0.0690565, 0.0369426, -0.9969285>,
    <-0.0210903, 0.0146533, -0.9996702>,
    <-0.8042889, 0.2390891, -0.5440182>,
    <-0.1273319, 0.0645186, -0.9897595>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0021636, 0.0024633, -0.9999946>,
    <-0.0018725, 0.0015238, -0.9999971>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0033380, -0.0005722, -0.9999943>,
    <0.0033380, -0.0005722, -0.9999943>,
    <-0.8042889, 0.2390891, -0.5440182>,
    <-0.0002603, 0.0002129, -0.9999999>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.3332519, -0.0892942, 0.9385999>,
    <0.0026689, -0.0019454, -0.9999945>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0087363, -0.0038423, -0.9999545>,
    <0.0031994, -0.0016537, -0.9999935>,
    <0.3332519, -0.0892942, 0.9385999>,
    <0.0769825, -0.0221131, -0.9967872>,
    <0.0216458, -0.0055307, -0.9997504>,
    <-0.0008750, -0.0001507, -0.9999996>,
    <-0.0024078, -0.0004166, -0.9999970>,
    <-0.3670285, 0.0983449, 0.9249964>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0005325, -0.0024432, -0.9999969>,
    <0.1144126, -0.0209878, -0.9932116>,
    <0.3364250, -0.0525549, -0.9402426>,
    <0.1560715, -0.0227757, -0.9874831>,
    <0.0639228, -0.0084720, -0.9979189>,
    <-0.0828999, 0.0080598, -0.9965253>,
    <-0.3670285, 0.0983449, 0.9249964>,
    <0.6538455, -0.1362350, -0.7442621>,
    <0.9857821, -0.1416394, 0.0903983>,
    <0.3332519, -0.0892942, 0.9385999>,
    <0.4244073, -0.0840079, 0.9015659>,
    <0.4112474, -0.0562287, 0.9097878>,
    <0.9680026, -0.0951669, -0.2321942>,
    <0.4010216, -0.0328587, 0.9154791>,
    <0.4825164, -0.0103803, 0.8758254>,
    <0.3909245, -0.0332774, -0.9198210>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.3045872, -0.1420285, 0.9418357>,
    <-0.3045832, -0.1420287, 0.9418370>,
    <-0.3045838, -0.1420304, 0.9418366>,
    <-0.3045858, -0.1420307, 0.9418359>,
    <-0.3045955, -0.1420363, 0.9418319>,
    <-0.3046028, -0.1420364, 0.9418295>,
    <-0.3046143, -0.1420308, 0.9418266>,
    <-0.3045803, -0.1420217, 0.9418390>,
    <-0.3045803, -0.1420217, 0.9418390>,
    <-0.3045802, -0.1420258, 0.9418384>,
    <-0.3044852, -0.1420144, 0.9418708>,
    <-0.3041423, -0.1420613, 0.9419745>,
    <-0.3045802, -0.1420258, 0.9418384>,
    <-0.3045802, -0.1420289, 0.9418379>,
    <-0.3045802, -0.1420289, 0.9418379>,
    <-0.3045804, -0.1420321, 0.9418374>,
    <-0.3046853, -0.1425338, 0.9417276>,
    <-0.2161409, -0.1234541, 0.9685258>,
    <-0.3047347, -0.1422099, 0.9417606>,
    <0.0691736, 0.0073504, -0.9975776>,
    <0.3727425, 0.0350434, -0.9272729>,
    <0.9121206, 0.0843048, -0.4011592>,
    <0.3744300, 0.0390307, -0.9264334>,
    <0.0858852, 0.0127757, -0.9962231>,
    <0.0081909, 0.0012184, -0.9999657>,
    <0.0081909, 0.0012184, -0.9999657>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0277167, 0.0036535, -0.9996091>,
    <0.1343671, 0.0140942, -0.9908314>,
    <0.8997557, 0.0637800, 0.4317080>,
    <0.6328911, 0.0563964, 0.7721841>,
    <0.4074940, 0.0276614, -0.9127888>,
    <0.3792797, 0.0195223, 0.9250761>,
    <0.3646227, 0.0302422, 0.9306641>,
    <0.7490589, 0.0849175, 0.6570387>,
    <0.3691183, 0.0394658, 0.9285441>,
    <0.4133888, 0.0894293, 0.9061524>,
    <0.6755019, 0.1004833, -0.7304795>,
    <0.6755019, 0.1004833, -0.7304795>,
    <0.0858852, 0.0127757, -0.9962231>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.1294568, 0.0133690, -0.9914949>,
    <-0.0209927, 0.0015526, -0.9997784>,
    <-0.0758768, 0.0073877, -0.9970898>,
    <-0.1250941, 0.0130955, -0.9920585>,
    <-0.1560612, 0.0173444, -0.9875951>,
    <-0.1652323, 0.0194375, -0.9860631>,
    <-0.3670285, 0.0983449, 0.9249964>,
    <0.1328293, -0.0107929, -0.9910802>,
    <-0.0149563, 0.0024704, -0.9998851>,
    <0.2095496, -0.0058180, -0.9777807>,
    <0.0361875, 0.0007661, -0.9993447>,
    <-0.0842698, 0.0115632, -0.9963759>,
    <-0.0164826, 0.0061719, -0.9998451>,
    <-0.9582360, -0.0635741, -0.2788227>,
    <-0.1486706, 0.0179018, -0.9887247>,
    <0.0156935, 0.0019091, -0.9998750>,
    <0.0089024, 0.0011012, -0.9999598>,
    <0.0370000, 0.0040392, -0.9993071>,
    <0.0698674, 0.0071731, -0.9975305>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0075229, 0.0025944, -0.9999683>,
    <0.0476923, 0.0042108, -0.9988532>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0040138, 0.0005971, -0.9999918>,
    <0.0040138, 0.0005971, -0.9999918>,
    <-0.9582360, -0.0635741, -0.2788227>,
    <0.1397551, 0.0088864, -0.9901462>,
    <0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <0.0000000, 0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.0000000, -0.0000000, -1.0000000>,
    <-0.3157934, 0.1473266, 0.9373203>,
    <-0.3162125, 0.1477388, 0.9371141>,
    <-0.3157457, 0.1476702, 0.9372823>,
    <-0.3152121, 0.1472040, 0.9375352>,
    <-0.3148124, 0.1467953, 0.9377336>,
    <-0.3157364, 0.1472260, 0.9373553>,
    <-0.3157364, 0.1472260, 0.9373553>,
    <-0.3158711, 0.1472883, 0.9373002>,
    <-0.3158596, 0.1473039, 0.9373016>,
    <-0.3161224, 0.1475104, 0.9371805>,
    <-0.3185064, 0.1504308, 0.9359082>,
    <-0.3140211, 0.1478157, 0.9378386>,
    <-0.3179728, 0.1488403, 0.9363439>,
    <-0.2560873, 0.1469023, 0.9554261>,
    <-0.3127131, 0.1464125, 0.9384956>,
    <-0.3029237, 0.1435349, 0.9421438>,
    <-0.3121493, 0.1455535, 0.9388168>,
    <-0.3121493, 0.1455535, 0.9388168>,
    <-0.3148124, 0.1467953, 0.9377336>,
    <-0.3156573, 0.1470786, 0.9374051>,
    <-0.3151324, 0.1462118, 0.9377173>,
    <-0.3158823, 0.1472989, 0.9372947>,
    <-0.3159579, 0.1473571, 0.9372601>,
    <-0.3158711, 0.1472883, 0.9373002>,
    <-0.3137509, 0.1456168, 0.9382729>,
    <-0.3117360, 0.1414656, 0.9395787>,
    <-0.3167666, 0.1466946, 0.9370910>,
    <-0.3158851, 0.1473007, 0.9372935>,
    <-0.3249503, 0.1427199, 0.9349002>,
    <-0.2759421, 0.1004354, 0.9559125>,
    <-0.3193972, 0.1489389, 0.9358433>,
    <-0.3193972, 0.1489389, 0.9358433>,
    <-0.3158875, 0.1473023, 0.9372925>,
    <-0.3160887, 0.1474291, 0.9372047>,
    <-0.3158875, 0.1473023, 0.9372925>,
    <-0.3160099, 0.1473594, 0.9372422>,
    <-0.3160099, 0.1473594, 0.9372422>,
    <-0.2560873, 0.1469023, 0.9554261>,
    <-0.3045587, 0.0982849, 0.9474091>,
    <-0.3065206, 0.1009848, 0.9464920>,
    <-0.2979020, 0.1144897, 0.9477059>,
    <-0.2988201, 0.1216521, 0.9465238>,
    <-0.2898299, 0.1351411, 0.9474891>,
    <-0.2381450, 0.1110326, 0.9648620>,
    <-0.2381450, 0.1110326, 0.9648620>,
    <-0.3232518, 0.0887827, 0.9421390>,
    <-0.3245161, 0.0894692, 0.9416393>,
    <-0.3266517, 0.0925965, 0.9405980>,
    <-0.3230359, 0.1201657, 0.9387268>,
    <-0.3032158, 0.1279177, 0.9442972>,
    <-0.3444604, 0.1035961, 0.9330674>,
    <-0.2759421, 0.1004354, 0.9559125>,
    <-0.3083837, 0.1396620, 0.9409538>,
    <-0.3158711, 0.1472883, 0.9373002>,
    <-0.3126964, 0.1458068, 0.9385954>,
    <-0.3126964, 0.1458068, 0.9385954>,
    <-0.2898299, 0.1351411, 0.9474891>,
    <-0.3045085, -0.1418559, 0.9418872>,
    <-0.3046255, -0.1415554, 0.9418946>,
    <-0.3043847, -0.1410062, 0.9420548>,
    <-0.3041124, -0.1412882, 0.9421005>,
    <-0.3037401, -0.1416035, 0.9421732>,
    <-0.3045564, -0.1419941, 0.9418509>,
    <-0.3045564, -0.1419941, 0.9418509>,
    <-0.3046143, -0.1420308, 0.9418266>,
    <-0.3045801, -0.1419980, 0.9418426>,
    <-0.3046570, -0.1419284, 0.9418282>,
    <-0.3061126, -0.1399379, 0.9416541>,
    <-0.3037931, -0.1386929, 0.9425890>,
    <-0.3054255, -0.1418313, 0.9415939>,
    <-0.2350604, -0.0867957, 0.9680977>,
    <-0.3133954, -0.1284979, 0.9408888>,
    <-0.3029114, -0.1298107, 0.9441366>,
    <-0.3025597, -0.1394173, 0.9428788>,
    <-0.2987583, -0.1317881, 0.9451854>,
    <-0.2967543, -0.1314944, 0.9458573>,
    <-0.3013069, -0.1404610, 0.9431251>,
    <-0.3013069, -0.1404610, 0.9431251>,
    <-0.3037401, -0.1416035, 0.9421732>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.3046096, -0.1420363, 0.9418273>,
    <-0.3046048, -0.1420414, 0.9418281>,
    <-0.3046085, -0.1420427, 0.9418267>,
    <-0.3046283, -0.1420251, 0.9418229>,
    <-0.3046143, -0.1420308, 0.9418266>,
    <-0.3045981, -0.1420398, 0.9418305>,
    <-0.3046052, -0.1420424, 0.9418278>,
    <-0.2161409, -0.1234541, 0.9685258>,
    <-0.3045965, -0.1420397, 0.9418310>,
    <-0.3045965, -0.1420397, 0.9418310>,
    <-0.3046043, -0.1420433, 0.9418280>,
    <-0.3047074, -0.1420539, 0.9417930>,
    <-0.3046043, -0.1420433, 0.9418280>,
    <-0.3047413, -0.1421072, 0.9417740>,
    <-0.3047413, -0.1421072, 0.9417740>,
    <-0.2350604, -0.0867957, 0.9680977>,
    <-0.3021470, -0.1082800, 0.9470917>,
    <-0.3044812, -0.1082692, 0.9463451>,
    <-0.3107185, -0.0952985, 0.9457125>,
    <-0.3137875, -0.0920019, 0.9450254>,
    <-0.3163657, -0.0847568, 0.9448434>,
    <-0.2972071, -0.0795902, 0.9514901>,
    <-0.2972071, -0.0795902, 0.9514901>,
    <-0.2967543, -0.1314944, 0.9458573>,
    <-0.3178977, -0.1022040, 0.9426003>,
    <-0.3169993, -0.0906793, 0.9440809>,
    <-0.2350604, -0.0867957, 0.9680977>,
    <-0.3270811, -0.0924811, 0.9404601>,
    <-0.3230957, -0.0880956, 0.9422570>,
    <-0.3213686, -0.0877528, 0.9428795>,
    <-0.3240256, -0.0870076, 0.9420388>,
    <-0.3247301, -0.0870185, 0.9417952>,
    <-0.3237229, -0.0867422, 0.9421673>,
    <-0.3237229, -0.0867422, 0.9421673>,
    <-0.3163657, -0.0847568, 0.9448434>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.3314294, -0.0895344, 0.9392221>,
    <-0.3276986, -0.0882331, 0.9406533>,
    <-0.3287818, -0.0888864, 0.9402137>,
    <-0.3311910, -0.0899561, 0.9392659>,
    <-0.3361742, -0.0921307, 0.9372827>,
    <-0.3377349, -0.0920502, 0.9367294>,
    <-0.3395858, -0.0910035, 0.9361623>,
    <-0.3294692, -0.0882927, 0.9400289>,
    <-0.3294692, -0.0882927, 0.9400289>,
    <-0.3262672, -0.0874342, 0.9412253>,
    <-0.3254685, -0.0874037, 0.9415046>,
    <-0.3266999, -0.0883430, 0.9409903>,
    <-0.3262672, -0.0874342, 0.9412253>,
    <-0.3249152, -0.0870708, 0.9417265>,
    <-0.3249152, -0.0870708, 0.9417265>,
    <-0.3247301, -0.0870185, 0.9417952>,
    <-0.3293422, -0.0900060, 0.9399110>,
    <-0.2350604, -0.0867957, 0.9680977>,
    <-0.3349129, -0.0922938, 0.9377181>,
    <-0.3366053, 0.0902742, 0.9373086>,
    <-0.3370922, 0.0906066, 0.9371015>,
    <-0.3366372, 0.0906278, 0.9372630>,
    <-0.3360350, 0.0902632, 0.9375143>,
    <-0.3355761, 0.0899323, 0.9377104>,
    <-0.3365449, 0.0901918, 0.9373382>,
    <-0.3365449, 0.0901918, 0.9373382>,
    <-0.3366258, 0.0902131, 0.9373071>,
    <-0.3366204, 0.0902230, 0.9373081>,
    <-0.3369235, 0.0903806, 0.9371840>,
    <-0.3398631, 0.0929091, 0.9358744>,
    <-0.3349146, 0.0910764, 0.9378365>,
    <-0.3390198, 0.0913888, 0.9363299>,
    <-0.2759421, 0.1004354, 0.9559125>,
    <-0.3334248, 0.0899189, 0.9384788>,
    <-0.3232518, 0.0887827, 0.9421390>,
    <-0.3327325, 0.0891705, 0.9387959>,
    <-0.3327325, 0.0891705, 0.9387959>,
    <-0.3355761, 0.0899323, 0.9377104>,
    <-0.3363454, 0.0900208, 0.9374263>,
    <-0.3356527, 0.0892474, 0.9377485>,
    <-0.3365877, 0.0901905, 0.9373230>,
    <-0.3366950, 0.0902429, 0.9372794>,
    <-0.3366258, 0.0902131, 0.9373071>,
    <-0.3342029, 0.0889112, 0.9382980>,
    <-0.3314717, 0.0851610, 0.9396138>,
    <-0.3373265, 0.0894320, 0.9371301>,
    <-0.3365781, 0.0901867, 0.9373268>,
    <-0.3446699, 0.0840825, 0.9349507>,
    <-0.2856231, 0.0498155, 0.9570464>,
    <-0.3403011, 0.0911831, 0.9358850>,
    <-0.3403011, 0.0911831, 0.9358850>,
    <-0.3365706, 0.0901835, 0.9373298>,
    <-0.3368296, 0.0902869, 0.9372268>,
    <-0.3365706, 0.0901835, 0.9373298>,
    <-0.3367238, 0.0902246, 0.9372708>,
    <-0.3367238, 0.0902246, 0.9372708>,
    <-0.2759421, 0.1004354, 0.9559125>,
    <-0.3168836, 0.0438677, 0.9474494>,
    <-0.3192255, 0.0461653, 0.9465537>,
    <-0.3131386, 0.0609918, 0.9477469>,
    <-0.3152912, 0.0678902, 0.9465635>,
    <-0.3087780, 0.0827486, 0.9475277>,
    <-0.2536671, 0.0679765, 0.9649001>,
    <-0.2536671, 0.0679765, 0.9649001>,
    <-0.3336640, 0.0312758, 0.9421731>,
    <-0.3349557, 0.0317179, 0.9416999>,
    <-0.3373592, 0.0343454, 0.9407493>,
    <-0.3387939, 0.0621655, 0.9388046>,
    <-0.3207123, 0.0732965, 0.9443364>,
    <-0.3564812, 0.0419067, 0.9333622>,
    <-0.2856231, 0.0498155, 0.9570464>,
    <-0.3278584, 0.0839754, 0.9409873>,
    <-0.3366258, 0.0902131, 0.9373071>,
    <-0.3331775, 0.0892884, 0.9386268>,
    <-0.3331775, 0.0892884, 0.9386268>,
    <-0.3087780, 0.0827486, 0.9475277>,
    <-0.3518934, -0.0928604, 0.9314225>,
    <-0.3521430, -0.0945650, 0.9311567>,
    <-0.3516694, -0.0945928, 0.9313328>,
    <-0.3510147, -0.0916290, 0.9318760>,
    <-0.3469101, -0.0794626, 0.9345261>,
    <-0.3452594, -0.0845842, 0.9346879>,
    <-0.3442287, -0.0852302, 0.9350093>,
    <-0.3514307, -0.0941771, 0.9314651>,
    <-0.3514307, -0.0941771, 0.9314651>,
    <-0.3529893, -0.0945948, 0.9308332>,
    <-0.3492064, -0.0945019, 0.9322684>,
    <-0.3502683, -0.0951297, 0.9318060>,
    <-0.3529893, -0.0945948, 0.9308332>,
    <-0.3503387, -0.0938847, 0.9319058>,
    <-0.3503387, -0.0938847, 0.9319058>,
    <-0.3395858, -0.0910035, 0.9361623>,
    <-0.3444756, -0.0941179, 0.9340655>,
    <-0.3473056, -0.0954503, 0.9328816>,
    <-0.3529193, -0.0929998, 0.9310204>,
    <-0.3503092, -0.0960728, 0.9316939>,
    <-0.2522172, -0.0444731, 0.9666481>,
    <-0.3610607, -0.0747328, 0.9295430>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.3420932, -0.0940221, 0.9349503>,
    <-0.3408708, -0.0940226, 0.9353966>,
    <-0.3433631, -0.0949266, 0.9343932>,
    <-0.3447657, -0.0952557, 0.9338431>,
    <-0.3395858, -0.0910035, 0.9361623>,
    <-0.3408587, -0.0944106, 0.9353619>,
    <-0.3442596, -0.0954432, 0.9340107>,
    <-0.2350604, -0.0867957, 0.9680977>,
    <-0.3419012, -0.0950540, 0.9349162>,
    <-0.3419012, -0.0950540, 0.9349162>,
    <-0.3449600, -0.0959044, 0.9337050>,
    <-0.3467745, -0.0961620, 0.9330061>,
    <-0.3449600, -0.0959044, 0.9337050>,
    <-0.3473106, -0.0965579, 0.9327657>,
    <-0.3473106, -0.0965579, 0.9327657>,
    <-0.2522172, -0.0444731, 0.9666481>,
    <-0.3431217, -0.0554138, 0.9376550>,
    <-0.3442190, -0.0530938, 0.9373870>,
    <-0.3499857, -0.0390545, 0.9359406>,
    <-0.3531573, -0.0363860, 0.9348561>,
    <-0.3553574, -0.0311079, 0.9342127>,
    <-0.3331496, -0.0291908, 0.9424220>,
    <-0.3331496, -0.0291908, 0.9424220>,
    <-0.3442287, -0.0852302, 0.9350093>,
    <-0.3602679, -0.0436656, 0.9318263>,
    <-0.3562922, -0.0337673, 0.9337642>,
    <-0.2522172, -0.0444731, 0.9666481>,
    <-0.3676215, -0.0320843, 0.9294219>,
    <-0.3609395, -0.0300045, 0.9321065>,
    <-0.3586534, -0.0313247, 0.9329451>,
    <-0.3577746, -0.0295546, 0.9333402>,
    <-0.3503080, -0.0306511, 0.9361329>,
    <-0.3603276, -0.0315323, 0.9322927>,
    <-0.3603276, -0.0315323, 0.9322927>,
    <-0.3553574, -0.0311079, 0.9342127>,
    <-0.3440425, 0.0299438, 0.9384765>,
    <-0.3445584, 0.0300292, 0.9382845>,
    <-0.3454054, 0.0303978, 0.9379611>,
    <-0.3452570, 0.0302971, 0.9380190>,
    <-0.3452968, 0.0302118, 0.9380071>,
    <-0.3449031, 0.0301774, 0.9381531>,
    <-0.3449031, 0.0301774, 0.9381531>,
    <-0.3408632, 0.0298239, 0.9396397>,
    <-0.3409789, 0.0293240, 0.9396135>,
    <-0.3417127, 0.0292982, 0.9393477>,
    <-0.3486243, 0.0318616, 0.9367208>,
    <-0.3445644, 0.0312713, 0.9382417>,
    <-0.3443638, 0.0298047, 0.9383631>,
    <-0.2856231, 0.0498155, 0.9570464>,
    <-0.3435579, 0.0305666, 0.9386339>,
    <-0.3336640, 0.0312758, 0.9421731>,
    <-0.3429638, 0.0300077, 0.9388692>,
    <-0.3429638, 0.0300077, 0.9388692>,
    <-0.3452968, 0.0302118, 0.9380071>,
    <-0.3382841, 0.0286345, 0.9406083>,
    <-0.3359071, 0.0276449, 0.9414893>,
    <-0.3373698, 0.0284471, 0.9409423>,
    <-0.3389206, 0.0287254, 0.9403764>,
    <-0.3408632, 0.0298239, 0.9396397>,
    <-0.3354780, 0.0280196, 0.9416312>,
    <-0.3308582, 0.0245420, 0.9433613>,
    <-0.3362418, 0.0273091, 0.9413797>,
    <-0.3365322, 0.0282742, 0.9412474>,
    <-0.3417633, 0.0211174, 0.9395488>,
    <-0.2946380, 0.0008217, 0.9556086>,
    <-0.3387927, 0.0283621, 0.9404335>,
    <-0.3387927, 0.0283621, 0.9404335>,
    <-0.3358747, 0.0281178, 0.9414869>,
    <-0.3385509, 0.0285480, 0.9405149>,
    <-0.3358747, 0.0281178, 0.9414869>,
    <-0.3374205, 0.0282472, 0.9409301>,
    <-0.3374205, 0.0282472, 0.9409301>,
    <-0.2856231, 0.0498155, 0.9570464>,
    <-0.3094775, -0.0115412, 0.9508367>,
    <-0.3124153, -0.0098594, 0.9498944>,
    <-0.3093369, 0.0050749, 0.9509390>,
    <-0.3124143, 0.0114137, 0.9498774>,
    <-0.3085200, 0.0269938, 0.9508348>,
    <-0.2544318, 0.0222610, 0.9668345>,
    <-0.2544318, 0.0222610, 0.9668345>,
    <-0.3225441, -0.0262067, 0.9461916>,
    <-0.3240934, -0.0260042, 0.9456676>,
    <-0.3276408, -0.0238290, 0.9445018>,
    <-0.3329218, 0.0018510, 0.9429526>,
    <-0.3185576, 0.0153515, 0.9477792>,
    <-0.3472868, -0.0195093, 0.9375560>,
    <-0.2946380, 0.0008217, 0.9556086>,
    <-0.3275262, 0.0245455, 0.9445232>,
    <-0.3408632, 0.0298239, 0.9396397>,
    <-0.3334702, 0.0291769, 0.9423090>,
    <-0.3334702, 0.0291769, 0.9423090>,
    <-0.3085200, 0.0269938, 0.9508348>,
    <-0.3421480, -0.0293126, 0.9391888>,
    <-0.3427959, -0.0287892, 0.9389687>,
    <-0.3391368, -0.0287371, 0.9402980>,
    <-0.3372124, -0.0290305, 0.9409809>,
    <-0.3353344, -0.0293384, 0.9416422>,
    <-0.3396493, -0.0297167, 0.9400826>,
    <-0.3396493, -0.0297167, 0.9400826>,
    <-0.3503080, -0.0306511, 0.9361329>,
    <-0.3502189, -0.0292750, 0.9362103>,
    <-0.3495191, -0.0287228, 0.9364889>,
    <-0.3436029, -0.0273499, 0.9387167>,
    <-0.3358853, -0.0277786, 0.9414932>,
    <-0.3506220, -0.0280103, 0.9360981>,
    <-0.2946380, 0.0008217, 0.9556086>,
    <-0.3325643, -0.0284789, 0.9426505>,
    <-0.3225441, -0.0262067, 0.9461916>,
    <-0.3311834, -0.0289749, 0.9431214>,
    <-0.3311834, -0.0289749, 0.9431214>,
    <-0.3353344, -0.0293384, 0.9416422>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, 0.0000000, 1.0000000>,
    <0.0000000, 0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.0000000, -0.0000000, 1.0000000>,
    <-0.3568276, -0.0289755, 0.9337208>,
    <-0.3612171, -0.0288554, 0.9320352>,
    <-0.3602985, -0.0286679, 0.9323965>,
    <-0.3562951, -0.0286594, 0.9339338>,
    <-0.3503080, -0.0306511, 0.9361329>,
    <-0.3653994, -0.0289311, 0.9304011>,
    <-0.3627268, -0.0285861, 0.9314570>,
    <-0.2522172, -0.0444731, 0.9666481>,
    <-0.3678096, -0.0287103, 0.9294578>,
    <-0.3678096, -0.0287103, 0.9294578>,
    <-0.3646724, -0.0284654, 0.9307007>,
    <-0.3579206, -0.0283711, 0.9333209>,
    <-0.3646724, -0.0284654, 0.9307007>,
    <-0.3607740, -0.0281611, 0.9322280>,
    <-0.3607740, -0.0281611, 0.9322280>,
    <-0.2946380, 0.0008217, 0.9556086>,
    <0.3909632, 0.0325954, -0.9198290>,
    <0.3727697, 0.0275779, -0.9275140>,
    <0.3670200, 0.0238516, -0.9299072>,
    <0.3781197, 0.0274833, -0.9253487>,
    <0.3998863, 0.0310772, -0.9160377>,
    <0.3997466, 0.0342146, -0.9159869>,
    <0.4039518, 0.0353413, -0.9140973>,
    <0.3993634, 0.0349399, -0.9161267>,
    <0.3993634, 0.0349399, -0.9161267>,
    <0.3691786, 0.0322990, -0.9287970>,
    <0.3321282, 0.0170747, -0.9430797>,
    <0.3541306, 0.0140680, -0.9350902>,
    <0.3691786, 0.0322990, -0.9287970>,
    <0.2996665, 0.0262175, -0.9536837>,
    <0.2996665, 0.0262175, -0.9536837>,
    <0.2595905, -0.0022898, -0.9657161>,
    <0.2961096, -0.0025817, -0.9551505>,
    <0.3456981, -0.0027594, -0.9383417>,
    <0.3760631, 0.0179423, -0.9264203>,
    <0.3772507, -0.0023045, -0.9261083>,
    <0.4768497, 0.0042163, -0.8789747>,
    <0.4097112, 0.0250629, -0.9118709>,
    <0.3871472, -0.0327355, -0.9214366>,
    <0.3653498, -0.0277551, -0.9304564>,
    <0.3607761, -0.0255580, -0.9323022>,
    <0.3744824, -0.0291117, -0.9267769>,
    <0.3751377, -0.0328049, -0.9263884>,
    <0.4001543, -0.0349928, -0.9157795>,
    <0.4001543, -0.0349928, -0.9157795>,
    <0.4038188, -0.0353117, -0.9141572>,
    <0.3956799, -0.0336465, -0.9177719>,
    <0.3910801, -0.0298934, -0.9198710>,
    <0.3594726, -0.0196906, -0.9329479>,
    <0.3486957, -0.0176694, -0.9370694>,
    <0.3993670, -0.0229605, -0.9165036>,
    <0.3367758, -0.0205684, -0.9413602>,
    <0.2595905, -0.0022898, -0.9657161>,
    <0.3148324, -0.0275291, -0.9487480>,
    <0.3148324, -0.0275291, -0.9487480>,
    <0.3751377, -0.0328049, -0.9263884>,
    <0.3873097, 0.0365168, -0.9212262>,
    <0.3577427, 0.0393195, -0.9329920>,
    <0.3630241, 0.0477628, -0.9305548>,
    <0.3753093, 0.0431194, -0.9258962>,
    <0.3750964, 0.0327997, -0.9264054>,
    <0.4001788, 0.0350002, -0.9157685>,
    <0.4001788, 0.0350002, -0.9157685>,
    <0.4039351, 0.0353340, -0.9141050>,
    <0.3900524, 0.0344566, -0.9201477>,
    <0.3603625, 0.0339439, -0.9321946>,
    <0.3410704, 0.0514084, -0.9386310>,
    <0.3537968, 0.0614718, -0.9333001>,
    <0.3342956, 0.0361181, -0.9417759>,
    <0.4240712, 0.0772212, -0.9023306>,
    <0.3546719, 0.0776268, -0.9317628>,
    <0.3559335, 0.0797709, -0.9311004>,
    <0.3488994, 0.0552569, -0.9355297>,
    <0.3395901, 0.0765204, -0.9374557>,
    <0.3211588, 0.0724243, -0.9442520>,
    <0.3147370, 0.0275131, -0.9487801>,
    <0.3147370, 0.0275131, -0.9487801>,
    <0.3750964, 0.0327997, -0.9264054>,
    <0.3951297, 0.0347904, -0.9179663>,
    <0.3975171, 0.0347772, -0.9169355>,
    <0.3795423, 0.0332045, -0.9245783>,
    <0.3696147, 0.0331928, -0.9285920>,
    <0.4039351, 0.0353340, -0.9141050>,
    <0.4039429, 0.0353379, -0.9141014>,
    <0.4039429, 0.0353379, -0.9141014>,
    <0.4039478, 0.0353399, -0.9140991>,
    <0.3951596, 0.0345151, -0.9179638>,
    <0.3756864, 0.0332247, -0.9261511>,
    <0.4039478, 0.0353399, -0.9140991>,
    <0.4039512, 0.0353410, -0.9140976>,
    <0.4039512, 0.0353410, -0.9140976>,
    <0.4039518, 0.0353413, -0.9140973>,
    <0.3997154, 0.0355166, -0.9159510>,
    <0.3969133, 0.0371669, -0.9171033>,
    <0.3522660, 0.0327343, -0.9353273>,
    <0.3934435, 0.0419499, -0.9183912>,
    <0.4085551, 0.0359869, -0.9120239>,
    <0.4215908, 0.0343495, -0.9061354>,
    <0.4357195, 0.0388929, -0.8992418>,
    <0.4248082, 0.0404703, -0.9043783>,
    <0.4039518, 0.0353413, -0.9140973>,
    <0.4460501, 0.0327340, -0.8944092>,
    <0.4615554, 0.0417200, -0.8861298>,
    <0.5157691, 0.0353399, -0.8559984>,
    <0.5242984, 0.0493081, -0.8501058>,
    <0.4547790, 0.0481734, -0.8893005>,
    <0.5159916, 0.0616411, -0.8543729>,
    <0.4079712, -0.0348622, -0.9123289>,
    <0.4236037, -0.0383914, -0.9050337>,
    <0.4355344, -0.0362323, -0.8994426>,
    <0.4221340, -0.0323375, -0.9059565>,
    <0.4038188, -0.0353117, -0.9141572>,
    <0.4029548, -0.0355218, -0.9145303>,
    <0.4050800, -0.0370071, -0.9135320>,
    <0.4488642, -0.0436329, -0.8925341>,
    <0.4629488, -0.0375293, -0.8855902>,
    <0.4041599, -0.0407506, -0.9137802>,
    <0.4235956, -0.0712045, -0.9030486>,
    <0.5183817, -0.0525823, -0.8535312>,
    <0.5306153, -0.0406686, -0.8466366>,
    <0.4546300, -0.0290997, -0.8902049>,
    <0.5287756, -0.0261279, -0.8483594>,
    <0.3998685, -0.0349641, -0.9159054>,
    <0.4006493, -0.0350419, -0.9155612>,
    <0.3918042, -0.0342709, -0.9194101>,
    <0.3913675, -0.0345677, -0.9195850>,
    <0.4038188, -0.0353117, -0.9141572>,
    <0.4037343, -0.0353038, -0.9141949>,
    <0.4037343, -0.0353038, -0.9141949>,
    <0.4037087, -0.0353052, -0.9142061>,
    <0.3992364, -0.0351146, -0.9161753>,
    <0.3850480, -0.0345750, -0.9222487>,
    <0.4037087, -0.0353052, -0.9142061>,
    <0.4037161, -0.0353161, -0.9142024>,
    <0.4037161, -0.0353161, -0.9142024>,
    <0.4037553, -0.0353418, -0.9141841>,
    <0.3949334, -0.0350795, -0.9180398>,
    <0.3750906, -0.0364760, -0.9262702>,
    <0.3767037, -0.0348417, -0.9256783>,
    <0.3582667, -0.0409357, -0.9327214>,
    <0.3896502, -0.0382796, -0.9201670>,
    <0.3735360, -0.0473648, -0.9264057>,
    <0.3646579, -0.0538157, -0.9295851>,
    <0.3658846, -0.0440726, -0.9296161>,
    <0.4037553, -0.0353418, -0.9141841>,
    <0.3992497, -0.0349840, -0.9161745>,
    <0.3992497, -0.0349840, -0.9161745>,
    <0.3691731, -0.0323977, -0.9287958>,
    <0.3481389, -0.0621774, -0.9353787>,
    <0.3516387, -0.0679880, -0.9336637>,
    <0.3691731, -0.0323977, -0.9287958>,
    <0.2998601, -0.0263787, -0.9536184>,
    <0.2998601, -0.0263787, -0.9536184>,
    <0.3304948, -0.0789064, -0.9405036>,
    <0.3430389, -0.0818212, -0.9357508>,
    <0.3473987, -0.0823011, -0.9340989>,
    <0.3443662, -0.0577644, -0.9370567>,
    <0.3347777, -0.0771524, -0.9391333>,
    <0.5733718, -0.0529047, -0.8175854>,
    <0.5816165, -0.0425730, -0.8123483>,
    <0.5857360, -0.0350450, -0.8097439>,
    <0.5804737, -0.0397401, -0.8133087>,
    <0.5691726, -0.0630503, -0.8197971>,
    <0.5983373, -0.0504088, -0.7996571>,
    <0.6027204, -0.0260016, -0.7975287>,
    <0.5899534, -0.0209776, -0.8071647>,
    <0.6226545, -0.0341988, -0.7817492>,
    <0.6913312, -0.0003031, -0.7225379>,
    <0.6319334, -0.0008129, -0.7750223>,
    <0.5987617, -0.0008211, -0.8009268>,
    <0.5729361, -0.0227344, -0.8192847>,
    <0.5615929, -0.0003992, -0.8274136>,
    <-0.4915174, 0.0516057, 0.8693374>,
    <-0.4403113, 0.0440413, 0.8967644>,
    <-0.4571814, 0.0366100, 0.8886197>,
    <-0.4824395, 0.0416343, 0.8749393>,
    <-0.5206981, 0.0456419, 0.8525200>,
    <-0.5400166, 0.0517120, 0.8400643>,
    <-0.5532002, 0.0536171, 0.8313211>,
    <-0.4898927, 0.0565647, 0.8699457>,
    <-0.4898927, 0.0565647, 0.8699457>,
    <-0.4178888, 0.0531483, 0.9069422>,
    <-0.3705466, 0.0325932, 0.9282419>,
    <-0.4360929, 0.0248605, 0.8995582>,
    <-0.4178888, 0.0531483, 0.9069422>,
    <-0.3288542, 0.0439645, 0.9433568>,
    <-0.3288542, 0.0439645, 0.9433568>,
    <-0.2685000, 0.0213888, 0.9630422>,
    <-0.3266850, 0.0141145, 0.9450279>,
    <-0.4175197, 0.0057905, 0.9086494>,
    <-0.4877658, 0.0266735, 0.8725669>,
    <-0.5052027, 0.0012496, 0.8629998>,
    <-0.6215737, 0.0099051, 0.7832931>,
    <-0.5149825, 0.0365710, 0.8564202>,
    <-0.6251981, 0.0388314, 0.7794995>,
    <-0.6469753, 0.0424521, 0.7613283>,
    <-0.6085616, 0.0431831, 0.7923308>,
    <-0.5869696, 0.0413207, 0.8085538>,
    <-0.5584927, 0.0423741, 0.8284264>,
    <-0.4940300, 0.0435536, 0.8683533>,
    <-0.3650889, 0.0702286, 0.9283200>,
    <-0.7110934, 0.0326205, 0.7023404>,
    <-0.7110934, 0.0326205, 0.7023404>,
    <-0.6963668, 0.0401177, 0.7165639>,
    <-0.6030652, 0.0475654, 0.7962725>,
    <-0.5728765, 0.0448717, 0.8184125>,
    <-0.6963668, 0.0401177, 0.7165639>,
    <-0.6303391, 0.0474866, 0.7748662>,
    <-0.6303391, 0.0474866, 0.7748662>,
    <-0.5532002, 0.0536171, 0.8313211>,
    <-0.5510829, 0.0408634, 0.8334494>,
    <-0.5863934, 0.0381326, 0.8091283>,
    <0.3853475, 0.1028452, -0.9170225>,
    <0.3812490, 0.1007411, -0.9189670>,
    <0.3726733, 0.0974558, -0.9228310>,
    <0.3749282, 0.0986977, -0.9217850>,
    <0.3904095, 0.1023683, -0.9149323>,
    <0.3896150, 0.1039719, -0.9150902>,
    <0.3916764, 0.1049500, -0.9140980>,
    <0.3905820, 0.1046569, -0.9145997>,
    <0.3905820, 0.1046569, -0.9145997>,
    <0.3829449, 0.1026107, -0.9180546>,
    <0.3664028, 0.0940596, -0.9256899>,
    <0.3640881, 0.0916037, -0.9268488>,
    <0.3829449, 0.1026107, -0.9180546>,
    <0.3615550, 0.0968798, -0.9273038>,
    <0.3615550, 0.0968798, -0.9273038>,
    <0.3211588, 0.0724243, -0.9442520>,
    <0.3643243, 0.0922088, -0.9266959>,
    <0.3916316, 0.0980945, -0.9148782>,
    <0.5737036, 0.0454392, -0.8178016>,
    <0.5796747, 0.0580408, -0.8127783>,
    <0.5776993, 0.0652344, -0.8136387>,
    <0.5710798, 0.0587732, -0.8187879>,
    <0.5825381, 0.0361104, -0.8120009>,
    <0.6020103, 0.0540675, -0.7966557>,
    <0.5963386, 0.0783641, -0.7988988>,
    <0.5769905, 0.0795410, -0.8128685>,
    <0.6199912, 0.0744183, -0.7810716>,
    <0.6808809, 0.1197499, -0.7225380>,
    <0.6204298, 0.1084153, -0.7767323>,
    <0.5815580, 0.1011040, -0.8071978>,
    <0.5536639, 0.0728270, -0.8295496>,
    <0.5351248, 0.0926614, -0.8396757>,
    <0.5949481, 0.0264232, -0.8033296>,
    <0.6115882, 0.0211645, -0.7908931>,
    <0.6244467, 0.0390305, -0.7800916>,
    <0.6264554, 0.0490830, -0.7779104>,
    <0.6304710, 0.0245203, -0.7758254>,
    <0.6358035, 0.0469105, -0.7704241>,
    <0.6751456, 0.0343290, -0.7368853>,
    <0.6881525, 0.0599735, -0.7230832>,
    <0.6454807, 0.0672300, -0.7608119>,
    <0.7009641, 0.0866798, -0.7079096>,
    <0.7221006, -0.0757560, -0.6876276>,
    <0.7293442, -0.0574259, -0.6817325>,
    <0.7385676, -0.0467216, -0.6725585>,
    <0.7377891, -0.0549660, -0.6727897>,
    <0.6881116, -0.0604341, -0.7230838>,
    <0.6708493, -0.0834304, -0.7368857>,
    <0.6807756, -0.1203469, -0.7225380>,
    <0.7447616, -0.0895676, -0.6612925>,
    <0.7548440, -0.0662619, -0.6525488>,
    <0.7465079, -0.0330368, -0.6645559>,
    <0.7475287, -0.0263621, -0.6637061>,
    <0.7634287, -0.0423889, -0.6444997>,
    <0.8118763, -0.0003195, -0.5838294>,
    <0.7708582, -0.0009125, -0.6370062>,
    <0.7571445, -0.0003548, -0.6532473>,
    <0.7450350, -0.0294318, -0.6663758>,
    <0.7424102, 0.0001795, -0.6699456>,
    <0.7053662, -0.0363583, -0.7079101>,
    <0.5770519, -0.0755301, -0.8132074>,
    <0.5989754, -0.0844620, -0.7963006>,
    <0.6171934, -0.0694850, -0.7837373>,
    <0.6191474, -0.0597482, -0.7829985>,
    <0.5339797, -0.0958691, -0.8400445>,
    <0.5808740, -0.1038776, -0.8073381>,
    <0.6235341, -0.0851205, -0.7771485>,
    <0.6331749, -0.0640955, -0.7713504>,
    <0.6200436, -0.1103174, -0.7767728>,
    <0.6458698, -0.0457651, -0.7620746>,
    <0.3814581, -0.1019597, -0.9187459>,
    <0.3617431, -0.0956072, -0.9273625>,
    <0.3636381, -0.0958338, -0.9265977>,
    <0.3800760, -0.1008834, -0.9194372>,
    <0.3849809, -0.1031340, -0.9171440>,
    <0.3908348, -0.1047021, -0.9144865>,
    <0.3908348, -0.1047021, -0.9144865>,
    <0.3915693, -0.1048983, -0.9141498>,
    <0.3863972, -0.1028939, -0.9165752>,
    <0.3828030, -0.0997378, -0.9184303>,
    <0.3430213, -0.0877208, -0.9352227>,
    <0.3531066, -0.0904936, -0.9311963>,
    <0.3812664, -0.0937709, -0.9196972>,
    <0.3670544, -0.0955726, -0.9252767>,
    <0.3304948, -0.0789064, -0.9405036>,
    <0.3682204, -0.0986434, -0.9244908>,
    <0.3682204, -0.0986434, -0.9244908>,
    <0.3849809, -0.1031340, -0.9171440>,
    <-0.3889717, -0.0500078, 0.9198914>,
    <-0.4135159, -0.0612250, 0.9084361>,
    <-0.4102589, -0.0631612, 0.9097793>,
    <-0.3902027, -0.0519936, 0.9192598>,
    <-0.3496800, -0.0335151, 0.9362695>,
    <-0.3160005, -0.0279746, 0.9483465>,
    <-0.2966683, -0.0259526, 0.9546279>,
    <-0.4081359, -0.0572983, 0.9111213>,
    <-0.4081359, -0.0572983, 0.9111213>,
    <-0.4148896, -0.0582464, 0.9080055>,
    <-0.3926008, -0.0639977, 0.9174797>,
    <-0.4153922, -0.0719293, 0.9067941>,
    <-0.4148896, -0.0582464, 0.9080055>,
    <-0.3726878, -0.0523217, 0.9264806>,
    <-0.3726878, -0.0523217, 0.9264806>,
    <-0.3394808, -0.0611036, 0.9386262>,
    <-0.3677483, -0.0704427, 0.9272535>,
    <-0.4202387, -0.0851378, 0.9034108>,
    <-0.4211993, -0.0663990, 0.9045343>,
    <-0.4638928, -0.0921522, 0.8810854>,
    <-0.5575411, -0.0906691, 0.8251830>,
    <-0.3929956, -0.0436119, 0.9185056>,
    <-0.3079965, -0.0086881, 0.9513478>,
    <-0.2876646, -0.0086427, 0.9576922>,
    <-0.3109405, -0.0142871, 0.9503220>,
    <-0.3354007, -0.0170766, 0.9419208>,
    <-0.3846181, -0.0231717, 0.9227849>,
    <-0.3344685, -0.0090798, 0.9423632>,
    <-0.2685000, 0.0213888, 0.9630422>,
    <-0.2785627, -0.0012990, 0.9604172>,
    <-0.2785627, -0.0012990, 0.9604172>,
    <-0.2564708, -0.0011960, 0.9665512>,
    <-0.2796217, -0.0117903, 0.9600378>,
    <-0.3183371, -0.0194208, 0.9477786>,
    <-0.2564708, -0.0011960, 0.9665512>,
    <-0.2337714, -0.0010901, 0.9722910>,
    <-0.2337714, -0.0010901, 0.9722910>,
    <-0.2966683, -0.0259526, 0.9546279>,
    <-0.3557028, -0.0254814, 0.9342517>,
    <-0.4346675, -0.0388995, 0.8997505>,
    <-0.3604494, -0.0062507, 0.9327578>,
    <-0.4296663, -0.0256673, 0.9026229>,
    <-0.4564064, -0.0233340, 0.8894654>,
    <-0.4331458, -0.0114399, 0.9012513>,
    <-0.2685000, 0.0213888, 0.9630422>,
    <-0.5127464, -0.0466093, 0.8572740>,
    <-0.5190149, -0.0349620, 0.8540498>,
    <-0.6240855, -0.0706108, 0.7781590>,
    <-0.6172750, -0.0507536, 0.7851087>,
    <-0.5119683, -0.0197647, 0.8587769>,
    <-0.6056841, -0.0293285, 0.7951645>,
    <-0.4279209, 0.0563665, 0.9020568>,
    <-0.5329964, 0.0493195, 0.8446789>,
    <-0.5214410, 0.0575543, 0.8513441>,
    <-0.4789227, 0.0662520, 0.8753535>,
    <-0.4488212, 0.0811755, 0.8899270>,
    <-0.3554131, 0.0722252, 0.9319147>,
    <-0.3650889, 0.0702286, 0.9283200>,
    <-0.6072943, 0.0435753, 0.7932810>,
    <-0.5693667, 0.0568846, 0.8201132>,
    <-0.6794516, 0.0388703, 0.7326900>,
    <-0.6502292, 0.0579746, 0.7575229>,
    <-0.5423052, 0.0717284, 0.8371141>,
    <-0.6243370, 0.0776076, 0.7772904>,
    <-0.6233131, 0.1177887, 0.7730502>,
    <-0.5294714, 0.0914666, 0.8433824>,
    <-0.7072823, 0.0739622, 0.7030515>,
    <-0.7145384, 0.0548436, 0.6974432>,
    <-0.7273805, 0.0472709, 0.6846043>,
    <-0.7265727, 0.0571944, 0.6847050>,
    <-0.7524180, 0.0657666, 0.6553944>,
    <-0.7345754, 0.0877082, 0.6728345>,
    <-0.7196139, 0.0317972, 0.6936460>,
    <-0.7358716, 0.0277528, 0.6765521>,
    <-0.7191225, 0.0018656, 0.6948808>,
    <-0.7473118, 0.0013008, 0.6644723>,
    <-0.7458388, 0.0334580, 0.6652857>,
    <-0.7697229, 0.0011241, 0.6383771>,
    <-0.8118679, 0.0003536, 0.5838411>,
    <-0.7645677, 0.0424938, 0.6431411>,
    <0.7242855, 0.0507865, -0.6876272>,
    <0.7282361, 0.0700959, -0.6817322>,
    <0.7354607, 0.0822393, -0.6725580>,
    <0.7361257, 0.0739850, -0.6727891>,
    <0.7490003, 0.0411197, -0.6612924>,
    <0.7548826, 0.0658221, -0.6525486>,
    <0.7409039, 0.0970950, -0.6645555>,
    <0.7407503, 0.1038456, -0.6637056>,
    <0.7591914, 0.0908231, -0.6444995>,
    <0.7995979, 0.1406664, -0.5838289>,
    <0.7593060, 0.1329597, -0.6370056>,
    <0.7457039, 0.1311275, -0.6532467>,
    <0.7388275, 0.1003895, -0.6663752>,
    <0.7311005, 0.1290951, -0.6699452>,
    <0.7676040, 0.0333887, -0.6400541>,
    <0.7657672, 0.0263298, -0.6425786>,
    <0.7721859, 0.0482916, -0.6335588>,
    <0.7811386, 0.0610837, -0.6213624>,
    <0.7669537, 0.0296233, -0.6410183>,
    <0.7703506, 0.0568642, -0.6350798>,
    <0.7974229, 0.0404765, -0.6020618>,
    <0.8083721, 0.0704788, -0.5844375>,
    <0.7816058, 0.0816278, -0.6184086>,
    <0.8185176, 0.1013424, -0.5654720>,
    <0.8306143, -0.0872889, -0.5499641>,
    <0.8330887, -0.0657119, -0.5492223>,
    <0.8428500, -0.0532823, -0.5355044>,
    <0.8453499, -0.0629461, -0.5304916>,
    <0.8083297, -0.0709643, -0.5844375>,
    <0.7923371, -0.0986094, -0.6020615>,
    <0.7994868, -0.1412954, -0.5838292>,
    <0.8474969, -0.1020008, -0.5209077>,
    <0.8530740, -0.0748539, -0.5163928>,
    <0.8451534, -0.0373624, -0.5332164>,
    <0.8493133, -0.0297632, -0.5270494>,
    <0.8575145, -0.0474781, -0.5122643>,
    <0.8921705, -0.0002982, -0.4516987>,
    <0.8635875, -0.0010680, -0.5041979>,
    <0.8559273, -0.0003504, -0.5170960>,
    <0.8512155, -0.0334148, -0.5237514>,
    <0.8478485, 0.0003638, -0.5302384>,
    <0.8236803, -0.0423312, -0.5654722>,
    <0.7617405, -0.1004115, -0.6400538>,
    <0.7587060, -0.1070442, -0.6425782>,
    <0.7688407, -0.0865307, -0.6335585>,
    <0.7798786, -0.0754876, -0.6213622>,
    <0.7311628, -0.1287414, -0.6699452>,
    <0.7455806, -0.1318262, -0.6532468>,
    <0.7604463, -0.1040068, -0.6410180>,
    <0.7685218, -0.0777697, -0.6350796>,
    <0.7589890, -0.1347567, -0.6370058>,
    <0.7839060, -0.0553368, -0.6184086>,
    <-0.6983980, -0.0485383, 0.7140618>,
    <-0.6949992, -0.0670322, 0.7158791>,
    <-0.7155170, -0.0780300, 0.6942238>,
    <-0.7211222, -0.0691986, 0.6893434>,
    <-0.7507633, -0.0657035, 0.6572956>,
    <-0.7339289, -0.0405555, 0.6780144>,
    <-0.6917393, -0.0888036, 0.7166664>,
    <-0.7208804, -0.0982828, 0.6860554>,
    <-0.6882039, -0.1182453, 0.7158166>,
    <-0.7285718, -0.1265238, 0.6731826>,
    <-0.7381453, -0.0960293, 0.6677723>,
    <-0.7565467, -0.1320864, 0.6404610>,
    <-0.7995952, -0.1406311, 0.5838411>,
    <-0.7600730, -0.0909004, 0.6434487>,
    <-0.7543729, -0.0327023, 0.6556310>,
    <-0.7752954, -0.0605464, 0.6286900>,
    <-0.7692363, -0.0480782, 0.6371531>,
    <-0.7597995, -0.0260695, 0.6496346>,
    <-0.7810245, -0.0814606, 0.6191647>,
    <-0.7715654, -0.0569266, 0.6335978>,
    <-0.8171777, -0.1011091, 0.5674483>,
    <-0.8083661, -0.0704521, 0.5844491>,
    <-0.7677651, -0.0296911, 0.6400431>,
    <-0.7987550, -0.0405528, 0.6002883>,
    <-0.8306124, 0.0872351, 0.5499755>,
    <-0.8436270, 0.0628463, 0.5332389>,
    <-0.8428411, 0.0533113, 0.5355155>,
    <-0.8347234, 0.0657988, 0.5467242>,
    <-0.8530649, 0.0748768, 0.5164046>,
    <-0.8462533, 0.1018249, 0.5229598>,
    <-0.7994724, 0.1413276, 0.5838410>,
    <-0.7936618, 0.0987657, 0.6002885>,
    <-0.8083188, 0.0709896, 0.5844494>,
    <-0.8492942, 0.0334541, 0.5268588>,
    <-0.8493025, 0.0298665, 0.5270609>,
    <-0.8223202, 0.0423284, 0.5674485>,
    <-0.8469363, -0.0002739, 0.5316942>,
    <-0.8559198, 0.0003884, 0.5171084>,
    <-0.8469283, 0.0374713, 0.5303852>,
    <-0.8644078, 0.0010551, 0.5027903>,
    <-0.8921598, 0.0003306, 0.4517198>,
    <-0.8586632, 0.0476171, 0.5103235>,
    <-0.7501552, 0.0988767, 0.6538277>,
    <-0.7747962, 0.0750444, 0.6277413>,
    <-0.7662156, 0.0862644, 0.6367670>,
    <-0.7532246, 0.1063012, 0.6491169>,
    <-0.7360094, 0.1309945, 0.6641766>,
    <-0.7094349, 0.1265778, 0.6933110>,
    <-0.7834517, 0.0554068, 0.6189778>,
    <-0.7698055, 0.0779270, 0.6335036>,
    <-0.7613552, 0.1040917, 0.6399244>,
    <-0.7578922, 0.1347631, 0.6383089>,
    <-0.5184551, 0.1409787, 0.8434034>,
    <-0.4661904, 0.1244358, 0.8758894>,
    <-0.4829108, 0.1194316, 0.8674868>,
    <-0.5059707, 0.1283734, 0.8529443>,
    <-0.5414888, 0.1383233, 0.8292506>,
    <-0.5680938, 0.1493342, 0.8093014>,
    <-0.5842066, 0.1541919, 0.7968234>,
    <-0.5174534, 0.1460309, 0.8431589>,
    <-0.5174534, 0.1460309, 0.8431589>,
    <-0.4414090, 0.1296972, 0.8878833>,
    <-0.3937888, 0.0999380, 0.9137520>,
    <-0.4621549, 0.1035363, 0.8807344>,
    <-0.4414090, 0.1296972, 0.8878833>,
    <-0.3460547, 0.1039186, 0.9324415>,
    <-0.3460547, 0.1039186, 0.9324415>,
    <-0.3650889, 0.0702286, 0.9283200>,
    <-0.5094109, 0.1134917, 0.8530065>,
    <-0.5277752, 0.1267803, 0.8398691>,
    <0.8331530, 0.0582718, -0.5499641>,
    <0.8318430, 0.0799506, -0.5492223>,
    <0.8392977, 0.0938864, -0.5355042>,
    <0.8434377, 0.0848036, -0.5304915>,
    <0.8523336, 0.0467150, -0.5209079>,
    <0.8531121, 0.0744179, -0.5163930>,
    <0.8388016, 0.1099645, -0.5332163>,
    <0.8415788, 0.1181707, -0.5270491>,
    <0.8527313, 0.1021489, -0.5122645>,
    <0.8786680, 0.1546300, -0.4516991>,
    <0.8506532, 0.1489085, -0.5041978>,
    <0.8429850, 0.1482851, -0.5170956>,
    <0.8440863, 0.1149049, -0.5237510>,
    <0.8349050, 0.1475857, -0.5302378>,
    <0.8657865, 0.0377005, -0.4989914>,
    <0.8614609, 0.0295333, -0.5069644>,
    <0.8652431, 0.0541523, -0.4984195>,
    <0.8734191, 0.0684645, -0.4821324>,
    <0.8591570, 0.0330877, -0.5106412>,
    <0.8611087, 0.0636035, -0.5044267>,
    <0.8804567, 0.0446719, -0.4720174>,
    <0.8885083, 0.0775059, -0.4522674>,
    <0.8702509, 0.0910601, -0.4841192>,
    <0.8953111, 0.1109535, -0.4314016>,
    <0.9024874, -0.0949129, -0.4201285>,
    <0.9031755, -0.0712919, -0.4233101>,
    <0.9117561, -0.0575886, -0.4066748>,
    <0.9148204, -0.0680725, -0.3980826>,
    <0.8884689, -0.0779593, -0.4522669>,
    <0.8748380, -0.1088963, -0.4720170>,
    <0.8785648, -0.1552174, -0.4516984>,
    <0.9140985, -0.1100394, -0.3902758>,
    <0.9177366, -0.0804846, -0.3889497>,
    <0.9117618, -0.0402528, -0.4087421>,
    <0.9164750, -0.0319662, -0.3988129>,
    <0.9203346, -0.0508434, -0.3878132>,
    <0.9443370, -0.0002481, -0.3289796>,
    <0.9251772, -0.0011397, -0.3795338>,
    <0.9209981, -0.0003100, -0.3895669>,
    <0.9195227, -0.0359347, -0.3913908>,
    <0.9166547, 0.0005260, -0.3996797>,
    <0.9009764, -0.0462011, -0.4314012>,
    <0.8591802, -0.1132144, -0.4989909>,
    <0.8535021, -0.1205064, -0.5069640>,
    <0.8615018, -0.0969181, -0.4984190>,
    <0.8720389, -0.0842431, -0.4821320>,
    <0.8350312, -0.1468691, -0.5302380>,
    <0.8428633, -0.1489753, -0.5170955>,
    <0.8518504, -0.1166059, -0.5106408>,
    <0.8590714, -0.0868926, -0.5044263>,
    <0.8502825, -0.1510122, -0.5041974>,
    <0.8728425, -0.0614406, -0.4841189>,
    <0.3750160, 0.1031742, -0.9212590>,
    <0.3454146, 0.1008049, -0.9330204>,
    <0.3491241, 0.1100234, -0.9305951>,
    <0.3620138, 0.1075728, -0.9259450>,
    <0.3635838, 0.0973592, -0.9264599>,
    <0.3879500, 0.1039106, -0.9158042>,
    <0.3879500, 0.1039106, -0.9158042>,
    <0.3916214, 0.1049131, -0.9141258>,
    <0.3781024, 0.1016387, -0.9201674>,
    <0.3489565, 0.0959811, -0.9322108>,
    <0.3268949, 0.1098182, -0.9386585>,
    <0.3376441, 0.1219207, -0.9333444>,
    <0.3229106, 0.0936000, -0.9417897>,
    <0.4042029, 0.1496801, -0.9023391>,
    <0.3357359, 0.1380073, -0.9317915>,
    <0.3365632, 0.1403201, -0.9311474>,
    <0.3338573, 0.1149256, -0.9355915>,
    <0.3209799, 0.1342587, -0.9375215>,
    <0.3035091, 0.1270114, -0.9443253>,
    <0.3049905, 0.0816375, -0.9488499>,
    <0.3049905, 0.0816375, -0.9488499>,
    <0.3635838, 0.0973592, -0.9264599>,
    <0.3830629, 0.1028617, -0.9179773>,
    <0.3854295, 0.1032715, -0.9169401>,
    <0.3680058, 0.0986025, -0.9245806>,
    <0.3582211, 0.0968608, -0.9285987>,
    <0.3916214, 0.1049131, -0.9141258>,
    <0.3916464, 0.1049317, -0.9141129>,
    <0.3916464, 0.1049317, -0.9141129>,
    <0.3916629, 0.1049423, -0.9141046>,
    <0.3831619, 0.1026088, -0.9179643>,
    <0.3642099, 0.0979558, -0.9261511>,
    <0.3916629, 0.1049423, -0.9141046>,
    <0.3916747, 0.1049486, -0.9140989>,
    <0.3916747, 0.1049486, -0.9140989>,
    <0.3916764, 0.1049500, -0.9140980>,
    <0.3874754, 0.1043870, -0.9159510>,
    <0.3844298, 0.1055251, -0.9171032>,
    <0.3412209, 0.0934009, -0.9353313>,
    <0.3801779, 0.1096309, -0.9183931>,
    <0.3964564, 0.1066221, -0.9118410>,
    <0.4103067, 0.1080210, -0.9055274>,
    <0.4234130, 0.1144608, -0.8986769>,
    <0.4115808, 0.1137339, -0.9042488>,
    <0.3916764, 0.1049500, -0.9140980>,
    <0.4352316, 0.1113396, -0.8934075>,
    <0.4490156, 0.1220467, -0.8851495>,
    <0.5033488, 0.1264292, -0.8547840>,
    <0.5089963, 0.1405012, -0.8492245>,
    <0.4398984, 0.1265816, -0.8890818>,
    <0.4977024, 0.1504730, -0.8541957>,
    <0.3964501, -0.1056588, -0.9119559>,
    <0.4110891, -0.1116760, -0.9047288>,
    <0.4241514, -0.1123240, -0.8985983>,
    <0.4114384, -0.1065924, -0.9051832>,
    <0.3915693, -0.1048983, -0.9141498>,
    <0.3906743, -0.1049554, -0.9145261>,
    <0.3925046, -0.1067865, -0.9135299>,
    <0.4351727, -0.1213012, -0.8921383>,
    <0.4506464, -0.1185779, -0.8847921>,
    <0.3909436, -0.1103119, -0.9137803>,
    <0.4047846, -0.1436745, -0.9030543>,
    <0.5008480, -0.1419330, -0.8538186>,
    <0.5121668, -0.1325864, -0.8485906>,
    <0.4420919, -0.1094707, -0.8902645>,
    <0.5060019, -0.1180659, -0.8544136>,
    <0.3877240, -0.1038678, -0.9159048>,
    <0.3884711, -0.1040765, -0.9155645>,
    <0.3798986, -0.1017827, -0.9194114>,
    <0.3794212, -0.1020015, -0.9195843>,
    <0.3915693, -0.1048983, -0.9141498>,
    <0.3914681, -0.1048715, -0.9141962>,
    <0.3914681, -0.1048715, -0.9141962>,
    <0.3914345, -0.1048658, -0.9142112>,
    <0.3870583, -0.1038972, -0.9161830>,
    <0.3731871, -0.1009052, -0.9222524>,
    <0.3914345, -0.1048658, -0.9142112>,
    <0.3914329, -0.1048733, -0.9142111>,
    <0.3914329, -0.1048733, -0.9142111>,
    <0.3914567, -0.1048962, -0.9141983>,
    <0.3828163, -0.1031067, -0.9180527>,
    <0.3630380, -0.1010395, -0.9262799>,
    <0.3649275, -0.0997222, -0.9256800>,
    <0.3456983, -0.1025139, -0.9327291>,
    <0.5537212, -0.1514669, -0.8188105>,
    <0.5640980, -0.1427929, -0.8132672>,
    <0.5655732, -0.1357495, -0.8134488>,
    <0.5575242, -0.1393007, -0.8183900>,
    <0.5495758, -0.1609276, -0.8197980>,
    <0.5804934, -0.1535430, -0.7996574>,
    <0.5872671, -0.1301356, -0.7988630>,
    <0.5698234, -0.1225008, -0.8125853>,
    <0.6072564, -0.1418020, -0.7817493>,
    <0.5459063, -0.1207662, -0.8290970>,
    <0.3770392, -0.1053278, -0.9201888>,
    <0.3595594, -0.1114585, -0.9264416>,
    <0.3497078, -0.1162786, -0.9296148>,
    <0.3526319, -0.1069099, -0.9296349>,
    <0.3914567, -0.1048962, -0.9141983>,
    <0.3870633, -0.1037458, -0.9161980>,
    <0.3870633, -0.1037458, -0.9161980>,
    <0.3578589, -0.0959535, -0.9288326>,
    <0.3319312, -0.1216185, -0.9354307>,
    <0.3344085, -0.1279712, -0.9336993>,
    <0.3578589, -0.0959535, -0.9288326>,
    <0.2905852, -0.0779605, -0.9536679>,
    <0.2905852, -0.0779605, -0.9536679>,
    <0.3115924, -0.1350196, -0.9405742>,
    <0.3234684, -0.1400808, -0.9358128>,
    <0.3277294, -0.1413326, -0.9341405>,
    <0.3290593, -0.1166588, -0.9370756>,
    <0.3162359, -0.1340887, -0.9391566>,
    <-0.8331419, -0.0583246, 0.5499752>,
    <-0.8417238, -0.0846028, 0.5332387>,
    <-0.8392940, -0.0938565, 0.5355153>,
    <-0.8334680, -0.0801491, 0.5467241>,
    <-0.8531072, -0.0743940, 0.5164045>,
    <-0.8510786, -0.0466724, 0.5229598>,
    <-0.8422009, -0.1145326, 0.5268586>,
    <-0.8415861, -0.1180671, 0.5270607>,
    <-0.8340220, -0.1473387, 0.5316941>,
    <-0.8429841, -0.1482465, 0.5171081>,
    <-0.8405685, -0.1101656, 0.5303850>,
    <-0.8514589, -0.1490639, 0.5027900>,
    <-0.8786634, -0.1545963, 0.4517197>,
    <-0.8538868, -0.1022116, 0.5103235>,
    <-0.8639618, -0.0375903, 0.5021523>,
    <-0.8718607, -0.0682469, 0.4849756>,
    <-0.8652367, -0.0541233, 0.4984336>,
    <-0.8614521, -0.0295675, 0.5069774>,
    <-0.8702520, -0.0909610, 0.4841359>,
    <-0.8626178, -0.0636884, 0.5018310>,
    <-0.8942821, -0.1107628, 0.4335795>,
    <-0.8884999, -0.0774804, 0.4522884>,
    <-0.8608616, -0.0331947, 0.5077553>,
    <-0.8815196, -0.0447337, 0.4700234>,
    <-0.9024814, 0.0948612, 0.4201532>,
    <-0.9135278, 0.0680027, 0.4010519>,
    <-0.9117438, 0.0576148, 0.4066987>,
    <-0.9044441, 0.0713508, 0.4205828>,
    <-0.9177249, 0.0805052, 0.3889728>,
    <-0.9131661, 0.1099019, 0.3924911>,
    <-0.8785485, 0.1552475, 0.4517198>,
    <-0.8758954, 0.1090201, 0.4700232>,
    <-0.8884560, 0.0779831, 0.4522881>,
    <-0.9180901, 0.0359856, 0.3947348>,
    <-0.9164618, 0.0320625, 0.3988356>,
    <-0.8999298, 0.0462103, 0.4335793>,
    <-0.9159629, -0.0004426, 0.4012628>,
    <-0.9209891, 0.0003436, 0.3895881>,
    <-0.9131309, 0.0403406, 0.4056657>,
    <-0.9257958, 0.0011240, 0.3780223>,
    <-0.9443373, 0.0002753, 0.3289788>,
    <-0.9212055, 0.0509621, 0.3857243>,
    <-0.8573639, 0.1130062, 0.5021522>,
    <-0.8704662, 0.0841869, 0.4849755>,
    <-0.8614904, 0.0969457, 0.4984334>,
    <-0.8534991, 0.1204713, 0.5069772>,
    <-0.8428492, 0.1490114, 0.5171082>,
    <-0.8341172, 0.1467992, 0.5316940>,
    <-0.8728262, 0.0615385, 0.4841358>,
    <-0.8605722, 0.0870712, 0.5018307>,
    <-0.8535475, 0.1167966, 0.5077551>,
    <-0.8510924, 0.1511418, 0.5027901>,
    <0.9052579, 0.0632441, -0.4201289>,
    <0.9018338, 0.0866258, -0.4233105>,
    <0.9079044, 0.1016109, -0.4066753>,
    <0.9127427, 0.0918183, -0.3980831>,
    <0.9193194, 0.0503637, -0.3902760>,
    <0.9177700, 0.0801012, -0.3889498>,
    <0.9048998, 0.1186843, -0.4087424>,
    <0.9081024, 0.1276635, -0.3988133>,
    <0.9151815, 0.1097433, -0.3878133>,
    <0.9300335, 0.1637381, -0.3289795>,
    <0.9113194, 0.1595328, -0.3795341>,
    <0.9070597, 0.1596242, -0.3895675>,
    <0.9117929, 0.1242845, -0.3913913>,
    <0.9026371, 0.1596933, -0.3996802>,
    <0.9286744, 0.0404944, -0.3686788>,
    <0.9243724, 0.0316672, -0.3801747>,
    <0.9263152, 0.0580290, -0.3722536>,
    <0.9324996, 0.0732240, -0.3536705>,
    <0.9211545, 0.0354435, -0.3875797>,
    <0.9219216, 0.0681478, -0.3813352>,
    <0.9354569, 0.0474770, -0.3502374>,
    <0.9405990, 0.0821017, -0.3294432>,
    <0.9282550, 0.0972654, -0.3590014>,
    <0.9442106, 0.1171080, -0.3078181>,
    <0.9488063, -0.0998058, -0.2996756>,
    <0.9492330, -0.0749361, -0.3055180>,
    <0.9559863, -0.0603205, -0.2871439>,
    <0.9584086, -0.0712580, -0.2763607>,
    <0.9405658, -0.0824788, -0.3294439>,
    <0.9294893, -0.1156846, -0.3502380>,
    <0.9299472, -0.1642267, -0.3289800>,
    <0.9559823, -0.1150689, -0.2699205>,
    <0.9589867, -0.0840511, -0.2707027>,
    <0.9554436, -0.0421148, -0.2921538>,
    <0.9594783, -0.0333339, -0.2798038>,
    <0.9609639, -0.0529892, -0.2715521>,
    <0.9767217, -0.0001768, -0.2145103>,
    <0.9647438, -0.0011460, -0.2631884>,
    <0.9625319, -0.0002403, -0.2711682>,
    <0.9621747, -0.0374648, -0.2698449>,
    <0.9602532, 0.0006739, -0.2791296>,
    <0.9502014, -0.0486315, -0.3078187>,
    <0.9215975, -0.1213833, -0.3686789>,
    <0.9158279, -0.1293293, -0.3801751>,
    <0.9223189, -0.1037054, -0.3722540>,
    <0.9310480, -0.0898151, -0.3536707>,
    <0.9028200, -0.1586573, -0.3996798>,
    <0.9069521, -0.1602349, -0.3895674>,
    <0.9133146, -0.1250516, -0.3875803>,
    <0.9197490, -0.0929774, -0.3813357>,
    <0.9109235, -0.1617777, -0.3795344>,
    <0.9310426, -0.0654019, -0.3590018>,
    <-0.6229827, 0.1456648, 0.7685533>,
    <-0.6632932, 0.1560118, 0.7319169>,
    <-0.6158207, 0.1488152, 0.7737047>,
    <-0.5811059, 0.1413894, 0.8014518>,
    <-0.5391469, 0.1358335, 0.8311858>,
    <-0.4727762, 0.1252155, 0.8722407>,
    <-0.3400039, 0.1297656, 0.9314281>,
    <-0.7260430, 0.1555413, 0.6698272>,
    <-0.7260430, 0.1555413, 0.6698272>,
    <-0.7247592, 0.1634906, 0.6693242>,
    <-0.6301608, 0.1555156, 0.7607314>,
    <-0.5876908, 0.1454458, 0.7959052>,
    <-0.7247592, 0.1634906, 0.6693242>,
    <-0.6634191, 0.1610825, 0.7307034>,
    <-0.6634191, 0.1610825, 0.7307034>,
    <-0.5842066, 0.1541919, 0.7968234>,
    <-0.5524103, 0.1358102, 0.8224345>,
    <-0.5730181, 0.1375615, 0.8079152>,
    <0.9517230, 0.0664689, -0.2996753>,
    <0.9478246, 0.0910348, -0.3055178>,
    <0.9519374, 0.1066011, -0.2871435>,
    <0.9562222, 0.0962503, -0.2763601>,
    <0.9614402, 0.0526837, -0.2699205>,
    <0.9590128, 0.0837519, -0.2707028>,
    <0.9482415, 0.1244360, -0.2921538>,
    <0.9506902, 0.1337842, -0.2798034>,
    <0.9555661, 0.1146853, -0.2715524>,
    <0.9619137, 0.1694317, -0.2145107>,
    <0.9502862, 0.1663974, -0.2631883>,
    <0.9479508, 0.1669053, -0.2711678>,
    <0.9540630, 0.1301842, -0.2698443>,
    <0.9455479, 0.1674100, -0.2791290>,
    <0.9676034, 0.0422594, -0.2489134>,
    <0.9643869, 0.0330611, -0.2624210>,
    <0.9650360, 0.0605202, -0.2550351>,
    <0.9689227, 0.0761903, -0.2353377>,
    <0.9615291, 0.0370126, -0.2721983>,
    <0.9613446, 0.0711250, -0.2660034>,
    <0.9704771, 0.0492944, -0.2361021>,
    <0.9729458, 0.0849861, -0.2148344>,
    <0.9648198, 0.1012075, -0.2426515>,
    <0.9737225, 0.1208579, -0.1930230>,
    <0.9727375, -0.1023005, -0.2081260>,
    <0.9547087, -0.0751311, -0.2879003>,
    <0.9702934, -0.0611527, -0.2340749>,
    <0.9813647, -0.0728977, -0.1777898>,
    <0.9729225, -0.0852551, -0.2148336>,
    <0.9642934, -0.1199760, -0.2361015>,
    <0.9618524, -0.1697801, -0.2145103>,
    <0.9772621, -0.1155328, -0.1777948>,
    <0.9600389, -0.0781861, -0.2687232>,
    <0.9181466, -0.0404520, -0.3941705>,
    <0.9640287, -0.0336170, -0.2636638>,
    <0.8855801, -0.0396460, -0.4627916>,
    <0.5943837, 0.0011073, -0.8041809>,
    <0.8626744, -0.0100909, -0.5056590>,
    <0.9524701, -0.0062151, -0.3045686>,
    <0.9832573, -0.0381774, -0.1781786>,
    <0.9799378, -0.0012986, -0.1992993>,
    <0.9799164, -0.0500631, -0.1930222>,
    <0.9602417, -0.1264050, -0.2489131>,
    <0.9554769, -0.1349050, -0.2624205>,
    <0.9608843, -0.1079758, -0.2550345>,
    <0.9674330, -0.0932187, -0.2353372>,
    <0.9457819, -0.1660825, -0.2791294>,
    <0.9478673, -0.1673785, -0.2711678>,
    <0.9533486, -0.1305173, -0.2721978>,
    <0.9590905, -0.0968911, -0.2660027>,
    <0.9498883, -0.1686546, -0.2631880>,
    <0.9677367, -0.0678691, -0.2426509>,
    <-0.9052430, -0.0632942, 0.4201534>,
    <-0.9114577, -0.0916628, 0.4010521>,
    <-0.9078970, -0.1015831, 0.4066989>,
    <-0.9030935, -0.0867882, 0.4205829>,
    <-0.9177622, -0.0800791, 0.3889729>,
    <-0.9183773, -0.0503374, 0.3924911>,
    <-0.9103910, -0.1239857, 0.3947350>,
    <-0.9081062, -0.1275664, 0.3988358>,
    <-0.9019705, -0.1594911, 0.4012629>,
    <-0.9070568, -0.1595896, 0.3895883>,
    <-0.9062633, -0.1188357, 0.4056659>,
    <-0.9119260, -0.1596557, 0.3780226>,
    <-0.9300383, -0.1637112, 0.3289793>,
    <-0.9160598, -0.1097778, 0.3857244>,
    <-0.9273356, -0.0404085, 0.3720428>,
    <-0.9313689, -0.0730464, 0.3566739>,
    <-0.9263100, -0.0580036, 0.3722707>,
    <-0.9243635, -0.0317024, 0.3801935>,
    <-0.9282596, -0.0971731, 0.3590146>,
    <-0.9230698, -0.0682096, 0.3785362>,
    <-0.9434956, -0.1169624, 0.3100577>,
    <-0.9406009, -0.0820810, 0.3294429>,
    <-0.9224571, -0.0355365, 0.3844608>,
    <-0.9362524, -0.0475280, 0.3480985>,
    <-0.9488152, 0.0997543, 0.2996645>,
    <-0.9575369, 0.0712147, 0.2793772>,
    <-0.9559889, 0.0603424, 0.2871305>,
    <-0.9501579, 0.0749653, 0.3026222>,
    <-0.9589894, 0.0840678, 0.2706878>,
    <-0.9553606, 0.1149658, 0.2721561>,
    <-0.9299428, 0.1642536, 0.3289789>,
    <-0.9302818, 0.1157726, 0.3480984>,
    <-0.9405644, 0.0824997, 0.3294427>,
    <-0.9612145, 0.0375250, 0.2732373>,
    <-0.9594792, 0.0334221, 0.2797903>,
    <-0.9494723, 0.0486508, 0.3100573>,
    <-0.9597882, -0.0005991, 0.2807244>,
    <-0.9625357, 0.0002671, 0.2711548>,
    <-0.9564274, 0.0421796, 0.2889075>,
    <-0.9651753, 0.0011248, 0.2616015>,
    <-0.9767216, 0.0001965, 0.2145106>,
    <-0.9615757, 0.0530860, 0.2693585>,
    <-0.9202641, 0.1212355, 0.3720429>,
    <-0.9299036, 0.0897939, 0.3566739>,
    <-0.9223094, 0.1037297, 0.3722707>,
    <-0.9158254, 0.1292933, 0.3801936>,
    <-0.9069375, 0.1602665, 0.3895882>,
    <-0.9021241, 0.1586194, 0.4012629>,
    <-0.9310313, 0.0654938, 0.3590144>,
    <-0.9208908, 0.0931160, 0.3785361>,
    <-0.9146137, 0.1251865, 0.3844608>,
    <-0.9115357, 0.1618697, 0.3780223>,
    <0.5555664, 0.1452227, -0.8186918>,
    <0.5601135, 0.1581448, -0.8131808>,
    <0.5573281, 0.1648170, -0.8137695>,
    <0.5519219, 0.1575072, -0.8188857>,
    <0.5588245, 0.1357011, -0.8181078>,
    <0.5806516, 0.1574232, -0.7987876>,
    <0.5735993, 0.1808094, -0.7989316>,
    <0.5543700, 0.1785785, -0.8128860>,
    <0.5971285, 0.1808720, -0.7814876>,
    <0.6497423, 0.2361643, -0.7225382>,
    <0.5921779, 0.2145047, -0.7767323>,
    <0.5551655, 0.2005542, -0.8071984>,
    <0.5325504, 0.1679316, -0.8295716>,
    <0.5109019, 0.1841760, -0.8396776>,
    <0.5700927, 0.1268352, -0.8117309>,
    <0.5925386, 0.1256731, -0.7956785>,
    <0.6045940, 0.1460049, -0.7830381>,
    <0.6037248, 0.1559771, -0.7817848>,
    <0.6152423, 0.1333183, -0.7769834>,
    <0.6171542, 0.1563900, -0.7711439>,
    <0.6589269, 0.1510450, -0.7368858>,
    <0.6672829, 0.1785585, -0.7230839>,
    <0.6230217, 0.1780213, -0.7616773>,
    <0.6752625, 0.2070838, -0.7079103>,
    <0.6979756, -0.1999965, -0.6876274>,
    <0.7082922, -0.1832028, -0.6817323>,
    <0.7192344, -0.1742627, -0.6725581>,
    <0.7170361, -0.1822467, -0.6727893>,
    <0.6671638, -0.1790053, -0.7230834>,
    <0.6461704, -0.1986547, -0.7368854>,
    <0.6495350, -0.2367340, -0.7225381>,
    <0.7178937, -0.2175333, -0.6612926>,
    <0.7318699, -0.1963325, -0.6525488>,
    <0.7294302, -0.1621646, -0.6645556>,
    <0.7315948, -0.1557685, -0.6637057>,
    <0.7444697, -0.1743129, -0.6444997>,
    <0.7286059, -0.1583586, -0.6663753>,
    <0.6883369, -0.1582915, -0.7079097>,
    <0.5551681, -0.1745861, -0.8132085>,
    <0.5752085, -0.1871896, -0.7963009>,
    <0.5957508, -0.1756038, -0.7837374>,
    <0.5993656, -0.1663542, -0.7829988>,
    <0.5092170, -0.1871363, -0.8400465>,
    <0.5540103, -0.2031669, -0.8073387>,
    <0.5992804, -0.1921028, -0.7771483>,
    <0.6124257, -0.1730714, -0.7713501>,
    <0.5914674, -0.2163108, -0.7767728>,
    <0.6281108, -0.1572239, -0.7620745>,
    <0.9757125, 0.0681669, -0.2081788>,
    <0.9531870, 0.0917880, -0.2881136>,
    <0.9661390, 0.1082622, -0.2342111>,
    <0.9791077, 0.0986211, -0.1778260>,
    <0.9824677, 0.0559269, -0.1778463>,
    <0.9589591, 0.0897184, -0.2689760>,
    <0.9110416, 0.1195732, -0.3945953>,
    <0.9551642, 0.1342870, -0.2638718>,
    <0.8787157, 0.1147176, -0.4633558>,
    <0.5844142, 0.1041710, -0.8047412>,
    <0.8509793, 0.1397885, -0.5062544>,
    <0.9389887, 0.1592454, -0.3048626>,
    <0.9749400, 0.1331420, -0.1782282>,
    <0.9652626, 0.1688785, -0.1993694>,
    <0.9795633, 0.0427907, -0.1965316>,
    <0.9339279, 0.0244169, -0.3566265>,
    <0.9122149, 0.0571144, -0.4057116>,
    <0.9545356, 0.0824660, -0.2864633>,
    <0.8028102, 0.0211763, -0.5958585>,
    <0.7920420, 0.0584022, -0.6076666>,
    <0.5755143, 0.0227008, -0.8174766>,
    <0.6143417, 0.0534393, -0.7872284>,
    <0.8469633, 0.0985743, -0.5224331>,
    <0.6259901, 0.0847509, -0.7752120>,
    <0.3669433, -0.0488138, -0.9289617>,
    <0.2692199, -0.0288566, -0.9626463>,
    <0.3316991, -0.0198251, -0.9431769>,
    <0.4419463, -0.0325823, -0.8964496>,
    <0.6151570, -0.0541285, -0.7865443>,
    <0.5716102, -0.0776869, -0.8168394>,
    <0.5864984, -0.1022895, -0.8034653>,
    <0.3355069, -0.0462987, -0.9408993>,
    <0.2558148, -0.0277634, -0.9663270>,
    <0.2486473, -0.0093056, -0.9685494>,
    <0.3189393, -0.0009710, -0.9477746>,
    <0.2226715, -0.0175474, -0.9747356>,
    <0.2155550, 0.0000008, -0.9764917>,
    <0.2604395, 0.0080669, -0.9654565>,
    <0.2915684, 0.0077759, -0.9565184>,
    <0.4329723, -0.0053538, -0.9013913>,
    <0.3714067, 0.0090651, -0.9284260>,
    <0.6320285, -0.0252871, -0.7745325>,
    <0.9721421, -0.1279629, -0.1963805>,
    <0.9241664, -0.1381370, -0.3561385>,
    <0.9085257, -0.1021861, -0.4051408>,
    <0.9544642, -0.0845685, -0.2860879>,
    <0.9648432, -0.1714410, -0.1992125>,
    <0.9370399, -0.1715207, -0.3041988>,
    <0.7948623, -0.1186124, -0.5950841>,
    <0.7907197, -0.0800795, -0.6069182>,
    <0.8482527, -0.1597970, -0.5049081>,
    <0.8516386, -0.0500447, -0.5217349>,
    <0.3690204, 0.0155863, -0.9292906>,
    <0.2694845, 0.0182672, -0.9628315>,
    <0.3293685, 0.0379904, -0.9434369>,
    <0.4400133, 0.0445672, -0.8968847>,
    <0.3376497, 0.0126189, -0.9411872>,
    <0.2561143, 0.0170279, -0.9664965>,
    <0.2458827, 0.0339297, -0.9687056>,
    <0.3135906, 0.0543292, -0.9480028>,
    <0.2217725, 0.0213273, -0.9748652>,
    <0.2117870, 0.0373444, -0.9766021>,
    <0.2544729, 0.0530462, -0.9656240>,
    <0.2851830, 0.0581737, -0.9567061>,
    <0.4265276, 0.0698061, -0.9017768>,
    <0.3635169, 0.0732995, -0.9286994>,
    <0.3187832, 0.0155743, -0.9476997>,
    <0.2676376, 0.0118332, -0.9634470>,
    <0.2434289, 0.0158961, -0.9697885>,
    <0.2638315, 0.0201517, -0.9643583>,
    <0.2330750, 0.0141126, -0.9723564>,
    <0.2124718, 0.0159409, -0.9770372>,
    <0.2155550, 0.0000008, -0.9764917>,
    <0.2289526, 0.0200313, -0.9732315>,
    <0.2289526, 0.0200313, -0.9732315>,
    <0.2049942, 0.0179351, -0.9785989>,
    <0.2153104, 0.0189075, -0.9763626>,
    <0.2049942, 0.0179351, -0.9785989>,
    <0.1980446, 0.0173271, -0.9800398>,
    <0.1980446, 0.0173271, -0.9800398>,
    <0.2117870, 0.0373444, -0.9766021>,
    <0.3174300, -0.0401177, -0.9474327>,
    <0.2663372, -0.0349124, -0.9632474>,
    <0.2431170, -0.0266850, -0.9696298>,
    <0.2639817, -0.0260353, -0.9641762>,
    <0.3682103, -0.0557161, -0.9280716>,
    <0.2892772, -0.0431017, -0.9562745>,
    <0.2326320, -0.0266479, -0.9721997>,
    <0.2125544, -0.0212507, -0.9769181>,
    <0.2586823, -0.0374013, -0.9652381>,
    <0.2129087, -0.0375410, -0.9763506>,
    <0.2296005, -0.0200868, -0.9730777>,
    <0.2296005, -0.0200868, -0.9730777>,
    <0.2055162, -0.0179797, -0.9784885>,
    <0.2158568, -0.0188155, -0.9762437>,
    <0.2055162, -0.0179797, -0.9784885>,
    <0.1985324, -0.0173688, -0.9799404>,
    <0.1985324, -0.0173688, -0.9799404>,
    <0.2155550, 0.0000008, -0.9764917>,
    <-0.4317635, -0.1269553, 0.8930076>,
    <-0.4296464, -0.1332990, 0.8931043>,
    <-0.4301649, -0.1386223, 0.8920438>,
    <-0.4251167, -0.1300276, 0.8957503>,
    <-0.4082922, -0.1152785, 0.9055431>,
    <-0.3972356, -0.1092492, 0.9111907>,
    <-0.3897315, -0.1067777, 0.9147174>,
    <-0.4425263, -0.1303895, 0.8872255>,
    <-0.4425263, -0.1303895, 0.8872255>,
    <-0.4239749, -0.1249234, 0.8970170>,
    <-0.3890159, -0.1269381, 0.9124436>,
    <-0.4235082, -0.1459697, 0.8940546>,
    <-0.4239749, -0.1249234, 0.8970170>,
    <-0.3634888, -0.1071012, 0.9254217>,
    <-0.3634888, -0.1071012, 0.9254217>,
    <-0.3163017, -0.1085859, 0.9424236>,
    <-0.3530979, -0.1280595, 0.9267808>,
    <-0.4160357, -0.1584718, 0.8954334>,
    <-0.4420665, -0.1480339, 0.8846825>,
    <-0.4691513, -0.1793383, 0.8647166>,
    <-0.5589399, -0.1960454, 0.8056999>,
    <-0.4303974, -0.1280672, 0.8935082>,
    <-0.3880280, -0.0966133, 0.9165698>,
    <-0.3816730, -0.0959003, 0.9193089>,
    <-0.3894815, -0.0999676, 0.9155930>,
    <-0.3996773, -0.1030873, 0.9108409>,
    <-0.4284404, -0.1120399, 0.8965968>,
    <-0.3900240, -0.0947208, 0.9159199>,
    <-0.3394808, -0.0611036, 0.9386262>,
    <-0.3774262, -0.0916093, 0.9214973>,
    <-0.3774262, -0.0916093, 0.9214973>,
    <-0.3652842, -0.0886622, 0.9266642>,
    <-0.3780510, -0.0970666, 0.9206821>,
    <-0.3935769, -0.1041507, 0.9133728>,
    <-0.3652842, -0.0886622, 0.9266642>,
    <-0.3491667, -0.0847501, 0.9332202>,
    <-0.3491667, -0.0847501, 0.9332202>,
    <-0.3897315, -0.1067777, 0.9147174>,
    <-0.4089781, -0.1103211, 0.9058511>,
    <-0.4676767, -0.1319616, 0.8739935>,
    <-0.3975098, -0.0913607, 0.9130384>,
    <-0.4554985, -0.1174460, 0.8824554>,
    <-0.4688988, -0.1163908, 0.8755496>,
    <-0.4424442, -0.1015185, 0.8910315>,
    <-0.3394808, -0.0611036, 0.9386262>,
    <-0.5241045, -0.1469076, 0.8388877>,
    <-0.5179401, -0.1333649, 0.8449567>,
    <-0.6171807, -0.1847023, 0.7648353>,
    <-0.6048730, -0.1618700, 0.7796966>,
    <-0.4951253, -0.1144373, 0.8612520>,
    <-0.5842962, -0.1365858, 0.7999639>,
    <-0.6801852, 0.1947306, 0.7067022>,
    <-0.6907994, 0.1770582, 0.7010325>,
    <-0.7065252, 0.1723593, 0.6863778>,
    <-0.7043638, 0.1821434, 0.6860724>,
    <-0.7288541, 0.1952332, 0.6562436>,
    <-0.7061297, 0.2134149, 0.6751555>,
    <-0.5881917, 0.2229868, 0.7773721>,
    <-0.5935734, 0.1827634, 0.7837526>,
    <-0.6233244, 0.1679368, 0.7637172>,
    <-0.7020657, 0.1555518, 0.6949154>,
    <-0.7193232, 0.1548400, 0.6771992>,
    <-0.6586581, 0.1544189, 0.7364268>,
    <-0.7284592, 0.1623717, 0.6655694>,
    <-0.7454586, 0.1745778, 0.6432838>,
    <-0.4000782, 0.1261284, 0.9077605>,
    <-0.5059982, 0.1376273, 0.8514837>,
    <-0.4920650, 0.1437675, 0.8586053>,
    <-0.4478141, 0.1447768, 0.8823277>,
    <-0.4147074, 0.1541414, 0.8968044>,
    <-0.3256875, 0.1293076, 0.9365934>,
    <-0.3400039, 0.1297656, 0.9314281>,
    <-0.5827352, 0.1454691, 0.7995364>,
    <-0.5407897, 0.1519080, 0.8273273>,
    <-0.5105208, 0.1616888, 0.8445266>,
    <-0.4937360, 0.1788577, 0.8510198>,
    <-0.9517227, -0.0665213, 0.2996646>,
    <-0.9553559, -0.0961418, 0.2793775>,
    <-0.9519436, -0.1065801, 0.2871308>,
    <-0.9487404, -0.0911669, 0.3026223>,
    <-0.9590185, -0.0837363, 0.2706876>,
    <-0.9608102, -0.0526776, 0.2721559>,
    <-0.9531275, -0.1299582, 0.2732378>,
    <-0.9507061, -0.1336975, 0.2797907>,
    <-0.9451027, -0.1672553, 0.2807251>,
    <-0.9479589, -0.1668794, 0.2711553>,
    <-0.9492215, -0.1245431, 0.2889076>,
    <-0.9507074, -0.1664932, 0.2616017>,
    <-0.9619173, -0.1694125, 0.2145101>,
    <-0.9561856, -0.1146965, 0.2693582>,
    <-0.9667275, -0.0421998, 0.2523037>,
    <-0.9681950, -0.0760530, 0.2383577>,
    <-0.9650402, -0.0605016, 0.2550233>,
    <-0.9643891, -0.0331006, 0.2624081>,
    <-0.9648307, -0.1011244, 0.2426429>,
    <-0.9621446, -0.0711671, 0.2630835>,
    <-0.9732840, -0.1207548, 0.1952856>,
    <-0.9729473, -0.0849714, 0.2148336>,
    <-0.9624428, -0.0370948, 0.2689383>,
    <-0.9710075, -0.0493369, 0.2339022>,
    <-0.9731877, 0.1022925, 0.2060144>,
    <-0.9810789, 0.0728914, 0.1793631>,
    <-0.9716957, 0.0612556, 0.2281560>,
    <-0.9583042, 0.0753682, 0.2756316>,
    <-0.9630318, 0.0784710, 0.2577054>,
    <-0.9772227, 0.1154937, 0.1780364>,
    <-0.9618489, 0.1697994, 0.2145107>,
    <-0.9648228, 0.1200264, 0.2339029>,
    <-0.9729209, 0.0852702, 0.2148346>,
    <-0.9830229, 0.0382546, 0.1794508>,
    <-0.9666040, 0.0337819, 0.2540385>,
    <-0.9794663, 0.0500889, 0.1952866>,
    <-0.9802738, 0.0013622, 0.1976398>,
    <-0.9570163, 0.0062187, 0.2899676>,
    <-0.9258737, 0.0408056, 0.3756232>,
    <-0.8735896, 0.0110736, 0.4865373>,
    <-0.6210422, -0.0025215, 0.7837731>,
    <-0.8962107, 0.0390371, 0.4419078>,
    <-0.9593685, 0.1263119, 0.2523042>,
    <-0.9666923, 0.0932279, 0.2383582>,
    <-0.9608849, 0.1079952, 0.2550240>,
    <-0.9554856, 0.1348667, 0.2624087>,
    <-0.9478661, 0.1674057, 0.2711554>,
    <-0.9453108, 0.1660755, 0.2807248>,
    <-0.9677326, 0.0679532, 0.2426435>,
    <-0.9598853, 0.0969890, 0.2630842>,
    <-0.9542624, 0.1305953, 0.2689390>,
    <-0.9503167, 0.1687087, 0.2616020>,
    <0.3615572, 0.1681739, -0.9170572>,
    <0.3578524, 0.1653770, -0.9190169>,
    <0.3499930, 0.1606570, -0.9228728>,
    <0.3520235, 0.1622808, -0.9218158>,
    <0.3666613, 0.1685942, -0.9149511>,
    <0.3655977, 0.1700360, -0.9151099>,
    <0.3674634, 0.1713623, -0.9141147>,
    <0.3663888, 0.1708659, -0.9146388>,
    <0.3663888, 0.1708659, -0.9146388>,
    <0.3591845, 0.1675100, -0.9181105>,
    <0.3443637, 0.1562067, -0.9257500>,
    <0.3425455, 0.1533983, -0.9268935>,
    <0.3591845, 0.1675100, -0.9181105>,
    <0.3390812, 0.1581382, -0.9273706>,
    <0.3390812, 0.1581382, -0.9273706>,
    <0.3035091, 0.1270114, -0.9443253>,
    <0.3427087, 0.1540481, -0.9267254>,
    <0.3686109, 0.1645975, -0.9148954>,
    <-0.9761558, -0.0682533, 0.2060614>,
    <-0.9788259, -0.0985782, 0.1793941>,
    <-0.9675418, -0.1084052, 0.2282786>,
    <-0.9567773, -0.0921799, 0.2758262>,
    <-0.9619648, -0.0899587, 0.2579364>,
    <-0.9824230, -0.0559586, 0.1780833>,
    <-0.9747236, -0.1330258, 0.1794938>,
    <-0.9577363, -0.1345731, 0.2542268>,
    <-0.9656062, -0.1688749, 0.1977016>,
    <-0.9434790, -0.1600337, 0.2902354>,
    <-0.9218047, -0.1209729, 0.3682956>,
    <-0.8744981, -0.1439410, 0.4631781>,
    <-0.6408356, -0.1068302, 0.7602085>,
    <-0.8941781, -0.1157286, 0.4324956>,
    <-0.9800766, -0.0427995, 0.1939536>,
    <-0.9584637, -0.0826880, 0.2729652>,
    <-0.9233166, -0.0577988, 0.3796652>,
    <-0.9415371, -0.0247397, 0.3359998>,
    <-0.8635705, -0.1000951, 0.4941932>,
    <-0.8166508, -0.0601736, 0.5739866>,
    <-0.6569980, -0.0879299, 0.7487469>,
    <-0.6518338, -0.0566879, 0.7562402>,
    <-0.8219524, -0.0208248, 0.5691753>,
    <-0.6016703, -0.0218598, 0.7984453>,
    <-0.4069874, 0.0544677, 0.9118084>,
    <-0.4887191, 0.0355261, 0.8717176>,
    <-0.3837084, 0.0213039, 0.9232085>,
    <-0.3079916, 0.0323477, 0.9508390>,
    <-0.3140365, 0.0266565, 0.9490366>,
    <-0.4056895, 0.0486398, 0.9127158>,
    <-0.6545661, 0.1074030, 0.7483367>,
    <-0.6044798, 0.0822212, 0.7923660>,
    <-0.6535648, 0.0575203, 0.7546817>,
    <-0.4857346, 0.0030461, 0.8741010>,
    <-0.3824902, -0.0017658, 0.9239579>,
    <-0.6672959, 0.0241403, 0.7444014>,
    <-0.4299542, -0.0116415, 0.9027756>,
    <-0.3586431, -0.0090619, 0.9334308>,
    <-0.2923379, 0.0082438, 0.9562796>,
    <-0.3166295, -0.0086464, 0.9485099>,
    <-0.8572828, -0.0750059, -0.5093528>,
    <-0.2715457, 0.0115634, 0.9623561>,
    <-0.9726462, 0.1280427, 0.1938152>,
    <-0.9583566, 0.0850308, 0.2726214>,
    <-0.9195428, 0.1034359, 0.3791332>,
    <-0.9316912, 0.1391362, 0.3355483>,
    <-0.9415016, 0.1723105, 0.2896269>,
    <-0.9651617, 0.1715613, 0.1975594>,
    <-0.8685662, 0.0500323, 0.4930411>,
    <-0.8155428, 0.0826346, 0.5727666>,
    <-0.8165323, 0.1218870, 0.5642858>,
    <-0.8654754, 0.1626338, 0.4738170>,
    <0.7044625, 0.1757856, -0.6876278>,
    <0.7050001, 0.1954877, -0.6817326>,
    <0.7100061, 0.2087011, -0.6725587>,
    <0.7120943, 0.2006876, -0.6727899>,
    <0.7304809, 0.1705575, -0.6612926>,
    <0.7319842, 0.1959060, -0.6525488>,
    <0.7127871, 0.2242763, -0.6645560>,
    <0.7114634, 0.2308976, -0.6637063>,
    <0.7318862, 0.2212755, -0.6444996>,
    <0.7630236, 0.2773780, -0.5838290>,
    <0.7246818, 0.2627915, -0.6370063>,
    <0.7116043, 0.2586252, -0.6532475>,
    <0.7101699, 0.2271601, -0.6663760>,
    <0.6975757, 0.2540878, -0.6699459>,
    <0.7501447, 0.1661747, -0.6400538>,
    <0.7495618, 0.1589041, -0.6425781>,
    <0.7520693, 0.1816468, -0.6335583>,
    <0.7586645, 0.1957991, -0.6213621>,
    <0.7501584, 0.1623536, -0.6410176>,
    <0.7487734, 0.1897705, -0.6350792>,
    <0.7782802, 0.1783328, -0.6020610>,
    <0.7838531, 0.2097806, -0.5844368>,
    <0.7555572, 0.2161122, -0.6184083>,
    <0.7884849, 0.2419371, -0.5654715>,
    <0.8028380, -0.2301976, -0.5499638>,
    <0.8090217, -0.2093781, -0.5492218>,
    <0.8207930, -0.1988323, -0.5355040>,
    <0.8215768, -0.2087833, -0.5304914>,
    <0.7837265, -0.2102512, -0.5844376>,
    <0.7631763, -0.2346993, -0.6020616>,
    <0.7628051, -0.2779783, -0.5838291>,
    <0.8169095, -0.2476176, -0.5209072>,
    <0.8271160, -0.2218516, -0.5163923>,
    <0.8258260, -0.1835542, -0.5332159>,
    <0.8312423, -0.1767928, -0.5270490>,
    <0.8362427, -0.1956627, -0.5122638>,
    <0.8324814, -0.1807192, -0.5237511>,
    <0.8038160, -0.1847188, -0.5654722>,
    <0.7327313, -0.2311608, -0.6400543>,
    <0.7285910, -0.2371659, -0.6425788>,
    <0.7421340, -0.2187239, -0.6335590>,
    <0.7549219, -0.2097652, -0.6213626>,
    <0.6976986, -0.2537505, -0.6699458>,
    <0.7113616, -0.2592921, -0.6532475>,
    <0.7308324, -0.2344768, -0.6410184>,
    <0.7433414, -0.2100406, -0.6350799>,
    <0.7240576, -0.2645065, -0.6370063>,
    <0.7623874, -0.1906199, -0.6184088>,
    <-0.4137664, -0.0155343, 0.9102506>,
    <-0.4907831, -0.0502503, 0.8698315>,
    <-0.3922938, -0.0470445, 0.9186362>,
    <-0.3365084, -0.0225621, 0.9414101>,
    <-0.3322604, -0.0225303, 0.9429186>,
    <-0.3963852, -0.0160124, 0.9179447>,
    <-0.4751760, -0.0774961, 0.8764714>,
    <-0.3742930, -0.0659600, 0.9249616>,
    <-0.4145630, -0.0747962, 0.9069416>,
    <-0.3435456, -0.0634380, 0.9369909>,
    <-0.3095741, -0.0426689, 0.9499175>,
    <-0.2978472, -0.0518252, 0.9532058>,
    <-0.5477053, -0.0479181, 0.8352980>,
    <-0.2967888, -0.0287473, 0.9545103>,
    <-0.3948087, -0.0204090, 0.9185366>,
    <-0.3511756, -0.0276177, 0.9359022>,
    <-0.3299163, -0.0213366, 0.9437690>,
    <-0.3475084, -0.0143860, 0.9375665>,
    <-0.2937537, -0.0264028, 0.9555164>,
    <-0.2887513, -0.0208593, 0.9571769>,
    <-0.5477053, -0.0479181, 0.8352980>,
    <-0.2706268, -0.0236772, 0.9623931>,
    <-0.2706268, -0.0236772, 0.9623931>,
    <-0.2804968, -0.0245409, 0.9595412>,
    <-0.3053346, -0.0165552, 0.9521012>,
    <-0.2804968, -0.0245409, 0.9595412>,
    <-0.3144420, -0.0275109, 0.9488780>,
    <-0.3144420, -0.0275109, 0.9488780>,
    <-0.8572828, -0.0750059, -0.5093528>,
    <-0.4213289, 0.0416107, 0.9059528>,
    <-0.3693704, 0.0245733, 0.9289573>,
    <-0.3516289, 0.0301292, 0.9356545>,
    <-0.3629301, 0.0420891, 0.9308653>,
    <-0.3737598, 0.0558775, 0.9258409>,
    <-0.4746739, 0.0651964, 0.8777438>,
    <-0.3181599, 0.0124430, 0.9479554>,
    <-0.3174566, 0.0244357, 0.9479579>,
    <-0.8572828, -0.0750059, -0.5093528>,
    <-0.3220971, 0.0384797, 0.9459243>,
    <-0.3259777, 0.0523879, 0.9439248>,
    <0.3578733, -0.1666219, -0.9187839>,
    <0.3395697, -0.1569439, -0.9273948>,
    <0.3413737, -0.1574874, -0.9266400>,
    <0.3566688, -0.1653094, -0.9194891>,
    <0.3610952, -0.1683744, -0.9172025>,
    <0.3666214, -0.1709490, -0.9145300>,
    <0.3666214, -0.1709490, -0.9145300>,
    <0.3673594, -0.1712894, -0.9141701>,
    <0.3626080, -0.1684116, -0.9165986>,
    <0.3596189, -0.1646787, -0.9184526>,
    <0.3225075, -0.1459272, -0.9352509>,
    <0.3319253, -0.1503965, -0.9312392>,
    <0.3591482, -0.1585369, -0.9197166>,
    <0.3447449, -0.1578077, -0.9253365>,
    <0.3115924, -0.1350196, -0.9405742>,
    <0.3453414, -0.1610295, -0.9245587>,
    <0.3453414, -0.1610295, -0.9245587>,
    <0.3610952, -0.1683744, -0.9172025>,
    <-0.6769569, -0.1709361, 0.7158982>,
    <-0.6751008, -0.1891815, 0.7130563>,
    <-0.6924474, -0.2025837, 0.6924424>,
    <-0.6977370, -0.1943793, 0.6894779>,
    <-0.7245534, -0.1948829, 0.6610923>,
    <-0.7053649, -0.1667385, 0.6889548>,
    <-0.6718904, -0.2108386, 0.7100073>,
    <-0.6950473, -0.2233410, 0.6833945>,
    <-0.6646929, -0.2394374, 0.7077097>,
    <-0.6981338, -0.2523758, 0.6700116>,
    <-0.7106142, -0.2232372, 0.6672276>,
    <-0.7226902, -0.2617361, 0.6396976>,
    <-0.7630272, -0.2773429, 0.5838411>,
    <-0.7320023, -0.2214497, 0.6443079>,
    <-0.7255129, -0.1606901, 0.6691859>,
    <-0.7480789, -0.1930969, 0.6348949>,
    <-0.7456875, -0.1800757, 0.6415005>,
    <-0.7381250, -0.1563532, 0.6562966>,
    <-0.7538989, -0.2155386, 0.6206284>,
    <-0.7491141, -0.1898286, 0.6346599>,
    <-0.7872054, -0.2414744, 0.5674485>,
    <-0.7838511, -0.2097529, 0.5844494>,
    <-0.7497210, -0.1622900, 0.6415453>,
    <-0.7795780, -0.1786389, 0.6002885>,
    <-0.8028455, 0.2301441, 0.5499752>,
    <-0.8198975, 0.2083858, 0.5332386>,
    <-0.8207792, 0.1988591, 0.5355153>,
    <-0.8106163, 0.2097473, 0.5467241>,
    <-0.8271028, 0.2218723, 0.5164046>,
    <-0.8157151, 0.2472283, 0.5229598>,
    <-0.7627854, 0.2780075, 0.5838410>,
    <-0.7644541, 0.2350831, 0.6002882>,
    <-0.7837117, 0.2102742, 0.5844490>,
    <-0.8305824, 0.1804242, 0.5268585>,
    <-0.8312136, 0.1768926, 0.5270607>,
    <-0.8024773, 0.1844797, 0.5674482>,
    <-0.8275548, 0.1839695, 0.5303850>,
    <-0.8373496, 0.1959990, 0.5103236>,
    <-0.7207079, 0.2273955, 0.6548828>,
    <-0.7495859, 0.2083434, 0.6282627>,
    <-0.7393952, 0.2179467, 0.6370196>,
    <-0.7230154, 0.2353888, 0.6494928>,
    <-0.7016978, 0.2567148, 0.6646185>,
    <-0.6754973, 0.2475467, 0.6945675>,
    <-0.7618451, 0.1905907, 0.6190857>,
    <-0.7445302, 0.2104047, 0.6335650>,
    <-0.7316462, 0.2346973, 0.6400085>,
    <-0.7228925, 0.2643017, 0.6384129>,
    <0.8103772, 0.2020623, -0.5499632>,
    <0.8053227, 0.2231843, -0.5492214>,
    <0.8102441, 0.2382029, -0.5355033>,
    <0.8158985, 0.2299770, -0.5304906>,
    <0.8312733, 0.1940117, -0.5209071>,
    <0.8272293, 0.2214289, -0.5163922>,
    <0.8069637, 0.2539506, -0.5332155>,
    <0.8082737, 0.2625143, -0.5270483>,
    <0.8220388, 0.2486725, -0.5122638>,
    <0.8384681, 0.3048601, -0.4516985>,
    <0.8118726, 0.2943610, -0.5041969>,
    <0.8044291, 0.2924155, -0.5170948>,
    <0.8113101, 0.2597335, -0.5237503>,
    <0.7965932, 0.2903235, -0.5302373>,
    <0.8460870, 0.1874702, -0.4989906>,
    <0.8432452, 0.1786758, -0.5069640>,
    <0.8426949, 0.2035776, -0.4984190>,
    <0.8482615, 0.2190922, -0.4821317>,
    <0.8403589, 0.1817761, -0.5106411>,
    <0.8369820, 0.2121672, -0.5044266>,
    <0.8593233, 0.1968829, -0.4720177>,
    <0.8615510, 0.2306163, -0.4522675>,
    <0.8412176, 0.2407944, -0.4841188>,
    <0.8624424, 0.2647371, -0.4314016>,
    <0.8722950, -0.2501863, -0.4201289>,
    <0.8770742, -0.2270436, -0.4233108>,
    <0.8879041, -0.2150385, -0.4066752>,
    <0.8891015, -0.2258953, -0.3980827>,
    <0.8614336, -0.2310560, -0.4522667>,
    <0.8426376, -0.2591561, -0.4720170>,
    <0.8382640, -0.3054206, -0.4516988>,
    <0.8811028, -0.2670993, -0.3902765>,
    <0.8898177, -0.2386252, -0.3889504>,
    <0.8909200, -0.1979671, -0.4087427>,
    <0.8970006, -0.1906247, -0.3988133>,
    <0.8975235, -0.2098855, -0.3878139>,
    <0.8993130, -0.1950622, -0.3913909>,
    <0.8792659, -0.2019522, -0.4314009>,
    <0.8264682, -0.2606896, -0.4989903>,
    <0.8196100, -0.2668849, -0.5069633>,
    <0.8315843, -0.2450441, -0.4984184>,
    <0.8441623, -0.2343914, -0.4821313>,
    <0.7968420, -0.2896396, -0.5302374>,
    <0.8041894, -0.2930738, -0.5170949>,
    <0.8186606, -0.2627568, -0.5106404>,
    <0.8309317, -0.2347488, -0.5044259>,
    <0.8111419, -0.2963681, -0.5041971>,
    <0.8489133, -0.2120748, -0.4841183>,
    <-0.8103565, -0.2021120, 0.5499755>,
    <-0.8142448, -0.2294812, 0.5332390>,
    <-0.8102451, -0.2381724, 0.5355155>,
    <-0.8068879, -0.2236616, 0.5467242>,
    <-0.8272282, -0.2214042, 0.5164046>,
    <-0.8300442, -0.1937515, 0.5229599>,
    <-0.8095174, -0.2590392, 0.5268588>,
    <-0.8082983, -0.2624132, 0.5270609>,
    <-0.7957661, -0.2899267, 0.5316943>,
    <-0.8044344, -0.2923769, 0.5171083>,
    <-0.8086682, -0.2544551, 0.5303851>,
    <-0.8126386, -0.2946535, 0.5027901>,
    <-0.8384693, -0.3048260, 0.4517194>,
    <-0.8231656, -0.2489347, 0.5103234>,
    <-0.8443089, -0.1870446, 0.5021522>,
    <-0.8467643, -0.2186071, 0.4849754>,
    <-0.8426936, -0.2035479, 0.4984334>,
    <-0.8432305, -0.1787079, 0.5069771>,
    <-0.8412358, -0.2406968, 0.4841356>,
    <-0.8384536, -0.2125129, 0.5018305>,
    <-0.8614624, -0.2643706, 0.4335789>,
    <-0.8615475, -0.2305897, 0.4522878>,
    <-0.8420192, -0.1821775, 0.5077549>,
    <-0.8603597, -0.1971284, 0.4700230>,
    <-0.8722982, 0.2501342, 0.4201532>,
    <-0.8878406, 0.2256020, 0.4010520>,
    <-0.8878876, 0.2150621, 0.4066987>,
    <-0.8783137, 0.2273219, 0.4205827>,
    <-0.8898032, 0.2386433, 0.3889725>,
    <-0.8802090, 0.2668018, 0.3924907>,
    <-0.8382430, 0.3054473, 0.4517196>,
    <-0.8436574, 0.2594615, 0.4700234>,
    <-0.8614166, 0.2310771, 0.4522883>,
    <-0.8978933, 0.1948636, 0.3947350>,
    <-0.8969710, 0.1907173, 0.3988356>,
    <-0.8782334, 0.2017794, 0.4335795>,
    <-0.8922533, 0.1982912, 0.4056656>,
    <-0.8983610, 0.2101535, 0.3857240>,
    <-0.8247152, 0.2601690, 0.5021524>,
    <-0.8426229, 0.2340628, 0.4849756>,
    <-0.8315678, 0.2450691, 0.4984337>,
    <-0.8196128, 0.2668496, 0.5069774>,
    <-0.8041687, 0.2931068, 0.5171084>,
    <-0.7959535, 0.2894119, 0.5316942>,
    <-0.8488799, 0.2121683, 0.4841359>,
    <-0.8323783, 0.2351852, 0.5018310>,
    <-0.8202985, 0.2632392, 0.5077553>,
    <-0.8119168, 0.2966363, 0.5027903>,
    <0.8805225, 0.2194797, -0.4201294>,
    <0.8730902, 0.2419115, -0.4233111>,
    <0.8764665, 0.2577231, -0.4066759>,
    <0.8829318, 0.2489195, -0.3980835>,
    <0.8966071, 0.2092367, -0.3902766>,
    <0.8899173, 0.2382534, -0.3889505>,
    <0.8705427, 0.2740154, -0.4087431>,
    <0.8721375, 0.2834143, -0.3988140>,
    <0.8822209, 0.2669956, -0.3878140>,
    <0.8874712, 0.3227491, -0.3289801>,
    <0.8697716, 0.3153580, -0.3795349>,
    <0.8655608, 0.3147083, -0.3895681>,
    <0.8763587, 0.2807275, -0.3913917>,
    <0.8611935, 0.3140085, -0.3996805>,
    <0.9075338, 0.2011418, -0.3686794>,
    <0.9048299, 0.1917017, -0.3801753>,
    <0.9021656, 0.2180003, -0.3722542>,
    <0.9056173, 0.2340384, -0.3536711>,
    <0.9010052, 0.1948619, -0.3875802>,
    <0.8960815, 0.2272025, -0.3813357>,
    <0.9130008, 0.2091962, -0.3502377>,
    <0.9120522, 0.2441877, -0.3294436>,
    <0.8972625, 0.2569776, -0.3590020>,
    <0.9095302, 0.2792894, -0.3078186>,
    <0.9170607, -0.2630481, -0.2996755>,
    <0.9217996, -0.2386304, -0.3055177>,
    <0.9309883, -0.2254095, -0.2871436>,
    <0.9314744, -0.2366015, -0.2763605>,
    <0.9119541, -0.2445535, -0.3294439>,
    <0.8952798, -0.2753313, -0.3502381>,
    <0.8873016, -0.3232154, -0.3289797>,
    <0.9214772, -0.2793254, -0.2699203>,
    <0.9298222, -0.2493006, -0.2707025>,
    <0.9336152, -0.2073861, -0.2921535>,
    <0.9391134, -0.1994392, -0.2798035>,
    <0.9371632, -0.2190539, -0.2715520>,
    <0.9410514, -0.2039756, -0.2698447>,
    <0.9273208, -0.2128934, -0.3078189>,
    <0.8865180, -0.2795730, -0.3686797>,
    <0.8794563, -0.2863964, -0.3801758>,
    <0.8902983, -0.2622890, -0.3722546>,
    <0.9013067, -0.2501255, -0.3536714>,
    <0.8615532, -0.3130201, -0.3996806>,
    <0.8653486, -0.3152912, -0.3895680>,
    <0.8777241, -0.2817473, -0.3875807>,
    <0.8896304, -0.2512777, -0.3813361>,
    <0.8689920, -0.3175002, -0.3795346>,
    <0.9055408, -0.2260822, -0.3590023>,
    <-0.4705846, 0.2242204, 0.8533905>,
    <-0.4219190, 0.1988143, 0.8845661>,
    <-0.4401118, 0.1972637, 0.8760072>,
    <-0.4625527, 0.2105080, 0.8612383>,
    <-0.4978771, 0.2271538, 0.8369704>,
    <-0.5195538, 0.2416173, 0.8195639>,
    <-0.5335268, 0.2487907, 0.8083640>,
    <-0.4678774, 0.2286675, 0.8536990>,
    <-0.4678774, 0.2286675, 0.8536990>,
    <-0.3967893, 0.1996142, 0.8959422>,
    <-0.3568432, 0.1627608, 0.9198760>,
    <-0.4231413, 0.1783174, 0.8883436>,
    <-0.3967893, 0.1996142, 0.8959422>,
    <-0.3102732, 0.1585784, 0.9373278>,
    <-0.3102732, 0.1585784, 0.9373278>,
    <-0.3400039, 0.1297656, 0.9314281>,
    <-0.4697026, 0.1970108, 0.8605616>,
    <-0.4889297, 0.2142843, 0.8455945>,
    <0.9257220, 0.2307242, -0.2996752>,
    <0.9176171, 0.2542400, -0.3055175>,
    <0.9189642, 0.2702840, -0.2871433>,
    <0.9249813, 0.2608344, -0.2763603>,
    <0.9376855, 0.2188358, -0.2699201>,
    <0.9299000, 0.2490106, -0.2707023>,
    <0.9122275, 0.2872061, -0.2921534>,
    <0.9130157, 0.2968374, -0.2798033>,
    <0.9211341, 0.2788755, -0.2715519>,
    <0.9178786, 0.3338924, -0.2145103>,
    <0.9069546, 0.3288851, -0.2631879>,
    <0.9045664, 0.3289797, -0.2711677>,
    <0.9169623, 0.2938778, -0.2698445>,
    <0.9021124, 0.3290593, -0.2791293>,
    <0.9455651, 0.2096401, -0.2489128>,
    <0.9439948, 0.2000230, -0.2624205>,
    <0.9398658, 0.2271777, -0.2550346>,
    <0.9409724, 0.2432847, -0.2353371>,
    <0.9404941, 0.2034182, -0.2721981>,
    <0.9343890, 0.2369803, -0.2660030>,
    <0.9471735, 0.2170672, -0.2361021>,
    <0.9434069, 0.2526454, -0.2148341>,
    <0.9325876, 0.2672093, -0.2426510>,
    <0.9379427, 0.2881071, -0.1930227>,
    <0.9402078, -0.2696642, -0.2080636>,
    <0.9272334, -0.2397935, -0.2876409>,
    <0.9449721, -0.2287229, -0.2339093>,
    <0.9538044, -0.2422045, -0.1777475>,
    <0.9433370, -0.2529062, -0.2148341>,
    <0.9288099, -0.2856011, -0.2361020>,
    <0.9177576, -0.3342247, -0.2145107>,
    <0.9423620, -0.2834867, -0.1777335>,
    <0.9319556, -0.2437461, -0.2684150>,
    <0.8973937, -0.1993211, -0.3936440>,
    <0.9436142, -0.2005222, -0.2634065>,
    <0.8655930, -0.1929274, -0.4620907>,
    <0.9617005, -0.2083407, -0.1781190>,
    <0.9563357, -0.2194634, -0.1930227>,
    <0.9237035, -0.2912290, -0.2489129>,
    <0.9175350, -0.2987724, -0.2624205>,
    <0.9275365, -0.2731913, -0.2550346>,
    <0.9365483, -0.2597956, -0.2353372>,
    <0.9025735, -0.3277927, -0.2791290>,
    <0.9044021, -0.3294311, -0.2711677>,
    <0.9162009, -0.2940818, -0.2721980>,
    <0.9276947, -0.2619636, -0.2660029>,
    <0.9061707, -0.3310387, -0.2631882>,
    <0.9412492, -0.2348839, -0.2426511>,
    <-0.8804997, -0.2195265, 0.4201529>,
    <-0.8816938, -0.2485433, 0.4010514>,
    <-0.8764645, -0.2576946, 0.4066982>,
    <-0.8743031, -0.2422902, 0.4205824>,
    <-0.8899139, -0.2382302, 0.3889726>,
    <-0.8956842, -0.2090472, 0.3924908>,
    <-0.8750306, -0.2801899, 0.3947342>,
    <-0.8721586, -0.2833195, 0.3988351>,
    <-0.8605724, -0.3136937, 0.4012621>,
    <-0.8655644, -0.3146740, 0.3895876>,
    <-0.8718598, -0.2744014, 0.4056654>,
    <-0.8703481, -0.3155846, 0.3780220>,
    <-0.8874808, -0.3227235, 0.3289793>,
    <-0.8830802, -0.2671821, 0.3857242>,
    <-0.9062304, -0.2008247, 0.3720428>,
    <-0.9045349, -0.2336671, 0.3566739>,
    <-0.9021650, -0.2179743, 0.3722708>,
    <-0.9048152, -0.1917346, 0.3801937>,
    <-0.8972833, -0.2568873, 0.3590146>,
    <-0.8972017, -0.2274626, 0.3785365>,
    <-0.9088515, -0.2790217, 0.3100579>,
    <-0.9120578, -0.2441674, 0.3294433>,
    <-0.9022719, -0.1951794, 0.3844612>,
    <-0.9137753, -0.2093842, 0.3480990>,
    <-0.9170783, 0.2629987, 0.2996648>,
    <-0.9306234, 0.2364072, 0.2793775>,
    <-0.9309869, 0.2254312, 0.2871310>,
    <-0.9227052, 0.2388194, 0.3026227>,
    <-0.9298219, 0.2493172, 0.2706882>,
    <-0.9208829, 0.2791156, 0.2721565>,
    <-0.8872926, 0.3232410, 0.3289789>,
    <-0.8960450, 0.2755554, 0.3480984>,
    <-0.9119492, 0.2445735, 0.3294427>,
    <-0.9400952, 0.2038679, 0.2732376>,
    <-0.9390988, 0.1995260, 0.2797908>,
    <-0.9265995, 0.2127857, 0.3100573>,
    <-0.9345726, 0.2076206, 0.2889080>,
    <-0.9377489, 0.2192552, 0.2693589>,
    <-0.8852312, 0.2791958, 0.3720423>,
    <-0.9001840, 0.2499057, 0.3566734>,
    <-0.8902852, 0.2623111, 0.3722702>,
    <-0.8794606, 0.2863604, 0.3801930>,
    <-0.8653294, 0.3153198, 0.3895876>,
    <-0.8608751, 0.3128619, 0.4012623>,
    <-0.9055141, 0.2261705, 0.3590141>,
    <-0.8907311, 0.2516123, 0.3785358>,
    <-0.8789804, 0.2821055, 0.3844604>,
    <-0.8695793, 0.3176971, 0.3780218>,
    <0.9490439, 0.2365601, -0.2082186>,
    <0.9227209, 0.2559004, -0.2882727>,
    <0.9326384, 0.2743790, -0.2343111>,
    <0.9471029, 0.2671419, -0.1778521>,
    <0.9578223, 0.2256832, -0.1778863>,
    <0.9287570, 0.2548734, -0.2691653>,
    <0.8763105, 0.2759176, -0.3949042>,
    <0.9172956, 0.2980965, -0.2640214>,
    <0.8452364, 0.2655122, -0.4637658>,
    <0.5569492, 0.2038895, -0.8051314>,
    <0.8135478, 0.2853411, -0.5066758>,
    <0.8970113, 0.3198490, -0.3050694>,
    <0.9370025, 0.3004140, -0.1782631>,
    <0.9212644, 0.3339228, -0.1994176>,
    <0.9572280, 0.2122349, -0.1966491>,
    <0.9153602, 0.1861767, -0.3570069>,
    <0.8882508, 0.2146059, -0.4061464>,
    <0.9256289, 0.2469582, -0.2867453>,
    <0.7865030, 0.1601532, -0.5964596>,
    <0.7694487, 0.1949456, -0.6082310>,
    <0.5621527, 0.1221334, -0.8179656>,
    <0.5950996, 0.1591387, -0.7877381>,
    <0.8166733, 0.2440767, -0.5229447>,
    <0.6011873, 0.1919934, -0.7757012>,
    <0.3538501, -0.1120618, -0.9285646>,
    <0.2608955, -0.0753670, -0.9624206>,
    <0.3241077, -0.0773354, -0.9428539>,
    <0.4306257, -0.1090968, -0.8959126>,
    <0.5974410, -0.1604032, -0.7857067>,
    <0.5504748, -0.1760774, -0.8160725>,
    <0.5609077, -0.2029705, -0.8026117>,
    <0.3232948, -0.1041321, -0.9405514>,
    <0.2478557, -0.0719675, -0.9661202>,
    <0.2439991, -0.0525017, -0.9683532>,
    <0.3147724, -0.0565153, -0.9474832>,
    <0.2169174, -0.0561167, -0.9745757>,
    <0.2129087, -0.0375410, -0.9763506>,
    <0.4264596, -0.0806759, -0.9009016>,
    <0.6190469, -0.1348932, -0.7736826>,
    <0.9351871, -0.2948404, -0.1961992>,
    <0.8863569, -0.2965661, -0.3555560>,
    <0.8772717, -0.2584838, -0.4044508>,
    <0.9254045, -0.2490819, -0.2856304>,
    <0.9204366, -0.3363806, -0.1991092>,
    <0.8931575, -0.3316606, -0.3037612>,
    <0.7628483, -0.2550254, -0.5941586>,
    <0.7654689, -0.2163586, -0.6060086>,
    <0.8081127, -0.3048226, -0.5040208>,
    <0.8305166, -0.1973191, -0.5208717>,
    <0.3600934, 0.0792739, -0.9295420>,
    <0.2617397, 0.0646520, -0.9629706>,
    <0.3172511, 0.0944541, -0.9436261>,
    <0.4249637, 0.1201211, -0.8972050>,
    <0.3297302, 0.0709180, -0.9414078>,
    <0.2488018, 0.0611212, -0.9666240>,
    <0.2358408, 0.0759783, -0.9688170>,
    <0.2989438, 0.1078107, -0.9481611>,
    <0.2142978, 0.0593994, -0.9749606>,
    <0.2017592, 0.0734356, -0.9766783>,
    <0.2410076, 0.0962778, -0.9657359>,
    <0.2703592, 0.1066650, -0.9568325>,
    <0.4073874, 0.1426409, -0.9020472>,
    <0.3448302, 0.1351497, -0.9288846>,
    <0.3106475, 0.0705603, -0.9479026>,
    <0.2609828, 0.0580080, -0.9635990>,
    <0.2365092, 0.0578130, -0.9699078>,
    <0.2558432, 0.0655379, -0.9644942>,
    <0.2266050, 0.0542560, -0.9724744>,
    <0.2060803, 0.0524935, -0.9771261>,
    <0.2117870, 0.0373444, -0.9766021>,
    <0.2215300, 0.0593595, -0.9733452>,
    <0.2215300, 0.0593595, -0.9733452>,
    <0.1983898, 0.0531590, -0.9786805>,
    <0.2083712, 0.0559061, -0.9764507>,
    <0.1983898, 0.0531590, -0.9786805>,
    <0.1916759, 0.0513600, -0.9801135>,
    <0.1916759, 0.0513600, -0.9801135>,
    <0.2017592, 0.0734356, -0.9766783>,
    <0.3065580, -0.0949123, -0.9471082>,
    <0.2570582, -0.0808883, -0.9630047>,
    <0.2355273, -0.0687108, -0.9694358>,
    <0.2562301, -0.0716997, -0.9639529>,
    <0.3539437, -0.1191669, -0.9276438>,
    <0.2783080, -0.0929968, -0.9559792>,
    <0.2252327, -0.0668630, -0.9720080>,
    <0.2062773, -0.0580174, -0.9767721>,
    <0.2491853, -0.0820636, -0.9649727>,
    <0.2038746, -0.0742028, -0.9761809>,
    <0.2233976, -0.0598576, -0.9728878>,
    <0.2233976, -0.0598576, -0.9728878>,
    <0.1998940, -0.0535601, -0.9783525>,
    <0.2099462, -0.0561836, -0.9760973>,
    <0.1998940, -0.0535601, -0.9783525>,
    <0.1930811, -0.0517346, -0.9798179>,
    <0.1930811, -0.0517346, -0.9798179>,
    <0.2129087, -0.0375410, -0.9763506>,
    <-0.9257124, -0.2307753, 0.2996653>,
    <-0.9241470, -0.2605768, 0.2793781>,
    <-0.9189738, -0.2702640, 0.2871315>,
    <-0.9184957, -0.2545287, 0.3026231>,
    <-0.9299080, -0.2489958, 0.2706884>,
    <-0.9370658, -0.2187200, 0.2721567>,
    <-0.9160802, -0.2934926, 0.2732383>,
    <-0.9130463, -0.2967545, 0.2797914>,
    <-0.9017008, -0.3288296, 0.2807255>,
    <-0.9045788, -0.3289553, 0.2711560>,
    <-0.9131738, -0.2874814, 0.2889085>,
    <-0.9073526, -0.3290522, 0.2616025>,
    <-0.9178853, -0.3338738, 0.2145109>,
    <-0.9217419, -0.2789937, 0.2693591>,
    <-0.9447126, -0.2094290, 0.2523045>,
    <-0.9402793, -0.2430227, 0.2383585>,
    <-0.9398730, -0.2271597, 0.2550240>,
    <-0.9439899, -0.2000620, 0.2624087>,
    <-0.9326126, -0.2671289, 0.2426436>,
    <-0.9351694, -0.2371604, 0.2630840>,
    <-0.9375287, -0.2879291, 0.1952862>,
    <-0.9434108, -0.2526309, 0.2148340>,
    <-0.9413796, -0.2036576, 0.2689387>,
    <-0.9476885, -0.2172010, 0.2339023>,
    <-0.9406516, 0.2697340, 0.2059564>,
    <-0.9535237, 0.2421482, 0.1793232>,
    <-0.9463314, 0.2290665, 0.2280033>,
    <-0.9307240, 0.2406487, 0.2753925>,
    <-0.9348432, 0.2445437, 0.2574228>,
    <-0.9423292, 0.2834411, 0.1779798>,
    <-0.9177509, 0.3342431, 0.2145109>,
    <-0.9293227, 0.2857426, 0.2339028>,
    <-0.9433331, 0.2529206, 0.2148343>,
    <-0.9614557, 0.2083755, 0.1793951>,
    <-0.9461139, 0.2011298, 0.2538017>,
    <-0.9558883, 0.2194103, 0.1952863>,
    <-0.9068352, 0.2014312, 0.3702369>,
    <-0.8822930, 0.1963834, 0.4277764>,
    <-0.9228596, 0.2909853, 0.2523046>,
    <-0.9358171, 0.2596757, 0.2383586>,
    <-0.9275337, 0.2732103, 0.2550243>,
    <-0.9175501, 0.2987360, 0.2624091>,
    <-0.9043961, 0.3294575, 0.2711559>,
    <-0.9021106, 0.3277039, 0.2807252>,
    <-0.9412307, 0.2349657, 0.2426437>,
    <-0.9284605, 0.2621977, 0.2630844>,
    <-0.9170873, 0.2943170, 0.2689393>,
    <-0.9065832, 0.3311663, 0.2616024>,
    <-0.9494665, -0.2367222, 0.2060972>,
    <-0.9468332, -0.2670506, 0.1794180>,
    <-0.9339980, -0.2747641, 0.2283691>,
    <-0.9261948, -0.2569114, 0.2759705>,
    <-0.9316822, -0.2556337, 0.2581078>,
    <-0.9577736, -0.2257070, 0.1781184>,
    <-0.9368101, -0.3002619, 0.1795260>,
    <-0.9197840, -0.2988264, 0.2543624>,
    <-0.9216043, -0.3339791, 0.1977458>,
    <-0.9013053, -0.3214081, 0.2904231>,
    <-0.8885296, -0.2797512, 0.3636681>,
    <-0.8415982, -0.2968627, 0.4512040>,
    <-0.6534692, -0.2373640, 0.7187742>,
    <-0.8668258, -0.2703749, 0.4189397>,
    <-0.9577347, -0.2123334, 0.1940588>,
    <-0.9294699, -0.2478620, 0.2732218>,
    <-0.8990915, -0.2172141, 0.3800691>,
    <-0.9228177, -0.1878201, 0.3363496>,
    <-0.8437961, -0.2501763, 0.4747842>,
    <-0.8064661, -0.2043583, 0.5548424>,
    <-0.6801746, -0.2125606, 0.7015558>,
    <-0.6713134, -0.1795227, 0.7191036>,
    <-0.8245061, -0.1689037, 0.5400566>,
    <-0.6556652, -0.1440655, 0.7411804>,
    <-0.4699467, 0.1424374, 0.8711267>,
    <-0.5302280, 0.1349568, 0.8370453>,
    <-0.4162432, 0.1010534, 0.9036204>,
    <-0.3559492, 0.0988254, 0.9292652>,
    <-0.3335068, 0.0968208, 0.9377627>,
    <-0.4214821, 0.1357132, 0.8966241>,
    <-0.6561426, 0.2392976, 0.7156910>,
    <-0.6491079, 0.2037268, 0.7329081>,
    <-0.6734508, 0.1808072, 0.7167794>,
    <-0.5267027, 0.1031045, 0.8437735>,
    <-0.3949854, 0.0762442, 0.9155181>,
    <-0.7015742, 0.1533852, 0.6958927>,
    <-0.3180108, 0.0703914, 0.9454703>,
    <-0.3024596, 0.0763841, 0.9500967>,
    <-0.9356663, 0.2950055, 0.1936501>,
    <-0.9291401, 0.2502085, 0.2722029>,
    <-0.8878635, 0.2616157, 0.3784913>,
    <-0.8935648, 0.2988469, 0.3350111>,
    <-0.8973971, 0.3332067, 0.2892262>,
    <-0.9207274, 0.3365537, 0.1974654>,
    <-0.8571661, 0.2041334, 0.4728592>,
    <-0.8019916, 0.2266472, 0.5526667>,
    <-0.8023900, 0.2663399, 0.5340725>,
    <-0.8366987, 0.3139197, 0.4487647>,
    <-0.4699433, -0.1078481, 0.8760834>,
    <-0.5234258, -0.1473253, 0.8392382>,
    <-0.4070219, -0.1194386, 0.9055758>,
    <-0.3520110, -0.0905133, 0.9316091>,
    <-0.3332191, -0.0810283, 0.9393612>,
    <-0.4131279, -0.0830108, 0.9068818>,
    <-0.5017116, -0.1681416, 0.8485363>,
    <-0.3764519, -0.1286444, 0.9174610>,
    <-0.4356439, -0.1662769, 0.8846278>,
    <-0.3450855, -0.1318777, 0.9292601>,
    <-0.3053791, -0.0953508, 0.9474449>,
    <-0.3057302, -0.1140733, 0.9452599>,
    <-0.2924535, -0.0826835, 0.9526985>,
    <-0.3739119, -0.0730303, 0.9245845>,
    <-0.3372977, -0.0798967, 0.9380015>,
    <-0.3289771, -0.0706749, 0.9416895>,
    <-0.3409346, -0.0637046, 0.9379261>,
    <-0.2990598, -0.0794344, 0.9509224>,
    <-0.2956898, -0.0667121, 0.9529518>,
    <-0.3037475, -0.0554482, 0.9511377>,
    <-0.5477053, -0.0479181, 0.8352980>,
    <-0.3846468, 0.1220384, 0.9149609>,
    <-0.3352754, 0.0965111, 0.9371638>,
    <-0.3193870, 0.0953288, 0.9428172>,
    <-0.3357661, 0.1079987, 0.9357336>,
    <-0.3540393, 0.1225791, 0.9271626>,
    <-0.4442726, 0.1539880, 0.8825585>,
    <-0.3072338, 0.0821287, 0.9480835>,
    <-0.3075357, 0.0887344, 0.9473901>,
    <-0.3154645, 0.0996166, 0.9436942>,
    <-0.3173816, 0.1125898, 0.9415904>,
    <0.3514838, 0.1668025, -0.9212144>,
    <0.3227406, 0.1593217, -0.9329818>,
    <0.3248241, 0.1690687, -0.9305402>,
    <0.3379615, 0.1689123, -0.9258783>,
    <0.3412953, 0.1591487, -0.9263850>,
    <0.3640963, 0.1697809, -0.9157556>,
    <0.3640963, 0.1697809, -0.9157556>,
    <0.3675017, 0.1713688, -0.9140980>,
    <0.3547563, 0.1657961, -0.9201411>,
    <0.3270314, 0.1551586, -0.9321890>,
    <0.3029399, 0.1649780, -0.9386212>,
    <0.3114686, 0.1787959, -0.9332842>,
    <0.3017928, 0.1482847, -0.9417711>,
    <0.3720907, 0.2176086, -0.9023276>,
    <0.3067543, 0.1942644, -0.9317527>,
    <0.3072203, 0.1967195, -0.9310839>,
    <0.3090067, 0.1712928, -0.9355072>,
    <0.2929918, 0.1880866, -0.9374323>,
    <0.2770835, 0.1779405, -0.9442256>,
    <0.2864086, 0.1335546, -0.9487535>,
    <0.2864086, 0.1335546, -0.9487535>,
    <0.3412953, 0.1591487, -0.9263850>,
    <0.3594077, 0.1678411, -0.9179627>,
    <0.3616504, 0.1686422, -0.9169345>,
    <0.3452959, 0.1610151, -0.9245782>,
    <0.3359751, 0.1576113, -0.9285900>,
    <0.3675017, 0.1713688, -0.9140980>,
    <0.3675031, 0.1713703, -0.9140972>,
    <0.3675031, 0.1713703, -0.9140972>,
    <0.3675056, 0.1713738, -0.9140955>,
    <0.3595168, 0.1675866, -0.9179664>,
    <0.3416629, 0.1597139, -0.9261522>,
    <0.3675056, 0.1713738, -0.9140955>,
    <0.3675030, 0.1713760, -0.9140961>,
    <0.3675030, 0.1713760, -0.9140961>,
    <0.3674634, 0.1713623, -0.9141147>,
    <0.3634411, 0.1700795, -0.9159605>,
    <0.3602557, 0.1706752, -0.9171073>,
    <0.3198280, 0.1512452, -0.9353261>,
    <0.3553676, 0.1739862, -0.9183914>,
    <0.3718956, 0.1738397, -0.9118516>,
    <0.3852952, 0.1776231, -0.9055372>,
    <0.3970947, 0.1862444, -0.8986817>,
    <0.3855682, 0.1834734, -0.9042537>,
    <0.3674634, 0.1713623, -0.9141147>,
    <0.4092716, 0.1852210, -0.8934148>,
    <0.4209965, 0.1981625, -0.8851517>,
    <0.4737426, 0.2119126, -0.8547871>,
    <0.4768650, 0.2267533, -0.8492248>,
    <0.4112329, 0.2010463, -0.8890826>,
    <0.4640136, 0.2346138, -0.8541942>,
    <0.3720496, -0.1728868, -0.9119700>,
    <0.3854352, -0.1813588, -0.9047368>,
    <0.3981853, -0.1842649, -0.8986072>,
    <0.3866490, -0.1764087, -0.9051975>,
    <0.3673594, -0.1712894, -0.9141701>,
    <0.3664880, -0.1711931, -0.9145378>,
    <0.3679840, -0.1733175, -0.9135364>,
    <0.4074903, -0.1950231, -0.8921422>,
    <0.4231984, -0.1950269, -0.8847981>,
    <0.3658421, -0.1765215, -0.9137832>,
    <0.3736957, -0.2117912, -0.9030482>,
    <0.4685895, -0.2267477, -0.8538205>,
    <0.4813574, -0.2195074, -0.8485939>,
    <0.4163445, -0.1845684, -0.8902762>,
    <0.4778033, -0.2041353, -0.8544196>,
    <0.3637874, -0.1696173, -0.9159087>,
    <0.3644987, -0.1699584, -0.9155626>,
    <0.3564497, -0.1662077, -0.9194121>,
    <0.3559361, -0.1663368, -0.9195877>,
    <0.3673594, -0.1712894, -0.9141701>,
    <0.3673074, -0.1712622, -0.9141961>,
    <0.3673074, -0.1712622, -0.9141961>,
    <0.3672862, -0.1712544, -0.9142061>,
    <0.3631470, -0.1695431, -0.9161765>,
    <0.3499967, -0.1641824, -0.9222508>,
    <0.3672862, -0.1712544, -0.9142061>,
    <0.3672888, -0.1712654, -0.9142030>,
    <0.3672888, -0.1712654, -0.9142030>,
    <0.3673160, -0.1713019, -0.9141852>,
    <0.3591145, -0.1680376, -0.9180415>,
    <0.3399875, -0.1625625, -0.9262732>,
    <0.3420626, -0.1615782, -0.9256812>,
    <0.3226506, -0.1609991, -0.9327250>,
    <0.5190066, -0.2453189, -0.8188106>,
    <0.5307323, -0.2385784, -0.8132672>,
    <0.5334076, -0.2318979, -0.8134493>,
    <0.5248629, -0.2339971, -0.8183913>,
    <0.5132841, -0.2539173, -0.8197960>,
    <0.5450128, -0.2520125, -0.7996567>,
    <0.5557473, -0.2301364, -0.7988630>,
    <0.5398936, -0.2195884, -0.8125859>,
    <0.5734073, -0.2450968, -0.7817491>,
    <0.5166389, -0.2137262, -0.8290991>,
    <0.3530537, -0.1692376, -0.9201694>,
    <0.3347977, -0.1722620, -0.9264105>,
    <0.3242465, -0.1752879, -0.9295904>,
    <0.3287349, -0.1665521, -0.9296202>,
    <0.3673160, -0.1713019, -0.9141852>,
    <0.3632037, -0.1694243, -0.9161760>,
    <0.3632037, -0.1694243, -0.9161760>,
    <0.3358196, -0.1567045, -0.9287997>,
    <0.3058544, -0.1774916, -0.9353875>,
    <0.3071599, -0.1841527, -0.9336705>,
    <0.3358196, -0.1567045, -0.9287997>,
    <0.2727311, -0.1273354, -0.9536265>,
    <0.2727311, -0.1273354, -0.9536265>,
    <0.2835381, -0.1871738, -0.9405169>,
    <0.2943350, -0.1942070, -0.9357620>,
    <0.2982788, -0.1961551, -0.9341054>,
    <0.3038274, -0.1720594, -0.9370616>,
    <0.2881873, -0.1870027, -0.9391369>,
    <-0.5870842, 0.2513656, 0.7695112>,
    <-0.6202821, 0.2671853, 0.7374701>,
    <-0.5761720, 0.2524088, 0.7773774>,
    <-0.5461614, 0.2398892, 0.8025963>,
    <-0.5068637, 0.2273460, 0.8315064>,
    <-0.4438588, 0.2054465, 0.8722277>,
    <-0.3123317, 0.1868469, 0.9314167>,
    <-0.6862221, 0.2787594, 0.6718574>,
    <-0.6862221, 0.2787594, 0.6718574>,
    <-0.6788157, 0.2849877, 0.6767505>,
    <-0.5826128, 0.2594255, 0.7702342>,
    <-0.5456721, 0.2432669, 0.8019122>,
    <-0.6788157, 0.2849877, 0.6767505>,
    <-0.6137763, 0.2704388, 0.7417153>,
    <-0.6137763, 0.2704388, 0.7417153>,
    <-0.5335268, 0.2487907, 0.8083640>,
    <-0.5160827, 0.2286779, 0.8254484>,
    <-0.5384980, 0.2345863, 0.8093140>,
    <0.5219077, 0.2394896, -0.8186923>,
    <0.5241426, 0.2530051, -0.8131807>,
    <0.5202414, 0.2590926, -0.8137689>,
    <0.5161866, 0.2509551, -0.8188852>,
    <0.5267686, 0.2306779, -0.8181091>,
    <0.5444935, 0.2558606, -0.7987879>,
    <0.5334881, 0.2776672, -0.7989314>,
    <0.5149390, 0.2721315, -0.8128851>,
    <0.5566487, 0.2818145, -0.7814875>,
    <0.5988619, 0.3454031, -0.7225380>,
    <0.5459333, 0.3140766, -0.7767321>,
    <0.5119066, 0.2939116, -0.8071974>,
    <0.4953008, 0.2578583, -0.8295699>,
    <0.4711618, 0.2700974, -0.8396749>,
    <0.5394054, 0.2239032, -0.8117322>,
    <0.5617132, 0.2266569, -0.7956789>,
    <0.5700551, 0.2487733, -0.7830383>,
    <0.5674672, 0.2584430, -0.7817852>,
    <0.5827450, 0.2381287, -0.7769833>,
    <0.5806216, 0.2611819, -0.7711437>,
    <0.6226879, 0.2631719, -0.7368856>,
    <0.6261394, 0.2917185, -0.7230835>,
    <0.5826437, 0.2835035, -0.7616772>,
    <0.6290443, 0.3211961, -0.7079098>,
    <0.6526424, -0.3181602, -0.6876278>,
    <0.6657184, -0.3034131, -0.6817327>,
    <0.6780467, -0.2965088, -0.6725587>,
    <0.6744953, -0.3039898, -0.6727899>,
    <0.6259437, -0.2921374, -0.7230838>,
    <0.6018573, -0.3078429, -0.7368857>,
    <0.5985588, -0.3459281, -0.7225380>,
    <0.6692129, -0.3388894, -0.6612927>,
    <0.6866583, -0.3204376, -0.6525490>,
    <0.6901886, -0.2863651, -0.6645561>,
    <0.6934307, -0.2804420, -0.6637063>,
    <0.7028904, -0.3009405, -0.6444998>,
    <0.6900374, -0.2824737, -0.6663760>,
    <0.6503920, -0.2754150, -0.7079102>,
    <0.5164203, -0.2683394, -0.8132060>,
    <0.5339660, -0.2842305, -0.7962998>,
    <0.5562074, -0.2763874, -0.7837368>,
    <0.5613739, -0.2679062, -0.7829978>,
    <0.4689914, -0.2727219, -0.8400416>,
    <0.5103168, -0.2962848, -0.8073364>,
    <0.5568177, -0.2932484, -0.7771482>,
    <0.5730680, -0.2767887, -0.7713502>,
    <0.5449202, -0.3157321, -0.7767723>,
    <0.5912667, -0.2639057, -0.7620744>,
    <-0.4064142, -0.2033873, 0.8907643>,
    <-0.4100357, -0.2134753, 0.8867350>,
    <-0.4074773, -0.2171977, 0.8870104>,
    <-0.3993817, -0.2045556, 0.8936729>,
    <-0.3784783, -0.1819112, 0.9075585>,
    <-0.3623715, -0.1710791, 0.9161980>,
    <-0.3513189, -0.1654335, 0.9215242>,
    <-0.4196876, -0.2117568, 0.8826219>,
    <-0.4196876, -0.2117568, 0.8826219>,
    <-0.4077224, -0.2057196, 0.8896302>,
    <-0.3730952, -0.2016122, 0.9056227>,
    <-0.4014844, -0.2246385, 0.8878895>,
    <-0.4077224, -0.2057196, 0.8896302>,
    <-0.3509617, -0.1770805, 0.9194935>,
    <-0.3509617, -0.1770805, 0.9194935>,
    <-0.3555234, -0.2149440, 0.9096165>,
    <-0.3402721, -0.1999358, 0.9188257>,
    <-0.3953710, -0.2383068, 0.8870691>,
    <-0.4151578, -0.2264284, 0.8811210>,
    <-0.4392120, -0.2638293, 0.8587706>,
    <-0.5213551, -0.2925593, 0.8016221>,
    <-0.4023198, -0.2005272, 0.8932680>,
    <-0.3574047, -0.1546565, 0.9210555>,
    <-0.3460131, -0.1505947, 0.9260649>,
    <-0.3576287, -0.1589053, 0.9202450>,
    <-0.3715255, -0.1659777, 0.9134660>,
    <-0.4062787, -0.1839850, 0.8950347>,
    <-0.3674403, -0.1569432, 0.9167096>,
    <-0.3163017, -0.1085859, 0.9424236>,
    <-0.3415034, -0.1437453, 0.9288233>,
    <-0.3415034, -0.1437453, 0.9288233>,
    <-0.3250104, -0.1368031, 0.9357634>,
    <-0.3397260, -0.1505876, 0.9283909>,
    <-0.3613350, -0.1645753, 0.9177973>,
    <-0.3250104, -0.1368031, 0.9357634>,
    <-0.3055070, -0.1285937, 0.9434665>,
    <-0.3055070, -0.1285937, 0.9434665>,
    <-0.3513189, -0.1654335, 0.9215242>,
    <-0.3810164, -0.1763845, 0.9075875>,
    <-0.4423957, -0.2120063, 0.8714008>,
    <-0.3805927, -0.1570830, 0.9113035>,
    <-0.4377461, -0.1968543, 0.8772837>,
    <-0.4533696, -0.1988045, 0.8688687>,
    <-0.4313307, -0.1789620, 0.8842660>,
    <-0.3163017, -0.1085859, 0.9424236>,
    <-0.5016165, -0.2398969, 0.8311621>,
    <-0.4996438, -0.2255386, 0.8363543>,
    <-0.5844957, -0.2928948, 0.7566885>,
    <-0.5781872, -0.2686237, 0.7704160>,
    <-0.4861395, -0.2044390, 0.8496311>,
    <-0.5658804, -0.2411816, 0.7884230>,
    <-0.6360495, 0.3096909, 0.7067762>,
    <-0.6493264, 0.2941866, 0.7013056>,
    <-0.6656670, 0.2923208, 0.6866120>,
    <-0.6619761, 0.3015785, 0.6861764>,
    <-0.6836477, 0.3186577, 0.6565692>,
    <-0.6577032, 0.3322662, 0.6760367>,
    <-0.5404675, 0.3205474, 0.7779102>,
    <-0.5536219, 0.2831559, 0.7831510>,
    <-0.5848212, 0.2736471, 0.7636108>,
    <-0.6636292, 0.2749147, 0.6957142>,
    <-0.6811808, 0.2773129, 0.6775621>,
    <-0.6209963, 0.2663048, 0.7371875>,
    <-0.6891288, 0.2863652, 0.6656550>,
    <-0.7037667, 0.3013359, 0.6433577>,
    <-0.3722304, 0.1937420, 0.9076941>,
    <-0.4742716, 0.2234174, 0.8515581>,
    <-0.4599698, 0.2271768, 0.8583813>,
    <-0.4164875, 0.2205493, 0.8819842>,
    <-0.3826483, 0.2242033, 0.8962774>,
    <-0.2984996, 0.1839954, 0.9365061>,
    <-0.3123317, 0.1868469, 0.9314167>,
    <-0.5481997, 0.2444359, 0.7998301>,
    <-0.5066330, 0.2436861, 0.8270067>,
    <-0.4757673, 0.2482098, 0.8438231>,
    <-0.4572755, 0.2625057, 0.8496998>,
    <0.6632355, 0.2954438, -0.6876276>,
    <0.6603436, 0.3149398, -0.6817326>,
    <0.6629792, 0.3288219, -0.6725584>,
    <0.6664272, 0.3212928, -0.6727895>,
    <0.6897660, 0.2948129, -0.6612928>,
    <0.6868448, 0.3200374, -0.6525491>,
    <0.6630132, 0.3446433, -0.6645559>,
    <0.6605600, 0.3509343, -0.6637060>,
    <0.6823429, 0.3450044, -0.6444999>,
    <0.7032651, 0.4056615, -0.5838295>,
    <0.6680390, 0.3846389, -0.6370061>,
    <0.6558839, 0.3782651, -0.6532471>,
    <0.6599353, 0.3470290, -0.6663755>,
    <0.6428564, 0.3713606, -0.6699455>,
    <0.7098919, 0.2939111, -0.6400545>,
    <0.7105803, 0.2866497, -0.6425789>,
    <0.7091005, 0.3094823, -0.6335591>,
    <0.7131381, 0.3245649, -0.6213628>,
    <0.7105688, 0.2901504, -0.6410185>,
    <0.7044439, 0.3169102, -0.6350801>,
    <0.7354886, 0.3107701, -0.6020618>,
    <0.7355160, 0.3427078, -0.5844378>,
    <0.7065506, 0.3440298, -0.6184090>,
    <0.7344936, 0.3751801, -0.5654725>,
    <0.7506680, -0.3661117, -0.5499635>,
    <0.7603729, -0.3466823, -0.5492216>,
    <0.7737968, -0.3383409, -0.5355035>,
    <0.7728407, -0.3482768, -0.5304908>,
    <0.7353106, -0.3431498, -0.5844370>,
    <0.7108271, -0.3636579, -0.6020612>,
    <0.7029460, -0.4062148, -0.5838292>,
    <0.7615004, -0.3857105, -0.5209073>,
    <0.7760260, -0.3621083, -0.5163924>,
    <0.7814062, -0.3241689, -0.5332156>,
    <0.7879144, -0.3184507, -0.5270484>,
    <0.7895617, -0.3379022, -0.5122640>,
    <0.7884530, -0.3225327, -0.5237505>,
    <0.7595285, -0.3214937, -0.5654717>,
    <0.6814590, -0.3548865, -0.6400541>,
    <0.6763390, -0.3600813, -0.6425784>,
    <0.6928786, -0.3442712, -0.6335586>,
    <0.7070277, -0.3376692, -0.6213624>,
    <0.6430360, -0.3710496, -0.6699454>,
    <0.6555293, -0.3788796, -0.6532470>,
    <0.6790134, -0.3578224, -0.6410179>,
    <0.6955756, -0.3359295, -0.6350795>,
    <0.6671268, -0.3862194, -0.6370059>,
    <0.7177045, -0.3201112, -0.6184085>,
    <-0.6433600, -0.2881277, 0.7092745>,
    <-0.6384481, -0.3062479, 0.7061135>,
    <-0.6500212, -0.3211462, 0.6887217>,
    <-0.6556483, -0.3133138, 0.6869933>,
    <-0.6817887, -0.3184627, 0.6585938>,
    <-0.6718485, -0.2888970, 0.6820250>,
    <-0.6300118, -0.3267283, 0.7045095>,
    <-0.6478962, -0.3418014, 0.6807366>,
    <-0.6160100, -0.3529124, 0.7042617>,
    <-0.6449590, -0.3705392, 0.6683775>,
    <-0.6617416, -0.3435247, 0.6663999>,
    <-0.6665325, -0.3834367, 0.6393048>,
    <-0.7032751, -0.4056277, 0.5838410>,
    <-0.6828297, -0.3453252, 0.6438122>,
    <-0.6913985, -0.2862796, 0.6633341>,
    <-0.7052732, -0.3209949, 0.6321012>,
    <-0.7044614, -0.3074262, 0.6397057>,
    <-0.7018966, -0.2830615, 0.6536186>,
    <-0.7054745, -0.3433983, 0.6199866>,
    <-0.7050997, -0.3171754, 0.6342193>,
    <-0.7333145, -0.3745027, 0.5674483>,
    <-0.7355196, -0.3426808, 0.5844492>,
    <-0.7106199, -0.2902090, 0.6409353>,
    <-0.7367142, -0.3112974, 0.6002883>,
    <-0.7506842, 0.3660603, 0.5499755>,
    <-0.7712554, 0.3475936, 0.5332390>,
    <-0.7737780, 0.3383648, 0.5355156>,
    <-0.7618788, 0.3473228, 0.5467244>,
    <-0.7760094, 0.3621265, 0.5164048>,
    <-0.7603917, 0.3851198, 0.5229601>,
    <-0.7029212, 0.4062401, 0.5838413>,
    <-0.7120183, 0.3642577, 0.6002885>,
    <-0.7352914, 0.3431697, 0.5844494>,
    <-0.7866335, 0.3219123, 0.5268588>,
    <-0.7878683, 0.3185439, 0.5270610>,
    <-0.7582511, 0.3210258, 0.5674484>,
    <-0.7830363, 0.3248780, 0.5303852>,
    <-0.7905934, 0.3384256, 0.5103236>,
    <-0.6693360, 0.3485467, 0.6561285>,
    <-0.7016356, 0.3351488, 0.6287947>,
    <-0.6900422, 0.3428942, 0.6373895>,
    <-0.6706843, 0.3570951, 0.6501273>,
    <-0.6455233, 0.3741197, 0.6658334>,
    <-0.6203585, 0.3598192, 0.6969113>,
    <-0.7170851, 0.3199471, 0.6192114>,
    <-0.6966160, 0.3364624, 0.6336554>,
    <-0.6796744, 0.3581250, 0.6401478>,
    <-0.6657997, 0.3857067, 0.6387027>,
    <0.7629777, 0.3397128, -0.5499639>,
    <0.7543322, 0.3596362, -0.5492220>,
    <0.7565708, 0.3752811, -0.5355042>,
    <0.7635675, 0.3681620, -0.5304916>,
    <0.7849545, 0.3354133, -0.5209073>,
    <0.7762110, 0.3617117, -0.5163923>,
    <0.7506058, 0.3902200, -0.5332160>,
    <0.7504086, 0.3988810, -0.5270492>,
    <0.7663687, 0.3876402, -0.5122638>,
    <0.7727917, 0.4458272, -0.4516981>,
    <0.7484229, 0.4308690, -0.5041974>,
    <0.7414302, 0.4276603, -0.5170957>,
    <0.7538817, 0.3966697, -0.5237514>,
    <0.7340765, 0.4242394, -0.5302383>,
    <0.8006794, 0.3315437, -0.4989903>,
    <0.7994080, 0.3223896, -0.5069633>,
    <0.7945419, 0.3468175, -0.4984183>,
    <0.7973297, 0.3630629, -0.4821313>,
    <0.7960273, 0.3249417, -0.5106402>,
    <0.7874243, 0.3542847, -0.5044257>,
    <0.8120803, 0.3431121, -0.4720166>,
    <0.8084165, 0.3767198, -0.4522664>,
    <0.7866244, 0.3832123, -0.4841182>,
    <0.8033693, 0.4104770, -0.4314005>,
    <0.8155983, -0.3978579, -0.4201292>,
    <0.8243237, -0.3758967, -0.4233109>,
    <0.8370736, -0.3659545, -0.4066757>,
    <0.8363674, -0.3768543, -0.3980835>,
    <0.8082236, -0.3771321, -0.4522676>,
    <0.7848337, -0.4015413, -0.4720176>,
    <0.7724931, -0.4463435, -0.4516988>,
    <0.8213357, -0.4160434, -0.3902762>,
    <0.8348627, -0.3895152, -0.3889500>,
    <0.8430082, -0.3496662, -0.4087429>,
    <0.8502713, -0.3434913, -0.3988138>,
    <0.8474420, -0.3625502, -0.3878136>,
    <0.8517778, -0.3482629, -0.3913917>,
    <0.8308389, -0.3515670, -0.4314017>,
    <0.7686436, -0.4002437, -0.4989909>,
    <0.7608138, -0.4051539, -0.5069642>,
    <0.7763988, -0.3857243, -0.4984192>,
    <0.7906356, -0.3774176, -0.4821319>,
    <0.7344404, -0.4236093, -0.5302381>,
    <0.7410797, -0.4282672, -0.5170958>,
    <0.7605957, -0.4009237, -0.5106412>,
    <0.7775438, -0.3754721, -0.5044267>,
    <0.7473547, -0.4327187, -0.5041979>,
    <0.7991896, -0.3562651, -0.4841190>,
    <0.3269572, 0.2284517, -0.9170108>,
    <0.3238365, 0.2250795, -0.9189500>,
    <0.3168969, 0.2190569, -0.9228166>,
    <0.3185829, 0.2209904, -0.9217745>,
    <0.3318658, 0.2297293, -0.9149260>,
    <0.3305712, 0.2309639, -0.9150838>,
    <0.3321713, 0.2325852, -0.9140932>,
    <0.3312594, 0.2319453, -0.9145866>,
    <0.3312594, 0.2319453, -0.9145866>,
    <0.3247949, 0.2274180, -0.9180356>,
    <0.3121803, 0.2137295, -0.9256691>,
    <0.3108340, 0.2106239, -0.9268332>,
    <0.3247949, 0.2274180, -0.9180356>,
    <0.3066663, 0.2147240, -0.9272807>,
    <0.3066663, 0.2147240, -0.9272807>,
    <0.2770835, 0.1779405, -0.9442256>,
    <0.3108377, 0.2112667, -0.9266857>,
    <0.3344748, 0.2261313, -0.9148723>,
    <-0.7629490, -0.3397585, 0.5499754>,
    <-0.7620256, -0.3673871, 0.5332388>,
    <-0.7565774, -0.3752516, 0.5355155>,
    <-0.7557910, -0.3603783, 0.5467243>,
    <-0.7762142, -0.3616873, 0.5164047>,
    <-0.7837893, -0.3349437, 0.5229599>,
    <-0.7522374, -0.3956751, 0.5268587>,
    <-0.7504508, -0.3987861, 0.5270609>,
    <-0.7333315, -0.4237054, 0.5316942>,
    <-0.7414425, -0.4276236, 0.5171084>,
    <-0.7521970, -0.3910131, 0.5303852>,
    <-0.7491266, -0.4312902, 0.5027903>,
    <-0.7727984, -0.4457936, 0.4517196>,
    <-0.7674327, -0.3880940, 0.5103236>,
    <-0.7990019, -0.3308157, 0.5021524>,
    <-0.7959392, -0.3623251, 0.4849756>,
    <-0.7945453, -0.3467877, 0.4984335>,
    <-0.7993875, -0.3224183, 0.5069773>,
    <-0.7866589, -0.3831192, 0.4841357>,
    <-0.7888130, -0.3548803, 0.5018307>,
    <-0.8024673, -0.4099457, 0.4335790>,
    <-0.8084172, -0.3766928, 0.4522878>,
    <-0.7975922, -0.3256249, 0.5077550>,
    <-0.8130579, -0.3435336, 0.4700229>,
    <-0.8156109, 0.3978073, 0.4201526>,
    <-0.8351772, 0.3763466, 0.4010514>,
    <-0.8370538, 0.3659750, 0.4066980>,
    <-0.8254963, 0.3763861, 0.4205821>,
    <-0.8348453, 0.3895307, 0.3889720>,
    <-0.8205071, 0.4155953, 0.3924902>,
    <-0.7724680, 0.4463664, 0.4517192>,
    <-0.7857855, 0.4020194, 0.4700229>,
    <-0.8082039, 0.3771501, 0.4522878>,
    <-0.8504149, 0.3478208, 0.3947343>,
    <-0.8502266, 0.3435774, 0.3988349>,
    <-0.8298526, 0.3512177, 0.4335791>,
    <-0.8442653, 0.3502170, 0.4056651>,
    <-0.8482202, 0.3629596, 0.3857237>,
    <-0.7670079, 0.3994268, 0.5021525>,
    <-0.7891769, 0.3768268, 0.4849757>,
    <-0.7763787, 0.3857462, 0.4984336>,
    <-0.7608231, 0.4051199, 0.5069774>,
    <-0.7410541, 0.4282963, 0.5171084>,
    <-0.7336052, 0.4232309, 0.5316944>,
    <-0.7991409, 0.3563515, 0.4841358>,
    <-0.7788932, 0.3761532, 0.5018307>,
    <-0.7621255, 0.4016834, 0.5077550>,
    <-0.7480717, 0.4331177, 0.5027900>,
    <0.8290336, 0.3690467, -0.4201284>,
    <0.8178188, 0.3898471, -0.4233103>,
    <0.8183983, 0.4060049, -0.4066747>,
    <0.8262941, 0.3984577, -0.3980822>,
    <0.8466522, 0.3617522, -0.3902761>,
    <0.8350254, 0.3891664, -0.3889501>,
    <0.8097353, 0.4210209, -0.4087423>,
    <0.8096738, 0.4305540, -0.3988127>,
    <0.8224548, 0.4161354, -0.3878137>,
    <0.8179437, 0.4719535, -0.3289801>,
    <0.8017968, 0.4616015, -0.3795340>,
    <0.7977628, 0.4602306, -0.3895668>,
    <0.8142975, 0.4286410, -0.3913904>,
    <0.7935834, 0.4587830, -0.3996792>,
    <0.8588183, 0.3556775, -0.3686795>,
    <0.8577947, 0.3459112, -0.3801758>,
    <0.8506041, 0.3713477, -0.3722546>,
    <0.8512186, 0.3877416, -0.3536713>,
    <0.8534793, 0.3483592, -0.3875809>,
    <0.8430145, 0.3793535, -0.3813363>,
    <0.8628035, 0.3645587, -0.3502385>,
    <0.8557932, 0.3988539, -0.3294444>,
    <0.8390074, 0.4088813, -0.3590023>,
    <0.8472141, 0.4329844, -0.3078193>,
    <0.8574508, -0.4182976, -0.2996752>,
    <0.8663577, -0.3950737, -0.3055178>,
    <0.8777026, -0.3836493, -0.2871434>,
    <0.8762380, -0.3947558, -0.2763601>,
    <0.8556335, -0.3991973, -0.3294432>,
    <0.8338680, -0.4266121, -0.3502374>,
    <0.8176958, -0.4723833, -0.3289795>,
    <0.8589736, -0.4350946, -0.2699205>,
    <0.8724055, -0.4069750, -0.2707028>,
    <0.8834193, -0.3663559, -0.2921536>,
    <0.8902140, -0.3594845, -0.2798033>,
    <0.8848872, -0.3784626, -0.2715524>,
    <0.8913349, -0.3642886, -0.2698443>,
    <0.8762644, -0.3706867, -0.3078182>,
    <0.8245028, -0.4292680, -0.3686788>,
    <0.8163637, -0.4347615, -0.3801747>,
    <0.8312271, -0.4129030, -0.3722536>,
    <0.8441803, -0.4028358, -0.3536706>,
    <0.7941093, -0.4578718, -0.3996797>,
    <0.7974528, -0.4607676, -0.3895668>,
    <0.8154651, -0.4298822, -0.3875797>,
    <0.8324814, -0.4019429, -0.3813352>,
    <0.8006571, -0.4635757, -0.3795336>,
    <0.8525252, -0.3798931, -0.3590015>,
    <0.3236174, -0.2263259, -0.9187211>,
    <0.3072700, -0.2136279, -0.9273340>,
    <0.3089479, -0.2144693, -0.9265820>,
    <0.3226652, -0.2248372, -0.9194212>,
    <0.3264736, -0.2285937, -0.9171477>,
    <0.3314676, -0.2320891, -0.9144747>,
    <0.3314676, -0.2320891, -0.9144747>,
    <0.3321511, -0.2325657, -0.9141055>,
    <0.3280786, -0.2290057, -0.9164719>,
    <0.3258570, -0.2248780, -0.9182849>,
    <0.2923313, -0.1997773, -0.9352173>,
    <0.3008515, -0.2058274, -0.9311946>,
    <0.3263128, -0.2186208, -0.9196330>,
    <0.3122174, -0.2153715, -0.9252759>,
    <0.2835381, -0.1871738, -0.9405169>,
    <0.3122441, -0.2186310, -0.9245021>,
    <0.3122441, -0.2186310, -0.9245021>,
    <0.3264736, -0.2285937, -0.9171477>,
    <0.8715931, 0.3879686, -0.2996761>,
    <0.8595279, 0.4097198, -0.3055184>,
    <0.8580686, 0.4257539, -0.2871443>,
    <0.8656351, 0.4174928, -0.2763613>,
    <0.8854393, 0.3783384, -0.2699208>,
    <0.8725324, 0.4067028, -0.2707030>,
    <0.8484958, 0.4412492, -0.2921542>,
    <0.8475995, 0.4508710, -0.2798043>,
    <0.8587137, 0.4345918, -0.2715524>,
    <0.8459542, 0.4882076, -0.2145105>,
    <0.8360656, 0.4813793, -0.2631887>,
    <0.8336972, 0.4810578, -0.2711687>,
    <0.8520000, 0.4486417, -0.2698455>,
    <0.8312666, 0.4807101, -0.2791301>,
    <0.8947962, 0.3706508, -0.2489131>,
    <0.8949198, 0.3609073, -0.2624205>,
    <0.8861381, 0.3869323, -0.2550346>,
    <0.8844309, 0.4029867, -0.2353374>,
    <0.8908828, 0.3636430, -0.2721978>,
    <0.8790423, 0.3956350, -0.2660028>,
    <0.8950906, 0.3782445, -0.2361017>,
    <0.8852031, 0.4126281, -0.2148338>,
    <0.8720191, 0.4250919, -0.2426511>,
    <0.8736640, 0.4466021, -0.1930225>,
    <0.8791111, -0.4288395, -0.2079912>,
    <0.8715890, -0.3972010, -0.2873396>,
    <0.8909412, -0.3893594, -0.2337158>,
    <0.8972638, -0.4041549, -0.1776978>,
    <0.8850888, -0.4128727, -0.2148347>,
    <0.8651050, -0.4425483, -0.2361025>,
    <0.8457773, -0.4885140, -0.2145109>,
    <0.8788267, -0.4428315, -0.1776622>,
    <0.8755533, -0.4019355, -0.2680565>,
    <0.8493923, -0.3522246, -0.3930274>,
    <0.8945351, -0.3613629, -0.2631041>,
    <0.8193254, -0.3404963, -0.4612680>,
    <0.9109239, -0.3721778, -0.1780486>,
    <0.9036974, -0.3821952, -0.1930232>,
    <0.8590988, -0.4472039, -0.2489135>,
    <0.8517141, -0.4535616, -0.2624213>,
    <0.8660057, -0.4301058, -0.2550354>,
    <0.8772068, -0.4184785, -0.2353378>,
    <0.8319406, -0.4795429, -0.2791297>,
    <0.8334569, -0.4814740, -0.2711686>,
    <0.8512148, -0.4487106, -0.2721988>,
    <0.8681113, -0.4190762, -0.2660037>,
    <0.8349195, -0.4833643, -0.2631890>,
    <0.8861622, -0.3947616, -0.2426517>,
    <-0.8290027, -0.3690887, 0.4201526>,
    <-0.8251398, -0.3978720, 0.4010513>,
    <-0.8184009, -0.4059762, 0.4066979>,
    <-0.8189473, -0.3904306, 0.4205820>,
    <-0.8350260, -0.3891431, 0.3889720>,
    <-0.8457763, -0.3614054, 0.3924902>,
    <-0.8130824, -0.4278807, 0.3947342>,
    <-0.8097107, -0.4304641, 0.3988348>,
    <-0.7930260, -0.4583649, 0.4012622>,
    <-0.7977720, -0.4601972, 0.3895874>,
    <-0.8109651, -0.4216297, 0.4056649>,
    <-0.8023249, -0.4619247, 0.3780215>,
    <-0.8179578, -0.4719302, 0.3289786>,
    <-0.8232687, -0.4164685, 0.3857236>,
    <-0.8575902, -0.3551392, 0.3720421>,
    <-0.8502174, -0.3871882, 0.3566731>,
    <-0.8506084, -0.3713223, 0.3722701>,
    <-0.8577749, -0.3459415, 0.3801929>,
    <-0.8390437, -0.4087965, 0.3590140>,
    <-0.8440729, -0.3798046, 0.3785359>,
    <-0.8465924, -0.4326033, 0.3100575>,
    <-0.8558024, -0.3988353, 0.3294430>,
    <-0.8546720, -0.3488922, 0.3844606>,
    <-0.8635339, -0.3648788, 0.3480987>,
    <-0.8574764, 0.4182522, 0.2996652>,
    <-0.8754333, 0.3944167, 0.2793778>,
    <-0.8776972, 0.3836706, 0.2871314>,
    <-0.8672165, 0.3954173, 0.3026232>,
    <-0.8724022, 0.4069914, 0.2706887>,
    <-0.8584245, 0.4347850, 0.2721569>,
    <-0.8176822, 0.4724071, 0.3289792>,
    <-0.8345823, 0.4269658, 0.3480986>,
    <-0.8556248, 0.3992163, 0.3294428>,
    <-0.8904117, 0.3640166, 0.2732380>,
    <-0.8901843, 0.3595676, 0.2797913>,
    <-0.8755725, 0.3704554, 0.3100574>,
    <-0.8843212, 0.3667532, 0.2889085>,
    <-0.8854289, 0.3787627, 0.2693593>,
    <-0.8233007, 0.4286731, 0.3720420>,
    <-0.8431126, 0.4024245, 0.3566731>,
    <-0.8312100, 0.4129225, 0.3722700>,
    <-0.8163737, 0.4347268, 0.3801928>,
    <-0.7974284, 0.4607923, 0.3895875>,
    <-0.7934687, 0.4575983, 0.4012620>,
    <-0.8524832, 0.3799755, 0.3590139>,
    <-0.8335068, 0.4024637, 0.3785358>,
    <-0.8166396, 0.4304532, 0.3844605>,
    <-0.8012008, 0.4638715, 0.3780219>,
    <0.8935427, 0.3977638, -0.2082435>,
    <0.8642395, 0.4122291, -0.2883701>,
    <0.8708113, 0.4321552, -0.2343704>,
    <0.8863230, 0.4275449, -0.1778677>,
    <0.9040761, 0.3885793, -0.1779117>,
    <0.8703564, 0.4122701, -0.2692826>,
    <0.8150168, 0.4238600, -0.3950827>,
    <0.8515756, 0.4528434, -0.2641059>,
    <0.7861744, 0.4082018, -0.4640055>,
    <0.5128421, 0.2973647, -0.8053367>,
    <0.7515268, 0.4222052, -0.5069026>,
    <0.8278145, 0.4707325, -0.3051788>,
    <0.8705978, 0.4585571, -0.1782830>,
    <0.8492797, 0.4888216, -0.1994427>,
    <0.9058169, 0.3752254, -0.1967271>,
    <0.8690360, 0.3422527, -0.3572667>,
    <0.8373742, 0.3655379, -0.4064315>,
    <0.8686305, 0.4039253, -0.2869240>,
    <0.7464646, 0.2941708, -0.5968703>,
    <0.7236520, 0.3254824, -0.6085959>,
    <0.5319737, 0.2177099, -0.8182948>,
    <0.5580490, 0.2598839, -0.7880620>,
    <0.7617084, 0.3821057, -0.5232547>,
    <0.5584000, 0.2933128, -0.7759878>,
    <0.3300477, -0.1723042, -0.9281055>,
    <0.2446928, -0.1199110, -0.9621574>,
    <0.3067437, -0.1328691, -0.9424723>,
    <0.4062983, -0.1827377, -0.8952813>,
    <0.5616356, -0.2622357, -0.7847279>,
    <0.5126498, -0.2695521, -0.8151882>,
    <0.5182687, -0.2979366, -0.8016429>,
    <0.3012894, -0.1591876, -0.9401510>,
    <0.2324053, -0.1142981, -0.9658798>,
    <0.2320137, -0.0944146, -0.9681196>,
    <0.3011385, -0.1106987, -0.9471333>,
    <0.2046219, -0.0932646, -0.9743878>,
    <0.2038746, -0.0742028, -0.9761809>,
    <0.4070934, -0.1539654, -0.9003164>,
    <0.5873440, -0.2408248, -0.7726774>,
    <0.8698182, -0.4527739, -0.1959902>,
    <0.8216285, -0.4460720, -0.3548892>,
    <0.8193745, -0.4070502, -0.4036527>,
    <0.8682256, -0.4060831, -0.2850979>,
    <0.8480657, -0.4911077, -0.1989917>,
    <0.8221435, -0.4817780, -0.3032657>,
    <0.7076778, -0.3839617, -0.5930983>,
    <0.7169932, -0.3463432, -0.6049522>,
    <0.7434232, -0.4407893, -0.5030176>,
    <0.7841889, -0.3388133, -0.5198589>,
    <0.3404689, 0.1404250, -0.9297106>,
    <0.2462445, 0.1089805, -0.9630612>,
    <0.2957363, 0.1479621, -0.9437411>,
    <0.3972844, 0.1919140, -0.8974041>,
    <0.3120261, 0.1269347, -0.9415558>,
    <0.2341243, 0.1032665, -0.9667067>,
    <0.2188386, 0.1156576, -0.9688823>,
    <0.2754558, 0.1579620, -0.9482469>,
    <0.2004920, 0.0955953, -0.9750203>,
    <0.1857810, 0.1072616, -0.9767192>,
    <0.2204518, 0.1365572, -0.9657915>,
    <0.2475515, 0.1518851, -0.9568956>,
    <0.3761523, 0.2110704, -0.9021966>,
    <0.3159233, 0.1928579, -0.9289770>,
    <0.2933075, 0.1232780, -0.9480365>,
    <0.2466098, 0.1023067, -0.9636996>,
    <0.2225955, 0.0978812, -0.9699848>,
    <0.2402865, 0.1088398, -0.9645809>,
    <0.2134480, 0.0926544, -0.9725508>,
    <0.1935963, 0.0873750, -0.9771827>,
    <0.2017592, 0.0734356, -0.9766783>,
    <0.2075833, 0.0967994, -0.9734162>,
    <0.2075833, 0.0967994, -0.9734162>,
    <0.1859236, 0.0866992, -0.9787317>,
    <0.1952701, 0.0911352, -0.9765060>,
    <0.1859236, 0.0866992, -0.9787317>,
    <0.1796378, 0.0837680, -0.9801598>,
    <0.1796378, 0.0837680, -0.9801598>,
    <0.1857810, 0.1072616, -0.9767192>,
    <0.2863982, -0.1472076, -0.9467344>,
    <0.2399897, -0.1247538, -0.9627260>,
    <0.2208114, -0.1089583, -0.9692112>,
    <0.2407317, -0.1155136, -0.9636933>,
    <0.3289245, -0.1794190, -0.9271556>,
    <0.2588862, -0.1404485, -0.9556423>,
    <0.2110172, -0.1053656, -0.9717869>,
    <0.1937633, -0.0932908, -0.9766026>,
    <0.2321254, -0.1246203, -0.9646697>,
    <0.1886389, -0.1089098, -0.9759887>,
    <0.2104498, -0.0981336, -0.9726668>,
    <0.2104498, -0.0981336, -0.9726668>,
    <0.1882334, -0.0877740, -0.9781942>,
    <0.1976939, -0.0921121, -0.9759265>,
    <0.1882334, -0.0877740, -0.9781942>,
    <0.1817971, -0.0847727, -0.9796752>,
    <0.1817971, -0.0847727, -0.9796752>,
    <0.2038746, -0.0742028, -0.9761809>,
    <-0.8715750, -0.3880177, 0.2996653>,
    <-0.8648584, -0.4170946, 0.2793780>,
    <-0.8580816, -0.4257363, 0.2871315>,
    <-0.8603432, -0.4101570, 0.3026233>,
    <-0.8725428, -0.4066898, 0.2706888>,
    <-0.8848492, -0.3781170, 0.2721569>,
    <-0.8511985, -0.4481095, 0.2732380>,
    <-0.8476441, -0.4507951, 0.2797914>,
    <-0.8309013, -0.4804127, 0.2807251>,
    <-0.8337137, -0.4810362, 0.2711560>,
    <-0.8493799, -0.4416849, 0.2889087>,
    <-0.8364285, -0.4816132, 0.2616028>,
    <-0.8459638, -0.4881905, 0.2145116>,
    <-0.8592917, -0.4348140, 0.2693595>,
    <-0.8939932, -0.3702949, 0.2523050>,
    <-0.8837938, -0.4026084, 0.2383590>,
    <-0.8861481, -0.3869159, 0.2550247>,
    <-0.8949080, -0.3609447, 0.2624094>,
    <-0.8720575, -0.4250171, 0.2426443>,
    <-0.8797794, -0.3959478, 0.2630849>,
    <-0.8732870, -0.4463549, 0.1952872>,
    <-0.8852092, -0.4126144, 0.2148350>,
    <-0.8917129, -0.3640324, 0.2689396>,
    <-0.8955742, -0.3784655, 0.2339033>,
    <-0.8795346, 0.4289848, 0.2058908>,
    <-0.8969964, 0.4040505, 0.1792781>,
    <-0.8922152, 0.3899318, 0.2278273>,
    <-0.8748675, 0.3986448, 0.2751169>,
    <-0.8782468, 0.4032173, 0.2570960>,
    <-0.8788011, 0.4427806, 0.1779156>,
    <-0.8457675, 0.4885309, 0.2145109>,
    <-0.8655854, 0.4427768, 0.2339030>,
    <-0.8850825, 0.4128863, 0.2148346>,
    <-0.9106757, 0.3721693, 0.1793312>,
    <-0.8968818, 0.3623917, 0.2535259>,
    <-0.9032659, 0.3820653, 0.1952866>,
    <-0.8610845, 0.3570872, 0.3619699>,
    <-0.8387601, 0.3505439, 0.4166540>,
    <-0.8583101, 0.4468176, 0.2523050>,
    <-0.8765076, 0.4182337, 0.2383590>,
    <-0.8659998, 0.4301242, 0.2550246>,
    <-0.8517354, 0.4535285, 0.2624093>,
    <-0.8334464, 0.4814992, 0.2711560>,
    <-0.8315002, 0.4793753, 0.2807255>,
    <-0.8861297, 0.3948391, 0.2426441>,
    <-0.8688249, 0.4194399, 0.2630847>,
    <-0.8520470, 0.4490963, 0.2689394>,
    <-0.8353037, 0.4835618, 0.2616024>,
    <-0.8939309, -0.3979970, 0.2061211>,
    <-0.8860733, -0.4274082, 0.1794335>,
    <-0.8720845, -0.4327711, 0.2284245>,
    <-0.8674882, -0.4138295, 0.2760606>,
    <-0.8731088, -0.4135288, 0.2582149>,
    <-0.9040242, -0.3885944, 0.1781423>,
    <-0.8704348, -0.4583740, 0.1795454>,
    <-0.8539016, -0.4539954, 0.2544411>,
    <-0.8496049, -0.4889361, 0.1977701>,
    <-0.8317760, -0.4730155, 0.2905254>,
    <-0.8263961, -0.4297634, 0.3638309>,
    <-0.7771737, -0.4384369, 0.4514135>,
    <-0.6020962, -0.3471005, 0.7190281>,
    <-0.8066128, -0.4167503, 0.4191598>,
    <-0.9063003, -0.3754112, 0.1941294>,
    <-0.8722631, -0.4054858, 0.2733832>,
    <-0.8476149, -0.3699968, 0.3803305>,
    <-0.8761087, -0.3451716, 0.3365861>,
    <-0.7873905, -0.3928375, 0.4750735>,
    <-0.7585135, -0.3411987, 0.5551943>,
    <-0.6326413, -0.3272973, 0.7018843>,
    <-0.6295985, -0.2932083, 0.7194683>,
    <-0.7843522, -0.3110551, 0.5366902>,
    <-0.6254849, -0.2600088, 0.7356386>,
    <-0.4386681, 0.2221501, 0.8707581>,
    <-0.4995984, 0.2253676, 0.8364275>,
    <-0.3928130, 0.1719908, 0.9033920>,
    <-0.3333712, 0.1590884, 0.9292763>,
    <-0.3119886, 0.1532292, 0.9376481>,
    <-0.3923700, 0.2071647, 0.8961744>,
    <-0.6056652, 0.3502051, 0.7145110>,
    <-0.6049172, 0.3138766, 0.7318174>,
    <-0.6328618, 0.2954889, 0.7156621>,
    <-0.4961886, 0.1952725, 0.8459701>,
    <-0.3754495, 0.1452634, 0.9153886>,
    <-0.6607751, 0.2757145, 0.6981102>,
    <-0.3027489, 0.1262701, 0.9446687>,
    <-0.2852667, 0.1284529, 0.9498014>,
    <-0.8702573, 0.4530177, 0.1934610>,
    <-0.8716893, 0.4078326, 0.2717174>,
    <-0.8292170, 0.4119518, 0.3777499>,
    <-0.8282999, 0.4495529, 0.3343972>,
    <-0.8260320, 0.4840260, 0.2887733>,
    <-0.8483199, 0.4913274, 0.1973592>,
    <-0.8085896, 0.3514371, 0.4718843>,
    <-0.7510663, 0.3627656, 0.5516343>,
    <-0.7445338, 0.4019083, 0.5330471>,
    <-0.7698885, 0.4546525, 0.4478424>,
    <-0.4471266, -0.1909947, 0.8738414>,
    <-0.4892438, -0.2356674, 0.8397032>,
    <-0.3793643, -0.1879393, 0.9059589>,
    <-0.3305839, -0.1505177, 0.9316967>,
    <-0.3124412, -0.1383135, 0.9398137>,
    <-0.4059050, -0.1653955, 0.8988245>,
    <-0.4644418, -0.2524717, 0.8488532>,
    <-0.3482839, -0.1920085, 0.9175135>,
    <-0.4000088, -0.2393345, 0.8847101>,
    <-0.3175794, -0.1903075, 0.9289383>,
    <-0.2858805, -0.1481590, 0.9467424>,
    <-0.2853525, -0.1686360, 0.9434701>,
    <-0.2757936, -0.1338651, 0.9518498>,
    <-0.3691832, -0.1524312, 0.9167707>,
    <-0.3145095, -0.1403995, 0.9388140>,
    <-0.3005763, -0.1304508, 0.9447944>,
    <-0.3210194, -0.1309479, 0.9379761>,
    <-0.2845816, -0.1340215, 0.9492374>,
    <-0.2861920, -0.1274812, 0.9496540>,
    <-0.2962108, -0.1227111, 0.9472070>,
    <-0.3587841, 0.1874556, 0.9144038>,
    <-0.3144146, 0.1534527, 0.9368008>,
    <-0.2990386, 0.1496540, 0.9424328>,
    <-0.3130235, 0.1651721, 0.9352724>,
    <-0.3284954, 0.1828428, 0.9266387>,
    <-0.4119733, 0.2294900, 0.8818233>,
    <-0.2892692, 0.1344969, 0.9477520>,
    <-0.2885330, 0.1410600, 0.9470221>,
    <-0.2945174, 0.1533866, 0.9432561>,
    <-0.2941701, 0.1666593, 0.9411103>,
    <-0.4316268, 0.3055244, 0.8487362>,
    <-0.3834584, 0.2699774, 0.8832167>,
    <-0.4029082, 0.2722920, 0.8737975>,
    <-0.4258558, 0.2905078, 0.8568851>,
    <-0.4630704, 0.3150942, 0.8284211>,
    <-0.4850620, 0.3349006, 0.8078097>,
    <-0.4987749, 0.3450853, 0.7950722>,
    <-0.4272873, 0.3090529, 0.8496540>,
    <-0.4272873, 0.3090529, 0.8496540>,
    <-0.3576697, 0.2659645, 0.8951733>,
    <-0.3237825, 0.2225025, 0.9195964>,
    <-0.3879288, 0.2500338, 0.8871270>,
    <-0.3576697, 0.2659645, 0.8951733>,
    <-0.2782146, 0.2100623, 0.9372676>,
    <-0.2782146, 0.2100623, 0.9372676>,
    <-0.3123317, 0.1868469, 0.9314167>,
    <-0.4328434, 0.2772291, 0.8577824>,
    <-0.4516284, 0.2981242, 0.8409243>,
    <0.3171436, 0.2252572, -0.9212378>,
    <0.2901313, 0.2128957, -0.9330055>,
    <0.2904685, 0.2228315, -0.9305773>,
    <0.3034312, 0.2249536, -0.9259187>,
    <0.3084151, 0.2159179, -0.9264230>,
    <0.3290493, 0.2303807, -0.9157790>,
    <0.3290493, 0.2303807, -0.9157790>,
    <0.3321408, 0.2325556, -0.9141118>,
    <0.3205561, 0.2248535, -0.9201547>,
    <0.2950994, 0.2095633, -0.9322015>,
    <0.2696372, 0.2150189, -0.9386494>,
    <0.2756012, 0.2300702, -0.9333336>,
    <0.2714361, 0.1984120, -0.9417830>,
    <0.3286360, 0.2789019, -0.9023370>,
    <0.2682893, 0.2445150, -0.9317904>,
    <0.2682750, 0.2469707, -0.9311466>,
    <0.2744508, 0.2222197, -0.9355721>,
    <0.2557052, 0.2359458, -0.9375204>,
    <0.2417679, 0.2231612, -0.9443238>,
    <0.2587552, 0.1811253, -0.9488095>,
    <0.2587552, 0.1811253, -0.9488095>,
    <0.3084151, 0.2159179, -0.9264230>,
    <0.3247899, 0.2276862, -0.9179709>,
    <0.3268673, 0.2288718, -0.9169381>,
    <0.3120884, 0.2185235, -0.9245801>,
    <0.3034940, 0.2135465, -0.9285953>,
    <0.3321408, 0.2325556, -0.9141118>,
    <0.3321482, 0.2325669, -0.9141062>,
    <0.3321482, 0.2325669, -0.9141062>,
    <0.3321533, 0.2325730, -0.9141028>,
    <0.3249604, 0.2274689, -0.9179644>,
    <0.3087409, 0.2166149, -0.9261517>,
    <0.3321533, 0.2325730, -0.9141028>,
    <0.3321589, 0.2325774, -0.9140997>,
    <0.3321589, 0.2325774, -0.9140997>,
    <0.3321713, 0.2325852, -0.9140932>,
    <0.3284096, 0.2306175, -0.9159491>,
    <0.3251549, 0.2306442, -0.9171028>,
    <0.2887003, 0.2044771, -0.9353295>,
    <0.3197556, 0.2330496, -0.9183922>,
    <0.3360865, 0.2357909, -0.9118380>,
    <0.3486228, 0.2418426, -0.9055243>,
    <0.3587326, 0.2523748, -0.8986756>,
    <0.3478622, 0.2476450, -0.9042477>,
    <0.3321713, 0.2325852, -0.9140932>,
    <0.3709079, 0.2534853, -0.8934050>,
    <0.3801952, 0.2682592, -0.8851489>,
    <0.4297537, 0.2909611, -0.8547826>,
    <0.4302467, 0.3061156, -0.8492238>,
    <0.3700761, 0.2694024, -0.8890816>,
    <0.4162235, 0.3116237, -0.8541948>,
    <0.3358895, -0.2348247, -0.9121599>,
    <0.3453814, -0.2448155, -0.9059675>,
    <0.3583953, -0.2498779, -0.8995075>,
    <0.3500619, -0.2409794, -0.9051992>,
    <0.3321511, -0.2325657, -0.9141055>,
    <0.3284623, -0.2308614, -0.9158687>,
    <0.3268444, -0.2335257, -0.9157721>,
    <0.3628727, -0.2616450, -0.8943519>,
    <0.3801042, -0.2643300, -0.8863692>,
    <0.3302003, -0.2442890, -0.9117514>,
    <0.3679931, -0.3032820, -0.8789773>,
    <0.4179845, -0.3044947, -0.8559042>,
    <0.4337406, -0.2992944, -0.8498776>,
    <0.3774335, -0.2538707, -0.8905581>,
    <0.4345876, -0.2838847, -0.8547182>,
    <0.4689866, -0.3341117, -0.8175701>,
    <0.4815292, -0.3282260, -0.8126484>,
    <0.4850097, -0.3216189, -0.8132200>,
    <0.4760637, -0.3224326, -0.8181690>,
    <0.4694618, -0.3467866, -0.8120004>,
    <0.4959209, -0.3455469, -0.7966554>,
    <0.5073127, -0.3233425, -0.7988012>,
    <0.4935418, -0.3101400, -0.8125452>,
    <0.5227762, -0.3415151, -0.7810714>,
    <0.4716756, -0.3003860, -0.8290298>,
    <0.3206600, -0.2263929, -0.9197410>,
    <0.3034871, -0.2184878, -0.9274474>,
    <0.2966982, -0.2176726, -0.9298327>,
    <0.3076437, -0.2220962, -0.9252181>,
    <0.3321511, -0.2325657, -0.9141055>,
    <0.3283470, -0.2298998, -0.9161519>,
    <0.3283470, -0.2298998, -0.9161519>,
    <0.3035004, -0.2125002, -0.9288332>,
    <0.2654068, -0.2003250, -0.9430955>,
    <0.2803602, -0.2168130, -0.9350884>,
    <0.3035004, -0.2125002, -0.9288332>,
    <0.2463130, -0.1724557, -0.9537237>,
    <0.2463130, -0.1724557, -0.9537237>,
    <0.1972723, -0.1685301, -0.9657542>,
    <0.2250768, -0.1922420, -0.9551877>,
    <0.2629833, -0.2242808, -0.9383698>,
    <0.2997217, -0.2279930, -0.9263833>,
    <0.2874747, -0.2442363, -0.9261247>,
    <-0.5514256, 0.3534021, 0.7556698>,
    <-0.5920976, 0.3812873, 0.7099580>,
    <-0.5424960, 0.3552019, 0.7612685>,
    <-0.5059334, 0.3326370, 0.7958543>,
    <-0.4544463, 0.3056509, 0.8366935>,
    <-0.3946614, 0.2716921, 0.8777390>,
    <-0.2667138, 0.2309420, 0.9356974>,
    <-0.6671837, 0.4067147, 0.6240586>,
    <-0.6671837, 0.4067147, 0.6240586>,
    <-0.6619314, 0.4156821, 0.6237429>,
    <-0.5537943, 0.3672898, 0.7472684>,
    <-0.5123476, 0.3408660, 0.7882324>,
    <-0.6619314, 0.4156821, 0.6237429>,
    <-0.5896005, 0.3869776, 0.7089567>,
    <-0.5896005, 0.3869776, 0.7089567>,
    <-0.4987749, 0.3450853, 0.7950722>,
    <-0.4773620, 0.3168773, 0.8195817>,
    <-0.4867104, 0.3204041, 0.8126833>,
    <0.4723934, 0.3264802, -0.8186911>,
    <0.4722464, 0.3401780, -0.8131804>,
    <0.4673471, 0.3454954, -0.8137687>,
    <0.4647674, 0.3367776, -0.8188847>,
    <0.4787116, 0.3186471, -0.8181071>,
    <0.4917926, 0.3465242, -0.7987872>,
    <0.4771671, 0.3660881, -0.7989312>,
    <0.4598608, 0.3574153, -0.8128852>,
    <0.4992557, 0.3741943, -0.7814873>,
    <0.5297853, 0.4441469, -0.7225379>,
    <0.4831006, 0.4041055, -0.7767319>,
    <0.4530920, 0.3783377, -0.8071978>,
    <0.4429990, 0.3399483, -0.8295704>,
    <0.4171000, 0.3478086, -0.8396766>,
    <0.4923325, 0.3141698, -0.8117303>,
    <0.5138219, 0.3207546, -0.7956781>,
    <0.5181963, 0.3439833, -0.7830377>,
    <0.5139690, 0.3530569, -0.7817843>,
    <0.5325413, 0.3357037, -0.7769831>,
    <0.5264470, 0.3580378, -0.7711436>,
    <0.5675285, 0.3673023, -0.7368856>,
    <0.5659705, 0.3960145, -0.7230836>,
    <0.5245624, 0.3803715, -0.7616770>,
    <0.5637126, 0.4255487, -0.7079099>,
    <0.5874798, -0.4266569, -0.6876274>,
    <0.6029178, -0.4144044, -0.6817324>,
    <0.6162578, -0.4097459, -0.6725582>,
    <0.6114615, -0.4164966, -0.6727893>,
    <0.5657056, -0.3963934, -0.7230833>,
    <0.5392578, -0.4076777, -0.7368853>,
    <0.5293958, -0.4446114, -0.7225377>,
    <0.6001987, -0.4499486, -0.6612925>,
    <0.6205831, -0.4348064, -0.6525488>,
    <0.6299766, -0.4018647, -0.6645557>,
    <0.6341981, -0.3965946, -0.6637058>,
    <0.6399542, -0.4184241, -0.6444997>,
    <0.6305036, -0.3980062, -0.6663754>,
    <0.5926863, -0.3841704, -0.7079096>,
    <0.4727422, -0.3621848, -0.8033287>,
    <0.4821086, -0.3769089, -0.7908925>,
    <0.5034426, -0.3714878, -0.7800913>,
    <0.5114431, -0.3650783, -0.7779099>,
    <0.4299508, -0.3612933, -0.8274113>,
    <0.4581516, -0.3855069, -0.8009254>,
    <0.4987303, -0.3864755, -0.7758252>,
    <0.5172074, -0.3727512, -0.7704240>,
    <0.4835670, -0.4068221, -0.7750218>,
    <0.5376817, -0.3634059, -0.7608118>,
    <-0.4096565, -0.2763768, 0.8693661>,
    <-0.3655806, -0.2492679, 0.8967811>,
    <-0.3737261, -0.2658023, 0.8886382>,
    <-0.3962987, -0.2781835, 0.8749636>,
    <-0.4281726, -0.2996952, 0.8525556>,
    <-0.4468611, -0.3074540, 0.8401114>,
    <-0.4581800, -0.3144652, 0.8313740>,
    <-0.4115991, -0.2715347, 0.8699742>,
    <-0.4115991, -0.2715347, 0.8699742>,
    <-0.3542598, -0.2278823, 0.9069562>,
    <-0.3048390, -0.2138599, 0.9280825>,
    <-0.3504261, -0.2619811, 0.8992038>,
    <-0.3542598, -0.2278823, 0.9069562>,
    <-0.2792318, -0.1771053, 0.9437496>,
    <-0.2792318, -0.1771053, 0.9437496>,
    <-0.2737486, -0.2225605, 0.9356968>,
    <-0.2623222, -0.2056273, 0.9428173>,
    <-0.3266026, -0.2681775, 0.9063176>,
    <-0.3908322, -0.2931845, 0.8725211>,
    <-0.3885671, -0.3246958, 0.8623156>,
    <-0.4825130, -0.3919430, 0.7833019>,
    <-0.4179795, -0.3029822, 0.8564432>,
    <-0.5078655, -0.3757572, 0.7751640>,
    <-0.5228331, -0.3832820, 0.7614069>,
    <-0.4938917, -0.3580449, 0.7923855>,
    <-0.4778036, -0.3471481, 0.8069647>,
    <-0.4592699, -0.3309210, 0.8243558>,
    <-0.4218405, -0.2988837, 0.8559901>,
    <-0.3555234, -0.2149440, 0.9096165>,
    <-0.5671762, -0.4331998, 0.7004635>,
    <-0.5671762, -0.4331998, 0.7004635>,
    <-0.5591465, -0.4167965, 0.7166840>,
    <-0.4924798, -0.3511414, 0.7963438>,
    <-0.4676411, -0.3338157, 0.8184613>,
    <-0.5591465, -0.4167965, 0.7166840>,
    <-0.5133093, -0.3687215, 0.7749568>,
    <-0.5133093, -0.3687215, 0.7749568>,
    <-0.4581800, -0.3144652, 0.8313740>,
    <-0.4485729, -0.3230691, 0.8333119>,
    <-0.4740343, -0.3481305, 0.8087624>,
    <-0.3813686, -0.2508601, 0.8897343>,
    <-0.4467238, -0.3129200, 0.8381640>,
    <-0.4412935, -0.2991616, 0.8460274>,
    <-0.4138126, -0.2673464, 0.8702213>,
    <-0.3555234, -0.2149440, 0.9096165>,
    <-0.4948276, -0.3591633, 0.7912947>,
    <-0.4737929, -0.3261069, 0.8180309>,
    <-0.5459010, -0.4076551, 0.7319900>,
    <-0.5350344, -0.3748648, 0.7571093>,
    <-0.4546321, -0.2941861, 0.8406927>,
    <-0.5223701, -0.3406954, 0.7817008>,
    <-0.5677137, 0.4124844, 0.7124309>,
    <-0.5828427, 0.3988753, 0.7079497>,
    <-0.6019480, 0.4016991, 0.6901424>,
    <-0.5977770, 0.4108992, 0.6883491>,
    <-0.6173503, 0.4322488, 0.6572971>,
    <-0.5882878, 0.4406914, 0.6780181>,
    <-0.4697775, 0.4071235, 0.7833004>,
    <-0.4848251, 0.3677451, 0.7935415>,
    <-0.5183240, 0.3641698, 0.7737704>,
    <-0.6018401, 0.3832850, 0.7006291>,
    <-0.6208360, 0.3902630, 0.6798952>,
    <-0.5575404, 0.3643779, 0.7459072>,
    <-0.6283702, 0.4013638, 0.6663768>,
    <-0.6406790, 0.4189315, 0.6434492>,
    <-0.3190390, 0.2448296, 0.9155723>,
    <-0.4148620, 0.2921941, 0.8616915>,
    <-0.3989309, 0.2930012, 0.8689099>,
    <-0.3562498, 0.2782283, 0.8920062>,
    <-0.3208172, 0.2750726, 0.9063175>,
    <-0.2480536, 0.2226297, 0.9428178>,
    <-0.2667138, 0.2309420, 0.9356974>,
    <-0.4858628, 0.3273151, 0.8104333>,
    <-0.4432210, 0.3185115, 0.8379174>,
    <-0.4103172, 0.3166051, 0.8552198>,
    <-0.3872376, 0.3262817, 0.8623151>,
    <0.6018561, 0.4061249, -0.6876277>,
    <0.5956227, 0.4248225, -0.6817326>,
    <0.5958077, 0.4389513, -0.6725585>,
    <0.6005107, 0.4321353, -0.6727897>,
    <0.6280933, 0.4101107, -0.6612927>,
    <0.6208363, 0.4344446, -0.6525490>,
    <0.5930938, 0.4545382, -0.6645561>,
    <0.5895854, 0.4603077, -0.6637062>,
    <0.6120672, 0.4582505, -0.6444999>,
    <0.6221385, 0.5216191, -0.5838298>,
    <0.5910980, 0.4947989, -0.6370064>,
    <0.5802344, 0.4864112, -0.6532474>,
    <0.5896483, 0.4563532, -0.6663757>,
    <0.5686038, 0.4773495, -0.6699457>,
    <0.6480702, 0.4127175, -0.6400541>,
    <0.6500090, 0.4056860, -0.6425786>,
    <0.6445868, 0.4279147, -0.6335589>,
    <0.6459440, 0.4434693, -0.6213626>,
    <0.6493897, 0.4091314, -0.6410183>,
    <0.6387111, 0.4344211, -0.6350799>,
    <0.6703502, 0.4337651, -0.6020619>,
    <0.6648313, 0.4652224, -0.5844378>,
    <0.6360765, 0.4614945, -0.6184089>,
    <0.6581856, 0.4970237, -0.5654725>,
    <0.6756885, -0.4909015, -0.5499643>,
    <0.6886199, -0.4734525, -0.5492224>,
    <0.7032883, -0.4675688, -0.5355044>,
    <0.7006214, -0.4771878, -0.5304917>,
    <0.6645518, -0.4656216, -0.5844377>,
    <0.6368791, -0.4815667, -0.6020619>,
    <0.6217278, -0.5221085, -0.5838297>,
    <0.6829532, -0.5120836, -0.5209082>,
    <0.7013566, -0.4913624, -0.5163932>,
    <0.7132431, -0.4549335, -0.5332164>,
    <0.7206453, -0.4504324, -0.5270493>,
    <0.7188902, -0.4698745, -0.5122645>,
    <0.7204670, -0.4545458, -0.5237513>,
    <0.6921624, -0.4485000, -0.5654723>,
    <0.6094807, -0.4678290, -0.6400541>,
    <0.6035362, -0.4720558, -0.6425787>,
    <0.6225700, -0.4593579, -0.6335589>,
    <0.6376507, -0.4553133, -0.6213625>,
    <0.5688347, -0.4770746, -0.6699455>,
    <0.5797783, -0.4869549, -0.6532473>,
    <0.6065621, -0.4702954, -0.6410184>,
    <0.6266744, -0.4516112, -0.6350800>,
    <0.5899250, -0.4961970, -0.6370063>,
    <0.6512140, -0.4398759, -0.6184088>,
    <-0.5873349, -0.3980874, 0.7046730>,
    <-0.5819459, -0.4176359, 0.6977959>,
    <-0.5873753, -0.4316643, 0.6845846>,
    <-0.5928108, -0.4234898, 0.6850050>,
    <-0.6170000, -0.4325539, 0.6574254>,
    <-0.6139547, -0.4027033, 0.6788886>,
    <-0.5715971, -0.4383170, 0.6936534>,
    <-0.5814956, -0.4518312, 0.6765438>,
    <-0.5520792, -0.4608133, 0.6948810>,
    <-0.5733102, -0.4793662, 0.6644723>,
    <-0.5927507, -0.4538733, 0.6653162>,
    <-0.5903643, -0.4939070, 0.6383775>,
    <-0.6221542, -0.5215877, 0.5838411>,
    <-0.6126503, -0.4587417, 0.6435959>,
    <-0.6328654, -0.4030435, 0.6610880>,
    <-0.6395184, -0.4390695, 0.6310580>,
    <-0.6408034, -0.4253685, 0.6390874>,
    <-0.6428160, -0.4010935, 0.6526191>,
    <-0.6352750, -0.4607941, 0.6197535>,
    <-0.6394136, -0.4348660, 0.6340677>,
    <-0.6571421, -0.4961519, 0.5674483>,
    <-0.6648395, -0.4651963, 0.5844491>,
    <-0.6495880, -0.4092960, 0.6407123>,
    <-0.6714657, -0.4344972, 0.6002882>,
    <-0.6757139, 0.4908540, 0.5499756>,
    <-0.6991792, 0.4762400, 0.5332391>,
    <-0.7032661, 0.4675895, 0.5355156>,
    <-0.6899923, 0.4743451, 0.5467242>,
    <-0.7013376, 0.4913777, 0.5164044>,
    <-0.6819644, 0.5113096, 0.5229598>,
    <-0.6216994, 0.5221294, 0.5838414>,
    <-0.6379483, 0.4823644, 0.6002888>,
    <-0.6645297, 0.4656381, 0.5844497>,
    <-0.7187832, 0.4536191, 0.5268591>,
    <-0.7205843, 0.4505164, 0.5270609>,
    <-0.6909858, 0.4478175, 0.5674488>,
    <-0.7147258, 0.4559153, 0.5303850>,
    <-0.7198157, 0.4705693, 0.5103232>,
    <-0.5989030, 0.4598497, 0.6556321>,
    <-0.6328286, 0.4519687, 0.6286910>,
    <-0.6201728, 0.4576252, 0.6371538>,
    <-0.5987969, 0.4684190, 0.6496352>,
    <-0.5716379, 0.4813593, 0.6644722>,
    <-0.5496804, 0.4636727, 0.6948807>,
    <-0.6506609, 0.4396302, 0.6191653>,
    <-0.6276446, 0.4523441, 0.6335985>,
    <-0.6072268, 0.4707650, 0.6400437>,
    <-0.5889191, 0.4956292, 0.6383776>,
    <0.6923956, 0.4670413, -0.5499643>,
    <0.6804217, 0.4851607, -0.5492225>,
    <0.6799097, 0.5009568, -0.5355046>,
    <0.6880364, 0.4951608, -0.5304919>,
    <0.7147850, 0.4666232, -0.5209080>,
    <0.7016077, 0.4910039, -0.5163931>,
    <0.6714411, 0.5146328, -0.5332165>,
    <0.6697430, 0.5231280, -0.5270496>,
    <0.6874125, 0.5148293, -0.5122644>,
    <0.6836340, 0.5732478, -0.4516984>,
    <0.6622329, 0.5542852, -0.5041979>,
    <0.6559035, 0.5499110, -0.5170962>,
    <0.6735474, 0.5215535, -0.5237517>,
    <0.6492557, 0.5452651, -0.5302387>,
    <0.7309429, 0.4655430, -0.4989912>,
    <0.7312805, 0.4563072, -0.5069641>,
    <0.7222464, 0.4795190, -0.4984191>,
    <0.7221709, 0.4960017, -0.4821322>,
    <0.7275081, 0.4582335, -0.5106407>,
    <0.7139405, 0.4856368, -0.5044263>,
    <0.7401622, 0.4789156, -0.4720168>,
    <0.7307181, 0.5113765, -0.4522667>,
    <0.7081294, 0.5139861, -0.4841189>,
    <0.7198856, 0.5437444, -0.4314009>,
    <0.7341206, -0.5334408, -0.4201284>,
    <0.7465270, -0.5133285, -0.4233099>,
    <0.7608096, -0.5057513, -0.4066747>,
    <0.7582214, -0.5163629, -0.3980826>,
    <0.7304568, -0.5117492, -0.4522671>,
    <0.7031836, -0.5317260, -0.4720172>,
    <0.6832506, -0.5737046, -0.4516986>,
    <0.7366129, -0.5523464, -0.3902754>,
    <0.7545410, -0.5285702, -0.3889492>,
    <0.7694826, -0.4907410, -0.4087418>,
    <0.7777076, -0.4859211, -0.3988127>,
    <0.7716116, -0.5041992, -0.3878128>,
    <0.7783626, -0.4908818, -0.3913908>,
    <0.7571678, -0.4904996, -0.4314013>,
    <0.6874643, -0.5276364, -0.4989916>,
    <0.6789009, -0.5311125, -0.5069646>,
    <0.6976231, -0.5146844, -0.4984195>,
    <0.7130860, -0.5089761, -0.4821325>,
    <0.6497234, -0.5447077, -0.5302387>,
    <0.6554530, -0.5504478, -0.5170962>,
    <0.6794208, -0.5269088, -0.5106412>,
    <0.7005312, -0.5047869, -0.5044267>,
    <0.6608598, -0.5559214, -0.5041981>,
    <0.7251833, -0.4896303, -0.4841192>,
    <-0.6923598, -0.4670816, 0.5499752>,
    <-0.6866528, -0.4941301, 0.5332385>,
    <-0.6799217, -0.5009292, 0.5355151>,
    <-0.6817300, -0.4861452, 0.5467240>,
    <-0.7016156, -0.4909807, 0.5164044>,
    <-0.7137195, -0.4659588, 0.5229597>,
    <-0.6721011, -0.5202887, 0.5268584>,
    <-0.6698015, -0.5230423, 0.5270605>,
    <-0.6486150, -0.5446102, 0.5316939>,
    <-0.6559225, -0.5498774, 0.5171079>,
    <-0.6728709, -0.5156905, 0.5303849>,
    <-0.6628531, -0.5548226, 0.5027899>,
    <-0.6836466, -0.5732160, 0.4517198>,
    <-0.6883819, -0.5154613, 0.5103234>,
    <-0.7294178, -0.4645351, 0.5021523>,
    <-0.7209301, -0.4950339, 0.4849756>,
    <-0.7222553, -0.4794905, 0.4984336>,
    <-0.7312557, -0.4563322, 0.5069774>,
    <-0.7081798, -0.5139006, 0.4841359>,
    <-0.7152048, -0.4864646, 0.5018310>,
    <-0.7190895, -0.5430644, 0.4335796>,
    <-0.7307233, -0.5113499, 0.4522884>,
    <-0.7289307, -0.4591782, 0.5077553>,
    <-0.7410516, -0.4795004, 0.4700234>,
    <-0.7341414, 0.5333930, 0.4201527>,
    <-0.7571372, 0.5156561, 0.4010512>,
    <-0.7607861, 0.5057679, 0.4066981>,
    <-0.7475963, 0.5140138, 0.4205824>,
    <-0.7545206, 0.5285821, 0.3889726>,
    <-0.7358742, 0.5517610, 0.3924907>,
    <-0.6832217, 0.5737227, 0.4517194>,
    <-0.7040378, 0.5323621, 0.4700227>,
    <-0.7304342, 0.5117635, 0.4522875>,
    <-0.7770968, 0.4902097, 0.3947340>,
    <-0.7776482, 0.4859980, 0.3988349>,
    <-0.7562571, 0.4899843, 0.4335787>,
    <-0.7706244, 0.4915015, 0.4056653>,
    <-0.7723064, 0.5047373, 0.3857242>,
    <-0.6859958, 0.5265482, 0.5021521>,
    <-0.7117525, 0.5081412, 0.4849752>,
    <-0.6975998, 0.5147027, 0.4984331>,
    <-0.6789164, 0.5310809, 0.5069769>,
    <-0.6554232, 0.5504723, 0.5171079>,
    <-0.6489670, 0.5441904, 0.5316940>,
    <-0.7251206, 0.4897071, 0.4841354>,
    <-0.7017420, 0.5056921, 0.5018303>,
    <-0.6807957, 0.5279227, 0.5077547>,
    <-0.6614969, 0.5564390, 0.5027897>,
    <0.7523545, 0.5074003, -0.4201281>,
    <0.7376983, 0.5259373, -0.4233097>,
    <0.7354631, 0.5419502, -0.4066743>,
    <0.7445495, 0.5358887, -0.3980822>,
    <0.7709723, 0.5032762, -0.3902753>,
    <0.7547617, 0.5282550, -0.3889491>,
    <0.7243243, 0.5552338, -0.4087416>,
    <0.7226083, 0.5646114, -0.3988124>,
    <0.7376990, 0.5526314, -0.3878128>,
    <0.7235636, 0.6068181, -0.3289795>,
    <0.7094596, 0.5938194, -0.3795334>,
    <0.7057250, 0.5917688, -0.3895664>,
    <0.7274938, 0.5635303, -0.3913903>,
    <0.7018603, 0.5896174, -0.3996791>,
    <0.7840086, 0.4994065, -0.3686783>,
    <0.7846964, 0.4896109, -0.3801746>,
    <0.7731981, 0.5134123, -0.3722534>,
    <0.7709564, 0.5296638, -0.3536701>,
    <0.7800214, 0.4912722, -0.3875799>,
    <0.7643335, 0.5199785, -0.3813353>,
    <0.7863908, 0.5088447, -0.3502379>,
    <0.7735317, 0.5414016, -0.3294436>,
    <0.7552597, 0.5483619, -0.3590013>,
    <0.7591563, 0.5735238, -0.3078185>,
    <0.7717874, -0.5608375, -0.2996758>,
    <0.7845917, -0.5395130, -0.3055185>,
    <0.7977481, -0.5302322, -0.2871441>,
    <0.7943772, -0.5409156, -0.2763607>,
    <0.7733145, -0.5417118, -0.3294435>,
    <0.7471192, -0.5649306, -0.3502376>,
    <0.7232447, -0.6071982, -0.3289795>,
    <0.7703704, -0.5776437, -0.2699209>,
    <0.7884811, -0.5522837, -0.2707033>,
    <0.8063809, -0.5141942, -0.2921544>,
    <0.8142656, -0.5086071, -0.2798042>,
    <0.8057243, -0.5263718, -0.2715529>,
    <0.8145353, -0.5135328, -0.2698449>,
    <0.7985829, -0.5172168, -0.3078184>,
    <0.7374354, -0.5659200, -0.3686782>,
    <0.7284658, -0.5699167, -0.3801743>,
    <0.7468991, -0.5509712, -0.3722532>,
    <0.7614038, -0.5433064, -0.3536700>,
    <0.7025365, -0.5888115, -0.3996793>,
    <0.7053263, -0.5922438, -0.3895665>,
    <0.7284281, -0.5649554, -0.3875796>,
    <0.7500375, -0.5403955, -0.3813351>,
    <0.7079943, -0.5955656, -0.3795334>,
    <0.7736057, -0.5221612, -0.3590012>,
    <0.7909817, 0.5334251, -0.2996759>,
    <0.7753226, 0.5527507, -0.3055185>,
    <0.7711012, 0.5682879, -0.2871441>,
    <0.7799874, 0.5614663, -0.2763608>,
    <0.8062897, 0.5263455, -0.2699211>,
    <0.7886534, 0.5520376, -0.2707034>,
    <0.7589830, 0.5818854, -0.2921543>,
    <0.7564296, 0.5912055, -0.2798041>,
    <0.7702017, 0.5771034, -0.2715528>,
    <0.7483259, 0.6276891, -0.2145106>,
    <0.7397732, 0.6192474, -0.2631888>,
    <0.7374966, 0.6185195, -0.2711685>,
    <0.7611505, 0.5897742, -0.2698449>,
    <0.7351634, 0.6177551, -0.2791297>,
    <0.8168393, 0.5203993, -0.2489139>,
    <0.8186529, 0.5108252, -0.2624214>,
    <0.8054854, 0.5349300, -0.2550354>,
    <0.8010164, 0.5504441, -0.2353381>,
    <0.8142022, 0.5128184, -0.2721985>,
    <0.7969863, 0.5422683, -0.2660035>,
    <0.8158106, 0.5279288, -0.2361021>,
    <0.8001027, 0.5600731, -0.2148343>,
    <0.7849547, 0.5700582, -0.2426517>,
    <0.7828395, 0.5915273, -0.1930229>,
    <0.7913021, -0.5749905, -0.2079108>,
    <0.7894565, -0.5425738, -0.2870053>,
    <0.8098375, -0.5381831, -0.2334999>,
    <0.8134600, -0.5538287, -0.1776419>,
    <0.7999478, -0.5602942, -0.2148344>,
    <0.7751145, -0.5860489, -0.2361022>,
    <0.7480985, -0.6279600, -0.2145106>,
    <0.7885851, -0.5887253, -0.1775839>,
    <0.7925340, -0.5479484, -0.2676610>,
    <0.7755734, -0.4945274, -0.3923374>,
    <0.8182741, -0.5112557, -0.2627645>,
    <0.7481349, -0.4778820, -0.4603509>,
    <0.8324691, -0.5247115, -0.1779691>,
    <0.8236007, -0.5333141, -0.1930230>,
    <0.7683910, -0.5895907, -0.2489136>,
    <0.7600146, -0.5945695, -0.2624212>,
    <0.7781621, -0.5739518, -0.2550354>,
    <0.7912120, -0.5644462, -0.2353380>,
    <0.7360298, -0.6167226, -0.2791297>,
    <0.7371878, -0.6188876, -0.2711685>,
    <0.7603653, -0.5897055, -0.2721985>,
    <0.7821510, -0.5634554, -0.2660035>,
    <0.7382999, -0.6210031, -0.2631888>,
    <0.8041498, -0.5426447, -0.2426518>,
    <-0.7523164, -0.5074360, 0.4201532>,
    <-0.7435141, -0.5351112, 0.4010521>,
    <-0.7354703, -0.5419221, 0.4066988>,
    <-0.7387079, -0.5267076, 0.4205827>,
    <-0.7547659, -0.5282318, 0.3889724>,
    <-0.7701695, -0.5027823, 0.3924907>,
    <-0.7264289, -0.5625702, 0.3947351>,
    <-0.7226598, -0.5645289, 0.3988357>,
    <-0.7013837, -0.5891085, 0.4012630>,
    <-0.7057394, -0.5917371, 0.3895883>,
    <-0.7254293, -0.5560466, 0.4056656>,
    <-0.7099233, -0.5942291, 0.3780221>,
    <-0.7235814, -0.6067975, 0.3289783>,
    <-0.7384423, -0.5531004, 0.3857238>,
    <-0.7828921, -0.4986628, 0.3720422>,
    <-0.7700661, -0.5289447, 0.3566732>,
    <-0.7732064, -0.5133878, 0.3722699>,
    <-0.7846713, -0.4896371, 0.3801927>,
    <-0.7553100, -0.5482845, 0.3590138>,
    <-0.7652973, -0.5206064, 0.3785354>,
    <-0.7586102, -0.5730406, 0.3100566>,
    <-0.7735440, -0.5413849, 0.3294420>,
    <-0.7811033, -0.4920042, 0.3844600>,
    <-0.7870545, -0.5092868, 0.3480978>,
    <-0.7718208, 0.5607973, 0.2996650>,
    <-0.7936436, 0.5404421, 0.2793780>,
    <-0.7977393, 0.5302524, 0.2871313>,
    <-0.7853781, 0.5400007, 0.3026227>,
    <-0.7884754, 0.5522995, 0.2706878>,
    <-0.7698837, 0.5772436, 0.2721561>,
    <-0.7232273, 0.6072192, 0.3289789>,
    <-0.7477612, 0.5654029, 0.3480989>,
    <-0.7733025, 0.5417290, 0.3294434>,
    <-0.8136734, 0.5131048, 0.2732383>,
    <-0.8142220, 0.5086839, 0.2797913>,
    <-0.7979414, 0.5168689, 0.3100580>,
    <-0.8072004, 0.5147423, 0.2889082>,
    <-0.8062060, 0.5267616, 0.2693587>,
    <-0.7363543, 0.5651251, 0.3720428>,
    <-0.7604232, 0.5427156, 0.3566739>,
    <-0.7468785, 0.5509873, 0.3722708>,
    <-0.7284813, 0.5698840, 0.3801937>,
    <-0.7052976, 0.5922636, 0.3895884>,
    <-0.7019527, 0.5884306, 0.4012628>,
    <-0.7735497, 0.5222349, 0.3590147>,
    <-0.7509566, 0.5410862, 0.3785365>,
    <-0.7294853, 0.5657215, 0.3844612>,
    <-0.7084781, 0.5959511, 0.3780225>,
    <0.8108950, 0.5468816, -0.2082542>,
    <0.7795183, 0.5560339, -0.2884053>,
    <0.7825351, 0.5768017, -0.2343898>,
    <0.7986146, 0.5749572, -0.1778735>,
    <0.8228628, 0.5396669, -0.1779228>,
    <0.7855328, 0.5571378, -0.2693247>,
    <0.7290160, 0.5589343, -0.3951305>,
    <0.7599985, 0.5938347, -0.2641263>,
    <0.7033195, 0.5385000, -0.4640683>,
    <0.4533954, 0.3818862, -0.8053543>,
    <0.6667790, 0.5462785, -0.5069375>,
    <0.7334931, 0.6073260, -0.3051934>,
    <0.7777432, 0.6027677, -0.1782881>,
    <0.7514939, 0.6288707, -0.1994455>,
    <0.8268924, 0.5268146, -0.1967622>,
    <0.7963639, 0.4879303, -0.3573913>,
    <0.7611337, 0.5053639, -0.4065500>,
    <0.7852751, 0.5486164, -0.2869895>,
    <0.6839201, 0.4192415, -0.5970677>,
    <0.6560473, 0.4461364, -0.6087399>,
    <0.4859068, 0.3066600, -0.8184462>,
    <0.5043183, 0.3527530, -0.7881804>,
    <0.6837374, 0.5085391, -0.5233461>,
    <0.4989154, 0.3857719, -0.7760564>,
    <0.2961276, -0.2277300, -0.9276031>,
    <0.2209960, -0.1611572, -0.9618675>,
    <0.2800083, -0.1847745, -0.9420476>,
    <0.3695533, -0.2513035, -0.8945820>,
    <0.5086814, -0.3565606, -0.7836503>,
    <0.4591401, -0.3552873, -0.8142243>,
    <0.4597397, -0.3843096, -0.8005908>,
    <0.2700397, -0.2098101, -0.9397118>,
    <0.2098333, -0.1534890, -0.9656144>,
    <0.2129477, -0.1338060, -0.9678581>,
    <0.2783322, -0.1619226, -0.9467377>,
    <0.1860646, -0.1278851, -0.9741793>,
    <0.1886389, -0.1089098, -0.9759887>,
    <0.3753231, -0.2230478, -0.8996567>,
    <0.5377407, -0.3399068, -0.7715558>,
    <0.7780162, -0.5969651, -0.1957637>,
    <0.7319184, -0.5821164, -0.3541693>,
    <0.7365509, -0.5433765, -0.4027837>,
    <0.7846451, -0.5508026, -0.2845147>,
    <0.7499266, -0.6309220, -0.1988654>,
    <0.7261375, -0.6173140, -0.3027339>,
    <0.6309362, -0.5015121, -0.5919503>,
    <0.6466698, -0.4660989, -0.6037963>,
    <0.6560849, -0.5635685, -0.5019395>,
    <0.7139894, -0.4702438, -0.5187387>,
    <0.2822472, 0.2817272, -0.9170422>,
    <0.2797236, 0.2778560, -0.9189944>,
    <0.2739608, 0.2707399, -0.9228463>,
    <0.2753377, 0.2729871, -0.9217739>,
    <0.2870975, 0.2840997, -0.9148018>,
    <0.2854650, 0.2849203, -0.9150575>,
    <0.2866455, 0.2866455, -0.9141492>,
    <0.2858352, 0.2858492, -0.9146521>,
    <0.2858352, 0.2858492, -0.9146521>,
    <0.2802105, 0.2802354, -0.9181232>,
    <0.2701672, 0.2646012, -0.9257407>,
    <0.2694217, 0.2613382, -0.9268842>,
    <0.2802105, 0.2802354, -0.9181232>,
    <0.2645210, 0.2645531, -0.9273836>,
    <0.2645210, 0.2645531, -0.9273836>,
    <0.2417679, 0.2231612, -0.9443238>,
    <0.2693620, 0.2620139, -0.9267108>,
    <0.2901933, 0.2808786, -0.9148197>,
    <0.3107516, 0.1973041, -0.9297874>,
    <0.2234718, 0.1500078, -0.9630981>,
    <0.2654718, 0.1970105, -0.9437752>,
    <0.3578138, 0.2579075, -0.8974703>,
    <0.2850813, 0.1790815, -0.9416254>,
    <0.2125289, 0.1422786, -0.9667411>,
    <0.1953842, 0.1518661, -0.9688971>,
    <0.2438215, 0.2033797, -0.9482551>,
    <0.1807725, 0.1289045, -0.9750410>,
    <0.1643208, 0.1378832, -0.9767225>,
    <0.1934035, 0.1727768, -0.9657863>,
    <0.2174252, 0.1925732, -0.9568918>,
    <0.3337511, 0.2731559, -0.9022173>,
    <0.2776414, 0.2447944, -0.9289730>,
    <0.2672919, 0.1722381, -0.9480976>,
    <0.2249554, 0.1434831, -0.9637467>,
    <0.2021083, 0.1349740, -0.9700177>,
    <0.2176315, 0.1488396, -0.9646156>,
    <0.1939992, 0.1282331, -0.9725845>,
    <0.1753953, 0.1196048, -0.9772058>,
    <0.1857810, 0.1072616, -0.9767192>,
    <0.1875261, 0.1313082, -0.9734434>,
    <0.1875261, 0.1313082, -0.9734434>,
    <0.1679681, 0.1176134, -0.9787511>,
    <0.1764012, 0.1236046, -0.9765268>,
    <0.1679681, 0.1176134, -0.9787511>,
    <0.1622923, 0.1136391, -0.9801772>,
    <0.1622923, 0.1136391, -0.9801772>,
    <0.1643208, 0.1378832, -0.9767225>,
    <0.2574485, -0.1954345, -0.9463221>,
    <0.2155506, -0.1651942, -0.9624182>,
    <0.1993247, -0.1462241, -0.9689624>,
    <0.2178570, -0.1561676, -0.9634054>,
    <0.2937903, -0.2346558, -0.9266196>,
    <0.2314951, -0.1840306, -0.9552710>,
    <0.1903269, -0.1410063, -0.9715415>,
    <0.1753127, -0.1260175, -0.9764144>,
    <0.2079163, -0.1637984, -0.9643344>,
    <0.1675835, -0.1406176, -0.9757779>,
    <0.1910571, -0.1337780, -0.9724200>,
    <0.1910571, -0.1337780, -0.9724200>,
    <0.1708113, -0.1196019, -0.9780178>,
    <0.1793896, -0.1255289, -0.9757366>,
    <0.1708113, -0.1196019, -0.9780178>,
    <0.1649488, -0.1154970, -0.9795164>,
    <0.1649488, -0.1154970, -0.9795164>,
    <0.1886389, -0.1089098, -0.9759887>,
    <-0.7909555, -0.5334706, 0.2996641>,
    <-0.7792918, -0.5609394, 0.2793766>,
    <-0.7711174, -0.5682731, 0.2871301>,
    <-0.7760499, -0.5533231, 0.3026220>,
    <-0.7886662, -0.5520269, 0.2706878>,
    <-0.8057473, -0.5260251, 0.2721560>,
    <-0.7604537, -0.5891111, 0.2732366>,
    <-0.7564871, -0.5911387, 0.2797899>,
    <-0.7348555, -0.6173990, 0.2807238>,
    <-0.7375169, -0.6185014, 0.2711545>,
    <-0.7597784, -0.5824683, 0.2889074>,
    <-0.7400902, -0.6195410, 0.2616015>,
    <-0.7483384, -0.6276739, 0.2145112>,
    <-0.7707327, -0.5774227, 0.2693587>,
    <-0.8161105, -0.5199096, 0.2523045>,
    <-0.8004549, -0.5499611, 0.2383585>,
    <-0.8054984, -0.5349157, 0.2550245>,
    <-0.8186350, -0.5108602, 0.2624093>,
    <-0.7850056, -0.5699913, 0.2426440>,
    <-0.7976580, -0.5427044, 0.2630849>,
    <-0.7825111, -0.5912184, 0.1952873>,
    <-0.8001112, -0.5600606, 0.2148354>,
    <-0.8149523, -0.5133461, 0.2689398>,
    <-0.8162485, -0.5282304, 0.2339038>,
    <-0.7916924, 0.5752060, 0.2058183>,
    <-0.8132140, 0.5536789, 0.1792278>,
    <-0.8109877, 0.5389646, 0.2276315>,
    <-0.7924238, 0.5445575, 0.2748120>,
    <-0.7949521, 0.5496704, 0.2567364>,
    <-0.7885676, 0.5886698, 0.1778454>,
    <-0.7480859, 0.6279750, 0.2145106>,
    <-0.7755481, 0.5863572, 0.2339025>,
    <-0.7999394, 0.5603065, 0.2148341>,
    <-0.8322251, 0.5246593, 0.1792596>,
    <-0.8203966, 0.5126701, 0.2532169>,
    <-0.8231984, 0.5331113, 0.1952863>,
    <-0.7861990, 0.5013180, 0.3613465>,
    <-0.7654524, 0.4910987, 0.4158181>,
    <-0.7676817, 0.5890735, 0.2523036>,
    <-0.7905663, 0.5640838, 0.2383577>,
    <-0.7781534, 0.5739690, 0.2550233>,
    <-0.7600416, 0.5945408, 0.2624079>,
    <-0.7371735, 0.6189107, 0.2711545>,
    <-0.7356256, 0.6164811, 0.2807242>,
    <-0.8041046, 0.5427154, 0.2426432>,
    <-0.7827908, 0.5639375, 0.2630836>,
    <-0.7611181, 0.5902300, 0.2689383>,
    <-0.7386443, 0.6212644, 0.2616012>,
    <-0.8112370, -0.5471786, 0.2061314>,
    <-0.7983924, -0.5747792, 0.1794392>,
    <-0.7836824, -0.5776295, 0.2284425>,
    <-0.7824407, -0.5581746, 0.2760934>,
    <-0.7880258, -0.5588558, 0.2582548>,
    <-0.8228091, -0.5396726, 0.1781536>,
    <-0.7776145, -0.6025590, 0.1795503>,
    <-0.7620897, -0.5953735, 0.2544597>,
    <-0.7517943, -0.6290399, 0.1977728>,
    <-0.7369987, -0.6102627, 0.2905381>,
    <-0.7392004, -0.5667261, 0.3638740>,
    <-0.6892224, -0.5667209, 0.4514420>,
    <-0.5326568, -0.4463641, 0.7190520>,
    <-0.7219675, -0.5504703, 0.4192200>,
    <-0.8273365, -0.5270815, 0.1941632>,
    <-0.7885832, -0.5507847, 0.2734459>,
    <-0.7704496, -0.5115364, 0.3804443>,
    <-0.8028271, -0.4920357, 0.3367039>,
    <-0.7071716, -0.5235709, 0.4751650>,
    <-0.6876616, -0.4676751, 0.5553392>,
    <-0.5661251, -0.4321292, 0.7019735>,
    <-0.5690001, -0.3979994, 0.7196078>,
    <-0.7183206, -0.4424617, 0.5368828>,
    <-0.5706648, -0.3645630, 0.7358230>,
    <-0.3946135, 0.2958012, 0.8699321>,
    <-0.4541061, 0.3095387, 0.8354481>,
    <-0.3581381, 0.2383609, 0.9027299>,
    <-0.3017470, 0.2152914, 0.9287617>,
    <-0.2816850, 0.2058148, 0.9371733>,
    <-0.3515996, 0.2730198, 0.8954540>,
    <-0.5366492, 0.4508947, 0.7132332>,
    <-0.5422421, 0.4149113, 0.7306313>,
    <-0.5729625, 0.4016148, 0.7144365>,
    <-0.4559772, 0.2792602, 0.8450435>,
    <-0.3456609, 0.2089718, 0.9147947>,
    <-0.6038883, 0.3869465, 0.6968438>,
    <-0.2772657, 0.1775923, 0.9442376>,
    <-0.2596591, 0.1767315, 0.9493909>,
    <-0.7784024, 0.5972784, 0.1932568>,
    <-0.7877328, 0.5531135, 0.2711871>,
    <-0.7453485, 0.5498800, 0.3769451>,
    <-0.7378538, 0.5866786, 0.3337363>,
    <-0.7295592, 0.6201880, 0.2882885>,
    <-0.7501368, 0.6311807, 0.1972455>,
    <-0.7357279, 0.4868437, 0.4708372>,
    <-0.6772655, 0.4881106, 0.5505084>,
    <-0.6639983, 0.5254960, 0.5319400>,
    <-0.6796386, 0.5817332, 0.4468533>,
    <-0.4073817, -0.2658697, 0.8737010>,
    <-0.4410028, -0.3171257, 0.8396117>,
    <-0.3412199, -0.2511468, 0.9058114>,
    <-0.2998083, -0.2058869, 0.9315179>,
    <-0.2839183, -0.1905260, 0.9397288>,
    <-0.3710846, -0.2333346, 0.8988054>,
    <-0.4136110, -0.3293399, 0.8487999>,
    <-0.3094597, -0.2494147, 0.9176203>,
    <-0.3522885, -0.3050706, 0.8847738>,
    <-0.2789736, -0.2417859, 0.9293618>,
    <-0.2552480, -0.1951210, 0.9469827>,
    <-0.2493985, -0.2131947, 0.9446419>,
    <-0.2481238, -0.1795848, 0.9519369>,
    <-0.3371646, -0.2142384, 0.9167453>,
    <-0.2855619, -0.1929440, 0.9387369>,
    <-0.2741092, -0.1813347, 0.9444479>,
    <-0.2942388, -0.1854828, 0.9375605>,
    <-0.2572981, -0.1816839, 0.9490989>,
    <-0.2609624, -0.1764594, 0.9490841>,
    <-0.2730804, -0.1748279, 0.9459716>,
    <-0.3218255, 0.2477367, 0.9138134>,
    <-0.2839586, 0.2064502, 0.9363471>,
    <-0.2690812, 0.1998687, 0.9421506>,
    <-0.2800386, 0.2175391, 0.9350161>,
    <-0.2922460, 0.2376238, 0.9263516>,
    <-0.3669909, 0.2984970, 0.8810319>,
    <-0.2623970, 0.1833489, 0.9473811>,
    <-0.2599625, 0.1894695, 0.9468478>,
    <-0.2628862, 0.2022311, 0.9433946>,
    <-0.2595524, 0.2145503, 0.9415948>,
    <0.2755710, -0.2740453, -0.9213901>,
    <0.2620752, -0.2562423, -0.9304066>,
    <0.2599406, -0.2515719, -0.9322781>,
    <0.2681540, -0.2631130, -0.9267497>,
    <0.2662158, -0.2662280, -0.9264188>,
    <0.2840152, -0.2840255, -0.9157865>,
    <0.2840152, -0.2840255, -0.9157865>,
    <0.2867010, -0.2867085, -0.9141120>,
    <0.2816675, -0.2803689, -0.9176365>,
    <0.2806550, -0.2746560, -0.9196721>,
    <0.2626822, -0.2461781, -0.9329493>,
    <0.2557010, -0.2376792, -0.9370835>,
    <0.2912870, -0.2744489, -0.9164222>,
    <0.2446871, -0.2322304, -0.9413805>,
    <0.1972723, -0.1685301, -0.9657542>,
    <0.2233805, -0.2233942, -0.9487867>,
    <0.2233805, -0.2233942, -0.9487867>,
    <0.2662158, -0.2662280, -0.9264188>,
    <-0.3433220, 0.3554515, 0.8693585>,
    <-0.3089637, 0.3167460, 0.8967795>,
    <-0.3266632, 0.3218971, 0.8886357>,
    <-0.3427804, 0.3419805, 0.8749577>,
    <-0.3695085, 0.3696409, 0.8525427>,
    <-0.3803987, 0.3867026, 0.8400940>,
    <-0.3892706, 0.3966339, 0.8313543>,
    <-0.3388899, 0.3582056, 0.8699669>,
    <-0.3388899, 0.3582056, 0.8699669>,
    <-0.2859347, 0.3093102, 0.9069556>,
    <-0.2635427, 0.2630720, 0.9280832>,
    <-0.3188522, 0.2996120, 0.8992030>,
    <-0.2859347, 0.3093102, 0.9069556>,
    <-0.2228965, 0.2442349, 0.9437513>,
    <-0.2228965, 0.2442349, 0.9437513>,
    <-0.2667138, 0.2309420, 0.9356974>,
    <-0.3566009, 0.3339878, 0.8725182>,
    <-0.3709695, 0.3590256, 0.8564357>,
    <0.2740031, 0.2755244, -0.9214166>,
    <0.2562108, 0.2620386, -0.9304256>,
    <0.2515333, 0.2598945, -0.9323014>,
    <0.2630648, 0.2680975, -0.9267797>,
    <0.2661737, 0.2661521, -0.9264527>,
    <0.2839807, 0.2839678, -0.9158151>,
    <0.2839807, 0.2839678, -0.9158151>,
    <0.2866455, 0.2866455, -0.9141492>,
    <0.2803281, 0.2816261, -0.9176616>,
    <0.2746306, 0.2806267, -0.9196884>,
    <0.2461540, 0.2626528, -0.9329639>,
    <0.2376436, 0.2556578, -0.9371044>,
    <0.2744341, 0.2912690, -0.9164324>,
    <0.3032795, 0.3679901, -0.8789794>,
    <0.2442207, 0.2874563, -0.9261345>,
    <0.2242527, 0.2629504, -0.9383858>,
    <0.2321795, 0.2446258, -0.9414090>,
    <0.1921984, 0.2250257, -0.9552085>,
    <0.1684780, 0.1972113, -0.9657758>,
    <0.2233295, 0.2233023, -0.9488203>,
    <0.2233295, 0.2233023, -0.9488203>,
    <0.2661737, 0.2661521, -0.9264527>,
    <0.2889873, 0.2899677, -0.9123624>,
    <0.3008875, 0.2985688, -0.9057171>,
    <0.3073641, 0.3096871, -0.8997895>,
    <0.2964121, 0.3027196, -0.9058149>,
    <0.2866455, 0.2866455, -0.9141492>,
    <0.3205846, 0.3137314, -0.8937551>,
    <0.3257108, 0.3294895, -0.8861993>,
    <0.3729169, 0.3618404, -0.8544030>,
    <0.3719871, 0.3796103, -0.8470665>,
    <0.3144822, 0.3293711, -0.8902896>,
    <0.3598110, 0.3880180, -0.8485152>,
    <0.2896731, -0.2888754, -0.9124914>,
    <0.2973140, -0.3005634, -0.9062373>,
    <0.3088217, -0.3067704, -0.9002894>,
    <0.3025519, -0.2962956, -0.9059091>,
    <0.2867010, -0.2867085, -0.9141120>,
    <0.2833846, -0.2844022, -0.9158649>,
    <0.2813386, -0.2867507, -0.9157634>,
    <0.3115727, -0.3200608, -0.8946975>,
    <0.3280363, -0.3247192, -0.8871018>,
    <0.2827793, -0.2979346, -0.9117406>,
    <0.3097442, -0.3625795, -0.8789736>,
    <0.3592965, -0.3726199, -0.8556053>,
    <0.3782411, -0.3713946, -0.8479385>,
    <0.3290868, -0.3142754, -0.8904678>,
    <0.3877550, -0.3596840, -0.8486893>,
    <0.4052771, -0.4115476, -0.8163205>,
    <0.4182744, -0.4076209, -0.8117214>,
    <0.4260470, -0.4039709, -0.8095008>,
    <0.4187990, -0.4043999, -0.8130610>,
    <0.4021107, -0.4230390, -0.8120006>,
    <0.4283832, -0.4264131, -0.7966553>,
    <0.4449349, -0.4075312, -0.7974655>,
    <0.4384054, -0.3954199, -0.8071207>,
    <0.4555307, -0.4271060, -0.7810712>,
    <0.4242501, -0.3858953, -0.8192049>,
    <0.2765010, -0.2786733, -0.9197219>,
    <0.2609860, -0.2679309, -0.9274154>,
    <0.2544367, -0.2659405, -0.9298052>,
    <0.2644324, -0.2721808, -0.9251990>,
    <0.2867010, -0.2867085, -0.9141120>,
    <0.2834644, -0.2834691, -0.9161295>,
    <0.2834644, -0.2834691, -0.9161295>,
    <0.2620435, -0.2620459, -0.9287977>,
    <0.2266616, -0.2434544, -0.9430559>,
    <0.2385054, -0.2622641, -0.9350576>,
    <0.2620435, -0.2620459, -0.9287977>,
    <0.2127047, -0.2127055, -0.9536839>,
    <0.2127047, -0.2127055, -0.9536839>,
    <0.1651187, -0.2003438, -0.9657112>,
    <0.1883691, -0.2285068, -0.9551449>,
    <0.2201054, -0.2666050, -0.9383365>,
    <0.2556101, -0.2766118, -0.9263635>,
    <0.2407319, -0.2904789, -0.9261048>,
    <-0.4582690, 0.4349236, 0.7751329>,
    <-0.4682824, 0.4483616, 0.7613694>,
    <-0.4383977, 0.4242384, 0.7923568>,
    <-0.4248675, 0.4102820, 0.8069426>,
    <-0.4056594, 0.3948399, 0.8243433>,
    <-0.3676116, 0.3635433, 0.8559778>,
    <-0.2734309, 0.3128107, 0.9096071>,
    <-0.5251452, 0.4833627, 0.7004163>,
    <-0.5251452, 0.4833627, 0.7004163>,
    <-0.5076004, 0.4783083, 0.7166331>,
    <-0.4313549, 0.4240490, 0.7963136>,
    <-0.4099733, 0.4025910, 0.8184390>,
    <-0.5076004, 0.4783083, 0.7166331>,
    <-0.4522900, 0.4415132, 0.7749193>,
    <-0.4522900, 0.4415132, 0.7749193>,
    <-0.3892706, 0.3966339, 0.8313543>,
    <-0.3960721, 0.3856722, 0.8332970>,
    <-0.4251670, 0.4063886, 0.8087530>,
    <0.4097733, 0.4052317, -0.8172350>,
    <0.4068659, 0.4182142, -0.8121312>,
    <0.4035975, 0.4261270, -0.8096449>,
    <0.4039010, 0.4190383, -0.8131857>,
    <0.4161043, 0.3969320, -0.8181089>,
    <0.4241473, 0.4266583, -0.7987877>,
    <0.4074264, 0.4449697, -0.7974996>,
    <0.3953531, 0.4384276, -0.8071414>,
    <0.4266927, 0.4552044, -0.7814872>,
    <0.4446114, 0.5293958, -0.7225377>,
    <0.4068221, 0.4835670, -0.7750218>,
    <0.3855068, 0.4581515, -0.8009255>,
    <0.3858022, 0.4242742, -0.8192363>,
    <0.3612930, 0.4299503, -0.8274117>,
    <0.4302963, 0.3948880, -0.8117318>,
    <0.4503168, 0.4051054, -0.7956786>,
    <0.4505913, 0.4287410, -0.7830381>,
    <0.4448522, 0.4369423, -0.7817851>,
    <0.4661566, 0.4230785, -0.7769830>,
    <0.4562765, 0.4440151, -0.7711435>,
    <0.4951253, 0.4602726, -0.7368854>,
    <0.4886051, 0.4882782, -0.7230834>,
    <0.4505423, 0.4656822, -0.7616769>,
    <0.4812529, 0.5169716, -0.7079096>,
    <0.5044662, -0.5221898, -0.6876276>,
    <0.5217974, -0.5128042, -0.6817327>,
    <0.5357437, -0.5105329, -0.6725585>,
    <0.5298480, -0.5163482, -0.6727895>,
    <0.4882782, -0.4886051, -0.7230834>,
    <0.4602726, -0.4951253, -0.7368854>,
    <0.4441469, -0.5297853, -0.7225379>,
    <0.5129474, -0.5473362, -0.6612927>,
    <0.5356515, -0.5359638, -0.6525491>,
    <0.5506225, -0.5051535, -0.6645561>,
    <0.5556951, -0.5006967, -0.6637061>,
    <0.5575730, -0.5231940, -0.6445001>,
    <0.5518117, -0.5014454, -0.6663755>,
    <0.5169716, -0.4812529, -0.7079096>,
    <0.4026670, -0.4387726, -0.8033292>,
    <0.4093344, -0.4548998, -0.7908928>,
    <0.4312859, -0.4532659, -0.7800914>,
    <0.4402778, -0.4483430, -0.7779100>,
    <0.3606797, -0.4304624, -0.8274130>,
    <0.3842479, -0.4592062, -0.8009265>,
    <0.4240426, -0.4672076, -0.7758253>,
    <0.4446222, -0.4569004, -0.7704240>,
    <0.4055763, -0.4846118, -0.7750221>,
    <0.4664083, -0.4512525, -0.7608117>,
    <-0.3758349, -0.3720167, 0.8487354>,
    <-0.3324634, -0.3307526, 0.8832162>,
    <-0.3381202, -0.3495049, 0.8737969>,
    <-0.3600441, -0.3689408, 0.8568844>,
    <-0.3907194, -0.4013208, 0.8284202>,
    <-0.4140439, -0.4195392, 0.8078084>,
    <-0.4264552, -0.4312754, 0.7950707>,
    <-0.3785563, -0.3671304, 0.8496531>,
    <-0.3785563, -0.3671304, 0.8496531>,
    <-0.3240332, -0.3060524, 0.8951728>,
    <-0.2753674, -0.2799615, 0.9196708>,
    <-0.3134864, -0.3382971, 0.8872888>,
    <-0.3240332, -0.3060524, 0.8951728>,
    <-0.2555130, -0.2378188, 0.9370994>,
    <-0.2555130, -0.2378188, 0.9370994>,
    <-0.2190003, -0.2411310, 0.9454600>,
    <-0.2322369, -0.2591870, 0.9374903>,
    <-0.2863027, -0.3359741, 0.8973027>,
    <-0.3481637, -0.3780796, 0.8578099>,
    <-0.3376828, -0.4043236, 0.8499957>,
    <-0.4095288, -0.4765942, 0.7779101>,
    <-0.3720200, -0.3929991, 0.8409238>,
    <-0.4437872, -0.4816807, 0.7556696>,
    <-0.4783126, -0.5168941, 0.7099561>,
    <-0.4440099, -0.4725752, 0.7612673>,
    <-0.4154381, -0.4404856, 0.7958540>,
    <-0.3799207, -0.3944659, 0.8366941>,
    <-0.3360952, -0.3414847, 0.8777404>,
    <-0.2737486, -0.2225605, 0.9356968>,
    <-0.5163920, -0.5864241, 0.6240562>,
    <-0.5163920, -0.5864241, 0.6240562>,
    <-0.5243117, -0.5796950, 0.6237395>,
    <-0.4578765, -0.4816033, 0.7472666>,
    <-0.4246566, -0.4453743, 0.7882313>,
    <-0.5243117, -0.5796950, 0.6237395>,
    <-0.4834831, -0.5134472, 0.7089542>,
    <-0.4834831, -0.5134472, 0.7089542>,
    <-0.4264552, -0.4312754, 0.7950707>,
    <-0.3949567, -0.4150852, 0.8195813>,
    <-0.4000528, -0.4236786, 0.8126833>,
    <-0.2965098, -0.2716767, 0.9155729>,
    <-0.3597942, -0.3578191, 0.8616923>,
    <-0.3578229, -0.3419902, 0.8689105>,
    <-0.3358632, -0.3025230, 0.8920066>,
    <-0.2737486, -0.2225605, 0.9356968>,
    <-0.4067113, -0.4216431, 0.8104339>,
    <-0.3906368, -0.3811778, 0.8379179>,
    <-0.4556577, -0.4857960, 0.7459077>,
    <-0.4486430, -0.4472115, 0.7737709>,
    <-0.3830460, -0.3491053, 0.8552200>,
    <-0.4463472, -0.4136010, 0.7935417>,
    <-0.4939366, 0.5093757, 0.7046723>,
    <-0.5122708, 0.5005990, 0.6978390>,
    <-0.5270730, 0.5035234, 0.6845862>,
    <-0.5199780, 0.5103286, 0.6849727>,
    <-0.5332289, 0.5326755, 0.6572090>,
    <-0.5034787, 0.5351713, 0.6783073>,
    <-0.3784146, 0.4633387, 0.8013236>,
    <-0.4257209, 0.4550188, 0.7821251>,
    <-0.4618529, 0.4616890, 0.7573211>,
    <-0.5308999, 0.4868065, 0.6936604>,
    <-0.5459350, 0.4942092, 0.6765443>,
    <-0.4961982, 0.4667868, 0.7320501>,
    <-0.5499005, 0.5049436, 0.6653130>,
    <-0.5581817, 0.5237180, 0.6435470>,
    <-0.3131796, 0.3319407, 0.8897943>,
    <-0.3856741, 0.3855485, 0.8382171>,
    <-0.3710129, 0.3824597, 0.8462115>,
    <-0.3347808, 0.3608235, 0.8704758>,
    <-0.3027625, 0.3474958, 0.8874579>,
    <-0.2558546, 0.3002612, 0.9189024>,
    <-0.2734309, 0.3128107, 0.9096071>,
    <-0.4395459, 0.4248767, 0.7913780>,
    <-0.4031213, 0.4097423, 0.8182936>,
    <-0.3680507, 0.3961983, 0.8411692>,
    <-0.3349576, 0.3859112, 0.8595789>,
    <0.5221898, 0.5044662, -0.6876276>,
    <0.5128042, 0.5217974, -0.6817327>,
    <0.5105329, 0.5357437, -0.6725585>,
    <0.5163482, 0.5298480, -0.6727895>,
    <0.5473362, 0.5129474, -0.6612927>,
    <0.5359638, 0.5356515, -0.6525491>,
    <0.5051535, 0.5506225, -0.6645561>,
    <0.5006967, 0.5556951, -0.6637061>,
    <0.5231940, 0.5575730, -0.6445001>,
    <0.5221085, 0.6217278, -0.5838297>,
    <0.4961970, 0.5899250, -0.6370063>,
    <0.4869549, 0.5797783, -0.6532473>,
    <0.5014454, 0.5518117, -0.6663755>,
    <0.4770746, 0.5688347, -0.6699455>,
    <0.5665568, 0.5189835, -0.6400543>,
    <0.5696871, 0.5123954, -0.6425788>,
    <0.5604873, 0.5333449, -0.6335591>,
    <0.5591229, 0.5488989, -0.6213627>,
    <0.5684789, 0.5156810, -0.6410186>,
    <0.5535710, 0.5387321, -0.6350802>,
    <0.5848434, 0.5435801, -0.6020622>,
    <0.5739458, 0.5736012, -0.5844381>,
    <0.5462752, 0.5649368, -0.6184091>,
    <0.5618789, 0.6037655, -0.5654727>,
    <0.5801790, -0.6007755, -0.5499647>,
    <0.5959439, -0.5858372, -0.5492228>,
    <0.6114111, -0.5825900, -0.5355048>,
    <0.6071144, -0.5915997, -0.5304922>,
    <0.5736012, -0.5739458, -0.5844381>,
    <0.5435801, -0.5848434, -0.6020622>,
    <0.5216191, -0.6221385, -0.5838298>,
    <0.5836551, -0.6228974, -0.5209084>,
    <0.6053772, -0.6056867, -0.5163934>,
    <0.6234088, -0.5718753, -0.5332167>,
    <0.6314802, -0.5687278, -0.5270498>,
    <0.6263757, -0.5875699, -0.5122647>,
    <0.6305902, -0.5727478, -0.5237518>,
    <0.6037655, -0.5618789, -0.5654727>,
    <0.5189835, -0.5665568, -0.6400543>,
    <0.5123954, -0.5696871, -0.6425788>,
    <0.5333449, -0.5604873, -0.6335591>,
    <0.5488989, -0.5591229, -0.6213627>,
    <0.4773495, -0.5686038, -0.6699457>,
    <0.4864112, -0.5802344, -0.6532474>,
    <0.5156810, -0.5684789, -0.6410186>,
    <0.5387321, -0.5535710, -0.6350802>,
    <0.4947989, -0.5910980, -0.6370064>,
    <0.5649368, -0.5462752, -0.6184091>,
    <-0.5048002, -0.4874613, 0.7124312>,
    <-0.4940249, -0.5047236, 0.7079502>,
    <-0.5001232, -0.5230483, 0.6901429>,
    <-0.5084595, -0.5173432, 0.6883495>,
    <-0.5328838, -0.5329120, 0.6572972>,
    <-0.5361515, -0.5028251, 0.6780180>,
    <-0.4819702, -0.5261396, 0.7006296>,
    <-0.4921408, -0.5436352, 0.6798957>,
    <-0.4620766, -0.5484516, 0.6969118>,
    <-0.4805296, -0.5707507, 0.6658340>,
    <-0.5043813, -0.5491274, 0.6663772>,
    <-0.4954616, -0.5887071, 0.6387031>,
    <-0.5221294, -0.6216994, 0.5838414>,
    <-0.5238197, -0.5581988, 0.6434493>,
    <-0.5568621, -0.5099524, 0.6556319>,
    <-0.5549919, -0.5447310, 0.6286908>,
    <-0.5583648, -0.5312853, 0.6371536>,
    <-0.5652827, -0.5083598, 0.6496351>,
    <-0.5459374, -0.5644350, 0.6191652>,
    <-0.5544614, -0.5395606, 0.6335983>,
    <-0.5610026, -0.6027256, 0.5674486>,
    <-0.5739585, -0.5735769, 0.5844495>,
    <-0.5690569, -0.5162543, 0.6400435>,
    <-0.5858148, -0.5444949, 0.6002885>,
    <-0.5802126, 0.6007334, 0.5499752>,
    <-0.6058591, 0.5904161, 0.5332387>,
    <-0.6113861, 0.5826067, 0.5355151>,
    <-0.5971408, 0.5869548, 0.5467238>,
    <-0.6053560, 0.6056987, 0.5164042>,
    <-0.5828160, 0.6219637, 0.5229595>,
    <-0.5215877, 0.6221542, 0.5838411>,
    <-0.5444949, 0.5858148, 0.6002885>,
    <-0.5735769, 0.5739585, 0.5844495>,
    <-0.6290933, 0.5715432, 0.5268586>,
    <-0.6314059, 0.5688004, 0.5270605>,
    <-0.6027256, 0.5610026, 0.5674486>,
    <-0.6246989, 0.5730998, 0.5303847>,
    <-0.6271667, 0.5884150, 0.5103231>,
    <-0.5072766, 0.5538146, 0.6602725>,
    <-0.5436460, 0.5537673, 0.6307066>,
    <-0.5303205, 0.5573508, 0.6388429>,
    <-0.5068576, 0.5636757, 0.6522002>,
    <-0.4773671, 0.5713702, 0.6675753>,
    <-0.4554058, 0.5465824, 0.7027469>,
    <-0.5641547, 0.5456537, 0.6196705>,
    <-0.5393265, 0.5542208, 0.6340081>,
    <-0.5159282, 0.5687036, 0.6406203>,
    <-0.4934631, 0.5899401, 0.6391126>,
    <0.6007755, 0.5801790, -0.5499647>,
    <0.5858372, 0.5959439, -0.5492228>,
    <0.5825900, 0.6114111, -0.5355048>,
    <0.5915997, 0.6071144, -0.5304922>,
    <0.6228974, 0.5836551, -0.5209084>,
    <0.6056867, 0.6053772, -0.5163934>,
    <0.5718753, 0.6234088, -0.5332167>,
    <0.5687278, 0.6314802, -0.5270498>,
    <0.5875699, 0.6263757, -0.5122647>,
    <0.5737046, 0.6832506, -0.4516986>,
    <0.5559214, 0.6608598, -0.5041981>,
    <0.5504478, 0.6554530, -0.5170962>,
    <0.5727478, 0.6305902, -0.5237518>,
    <0.5447077, 0.6497234, -0.5302387>,
    <0.6389973, 0.5853970, -0.4989917>,
    <0.6409336, 0.5763602, -0.5069646>,
    <0.6280061, 0.5976506, -0.4984196>,
    <0.6250696, 0.6138698, -0.4821326>,
    <0.6368840, 0.5776022, -0.5106412>,
    <0.6187640, 0.6022332, -0.5044267>,
    <0.6457545, 0.6001675, -0.4720170>,
    <0.6308171, 0.6304953, -0.4522670>,
    <0.6081185, 0.6291427, -0.4841192>,
    <0.6145286, 0.6604904, -0.4314012>,
    <0.6303367, -0.6528154, -0.4201282>,
    <0.6460472, -0.6351630, -0.4233096>,
    <0.6614285, -0.6301811, -0.4066744>,
    <0.6570369, -0.6401820, -0.3980823>,
    <0.6304953, -0.6308171, -0.4522670>,
    <0.6001675, -0.6457545, -0.4720170>,
    <0.5732478, -0.6836340, -0.4516984>,
    <0.6295082, -0.6718665, -0.3902752>,
    <0.6512926, -0.6515647, -0.3889490>,
    <0.6725762, -0.6169048, -0.4087416>,
    <0.6815132, -0.6135865, -0.3988124>,
    <0.6723358, -0.6305282, -0.3878126>,
    <0.6812969, -0.6185855, -0.3913905>,
    <0.6604904, -0.6145286, -0.4314012>,
    <0.5853970, -0.6389973, -0.4989917>,
    <0.5763602, -0.6409336, -0.5069646>,
    <0.5976506, -0.6280061, -0.4984196>,
    <0.6138698, -0.6250696, -0.4821326>,
    <0.5452651, -0.6492557, -0.5302387>,
    <0.5499110, -0.6559035, -0.5170962>,
    <0.5776022, -0.6368840, -0.5106412>,
    <0.6022332, -0.6187640, -0.5044267>,
    <0.5542852, -0.6622329, -0.5041979>,
    <0.6291427, -0.6081185, -0.4841192>,
    <-0.6007334, -0.5802126, 0.5499752>,
    <-0.5904161, -0.6058591, 0.5332387>,
    <-0.5826067, -0.6113861, 0.5355151>,
    <-0.5869548, -0.5971408, 0.5467238>,
    <-0.6056987, -0.6053560, 0.5164042>,
    <-0.6219637, -0.5828160, 0.5229595>,
    <-0.5715432, -0.6290933, 0.5268586>,
    <-0.5688004, -0.6314059, 0.5270605>,
    <-0.5441904, -0.6489670, 0.5316940>,
    <-0.5504723, -0.6554232, 0.5171079>,
    <-0.5730998, -0.6246989, 0.5303847>,
    <-0.5564390, -0.6614969, 0.5027897>,
    <-0.5737227, -0.6832217, 0.4517194>,
    <-0.5884150, -0.6271667, 0.5103231>,
    <-0.6376707, -0.5841400, 0.5021519>,
    <-0.6240159, -0.6127016, 0.4849751>,
    <-0.6280201, -0.5976245, 0.4984332>,
    <-0.6409052, -0.5763809, 0.5069770>,
    <-0.6081832, -0.6290676, 0.4841355>,
    <-0.6198656, -0.6032683, 0.5018306>,
    <-0.6138629, -0.6596828, 0.4335792>,
    <-0.6308270, -0.6304702, 0.4522881>,
    <-0.6381212, -0.5787799, 0.5077549>,
    <-0.6465290, -0.6008980, 0.4700232>,
    <-0.6303652, 0.6527717, 0.4201534>,
    <-0.6560916, 0.6392974, 0.4010520>,
    <-0.6614021, 0.6301931, 0.4066989>,
    <-0.6469809, 0.6360233, 0.4205830>,
    <-0.6512703, 0.6515727, 0.3889730>,
    <-0.6288822, 0.6711615, 0.3924912>,
    <-0.5732160, 0.6836466, 0.4517198>,
    <-0.6008980, 0.6465290, 0.4700232>,
    <-0.6304702, 0.6308270, 0.4522881>,
    <-0.6801667, 0.6177036, 0.3947349>,
    <-0.6814410, 0.6136516, 0.3988358>,
    <-0.6596828, 0.6138629, 0.4335792>,
    <-0.6735683, 0.6178518, 0.4056659>,
    <-0.6729265, 0.6311787, 0.3857244>,
    <-0.5841400, 0.6376707, 0.5021519>,
    <-0.6127016, 0.6240159, 0.4849751>,
    <-0.5976245, 0.6280201, 0.4984332>,
    <-0.5763809, 0.6409052, 0.5069770>,
    <-0.5498774, 0.6559225, 0.5171079>,
    <-0.5446102, 0.6486150, 0.5316939>,
    <-0.6290676, 0.6081832, 0.4841355>,
    <-0.6032683, 0.6198656, 0.5018306>,
    <-0.5787799, 0.6381212, 0.5077549>,
    <-0.5548226, 0.6628531, 0.5027899>,
    <0.6528154, 0.6303367, -0.4201282>,
    <0.6351630, 0.6460472, -0.4233096>,
    <0.6301811, 0.6614285, -0.4066744>,
    <0.6401820, 0.6570369, -0.3980823>,
    <0.6718665, 0.6295082, -0.3902752>,
    <0.6515647, 0.6512926, -0.3889490>,
    <0.6169048, 0.6725762, -0.4087416>,
    <0.6135865, 0.6815132, -0.3988124>,
    <0.6305282, 0.6723358, -0.3878126>,
    <0.6071982, 0.7232447, -0.3289795>,
    <0.5955656, 0.7079943, -0.3795334>,
    <0.5922438, 0.7053263, -0.3895665>,
    <0.6185855, 0.6812969, -0.3913905>,
    <0.5888115, 0.7025365, -0.3996793>,
    <0.6853768, 0.6279611, -0.3686781>,
    <0.6877552, 0.6184338, -0.3801742>,
    <0.6722984, 0.6398769, -0.3722531>,
    <0.6672688, 0.6554922, -0.3536698>,
    <0.6828627, 0.6192581, -0.3875795>,
    <0.6624283, 0.6448041, -0.3813350>,
    <0.6860839, 0.6376696, -0.3502375>,
    <0.6677667, 0.6674989, -0.3294433>,
    <0.6485637, 0.6711806, -0.3590010>,
    <0.6480316, 0.6966369, -0.3078182>,
    <0.6626738, -0.6863366, -0.2996757>,
    <0.6789866, -0.6675596, -0.3055183>,
    <0.6935547, -0.6607043, -0.2871440>,
    <0.6883798, -0.6706401, -0.2763605>,
    <0.6674989, -0.6677667, -0.3294433>,
    <0.6376696, -0.6860839, -0.3502375>,
    <0.6068181, -0.7235636, -0.3289795>,
    <0.6583599, -0.7026414, -0.2699208>,
    <0.6805992, -0.6808116, -0.2707032>,
    <0.7048413, -0.6464090, -0.2921543>,
    <0.7135764, -0.6422760, -0.2798040>,
    <0.7020801, -0.6582877, -0.2715527>,
    <0.7129867, -0.6471737, -0.2698448>,
    <0.6966369, -0.6480316, -0.3078182>,
    <0.6279611, -0.6853768, -0.3686781>,
    <0.6184338, -0.6877552, -0.3801742>,
    <0.6398769, -0.6722984, -0.3722531>,
    <0.6554922, -0.6672688, -0.3536698>,
    <0.5896174, -0.7018603, -0.3996791>,
    <0.5917688, -0.7057250, -0.3895664>,
    <0.6192581, -0.6828627, -0.3875795>,
    <0.6448041, -0.6624283, -0.3813350>,
    <0.5938194, -0.7094596, -0.3795334>,
    <0.6711806, -0.6485637, -0.3590010>,
    <0.6863366, 0.6626738, -0.2996757>,
    <0.6675596, 0.6789866, -0.3055183>,
    <0.6607043, 0.6935547, -0.2871440>,
    <0.6706401, 0.6883798, -0.2763605>,
    <0.7026414, 0.6583599, -0.2699208>,
    <0.6808116, 0.6805992, -0.2707032>,
    <0.6464090, 0.7048413, -0.2921543>,
    <0.6422760, 0.7135764, -0.2798040>,
    <0.6582877, 0.7020801, -0.2715527>,
    <0.6279600, 0.7480985, -0.2145106>,
    <0.6210031, 0.7382999, -0.2631888>,
    <0.6188876, 0.7371878, -0.2711685>,
    <0.6471737, 0.7129867, -0.2698448>,
    <0.6167226, 0.7360298, -0.2791297>,
    <0.7140633, 0.6543360, -0.2489136>,
    <0.7175119, 0.6452223, -0.2624212>,
    <0.7003587, 0.6666744, -0.2550353>,
    <0.6932636, 0.6811767, -0.2353379>,
    <0.7127827, 0.6464123, -0.2721985>,
    <0.6907144, 0.6724253, -0.2660034>,
    <0.7117428, 0.6615724, -0.2361021>,
    <0.6906917, 0.6905008, -0.2148342>,
    <0.6740399, 0.6977037, -0.2426516>,
    <0.6682287, 0.7184794, -0.1930228>,
    <0.6794467, -0.7036762, -0.2078266>,
    <0.6833208, -0.6714935, -0.2866515>,
    <0.7041195, -0.6706716, -0.2332709>,
    <0.7049379, -0.6866781, -0.1775829>,
    <0.6905008, -0.6906917, -0.2148342>,
    <0.6615724, -0.7117428, -0.2361021>,
    <0.6276891, -0.7483259, -0.2145106>,
    <0.6743776, -0.7167342, -0.1775018>,
    <0.6854096, -0.6773448, -0.2672411>,
    <0.6781481, -0.6219033, -0.3916011>,
    <0.7171379, -0.6456457, -0.2624020>,
    <0.6541366, -0.6009041, -0.4593686>,
    <0.7287182, -0.6613069, -0.1778844>,
    <0.7184794, -0.6682287, -0.1930228>,
    <0.6543360, -0.7140633, -0.2489136>,
    <0.6452223, -0.7175119, -0.2624212>,
    <0.6666744, -0.7003587, -0.2550353>,
    <0.6811767, -0.6932636, -0.2353379>,
    <0.6177551, -0.7351634, -0.2791297>,
    <0.6185195, -0.7374966, -0.2711685>,
    <0.6464123, -0.7127827, -0.2721985>,
    <0.6724253, -0.6907144, -0.2660034>,
    <0.6192474, -0.7397732, -0.2631888>,
    <0.6977037, -0.6740399, -0.2426516>,
    <-0.6527717, -0.6303652, 0.4201534>,
    <-0.6392974, -0.6560916, 0.4010520>,
    <-0.6301931, -0.6614021, 0.4066989>,
    <-0.6360233, -0.6469809, 0.4205830>,
    <-0.6515727, -0.6512703, 0.3889730>,
    <-0.6711615, -0.6288822, 0.3924912>,
    <-0.6177036, -0.6801667, 0.3947349>,
    <-0.6136516, -0.6814410, 0.3988358>,
    <-0.5884306, -0.7019527, 0.4012628>,
    <-0.5922636, -0.7052976, 0.3895884>,
    <-0.6178518, -0.6735683, 0.4056659>,
    <-0.5959511, -0.7084781, 0.3780225>,
    <-0.6072192, -0.7232273, 0.3289789>,
    <-0.6311787, -0.6729265, 0.3857244>,
    <-0.6844061, -0.6270345, 0.3720430>,
    <-0.6665166, -0.6546291, 0.3566740>,
    <-0.6723106, -0.6398539, 0.3722707>,
    <-0.6877256, -0.6184548, 0.3801936>,
    <-0.6486265, -0.6711128, 0.3590144>,
    <-0.6632682, -0.6455895, 0.3785360>,
    <-0.6475777, -0.6960659, 0.3100571>,
    <-0.6677816, -0.6674844, 0.3294424>,
    <-0.6838008, -0.6201665, 0.3844607>,
    <-0.6866607, -0.6382201, 0.3480980>,
    <-0.6627139, 0.6863030, 0.2996639>,
    <-0.6877400, 0.6700465, 0.2793767>,
    <-0.6935428, 0.6607229, 0.2871300>,
    <-0.6796766, 0.6681765, 0.3026215>,
    <-0.6805911, 0.6808263, 0.2706869>,
    <-0.6579504, 0.7021630, 0.2721552>,
    <-0.6067975, 0.7235814, 0.3289783>,
    <-0.6382201, 0.6866607, 0.3480980>,
    <-0.6674844, 0.6677816, 0.3294424>,
    <-0.7122125, 0.6466026, 0.2732369>,
    <-0.7135206, 0.6423442, 0.2797898>,
    <-0.6960659, 0.6475777, 0.3100571>,
    <-0.7055535, 0.6470912, 0.2889069>,
    <-0.7024869, 0.6587552, 0.2693579>,
    <-0.6270345, 0.6844061, 0.3720430>,
    <-0.6546291, 0.6665166, 0.3566740>,
    <-0.6398539, 0.6723106, 0.3722707>,
    <-0.6184548, 0.6877256, 0.3801936>,
    <-0.5917371, 0.7057394, 0.3895883>,
    <-0.5891085, 0.7013837, 0.4012630>,
    <-0.6711128, 0.6486265, 0.3590144>,
    <-0.6455895, 0.6632682, 0.3785360>,
    <-0.6201665, 0.6838008, 0.3844607>,
    <-0.5942291, 0.7099233, 0.3780221>,
    <0.7036114, 0.6793844, -0.2082495>,
    <0.6711276, 0.6829546, -0.2883761>,
    <0.6704898, 0.7039286, -0.2343670>,
    <0.6866422, 0.7049010, -0.1778683>,
    <0.7166501, 0.6743569, -0.1779195>,
    <0.6768606, 0.6850851, -0.2692921>,
    <0.6209081, 0.6770628, -0.3950430>,
    <0.6453426, 0.7167950, -0.2640793>,
    <0.5991685, 0.6524901, -0.4639545>,
    <0.3803438, 0.4549945, -0.8051824>,
    <0.5618483, 0.6538415, -0.5067719>,
    <0.6169035, 0.7254925, -0.3051079>,
    <0.6612593, 0.7286654, -0.1782775>,
    <0.6308765, 0.7498165, -0.1994245>,
    <0.7228505, 0.6624002, -0.1967564>,
    <0.6995383, 0.6188060, -0.3573868>,
    <0.6618276, 0.6298678, -0.4065104>,
    <0.6780894, 0.6766506, -0.2869473>,
    <0.6007332, 0.5316378, -0.5970601>,
    <0.5686463, 0.5533154, -0.6086734>,
    <0.4252939, 0.3863972, -0.8184267>,
    <0.4354712, 0.4350370, -0.7881038>,
    <0.5850960, 0.6195930, -0.5232276>,
    <0.4244667, 0.4666728, -0.7759153>,
    <0.2530110, -0.2766454, -0.9270667>,
    <0.1904349, -0.1978493, -0.9615561>,
    <0.2446052, -0.2314762, -0.9415875>,
    <0.3213811, -0.3127089, -0.8938273>,
    <0.4400662, -0.4405050, -0.7824941>,
    <0.3914539, -0.4306636, -0.8131990>,
    <0.3869736, -0.4594357, -0.7994812>,
    <0.2303844, -0.2544488, -0.9392437>,
    <0.1807348, -0.1883445, -0.9653296>,
    <0.1872897, -0.1694858, -0.9675728>,
    <0.2469356, -0.2086404, -0.9463044>,
    <0.1617278, -0.1589272, -0.9739539>,
    <0.1675835, -0.1406176, -0.9757779>,
    <0.3319828, -0.2858309, -0.8989372>,
    <0.4716155, -0.4291278, -0.7703428>,
    <0.6625667, -0.7230321, -0.1955247>,
    <0.6199287, -0.7005638, -0.3534103>,
    <0.6312843, -0.6633158, -0.4018609>,
    <0.6771872, -0.6788386, -0.2838937>,
    <0.6289987, -0.7515754, -0.1987334>,
    <0.6080420, -0.7341485, -0.3021771>,
    <0.5348828, -0.6040945, -0.5907370>,
    <0.5565583, -0.5719788, -0.6025638>,
    <0.5486980, -0.6694178, -0.5008097>,
    <0.6219882, -0.5876106, -0.5175369>,
    <0.2717898, 0.2482884, -0.9297759>,
    <0.1940641, 0.1865709, -0.9630838>,
    <0.2273126, 0.2402048, -0.9437323>,
    <0.3076782, 0.3162104, -0.8974102>,
    <0.2496698, 0.2258812, -0.9416171>,
    <0.1846283, 0.1770570, -0.9667281>,
    <0.1661310, 0.1835818, -0.9688644>,
    <0.2049323, 0.2427756, -0.9481892>,
    <0.1556928, 0.1583894, -0.9750244>,
    <0.1379769, 0.1644354, -0.9766900>,
    <0.1606088, 0.2039175, -0.9657238>,
    <0.1808252, 0.2275767, -0.9568234>,
    <0.2813940, 0.3271207, -0.9021139>,
    <0.2310740, 0.2894770, -0.9288745>,
    <0.2333506, 0.2160633, -0.9480844>,
    <0.1966443, 0.1803878, -0.9637382>,
    <0.1756346, 0.1680533, -0.9700055>,
    <0.1885246, 0.1844143, -0.9645983>,
    <0.1688172, 0.1600047, -0.9725735>,
    <0.1519979, 0.1482810, -0.9771946>,
    <0.1643208, 0.1378832, -0.9767225>,
    <0.1619292, 0.1619312, -0.9734255>,
    <0.1619292, 0.1619312, -0.9734255>,
    <0.1450358, 0.1450375, -0.9787383>,
    <0.1523013, 0.1524027, -0.9765130>,
    <0.1450358, 0.1450375, -0.9787383>,
    <0.1401331, 0.1401348, -0.9801658>,
    <0.1401331, 0.1401348, -0.9801658>,
    <0.1379769, 0.1644354, -0.9766900>,
    <0.2204738, -0.2381144, -0.9458820>,
    <0.1843776, -0.2009678, -0.9620898>,
    <0.1716255, -0.1793682, -0.9686959>,
    <0.1882019, -0.1924206, -0.9630962>,
    <0.2494841, -0.2831745, -0.9260507>,
    <0.1968511, -0.2223977, -0.9548764>,
    <0.1636906, -0.1726930, -0.9712788>,
    <0.1514029, -0.1551982, -0.9762124>,
    <0.1771724, -0.1983872, -0.9639774>,
    <0.1412579, -0.1683427, -0.9755547>,
    <0.1657053, -0.1657036, -0.9721543>,
    <0.1657053, -0.1657036, -0.9721543>,
    <0.1480754, -0.1480739, -0.9778281>,
    <0.1555081, -0.1554163, -0.9755322>,
    <0.1480754, -0.1480739, -0.9778281>,
    <0.1429733, -0.1429718, -0.9793456>,
    <0.1429733, -0.1429718, -0.9793456>,
    <0.1675835, -0.1406176, -0.9757779>,
    <-0.6863030, -0.6627139, 0.2996639>,
    <-0.6700465, -0.6877400, 0.2793767>,
    <-0.6607229, -0.6935428, 0.2871300>,
    <-0.6681765, -0.6796766, 0.3026215>,
    <-0.6808263, -0.6805911, 0.2706869>,
    <-0.7021630, -0.6579504, 0.2721552>,
    <-0.6466026, -0.7122125, 0.2732369>,
    <-0.6423442, -0.7135206, 0.2797898>,
    <-0.6164811, -0.7356256, 0.2807242>,
    <-0.6189107, -0.7371735, 0.2711545>,
    <-0.6470912, -0.7055535, 0.2889069>,
    <-0.6212644, -0.7386443, 0.2616012>,
    <-0.6279750, -0.7480859, 0.2145106>,
    <-0.6587552, -0.7024869, 0.2693579>,
    <-0.7134308, -0.6537275, 0.2523031>,
    <-0.6927946, -0.6806038, 0.2383572>,
    <-0.7003741, -0.6666628, 0.2550231>,
    <-0.7174883, -0.6452539, 0.2624078>,
    <-0.6741018, -0.6976469, 0.2426429>,
    <-0.6913003, -0.6729717, 0.2630837>,
    <-0.6679590, -0.7181183, 0.1952864>,
    <-0.6907022, -0.6904901, 0.2148345>,
    <-0.7134299, -0.6470625, 0.2689385>,
    <-0.7121217, -0.6619457, 0.2339030>,
    <-0.6797923, 0.7039548, 0.2057425>,
    <-0.7047209, 0.6864872, 0.1791751>,
    <-0.7051118, 0.6716365, 0.2274243>,
    <-0.6858886, 0.6739527, 0.2744895>,
    <-0.6874810, 0.6794500, 0.2563542>,
    <-0.6743690, 0.7166755, 0.1777716>,
    <-0.6276739, 0.7483384, 0.2145112>,
    <-0.6619457, 0.7121217, 0.2339030>,
    <-0.6904901, 0.6907022, 0.2148345>,
    <-0.7284859, 0.6612122, 0.1791835>,
    <-0.7189733, 0.6473988, 0.2528878>,
    <-0.7181183, 0.6679590, 0.1952864>,
    <-0.6873915, 0.6303977, 0.3606823>,
    <-0.6688246, 0.6168567, 0.4149234>,
    <-0.6537275, 0.7134308, 0.2523031>,
    <-0.6806038, 0.6927946, 0.2383572>,
    <-0.6666628, 0.7003741, 0.2550231>,
    <-0.6452539, 0.7174883, 0.2624078>,
    <-0.6185014, 0.7375169, 0.2711545>,
    <-0.6173990, 0.7348555, 0.2807238>,
    <-0.6976469, 0.6741018, 0.2426429>,
    <-0.6729717, 0.6913003, 0.2630837>,
    <-0.6470625, 0.7134299, 0.2689385>,
    <-0.6195410, 0.7400902, 0.2616015>,
    <-0.7038965, -0.6797363, 0.2061271>,
    <-0.6864543, -0.7046871, 0.1794341>,
    <-0.6714754, -0.7049426, 0.2284221>,
    <-0.6736329, -0.6855695, 0.2760672>,
    <-0.6790165, -0.6872091, 0.2582252>,
    <-0.7165962, -0.6743532, 0.1781507>,
    <-0.6611686, -0.7284376, 0.1795404>,
    <-0.6471335, -0.7186723, 0.2544176>,
    <-0.6311426, -0.7500350, 0.1977536>,
    <-0.6198432, -0.7289902, 0.2904612>,
    <-0.6295798, -0.6864996, 0.3637962>,
    <-0.5803878, -0.6778548, 0.4512902>,
    <-0.4471910, -0.5322406, 0.7188464>,
    <-0.6154454, -0.6675080, 0.4191181>,
    <-0.7232415, -0.6627402, 0.1941578>,
    <-0.6809696, -0.6793596, 0.2734062>,
    <-0.6699291, -0.6375634, 0.3804049>,
    <-0.7051907, -0.6239717, 0.3366978>,
    <-0.6055546, -0.6384571, 0.4750539>,
    <-0.5960364, -0.5800133, 0.5552704>,
    <-0.4825902, -0.5239814, 0.7018192>,
    <-0.4913113, -0.4908262, 0.7195157>,
    <-0.6305812, -0.5604806, 0.5368694>,
    <-0.4987172, -0.4581453, 0.7357880>,
    <-0.3383233, 0.3609277, 0.8690619>,
    <-0.3946308, 0.3848353, 0.8343670>,
    <-0.3122183, 0.2977989, 0.9021284>,
    <-0.2603420, 0.2649443, 0.9284538>,
    <-0.2423486, 0.2521361, 0.9368535>,
    <-0.2998785, 0.3310044, 0.8947117>,
    <-0.4510768, 0.5382803, 0.7118877>,
    <-0.4628803, 0.5037499, 0.7293681>,
    <-0.4954662, 0.4959556, 0.7131208>,
    <-0.4017616, 0.3553032, 0.8440067>,
    <-0.3048521, 0.2664994, 0.9143540>,
    <-0.5284863, 0.4868418, 0.6954763>,
    <-0.2418421, 0.2226969, 0.9444144>,
    <-0.2248279, 0.2184829, 0.9495881>,
    <-0.6628892, 0.7234041, 0.1930402>,
    <-0.6798093, 0.6816331, 0.2706208>,
    <-0.6387794, 0.6712067, 0.3760883>,
    <-0.6249554, 0.7060572, 0.3330375>,
    <-0.6108977, 0.7375549, 0.2877792>,
    <-0.6291590, 0.7518645, 0.1971260>,
    <-0.6404225, 0.6076420, 0.4697129>,
    <-0.5827691, 0.5988682, 0.5493059>,
    <-0.5631733, 0.6333415, 0.5307677>,
    <-0.5686501, 0.6912930, 0.4458150>,
    <-0.3547272, -0.3322946, 0.8739273>,
    <-0.3791248, -0.3887746, 0.8397135>,
    <-0.2922196, -0.3063684, 0.9059504>,
    <-0.2591166, -0.2544549, 0.9317249>,
    <-0.2462223, -0.2367631, 0.9398499>,
    <-0.3247098, -0.2941093, 0.8989234>,
    <-0.3501789, -0.3961992, 0.8487644>,
    <-0.2617083, -0.2996583, 0.9174495>,
    <-0.2941989, -0.3619136, 0.8845708>,
    <-0.2334976, -0.2876392, 0.9288394>,
    <-0.2180100, -0.2370479, 0.9467206>,
    <-0.2106175, -0.2562434, 0.9433873>,
    <-0.2133729, -0.2201147, 0.9518516>,
    <-0.2946479, -0.2693815, 0.9168513>,
    <-0.2474549, -0.2394346, 0.9388488>,
    <-0.2377450, -0.2253033, 0.9448364>,
    <-0.2567345, -0.2327204, 0.9380451>,
    <-0.2215542, -0.2232440, 0.9492501>,
    <-0.2252617, -0.2176088, 0.9496860>,
    <-0.2366470, -0.2170241, 0.9470474>,
    <-0.2750268, 0.3010039, 0.9131029>,
    <-0.2448910, 0.2534963, 0.9358248>,
    <-0.2317253, 0.2447367, 0.9414921>,
    <-0.2395593, 0.2643333, 0.9342051>,
    <-0.2480193, 0.2863938, 0.9254540>,
    <-0.3106121, 0.3589221, 0.8801676>,
    <-0.2277041, 0.2266141, 0.9469936>,
    <-0.2248318, 0.2329480, 0.9461427>,
    <-0.2262813, 0.2469602, 0.9422354>,
    <-0.2213717, 0.2595208, 0.9400231>,
    <0.2262984, 0.3204044, -0.9198533>,
    <0.2184256, 0.3032146, -0.9275512>,
    <0.2175914, 0.2964215, -0.9299399>,
    <0.2219602, 0.3072787, -0.9253721>,
    <0.2332145, 0.3262825, -0.9160517>,
    <0.2307203, 0.3281929, -0.9160009>,
    <0.2325624, 0.3321440, -0.9141089>,
    <0.2298992, 0.3283454, -0.9161526>,
    <0.2298992, 0.3283454, -0.9161526>,
    <0.2124947, 0.3034941, -0.9288365>,
    <0.2003191, 0.2652930, -0.9431288>,
    <0.2167913, 0.2802445, -0.9351281>,
    <0.2124947, 0.3034941, -0.9288365>,
    <0.1724359, 0.2462910, -0.9537330>,
    <0.1724359, 0.2462910, -0.9537330>,
    <0.1684780, 0.1972113, -0.9657758>,
    <0.2279477, 0.2995679, -0.9264442>,
    <0.2441401, 0.3299442, -0.9118840>,
    <0.2237915, -0.3176301, -0.9214274>,
    <0.2135925, -0.2977281, -0.9304495>,
    <0.2123390, -0.2928163, -0.9322933>,
    <0.2184313, -0.3056050, -0.9267650>,
    <0.2160273, -0.3084851, -0.9263742>,
    <0.2304262, -0.3290478, -0.9157682>,
    <0.2304262, -0.3290478, -0.9157682>,
    <0.2325274, -0.3320474, -0.9141529>,
    <0.2285721, -0.3247445, -0.9177668>,
    <0.2284894, -0.3188081, -0.9198663>,
    <0.2159900, -0.2880398, -0.9329423>,
    <0.2106152, -0.2784900, -0.9370617>,
    <0.2391255, -0.3206986, -0.9164995>,
    <0.2007380, -0.2712287, -0.9413497>,
    <0.1651187, -0.2003438, -0.9657112>,
    <0.1813057, -0.2588986, -0.9487359>,
    <0.1813057, -0.2588986, -0.9487359>,
    <0.2160273, -0.3084851, -0.9263742>,
    <-0.2674954, 0.3612460, 0.8932791>,
    <-0.2801661, 0.3654022, 0.8876870>,
    <-0.2828199, 0.3617747, 0.8883310>,
    <-0.2676101, 0.3547287, 0.8958529>,
    <-0.2396364, 0.3362529, 0.9107735>,
    <-0.2242365, 0.3195309, 0.9206617>,
    <-0.2157824, 0.3081657, 0.9265376>,
    <-0.2792877, 0.3736940, 0.8845062>,
    <-0.2792877, 0.3736940, 0.8845062>,
    <-0.2728327, 0.3650571, 0.8901099>,
    <-0.2629834, 0.3320587, 0.9058569>,
    <-0.2897876, 0.3553052, 0.8886965>,
    <-0.2728327, 0.3650571, 0.8901099>,
    <-0.2352782, 0.3148082, 0.9195324>,
    <-0.2352782, 0.3148082, 0.9195324>,
    <-0.2734309, 0.3128107, 0.9096071>,
    <-0.2928693, 0.3677023, 0.8826226>,
    <-0.2639734, 0.3589021, 0.8952694>,
    <0.2209805, 0.3201607, -0.9212300>,
    <0.1998277, 0.2993110, -0.9329962>,
    <0.1967526, 0.3087789, -0.9305611>,
    <0.2082067, 0.3152058, -0.9259024>,
    <0.2159764, 0.3084124, -0.9264103>,
    <0.2304146, 0.3290450, -0.9157721>,
    <0.2304146, 0.3290450, -0.9157721>,
    <0.2325738, 0.3321384, -0.9141081>,
    <0.2243224, 0.3209396, -0.9201507>,
    <0.2056311, 0.2978662, -0.9321972>,
    <0.1798489, 0.2943066, -0.9386362>,
    <0.1803165, 0.3105157, -0.9333091>,
    <0.1872102, 0.2792955, -0.9417783>,
    <0.2134311, 0.3744908, -0.9023324>,
    <0.1685042, 0.3215750, -0.9317703>,
    <0.1676670, 0.3239090, -0.9311126>,
    <0.1819272, 0.3027636, -0.9355409>,
    <0.1596453, 0.3092873, -0.9374725>,
    <0.1509319, 0.2925278, -0.9442706>,
    <0.1812240, 0.2587655, -0.9487878>,
    <0.1812240, 0.2587655, -0.9487878>,
    <0.2159764, 0.3084124, -0.9264103>,
    <0.2273306, 0.3250453, -0.9179686>,
    <0.2288749, 0.3268667, -0.9169375>,
    <0.2185263, 0.3120864, -0.9245801>,
    <0.2121543, 0.3044733, -0.9285939>,
    <0.2325738, 0.3321384, -0.9141081>,
    <0.2325762, 0.3321489, -0.9141036>,
    <0.2325762, 0.3321489, -0.9141036>,
    <0.2325783, 0.3321572, -0.9141001>,
    <0.2275582, 0.3248911, -0.9179668>,
    <0.2160320, 0.3091459, -0.9261528>,
    <0.2325783, 0.3321572, -0.9141001>,
    <0.2325780, 0.3321615, -0.9140986>,
    <0.2325780, 0.3321615, -0.9140986>,
    <0.2325624, 0.3321440, -0.9141089>,
    <0.2297143, 0.3290179, -0.9159577>,
    <0.2266546, 0.3279378, -0.9171066>,
    <0.2013544, 0.2908897, -0.9353286>,
    <0.2207634, 0.3283575, -0.9183926>,
    <0.2350350, 0.3360904, -0.9120317>,
    <0.2446695, 0.3450246, -0.9061428>,
    <0.2502761, 0.3587742, -0.8992458>,
    <0.2420543, 0.3514296, -0.9043821>,
    <0.2325624, 0.3321440, -0.9141089>,
    <0.2616323, 0.3627257, -0.8944152>,
    <0.2647198, 0.3803854, -0.8861323>,
    <0.3044554, 0.4178141, -0.8560013>,
    <0.2992393, 0.4333289, -0.8501070>,
    <0.2554217, 0.3793439, -0.8893020>,
    <0.2844527, 0.4348939, -0.8543735>,
    <0.2355369, -0.3349368, -0.9123266>,
    <0.2428787, -0.3491773, -0.9050332>,
    <0.2522022, -0.3569297, -0.8994416>,
    <0.2465746, -0.3441636, -0.9059539>,
    <0.2325274, -0.3320474, -0.9141529>,
    <0.2318060, -0.3315166, -0.9145287>,
    <0.2320315, -0.3340966, -0.9135321>,
    <0.2550987, -0.3718952, -0.8925349>,
    <0.2688292, -0.3787630, -0.8855899>,
    <0.2285709, -0.3357965, -0.9137812>,
    <0.2177354, -0.3702613, -0.9030492>,
    <0.2929280, -0.4309014, -0.8535322>,
    <0.3099191, -0.4326161, -0.8466366>,
    <0.2699419, -0.3669750, -0.8902026>,
    <0.3198767, -0.4218619, -0.8483581>,
    <0.2302465, -0.3287897, -0.9159060>,
    <0.2306872, -0.3294364, -0.9155627>,
    <0.2255922, -0.3221656, -0.9194115>,
    <0.2250848, -0.3220225, -0.9195860>,
    <0.2325274, -0.3320474, -0.9141529>,
    <0.2324705, -0.3319671, -0.9141965>,
    <0.2324705, -0.3319671, -0.9141965>,
    <0.2324514, -0.3319478, -0.9142084>,
    <0.2297228, -0.3284011, -0.9161769>,
    <0.2210162, -0.3171857, -0.9222500>,
    <0.2324514, -0.3319478, -0.9142084>,
    <0.2324478, -0.3319618, -0.9142043>,
    <0.2324478, -0.3319618, -0.9142043>,
    <0.2324534, -0.3320093, -0.9141856>,
    <0.2269838, -0.3250829, -0.9180411>,
    <0.2131596, -0.3107804, -0.9262713>,
    <0.2154487, -0.3109654, -0.9256794>,
    <0.1989295, -0.3007596, -0.9327222>,
    <0.3280287, -0.4732344, -0.8175857>,
    <0.3412432, -0.4729096, -0.8123482>,
    <0.3496579, -0.4712265, -0.8097438>,
    <0.3426788, -0.4702132, -0.8133086>,
    <0.3175576, -0.4765392, -0.8197972>,
    <0.3459885, -0.4907553, -0.7996570>,
    <0.3675029, -0.4784243, -0.7975285>,
    <0.3631452, -0.4654150, -0.8071644>,
    <0.3740370, -0.4989638, -0.7817490>,
    <0.3508612, -0.4535085, -0.8192841>,
    <0.2211366, -0.3230933, -0.9201681>,
    <0.2038193, -0.3165895, -0.9264064>,
    <0.1931711, -0.3139350, -0.9295858>,
    <0.2014230, -0.3086117, -0.9296169>,
    <0.2324534, -0.3320093, -0.9141856>,
    <0.2298315, -0.3283286, -0.9161757>,
    <0.2298315, -0.3283286, -0.9161757>,
    <0.2124803, -0.3036273, -0.9287963>,
    <0.1761477, -0.3066555, -0.9353793>,
    <0.1739462, -0.3130715, -0.9336643>,
    <0.2124803, -0.3036273, -0.9287963>,
    <0.1725384, -0.2466629, -0.9536183>,
    <0.1725384, -0.2466629, -0.9536183>,
    <0.1519910, -0.3038916, -0.9405045>,
    <0.1578213, -0.3153746, -0.9357517>,
    <0.1602564, -0.3190233, -0.9340996>,
    <0.1771032, -0.3009290, -0.9370572>,
    <0.1560881, -0.3060462, -0.9391338>,
    <-0.2091530, 0.3217439, 0.9234370>,
    <-0.2004454, 0.3073951, 0.9302311>,
    <-0.2125498, 0.3195711, 0.9234159>,
    <-0.2243263, 0.3350759, 0.9150966>,
    <-0.2527701, 0.3718636, 0.8932104>,
    <-0.2197964, 0.3393672, 0.9146144>,
    <-0.1651033, 0.2984974, 0.9400214>,
    <-0.1921521, 0.3041695, 0.9330372>,
    <-0.1921521, 0.3041695, 0.9330372>,
    <-0.1810121, 0.2865353, 0.9408146>,
    <-0.1983959, 0.2995377, 0.9332289>,
    <-0.2185421, 0.3216706, 0.9212857>,
    <-0.1810121, 0.2865353, 0.9408146>,
    <-0.1688859, 0.2673400, 0.9486869>,
    <-0.1688859, 0.2673400, 0.9486869>,
    <-0.2157824, 0.3081657, 0.9265376>,
    <-0.2362658, 0.3422688, 0.9094122>,
    <-0.2860933, 0.4013522, 0.8700960>,
    <0.3339612, 0.4686898, -0.8178018>,
    <0.3281461, 0.4813646, -0.8127781>,
    <0.3213656, 0.4844753, -0.8136386>,
    <0.3220601, 0.4752509, -0.8187881>,
    <0.3467870, 0.4694623, -0.8120000>,
    <0.3455471, 0.4959212, -0.7966551>,
    <0.3232888, 0.5071935, -0.7988987>,
    <0.3099505, 0.4931284, -0.8128684>,
    <0.3415152, 0.5227762, -0.7810713>,
    <0.3459281, 0.5985588, -0.7225380>,
    <0.3157537, 0.5449649, -0.7767322>,
    <0.2963681, 0.5104877, -0.8071978>,
    <0.3000996, 0.4709432, -0.8295497>,
    <0.2729887, 0.4694906, -0.8396760>,
    <0.3621850, 0.4727425, -0.8033284>,
    <0.3769090, 0.4821087, -0.7908924>,
    <0.3714880, 0.5034428, -0.7800911>,
    <0.3650786, 0.5114434, -0.7779095>,
    <0.3864755, 0.4987304, -0.7758252>,
    <0.3727512, 0.5172075, -0.7704239>,
    <0.4076777, 0.5392578, -0.7368853>,
    <0.3963934, 0.5657056, -0.7230833>,
    <0.3634060, 0.5376818, -0.7608116>,
    <0.3841704, 0.5926863, -0.7079096>,
    <0.4061249, -0.6018561, -0.6876277>,
    <0.4248225, -0.5956227, -0.6817326>,
    <0.4389513, -0.5958077, -0.6725585>,
    <0.4321353, -0.6005107, -0.6727897>,
    <0.3960145, -0.5659705, -0.7230836>,
    <0.3673023, -0.5675285, -0.7368856>,
    <0.3454031, -0.5988619, -0.7225380>,
    <0.4101107, -0.6280933, -0.6612927>,
    <0.4344446, -0.6208363, -0.6525490>,
    <0.4545382, -0.5930938, -0.6645561>,
    <0.4603077, -0.5895854, -0.6637062>,
    <0.4582505, -0.6120672, -0.6444999>,
    <0.4563532, -0.5896483, -0.6663757>,
    <0.4255487, -0.5637126, -0.7079099>,
    <0.3130624, -0.4905971, -0.8132075>,
    <0.3203124, -0.5131330, -0.7963005>,
    <0.3434958, -0.5174619, -0.7837371>,
    <0.3522106, -0.5127000, -0.7829984>,
    <0.2697954, -0.4706754, -0.8400447>,
    <0.2938038, -0.5117466, -0.8073381>,
    <0.3355940, -0.5323693, -0.7771483>,
    <0.3578971, -0.5262400, -0.7713502>,
    <0.3140484, -0.5458918, -0.7767727>,
    <0.3800992, -0.5241824, -0.7620744>,
    <-0.2700515, -0.3910947, 0.8798393>,
    <-0.2537058, -0.3779309, 0.8903941>,
    <-0.2515368, -0.3868112, 0.8871901>,
    <-0.2586160, -0.3870738, 0.8850377>,
    <-0.2644344, -0.3844042, 0.8844817>,
    <-0.2726694, -0.3902752, 0.8793956>,
    <-0.2773252, -0.3960610, 0.8753436>,
    <-0.2747092, -0.3926431, 0.8777051>,
    <-0.2747092, -0.3926431, 0.8777051>,
    <-0.2530493, -0.3616845, 0.8973017>,
    <-0.2188117, -0.3371851, 0.9156569>,
    <-0.2372362, -0.3832445, 0.8926604>,
    <-0.2530493, -0.3616845, 0.8973017>,
    <-0.2100837, -0.3002737, 0.9304303>,
    <-0.2100837, -0.3002737, 0.9304303>,
    <-0.1719399, -0.2790653, 0.9447535>,
    <-0.1862749, -0.3127284, 0.9313982>,
    <-0.2190371, -0.3844636, 0.8967778>,
    <-0.2547895, -0.4066470, 0.8773372>,
    <-0.2503702, -0.4436414, 0.8605214>,
    <-0.3102624, -0.5212573, 0.7950019>,
    <-0.2643743, -0.3969179, 0.8789553>,
    <-0.2692351, -0.3813718, 0.8843461>,
    <-0.2756978, -0.3934071, 0.8770528>,
    <-0.2709178, -0.3866744, 0.8815251>,
    <-0.2692347, -0.3836874, 0.8833440>,
    <-0.2771093, -0.3938424, 0.8764124>,
    <-0.2495920, -0.3399652, 0.9067125>,
    <-0.2190003, -0.2411310, 0.9454600>,
    <-0.2750034, -0.3922759, 0.8777772>,
    <-0.2750034, -0.3922759, 0.8777772>,
    <-0.2771333, -0.3953139, 0.8757420>,
    <-0.2751013, -0.3930211, 0.8774131>,
    <-0.2686656, -0.3855963, 0.8826858>,
    <-0.2771333, -0.3953139, 0.8757420>,
    <-0.2768221, -0.3948700, 0.8760406>,
    <-0.2768221, -0.3948700, 0.8760406>,
    <-0.2773252, -0.3960610, 0.8753436>,
    <-0.2669155, -0.3856977, 0.8831723>,
    <-0.2938233, -0.4341207, 0.8515909>,
    <-0.2476705, -0.3163515, 0.9157407>,
    <-0.2870026, -0.3986421, 0.8710419>,
    <-0.2962989, -0.3993507, 0.8675978>,
    <-0.2859583, -0.3648371, 0.8860709>,
    <-0.2190003, -0.2411310, 0.9454600>,
    <-0.3221267, -0.4715573, 0.8208947>,
    <-0.3232372, -0.4473441, 0.8339071>,
    <-0.3634720, -0.5524217, 0.7501456>,
    <-0.3686408, -0.5235447, 0.7681177>,
    <-0.3259791, -0.4232731, 0.8453268>,
    <-0.3746509, -0.4952896, 0.7837889>,
    <-0.3974343, 0.5868319, 0.7054603>,
    <-0.4147977, 0.5791009, 0.7018440>,
    <-0.4303784, 0.5862398, 0.6863653>,
    <-0.4231598, 0.5925860, 0.6854032>,
    <-0.4326299, 0.6171773, 0.6572089>,
    <-0.4028981, 0.6144686, 0.6783078>,
    <-0.2922077, 0.5220086, 0.8013250>,
    <-0.3393520, 0.5211527, 0.7830965>,
    <-0.3689033, 0.5287413, 0.7644233>,
    <-0.4329566, 0.5662978, 0.7013240>,
    <-0.4499743, 0.5798481, 0.6791902>,
    <-0.3931890, 0.5298191, 0.7514613>,
    <-0.4534563, 0.5924084, 0.6659052>,
    <-0.4587591, 0.6126889, 0.6435467>,
    <-0.2269568, 0.3573303, 0.9059833>,
    <-0.2750562, 0.4052781, 0.8718336>,
    <-0.2804109, 0.4209964, 0.8626307>,
    <-0.2575415, 0.4034210, 0.8780227>,
    <-0.2351540, 0.3921059, 0.8893568>,
    <-0.1951066, 0.3366867, 0.9211816>,
    <-0.1651033, 0.2984974, 0.9400214>,
    <-0.3278561, 0.4594537, 0.8254772>,
    <-0.3140704, 0.4607657, 0.8300933>,
    <-0.2908841, 0.4511631, 0.8437051>,
    <-0.2623507, 0.4376352, 0.8600276>,
    <0.4266569, 0.5874798, -0.6876274>,
    <0.4144044, 0.6029178, -0.6817324>,
    <0.4097459, 0.6162578, -0.6725582>,
    <0.4164966, 0.6114615, -0.6727893>,
    <0.4499486, 0.6001987, -0.6612925>,
    <0.4348064, 0.6205831, -0.6525488>,
    <0.4018647, 0.6299766, -0.6645557>,
    <0.3965946, 0.6341981, -0.6637058>,
    <0.4184241, 0.6399542, -0.6444997>,
    <0.4062148, 0.7029460, -0.5838292>,
    <0.3862194, 0.6671268, -0.6370059>,
    <0.3788796, 0.6555293, -0.6532470>,
    <0.3980062, 0.6305036, -0.6663754>,
    <0.3710496, 0.6430360, -0.6699454>,
    <0.4678290, 0.6094807, -0.6400541>,
    <0.4720558, 0.6035362, -0.6425787>,
    <0.4593579, 0.6225700, -0.6335589>,
    <0.4553133, 0.6376507, -0.6213625>,
    <0.4702954, 0.6065621, -0.6410184>,
    <0.4516112, 0.6266744, -0.6350800>,
    <0.4815667, 0.6368791, -0.6020619>,
    <0.4656216, 0.6645518, -0.5844377>,
    <0.4398759, 0.6512140, -0.6184088>,
    <0.4485000, 0.6921624, -0.5654723>,
    <0.4670413, -0.6923956, -0.5499643>,
    <0.4851607, -0.6804217, -0.5492225>,
    <0.5009568, -0.6799097, -0.5355046>,
    <0.4951608, -0.6880364, -0.5304919>,
    <0.4652224, -0.6648313, -0.5844378>,
    <0.4337651, -0.6703502, -0.6020619>,
    <0.4056615, -0.7032651, -0.5838295>,
    <0.4666232, -0.7147850, -0.5209080>,
    <0.4910039, -0.7016077, -0.5163931>,
    <0.5146328, -0.6714411, -0.5332165>,
    <0.5231280, -0.6697430, -0.5270496>,
    <0.5148293, -0.6874125, -0.5122644>,
    <0.5215535, -0.6735474, -0.5237517>,
    <0.4970237, -0.6581856, -0.5654725>,
    <0.4127175, -0.6480702, -0.6400541>,
    <0.4056860, -0.6500090, -0.6425786>,
    <0.4279147, -0.6445868, -0.6335589>,
    <0.4434693, -0.6459440, -0.6213626>,
    <0.3713606, -0.6428564, -0.6699455>,
    <0.3782651, -0.6558839, -0.6532471>,
    <0.4091314, -0.6493897, -0.6410183>,
    <0.4344211, -0.6387111, -0.6350799>,
    <0.3846389, -0.6680390, -0.6370061>,
    <0.4614945, -0.6360765, -0.6184089>,
    <-0.4151693, -0.5720729, 0.7073663>,
    <-0.4012162, -0.5857401, 0.7042259>,
    <-0.4029342, -0.6035163, 0.6880495>,
    <-0.4118156, -0.5992431, 0.6865243>,
    <-0.4325305, -0.6179268, 0.6565697>,
    <-0.4414270, -0.5900135, 0.6760371>,
    <-0.3835957, -0.6005284, 0.7015839>,
    <-0.3906303, -0.6207901, 0.6797262>,
    <-0.3582905, -0.6162916, 0.7012935>,
    <-0.3737182, -0.6443502, 0.6671938>,
    <-0.4015228, -0.6285199, 0.6661397>,
    <-0.3856104, -0.6655478, 0.6390233>,
    <-0.4062401, -0.7029212, 0.5838413>,
    <-0.4189655, -0.6407482, 0.6433581>,
    <-0.4594801, -0.5986424, 0.6561290>,
    <-0.4518946, -0.6327778, 0.6287953>,
    <-0.4575092, -0.6200155, 0.6373901>,
    <-0.4681329, -0.5984858, 0.6501279>,
    <-0.4396067, -0.6506324, 0.6192119>,
    <-0.4523166, -0.6276064, 0.6336559>,
    <-0.4478175, -0.6909858, 0.5674488>,
    <-0.4656381, -0.6645297, 0.5844497>,
    <-0.4707083, -0.6071606, 0.6401482>,
    <-0.4823644, -0.6379483, 0.6002888>,
    <-0.4670816, 0.6923598, 0.5499752>,
    <-0.4941301, 0.6866528, 0.5332385>,
    <-0.5009292, 0.6799217, 0.5355151>,
    <-0.4861452, 0.6817300, 0.5467240>,
    <-0.4909807, 0.7016156, 0.5164044>,
    <-0.4659588, 0.7137195, 0.5229597>,
    <-0.4056277, 0.7032751, 0.5838410>,
    <-0.4344972, 0.6714657, 0.6002882>,
    <-0.4651963, 0.6648395, 0.5844491>,
    <-0.5202887, 0.6721011, 0.5268584>,
    <-0.5230423, 0.6698015, 0.5270605>,
    <-0.4961519, 0.6571421, 0.5674483>,
    <-0.5156905, 0.6728709, 0.5303849>,
    <-0.5154613, 0.6883819, 0.5103234>,
    <-0.4034008, 0.6334881, 0.6602732>,
    <-0.4392262, 0.6397575, 0.6307065>,
    <-0.4254809, 0.6409727, 0.6388427>,
    <-0.4012760, 0.6431270, 0.6522003>,
    <-0.3708971, 0.6455830, 0.6675761>,
    <-0.3535732, 0.6173570, 0.7027491>,
    <-0.4608323, 0.6353287, 0.6196702>,
    <-0.4348936, 0.6394542, 0.6340078>,
    <-0.4093359, 0.6496539, 0.6406199>,
    <-0.3835244, 0.6666666, 0.6391124>,
    <0.4909015, 0.6756885, -0.5499643>,
    <0.4734525, 0.6886199, -0.5492224>,
    <0.4675688, 0.7032883, -0.5355044>,
    <0.4771878, 0.7006214, -0.5304917>,
    <0.5120836, 0.6829532, -0.5209082>,
    <0.4913624, 0.7013566, -0.5163932>,
    <0.4549335, 0.7132431, -0.5332164>,
    <0.4504324, 0.7206453, -0.5270493>,
    <0.4698745, 0.7188902, -0.5122645>,
    <0.4463435, 0.7724931, -0.4516988>,
    <0.4327187, 0.7473547, -0.5041979>,
    <0.4282672, 0.7410797, -0.5170958>,
    <0.4545458, 0.7204670, -0.5237513>,
    <0.4236093, 0.7344404, -0.5302381>,
    <0.5276364, 0.6874643, -0.4989916>,
    <0.5311125, 0.6789009, -0.5069646>,
    <0.5146844, 0.6976231, -0.4984195>,
    <0.5089761, 0.7130860, -0.4821325>,
    <0.5269088, 0.6794208, -0.5106412>,
    <0.5047869, 0.7005312, -0.5044267>,
    <0.5317260, 0.7031836, -0.4720172>,
    <0.5117492, 0.7304568, -0.4522671>,
    <0.4896303, 0.7251833, -0.4841192>,
    <0.4904996, 0.7571678, -0.4314013>,
    <0.5074003, -0.7523545, -0.4201281>,
    <0.5259373, -0.7376983, -0.4233097>,
    <0.5419502, -0.7354631, -0.4066743>,
    <0.5358887, -0.7445495, -0.3980822>,
    <0.5113765, -0.7307181, -0.4522667>,
    <0.4789156, -0.7401622, -0.4720168>,
    <0.4458272, -0.7727917, -0.4516981>,
    <0.5032762, -0.7709723, -0.3902753>,
    <0.5282550, -0.7547617, -0.3889491>,
    <0.5552338, -0.7243243, -0.4087416>,
    <0.5646114, -0.7226083, -0.3988124>,
    <0.5526314, -0.7376990, -0.3878128>,
    <0.5635303, -0.7274938, -0.3913903>,
    <0.5437444, -0.7198856, -0.4314009>,
    <0.4655430, -0.7309429, -0.4989912>,
    <0.4563072, -0.7312805, -0.5069641>,
    <0.4795190, -0.7222464, -0.4984191>,
    <0.4960017, -0.7221709, -0.4821322>,
    <0.4242394, -0.7340765, -0.5302383>,
    <0.4276603, -0.7414302, -0.5170957>,
    <0.4582335, -0.7275081, -0.5106407>,
    <0.4856368, -0.7139405, -0.5044263>,
    <0.4308690, -0.7484229, -0.5041974>,
    <0.5139861, -0.7081294, -0.4841189>,
    <-0.4908540, -0.6757139, 0.5499756>,
    <-0.4762400, -0.6991792, 0.5332391>,
    <-0.4675895, -0.7032661, 0.5355156>,
    <-0.4743451, -0.6899923, 0.5467242>,
    <-0.4913777, -0.7013376, 0.5164044>,
    <-0.5113096, -0.6819644, 0.5229598>,
    <-0.4536191, -0.7187832, 0.5268591>,
    <-0.4505164, -0.7205843, 0.5270609>,
    <-0.4232309, -0.7336052, 0.5316944>,
    <-0.4282963, -0.7410541, 0.5171084>,
    <-0.4559153, -0.7147258, 0.5303850>,
    <-0.4331177, -0.7480717, 0.5027900>,
    <-0.4463664, -0.7724680, 0.4517192>,
    <-0.4705693, -0.7198157, 0.5103232>,
    <-0.5265482, -0.6859958, 0.5021521>,
    <-0.5081412, -0.7117525, 0.4849752>,
    <-0.5147027, -0.6975998, 0.4984331>,
    <-0.5310809, -0.6789164, 0.5069769>,
    <-0.4897071, -0.7251206, 0.4841354>,
    <-0.5056921, -0.7017420, 0.5018303>,
    <-0.4899843, -0.7562571, 0.4335787>,
    <-0.5117635, -0.7304342, 0.4522875>,
    <-0.5279227, -0.6807957, 0.5077547>,
    <-0.5323621, -0.7040378, 0.4700227>,
    <-0.5074360, 0.7523164, 0.4201532>,
    <-0.5351112, 0.7435141, 0.4010521>,
    <-0.5419221, 0.7354703, 0.4066988>,
    <-0.5267076, 0.7387079, 0.4205827>,
    <-0.5282318, 0.7547659, 0.3889724>,
    <-0.5027823, 0.7701695, 0.3924907>,
    <-0.4457936, 0.7727984, 0.4517196>,
    <-0.4795004, 0.7410516, 0.4700234>,
    <-0.5113499, 0.7307233, 0.4522884>,
    <-0.5625702, 0.7264289, 0.3947351>,
    <-0.5645289, 0.7226598, 0.3988357>,
    <-0.5430644, 0.7190895, 0.4335796>,
    <-0.5560466, 0.7254293, 0.4056656>,
    <-0.5531004, 0.7384423, 0.3857238>,
    <-0.4645351, 0.7294178, 0.5021523>,
    <-0.4950339, 0.7209301, 0.4849756>,
    <-0.4794905, 0.7222553, 0.4984336>,
    <-0.4563322, 0.7312557, 0.5069774>,
    <-0.4276236, 0.7414425, 0.5171084>,
    <-0.4237054, 0.7333315, 0.5316942>,
    <-0.5139006, 0.7081798, 0.4841359>,
    <-0.4864646, 0.7152048, 0.5018310>,
    <-0.4591782, 0.7289307, 0.5077553>,
    <-0.4312902, 0.7491266, 0.5027903>,
    <0.5334408, 0.7341206, -0.4201284>,
    <0.5133285, 0.7465270, -0.4233099>,
    <0.5057513, 0.7608096, -0.4066747>,
    <0.5163629, 0.7582214, -0.3980826>,
    <0.5523464, 0.7366129, -0.3902754>,
    <0.5285702, 0.7545410, -0.3889492>,
    <0.4907410, 0.7694826, -0.4087418>,
    <0.4859211, 0.7777076, -0.3988127>,
    <0.5041992, 0.7716116, -0.3878128>,
    <0.4723833, 0.8176958, -0.3289795>,
    <0.4635757, 0.8006571, -0.3795336>,
    <0.4607676, 0.7974528, -0.3895668>,
    <0.4908818, 0.7783626, -0.3913908>,
    <0.4578718, 0.7941093, -0.3996797>,
    <0.5659200, 0.7374354, -0.3686782>,
    <0.5699167, 0.7284658, -0.3801743>,
    <0.5509712, 0.7468991, -0.3722532>,
    <0.5433064, 0.7614038, -0.3536700>,
    <0.5649554, 0.7284281, -0.3875796>,
    <0.5403955, 0.7500375, -0.3813351>,
    <0.5649306, 0.7471192, -0.3502376>,
    <0.5417118, 0.7733145, -0.3294435>,
    <0.5221612, 0.7736057, -0.3590012>,
    <0.5172168, 0.7985829, -0.3078184>,
    <0.5334251, -0.7909817, -0.2996759>,
    <0.5527507, -0.7753226, -0.3055185>,
    <0.5682879, -0.7711012, -0.2871441>,
    <0.5614663, -0.7799874, -0.2763608>,
    <0.5414016, -0.7735317, -0.3294436>,
    <0.5088447, -0.7863908, -0.3502379>,
    <0.4719535, -0.8179437, -0.3289801>,
    <0.5263455, -0.8062897, -0.2699211>,
    <0.5520376, -0.7886534, -0.2707034>,
    <0.5818854, -0.7589830, -0.2921543>,
    <0.5912055, -0.7564296, -0.2798041>,
    <0.5771034, -0.7702017, -0.2715528>,
    <0.5897742, -0.7611505, -0.2698449>,
    <0.5735238, -0.7591563, -0.3078185>,
    <0.4994065, -0.7840086, -0.3686783>,
    <0.4896109, -0.7846964, -0.3801746>,
    <0.5134123, -0.7731981, -0.3722534>,
    <0.5296638, -0.7709564, -0.3536701>,
    <0.4587830, -0.7935834, -0.3996792>,
    <0.4602306, -0.7977628, -0.3895668>,
    <0.4912722, -0.7800214, -0.3875799>,
    <0.5199785, -0.7643335, -0.3813353>,
    <0.4616015, -0.8017968, -0.3795340>,
    <0.5483619, -0.7552597, -0.3590013>,
    <0.5608375, 0.7717874, -0.2996758>,
    <0.5395130, 0.7845917, -0.3055185>,
    <0.5302322, 0.7977481, -0.2871441>,
    <0.5409156, 0.7943772, -0.2763607>,
    <0.5776437, 0.7703704, -0.2699209>,
    <0.5522837, 0.7884811, -0.2707033>,
    <0.5141942, 0.8063809, -0.2921544>,
    <0.5086071, 0.8142656, -0.2798042>,
    <0.5263718, 0.8057243, -0.2715529>,
    <0.4885140, 0.8457773, -0.2145109>,
    <0.4833643, 0.8349195, -0.2631890>,
    <0.4814740, 0.8334569, -0.2711686>,
    <0.5135328, 0.8145353, -0.2698449>,
    <0.4795429, 0.8319406, -0.2791297>,
    <0.5895907, 0.7683910, -0.2489136>,
    <0.5945695, 0.7600146, -0.2624212>,
    <0.5739518, 0.7781621, -0.2550354>,
    <0.5644462, 0.7912120, -0.2353380>,
    <0.5897055, 0.7603653, -0.2721985>,
    <0.5634554, 0.7821510, -0.2660035>,
    <0.5860489, 0.7751145, -0.2361022>,
    <0.5602942, 0.7999478, -0.2148344>,
    <0.5426447, 0.8041498, -0.2426518>,
    <0.5333141, 0.8236007, -0.1930230>,
    <0.5469425, -0.8109858, -0.2077400>,
    <0.5563987, -0.7800390, -0.2862859>,
    <0.5769951, -0.7827975, -0.2330338>,
    <0.5749943, -0.7986661, -0.1775222>,
    <0.5600731, -0.8001027, -0.2148343>,
    <0.5279288, -0.8158106, -0.2361021>,
    <0.4882076, -0.8459542, -0.2145105>,
    <0.5396739, -0.8229672, -0.1774178>,
    <0.5574262, -0.7861866, -0.2668082>,
    <0.5600512, -0.7304728, -0.3908351>,
    <0.5941916, -0.7604468, -0.2620247>,
    <0.5401443, -0.7058057, -0.4583474>,
    <0.6028223, -0.7778134, -0.1777965>,
    <0.5915273, -0.7828395, -0.1930229>,
    <0.5203993, -0.8168393, -0.2489139>,
    <0.5108252, -0.8186529, -0.2624214>,
    <0.5349300, -0.8054854, -0.2550354>,
    <0.5504441, -0.8010164, -0.2353381>,
    <0.4807101, -0.8312666, -0.2791301>,
    <0.4810578, -0.8336972, -0.2711687>,
    <0.5128184, -0.8142022, -0.2721985>,
    <0.5422683, -0.7969863, -0.2660035>,
    <0.4813793, -0.8360656, -0.2631887>,
    <0.5700582, -0.7849547, -0.2426517>,
    <-0.5333930, -0.7341414, 0.4201527>,
    <-0.5156561, -0.7571372, 0.4010512>,
    <-0.5057679, -0.7607861, 0.4066981>,
    <-0.5140138, -0.7475963, 0.4205824>,
    <-0.5285821, -0.7545206, 0.3889726>,
    <-0.5517610, -0.7358742, 0.3924907>,
    <-0.4902097, -0.7770968, 0.3947340>,
    <-0.4859980, -0.7776482, 0.3988349>,
    <-0.4575983, -0.7934687, 0.4012620>,
    <-0.4607923, -0.7974284, 0.3895875>,
    <-0.4915015, -0.7706244, 0.4056653>,
    <-0.4638715, -0.8012008, 0.3780219>,
    <-0.4724071, -0.8176822, 0.3289792>,
    <-0.5047373, -0.7723064, 0.3857242>,
    <-0.5651251, -0.7363543, 0.3720428>,
    <-0.5427156, -0.7604232, 0.3566739>,
    <-0.5509873, -0.7468785, 0.3722708>,
    <-0.5698840, -0.7284813, 0.3801937>,
    <-0.5222349, -0.7735497, 0.3590147>,
    <-0.5410862, -0.7509566, 0.3785365>,
    <-0.5168689, -0.7979414, 0.3100580>,
    <-0.5417290, -0.7733025, 0.3294434>,
    <-0.5657215, -0.7294853, 0.3844612>,
    <-0.5654029, -0.7477612, 0.3480989>,
    <-0.5334706, 0.7909555, 0.2996641>,
    <-0.5609394, 0.7792918, 0.2793766>,
    <-0.5682731, 0.7711174, 0.2871301>,
    <-0.5533231, 0.7760499, 0.3026220>,
    <-0.5520269, 0.7886662, 0.2706878>,
    <-0.5260251, 0.8057473, 0.2721560>,
    <-0.4719302, 0.8179578, 0.3289786>,
    <-0.5092868, 0.7870545, 0.3480978>,
    <-0.5413849, 0.7735440, 0.3294420>,
    <-0.5891111, 0.7604537, 0.2732366>,
    <-0.5911387, 0.7564871, 0.2797899>,
    <-0.5730406, 0.7586102, 0.3100566>,
    <-0.5824683, 0.7597784, 0.2889074>,
    <-0.5774227, 0.7707327, 0.2693587>,
    <-0.4986628, 0.7828921, 0.3720422>,
    <-0.5289447, 0.7700661, 0.3566732>,
    <-0.5133878, 0.7732064, 0.3722699>,
    <-0.4896371, 0.7846713, 0.3801927>,
    <-0.4601972, 0.7977720, 0.3895874>,
    <-0.4583649, 0.7930260, 0.4012622>,
    <-0.5482845, 0.7553100, 0.3590138>,
    <-0.5206064, 0.7652973, 0.3785354>,
    <-0.4920042, 0.7811033, 0.3844600>,
    <-0.4619247, 0.8023249, 0.3780215>,
    <0.5749505, 0.7912472, -0.2082300>,
    <0.5423536, 0.7891418, -0.2882840>,
    <0.5380760, 0.8096764, -0.2343038>,
    <0.5538073, 0.8134285, -0.1778529>,
    <0.5886651, 0.7885585, -0.1779014>,
    <0.5476359, 0.7922342, -0.2691838>,
    <0.4939548, 0.7746754, -0.3948249>,
    <0.5110841, 0.8179938, -0.2639683>,
    <0.4768524, 0.7467441, -0.4636649>,
    <0.2957973, 0.5145473, -0.8048261>,
    <0.4398708, 0.7416578, -0.5064162>,
    <0.4815730, 0.8216483, -0.3049286>,
    <0.5246843, 0.8324257, -0.1782522>,
    <0.4910898, 0.8479846, -0.1993815>,
    <0.5968502, 0.7778664, -0.1967071>,
    <0.5814856, 0.7309247, -0.3572445>,
    <0.5424523, 0.7352982, -0.4063029>,
    <0.5503214, 0.7841536, -0.2867919>,
    <0.4993875, 0.6280127, -0.5968352>,
    <0.4640544, 0.6438332, -0.6083850>,
    <0.3519059, 0.4546063, -0.8182269>,
    <0.3535192, 0.5043422, -0.7878218>,
    <0.4687381, 0.7119470, -0.5228921>,
    <0.3372218, 0.5336571, -0.7755588>,
    <0.2018955, -0.3175062, -0.9265139>,
    <0.1538422, -0.2288298, -0.9612333>,
    <0.2014932, -0.2715122, -0.9411066>,
    <0.2631110, -0.3650331, -0.8930417>,
    <0.3577482, -0.5114597, -0.7812971>,
    <0.3115287, -0.4933238, -0.8121462>,
    <0.3020679, -0.5209530, -0.7983502>,
    <0.1834228, -0.2916899, -0.9387615>,
    <0.1459035, -0.2177630, -0.9650344>,
    <0.1557162, -0.2003377, -0.9672731>,
    <0.2077826, -0.2494006, -0.9458466>,
    <0.1322639, -0.1854123, -0.9737189>,
    <0.1412579, -0.1683427, -0.9755547>,
    <0.2782525, -0.3403666, -0.8981794>,
    <0.3908458, -0.5057292, -0.7690758>,
    <0.5269737, -0.8271421, -0.1952809>,
    <0.4890379, -0.7978023, -0.3526379>,
    <0.5067393, -0.7632052, -0.4009152>,
    <0.5491026, -0.7862906, -0.2832549>,
    <0.4889541, -0.8494010, -0.1985999>,
    <0.4714307, -0.8287231, -0.3016142>,
    <0.4223632, -0.6885492, -0.5894992>,
    <0.4493176, -0.6607253, -0.6012951>,
    <0.4244747, -0.7550858, -0.4996665>,
    <0.5109178, -0.6873182, -0.5162913>,
    <0.2247004, 0.2919259, -0.9296714>,
    <0.1588563, 0.2176366, -0.9630156>,
    <0.1823417, 0.2763214, -0.9436090>,
    <0.2483146, 0.3651579, -0.8972177>,
    <0.2068004, 0.2660010, -0.9415291>,
    <0.1512128, 0.2066174, -0.9666664>,
    <0.1319002, 0.2099144, -0.9687819>,
    <0.1598835, 0.2750331, -0.9480475>,
    <0.1259603, 0.1832204, -0.9749689>,
    <0.1074845, 0.1861699, -0.9766206>,
    <0.1229743, 0.2291046, -0.9656026>,
    <0.1387742, 0.2559017, -0.9566902>,
    <0.2205720, 0.3714200, -0.9018842>,
    <0.1775349, 0.3256233, -0.9286823>,
    <0.1924438, 0.2535075, -0.9479975>,
    <0.1624710, 0.2119741, -0.9636753>,
    <0.1439189, 0.1961811, -0.9699486>,
    <0.1537868, 0.2145556, -0.9645286>,
    <0.1386034, 0.1870706, -0.9725193>,
    <0.1240614, 0.1725902, -0.9771496>,
    <0.1379769, 0.1644354, -0.9766900>,
    <0.1315018, 0.1878050, -0.9733635>,
    <0.1315018, 0.1878050, -0.9733635>,
    <0.1177696, 0.1681933, -0.9786937>,
    <0.1236497, 0.1767134, -0.9764646>,
    <0.1177696, 0.1681933, -0.9786937>,
    <0.1137852, 0.1625029, -0.9801254>,
    <0.1137852, 0.1625029, -0.9801254>,
    <0.1074845, 0.1861699, -0.9766206>,
    <0.1764922, -0.2738933, -0.9454274>,
    <0.1473237, -0.2309363, -0.9617506>,
    <0.1384687, -0.2073406, -0.9684195>,
    <0.1525736, -0.2231268, -0.9627750>,
    <0.1972427, -0.3234311, -0.9254661>,
    <0.1559068, -0.2543225, -0.9544701>,
    <0.1318290, -0.1994184, -0.9710064>,
    <0.1226839, -0.1799102, -0.9760026>,
    <0.1407253, -0.2272757, -0.9636089>,
    <0.1103861, -0.1911920, -0.9753259>,
    <0.1350713, -0.1928999, -0.9718773>,
    <0.1350713, -0.1928999, -0.9718773>,
    <0.1206410, -0.1722915, -0.9776305>,
    <0.1266970, -0.1808317, -0.9753193>,
    <0.1206410, -0.1722915, -0.9776305>,
    <0.1164673, -0.1663309, -0.9791677>,
    <0.1164673, -0.1663309, -0.9791677>,
    <0.1412579, -0.1683427, -0.9755547>,
    <-0.5607973, -0.7718208, 0.2996650>,
    <-0.5404421, -0.7936436, 0.2793780>,
    <-0.5302524, -0.7977393, 0.2871313>,
    <-0.5400007, -0.7853781, 0.3026227>,
    <-0.5522995, -0.7884754, 0.2706878>,
    <-0.5772436, -0.7698837, 0.2721561>,
    <-0.5131048, -0.8136734, 0.2732383>,
    <-0.5086839, -0.8142220, 0.2797913>,
    <-0.4793753, -0.8315002, 0.2807255>,
    <-0.4814992, -0.8334464, 0.2711560>,
    <-0.5147423, -0.8072004, 0.2889082>,
    <-0.4835618, -0.8353037, 0.2616024>,
    <-0.4885309, -0.8457675, 0.2145109>,
    <-0.5267616, -0.8062060, 0.2693587>,
    <-0.5890735, -0.7676817, 0.2523036>,
    <-0.5640838, -0.7905663, 0.2383577>,
    <-0.5739690, -0.7781534, 0.2550233>,
    <-0.5945408, -0.7600416, 0.2624079>,
    <-0.5427154, -0.8041046, 0.2426432>,
    <-0.5639375, -0.7827908, 0.2630836>,
    <-0.5331113, -0.8231984, 0.1952863>,
    <-0.5603065, -0.7999394, 0.2148341>,
    <-0.5902300, -0.7611181, 0.2689383>,
    <-0.5863572, -0.7755481, 0.2339025>,
    <-0.5472334, 0.8113186, 0.2056640>,
    <-0.5748131, 0.7984396, 0.1791205>,
    <-0.5778008, 0.7839148, 0.2272087>,
    <-0.5584923, 0.7828954, 0.2741552>,
    <-0.5590916, 0.7886073, 0.2559592>,
    <-0.5396747, 0.8229068, 0.1776951>,
    <-0.4881905, 0.8459638, 0.2145116>,
    <-0.5282304, 0.8162485, 0.2339038>,
    <-0.5600606, 0.8001112, 0.2148354>,
    <-0.6026090, 0.7776786, 0.1791043>,
    <-0.5956867, 0.7624820, 0.2525440>,
    <-0.5912184, 0.7825111, 0.1952873>,
    <-0.5676437, 0.7403971, 0.3599899>,
    <-0.5517788, 0.7239820, 0.4139931>,
    <-0.5199096, 0.8161105, 0.2523045>,
    <-0.5499611, 0.8004549, 0.2383585>,
    <-0.5349157, 0.8054984, 0.2550245>,
    <-0.5108602, 0.8186350, 0.2624093>,
    <-0.4810362, 0.8337137, 0.2711560>,
    <-0.4804127, 0.8309013, 0.2807251>,
    <-0.5699913, 0.7850056, 0.2426440>,
    <-0.5427044, 0.7976580, 0.2630849>,
    <-0.5133461, 0.8149523, 0.2689398>,
    <-0.4816132, 0.8364285, 0.2616028>,
    <-0.5751699, -0.7916431, 0.2061086>,
    <-0.5536592, -0.8131852, 0.1794194>,
    <-0.5388697, -0.8108449, 0.2283636>,
    <-0.5443650, -0.7921493, 0.2759823>,
    <-0.5493881, -0.7946971, 0.2581265>,
    <-0.5886125, -0.7885453, 0.1781338>,
    <-0.5246344, -0.8321854, 0.1795166>,
    <-0.5125199, -0.8201506, 0.2543152>,
    <-0.4913136, -0.8482454, 0.1977136>,
    <-0.4838571, -0.8255973, 0.2902955>,
    <-0.5008473, -0.7854608, 0.3635979>,
    <-0.4539385, -0.7684892, 0.4509591>,
    <-0.3481983, -0.6021946, 0.7184147>,
    <-0.4902569, -0.7643349, 0.4188561>,
    <-0.5971755, -0.7782682, 0.1941135>,
    <-0.5526837, -0.7873160, 0.2732661>,
    <-0.5490859, -0.7442721, 0.3802154>,
    <-0.5861498, -0.7369868, 0.3365692>,
    <-0.4855880, -0.7340446, 0.4747450>,
    <-0.4863716, -0.6748526, 0.5549926>,
    <-0.3844823, -0.6001436, 0.7014278>,
    <-0.3988052, -0.5689541, 0.7191979>,
    <-0.5237553, -0.6615768, 0.5366531>,
    <-0.4117472, -0.5380044, 0.7355375>,
    <-0.2714214, 0.4155326, 0.8681377>,
    <-0.3227549, 0.4488305, 0.8332949>,
    <-0.2568278, 0.3489381, 0.9012667>,
    <-0.2115525, 0.3077994, 0.9276341>,
    <-0.1958854, 0.2920230, 0.9361365>,
    <-0.2387283, 0.3794174, 0.8938967>,
    <-0.3514448, 0.6096316, 0.7105180>,
    <-0.3691287, 0.5776276, 0.7280730>,
    <-0.4026077, 0.5755881, 0.7117622>,
    <-0.3349382, 0.4209527, 0.8429800>,
    <-0.2551796, 0.3169598, 0.9134658>,
    <-0.4367390, 0.5723198, 0.6940527>,
    <-0.2014670, 0.2638896, 0.9432780>,
    <-0.1851601, 0.2570864, 0.9484842>,
    <-0.5272240, 0.8275602, 0.1928186>,
    <-0.5511849, 0.7894774, 0.2700382>,
    <-0.5127178, 0.7722288, 0.3752108>,
    <-0.4930134, 0.8040503, 0.3323264>,
    <-0.4736401, 0.8325531, 0.2872637>,
    <-0.4890605, 0.8497112, 0.1970043>,
    <-0.5255165, 0.7101365, 0.4685494>,
    <-0.4703792, 0.6916375, 0.5480703>,
    <-0.4450605, 0.7221314, 0.5295729>,
    <-0.4402546, 0.7799748, 0.4447643>,
    <-0.2917537, -0.3890123, 0.8738130>,
    <-0.3060421, -0.4489764, 0.8394989>,
    <-0.2346722, -0.3525956, 0.9058727>,
    <-0.2109797, -0.2955808, 0.9317293>,
    <-0.2013682, -0.2760103, 0.9398240>,
    <-0.2688230, -0.3462135, 0.8988161>,
    <-0.2762746, -0.4513258, 0.8485148>,
    <-0.2057696, -0.3406888, 0.9173822>,
    <-0.2270947, -0.4078505, 0.8843562>,
    <-0.1800173, -0.3238600, 0.9288210>,
    <-0.1733883, -0.2711536, 0.9467905>,
    <-0.1625961, -0.2885747, 0.9435503>,
    <-0.1716913, -0.2537179, 0.9519188>,
    <-0.2436664, -0.3169389, 0.9166114>,
    <-0.2023358, -0.2793001, 0.9386435>,
    <-0.1956326, -0.2644930, 0.9443365>,
    <-0.2131934, -0.2752010, 0.9374503>,
    <-0.1796659, -0.2591117, 0.9489896>,
    <-0.1849792, -0.2554925, 0.9489501>,
    <-0.1969712, -0.2579843, 0.9458575>,
    <-0.2192013, 0.3453231, 0.9125255>,
    <-0.1977601, 0.2934322, 0.9353013>,
    <-0.1858764, 0.2820349, 0.9412260>,
    <-0.1900712, 0.3024295, 0.9340285>,
    <-0.1946386, 0.3255614, 0.9252705>,
    <-0.2441916, 0.4085695, 0.8794552>,
    <-0.1853995, 0.2642678, 0.9464616>,
    <-0.1808663, 0.2691375, 0.9459664>,
    <-0.1790783, 0.2820651, 0.9425339>,
    <-0.1719120, 0.2928932, 0.9405636>,
    <0.1688988, 0.3612794, -0.9170335>,
    <0.1678710, 0.3567780, -0.9189825>,
    <0.1648783, 0.3481014, -0.9228437>,
    <0.1653804, 0.3506339, -0.9217946>,
    <0.1725245, 0.3648607, -0.9149382>,
    <0.1707844, 0.3652820, -0.9150966>,
    <0.1713604, 0.3674918, -0.9141036>,
    <0.1708737, 0.3664516, -0.9146121>,
    <0.1708737, 0.3664516, -0.9146121>,
    <0.1675260, 0.3592751, -0.9180722>,
    <0.1634430, 0.3411035, -0.9257077>,
    <0.1638423, 0.3377616, -0.9268618>,
    <0.1675260, 0.3592751, -0.9180722>,
    <0.1581621, 0.3391965, -0.9273244>,
    <0.1581621, 0.3391965, -0.9273244>,
    <0.1509319, 0.2925278, -0.9442706>,
    <0.1635361, 0.3383407, -0.9267047>,
    <0.1765852, 0.3630510, -0.9148834>,
    <0.1670896, -0.3577499, -0.9187470>,
    <0.1592837, -0.3385644, -0.9273634>,
    <0.1603279, -0.3401615, -0.9265987>,
    <0.1670257, -0.3559990, -0.9194385>,
    <0.1684542, -0.3612028, -0.9171454>,
    <0.1710159, -0.3666953, -0.9144879>,
    <0.1710159, -0.3666953, -0.9144879>,
    <0.1713381, -0.3673852, -0.9141506>,
    <0.1695490, -0.3621343, -0.9165762>,
    <0.1696565, -0.3573525, -0.9184312>,
    <0.1532911, -0.3191540, -0.9352233>,
    <0.1576494, -0.3286615, -0.9311972>,
    <0.1732400, -0.3523405, -0.9196978>,
    <0.1627238, -0.3426102, -0.9252779>,
    <0.1519910, -0.3038916, -0.9405045>,
    <0.1611209, -0.3454770, -0.9244921>,
    <0.1611209, -0.3454770, -0.9244921>,
    <0.1684542, -0.3612028, -0.9171454>,
    <-0.2007041, 0.4022079, 0.8932786>,
    <-0.2124600, 0.4085012, 0.8876866>,
    <-0.2157036, 0.4053903, 0.8883303>,
    <-0.2019488, 0.3958102, 0.8958521>,
    <-0.1776077, 0.3727554, 0.9107738>,
    <-0.1653454, 0.3536129, 0.9206622>,
    <-0.1589932, 0.3409520, 0.9265381>,
    <-0.2101554, 0.4165143, 0.8845059>,
    <-0.2101554, 0.4165143, 0.8845059>,
    <-0.2052981, 0.4068875, 0.8901097>,
    <-0.2008601, 0.3725466, 0.9060156>,
    <-0.2232436, 0.3998811, 0.8889642>,
    <-0.2052981, 0.4068875, 0.8901097>,
    <-0.1774605, 0.3517152, 0.9191323>,
    <-0.1774605, 0.3517152, 0.9191323>,
    <-0.1651033, 0.2984974, 0.9400214>,
    <-0.2245111, 0.4129270, 0.8826585>,
    <-0.1976418, 0.3992867, 0.8952697>,
    <0.1620188, 0.3535969, -0.9212595>,
    <0.1448066, 0.3293983, -0.9330208>,
    <0.1401294, 0.3381662, -0.9305952>,
    <0.1502919, 0.3464651, -0.9259451>,
    <0.1591250, 0.3411027, -0.9264600>,
    <0.1697684, 0.3639782, -0.9158049>,
    <0.1697684, 0.3639782, -0.9158049>,
    <0.1713602, 0.3674341, -0.9141268>,
    <0.1651789, 0.3549734, -0.9201684>,
    <0.1507784, 0.3290102, -0.9322114>,
    <0.1259980, 0.3210057, -0.9386585>,
    <0.1236366, 0.3370202, -0.9333442>,
    <0.1358607, 0.3075279, -0.9417900>,
    <0.1451549, 0.4058498, -0.9023392>,
    <0.1100872, 0.3458985, -0.9317913>,
    <0.1088475, 0.3480197, -0.9311469>,
    <0.1265611, 0.3296236, -0.9355910>,
    <0.1034743, 0.3321870, -0.9375206>,
    <0.0977962, 0.3141456, -0.9443243>,
    <0.1335058, 0.2861131, -0.9488496>,
    <0.1335058, 0.2861131, -0.9488496>,
    <0.1591250, 0.3411027, -0.9264600>,
    <0.1674304, 0.3595593, -0.9179783>,
    <0.1686374, 0.3616358, -0.9169411>,
    <0.1610147, 0.3452873, -0.9245815>,
    <0.1560596, 0.3366725, -0.9285995>,
    <0.1713602, 0.3674341, -0.9141268>,
    <0.1713621, 0.3674654, -0.9141139>,
    <0.1713621, 0.3674654, -0.9141139>,
    <0.1713646, 0.3674861, -0.9141051>,
    <0.1676867, 0.3594719, -0.9179658>,
    <0.1590699, 0.3419639, -0.9261519>,
    <0.1713646, 0.3674861, -0.9141051>,
    <0.1713665, 0.3674996, -0.9140993>,
    <0.1713665, 0.3674996, -0.9140993>,
    <0.1713604, 0.3674918, -0.9141036>,
    <0.1690953, 0.3639157, -0.9159542>,
    <0.1662680, 0.3623173, -0.9171048>,
    <0.1477827, 0.3214261, -0.9353318>,
    <0.1603910, 0.3617013, -0.9183936>,
    <0.1731556, 0.3722318, -0.9118446>,
    <0.1809874, 0.3837419, -0.9055306>,
    <0.1844806, 0.3979243, -0.8986786>,
    <0.1774318, 0.3883925, -0.9042506>,
    <0.1713604, 0.3674918, -0.9141036>,
    <0.1944679, 0.4049706, -0.8934098>,
    <0.1951276, 0.4224147, -0.8851503>,
    <0.2266951, 0.4668532, -0.8547850>,
    <0.2195461, 0.4802258, -0.8492248>,
    <0.1857936, 0.4183458, -0.8890824>,
    <0.2046478, 0.4779840, -0.8541958>,
    <0.1738928, -0.3716126, -0.9119569>,
    <0.1786932, -0.3866947, -0.9047298>,
    <0.1865932, -0.3971175, -0.8985993>,
    <0.1828121, -0.3836945, -0.9051841>,
    <0.1713381, -0.3673852, -0.9141506>,
    <0.1707191, -0.3667363, -0.9145269>,
    <0.1704930, -0.3693155, -0.9135306>,
    <0.1868007, -0.4113310, -0.8921392>,
    <0.1988332, -0.4214341, -0.8847930>,
    <0.1667892, -0.3703865, -0.9137807>,
    <0.1501291, -0.4024342, -0.9030548>,
    <0.2132113, -0.4749036, -0.8538194>,
    <0.2276469, -0.4775664, -0.8485913>,
    <0.2003110, -0.4090270, -0.8902653>,
    <0.2348075, -0.4635104, -0.8544142>,
    <0.2398946, -0.5215359, -0.8188107>,
    <0.2532095, -0.5239098, -0.8132672>,
    <0.2595533, -0.5205123, -0.8134489>,
    <0.2516588, -0.5166287, -0.8183903>,
    <0.2299829, -0.5244422, -0.8197977>,
    <0.2555133, -0.5433796, -0.7996571>,
    <0.2777984, -0.5335224, -0.7988629>,
    <0.2724343, -0.5152521, -0.8125853>,
    <0.2817103, -0.5563341, -0.7817491>,
    <0.2583894, -0.4958152, -0.8290972>,
    <0.1696562, -0.3637782, -0.9159051>,
    <0.1699770, -0.3644866, -0.9155640>,
    <0.1662234, -0.3564443, -0.9194114>,
    <0.1657487, -0.3562180, -0.9195847>,
    <0.1713381, -0.3673852, -0.9141506>,
    <0.1712941, -0.3672920, -0.9141963>,
    <0.1712941, -0.3672920, -0.9141963>,
    <0.1712775, -0.3672647, -0.9142104>,
    <0.1692065, -0.3632916, -0.9161814>,
    <0.1625817, -0.3507401, -0.9222519>,
    <0.1712775, -0.3672647, -0.9142104>,
    <0.1712709, -0.3672707, -0.9142092>,
    <0.1712709, -0.3672707, -0.9142092>,
    <0.1712686, -0.3673068, -0.9141952>,
    <0.1670853, -0.3595364, -0.9180501>,
    <0.1559554, -0.3430534, -0.9262787>,
    <0.1581787, -0.3436512, -0.9256799>,
    <0.1436802, -0.3307156, -0.9327289>,
    <0.1616707, -0.3565402, -0.9201857>,
    <0.1457383, -0.3470841, -0.9264410>,
    <0.1357126, -0.3426299, -0.9296165>,
    <0.1447697, -0.3388536, -0.9296343>,
    <0.1712686, -0.3673068, -0.9141952>,
    <0.1693258, -0.3632064, -0.9161932>,
    <0.1693258, -0.3632064, -0.9161932>,
    <0.1565234, -0.3358280, -0.9288272>,
    <0.1201920, -0.3324277, -0.9354388>,
    <0.1169187, -0.3384135, -0.9337057>,
    <0.1565234, -0.3358280, -0.9288272>,
    <0.1270636, -0.2727150, -0.9536673>,
    <0.1270636, -0.2727150, -0.9536673>,
    <0.0968408, -0.3254291, -0.9405944>,
    <0.1006003, -0.3377897, -0.9358299>,
    <0.1023848, -0.3418739, -0.9341518>,
    <0.1221483, -0.3270545, -0.9370780>,
    <0.1005498, -0.3284253, -0.9391627>,
    <-0.1501006, 0.3531623, 0.9234426>,
    <-0.1440184, 0.3375222, 0.9302352>,
    <-0.1538251, 0.3516161, 0.9234197>,
    <-0.1627294, 0.3689287, 0.9151015>,
    <-0.1843500, 0.4100917, 0.8932188>,
    <-0.1575188, 0.3723604, 0.9146232>,
    <-0.1107527, 0.3226131, 0.9400290>,
    <-0.1364097, 0.3329028, 0.9330424>,
    <-0.1364097, 0.3329028, 0.9330424>,
    <-0.1285016, 0.3136032, 0.9408190>,
    <-0.1433661, 0.3294311, 0.9332316>,
    <-0.1593636, 0.3547273, 0.9212881>,
    <-0.1285016, 0.3136032, 0.9408190>,
    <-0.1198928, 0.2925940, 0.9486909>,
    <-0.1198928, 0.2925940, 0.9486909>,
    <-0.1589932, 0.3409520, 0.9265381>,
    <-0.1732407, 0.3780896, 0.9094151>,
    <-0.2120486, 0.4449236, 0.8701025>,
    <0.2458640, 0.5189357, -0.8186920>,
    <0.2388881, 0.5307254, -0.8131808>,
    <0.2319864, 0.5328804, -0.8137695>,
    <0.2341109, 0.5240402, -0.8188858>,
    <0.2552521, 0.5153111, -0.8181081>,
    <0.2526425, 0.5459945, -0.7987877>,
    <0.2301945, 0.5556247, -0.7989316>,
    <0.2195431, 0.5394601, -0.8128860>,
    <0.2452709, 0.5736893, -0.7814876>,
    <0.2367340, 0.6495350, -0.7225381>,
    <0.2163245, 0.5915156, -0.7767323>,
    <0.2032201, 0.5541952, -0.8071984>,
    <0.2136737, 0.5159015, -0.8295717>,
    <0.1873144, 0.5097595, -0.8396776>,
    <0.2692870, 0.5182442, -0.8117312>,
    <0.2846053, 0.5346920, -0.7956785>,
    <0.2767793, 0.5569960, -0.7830381>,
    <0.2685814, 0.5627401, -0.7817849>,
    <0.2933424, 0.5569984, -0.7769833>,
    <0.2768974, 0.5732931, -0.7711438>,
    <0.3078429, 0.6018573, -0.7368857>,
    <0.2921374, 0.6259437, -0.7230838>,
    <0.2640984, 0.5916923, -0.7616773>,
    <0.2754150, 0.6503920, -0.7079102>,
    <0.2954438, -0.6632355, -0.6876276>,
    <0.3149398, -0.6603436, -0.6817326>,
    <0.3288219, -0.6629792, -0.6725584>,
    <0.3212928, -0.6664272, -0.6727895>,
    <0.2917185, -0.6261394, -0.7230835>,
    <0.2631719, -0.6226879, -0.7368856>,
    <0.2361643, -0.6497423, -0.7225382>,
    <0.2948129, -0.6897660, -0.6612928>,
    <0.3200374, -0.6868448, -0.6525491>,
    <0.3446433, -0.6630132, -0.6645559>,
    <0.3509343, -0.6605600, -0.6637060>,
    <0.3450044, -0.6823429, -0.6444999>,
    <0.3470290, -0.6599353, -0.6663755>,
    <0.3211961, -0.6290443, -0.7079098>,
    <0.2231146, -0.5375057, -0.8132082>,
    <0.2263414, -0.5609586, -0.7963008>,
    <0.2484210, -0.5692477, -0.7837372>,
    <0.2578303, -0.5660715, -0.7829985>,
    <0.1839636, -0.5103717, -0.8400465>,
    <0.2004761, -0.5549897, -0.8073387>,
    <0.2380507, -0.5825567, -0.7771484>,
    <0.2610793, -0.5803935, -0.7713501>,
    <0.2144842, -0.5921322, -0.7767728>,
    <0.2833014, -0.5822224, -0.7620744>,
    <-0.1823215, -0.4110808, 0.8931805>,
    <-0.1756821, -0.4131539, 0.8935545>,
    <-0.1717742, -0.4170942, 0.8924831>,
    <-0.1753645, -0.4078743, 0.8960390>,
    <-0.1763045, -0.3864258, 0.9053131>,
    <-0.1737611, -0.3736418, 0.9111525>,
    <-0.1708228, -0.3663267, 0.9146717>,
    <-0.1867835, -0.4216137, 0.8873296>,
    <-0.1867835, -0.4216137, 0.8873296>,
    <-0.1785529, -0.4030356, 0.8975975>,
    <-0.1534994, -0.3771286, 0.9133521>,
    <-0.1614162, -0.4168035, 0.8945500>,
    <-0.1785529, -0.4030356, 0.8975975>,
    <-0.1521555, -0.3434503, 0.9267635>,
    <-0.1521555, -0.3434503, 0.9267635>,
    <-0.1240682, -0.3348315, 0.9340744>,
    <-0.1287265, -0.3519820, 0.9271128>,
    <-0.1466023, -0.4202722, 0.8954770>,
    <-0.1722129, -0.4328676, 0.8848550>,
    <-0.1651561, -0.4745062, 0.8646197>,
    <-0.2112032, -0.5571094, 0.8031328>,
    <-0.1807662, -0.4124525, 0.8928642>,
    <-0.1794348, -0.3632318, 0.9142570>,
    <-0.1752975, -0.3568842, 0.9175535>,
    <-0.1774884, -0.3664538, 0.9133507>,
    <-0.1822247, -0.3777336, 0.9078059>,
    <-0.1953484, -0.4086520, 0.8915394>,
    <-0.1814032, -0.3592813, 0.9154288>,
    <-0.1719399, -0.2790653, 0.9447535>,
    <-0.1759680, -0.3504953, 0.9198849>,
    <-0.1759680, -0.3504953, 0.9198849>,
    <-0.1696415, -0.3378940, 0.9257696>,
    <-0.1711754, -0.3525197, 0.9200157>,
    <-0.1761619, -0.3702520, 0.9120748>,
    <-0.1696415, -0.3378940, 0.9257696>,
    <-0.1618547, -0.3223842, 0.9326690>,
    <-0.1618547, -0.3223842, 0.9326690>,
    <-0.1708228, -0.3663267, 0.9146717>,
    <-0.1818457, -0.3879702, 0.9035548>,
    <-0.2048687, -0.4524834, 0.8679214>,
    <-0.1894667, -0.3590969, 0.9138664>,
    <-0.2095925, -0.4329275, 0.8767239>,
    <-0.2200792, -0.4422571, 0.8694676>,
    <-0.2160954, -0.4109619, 0.8856710>,
    <-0.1719399, -0.2790653, 0.9447535>,
    <-0.2311188, -0.5084506, 0.8294951>,
    <-0.2384395, -0.4934608, 0.8364466>,
    <-0.2599067, -0.6007239, 0.7560286>,
    <-0.2707378, -0.5772259, 0.7703968>,
    <-0.2431251, -0.4694843, 0.8488078>,
    <-0.2800570, -0.5492148, 0.7873571>,
    <-0.2900811, 0.6466574, 0.7054695>,
    <-0.3083093, 0.6423810, 0.7016352>,
    <-0.3222309, 0.6519797, 0.6863598>,
    <-0.3140217, 0.6568016, 0.6855669>,
    <-0.3186647, 0.6819865, 0.6582912>,
    <-0.2895609, 0.6723959, 0.6812035>,
    <-0.1994084, 0.5619046, 0.8028073>,
    <-0.2456409, 0.5742109, 0.7809881>,
    <-0.2723159, 0.5857087, 0.7634064>,
    <-0.3281227, 0.6328720, 0.7012906>,
    <-0.3424966, 0.6491526, 0.6791885>,
    <-0.2954280, 0.5902903, 0.7511855>,
    <-0.3437530, 0.6621039, 0.6659222>,
    <-0.3453450, 0.6828380, 0.6437927>,
    <-0.1617429, 0.3917627, 0.9057380>,
    <-0.2006975, 0.4471945, 0.8716293>,
    <-0.2037748, 0.4644498, 0.8618365>,
    <-0.1847447, 0.4438531, 0.8768488>,
    <-0.1653547, 0.4302178, 0.8874517>,
    <-0.1340651, 0.3662190, 0.9208204>,
    <-0.1107527, 0.3226131, 0.9400290>,
    <-0.2433642, 0.5098223, 0.8251395>,
    <-0.2302894, 0.5098122, 0.8288898>,
    <-0.2102192, 0.4979064, 0.8413662>,
    <-0.1863086, 0.4823178, 0.8559548>,
    <0.3181602, 0.6526424, -0.6876278>,
    <0.3034131, 0.6657184, -0.6817327>,
    <0.2965088, 0.6780467, -0.6725587>,
    <0.3039898, 0.6744953, -0.6727899>,
    <0.3388894, 0.6692129, -0.6612927>,
    <0.3204376, 0.6866583, -0.6525490>,
    <0.2863651, 0.6901886, -0.6645561>,
    <0.2804420, 0.6934307, -0.6637063>,
    <0.3009405, 0.7028904, -0.6444998>,
    <0.2779783, 0.7628051, -0.5838291>,
    <0.2645065, 0.7240576, -0.6370063>,
    <0.2592921, 0.7113616, -0.6532475>,
    <0.2824737, 0.6900374, -0.6663760>,
    <0.2537505, 0.6976986, -0.6699458>,
    <0.3548865, 0.6814590, -0.6400541>,
    <0.3600813, 0.6763390, -0.6425784>,
    <0.3442712, 0.6928786, -0.6335586>,
    <0.3376692, 0.7070277, -0.6213624>,
    <0.3578224, 0.6790134, -0.6410179>,
    <0.3359295, 0.6955756, -0.6350795>,
    <0.3636579, 0.7108271, -0.6020612>,
    <0.3431498, 0.7353106, -0.5844370>,
    <0.3201112, 0.7177045, -0.6184085>,
    <0.3214937, 0.7595285, -0.5654717>,
    <0.3397128, -0.7629777, -0.5499639>,
    <0.3596362, -0.7543322, -0.5492220>,
    <0.3752811, -0.7565708, -0.5355042>,
    <0.3681620, -0.7635675, -0.5304916>,
    <0.3427078, -0.7355160, -0.5844378>,
    <0.3107701, -0.7354886, -0.6020618>,
    <0.2773780, -0.7630236, -0.5838290>,
    <0.3354133, -0.7849545, -0.5209073>,
    <0.3617117, -0.7762110, -0.5163923>,
    <0.3902200, -0.7506058, -0.5332160>,
    <0.3988810, -0.7504086, -0.5270492>,
    <0.3876402, -0.7663687, -0.5122638>,
    <0.3966697, -0.7538817, -0.5237514>,
    <0.3751801, -0.7344936, -0.5654725>,
    <0.2939111, -0.7098919, -0.6400545>,
    <0.2866497, -0.7105803, -0.6425789>,
    <0.3094823, -0.7091005, -0.6335591>,
    <0.3245649, -0.7131381, -0.6213628>,
    <0.2540878, -0.6975757, -0.6699459>,
    <0.2586252, -0.7116043, -0.6532475>,
    <0.2901504, -0.7105688, -0.6410185>,
    <0.3169102, -0.7044439, -0.6350801>,
    <0.2627915, -0.7246818, -0.6370063>,
    <0.3440298, -0.7065506, -0.6184090>,
    <-0.3085036, -0.6345419, 0.7086481>,
    <-0.2926102, -0.6449877, 0.7059534>,
    <-0.2916994, -0.6637192, 0.6887585>,
    <-0.3011871, -0.6614707, 0.6868354>,
    <-0.3181619, -0.6829849, 0.6574987>,
    <-0.3307510, -0.6555415, 0.6788735>,
    <-0.2727013, -0.6552332, 0.7044881>,
    <-0.2766479, -0.6782168, 0.6807994>,
    <-0.2449734, -0.6659868, 0.7045918>,
    <-0.2558682, -0.6983373, 0.6684733>,
    <-0.2861792, -0.6884900, 0.6663956>,
    <-0.2641207, -0.7221499, 0.6393276>,
    <-0.2780075, -0.7627854, 0.5838410>,
    <-0.3012309, -0.7036209, 0.6435663>,
    <-0.3472886, -0.6668122, 0.6593574>,
    <-0.3345942, -0.7005362, 0.6303140>,
    <-0.3425024, -0.6892536, 0.6384525>,
    <-0.3565265, -0.6695095, 0.6516486>,
    <-0.3198304, -0.7168299, 0.6195672>,
    <-0.3363702, -0.6964253, 0.6339140>,
    <-0.3210258, -0.7582511, 0.5674484>,
    <-0.3431697, -0.7352914, 0.5844494>,
    <-0.3579953, -0.6794167, 0.6404938>,
    <-0.3642577, -0.7120183, 0.6002885>,
    <-0.3397585, 0.7629490, 0.5499754>,
    <-0.3673871, 0.7620256, 0.5332388>,
    <-0.3752516, 0.7565774, 0.5355155>,
    <-0.3603783, 0.7557910, 0.5467243>,
    <-0.3616873, 0.7762142, 0.5164047>,
    <-0.3349437, 0.7837893, 0.5229599>,
    <-0.2773429, 0.7630272, 0.5838411>,
    <-0.3112974, 0.7367142, 0.6002883>,
    <-0.3426808, 0.7355196, 0.5844492>,
    <-0.3956751, 0.7522374, 0.5268587>,
    <-0.3987861, 0.7504508, 0.5270609>,
    <-0.3745027, 0.7333145, 0.5674483>,
    <-0.3910131, 0.7521970, 0.5303852>,
    <-0.3880940, 0.7674327, 0.5103236>,
    <-0.2860498, 0.6905399, 0.6643268>,
    <-0.3208963, 0.7049948, 0.6324618>,
    <-0.3073064, 0.7041870, 0.6400652>,
    <-0.2828729, 0.7013475, 0.6542894>,
    <-0.2519392, 0.6968014, 0.6715612>,
    <-0.2389204, 0.6621972, 0.7102196>,
    <-0.3433661, 0.7054018, 0.6200871>,
    <-0.3171457, 0.7050338, 0.6343074>,
    <-0.2901664, 0.7105053, 0.6410816>,
    <-0.2616173, 0.7224004, 0.6400735>,
    <0.3661117, 0.7506680, -0.5499635>,
    <0.3466823, 0.7603729, -0.5492216>,
    <0.3383409, 0.7737968, -0.5355035>,
    <0.3482768, 0.7728407, -0.5304908>,
    <0.3857105, 0.7615004, -0.5209073>,
    <0.3621083, 0.7760260, -0.5163924>,
    <0.3241689, 0.7814062, -0.5332156>,
    <0.3184507, 0.7879144, -0.5270484>,
    <0.3379022, 0.7895617, -0.5122640>,
    <0.3054206, 0.8382640, -0.4516988>,
    <0.2963681, 0.8111419, -0.5041971>,
    <0.2930738, 0.8041894, -0.5170949>,
    <0.3225327, 0.7884530, -0.5237505>,
    <0.2896396, 0.7968420, -0.5302374>,
    <0.4002437, 0.7686436, -0.4989909>,
    <0.4051539, 0.7608138, -0.5069642>,
    <0.3857243, 0.7763988, -0.4984192>,
    <0.3774176, 0.7906356, -0.4821319>,
    <0.4009237, 0.7605957, -0.5106412>,
    <0.3754721, 0.7775438, -0.5044267>,
    <0.4015413, 0.7848337, -0.4720176>,
    <0.3771321, 0.8082236, -0.4522676>,
    <0.3562651, 0.7991896, -0.4841190>,
    <0.3515670, 0.8308389, -0.4314017>,
    <0.3690467, -0.8290336, -0.4201284>,
    <0.3898471, -0.8178188, -0.4233103>,
    <0.4060049, -0.8183983, -0.4066747>,
    <0.3984577, -0.8262941, -0.3980822>,
    <0.3767198, -0.8084165, -0.4522664>,
    <0.3431121, -0.8120803, -0.4720166>,
    <0.3048601, -0.8384681, -0.4516985>,
    <0.3617522, -0.8466522, -0.3902761>,
    <0.3891664, -0.8350254, -0.3889501>,
    <0.4210209, -0.8097353, -0.4087423>,
    <0.4305540, -0.8096738, -0.3988127>,
    <0.4161354, -0.8224548, -0.3878137>,
    <0.4286410, -0.8142975, -0.3913904>,
    <0.4104770, -0.8033693, -0.4314005>,
    <0.3315437, -0.8006794, -0.4989903>,
    <0.3223896, -0.7994080, -0.5069633>,
    <0.3468175, -0.7945419, -0.4984183>,
    <0.3630629, -0.7973297, -0.4821313>,
    <0.2903235, -0.7965932, -0.5302373>,
    <0.2924155, -0.8044291, -0.5170948>,
    <0.3249417, -0.7960273, -0.5106402>,
    <0.3542847, -0.7874243, -0.5044257>,
    <0.2943610, -0.8118726, -0.5041969>,
    <0.3832123, -0.7866244, -0.4841182>,
    <-0.3660603, -0.7506842, 0.5499755>,
    <-0.3475936, -0.7712554, 0.5332390>,
    <-0.3383648, -0.7737780, 0.5355156>,
    <-0.3473228, -0.7618788, 0.5467244>,
    <-0.3621265, -0.7760094, 0.5164048>,
    <-0.3851198, -0.7603917, 0.5229601>,
    <-0.3219123, -0.7866335, 0.5268588>,
    <-0.3185439, -0.7878683, 0.5270610>,
    <-0.2894119, -0.7959535, 0.5316942>,
    <-0.2931068, -0.8041687, 0.5171084>,
    <-0.3248780, -0.7830363, 0.5303852>,
    <-0.2966363, -0.8119168, 0.5027903>,
    <-0.3054473, -0.8382430, 0.4517196>,
    <-0.3384256, -0.7905934, 0.5103236>,
    <-0.3994268, -0.7670079, 0.5021525>,
    <-0.3768268, -0.7891769, 0.4849757>,
    <-0.3857462, -0.7763787, 0.4984336>,
    <-0.4051199, -0.7608231, 0.5069774>,
    <-0.3563515, -0.7991409, 0.4841358>,
    <-0.3761532, -0.7788932, 0.5018307>,
    <-0.3512177, -0.8298526, 0.4335791>,
    <-0.3771501, -0.8082039, 0.4522878>,
    <-0.4016834, -0.7621255, 0.5077550>,
    <-0.4020194, -0.7857855, 0.4700229>,
    <-0.3690887, 0.8290027, 0.4201526>,
    <-0.3978720, 0.8251398, 0.4010513>,
    <-0.4059762, 0.8184009, 0.4066979>,
    <-0.3904306, 0.8189473, 0.4205820>,
    <-0.3891431, 0.8350260, 0.3889720>,
    <-0.3614054, 0.8457763, 0.3924902>,
    <-0.3048260, 0.8384693, 0.4517194>,
    <-0.3435336, 0.8130579, 0.4700229>,
    <-0.3766928, 0.8084172, 0.4522878>,
    <-0.4278807, 0.8130824, 0.3947342>,
    <-0.4304641, 0.8097107, 0.3988348>,
    <-0.4099457, 0.8024673, 0.4335790>,
    <-0.4216297, 0.8109651, 0.4056649>,
    <-0.4164685, 0.8232687, 0.3857236>,
    <-0.3308157, 0.7990019, 0.5021524>,
    <-0.3623251, 0.7959392, 0.4849756>,
    <-0.3467877, 0.7945453, 0.4984335>,
    <-0.3224183, 0.7993875, 0.5069773>,
    <-0.2923769, 0.8044344, 0.5171083>,
    <-0.2899267, 0.7957661, 0.5316943>,
    <-0.3831192, 0.7866589, 0.4841357>,
    <-0.3548803, 0.7888130, 0.5018307>,
    <-0.3256249, 0.7975922, 0.5077550>,
    <-0.2946535, 0.8126386, 0.5027901>,
    <0.3978579, 0.8155983, -0.4201292>,
    <0.3758967, 0.8243237, -0.4233109>,
    <0.3659545, 0.8370736, -0.4066757>,
    <0.3768543, 0.8363674, -0.3980835>,
    <0.4160434, 0.8213357, -0.3902762>,
    <0.3895152, 0.8348627, -0.3889500>,
    <0.3496662, 0.8430082, -0.4087429>,
    <0.3434913, 0.8502713, -0.3988138>,
    <0.3625502, 0.8474420, -0.3878136>,
    <0.3232154, 0.8873016, -0.3289797>,
    <0.3175002, 0.8689920, -0.3795346>,
    <0.3152912, 0.8653486, -0.3895680>,
    <0.3482629, 0.8517778, -0.3913917>,
    <0.3130201, 0.8615532, -0.3996806>,
    <0.4292680, 0.8245028, -0.3686788>,
    <0.4347615, 0.8163637, -0.3801747>,
    <0.4129030, 0.8312271, -0.3722536>,
    <0.4028358, 0.8441803, -0.3536706>,
    <0.4298822, 0.8154651, -0.3875797>,
    <0.4019429, 0.8324814, -0.3813352>,
    <0.4266121, 0.8338680, -0.3502374>,
    <0.3991973, 0.8556335, -0.3294432>,
    <0.3798931, 0.8525252, -0.3590015>,
    <0.3706867, 0.8762644, -0.3078182>,
    <0.3879686, -0.8715931, -0.2996761>,
    <0.4097198, -0.8595279, -0.3055184>,
    <0.4257539, -0.8580686, -0.2871443>,
    <0.4174928, -0.8656351, -0.2763613>,
    <0.3988539, -0.8557932, -0.3294444>,
    <0.3645587, -0.8628035, -0.3502385>,
    <0.3227491, -0.8874712, -0.3289801>,
    <0.3783384, -0.8854393, -0.2699208>,
    <0.4067028, -0.8725324, -0.2707030>,
    <0.4412492, -0.8484958, -0.2921542>,
    <0.4508710, -0.8475995, -0.2798043>,
    <0.4345918, -0.8587137, -0.2715524>,
    <0.4486417, -0.8520000, -0.2698455>,
    <0.4329844, -0.8472141, -0.3078193>,
    <0.3556775, -0.8588183, -0.3686795>,
    <0.3459112, -0.8577947, -0.3801758>,
    <0.3713477, -0.8506041, -0.3722546>,
    <0.3877416, -0.8512186, -0.3536713>,
    <0.3140085, -0.8611935, -0.3996805>,
    <0.3147083, -0.8655608, -0.3895681>,
    <0.3483592, -0.8534793, -0.3875809>,
    <0.3793535, -0.8430145, -0.3813363>,
    <0.3153580, -0.8697716, -0.3795349>,
    <0.4088813, -0.8390074, -0.3590023>,
    <0.4182976, 0.8574508, -0.2996752>,
    <0.3950737, 0.8663577, -0.3055178>,
    <0.3836493, 0.8777026, -0.2871434>,
    <0.3947558, 0.8762380, -0.2763601>,
    <0.4350946, 0.8589736, -0.2699205>,
    <0.4069750, 0.8724055, -0.2707028>,
    <0.3663559, 0.8834193, -0.2921536>,
    <0.3594845, 0.8902140, -0.2798033>,
    <0.3784626, 0.8848872, -0.2715524>,
    <0.3342247, 0.9177576, -0.2145107>,
    <0.3310387, 0.9061707, -0.2631882>,
    <0.3294311, 0.9044021, -0.2711677>,
    <0.3642886, 0.8913349, -0.2698443>,
    <0.3277927, 0.9025735, -0.2791290>,
    <0.4472039, 0.8590988, -0.2489135>,
    <0.4535616, 0.8517141, -0.2624213>,
    <0.4301058, 0.8660057, -0.2550354>,
    <0.4184785, 0.8772068, -0.2353378>,
    <0.4487106, 0.8512148, -0.2721988>,
    <0.4190762, 0.8681113, -0.2660037>,
    <0.4425483, 0.8651050, -0.2361025>,
    <0.4128727, 0.8850888, -0.2148347>,
    <0.3947616, 0.8861622, -0.2426517>,
    <0.3821952, 0.9036974, -0.1930232>,
    <0.3978145, -0.8936573, -0.2076540>,
    <0.4125395, -0.8649047, -0.2859214>,
    <0.4323233, -0.8711500, -0.2327966>,
    <0.4275768, -0.8863891, -0.1774614>,
    <0.4126281, -0.8852031, -0.2148338>,
    <0.3782445, -0.8950906, -0.2361017>,
    <0.3338924, -0.9178786, -0.2145103>,
    <0.3885665, -0.9041949, -0.1773347>,
    <0.4124668, -0.8711570, -0.2663768>,
    <0.4248481, -0.8169166, -0.3900658>,
    <0.4531635, -0.8521646, -0.2616453>,
    <0.4095872, -0.7893639, -0.4573215>,
    <0.4586058, -0.8706897, -0.1777081>,
    <0.4466021, -0.8736640, -0.1930225>,
    <0.3706508, -0.8947962, -0.2489131>,
    <0.3609073, -0.8949198, -0.2624205>,
    <0.3869323, -0.8861381, -0.2550346>,
    <0.4029867, -0.8844309, -0.2353374>,
    <0.3290593, -0.9021124, -0.2791293>,
    <0.3289797, -0.9045664, -0.2711677>,
    <0.3636430, -0.8908828, -0.2721978>,
    <0.3956350, -0.8790423, -0.2660028>,
    <0.3288851, -0.9069546, -0.2631879>,
    <0.4250919, -0.8720191, -0.2426511>,
    <-0.3978073, -0.8156109, 0.4201526>,
    <-0.3763466, -0.8351772, 0.4010514>,
    <-0.3659750, -0.8370538, 0.4066980>,
    <-0.3763861, -0.8254963, 0.4205821>,
    <-0.3895307, -0.8348453, 0.3889720>,
    <-0.4155953, -0.8205071, 0.3924902>,
    <-0.3478208, -0.8504149, 0.3947343>,
    <-0.3435774, -0.8502266, 0.3988349>,
    <-0.3128619, -0.8608751, 0.4012623>,
    <-0.3153198, -0.8653294, 0.3895876>,
    <-0.3502170, -0.8442653, 0.4056651>,
    <-0.3176971, -0.8695793, 0.3780218>,
    <-0.3232410, -0.8872926, 0.3289789>,
    <-0.3629596, -0.8482202, 0.3857237>,
    <-0.4286731, -0.8233007, 0.3720420>,
    <-0.4024245, -0.8431126, 0.3566731>,
    <-0.4129225, -0.8312100, 0.3722700>,
    <-0.4347268, -0.8163737, 0.3801928>,
    <-0.3799755, -0.8524832, 0.3590139>,
    <-0.4024637, -0.8335068, 0.3785358>,
    <-0.3704554, -0.8755725, 0.3100574>,
    <-0.3992163, -0.8556248, 0.3294428>,
    <-0.4304532, -0.8166396, 0.3844605>,
    <-0.4269658, -0.8345823, 0.3480986>,
    <-0.3880177, 0.8715750, 0.2996653>,
    <-0.4170946, 0.8648584, 0.2793780>,
    <-0.4257363, 0.8580816, 0.2871315>,
    <-0.4101570, 0.8603432, 0.3026233>,
    <-0.4066898, 0.8725428, 0.2706888>,
    <-0.3781170, 0.8848492, 0.2721569>,
    <-0.3227235, 0.8874808, 0.3289793>,
    <-0.3648788, 0.8635339, 0.3480987>,
    <-0.3988353, 0.8558024, 0.3294430>,
    <-0.4481095, 0.8511985, 0.2732380>,
    <-0.4507951, 0.8476441, 0.2797914>,
    <-0.4326033, 0.8465924, 0.3100575>,
    <-0.4416849, 0.8493799, 0.2889087>,
    <-0.4348140, 0.8592917, 0.2693595>,
    <-0.3551392, 0.8575902, 0.3720421>,
    <-0.3871882, 0.8502174, 0.3566731>,
    <-0.3713223, 0.8506084, 0.3722701>,
    <-0.3459415, 0.8577749, 0.3801929>,
    <-0.3146740, 0.8655644, 0.3895876>,
    <-0.3136937, 0.8605724, 0.4012621>,
    <-0.4087965, 0.8390437, 0.3590140>,
    <-0.3798046, 0.8440729, 0.3785359>,
    <-0.3488922, 0.8546720, 0.3844606>,
    <-0.3155846, 0.8703481, 0.3780220>,
    <0.4288203, 0.8790718, -0.2081969>,
    <0.3971002, 0.8713726, -0.2881341>,
    <0.3893124, 0.8908337, -0.2342032>,
    <0.4041453, 0.8972423, -0.1778280>,
    <0.4427957, 0.8788027, -0.1778703>,
    <0.4017759, 0.8753351, -0.2690067>,
    <0.3514176, 0.8474460, -0.3979208>,
    <0.3612936, 0.8943588, -0.2637979>,
    <0.3383702, 0.8165667, -0.4676799>,
    <0.1948832, 0.5474680, -0.8138177>,
    <0.3027569, 0.8011264, -0.5162700>,
    <0.3315978, 0.8928740, -0.3046621>,
    <0.3721667, 0.9108963, -0.1782130>,
    <0.3363787, 0.9203922, -0.1993177>,
    <0.4527158, 0.8697066, -0.1966183>,
    <0.4457672, 0.8208897, -0.3569757>,
    <0.4065992, 0.8184667, -0.4059426>,
    <0.4058380, 0.8678674, -0.2865338>,
    <0.3828864, 0.7054743, -0.5964093>,
    <0.3453675, 0.7149730, -0.6078938>,
    <0.2678528, 0.5092741, -0.8178599>,
    <0.2608243, 0.5586126, -0.7873517>,
    <0.3376052, 0.7830472, -0.5223598>,
    <0.2388979, 0.5865404, -0.7738851>,
    <0.1442502, -0.3489786, -0.9259621>,
    <0.1122564, -0.2530852, -0.9609091>,
    <0.1518893, -0.3035853, -0.9406198>,
    <0.1964086, -0.4065885, -0.8922497>,
    <0.2641317, -0.5671702, -0.7800977>,
    <0.2217062, -0.5412613, -0.8110996>,
    <0.2075252, -0.5668814, -0.7972320>,
    <0.1305031, -0.3203122, -0.9382798>,
    <0.1063283, -0.2407804, -0.9647378>,
    <0.1191043, -0.2253597, -0.9669680>,
    <0.1619632, -0.2828925, -0.9453781>,
    <0.0985008, -0.2064740, -0.9734814>,
    <0.1103861, -0.1911920, -0.9753259>,
    <0.2156513, -0.3849103, -0.8974066>,
    <0.2977793, -0.5672904, -0.7677950>,
    <0.3753544, -0.9061282, -0.1950405>,
    <0.3432051, -0.8708574, -0.3518773>,
    <0.3666756, -0.8399803, -0.3999775>,
    <0.4042734, -0.8698789, -0.2826194>,
    <0.3340459, -0.9214246, -0.1984693>,
    <0.3204438, -0.8981519, -0.3010631>,
    <0.2967442, -0.7522455, -0.5882769>,
    <0.3281471, -0.7295763, -0.6000316>,
    <0.2871547, -0.8179206, -0.4985460>,
    <0.3841052, -0.7662862, -0.5150423>,
    <0.1708039, 0.3269436, -0.9294804>,
    <0.1188252, 0.2423002, -0.9628973>,
    <0.1318118, 0.3043025, -0.9434117>,
    <0.1813946, 0.4033117, -0.8969034>,
    <0.1576738, 0.2982797, -0.9413651>,
    <0.1132104, 0.2301035, -0.9665587>,
    <0.0936319, 0.2302282, -0.9686217>,
    <0.1098216, 0.3001289, -0.9475557>,
    <0.0923949, 0.2026767, -0.9748771>,
    <0.0736837, 0.2024470, -0.9765172>,
    <0.0816317, 0.2483460, -0.9652256>,
    <0.0924475, 0.2802533, -0.9554640>,
    <0.1524733, 0.4068205, -0.9006936>,
    <0.1165037, 0.3567520, -0.9269061>,
    <0.1457150, 0.2834941, -0.9478387>,
    <0.1233865, 0.2373401, -0.9635587>,
    <0.1078426, 0.2185500, -0.9698484>,
    <0.1143836, 0.2383946, -0.9644088>,
    <0.1041938, 0.2086600, -0.9724221>,
    <0.0923619, 0.1918337, -0.9770717>,
    <0.1074845, 0.1861699, -0.9766206>,
    <0.0970805, 0.2081910, -0.9732584>,
    <0.0970805, 0.2081910, -0.9732584>,
    <0.0869260, 0.1864145, -0.9786182>,
    <0.0912417, 0.1958344, -0.9763830>,
    <0.0869260, 0.1864145, -0.9786182>,
    <0.0839804, 0.1800975, -0.9800572>,
    <0.0839804, 0.1800975, -0.9800572>,
    <0.0736837, 0.2024470, -0.9765172>,
    <0.1267612, -0.3015955, -0.9449718>,
    <0.1054440, -0.2541092, -0.9614105>,
    <0.1007947, -0.2292216, -0.9681415>,
    <0.1119815, -0.2472798, -0.9624515>,
    <0.1385758, -0.3541010, -0.9248833>,
    <0.1098343, -0.2787444, -0.9540639>,
    <0.0956421, -0.2202989, -0.9707322>,
    <0.0899682, -0.1993425, -0.9757911>,
    <0.0996065, -0.2494962, -0.9632394>,
    <0.0758519, -0.2083983, -0.9750983>,
    <0.1000107, -0.2144702, -0.9715968>,
    <0.1000107, -0.2144702, -0.9715968>,
    <0.0892815, -0.1914618, -0.9774309>,
    <0.0937702, -0.2009437, -0.9751045>,
    <0.0892815, -0.1914618, -0.9774309>,
    <0.0861801, -0.1848109, -0.9789882>,
    <0.0861801, -0.1848109, -0.9789882>,
    <0.1103861, -0.1911920, -0.9753259>,
    <-0.4182522, -0.8574764, 0.2996652>,
    <-0.3944167, -0.8754333, 0.2793778>,
    <-0.3836706, -0.8776972, 0.2871314>,
    <-0.3954173, -0.8672165, 0.3026232>,
    <-0.4069914, -0.8724022, 0.2706887>,
    <-0.4347850, -0.8584245, 0.2721569>,
    <-0.3640166, -0.8904117, 0.2732380>,
    <-0.3595676, -0.8901843, 0.2797913>,
    <-0.3277039, -0.9021106, 0.2807252>,
    <-0.3294575, -0.9043961, 0.2711559>,
    <-0.3667532, -0.8843212, 0.2889085>,
    <-0.3311663, -0.9065832, 0.2616024>,
    <-0.3342431, -0.9177509, 0.2145109>,
    <-0.3787627, -0.8854289, 0.2693593>,
    <-0.4468176, -0.8583101, 0.2523050>,
    <-0.4182337, -0.8765076, 0.2383590>,
    <-0.4301242, -0.8659998, 0.2550246>,
    <-0.4535285, -0.8517354, 0.2624093>,
    <-0.3948391, -0.8861297, 0.2426441>,
    <-0.4194399, -0.8688249, 0.2630847>,
    <-0.3820653, -0.9032659, 0.1952866>,
    <-0.4128863, -0.8850825, 0.2148346>,
    <-0.4490963, -0.8520470, 0.2689394>,
    <-0.4427768, -0.8655854, 0.2339030>,
    <-0.3980426, 0.8940341, 0.2055850>,
    <-0.4274374, 0.8861338, 0.1790648>,
    <-0.4329200, 0.8723846, 0.2269920>,
    <-0.4140996, 0.8680690, 0.2738207>,
    <-0.4136802, 0.8738167, 0.2555641>,
    <-0.3885773, 0.9041346, 0.1776185>,
    <-0.3338738, 0.9178853, 0.2145109>,
    <-0.3784655, 0.8955742, 0.2339033>,
    <-0.4126144, 0.8852092, 0.2148350>,
    <-0.4584185, 0.8705188, 0.1790237>,
    <-0.4542767, 0.8544174, 0.2521974>,
    <-0.4463549, 0.8732870, 0.1952872>,
    <-0.4305753, 0.8279572, 0.3592935>,
    <-0.4178445, 0.8091908, 0.4130572>,
    <-0.3702949, 0.8939932, 0.2523050>,
    <-0.4026084, 0.8837938, 0.2383590>,
    <-0.3869159, 0.8861481, 0.2550247>,
    <-0.3609447, 0.8949080, 0.2624094>,
    <-0.3289553, 0.9045788, 0.2711560>,
    <-0.3288296, 0.9017008, 0.2807255>,
    <-0.4250171, 0.8720575, 0.2426443>,
    <-0.3959478, 0.8797794, 0.2630849>,
    <-0.3640324, 0.8917129, 0.2689396>,
    <-0.3290522, 0.9073526, 0.2616025>,
    <-0.4289674, -0.8794992, 0.2060781>,
    <-0.4040417, -0.8969767, 0.1793965>,
    <-0.3898901, -0.8921198, 0.2282715>,
    <-0.3985564, -0.8746786, 0.2758444>,
    <-0.4030714, -0.8780593, 0.2579637>,
    <-0.4427461, -0.8787802, 0.1781047>,
    <-0.3721591, -0.9106505, 0.1794807>,
    <-0.3623310, -0.8967269, 0.2541595>,
    <-0.3365533, -0.9206869, 0.1976552>,
    <-0.3331574, -0.8971489, 0.2900516>,
    <-0.3568903, -0.8606096, 0.3632911>,
    <-0.3136680, -0.8358774, 0.4504679>,
    <-0.2385636, -0.6541306, 0.7177748>,
    <-0.3501692, -0.8380245, 0.4184453>,
    <-0.4529657, -0.8701574, 0.1940314>,
    <-0.4076112, -0.8713831, 0.2730285>,
    <-0.4115642, -0.8284369, 0.3798778>,
    <-0.4493014, -0.8276580, 0.3363191>,
    <-0.3508660, -0.8074556, 0.4742452>,
    <-0.3619355, -0.7493478, 0.5545092>,
    <-0.2746682, -0.6583514, 0.7008073>,
    <-0.2941846, -0.6300687, 0.7186577>,
    <-0.4010322, -0.7427146, 0.5362352>,
    <-0.3122953, -0.6017797, 0.7350734>,
    <-0.1958426, 0.4579014, 0.8671632>,
    <-0.2406245, 0.4995345, 0.8322050>,
    <-0.1929633, 0.3895053, 0.9005836>,
    <-0.1555597, 0.3412501, 0.9270111>,
    <-0.1430241, 0.3233647, 0.9354033>,
    <-0.1699273, 0.4168044, 0.8929719>,
    <-0.2407090, 0.6626781, 0.7091663>,
    <-0.2637570, 0.6342075, 0.7267827>,
    <-0.2971238, 0.6380059, 0.7103984>,
    <-0.2574454, 0.4740649, 0.8420121>,
    <-0.1966842, 0.3572916, 0.9130488>,
    <-0.3313428, 0.6407012, 0.6926138>,
    <-0.1527222, 0.2952544, 0.9431335>,
    <-0.1378435, 0.2857790, 0.9483299>,
    <-0.3755267, 0.9065790, 0.1925986>,
    <-0.4057604, 0.8733566, 0.2694562>,
    <-0.3709737, 0.8498528, 0.3743377>,
    <-0.3460212, 0.8776645, 0.3316237>,
    <-0.3219472, 0.9022860, 0.2867577>,
    <-0.3340961, 0.9217464, 0.1968843>,
    <-0.3944637, 0.7911725, 0.4673805>,
    <-0.3434627, 0.7635464, 0.5468365>,
    <-0.3132062, 0.7891172, 0.5283900>,
    <-0.2983252, 0.8450464, 0.4437327>,
    <-0.2199727, -0.4341887, 0.8735515>,
    <-0.2237091, -0.4959222, 0.8390563>,
    <-0.1700086, -0.3882860, 0.9057213>,
    <-0.1563133, -0.3274900, 0.9318350>,
    <-0.1501682, -0.3066505, 0.9399016>,
    <-0.2047754, -0.3879996, 0.8986230>,
    <-0.1940231, -0.4932039, 0.8480006>,
    <-0.1436386, -0.3715433, 0.9172369>,
    <-0.1531223, -0.4419209, 0.8838889>,
    <-0.1212932, -0.3506264, 0.9286275>,
    <-0.1232444, -0.2960487, 0.9471885>,
    <-0.1099774, -0.3112280, 0.9439503>,
    <-0.1241989, -0.2787388, 0.9523021>,
    <-0.1850432, -0.3547403, 0.9164706>,
    <-0.1506707, -0.3104490, 0.9385733>,
    <-0.1465578, -0.2944462, 0.9443634>,
    <-0.1620487, -0.3079165, 0.9375114>,
    <-0.1317481, -0.2871120, 0.9487935>,
    <-0.1374955, -0.2836767, 0.9490113>,
    <-0.1486736, -0.2875761, 0.9461481>,
    <-0.1564026, 0.3797683, 0.9117644>,
    <-0.1444139, 0.3250505, 0.9346051>,
    <-0.1340486, 0.3114953, 0.9407453>,
    <-0.1343063, 0.3319254, 0.9336956>,
    <-0.1347343, 0.3545458, 0.9252805>,
    <-0.1700315, 0.4462615, 0.8786011>,
    <-0.1364934, 0.2926611, 0.9464243>,
    <-0.1306483, 0.2973902, 0.9457749>,
    <-0.1253628, 0.3091952, 0.9426996>,
    <-0.1158010, 0.3150991, 0.9419675>,
    <0.1035763, 0.3850705, -0.9170565>,
    <0.1033376, 0.3804349, -0.9190161>,
    <0.1019013, 0.3713800, -0.9228721>,
    <0.1019625, 0.3739789, -0.9218153>,
    <0.1065350, 0.3892500, -0.9149507>,
    <0.1047469, 0.3893624, -0.9151093>,
    <0.1049302, 0.3916448, -0.9141138>,
    <0.1046198, 0.3905021, -0.9146381>,
    <0.1046198, 0.3905021, -0.9146381>,
    <0.1025600, 0.3828266, -0.9181096>,
    <0.1016921, 0.3642077, -0.9257491>,
    <0.1026746, 0.3610091, -0.9268928>,
    <0.1025600, 0.3828266, -0.9181096>,
    <0.0968172, 0.3614031, -0.9273695>,
    <0.0968172, 0.3614031, -0.9273695>,
    <0.0977962, 0.3141456, -0.9443243>,
    <0.1022815, 0.3615512, -0.9267250>,
    <0.1108497, 0.3881741, -0.9148952>,
    <0.1023868, -0.3812242, -0.9187954>,
    <0.0980365, -0.3609841, -0.9274046>,
    <0.0987773, -0.3627083, -0.9266530>,
    <0.1026149, -0.3794482, -0.9195049>,
    <0.1031102, -0.3848051, -0.9172204>,
    <0.1046937, -0.3907046, -0.9145432>,
    <0.1046937, -0.3907046, -0.9145432>,
    <0.1049125, -0.3915039, -0.9141762>,
    <0.1040630, -0.3860120, -0.9166055>,
    <0.1050020, -0.3813237, -0.9184590>,
    <0.0955095, -0.3408342, -0.9352593>,
    <0.0981360, -0.3509115, -0.9312521>,
    <0.1094056, -0.3770179, -0.9197217>,
    <0.1006951, -0.3654850, -0.9253547>,
    <0.0968408, -0.3254291, -0.9405944>,
    <0.0986073, -0.3680056, -0.9245801>,
    <0.0986073, -0.3680056, -0.9245801>,
    <0.1031102, -0.3848051, -0.9172204>,
    <-0.1377474, 0.4548537, 0.8798487>,
    <-0.1420033, 0.4477123, 0.8828300>,
    <-0.1476750, 0.4484545, 0.8815218>,
    <-0.1402253, 0.4453660, 0.8842997>,
    <-0.1274547, 0.4317872, 0.8929250>,
    <-0.1242478, 0.4299346, 0.8942699>,
    <-0.1230901, 0.4272361, 0.8957221>,
    <-0.1398893, 0.4641185, 0.8746571>,
    <-0.1398893, 0.4641185, 0.8746571>,
    <-0.1328717, 0.4408355, 0.8876988>,
    <-0.1341471, 0.4040345, 0.9048539>,
    <-0.1540260, 0.4396237, 0.8848768>,
    <-0.1328717, 0.4408355, 0.8876988>,
    <-0.1138092, 0.3775909, 0.9189519>,
    <-0.1138092, 0.3775909, 0.9189519>,
    <-0.1107527, 0.3226131, 0.9400290>,
    <-0.1567879, 0.4582291, 0.8748963>,
    <-0.1372516, 0.4454833, 0.8847071>,
    <0.0981520, 0.3764739, -0.9212131>,
    <0.0854066, 0.3496464, -0.9329808>,
    <0.0792793, 0.3575081, -0.9305390>,
    <0.0878437, 0.3674712, -0.9258771>,
    <0.0974661, 0.3637481, -0.9263842>,
    <0.1039777, 0.3880501, -0.9157542>,
    <0.1039777, 0.3880501, -0.9157542>,
    <0.1049502, 0.3916802, -0.9140963>,
    <0.1010264, 0.3783342, -0.9201396>,
    <0.0913538, 0.3502572, -0.9321879>,
    <0.0683459, 0.3381141, -0.9386201>,
    <0.0632430, 0.3535303, -0.9332827>,
    <0.0803962, 0.3265042, -0.9417704>,
    <0.0724776, 0.4249159, -0.9023267>,
    <0.0483631, 0.3598619, -0.9317513>,
    <0.0467820, 0.3617979, -0.9310820>,
    <0.0674083, 0.3468210, -0.9355059>,
    <0.0442494, 0.3453493, -0.9374304>,
    <0.0417961, 0.3266408, -0.9442239>,
    <0.0817915, 0.3052492, -0.9487534>,
    <0.0817915, 0.3052492, -0.9487534>,
    <0.0974661, 0.3637481, -0.9263842>,
    <0.1024497, 0.3832121, -0.9179611>,
    <0.1032775, 0.3854447, -0.9169330>,
    <0.0986076, 0.3680131, -0.9245771>,
    <0.0952238, 0.3586851, -0.9285889>,
    <0.1049502, 0.3916802, -0.9140963>,
    <0.1049499, 0.3916825, -0.9140954>,
    <0.1049499, 0.3916825, -0.9140954>,
    <0.1049488, 0.3916862, -0.9140939>,
    <0.1027146, 0.3831310, -0.9179653>,
    <0.0972691, 0.3643930, -0.9261514>,
    <0.1049488, 0.3916862, -0.9140939>,
    <0.1049453, 0.3916849, -0.9140949>,
    <0.1049453, 0.3916849, -0.9140949>,
    <0.1049302, 0.3916448, -0.9141138>,
    <0.1033273, 0.3877388, -0.9159597>,
    <0.1008234, 0.3856813, -0.9171066>,
    <0.0897212, 0.3422227, -0.9353255>,
    <0.0951449, 0.3840647, -0.9183908>,
    <0.1058813, 0.3966317, -0.9118511>,
    <0.1115960, 0.4093278, -0.9055369>,
    <0.1125762, 0.4239083, -0.8986814>,
    <0.1072898, 0.4132977, -0.9042532>,
    <0.1049302, 0.3916448, -0.9141138>,
    <0.1211873, 0.4325782, -0.8934146>,
    <0.1188101, 0.4498787, -0.8851516>,
    <0.1421814, 0.4991226, -0.8547871>,
    <0.1328198, 0.5110541, -0.8492247>,
    <0.1103251, 0.4442534, -0.8890823>,
    <0.1185376, 0.5062623, -0.8541940>,
    <0.1067065, -0.3961280, -0.9119739>,
    <0.1088227, -0.4118321, -0.9047386>,
    <0.1147919, -0.4234670, -0.8986092>,
    <0.1133933, -0.4095764, -0.9052012>,
    <0.1049125, -0.3915039, -0.9141762>,
    <0.1044295, -0.3907801, -0.9145411>,
    <0.1037655, -0.3932955, -0.9135378>,
    <0.1125331, -0.4375134, -0.8921425>,
    <0.1226266, -0.4495477, -0.8847992>,
    <0.0999353, -0.3937169, -0.9137833>,
    <0.0779656, -0.4224048, -0.9030479>,
    <0.1275047, -0.5047110, -0.8538205>,
    <0.1412578, -0.5098371, -0.8485943>,
    <0.1262317, -0.4375720, -0.8902788>,
    <0.1507487, -0.4972326, -0.8544206>,
    <0.1456858, -0.5552699, -0.8188107>,
    <0.1583865, -0.5599197, -0.8132673>,
    <0.1652236, -0.5576748, -0.8134494>,
    <0.1581231, -0.5524783, -0.8183916>,
    <0.1354207, -0.5564132, -0.8197961>,
    <0.1572746, -0.5794944, -0.7996568>,
    <0.1809327, -0.5736559, -0.7988631>,
    <0.1788224, -0.5547311, -0.8125860>,
    <0.1808240, -0.5968005, -0.7817492>,
    <0.1683652, -0.5331485, -0.8290994>,
    <0.1039021, -0.3877031, -0.9159098>,
    <0.1040989, -0.3884692, -0.9155627>,
    <0.1017985, -0.3798923, -0.9194123>,
    <0.1013692, -0.3795811, -0.9195882>,
    <0.1049125, -0.3915039, -0.9141762>,
    <0.1049043, -0.3914592, -0.9141962>,
    <0.1049043, -0.3914592, -0.9141962>,
    <0.1048980, -0.3914392, -0.9142055>,
    <0.1035486, -0.3871675, -0.9161763>,
    <0.0992024, -0.3736476, -0.9222507>,
    <0.1048980, -0.3914392, -0.9142055>,
    <0.1048916, -0.3914476, -0.9142027>,
    <0.1048916, -0.3914476, -0.9142027>,
    <0.1048811, -0.3914921, -0.9141848>,
    <0.1021099, -0.3831111, -0.9180411>,
    <0.0940096, -0.3649395, -0.9262728>,
    <0.0960974, -0.3658958, -0.9256811>,
    <0.0840634, -0.3506539, -0.9327246>,
    <0.0972948, -0.3792407, -0.9201686>,
    <0.0832434, -0.3672018, -0.9264089>,
    <0.0741434, -0.3610636, -0.9295891>,
    <0.0837204, -0.3588853, -0.9296194>,
    <0.1048811, -0.3914921, -0.9141848>,
    <0.1036759, -0.3871361, -0.9161752>,
    <0.1036759, -0.3871361, -0.9161752>,
    <0.0958177, -0.3579844, -0.9287982>,
    <0.0606331, -0.3483937, -0.9353852>,
    <0.0563696, -0.3536736, -0.9336688>,
    <0.0958177, -0.3579844, -0.9287982>,
    <0.0777636, -0.2907798, -0.9536246>,
    <0.0777636, -0.2907798, -0.9536246>,
    <0.0388721, -0.3375243, -0.9405138>,
    <0.0404244, -0.3503151, -0.9357591>,
    <0.0414668, -0.3545862, -0.9341034>,
    <0.0634914, -0.3433453, -0.9370608>,
    <0.0419912, -0.3409704, -0.9391357>,
    <-0.1052017, 0.3973153, 0.9116321>,
    <-0.1111533, 0.4101297, 0.9052285>,
    <-0.1117638, 0.4094546, 0.9054589>,
    <-0.1098476, 0.4064233, 0.9070577>,
    <-0.1099268, 0.4137561, 0.9037267>,
    <-0.0864172, 0.3584955, 0.9295230>,
    <-0.0337083, 0.2814350, 0.9589881>,
    <-0.1085329, 0.4050437, 0.9078327>,
    <-0.1085329, 0.4050437, 0.9078327>,
    <-0.1085716, 0.4051880, 0.9077637>,
    <-0.1144578, 0.4141045, 0.9030043>,
    <-0.1169235, 0.4169436, 0.9013806>,
    <-0.1085716, 0.4051880, 0.9077637>,
    <-0.1058760, 0.3951282, 0.9125042>,
    <-0.1058760, 0.3951282, 0.9125042>,
    <-0.1230901, 0.4272361, 0.8957221>,
    <-0.1182762, 0.4199476, 0.8998082>,
    <-0.1332757, 0.4623667, 0.8766154>,
    <0.1520161, 0.5537453, -0.8186924>,
    <0.1430992, 0.5641450, -0.8131808>,
    <0.1359283, 0.5650695, -0.8137690>,
    <0.1395555, 0.5567327, -0.8188852>,
    <0.1618908, 0.5518050, -0.8181092>,
    <0.1539931, 0.5815701, -0.7987880>,
    <0.1302141, 0.5871565, -0.7989315>,
    <0.1225316, 0.5693889, -0.8128852>,
    <0.1419245, 0.6075644, -0.7814876>,
    <0.1203469, 0.6807756, -0.7225380>,
    <0.1103225, 0.6200936, -0.7767322>,
    <0.1038979, 0.5810659, -0.8071974>,
    <0.1208423, 0.5451707, -0.8295698>,
    <0.0959504, 0.5345465, -0.8396747>,
    <0.1752033, 0.5571307, -0.8117322>,
    <0.1874330, 0.5759895, -0.7956789>,
    <0.1758529, 0.5965960, -0.7830383>,
    <0.1667821, 0.6008290, -0.7817853>,
    <0.1921640, 0.5994748, -0.7769832>,
    <0.1731394, 0.6126665, -0.7711436>,
    <0.1986547, 0.6461704, -0.7368854>,
    <0.1790053, 0.6671638, -0.7230834>,
    <0.1573399, 0.6285635, -0.7616772>,
    <0.1582915, 0.6883369, -0.7079097>,
    <0.1757856, -0.7044625, -0.6876278>,
    <0.1954877, -0.7050001, -0.6817326>,
    <0.2087011, -0.7100061, -0.6725587>,
    <0.2006876, -0.7120943, -0.6727899>,
    <0.1785585, -0.6672829, -0.7230839>,
    <0.1510450, -0.6589269, -0.7368858>,
    <0.1197499, -0.6808809, -0.7225380>,
    <0.1705575, -0.7304809, -0.6612926>,
    <0.1959060, -0.7319842, -0.6525488>,
    <0.2242763, -0.7127871, -0.6645560>,
    <0.2308976, -0.7114634, -0.6637063>,
    <0.2212755, -0.7318862, -0.6444996>,
    <0.2271601, -0.7101699, -0.6663760>,
    <0.2070838, -0.6752625, -0.7079103>,
    <0.1263886, -0.5680860, -0.8132061>,
    <0.1254935, -0.5917414, -0.7962999>,
    <0.1457981, -0.6037378, -0.7837369>,
    <0.1556160, -0.6022440, -0.7829980>,
    <0.0925448, -0.5345705, -0.8400416>,
    <0.1010579, -0.5813733, -0.8073366>,
    <0.1332742, -0.6150434, -0.7771484>,
    <0.1563285, -0.6169117, -0.7713503>,
    <0.1084031, -0.6203816, -0.7767724>,
    <0.1778954, -0.6225718, -0.7620746>,
    <-0.1188198, -0.4411124, 0.8895514>,
    <-0.1073472, -0.4202279, 0.9010467>,
    <-0.1025625, -0.4295801, 0.8971855>,
    <-0.1095402, -0.4354395, 0.8935286>,
    <-0.1164786, -0.4403627, 0.8902322>,
    <-0.1227994, -0.4501642, 0.8844617>,
    <-0.1258698, -0.4594175, 0.8792567>,
    <-0.1226065, -0.4415834, 0.8888036>,
    <-0.1226065, -0.4415834, 0.8888036>,
    <-0.1121859, -0.4040522, 0.9078305>,
    <-0.0882120, -0.3714815, 0.9242403>,
    <-0.0902342, -0.4219445, 0.9021201>,
    <-0.1121859, -0.4040522, 0.9078305>,
    <-0.0926284, -0.3336135, 0.9381482>,
    <-0.0926284, -0.3336135, 0.9381482>,
    <-0.0629073, -0.3709337, 0.9265262>,
    <-0.0650198, -0.3435950, 0.9368644>,
    <-0.0723399, -0.4199740, 0.9046484>,
    <-0.0992872, -0.4529756, 0.8859769>,
    <-0.0822169, -0.4865295, 0.8697870>,
    <-0.1128107, -0.5884108, 0.8006538>,
    <-0.1120780, -0.4527417, 0.8845696>,
    <-0.1230979, -0.4535408, 0.8826934>,
    <-0.1246636, -0.4629446, 0.8775770>,
    <-0.1224240, -0.4538491, 0.8826287>,
    <-0.1220411, -0.4529232, 0.8831572>,
    <-0.1260160, -0.4686901, 0.8743281>,
    <-0.1200138, -0.4198640, 0.8996171>,
    <-0.1240682, -0.3348315, 0.9340744>,
    <-0.1245663, -0.4638317, 0.8771222>,
    <-0.1245663, -0.4638317, 0.8771222>,
    <-0.1256072, -0.4677073, 0.8749130>,
    <-0.1244379, -0.4606117, 0.8788356>,
    <-0.1205194, -0.4489510, 0.8853915>,
    <-0.1256072, -0.4677073, 0.8749130>,
    <-0.1265343, -0.4711595, 0.8729248>,
    <-0.1265343, -0.4711595, 0.8729248>,
    <-0.1258698, -0.4594175, 0.8792567>,
    <-0.1187947, -0.4495200, 0.8853359>,
    <-0.1275373, -0.5063354, 0.8528533>,
    <-0.1252909, -0.4027292, 0.9067036>,
    <-0.1332539, -0.4807956, 0.8666481>,
    <-0.1404849, -0.4840230, 0.8637046>,
    <-0.1409212, -0.4491891, 0.8822530>,
    <-0.1240682, -0.3348315, 0.9340744>,
    <-0.1412820, -0.5545685, 0.8200568>,
    <-0.1493211, -0.5333135, 0.8326343>,
    <-0.1525073, -0.6426124, 0.7508601>,
    <-0.1663539, -0.6179890, 0.7683853>,
    <-0.1563683, -0.5045504, 0.8491041>,
    <-0.1793494, -0.5884373, 0.7884005>,
    <-0.1671710, 0.6709664, 0.7223974>,
    <-0.1855941, 0.6660037, 0.7224915>,
    <-0.2005334, 0.6874960, 0.6979510>,
    <-0.1927571, 0.6950503, 0.6926397>,
    <-0.1945688, 0.7256885, 0.6599388>,
    <-0.1659344, 0.7093019, 0.6850960>,
    <-0.0959671, 0.6001568, 0.7941046>,
    <-0.1301441, 0.5747374, 0.8079229>,
    <-0.1552027, 0.5871034, 0.7944946>,
    <-0.2089147, 0.6651607, 0.7168793>,
    <-0.2222541, 0.6919943, 0.6868385>,
    <-0.1810200, 0.6026141, 0.7772310>,
    <-0.2227592, 0.7097511, 0.6683051>,
    <-0.2214319, 0.7323416, 0.6439283>,
    <-0.0707213, 0.3453536, 0.9358041>,
    <-0.1061889, 0.4228501, 0.8999565>,
    <-0.1023281, 0.4348756, 0.8946576>,
    <-0.0834855, 0.4060443, 0.9100320>,
    <-0.0611713, 0.3876274, 0.9197842>,
    <-0.0389109, 0.3025991, 0.9523233>,
    <-0.0337083, 0.2814350, 0.9589881>,
    <-0.1407584, 0.5020585, 0.8533020>,
    <-0.1231521, 0.4921632, 0.8617476>,
    <-0.1036721, 0.4796019, 0.8713404>,
    <-0.0810050, 0.4749788, 0.8762610>,
    <0.1999965, 0.6979756, -0.6876274>,
    <0.1832028, 0.7082922, -0.6817323>,
    <0.1742627, 0.7192344, -0.6725581>,
    <0.1822467, 0.7170361, -0.6727893>,
    <0.2175333, 0.7178937, -0.6612926>,
    <0.1963325, 0.7318699, -0.6525488>,
    <0.1621646, 0.7294302, -0.6645556>,
    <0.1557685, 0.7315948, -0.6637057>,
    <0.1743129, 0.7444697, -0.6444997>,
    <0.1412954, 0.7994868, -0.5838292>,
    <0.1347567, 0.7589890, -0.6370058>,
    <0.1318262, 0.7455806, -0.6532468>,
    <0.1583586, 0.7286059, -0.6663753>,
    <0.1287414, 0.7311628, -0.6699452>,
    <0.2311608, 0.7327313, -0.6400543>,
    <0.2371659, 0.7285910, -0.6425788>,
    <0.2187239, 0.7421340, -0.6335590>,
    <0.2097652, 0.7549219, -0.6213626>,
    <0.2344768, 0.7308324, -0.6410184>,
    <0.2100406, 0.7433414, -0.6350799>,
    <0.2346993, 0.7631763, -0.6020616>,
    <0.2102512, 0.7837265, -0.5844376>,
    <0.1906199, 0.7623874, -0.6184088>,
    <0.1847188, 0.8038160, -0.5654722>,
    <0.2020623, -0.8103772, -0.5499632>,
    <0.2231843, -0.8053227, -0.5492214>,
    <0.2382029, -0.8102441, -0.5355033>,
    <0.2299770, -0.8158985, -0.5304906>,
    <0.2097806, -0.7838531, -0.5844368>,
    <0.1783328, -0.7782802, -0.6020610>,
    <0.1406664, -0.7995979, -0.5838289>,
    <0.1940117, -0.8312733, -0.5209071>,
    <0.2214289, -0.8272293, -0.5163922>,
    <0.2539506, -0.8069637, -0.5332155>,
    <0.2625143, -0.8082737, -0.5270483>,
    <0.2486725, -0.8220388, -0.5122638>,
    <0.2597335, -0.8113101, -0.5237503>,
    <0.2419371, -0.7884849, -0.5654715>,
    <0.1661747, -0.7501447, -0.6400538>,
    <0.1589041, -0.7495618, -0.6425781>,
    <0.1816468, -0.7520693, -0.6335583>,
    <0.1957991, -0.7586645, -0.6213621>,
    <0.1290951, -0.7311005, -0.6699452>,
    <0.1311275, -0.7457039, -0.6532467>,
    <0.1623536, -0.7501584, -0.6410176>,
    <0.1897705, -0.7487734, -0.6350792>,
    <0.1329597, -0.7593060, -0.6370056>,
    <0.2161122, -0.7555572, -0.6184083>,
    <-0.1931542, -0.6782750, 0.7089672>,
    <-0.1760416, -0.6868782, 0.7051295>,
    <-0.1719149, -0.7046648, 0.6883987>,
    <-0.1815706, -0.7037604, 0.6868431>,
    <-0.1944773, -0.7273579, 0.6581254>,
    <-0.2111343, -0.7014617, 0.6807156>,
    <-0.1548960, -0.6943183, 0.7028010>,
    <-0.1546604, -0.7164604, 0.6802681>,
    <-0.1257607, -0.6998584, 0.7031233>,
    <-0.1307565, -0.7327175, 0.6678532>,
    <-0.1622365, -0.7278340, 0.6662860>,
    <-0.1347160, -0.7571660, 0.6391801>,
    <-0.1413276, -0.7994724, 0.5838410>,
    <-0.1744192, -0.7451298, 0.6437077>,
    <-0.2256361, -0.7151317, 0.6615701>,
    <-0.2076246, -0.7472001, 0.6313351>,
    <-0.2174437, -0.7376887, 0.6391664>,
    <-0.2345822, -0.7203657, 0.6527208>,
    <-0.1904475, -0.7612939, 0.6198075>,
    <-0.2102882, -0.7441178, 0.6340880>,
    <-0.1844797, -0.8024773, 0.5674482>,
    <-0.2102742, -0.7837117, 0.5844490>,
    <-0.2345171, -0.7310673, 0.6407358>,
    <-0.2350831, -0.7644541, 0.6002882>,
    <-0.2021120, 0.8103565, 0.5499755>,
    <-0.2294812, 0.8142448, 0.5332390>,
    <-0.2381724, 0.8102451, 0.5355155>,
    <-0.2236616, 0.8068879, 0.5467242>,
    <-0.2214042, 0.8272282, 0.5164046>,
    <-0.1937515, 0.8300442, 0.5229599>,
    <-0.1406311, 0.7995952, 0.5838411>,
    <-0.1786389, 0.7795780, 0.6002885>,
    <-0.2097529, 0.7838511, 0.5844494>,
    <-0.2590392, 0.8095174, 0.5268588>,
    <-0.2624132, 0.8082983, 0.5270609>,
    <-0.2414744, 0.7872054, 0.5674485>,
    <-0.2544551, 0.8086682, 0.5303851>,
    <-0.2489347, 0.8231656, 0.5103234>,
    <-0.1623179, 0.7332544, 0.6602960>,
    <-0.1938038, 0.7512944, 0.6308698>,
    <-0.1806821, 0.7481985, 0.6383987>,
    <-0.1572662, 0.7420588, 0.6516257>,
    <-0.1279096, 0.7334585, 0.6675911>,
    <-0.1218111, 0.7018474, 0.7018350>,
    <-0.2157406, 0.7546506, 0.6196438>,
    <-0.1899813, 0.7497165, 0.6339025>,
    <-0.1624846, 0.7505842, 0.6404859>,
    <-0.1324014, 0.7576249, 0.6391200>,
    <0.2301976, 0.8028380, -0.5499638>,
    <0.2093781, 0.8090217, -0.5492218>,
    <0.1988323, 0.8207930, -0.5355040>,
    <0.2087833, 0.8215768, -0.5304914>,
    <0.2476176, 0.8169095, -0.5209072>,
    <0.2218516, 0.8271160, -0.5163923>,
    <0.1835542, 0.8258260, -0.5332159>,
    <0.1767928, 0.8312423, -0.5270490>,
    <0.1956627, 0.8362427, -0.5122638>,
    <0.1552174, 0.8785648, -0.4516984>,
    <0.1510122, 0.8502825, -0.5041974>,
    <0.1489753, 0.8428633, -0.5170955>,
    <0.1807192, 0.8324814, -0.5237511>,
    <0.1468691, 0.8350312, -0.5302380>,
    <0.2606896, 0.8264682, -0.4989903>,
    <0.2668849, 0.8196100, -0.5069633>,
    <0.2450441, 0.8315843, -0.4984184>,
    <0.2343914, 0.8441623, -0.4821313>,
    <0.2627568, 0.8186606, -0.5106404>,
    <0.2347488, 0.8309317, -0.5044259>,
    <0.2591561, 0.8426376, -0.4720170>,
    <0.2310560, 0.8614336, -0.4522667>,
    <0.2120748, 0.8489133, -0.4841183>,
    <0.2019522, 0.8792659, -0.4314009>,
    <0.2194797, -0.8805225, -0.4201294>,
    <0.2419115, -0.8730902, -0.4233111>,
    <0.2577231, -0.8764665, -0.4066759>,
    <0.2489195, -0.8829318, -0.3980835>,
    <0.2306163, -0.8615510, -0.4522675>,
    <0.1968829, -0.8593233, -0.4720177>,
    <0.1546300, -0.8786680, -0.4516991>,
    <0.2092367, -0.8966071, -0.3902766>,
    <0.2382534, -0.8899173, -0.3889505>,
    <0.2740154, -0.8705427, -0.4087431>,
    <0.2834143, -0.8721375, -0.3988140>,
    <0.2669956, -0.8822209, -0.3878140>,
    <0.2807275, -0.8763587, -0.3913917>,
    <0.2647371, -0.8624424, -0.4314016>,
    <0.1874702, -0.8460870, -0.4989906>,
    <0.1786758, -0.8432452, -0.5069640>,
    <0.2035776, -0.8426949, -0.4984190>,
    <0.2190922, -0.8482615, -0.4821317>,
    <0.1475857, -0.8349050, -0.5302378>,
    <0.1482851, -0.8429850, -0.5170956>,
    <0.1817761, -0.8403589, -0.5106411>,
    <0.2121672, -0.8369820, -0.5044266>,
    <0.1489085, -0.8506532, -0.5041978>,
    <0.2407944, -0.8412176, -0.4841188>,
    <-0.2301441, -0.8028455, 0.5499752>,
    <-0.2083858, -0.8198975, 0.5332386>,
    <-0.1988591, -0.8207792, 0.5355153>,
    <-0.2097473, -0.8106163, 0.5467241>,
    <-0.2218723, -0.8271028, 0.5164046>,
    <-0.2472283, -0.8157151, 0.5229598>,
    <-0.1804242, -0.8305824, 0.5268585>,
    <-0.1768926, -0.8312136, 0.5270607>,
    <-0.1467992, -0.8341172, 0.5316940>,
    <-0.1490114, -0.8428492, 0.5171082>,
    <-0.1839695, -0.8275548, 0.5303850>,
    <-0.1511418, -0.8510924, 0.5027901>,
    <-0.1552475, -0.8785485, 0.4517198>,
    <-0.1959990, -0.8373496, 0.5103236>,
    <-0.2601690, -0.8247152, 0.5021524>,
    <-0.2340628, -0.8426229, 0.4849756>,
    <-0.2450691, -0.8315678, 0.4984337>,
    <-0.2668496, -0.8196128, 0.5069774>,
    <-0.2121683, -0.8488799, 0.4841359>,
    <-0.2351852, -0.8323783, 0.5018310>,
    <-0.2017794, -0.8782334, 0.4335795>,
    <-0.2310771, -0.8614166, 0.4522883>,
    <-0.2632392, -0.8202985, 0.5077553>,
    <-0.2594615, -0.8436574, 0.4700234>,
    <-0.2195265, 0.8804997, 0.4201529>,
    <-0.2485433, 0.8816938, 0.4010514>,
    <-0.2576946, 0.8764645, 0.4066982>,
    <-0.2422902, 0.8743031, 0.4205824>,
    <-0.2382302, 0.8899139, 0.3889726>,
    <-0.2090472, 0.8956842, 0.3924908>,
    <-0.1545963, 0.8786634, 0.4517197>,
    <-0.1971284, 0.8603597, 0.4700230>,
    <-0.2305897, 0.8615475, 0.4522878>,
    <-0.2801899, 0.8750306, 0.3947342>,
    <-0.2833195, 0.8721586, 0.3988351>,
    <-0.2643706, 0.8614624, 0.4335789>,
    <-0.2744014, 0.8718598, 0.4056654>,
    <-0.2671821, 0.8830802, 0.3857242>,
    <-0.1870446, 0.8443089, 0.5021522>,
    <-0.2186071, 0.8467643, 0.4849754>,
    <-0.2035479, 0.8426936, 0.4984334>,
    <-0.1787079, 0.8432305, 0.5069771>,
    <-0.1482465, 0.8429841, 0.5171081>,
    <-0.1473387, 0.8340220, 0.5316941>,
    <-0.2406968, 0.8412358, 0.4841356>,
    <-0.2125129, 0.8384536, 0.5018305>,
    <-0.1821775, 0.8420192, 0.5077549>,
    <-0.1490639, 0.8514589, 0.5027900>,
    <0.2501863, 0.8722950, -0.4201289>,
    <0.2270436, 0.8770742, -0.4233108>,
    <0.2150385, 0.8879041, -0.4066752>,
    <0.2258953, 0.8891015, -0.3980827>,
    <0.2670993, 0.8811028, -0.3902765>,
    <0.2386252, 0.8898177, -0.3889504>,
    <0.1979671, 0.8909200, -0.4087427>,
    <0.1906247, 0.8970006, -0.3988133>,
    <0.2098855, 0.8975235, -0.3878139>,
    <0.1642267, 0.9299472, -0.3289800>,
    <0.1617777, 0.9109235, -0.3795344>,
    <0.1602349, 0.9069521, -0.3895674>,
    <0.1950622, 0.8993130, -0.3913909>,
    <0.1586573, 0.9028200, -0.3996798>,
    <0.2795730, 0.8865180, -0.3686797>,
    <0.2863964, 0.8794563, -0.3801758>,
    <0.2622890, 0.8902983, -0.3722546>,
    <0.2501255, 0.9013067, -0.3536714>,
    <0.2817473, 0.8777241, -0.3875807>,
    <0.2512777, 0.8896304, -0.3813361>,
    <0.2753313, 0.8952798, -0.3502381>,
    <0.2445535, 0.9119541, -0.3294439>,
    <0.2260822, 0.9055408, -0.3590023>,
    <0.2128934, 0.9273208, -0.3078189>,
    <0.2307242, -0.9257220, -0.2996752>,
    <0.2542400, -0.9176171, -0.3055175>,
    <0.2702840, -0.9189642, -0.2871433>,
    <0.2608344, -0.9249813, -0.2763603>,
    <0.2441877, -0.9120522, -0.3294436>,
    <0.2091962, -0.9130008, -0.3502377>,
    <0.1637381, -0.9300335, -0.3289795>,
    <0.2188358, -0.9376855, -0.2699201>,
    <0.2490106, -0.9299000, -0.2707023>,
    <0.2872061, -0.9122275, -0.2921534>,
    <0.2968374, -0.9130157, -0.2798033>,
    <0.2788755, -0.9211341, -0.2715519>,
    <0.2938778, -0.9169623, -0.2698445>,
    <0.2792894, -0.9095302, -0.3078186>,
    <0.2011418, -0.9075338, -0.3686794>,
    <0.1917017, -0.9048299, -0.3801753>,
    <0.2180003, -0.9021656, -0.3722542>,
    <0.2340384, -0.9056173, -0.3536711>,
    <0.1596933, -0.9026371, -0.3996802>,
    <0.1596242, -0.9070597, -0.3895675>,
    <0.1948619, -0.9010052, -0.3875802>,
    <0.2272025, -0.8960815, -0.3813357>,
    <0.1595328, -0.9113194, -0.3795341>,
    <0.2569776, -0.8972625, -0.3590020>,
    <0.2630481, 0.9170607, -0.2996755>,
    <0.2386304, 0.9217996, -0.3055177>,
    <0.2254095, 0.9309883, -0.2871436>,
    <0.2366015, 0.9314744, -0.2763605>,
    <0.2793254, 0.9214772, -0.2699203>,
    <0.2493006, 0.9298222, -0.2707025>,
    <0.2073861, 0.9336152, -0.2921535>,
    <0.1994392, 0.9391134, -0.2798035>,
    <0.2190539, 0.9371632, -0.2715520>,
    <0.1697801, 0.9618524, -0.2145103>,
    <0.1686546, 0.9498883, -0.2631880>,
    <0.1673785, 0.9478673, -0.2711678>,
    <0.2039756, 0.9410514, -0.2698447>,
    <0.1660825, 0.9457819, -0.2791294>,
    <0.2912290, 0.9237035, -0.2489129>,
    <0.2987724, 0.9175350, -0.2624205>,
    <0.2731913, 0.9275365, -0.2550346>,
    <0.2597956, 0.9365483, -0.2353372>,
    <0.2940818, 0.9162009, -0.2721980>,
    <0.2619636, 0.9276947, -0.2660029>,
    <0.2856011, 0.9288099, -0.2361020>,
    <0.2529062, 0.9433370, -0.2148341>,
    <0.2348839, 0.9412492, -0.2426511>,
    <0.2194634, 0.9563357, -0.1930227>,
    <0.2365930, -0.9491774, -0.2075717>,
    <0.2561102, -0.9235030, -0.2855692>,
    <0.2744972, -0.9330401, -0.2325671>,
    <0.2671639, -0.9471809, -0.1774031>,
    <0.2526454, -0.9434069, -0.2148341>,
    <0.2170672, -0.9471735, -0.2361021>,
    <0.1694317, -0.9619137, -0.2145107>,
    <0.2256468, -0.9579479, -0.1772552>,
    <0.2549333, -0.9296636, -0.2659596>,
    <0.2766328, -0.8785822, -0.3893169>,
    <0.2983340, -0.9180042, -0.2612759>,
    <0.2664128, -0.8489966, -0.4563211>,
    <0.3004496, -0.9371127, -0.1776225>,
    <0.2881071, -0.9379427, -0.1930227>,
    <0.2096401, -0.9455651, -0.2489128>,
    <0.2000230, -0.9439948, -0.2624205>,
    <0.2271777, -0.9398658, -0.2550346>,
    <0.2432847, -0.9409724, -0.2353371>,
    <0.1674100, -0.9455479, -0.2791290>,
    <0.1669053, -0.9479508, -0.2711678>,
    <0.2034182, -0.9404941, -0.2721981>,
    <0.2369803, -0.9343890, -0.2660030>,
    <0.1663974, -0.9502862, -0.2631883>,
    <0.2672093, -0.9325876, -0.2426510>,
    <-0.2501342, -0.8722982, 0.4201532>,
    <-0.2256020, -0.8878406, 0.4010520>,
    <-0.2150621, -0.8878876, 0.4066987>,
    <-0.2273219, -0.8783137, 0.4205827>,
    <-0.2386433, -0.8898032, 0.3889725>,
    <-0.2668018, -0.8802090, 0.3924907>,
    <-0.1948636, -0.8978933, 0.3947350>,
    <-0.1907173, -0.8969710, 0.3988356>,
    <-0.1586194, -0.9021241, 0.4012629>,
    <-0.1602665, -0.9069375, 0.3895882>,
    <-0.1982912, -0.8922533, 0.4056656>,
    <-0.1618697, -0.9115357, 0.3780223>,
    <-0.1642536, -0.9299428, 0.3289789>,
    <-0.2101535, -0.8983610, 0.3857240>,
    <-0.2791958, -0.8852312, 0.3720423>,
    <-0.2499057, -0.9001840, 0.3566734>,
    <-0.2623111, -0.8902852, 0.3722702>,
    <-0.2863604, -0.8794606, 0.3801930>,
    <-0.2261705, -0.9055141, 0.3590141>,
    <-0.2516123, -0.8907311, 0.3785358>,
    <-0.2127857, -0.9265995, 0.3100573>,
    <-0.2445735, -0.9119492, 0.3294427>,
    <-0.2821055, -0.8789804, 0.3844604>,
    <-0.2755554, -0.8960450, 0.3480984>,
    <-0.2307753, 0.9257124, 0.2996653>,
    <-0.2605768, 0.9241470, 0.2793781>,
    <-0.2702640, 0.9189738, 0.2871315>,
    <-0.2545287, 0.9184957, 0.3026231>,
    <-0.2489958, 0.9299080, 0.2706884>,
    <-0.2187200, 0.9370658, 0.2721567>,
    <-0.1637112, 0.9300383, 0.3289793>,
    <-0.2093842, 0.9137753, 0.3480990>,
    <-0.2441674, 0.9120578, 0.3294433>,
    <-0.2934926, 0.9160802, 0.2732383>,
    <-0.2967545, 0.9130463, 0.2797914>,
    <-0.2790217, 0.9088515, 0.3100579>,
    <-0.2874814, 0.9131738, 0.2889085>,
    <-0.2789937, 0.9217419, 0.2693591>,
    <-0.2008247, 0.9062304, 0.3720428>,
    <-0.2336671, 0.9045349, 0.3566739>,
    <-0.2179743, 0.9021650, 0.3722708>,
    <-0.1917346, 0.9048152, 0.3801937>,
    <-0.1595896, 0.9070568, 0.3895883>,
    <-0.1594911, 0.9019705, 0.4012629>,
    <-0.2568873, 0.8972833, 0.3590146>,
    <-0.2274626, 0.8972017, 0.3785365>,
    <-0.1951794, 0.9022719, 0.3844612>,
    <-0.1596557, 0.9119260, 0.3780226>,
    <0.2696591, 0.9401902, -0.2081497>,
    <0.2397712, 0.9271504, -0.2879270>,
    <0.2287140, 0.9449356, -0.2340653>,
    <0.2422025, 0.9537964, -0.1777930>,
    <0.2834729, 0.9423487, -0.1778257>,
    <0.2437024, 0.9318666, -0.2687633>,
    <0.1988148, 0.8951144, -0.3990526>,
    <0.2005134, 0.9435707, -0.2635692>,
    <0.1907409, 0.8605733, -0.4722621>,
    <0.0967894, 0.5580720, -0.8241283>,
    <0.1591364, 0.8398252, -0.5190080>,
    <0.1715191, 0.9370038, -0.3043107>,
    <0.2083392, 0.9616932, -0.1781598>,
    <0.1714416, 0.9648388, -0.1992335>,
    <0.2948228, 0.9351312, -0.1964922>,
    <0.2964809, 0.8859703, -0.3565890>,
    <0.2583600, 0.8768514, -0.4054402>,
    <0.2490133, 0.9252531, -0.2861801>,
    <0.2524537, 0.7526606, -0.6080865>,
    <0.2144288, 0.7585352, -0.6153410>,
    <0.1680743, 0.5210631, -0.8368060>,
    <0.1555286, 0.5792626, -0.8001660>,
    <0.1949355, 0.8252369, -0.5300794>,
    <0.1281214, 0.5989608, -0.7904625>,
    <0.0817810, -0.3699957, -0.9254269>,
    <0.0668979, -0.2697888, -0.9605929>,
    <0.0972424, -0.3266168, -0.9401411>,
    <0.1232375, -0.4359893, -0.8914740>,
    <0.1620065, -0.6058240, -0.7789295>,
    <0.1246708, -0.5728996, -0.8100885>,
    <0.1061830, -0.5956983, -0.7961587>,
    <0.0731899, -0.3393378, -0.9378129>,
    <0.0631705, -0.2566093, -0.9644486>,
    <0.0785118, -0.2437052, -0.9666663>,
    <0.1108015, -0.3079987, -0.9449126>,
    <0.0614216, -0.2213931, -0.9732484>,
    <0.0758519, -0.2083983, -0.9750983>,
    <0.1460062, -0.4179908, -0.8966414>,
    <0.1951782, -0.6118221, -0.7665371>,
    <0.2123143, -0.9575864, -0.1948097>,
    <0.1868517, -0.9174862, -0.3511488>,
    <0.2153365, -0.8912747, -0.3990733>,
    <0.2470963, -0.9270474, -0.2820046>,
    <0.1689794, -0.9654560, -0.1983451>,
    <0.1596636, -0.9403107, -0.3005384>,
    <0.1618166, -0.7931739, -0.5871035>,
    <0.1966973, -0.7763625, -0.5988084>,
    <0.1408953, -0.8559579, -0.4974782>,
    <0.2453771, -0.8220544, -0.5138254>,
    <0.1066857, 0.3295057, -0.9381067>,
    <0.0746105, 0.2534775, -0.9644597>,
    <0.0734637, 0.3131766, -0.9468492>,
    <0.1038100, 0.4113784, -0.9055337>,
    <0.0995776, 0.3151678, -0.9437974>,
    <0.0719357, 0.2484846, -0.9659610>,
    <0.0487474, 0.2337102, -0.9710835>,
    <0.0511976, 0.3031706, -0.9515600>,
    <0.0556294, 0.2166248, -0.9746687>,
    <0.0790764, 0.2951176, 0.9521830>,
    <0.0336887, 0.2195299, -0.9750239>,
    <0.0414127, 0.2712880, -0.9616069>,
    <0.0740535, 0.4088845, -0.9095766>,
    <0.0525555, 0.3519574, -0.9345394>,
    <0.0933361, 0.3141486, -0.9447746>,
    <0.0812533, 0.2637696, -0.9611574>,
    <0.0695194, 0.2431542, -0.9674932>,
    <0.0720720, 0.2646078, -0.9616592>,
    <0.0669094, 0.2257325, -0.9718889>,
    <0.0584078, 0.2080389, -0.9763751>,
    <0.0736837, 0.2024470, -0.9765172>,
    <0.0596671, 0.2226851, -0.9730628>,
    <0.0596671, 0.2226851, -0.9730628>,
    <0.0534766, 0.1995810, -0.9784210>,
    <0.0563327, 0.2127952, -0.9754716>,
    <0.0534766, 0.1995810, -0.9784210>,
    <0.0516437, 0.1927398, -0.9798899>,
    <0.0516437, 0.1927398, -0.9798899>,
    <0.0790764, 0.2951176, 0.9521830>,
    <0.0727467, -0.3202695, -0.9445292>,
    <0.0599701, -0.2696829, -0.9610800>,
    <0.0597079, -0.2442577, -0.9678704>,
    <0.0676147, -0.2640521, -0.9621355>,
    <0.0752260, -0.3741310, -0.9243198>,
    <0.0599948, -0.2948109, -0.9536703>,
    <0.0561875, -0.2346080, -0.9704649>,
    <0.0542129, -0.2128275, -0.9755846>,
    <0.0550231, -0.2642607, -0.9628804>,
    <0.0386792, -0.2193536, -0.9748784>,
    <0.0615401, -0.2296651, -0.9713222>,
    <0.0615401, -0.2296651, -0.9713222>,
    <0.0549115, -0.2049273, -0.9772356>,
    <0.0576894, -0.2150651, -0.9748943>,
    <0.0549115, -0.2049273, -0.9772356>,
    <0.0529965, -0.1977807, -0.9788126>,
    <0.0529965, -0.1977807, -0.9788126>,
    <0.0758519, -0.2083983, -0.9750983>,
    <-0.2629987, -0.9170783, 0.2996648>,
    <-0.2364072, -0.9306234, 0.2793775>,
    <-0.2254312, -0.9309869, 0.2871310>,
    <-0.2388194, -0.9227052, 0.3026227>,
    <-0.2493172, -0.9298219, 0.2706882>,
    <-0.2791156, -0.9208829, 0.2721565>,
    <-0.2038679, -0.9400952, 0.2732376>,
    <-0.1995260, -0.9390988, 0.2797908>,
    <-0.1660755, -0.9453108, 0.2807248>,
    <-0.1674057, -0.9478661, 0.2711554>,
    <-0.2076206, -0.9345726, 0.2889080>,
    <-0.1687087, -0.9503167, 0.2616020>,
    <-0.1697994, -0.9618489, 0.2145107>,
    <-0.2192552, -0.9377489, 0.2693589>,
    <-0.2909853, -0.9228596, 0.2523046>,
    <-0.2596757, -0.9358171, 0.2383586>,
    <-0.2732103, -0.9275337, 0.2550243>,
    <-0.2987360, -0.9175501, 0.2624091>,
    <-0.2349657, -0.9412307, 0.2426437>,
    <-0.2621977, -0.9284605, 0.2630844>,
    <-0.2194103, -0.9558883, 0.1952863>,
    <-0.2529206, -0.9433331, 0.2148343>,
    <-0.2943170, -0.9170873, 0.2689393>,
    <-0.2857426, -0.9293227, 0.2339028>,
    <-0.2367518, 0.9495866, 0.2055089>,
    <-0.2670708, 0.9469047, 0.1790105>,
    <-0.2748688, 0.9343539, 0.2267816>,
    <-0.2570935, 0.9268777, 0.2734971>,
    <-0.2556623, 0.9324798, 0.2551827>,
    <-0.2256676, 0.9578893, 0.1775452>,
    <-0.1694125, 0.9619173, 0.2145101>,
    <-0.2172010, 0.9476885, 0.2339023>,
    <-0.2526309, 0.9434108, 0.2148340>,
    <-0.3002946, 0.9369109, 0.1789446>,
    <-0.2990353, 0.9204048, 0.2518590>,
    <-0.2879291, 0.9375287, 0.1952862>,
    <-0.2803389, 0.8903961, 0.3586151>,
    <-0.2710747, 0.8698586, 0.4121462>,
    <-0.2094290, 0.9447126, 0.2523045>,
    <-0.2430227, 0.9402793, 0.2383585>,
    <-0.2271597, 0.9398730, 0.2550240>,
    <-0.2000620, 0.9439899, 0.2624087>,
    <-0.1668794, 0.9479589, 0.2711553>,
    <-0.1672553, 0.9451027, 0.2807251>,
    <-0.2671289, 0.9326126, 0.2426436>,
    <-0.2371604, 0.9351694, 0.2630840>,
    <-0.2036576, 0.9413796, 0.2689387>,
    <-0.1664932, 0.9507074, 0.2616017>,
    <-0.2697295, -0.9406358, 0.2060347>,
    <-0.2421463, -0.9535164, 0.1793645>,
    <-0.2290586, -0.9462990, 0.2281456>,
    <-0.2406292, -0.9306515, 0.2756545>,
    <-0.2445029, -0.9347662, 0.2577413>,
    <-0.2834276, -0.9423174, 0.1780636>,
    <-0.2083741, -0.9614491, 0.1794322>,
    <-0.2011221, -0.9460756, 0.2539506>,
    <-0.1715619, -0.9651576, 0.1975786>,
    <-0.1723098, -0.9414702, 0.2897295>,
    <-0.2014003, -0.9066960, 0.3705944>,
    <-0.1626167, -0.8653385, 0.4740728>,
    <-0.1073905, -0.6544970, 0.7483989>,
    <-0.1963156, -0.8820757, 0.4282554>,
    <-0.2949897, -0.9356161, 0.1939166>,
    <-0.2501453, -0.9290095, 0.2727062>,
    <-0.2615091, -0.8875017, 0.3794124>,
    <-0.2987794, -0.8932297, 0.3359636>,
    <-0.2040192, -0.8567914, 0.4735870>,
    <-0.2264341, -0.8012374, 0.5538468>,
    <-0.1532330, -0.7009368, 0.6965682>,
    <-0.1805018, -0.6723133, 0.7179233>,
    <-0.2660706, -0.8014333, 0.5356408>,
    <-0.2032561, -0.6475439, 0.7344208>,
    <-0.1139780, 0.4875105, 0.8656457>,
    <-0.1508515, 0.5359537, 0.8306609>,
    <-0.1231156, 0.4195524, 0.8993433>,
    <-0.0946539, 0.3658361, 0.9258534>,
    <-0.0849565, 0.3452515, 0.9346570>,
    <-0.0952751, 0.4419479, 0.8919668>,
    <-0.1222042, 0.6956875, 0.7078736>,
    <-0.1499219, 0.6716500, 0.7255409>,
    <-0.1821652, 0.6811949, 0.7090764>,
    <-0.1718243, 0.5135392, 0.8406866>,
    <-0.1319357, 0.3872159, 0.9125003>,
    <-0.2154382, 0.6897957, 0.6912078>,
    <-0.0991443, 0.3177465, 0.9429780>,
    <-0.0866967, 0.3072258, 0.9476793>,
    <-0.2124046, 0.9580558, 0.1923886>,
    <-0.2479502, 0.9307072, 0.2688955>,
    <-0.2178417, 0.9016891, 0.3734995>,
    <-0.1884355, 0.9246414, 0.3309537>,
    <-0.1604228, 0.9446213, 0.2862780>,
    <-0.1689728, 0.9657792, 0.1967707>,
    <-0.2512224, 0.8482347, 0.4662458>,
    <-0.2058467, 0.8123401, 0.5456471>,
    <-0.1715932, 0.8321981, 0.5272590>,
    <-0.1471617, 0.8844846, 0.4427533>,
    <-0.1420670, -0.4685917, 0.8719167>,
    <-0.1347302, -0.5293381, 0.8376449>,
    <-0.1009102, -0.4156536, 0.9039077>,
    <-0.0985642, -0.3548828, 0.9297006>,
    <-0.0964090, -0.3318301, 0.9383997>,
    <-0.1351985, -0.4196257, 0.8975721>,
    <-0.1030601, -0.5265227, 0.8438913>,
    <-0.0762039, -0.3946693, 0.9156578>,
    <-0.0652527, -0.4750676, 0.8775265>,
    <-0.0559514, -0.3735597, 0.9259172>,
    <-0.0701166, -0.3167162, 0.9459252>,
    <-0.0525145, -0.3244798, 0.9444337>,
    <-0.0758600, -0.3013239, 0.9504994>,
    <-0.1213284, -0.3823472, 0.9160186>,
    <-0.0959291, -0.3331593, 0.9379779>,
    <-0.0943218, -0.3162366, 0.9439798>,
    <-0.1067308, -0.3320887, 0.9371903>,
    <-0.0816822, -0.3063955, 0.9483933>,
    <-0.0874515, -0.3036981, 0.9487464>,
    <-0.0972705, -0.3093848, 0.9459490>,
    <-0.0884580, 0.4027916, 0.9110072>,
    <-0.0860040, 0.3467392, 0.9340103>,
    <-0.0789796, 0.3322635, 0.9398740>,
    <-0.0760976, 0.3530834, 0.9324920>,
    <-0.0723768, 0.3764584, 0.9236020>,
    <-0.0903446, 0.4708205, 0.8775910>,
    <-0.0845896, 0.3150058, 0.9453126>,
    <-0.0789254, 0.3188639, 0.9445087>,
    <-0.0733413, 0.3316592, 0.9405441>,
    <-0.0627751, 0.3400158, 0.9383222>,
    <0.0351606, 0.3973155, -0.9170082>,
    <0.0357380, 0.3927579, -0.9189473>,
    <0.0358907, 0.3835698, -0.9228142>,
    <0.0354932, 0.3861036, -0.9217723>,
    <0.0373369, 0.4018957, -0.9149239>,
    <0.0355590, 0.4016981, -0.9150815>,
    <0.0353456, 0.4039660, -0.9140909>,
    <0.0352498, 0.4028573, -0.9145838>,
    <0.0352498, 0.4028573, -0.9145838>,
    <0.0345628, 0.3949956, -0.9180326>,
    <0.0369402, 0.3765328, -0.9256665>,
    <0.0384536, 0.3735043, -0.9268311>,
    <0.0345628, 0.3949956, -0.9180326>,
    <0.0326341, 0.3729486, -0.9272779>,
    <0.0326341, 0.3729486, -0.9272779>,
    <0.0417961, 0.3266408, -0.9442239>,
    <0.0379634, 0.3739194, -0.9266839>,
    <0.0417701, 0.4015808, -0.9148706>,
    <0.0346411, -0.3933969, -0.9187159>,
    <0.0338610, -0.3727072, -0.9273310>,
    <0.0342952, -0.3745334, -0.9265790>,
    <0.0351701, -0.3917079, -0.9194172>,
    <0.0347401, -0.3970394, -0.9171438>,
    <0.0352710, -0.4031136, -0.9144700>,
    <0.0352710, -0.4031136, -0.9144700>,
    <0.0353448, -0.4039662, -0.9140908>,
    <0.0354563, -0.3985444, -0.9164634>,
    <0.0371906, -0.3941801, -0.9182804>,
    <0.0348690, -0.3523574, -0.9352157>,
    <0.0357112, -0.3627749, -0.9311923>,
    <0.0422769, -0.3905011, -0.9196312>,
    <0.0357060, -0.3776186, -0.9252726>,
    <0.0388721, -0.3375243, -0.9405138>,
    <0.0332263, -0.3797352, -0.9244984>,
    <0.0332263, -0.3797352, -0.9244984>,
    <0.0347401, -0.3970394, -0.9171438>,
    <-0.0300124, 0.4698999, 0.8822093>,
    <-0.0267463, 0.4118502, 0.9108590>,
    <-0.0372841, 0.4306832, 0.9017327>,
    <-0.0386379, 0.4632952, 0.8853613>,
    <-0.0448524, 0.5137241, 0.8567822>,
    <-0.0422289, 0.5330096, 0.8450547>,
    <-0.0426168, 0.5458714, 0.8367844>,
    <-0.0242757, 0.4661462, 0.8843746>,
    <-0.0242757, 0.4661462, 0.8843746>,
    <-0.0139629, 0.3905819, 0.9204623>,
    <-0.0260991, 0.3433925, 0.9388293>,
    <-0.0448256, 0.4075974, 0.9120609>,
    <-0.0139629, 0.3905819, 0.9204623>,
    <-0.0081611, 0.3054742, 0.9521654>,
    <-0.0081611, 0.3054742, 0.9521654>,
    <-0.0337083, 0.2814350, 0.9589881>,
    <-0.0535957, 0.4647454, 0.8838208>,
    <-0.0524207, 0.5041480, 0.8620249>,
    <0.0455146, -0.5740286, -0.8175693>,
    <0.0580853, -0.5798523, -0.8126484>,
    <0.0653839, -0.5782718, -0.8132199>,
    <0.0590103, -0.5719426, -0.8181683>,
    <0.0495305, -0.5246504, -0.8498757>,
    <0.0354195, -0.5159268, -0.8559001>,
    <0.0042164, -0.4768506, -0.8789742>,
    <0.0361104, -0.5825384, -0.8120006>,
    <0.0540675, -0.6020104, -0.7966556>,
    <0.0783995, -0.5964645, -0.7988014>,
    <0.0796615, -0.5774290, -0.8125452>,
    <0.0744183, -0.6199912, -0.7810716>,
    <0.0730782, -0.5544092, -0.8290296>,
    <0.0618794, -0.5153925, -0.8547172>,
    <0.0360193, -0.4082694, -0.9121506>,
    <0.0344672, -0.4219605, -0.9059588>,
    <0.0389546, -0.4351760, -0.8995023>,
    <0.0404148, -0.4230726, -0.9051940>,
    <0.0353448, -0.4039662, -0.9140908>,
    <0.0342803, -0.4000469, -0.9158534>,
    <0.0312004, -0.4005173, -0.9157578>,
    <0.0328189, -0.4461729, -0.8943448>,
    <0.0418379, -0.4610914, -0.8863658>,
    <0.0251136, -0.4100016, -0.9117390>,
    <0.0481337, -0.4523203, -0.8905557>,
    <0.0326881, -0.3912194, -0.9197167>,
    <0.0277063, -0.3730086, -0.9274141>,
    <0.0239681, -0.3672724, -0.9298046>,
    <0.0276144, -0.3784818, -0.9251967>,
    <0.0353448, -0.4039662, -0.9140908>,
    <0.0349415, -0.3993669, -0.9161251>,
    <0.0349415, -0.3993669, -0.9161251>,
    <0.0322998, -0.3691801, -0.9287964>,
    <0.0171445, -0.3321871, -0.9430577>,
    <0.0141267, -0.3542097, -0.9350593>,
    <0.0322998, -0.3691801, -0.9287964>,
    <0.0262177, -0.2996673, -0.9536834>,
    <0.0262177, -0.2996673, -0.9536834>,
    <-0.0022896, -0.2595908, -0.9657160>,
    <-0.0025815, -0.2961102, -0.9551503>,
    <-0.0027592, -0.3456991, -0.9383414>,
    <0.0180070, -0.3761993, -0.9263638>,
    <-0.0023044, -0.3772518, -0.9261079>,
    <-0.0822734, 0.6448326, 0.7598829>,
    <-0.0821993, 0.6745268, 0.7336599>,
    <-0.0712838, 0.6259109, 0.7766300>,
    <-0.0680945, 0.5952497, 0.8006503>,
    <-0.0571111, 0.5426963, 0.8379851>,
    <-0.0454255, 0.4769490, 0.8777563>,
    <0.0054753, 0.3527565, 0.9356991>,
    <-0.1152653, 0.7650447, 0.6335775>,
    <-0.1152653, 0.7650447, 0.6335775>,
    <-0.0999932, 0.7471120, 0.6571340>,
    <-0.0635550, 0.6161306, 0.7850757>,
    <-0.0595386, 0.5805041, 0.8120777>,
    <-0.0999932, 0.7471120, 0.6571340>,
    <-0.0709152, 0.6530956, 0.7539477>,
    <-0.0709152, 0.6530956, 0.7539477>,
    <-0.0426168, 0.5458714, 0.8367844>,
    <-0.0588299, 0.5523478, 0.8315353>,
    <-0.0649277, 0.5714479, 0.8180658>,
    <0.0507865, -0.7242855, -0.6876272>,
    <0.0700959, -0.7282361, -0.6817322>,
    <0.0822393, -0.7354607, -0.6725580>,
    <0.0739850, -0.7361257, -0.6727891>,
    <0.0599735, -0.6881525, -0.7230832>,
    <0.0343290, -0.6751456, -0.7368853>,
    <-0.0003031, -0.6913312, -0.7225379>,
    <0.0411197, -0.7490003, -0.6612924>,
    <0.0658221, -0.7548826, -0.6525486>,
    <0.0970950, -0.7409039, -0.6645555>,
    <0.1038456, -0.7407503, -0.6637056>,
    <0.0908231, -0.7591914, -0.6444995>,
    <0.1003895, -0.7388275, -0.6663752>,
    <0.0866798, -0.7009641, -0.7079096>,
    <0.0264232, -0.5949483, -0.8033295>,
    <0.0211645, -0.6115883, -0.7908931>,
    <0.0390305, -0.6244468, -0.7800916>,
    <0.0490830, -0.6264554, -0.7779103>,
    <-0.0003992, -0.5615932, -0.8274134>,
    <-0.0008211, -0.5987618, -0.8009267>,
    <0.0245203, -0.6304711, -0.7758254>,
    <0.0469105, -0.6358036, -0.7704241>,
    <-0.0008129, -0.6319334, -0.7750223>,
    <0.0672300, -0.6454807, -0.7608119>,
    <-0.0488595, 0.6997390, 0.7127259>,
    <-0.0687002, 0.7015752, 0.7092761>,
    <-0.0789344, 0.7184514, 0.6910839>,
    <-0.0694132, 0.7218358, 0.6885746>,
    <-0.0657035, 0.7507633, 0.6572956>,
    <-0.0405555, 0.7339289, 0.6780144>,
    <0.0099051, 0.6215737, 0.7832931>,
    <-0.0298624, 0.6076221, 0.7936647>,
    <-0.0538305, 0.6302074, 0.7745586>,
    <-0.0922825, 0.7043828, 0.7037960>,
    <-0.0996803, 0.7251472, 0.6813409>,
    <-0.0779371, 0.6577759, 0.7491706>,
    <-0.0963492, 0.7390717, 0.6667007>,
    <-0.0909004, 0.7600730, 0.6434487>,
    <-0.0174458, 0.4016364, 0.9156330>,
    <-0.0423940, 0.5046285, 0.8622951>,
    <-0.0317970, 0.4937144, 0.8690426>,
    <-0.0158217, 0.4517371, 0.8920108>,
    <0.0044989, 0.4225975, 0.9063063>,
    <0.0110978, 0.3331436, 0.9428108>,
    <0.0054753, 0.3527565, 0.9356991>,
    <-0.0606388, 0.5804602, 0.8120277>,
    <-0.0406434, 0.5439478, 0.8381342>,
    <-0.0211682, 0.5178477, 0.8552109>,
    <0.0010323, 0.5063951, 0.8623009>,
    <0.0582718, -0.8331530, -0.5499641>,
    <0.0799506, -0.8318430, -0.5492223>,
    <0.0938864, -0.8392977, -0.5355042>,
    <0.0848036, -0.8434377, -0.5304915>,
    <0.0704788, -0.8083721, -0.5844375>,
    <0.0404765, -0.7974229, -0.6020618>,
    <-0.0003195, -0.8118763, -0.5838294>,
    <0.0467150, -0.8523336, -0.5209079>,
    <0.0744179, -0.8531121, -0.5163930>,
    <0.1099645, -0.8388016, -0.5332163>,
    <0.1181707, -0.8415788, -0.5270491>,
    <0.1021489, -0.8527313, -0.5122645>,
    <0.1149049, -0.8440863, -0.5237510>,
    <0.1013424, -0.8185176, -0.5654720>,
    <0.0333887, -0.7676040, -0.6400541>,
    <0.0263298, -0.7657672, -0.6425786>,
    <0.0482916, -0.7721859, -0.6335588>,
    <0.0610837, -0.7811386, -0.6213624>,
    <0.0001795, -0.7424102, -0.6699456>,
    <-0.0003548, -0.7571445, -0.6532473>,
    <0.0296233, -0.7669537, -0.6410183>,
    <0.0568642, -0.7703506, -0.6350798>,
    <-0.0009125, -0.7708582, -0.6370062>,
    <0.0816278, -0.7816058, -0.6184086>,
    <-0.0583246, 0.8331419, 0.5499752>,
    <-0.0846028, 0.8417238, 0.5332387>,
    <-0.0938565, 0.8392940, 0.5355153>,
    <-0.0801491, 0.8334680, 0.5467241>,
    <-0.0743940, 0.8531072, 0.5164045>,
    <-0.0466724, 0.8510786, 0.5229598>,
    <0.0003536, 0.8118679, 0.5838411>,
    <-0.0405528, 0.7987550, 0.6002883>,
    <-0.0704521, 0.8083661, 0.5844491>,
    <-0.1145326, 0.8422009, 0.5268586>,
    <-0.1180671, 0.8415861, 0.5270607>,
    <-0.1011091, 0.8171777, 0.5674483>,
    <-0.1101656, 0.8405685, 0.5303850>,
    <-0.1022116, 0.8538868, 0.5103235>,
    <-0.0327023, 0.7543729, 0.6556310>,
    <-0.0605464, 0.7752954, 0.6286900>,
    <-0.0480782, 0.7692363, 0.6371531>,
    <-0.0260695, 0.7597995, 0.6496346>,
    <0.0013008, 0.7473118, 0.6644723>,
    <0.0018656, 0.7191225, 0.6948808>,
    <-0.0814606, 0.7810245, 0.6191647>,
    <-0.0569266, 0.7715654, 0.6335978>,
    <-0.0296911, 0.7677651, 0.6400431>,
    <0.0011241, 0.7697229, 0.6383771>,
    <0.0632441, -0.9052579, -0.4201289>,
    <0.0866258, -0.9018338, -0.4233105>,
    <0.1016109, -0.9079044, -0.4066753>,
    <0.0918183, -0.9127427, -0.3980831>,
    <0.0775059, -0.8885083, -0.4522674>,
    <0.0446719, -0.8804567, -0.4720174>,
    <-0.0002982, -0.8921705, -0.4516987>,
    <0.0503637, -0.9193194, -0.3902760>,
    <0.0801012, -0.9177700, -0.3889498>,
    <0.1186843, -0.9048998, -0.4087424>,
    <0.1276635, -0.9081024, -0.3988133>,
    <0.1097433, -0.9151815, -0.3878133>,
    <0.1242845, -0.9117929, -0.3913913>,
    <0.1109535, -0.8953111, -0.4314016>,
    <0.0377005, -0.8657865, -0.4989914>,
    <0.0295333, -0.8614609, -0.5069644>,
    <0.0541523, -0.8652431, -0.4984195>,
    <0.0684645, -0.8734191, -0.4821324>,
    <0.0003638, -0.8478485, -0.5302384>,
    <-0.0003504, -0.8559273, -0.5170960>,
    <0.0330877, -0.8591570, -0.5106412>,
    <0.0636035, -0.8611087, -0.5044267>,
    <-0.0010680, -0.8635875, -0.5041979>,
    <0.0910601, -0.8702509, -0.4841192>,
    <-0.0632942, 0.9052430, 0.4201534>,
    <-0.0916628, 0.9114577, 0.4010521>,
    <-0.1015831, 0.9078970, 0.4066989>,
    <-0.0867882, 0.9030935, 0.4205829>,
    <-0.0800791, 0.9177622, 0.3889729>,
    <-0.0503374, 0.9183773, 0.3924911>,
    <0.0003306, 0.8921598, 0.4517198>,
    <-0.0447337, 0.8815196, 0.4700234>,
    <-0.0774804, 0.8884999, 0.4522884>,
    <-0.1239857, 0.9103910, 0.3947350>,
    <-0.1275664, 0.9081062, 0.3988358>,
    <-0.1107628, 0.8942821, 0.4335795>,
    <-0.1188357, 0.9062633, 0.4056659>,
    <-0.1097778, 0.9160598, 0.3857244>,
    <-0.0375903, 0.8639618, 0.5021523>,
    <-0.0682469, 0.8718607, 0.4849756>,
    <-0.0541233, 0.8652367, 0.4984336>,
    <-0.0295675, 0.8614521, 0.5069774>,
    <0.0003884, 0.8559198, 0.5171084>,
    <-0.0002739, 0.8469363, 0.5316942>,
    <-0.0909610, 0.8702520, 0.4841359>,
    <-0.0636884, 0.8626178, 0.5018310>,
    <-0.0331947, 0.8608616, 0.5077553>,
    <0.0010551, 0.8644078, 0.5027903>,
    <0.0664689, -0.9517230, -0.2996753>,
    <0.0910348, -0.9478246, -0.3055178>,
    <0.1066011, -0.9519374, -0.2871435>,
    <0.0962503, -0.9562222, -0.2763601>,
    <0.0821017, -0.9405990, -0.3294432>,
    <0.0474770, -0.9354569, -0.3502374>,
    <-0.0002481, -0.9443370, -0.3289796>,
    <0.0526837, -0.9614402, -0.2699205>,
    <0.0837519, -0.9590128, -0.2707028>,
    <0.1244360, -0.9482415, -0.2921538>,
    <0.1337842, -0.9506902, -0.2798034>,
    <0.1146853, -0.9555661, -0.2715524>,
    <0.1301842, -0.9540630, -0.2698443>,
    <0.1171080, -0.9442106, -0.3078181>,
    <0.0404944, -0.9286744, -0.3686788>,
    <0.0316672, -0.9243724, -0.3801747>,
    <0.0580290, -0.9263152, -0.3722536>,
    <0.0732240, -0.9324996, -0.3536705>,
    <0.0005260, -0.9166547, -0.3996797>,
    <-0.0003100, -0.9209981, -0.3895669>,
    <0.0354435, -0.9211545, -0.3875797>,
    <0.0681478, -0.9219216, -0.3813352>,
    <-0.0011397, -0.9251772, -0.3795338>,
    <0.0972654, -0.9282550, -0.3590014>,
    <0.0681767, -0.9758576, -0.2074943>,
    <0.0918632, -0.9540444, -0.2852375>,
    <0.1083119, -0.9665825, -0.2323505>,
    <0.0986297, -0.9791935, -0.1773480>,
    <0.0849861, -0.9729458, -0.2148344>,
    <0.0492944, -0.9704771, -0.2361021>,
    <-0.0001768, -0.9767217, -0.2145103>,
    <0.0558660, -0.9825916, -0.1771799>,
    <0.0896139, -0.9599186, -0.2655666>,
    <0.1199048, -0.9135682, -0.3886078>,
    <0.1344058, -0.9559565, -0.2609259>,
    <0.1149680, -0.8828464, -0.4553731>,
    <0.1331591, -0.9750629, -0.1775414>,
    <0.1208579, -0.9737225, -0.1930230>,
    <0.0422594, -0.9676034, -0.2489134>,
    <0.0330611, -0.9643869, -0.2624210>,
    <0.0605202, -0.9650360, -0.2550351>,
    <0.0761903, -0.9689227, -0.2353377>,
    <0.0006739, -0.9602532, -0.2791296>,
    <-0.0002403, -0.9625319, -0.2711682>,
    <0.0370126, -0.9615291, -0.2721983>,
    <0.0711250, -0.9613446, -0.2660034>,
    <-0.0011460, -0.9647438, -0.2631884>,
    <0.1012075, -0.9648198, -0.2426515>,
    <-0.0665213, 0.9517227, 0.2996646>,
    <-0.0961418, 0.9553559, 0.2793775>,
    <-0.1065801, 0.9519436, 0.2871308>,
    <-0.0911669, 0.9487404, 0.3026223>,
    <-0.0837363, 0.9590185, 0.2706876>,
    <-0.0526776, 0.9608102, 0.2721559>,
    <0.0002753, 0.9443373, 0.3289788>,
    <-0.0475280, 0.9362524, 0.3480985>,
    <-0.0820810, 0.9406009, 0.3294429>,
    <-0.1299582, 0.9531275, 0.2732378>,
    <-0.1336975, 0.9507061, 0.2797907>,
    <-0.1169624, 0.9434956, 0.3100577>,
    <-0.1245431, 0.9492215, 0.2889076>,
    <-0.1146965, 0.9561856, 0.2693582>,
    <-0.0404085, 0.9273356, 0.3720428>,
    <-0.0730464, 0.9313689, 0.3566739>,
    <-0.0580036, 0.9263100, 0.3722707>,
    <-0.0317024, 0.9243635, 0.3801935>,
    <0.0003436, 0.9209891, 0.3895881>,
    <-0.0004426, 0.9159629, 0.4012628>,
    <-0.0971731, 0.9282596, 0.3590146>,
    <-0.0682096, 0.9230698, 0.3785362>,
    <-0.0355365, 0.9224571, 0.3844608>,
    <0.0011240, 0.9257958, 0.3780223>,
    <0.0158504, -0.3783430, -0.9255298>,
    <0.0189951, -0.2780361, -0.9603828>,
    <0.0391928, -0.3397899, -0.9396844>,
    <0.0458025, -0.4522064, -0.8907365>,
    <0.0544639, -0.6261169, -0.7778248>,
    <0.0226650, -0.5849661, -0.8107410>,
    <-0.0006006, -0.5909910, -0.8066779>,
    <0.0114474, -0.3426396, -0.9393972>,
    <0.0173416, -0.2640864, -0.9643431>,
    <0.0351325, -0.2546883, -0.9663848>,
    <0.0558211, -0.3238394, -0.9444639>,
    <0.0221155, -0.2296345, -0.9730256>,
    <0.0386792, -0.2193536, -0.9748784>,
    <0.0714017, -0.4384675, -0.8959063>,
    <0.0861374, -0.6378387, -0.7653379>,
    <0.0428076, -0.9799494, -0.1945935>,
    <0.0247273, -0.9362472, -0.3504709>,
    <0.0573199, -0.9154948, -0.3982257>,
    <0.0823489, -0.9560430, -0.2814258>,
    <-0.0012299, -0.9801549, -0.1982291>,
    <-0.0060248, -0.9539033, -0.3000538>,
    <0.0213931, -0.8090991, -0.5872827>,
    <0.0589583, -0.7995805, -0.5976578>,
    <-0.0102455, -0.8655204, -0.5007688>,
    <0.0989441, -0.8528635, -0.5126733>,
    <0.0131243, -0.3215216, -0.9468113>,
    <0.0095382, -0.2698893, -0.9628441>,
    <0.0150408, -0.2502530, -0.9680636>,
    <0.0198418, -0.2722537, -0.9620209>,
    <0.0071341, -0.3664503, -0.9304103>,
    <0.0065074, -0.2884499, -0.9574729>,
    <0.0127242, -0.2346933, -0.9719862>,
    <0.0158735, -0.2184558, -0.9757177>,
    <0.0063943, -0.2467138, -0.9690673>,
    <0.0614190, -0.7019994, 0.7095241>,
    <0.0210337, -0.2404099, -0.9704435>,
    <0.0210337, -0.2404099, -0.9704435>,
    <0.0185994, -0.2125869, -0.9769651>,
    <0.0194828, -0.2227773, -0.9746746>,
    <0.0185994, -0.2125869, -0.9769651>,
    <0.0179164, -0.2047797, -0.9786441>,
    <0.0179164, -0.2047797, -0.9786441>,
    <0.0386792, -0.2193536, -0.9748784>,
    <-0.0682621, 0.9762864, 0.2054388>,
    <-0.0985861, 0.9789045, 0.1789602>,
    <-0.1084492, 0.9679350, 0.2265845>,
    <-0.0922446, 0.9575258, 0.2731945>,
    <-0.0898413, 0.9628045, 0.2548256>,
    <-0.0558965, 0.9825361, 0.1774781>,
    <0.0001965, 0.9767216, 0.2145106>,
    <-0.0493369, 0.9710075, 0.2339022>,
    <-0.0849714, 0.9729473, 0.2148336>,
    <-0.1330415, 0.9748361, 0.1788704>,
    <-0.1346782, 0.9584307, 0.2515400>,
    <-0.1207548, 0.9732840, 0.1952856>,
    <-0.1214963, 0.9257928, 0.3579754>,
    <-0.1159273, 0.9041045, 0.4112857>,
    <-0.0421998, 0.9667275, 0.2523037>,
    <-0.0760530, 0.9681950, 0.2383577>,
    <-0.0605016, 0.9650402, 0.2550233>,
    <-0.0331006, 0.9643891, 0.2624081>,
    <0.0002671, 0.9625357, 0.2711548>,
    <-0.0005991, 0.9597882, 0.2807244>,
    <-0.1011244, 0.9648307, 0.2426429>,
    <-0.0711671, 0.9621446, 0.2630835>,
    <-0.0370948, 0.9624428, 0.2689383>,
    <0.0011248, 0.9651753, 0.2616015>,
    <-0.0276329, 0.5001271, 0.8655110>,
    <-0.0555781, 0.5548612, 0.8300844>,
    <-0.0484542, 0.4351263, 0.8990647>,
    <-0.0297120, 0.3764544, 0.9259586>,
    <-0.0239663, 0.3548874, 0.9346018>,
    <-0.0172915, 0.4524352, 0.8916297>,
    <0.0004586, 0.7075349, 0.7066782>,
    <-0.0310827, 0.6887022, 0.7243777>,
    <-0.0612181, 0.7037276, 0.7078275>,
    <-0.0802180, 0.5368846, 0.8398333>,
    <-0.0631302, 0.4065962, 0.9114242>,
    <-0.0925316, 0.7179946, 0.6898707>,
    <-0.0430594, 0.3333600, 0.9418158>,
    <-0.0322395, 0.3192609, 0.9471183>,
    <-0.0428146, 0.9804225, 0.1921943>,
    <-0.0825521, 0.9597723, 0.2683697>,
    <-0.0579751, 0.9261329, 0.3727154>,
    <-0.0250435, 0.9435324, 0.3303322>,
    <0.0060258, 0.9582593, 0.2858371>,
    <0.0012929, 0.9804694, 0.1966675>,
    <-0.1001434, 0.8795366, 0.4651737>,
    <-0.0617115, 0.8364682, 0.5445298>,
    <-0.0245255, 0.8500031, 0.5262065>,
    <0.0086400, 0.8970467, 0.4418514>,
    <-0.0171448, 0.4122402, 0.9109139>,
    <-0.0246239, 0.3564370, 0.9339948>,
    <-0.0193813, 0.3382920, 0.9408416>,
    <-0.0126286, 0.3571728, 0.9339530>,
    <-0.0053224, 0.3794951, 0.9251784>,
    <-0.0070924, 0.4797829, 0.8773586>,
    <-0.0284273, 0.3245377, 0.9454455>,
    <-0.0210133, 0.3231436, 0.9461166>,
    <-0.0119491, 0.3284081, 0.9444604>,
    <-0.0009463, 0.3302943, 0.9438775>,
    <-0.0415446, -0.4218969, 0.9056915>,
    <-0.0240931, -0.3689376, 0.9291418>,
    <-0.0298928, -0.3509146, 0.9359302>,
    <-0.0421406, -0.3629472, 0.9308563>,
    <-0.0485197, -0.4056726, 0.9127297>,
    <-0.0260986, -0.3127120, 0.9494894>,
    <-0.0118763, -0.3137734, 0.9494236>,
    <-0.0240594, -0.3150356, 0.9487748>,
    <-0.0109843, -0.2682956, 0.9632740>,
    <0.0577420, -0.6599551, -0.7490828>,
    <-0.0387293, -0.3217235, 0.9460412>,
    <-0.1280439, -0.9726552, 0.1937694>,
    <-0.0850561, -0.9584455, 0.2723006>,
    <-0.1034503, -0.9196711, 0.3788181>,
    <-0.1391366, -0.9317081, 0.3355011>,
    <-0.1154969, -0.9772267, 0.1780124>,
    <-0.0784912, -0.9630945, 0.2574646>,
    <-0.0507616, -0.8690691, 0.4920794>,
    <-0.0826742, -0.8159334, 0.5722042>,
    <-0.0401495, -0.8988829, 0.4363456>,
    <-0.0010880, -0.6360063, 0.7716831>,
    <-0.0258323, -0.6673158, 0.7443267>,
    <-0.0575914, -0.6543732, 0.7539754>,
    <-0.1218925, -0.8165875, 0.5642047>,
    <-0.0822500, -0.6047252, 0.7921757>,
    <-0.0543756, -0.4064830, 0.9120389>,
    <-0.0355618, -0.4892104, 0.8714405>,
    <-0.0212823, -0.3833210, 0.9233699>,
    <-0.0320859, -0.3059151, 0.9515180>,
    <-0.0045963, -0.4851531, 0.8744172>,
    <0.0011216, -0.3812506, 0.9244710>,
    <0.0073456, -0.4275267, 0.9039729>,
    <0.0070891, -0.3532472, 0.9355032>,
    <-0.0082764, -0.2888921, 0.9573259>,
    <0.0077294, -0.3117027, 0.9501482>,
    <0.0577420, -0.6599551, -0.7490828>,
    <-0.1263119, -0.9593685, 0.2523042>,
    <-0.0932279, -0.9666923, 0.2383582>,
    <-0.1079952, -0.9608849, 0.2550240>,
    <-0.1348667, -0.9554856, 0.2624087>,
    <-0.1149658, -0.9553606, 0.2721561>,
    <-0.0840678, -0.9589894, 0.2706878>,
    <-0.0679532, -0.9677326, 0.2426435>,
    <-0.0969890, -0.9598853, 0.2630842>,
    <-0.0530860, -0.9615757, 0.2693585>,
    <-0.0001965, -0.9767216, 0.2145106>,
    <-0.0500889, -0.9794663, 0.1952866>,
    <-0.0852702, -0.9729209, 0.2148346>,
    <-0.1305953, -0.9542624, 0.2689390>,
    <-0.1200264, -0.9648228, 0.2339029>,
    <-0.1022933, -0.9731946, 0.2059814>,
    <-0.0728919, -0.9810856, 0.1793262>,
    <-0.0612581, -0.9717341, 0.2279921>,
    <-0.0753736, -0.9583645, 0.2754201>,
    <-0.0382551, -0.9830368, 0.1793745>,
    <-0.0337841, -0.9666933, 0.2536982>,
    <-0.0013513, -0.9803044, 0.1974878>,
    <-0.0061896, -0.9572051, 0.2893444>,
    <-0.0408807, -0.9275792, 0.3713833>,
    <-0.0105736, -0.8802994, 0.4743007>,
    <0.0399843, 0.3143242, -0.9484733>,
    <0.0364166, 0.2569954, -0.9657263>,
    <0.0277398, 0.2372009, -0.9710645>,
    <0.0265670, 0.2696045, -0.9626046>,
    <0.0275818, 0.2551829, -0.9664993>,
    <0.0445700, 0.3229553, -0.9453641>,
    <0.0260067, 0.1955309, -0.9803527>,
    <0.0205877, 0.1809035, -0.9832853>,
    <0.0790764, 0.2951176, 0.9521830>,
    <0.0192839, 0.2007250, -0.9794578>,
    <-0.0492868, 0.8189163, -0.5717927>,
    <0.0181543, 0.2220617, -0.9748636>,
    <0.1279642, 0.9721521, -0.1963300>,
    <0.1381378, 0.9241857, -0.3560880>,
    <0.1022029, 0.9086750, -0.4048015>,
    <0.0845950, 0.9545674, -0.2857356>,
    <0.0782070, 0.9601111, -0.2684592>,
    <0.1155360, 0.9772665, -0.1777684>,
    <0.1182282, 0.7859443, -0.6068885>,
    <0.0796142, 0.7858830, -0.6132288>,
    <0.0758823, 0.5449608, -0.8350207>,
    <0.0529009, 0.6011496, -0.7973836>,
    <0.0493547, 0.8478815, -0.5278836>,
    <0.0236444, 0.6153090, -0.7879313>,
    <0.0006424, 0.5807478, -0.8140833>,
    <0.0393105, 0.8834489, -0.4668754>,
    <0.0481622, 0.3445458, -0.9375332>,
    <0.0292416, 0.2616634, -0.9647161>,
    <0.0184399, 0.3257905, -0.9452621>,
    <0.0311654, 0.4272944, -0.9035753>,
    <0.0083007, 0.2540457, -0.9671566>,
    <-0.0015693, 0.3218429, -0.9467918>,
    <-0.0492868, 0.8189163, -0.5717927>,
    <-0.0101048, 0.2723541, -0.9621440>,
    <-0.0082321, 0.2955140, -0.9553029>,
    <0.0032762, 0.4209061, -0.9070983>,
    <-0.0074496, 0.3603274, -0.9327962>,
    <-0.1212355, -0.9202641, 0.3720429>,
    <-0.0897939, -0.9299036, 0.3566739>,
    <-0.1037297, -0.9223094, 0.3722707>,
    <-0.1292933, -0.9158254, 0.3801936>,
    <-0.1099019, -0.9131661, 0.3924911>,
    <-0.0805052, -0.9177249, 0.3889728>,
    <-0.0654938, -0.9310313, 0.3590144>,
    <-0.0931160, -0.9208908, 0.3785361>,
    <-0.0509621, -0.9212055, 0.3857243>,
    <-0.0002753, -0.9443373, 0.3289788>,
    <-0.0486508, -0.9494723, 0.3100573>,
    <-0.0824997, -0.9405644, 0.3294427>,
    <-0.1251865, -0.9146137, 0.3844608>,
    <-0.1157726, -0.9302818, 0.3480984>,
    <-0.0997543, -0.9488152, 0.2996645>,
    <-0.0712147, -0.9575369, 0.2793772>,
    <-0.0603424, -0.9559889, 0.2871305>,
    <-0.0749653, -0.9501579, 0.3026222>,
    <-0.0375250, -0.9612145, 0.2732373>,
    <-0.0334221, -0.9594792, 0.2797903>,
    <0.0005991, -0.9597882, 0.2807244>,
    <-0.0002671, -0.9625357, 0.2711548>,
    <-0.0421796, -0.9564274, 0.2889075>,
    <-0.0011248, -0.9651753, 0.2616015>,
    <0.1264050, 0.9602417, -0.2489131>,
    <0.1349050, 0.9554769, -0.2624205>,
    <0.1079758, 0.9608843, -0.2550345>,
    <0.0932187, 0.9674330, -0.2353372>,
    <0.0840511, 0.9589867, -0.2707027>,
    <0.1150689, 0.9559823, -0.2699205>,
    <0.1305173, 0.9533486, -0.2721978>,
    <0.0968911, 0.9590905, -0.2660027>,
    <0.1199760, 0.9642934, -0.2361015>,
    <0.0852551, 0.9729225, -0.2148336>,
    <0.0678691, 0.9677367, -0.2426509>,
    <0.0500631, 0.9799164, -0.1930222>,
    <0.0001768, 0.9767217, -0.2145103>,
    <0.0529892, 0.9609639, -0.2715521>,
    <0.1023013, 0.9727451, -0.2080897>,
    <0.0751372, 0.9547779, -0.2876693>,
    <0.0611554, 0.9703367, -0.2338947>,
    <0.0728983, 0.9813720, -0.1777492>,
    <0.0404312, 0.9176742, -0.3952713>,
    <0.0336196, 0.9641306, -0.2632904>,
    <0.0104560, 0.8608929, -0.5086788>,
    <0.0061864, 0.9526878, -0.3038877>,
    <0.0381780, 0.9832725, -0.1780944>,
    <0.0012879, 0.9799718, -0.1991320>,
    <0.1213833, 0.9215975, -0.3686789>,
    <0.1293293, 0.9158279, -0.3801751>,
    <0.1037054, 0.9223189, -0.3722540>,
    <0.0898151, 0.9310480, -0.3536707>,
    <0.0804846, 0.9177366, -0.3889497>,
    <0.1100394, 0.9140985, -0.3902758>,
    <0.1250516, 0.9133146, -0.3875803>,
    <0.0929774, 0.9197490, -0.3813357>,
    <0.1156846, 0.9294893, -0.3502380>,
    <0.0824788, 0.9405658, -0.3294439>,
    <0.0654019, 0.9310426, -0.3590018>,
    <0.0486315, 0.9502014, -0.3078187>,
    <0.0002481, 0.9443370, -0.3289796>,
    <0.0508434, 0.9203346, -0.3878132>,
    <0.0998058, 0.9488063, -0.2996756>,
    <0.0749361, 0.9492330, -0.3055180>,
    <0.0603205, 0.9559863, -0.2871439>,
    <0.0712580, 0.9584086, -0.2763607>,
    <0.0421148, 0.9554436, -0.2921538>,
    <0.0333339, 0.9594783, -0.2798038>,
    <0.0011460, 0.9647438, -0.2631884>,
    <0.0002403, 0.9625319, -0.2711682>,
    <0.0374648, 0.9621747, -0.2698449>,
    <-0.0006739, 0.9602532, -0.2791296>,
    <-0.1130062, -0.8573639, 0.5021522>,
    <-0.0841869, -0.8704662, 0.4849755>,
    <-0.0969457, -0.8614904, 0.4984334>,
    <-0.1204713, -0.8534991, 0.5069772>,
    <-0.1018249, -0.8462533, 0.5229598>,
    <-0.0748768, -0.8530649, 0.5164046>,
    <-0.0615385, -0.8728262, 0.4841358>,
    <-0.0870712, -0.8605722, 0.5018307>,
    <-0.0476171, -0.8586632, 0.5103235>,
    <-0.0003306, -0.8921598, 0.4517198>,
    <-0.0462103, -0.8999298, 0.4335793>,
    <-0.0779831, -0.8884560, 0.4522881>,
    <-0.1167966, -0.8535475, 0.5077551>,
    <-0.1090201, -0.8758954, 0.4700232>,
    <-0.0948612, -0.9024814, 0.4201532>,
    <-0.0680027, -0.9135278, 0.4010519>,
    <-0.0576148, -0.9117438, 0.4066987>,
    <-0.0713508, -0.9044441, 0.4205828>,
    <-0.0359856, -0.9180901, 0.3947348>,
    <-0.0320625, -0.9164618, 0.3988356>,
    <0.0004426, -0.9159629, 0.4012628>,
    <-0.0003436, -0.9209891, 0.3895881>,
    <-0.0403406, -0.9131309, 0.4056657>,
    <-0.0011240, -0.9257958, 0.3780223>,
    <0.1132144, 0.8591802, -0.4989909>,
    <0.1205064, 0.8535021, -0.5069640>,
    <0.0969181, 0.8615018, -0.4984190>,
    <0.0842431, 0.8720389, -0.4821320>,
    <0.0748539, 0.8530740, -0.5163928>,
    <0.1020008, 0.8474969, -0.5209077>,
    <0.1166059, 0.8518504, -0.5106408>,
    <0.0868926, 0.8590714, -0.5044263>,
    <0.1088963, 0.8748380, -0.4720170>,
    <0.0779593, 0.8884689, -0.4522669>,
    <0.0614406, 0.8728425, -0.4841189>,
    <0.0462011, 0.9009764, -0.4314012>,
    <0.0002982, 0.8921705, -0.4516987>,
    <0.0474781, 0.8575145, -0.5122643>,
    <0.0949129, 0.9024874, -0.4201285>,
    <0.0712919, 0.9031755, -0.4233101>,
    <0.0575886, 0.9117561, -0.4066748>,
    <0.0680725, 0.9148204, -0.3980826>,
    <0.0402528, 0.9117618, -0.4087421>,
    <0.0319662, 0.9164750, -0.3988129>,
    <0.0011397, 0.9251772, -0.3795338>,
    <0.0003100, 0.9209981, -0.3895669>,
    <0.0359347, 0.9195227, -0.3913908>,
    <-0.0005260, 0.9166547, -0.3996797>,
    <-0.0981531, -0.7440169, 0.6609121>,
    <-0.0747726, -0.7720966, 0.6310910>,
    <-0.0860732, -0.7645174, 0.6388306>,
    <-0.1059813, -0.7505935, 0.6522096>,
    <-0.0863680, -0.7259772, 0.6822739>,
    <-0.0652847, -0.7495118, 0.6587639>,
    <-0.0553650, -0.7828602, 0.6197295>,
    <-0.0778855, -0.7693954, 0.6340068>,
    <-0.0423883, -0.7640353, 0.6437805>,
    <-0.0003536, -0.8118679, 0.5838411>,
    <-0.0423284, -0.8223202, 0.5674485>,
    <-0.0709896, -0.8083188, 0.5844494>,
    <-0.1040180, -0.7607794, 0.6406207>,
    <-0.0987657, -0.7936618, 0.6002885>,
    <-0.0872351, -0.8306124, 0.5499755>,
    <-0.0628463, -0.8436270, 0.5332389>,
    <-0.0533113, -0.8428411, 0.5355155>,
    <-0.0657988, -0.8347234, 0.5467242>,
    <-0.0334541, -0.8492942, 0.5268588>,
    <-0.0298665, -0.8493025, 0.5270609>,
    <0.0002739, -0.8469363, 0.5316942>,
    <-0.0003884, -0.8559198, 0.5171084>,
    <-0.0374713, -0.8469283, 0.5303852>,
    <-0.0010551, -0.8644078, 0.5027903>,
    <0.1004115, 0.7617405, -0.6400538>,
    <0.1070442, 0.7587060, -0.6425782>,
    <0.0865307, 0.7688407, -0.6335585>,
    <0.0754876, 0.7798786, -0.6213622>,
    <0.0662619, 0.7548440, -0.6525488>,
    <0.0895676, 0.7447616, -0.6612925>,
    <0.1040068, 0.7604463, -0.6410180>,
    <0.0777697, 0.7685218, -0.6350796>,
    <0.0986094, 0.7923371, -0.6020615>,
    <0.0709643, 0.8083297, -0.5844375>,
    <0.0553368, 0.7839060, -0.6184086>,
    <0.0423312, 0.8236803, -0.5654722>,
    <0.0003195, 0.8118763, -0.5838294>,
    <0.0423889, 0.7634287, -0.6444997>,
    <0.0872889, 0.8306143, -0.5499641>,
    <0.0657119, 0.8330887, -0.5492223>,
    <0.0532823, 0.8428500, -0.5355044>,
    <0.0629461, 0.8453499, -0.5304916>,
    <0.0373624, 0.8451534, -0.5332164>,
    <0.0297632, 0.8493133, -0.5270494>,
    <0.0010680, 0.8635875, -0.5041979>,
    <0.0003504, 0.8559273, -0.5170960>,
    <0.0334148, 0.8512155, -0.5237514>,
    <-0.0003638, 0.8478485, -0.5302384>,
    <-0.0299850, -0.6590226, 0.7515252>,
    <-0.0336212, -0.7097615, 0.7036392>,
    <-0.0358134, -0.6521721, 0.7572245>,
    <-0.0347022, -0.6075239, 0.7935430>,
    <-0.0369190, -0.5504926, 0.8340233>,
    <-0.0370067, -0.4898529, 0.8710193>,
    <-0.0629073, -0.3709337, 0.9265262>,
    <-0.0184880, -0.7843547, 0.6200370>,
    <-0.0184880, -0.7843547, 0.6200370>,
    <-0.0284338, -0.7881403, 0.6148385>,
    <-0.0402826, -0.6752355, 0.7365014>,
    <-0.0381742, -0.6225440, 0.7816532>,
    <-0.0284338, -0.7881403, 0.6148385>,
    <-0.0394171, -0.7168251, 0.6961379>,
    <-0.0394171, -0.7168251, 0.6961379>,
    <-0.0484621, -0.6208390, 0.7824387>,
    <-0.0464818, -0.6026819, 0.7966267>,
    <-0.0402987, -0.5707460, 0.8201372>,
    <-0.0351475, -0.5765550, 0.8163020>,
    <-0.0313956, -0.5494183, 0.8349574>,
    <-0.0067584, -0.6336359, 0.7736019>,
    <-0.0337526, -0.5839627, 0.8110785>,
    <-0.0504852, -0.4124871, 0.9095634>,
    <-0.0444204, -0.5115733, 0.8580907>,
    <-0.0524362, -0.4973077, 0.8659882>,
    <-0.0598778, -0.4534965, 0.8892444>,
    <-0.0629073, -0.3709337, 0.9265262>,
    <-0.0399995, -0.5866388, 0.8088603>,
    <-0.0528844, -0.5453749, 0.8365222>,
    <-0.0364502, -0.6664940, 0.7446188>,
    <-0.0553818, -0.6318031, 0.7731479>,
    <-0.0661202, -0.5115484, 0.8567067>,
    <-0.0742361, -0.6012523, 0.7956033>,
    <-0.0723860, -0.6970848, 0.7133253>,
    <-0.0534863, -0.7043976, 0.7077875>,
    <-0.0465983, -0.7224089, 0.6898942>,
    <-0.0565524, -0.7230196, 0.6885089>,
    <-0.0308005, -0.7136458, 0.6998293>,
    <-0.0274396, -0.7331370, 0.6795272>,
    <-0.0013122, -0.7183654, 0.6956647>,
    <-0.0011950, -0.7464931, 0.6653921>,
    <-0.0332978, -0.7449241, 0.6663178>,
    <-0.0011223, -0.7695397, 0.6385980>,
    <0.0757972, 0.5790932, -0.8117301>,
    <0.0845661, 0.5997874, -0.7956781>,
    <0.0695837, 0.6180695, -0.7830378>,
    <0.0599156, 0.6206636, -0.7817844>,
    <0.0506652, 0.5994764, -0.7987872>,
    <0.0636121, 0.5715373, -0.8181068>,
    <0.0851470, 0.6237363, -0.7769833>,
    <0.0641207, 0.6334239, -0.7711438>,
    <0.0834304, 0.6708493, -0.7368857>,
    <0.0604341, 0.6881116, -0.7230838>,
    <0.0458007, 0.6463360, -0.7616771>,
    <0.0363583, 0.7053662, -0.7079101>,
    <0.0003031, 0.6913312, -0.7225379>,
    <0.0342659, 0.6229793, -0.7814874>,
    <0.0757560, 0.7221006, -0.6876276>,
    <0.0574259, 0.7293442, -0.6817325>,
    <0.0467216, 0.7385676, -0.6725585>,
    <0.0549660, 0.7377891, -0.6727897>,
    <0.0330368, 0.7465079, -0.6645559>,
    <0.0263621, 0.7475287, -0.6637061>,
    <0.0009125, 0.7708582, -0.6370062>,
    <0.0003548, 0.7571445, -0.6532473>,
    <0.0294318, 0.7450350, -0.6663758>,
    <-0.0001795, 0.7424102, -0.6699456>,
    <-0.0477902, -0.5430966, 0.8383091>,
    <-0.0411326, -0.4834514, 0.8744043>,
    <-0.0332548, -0.5005492, 0.8650691>,
    <-0.0375680, -0.5282953, 0.8482291>,
    <-0.0484621, -0.6208390, 0.7824387>,
    <-0.0530654, -0.5419854, 0.8387108>,
    <-0.0530654, -0.5419854, 0.8387108>,
    <-0.0506959, -0.4589017, 0.8870395>,
    <-0.0304278, -0.4053387, 0.9136601>,
    <-0.0217419, -0.4747476, 0.8798534>,
    <-0.0506959, -0.4589017, 0.8870395>,
    <-0.0423083, -0.3602141, 0.9319098>,
    <-0.0423083, -0.3602141, 0.9319098>,
    <-0.0215119, -0.2840755, 0.9585606>,
    <-0.0125000, -0.3557059, 0.9345143>,
    <-0.0031735, -0.4517587, 0.8921345>,
    <-0.0225102, -0.5261445, 0.8500972>,
    <0.0021600, -0.5382792, 0.8427638>,
    <0.0343502, 0.3951785, -0.9179619>,
    <0.0347794, 0.3975221, -0.9169332>,
    <0.0332064, 0.3795455, -0.9245770>,
    <0.0314929, 0.3697705, -0.9285892>,
    <0.0291449, 0.3607983, -0.9321884>,
    <0.0337950, 0.3901284, -0.9201401>,
    <0.0353417, 0.4039529, -0.9140968>,
    <0.0353418, 0.4039525, -0.9140970>,
    <0.0353418, 0.4039525, -0.9140970>,
    <0.0353423, 0.4039518, -0.9140973>,
    <0.0346292, 0.3951532, -0.9179623>,
    <0.0325175, 0.3757502, -0.9261503>,
    <0.0353423, 0.4039518, -0.9140973>,
    <0.0353433, 0.4039528, -0.9140968>,
    <0.0353433, 0.4039528, -0.9140968>,
    <0.0353456, 0.4039660, -0.9140909>,
    <0.0344347, 0.3998185, -0.9159473>,
    <0.0323217, 0.3973418, -0.9171013>,
    <0.0289325, 0.3526033, -0.9353255>,
    <0.0270080, 0.3947542, -0.9183897>,
    <-0.0024091, 0.4310424, -0.9023285>,
    <0.0224784, 0.3355029, -0.9417710>,
    <0.0354064, 0.4090252, -0.9118359>,
    <0.0388287, 0.4225181, -0.9055224>,
    <0.0372588, 0.4370319, -0.8986740>,
    <0.0338946, 0.4256648, -0.9042459>,
    <0.0353456, 0.4039660, -0.9140909>,
    <0.0442343, 0.4470724, -0.8934034>,
    <0.0388864, 0.4636827, -0.8851475>,
    <0.0533514, 0.5162388, -0.8547814>,
    <0.0420592, 0.5263573, -0.8492226>,
    <0.0315060, 0.4566663, -0.8890800>,
    <0.0288255, 0.5191561, -0.8541932>,
    <0.0535504, 0.5717326, -0.8186906>,
    <0.0429627, 0.5804240, -0.8131803>,
    <0.0357401, 0.5800894, -0.8137684>,
    <0.0407601, 0.5725101, -0.8188839>,
    <0.0262772, 0.6008481, -0.7989312>,
    <0.0217967, 0.5820165, -0.8128848>,
    <0.0009682, 0.6298307, -0.7767319>,
    <0.0014184, 0.5902802, -0.8071972>,
    <0.0243387, 0.5578732, -0.8295693>,
    <0.0016697, 0.5430868, -0.8396749>,
    <0.0312874, 0.3877963, -0.9212139>,
    <0.0233945, 0.3591615, -0.9329822>,
    <0.0159958, 0.3658349, -0.9305423>,
    <0.0226999, 0.3771356, -0.9258798>,
    <0.0328215, 0.3751459, -0.9263845>,
    <0.0350142, 0.4002093, -0.9157546>,
    <0.0350142, 0.4002093, -0.9157546>,
    <0.0353417, 0.4039529, -0.9140968>,
    <0.0085959, 0.3448373, -0.9386231>,
    <0.0008946, 0.3591243, -0.9332893>,
    <-0.0148601, 0.3627764, -0.9317577>,
    <-0.0167529, 0.3643973, -0.9310929>,
    <0.0061622, 0.3532378, -0.9355133>,
    <-0.0163902, 0.3477478, -0.9374448>,
    <-0.0155573, 0.3288932, -0.9442390>,
    <0.0275432, 0.3148141, -0.9487536>,
    <0.0275432, 0.3148141, -0.9487536>,
    <0.0328215, 0.3751459, -0.9263845>,
    <-0.0343678, 0.3973579, -0.9170199>,
    <-0.0330074, 0.3929591, -0.9189634>,
    <-0.0312612, 0.3839435, -0.9228272>,
    <-0.0320927, 0.3863776, -0.9217822>,
    <-0.0330192, 0.4022586, -0.9149305>,
    <-0.0347363, 0.4017542, -0.9150885>,
    <-0.0353413, 0.4039531, -0.9140968>,
    <-0.0352429, 0.4028274, -0.9145972>,
    <-0.0352429, 0.4028274, -0.9145972>,
    <-0.0345541, 0.3949535, -0.9180510>,
    <-0.0290055, 0.3771837, -0.9256841>,
    <-0.0269890, 0.3744759, -0.9268438>,
    <-0.0345541, 0.3949535, -0.9180510>,
    <-0.0326245, 0.3728985, -0.9272984>,
    <-0.0326245, 0.3728985, -0.9272984>,
    <-0.0155573, 0.3288932, -0.9442390>,
    <-0.0275438, 0.3748098, -0.9266925>,
    <-0.0285983, 0.4027204, -0.9148762>,
    <-0.0327353, -0.3871477, -0.9214364>,
    <-0.0277550, -0.3653503, -0.9304562>,
    <-0.0255579, -0.3607768, -0.9323019>,
    <-0.0291116, -0.3744832, -0.9267766>,
    <-0.0328048, -0.3751387, -0.9263880>,
    <-0.0349926, -0.4001551, -0.9157791>,
    <-0.0349926, -0.4001551, -0.9157791>,
    <-0.0353113, -0.4038178, -0.9141577>,
    <-0.0336463, -0.3956798, -0.9177720>,
    <-0.0298933, -0.3910803, -0.9198710>,
    <-0.0196905, -0.3594734, -0.9329476>,
    <-0.0176693, -0.3486965, -0.9370691>,
    <-0.0229605, -0.3993675, -0.9165034>,
    <-0.0205682, -0.3367765, -0.9413599>,
    <-0.0022896, -0.2595908, -0.9657160>,
    <-0.0275290, -0.3148328, -0.9487479>,
    <-0.0275290, -0.3148328, -0.9487479>,
    <-0.0328048, -0.3751387, -0.9263880>,
    <0.0516057, 0.4915174, 0.8693374>,
    <0.0440413, 0.4403113, 0.8967644>,
    <0.0366100, 0.4571814, 0.8886197>,
    <0.0416343, 0.4824395, 0.8749393>,
    <0.0456419, 0.5206981, 0.8525200>,
    <0.0517120, 0.5400166, 0.8400643>,
    <0.0536171, 0.5532002, 0.8313211>,
    <0.0565647, 0.4898927, 0.8699457>,
    <0.0565647, 0.4898927, 0.8699457>,
    <0.0531483, 0.4178888, 0.9069422>,
    <0.0321214, 0.3710095, 0.9280734>,
    <0.0245597, 0.4368695, 0.8991896>,
    <0.0531483, 0.4178888, 0.9069422>,
    <0.0438185, 0.3277623, 0.9437435>,
    <0.0438185, 0.3277623, 0.9437435>,
    <0.0054753, 0.3527565, 0.9356991>,
    <0.0266279, 0.4878835, 0.8725025>,
    <0.0365710, 0.5149825, 0.8564202>,
    <0.0153024, -0.3871541, 0.9218880>,
    <0.0245629, -0.3413286, 0.9396230>,
    <0.0188626, -0.3187923, 0.9476369>,
    <0.0114813, -0.3367691, 0.9415173>,
    <0.0140205, -0.4069914, 0.9133244>,
    <0.0224184, -0.3321080, 0.9429749>,
    <0.0253692, -0.2912365, 0.9563146>,
    <0.0206564, -0.2864439, 0.9578743>,
    <0.0292206, -0.2999510, 0.9535070>,
    <0.0513387, -0.2911494, 0.9552991>,
    <0.0238174, -0.2722272, 0.9619382>,
    <0.0238174, -0.2722272, 0.9619382>,
    <0.0246784, -0.2820688, 0.9590767>,
    <0.0160675, -0.3029986, 0.9528555>,
    <0.0246784, -0.2820688, 0.9590767>,
    <0.0277273, -0.3169147, 0.9480487>,
    <0.0277273, -0.3169147, 0.9480487>,
    <0.0577420, -0.6599551, -0.7490828>,
    <0.0428026, -0.9801470, 0.1935969>,
    <0.0826546, -0.9587891, 0.2718304>,
    <0.0578382, -0.9239464, 0.3781241>,
    <0.0247958, -0.9419078, 0.3349549>,
    <0.0559452, -0.9824475, 0.1779522>,
    <0.0899288, -0.9621797, 0.2571440>,
    <0.1008641, -0.8699940, 0.4826353>,
    <0.0607751, -0.8243352, 0.5628302>,
    <0.1165907, -0.8954303, 0.4296640>,
    <0.1149648, -0.6450065, 0.7554798>,
    <0.0920580, -0.6835580, 0.7240675>,
    <0.0585003, -0.6725861, 0.7377030>,
    <0.0220006, -0.8322069, 0.5540285>,
    <0.0246662, -0.6339368, 0.7729914>,
    <0.0194215, -0.4420383, 0.8967859>,
    <0.0521092, -0.5145124, 0.8558981>,
    <0.0470253, -0.4077227, 0.9118941>,
    <0.0248370, -0.3457962, 0.9379809>,
    <0.0808816, -0.5022753, 0.8609168>,
    <0.0667551, -0.3938230, 0.9167591>,
    <0.0878906, -0.4406505, 0.8933658>,
    <0.0738911, -0.3663216, 0.9275498>,
    <0.0451032, -0.3270064, 0.9439452>,
    <0.0707173, -0.3412561, 0.9373064>,
    <0.0513387, -0.2911494, 0.9552991>,
    <0.0615302, 0.3917342, 0.9180187>,
    <0.0423712, 0.3606567, 0.9317357>,
    <0.0499723, 0.3550947, 0.9334937>,
    <0.0607640, 0.3610126, 0.9305792>,
    <0.0606812, 0.3567423, 0.9322300>,
    <0.0740812, 0.4298419, 0.8998600>,
    <0.1211338, 0.6533533, 0.7472992>,
    <0.0651132, 0.4320551, 0.8994936>,
    <0.0392216, 0.3552381, 0.9339526>,
    <0.0291611, 0.3222639, 0.9462006>,
    <0.0434118, 0.3274120, 0.9438839>,
    <0.0232383, 0.3138980, 0.9491723>,
    <0.0613233, 0.3369446, 0.9395253>,
    <0.0725866, 0.2708977, 0.9598675>,
    <0.0575386, 0.3097924, 0.9490616>,
    <0.0608914, 0.4939622, 0.8673486>,
    <0.0417295, 0.5575828, 0.8290718>,
    <0.0278762, 0.4374803, 0.8987958>,
    <0.0364117, 0.3755276, 0.9260957>,
    <0.0903047, 0.6783102, 0.7292052>,
    <0.0620118, 0.7047890, 0.7067015>,
    <0.0142875, 0.5437528, 0.8391238>,
    <0.0084554, 0.4097868, 0.9121422>,
    <0.0336210, 0.7243123, 0.6886518>,
    <0.0155308, 0.3290821, 0.9441736>,
    <0.0421998, -0.9667275, 0.2523037>,
    <0.0760530, -0.9681950, 0.2383577>,
    <0.0605016, -0.9650402, 0.2550233>,
    <0.0331006, -0.9643891, 0.2624081>,
    <0.0526776, -0.9608102, 0.2721559>,
    <0.0837363, -0.9590185, 0.2706876>,
    <0.1011244, -0.9648307, 0.2426429>,
    <0.0711671, -0.9621446, 0.2630835>,
    <0.1146965, -0.9561856, 0.2693582>,
    <0.1694125, -0.9619173, 0.2145101>,
    <0.1207548, -0.9732840, 0.1952856>,
    <0.0849714, -0.9729473, 0.2148336>,
    <0.0370948, -0.9624428, 0.2689383>,
    <0.0493369, -0.9710075, 0.2339022>,
    <0.0682553, -0.9761859, 0.2059181>,
    <0.0985803, -0.9788465, 0.1792801>,
    <0.1084173, -0.9676501, 0.2278135>,
    <0.0921966, -0.9569710, 0.2751477>,
    <0.1330306, -0.9747575, 0.1793064>,
    <0.1346053, -0.9579488, 0.2534077>,
    <0.1689084, -0.9656655, 0.1973832>,
    <0.1601648, -0.9438649, 0.2889053>,
    <0.1209523, -0.9216477, 0.3686952>,
    <0.1435474, -0.8718659, 0.4682349>,
    <0.1280887, 0.9729961, 0.1920206>,
    <0.0854019, 0.9596550, 0.2678968>,
    <0.1037583, 0.9224095, 0.3720147>,
    <0.1391838, 0.9337408, 0.3297816>,
    <0.1723363, 0.9427719, 0.2854494>,
    <0.1715266, 0.9653687, 0.1965755>,
    <0.1697994, 0.9618489, 0.2145107>,
    <0.1155764, 0.9773255, 0.1774176>,
    <0.0787399, 0.9638611, 0.2545032>,
    <0.0541684, 0.8840711, 0.4642026>,
    <0.0845427, 0.8351229, 0.5435276>,
    <0.0428737, 0.9108512, 0.4105021>,
    <0.1239448, 0.8396039, 0.5288696>,
    <0.1644441, 0.8763146, 0.4528034>,
    <0.1023069, 0.9733211, 0.2053763>,
    <0.0728974, 0.9811601, 0.1789159>,
    <0.0612813, 0.9721032, 0.2264065>,
    <0.0754365, 0.9590742, 0.2729212>,
    <0.1200264, 0.9648228, 0.2339029>,
    <0.0852702, 0.9729209, 0.2148346>,
    <0.0382589, 0.9831405, 0.1788042>,
    <0.0337997, 0.9673321, 0.2512494>,
    <0.0500889, 0.9794663, 0.1952866>,
    <0.0411218, 0.9330488, 0.3573920>,
    <-0.0130810, 0.3148475, -0.9490521>,
    <-0.0108862, 0.2706023, -0.9626297>,
    <-0.0151606, 0.2459456, -0.9691651>,
    <-0.0194227, 0.2656393, -0.9638768>,
    <-0.0167934, 0.2574225, -0.9661530>,
    <-0.0109589, 0.3342586, -0.9424177>,
    <-0.0146792, 0.2388460, -0.9709465>,
    <-0.0159233, 0.2146060, -0.9765709>,
    <-0.0492868, 0.8189163, -0.5717927>,
    <-0.0204269, 0.2334742, -0.9721484>,
    <-0.0204269, 0.2334742, -0.9721484>,
    <-0.0181204, 0.2071114, -0.9781495>,
    <-0.0190034, 0.2171914, -0.9759440>,
    <-0.0181204, 0.2071114, -0.9781495>,
    <-0.0174707, 0.1996860, -0.9797042>,
    <-0.0174707, 0.1996860, -0.9797042>,
    <-0.0377933, 0.2143294, -0.9760300>,
    <-0.0215075, 0.2237539, -0.9744083>,
    <-0.0427942, 0.9796419, -0.1961387>,
    <-0.0244742, 0.9343585, -0.3554930>,
    <-0.0571605, 0.9129481, -0.4040526>,
    <-0.0824374, 0.9549105, -0.2852191>,
    <-0.0896920, 0.9592046, -0.2681081>,
    <-0.0559137, 0.9824946, -0.1777022>,
    <-0.0209752, 0.8031980, -0.5953428>,
    <-0.0585325, 0.7938059, -0.6053479>,
    <-0.0221193, 0.5755865, -0.8174417>,
    <-0.0536913, 0.6172352, -0.7849446>,
    <-0.0986786, 0.8486129, -0.5197294>,
    <-0.0851631, 0.6295067, -0.7723138>,
    <-0.1048604, 0.5882785, -0.8018308>,
    <-0.1147922, 0.8799339, -0.4610197>,
    <-0.0152119, 0.3696950, -0.9290286>,
    <-0.0183221, 0.2711604, -0.9623598>,
    <-0.0383182, 0.3322069, -0.9424279>,
    <-0.0448869, 0.4431669, -0.8953146>,
    <-0.0342736, 0.2484629, -0.9680349>,
    <-0.0548268, 0.3170055, -0.9468377>,
    <-0.0377933, 0.2143294, -0.9760300>,
    <-0.0537784, 0.2580956, -0.9646215>,
    <-0.0588411, 0.2887087, -0.9556071>,
    <-0.0703241, 0.4303989, -0.8998952>,
    <-0.0740028, 0.3673884, -0.9271188>,
    <-0.0398274, -0.3230936, -0.9455286>,
    <-0.0365197, -0.2631571, -0.9640615>,
    <-0.0254020, -0.2386636, -0.9707700>,
    <-0.0223841, -0.2705731, -0.9624392>,
    <-0.0229074, -0.2459534, -0.9690109>,
    <-0.0442355, -0.3292001, -0.9432235>,
    <-0.0989002, -0.5703093, -0.8154545>,
    <-0.0543781, -0.3625491, -0.9303769>,
    <-0.0428522, -0.2790176, -0.9593294>,
    <-0.0260470, -0.2004271, -0.9793623>,
    <-0.0175782, -0.1809714, -0.9833313>,
    <-0.0349546, -0.2254561, -0.9736261>,
    <-0.0976161, -0.3643092, 0.9261479>,
    <-0.0127839, -0.1966333, -0.9803938>,
    <0.0614190, -0.7019994, 0.7095241>,
    <-0.0113719, -0.1962088, -0.9804962>,
    <-0.0481735, -0.3481220, -0.9362106>,
    <-0.0273202, -0.2482636, -0.9683072>,
    <-0.0182390, -0.3222413, -0.9464818>,
    <-0.0316171, -0.4334873, -0.9006049>,
    <-0.0539068, -0.6125811, -0.7885673>,
    <-0.0772394, -0.5565676, -0.8272041>,
    <-0.0075200, -0.2268749, -0.9738949>,
    <0.0012011, -0.3165848, -0.9485634>,
    <0.0614190, -0.7019994, 0.7095241>,
    <-0.0037159, -0.4271015, -0.9041961>,
    <-0.0242922, -0.6263942, -0.7791279>,
    <0.0404085, -0.9273356, 0.3720428>,
    <0.0730464, -0.9313689, 0.3566739>,
    <0.0580036, -0.9263100, 0.3722707>,
    <0.0317024, -0.9243635, 0.3801935>,
    <0.0503374, -0.9183773, 0.3924911>,
    <0.0800791, -0.9177622, 0.3889729>,
    <0.0971731, -0.9282596, 0.3590146>,
    <0.0682096, -0.9230698, 0.3785362>,
    <0.1097778, -0.9160598, 0.3857244>,
    <0.1637112, -0.9300383, 0.3289793>,
    <0.1169624, -0.9434956, 0.3100577>,
    <0.0820810, -0.9406009, 0.3294429>,
    <0.0355365, -0.9224571, 0.3844608>,
    <0.0475280, -0.9362524, 0.3480985>,
    <0.0665213, -0.9517227, 0.2996646>,
    <0.0961418, -0.9553559, 0.2793775>,
    <0.1065801, -0.9519436, 0.2871308>,
    <0.0911669, -0.9487404, 0.3026223>,
    <0.1299582, -0.9531275, 0.2732378>,
    <0.1336975, -0.9507061, 0.2797907>,
    <0.1672553, -0.9451027, 0.2807251>,
    <0.1668794, -0.9479589, 0.2711553>,
    <0.1245431, -0.9492215, 0.2889076>,
    <0.1664932, -0.9507074, 0.2616017>,
    <0.1263119, 0.9593685, 0.2523042>,
    <0.0932279, 0.9666923, 0.2383582>,
    <0.1079952, 0.9608849, 0.2550240>,
    <0.1348667, 0.9554856, 0.2624087>,
    <0.1674057, 0.9478661, 0.2711554>,
    <0.1660755, 0.9453108, 0.2807248>,
    <0.1642536, 0.9299428, 0.3289789>,
    <0.1149658, 0.9553606, 0.2721561>,
    <0.0840678, 0.9589894, 0.2706878>,
    <0.0679532, 0.9677326, 0.2426435>,
    <0.0969890, 0.9598853, 0.2630842>,
    <0.0530860, 0.9615757, 0.2693585>,
    <0.1305953, 0.9542624, 0.2689390>,
    <0.1687087, 0.9503167, 0.2616020>,
    <0.0997543, 0.9488152, 0.2996645>,
    <0.0712147, 0.9575369, 0.2793772>,
    <0.0603424, 0.9559889, 0.2871305>,
    <0.0749653, 0.9501579, 0.3026222>,
    <0.1157726, 0.9302818, 0.3480984>,
    <0.0824997, 0.9405644, 0.3294427>,
    <0.0375250, 0.9612145, 0.2732373>,
    <0.0334221, 0.9594792, 0.2797903>,
    <0.0486508, 0.9494723, 0.3100573>,
    <0.0421796, 0.9564274, 0.2889075>,
    <-0.0422594, 0.9676034, -0.2489134>,
    <-0.0330611, 0.9643869, -0.2624210>,
    <-0.0605202, 0.9650360, -0.2550351>,
    <-0.0761903, 0.9689227, -0.2353377>,
    <-0.0837519, 0.9590128, -0.2707028>,
    <-0.0526837, 0.9614402, -0.2699205>,
    <-0.0370126, 0.9615291, -0.2721983>,
    <-0.0711250, 0.9613446, -0.2660034>,
    <-0.0492944, 0.9704771, -0.2361021>,
    <-0.0849861, 0.9729458, -0.2148344>,
    <-0.1012075, 0.9648198, -0.2426515>,
    <-0.1208579, 0.9737225, -0.1930230>,
    <-0.1694317, 0.9619137, -0.2145107>,
    <-0.1146853, 0.9555661, -0.2715524>,
    <-0.0681692, 0.9757459, -0.2080215>,
    <-0.0918074, 0.9534086, -0.2873733>,
    <-0.1082759, 0.9662610, -0.2337009>,
    <-0.0986233, 0.9791302, -0.1777006>,
    <-0.1196713, 0.9117891, -0.3928351>,
    <-0.1343233, 0.9554065, -0.2629746>,
    <-0.1401545, 0.8526277, -0.5033713>,
    <-0.1593862, 0.9394348, -0.3034112>,
    <-0.1331471, 0.9749770, -0.1780218>,
    <-0.1689130, 0.9653288, -0.1990193>,
    <-0.1280143, -0.9725326, -0.1944034>,
    <-0.1382353, -0.9265413, -0.3498746>,
    <-0.1025617, -0.9118646, -0.3974720>,
    <-0.0849562, -0.9559670, -0.2809083>,
    <-0.0784637, -0.9609920, -0.2652129>,
    <-0.1156161, -0.9773760, -0.1771133>,
    <-0.1697801, -0.9618524, -0.2145103>,
    <-0.1714107, -0.9650716, -0.1981294>,
    <-0.1715825, -0.9384988, -0.2996321>,
    <-0.1190102, -0.7934520, -0.5968840>,
    <-0.0803686, -0.7933300, -0.6034637>,
    <-0.1598894, -0.8456065, -0.5092986>,
    <-0.0499914, -0.8535116, -0.5186702>,
    <-0.0397552, -0.8873279, -0.4594222>,
    <-0.1023164, -0.9728857, -0.2074242>,
    <-0.0752081, -0.9555912, -0.2849372>,
    <-0.0611817, -0.9707533, -0.2321528>,
    <-0.0729043, -0.9814534, -0.1772971>,
    <-0.0852551, -0.9729225, -0.2148336>,
    <-0.1199760, -0.9642934, -0.2361015>,
    <-0.0405356, -0.9200429, -0.3897151>,
    <-0.0336383, -0.9648594, -0.2606047>,
    <-0.0381821, -0.9833859, -0.1774661>,
    <-0.0500631, -0.9799164, -0.1930222>,
    <-0.0404944, 0.9286744, -0.3686788>,
    <-0.0316672, 0.9243724, -0.3801747>,
    <-0.0580290, 0.9263152, -0.3722536>,
    <-0.0732240, 0.9324996, -0.3536705>,
    <-0.0801012, 0.9177700, -0.3889498>,
    <-0.0503637, 0.9193194, -0.3902760>,
    <-0.0354435, 0.9211545, -0.3875797>,
    <-0.0681478, 0.9219216, -0.3813352>,
    <-0.0474770, 0.9354569, -0.3502374>,
    <-0.0821017, 0.9405990, -0.3294432>,
    <-0.0972654, 0.9282550, -0.3590014>,
    <-0.1171080, 0.9442106, -0.3078181>,
    <-0.1637381, 0.9300335, -0.3289795>,
    <-0.1097433, 0.9151815, -0.3878133>,
    <-0.0664689, 0.9517230, -0.2996753>,
    <-0.0910348, 0.9478246, -0.3055178>,
    <-0.1066011, 0.9519374, -0.2871435>,
    <-0.0962503, 0.9562222, -0.2763601>,
    <-0.1244360, 0.9482415, -0.2921538>,
    <-0.1337842, 0.9506902, -0.2798034>,
    <-0.1663974, 0.9502862, -0.2631883>,
    <-0.1669053, 0.9479508, -0.2711678>,
    <-0.1301842, 0.9540630, -0.2698443>,
    <-0.1674100, 0.9455479, -0.2791290>,
    <-0.1264050, -0.9602417, -0.2489131>,
    <-0.1349050, -0.9554769, -0.2624205>,
    <-0.1079758, -0.9608843, -0.2550345>,
    <-0.0932187, -0.9674330, -0.2353372>,
    <-0.0840511, -0.9589867, -0.2707027>,
    <-0.1150689, -0.9559823, -0.2699205>,
    <-0.1642267, -0.9299472, -0.3289800>,
    <-0.1660825, -0.9457819, -0.2791294>,
    <-0.1673785, -0.9478673, -0.2711678>,
    <-0.1305173, -0.9533486, -0.2721978>,
    <-0.0968911, -0.9590905, -0.2660027>,
    <-0.1686546, -0.9498883, -0.2631880>,
    <-0.0678691, -0.9677367, -0.2426509>,
    <-0.0529892, -0.9609639, -0.2715521>,
    <-0.0998058, -0.9488063, -0.2996756>,
    <-0.0749361, -0.9492330, -0.3055180>,
    <-0.0603205, -0.9559863, -0.2871439>,
    <-0.0712580, -0.9584086, -0.2763607>,
    <-0.0824788, -0.9405658, -0.3294439>,
    <-0.1156846, -0.9294893, -0.3502380>,
    <-0.0421148, -0.9554436, -0.2921538>,
    <-0.0333339, -0.9594783, -0.2798038>,
    <-0.0374648, -0.9621747, -0.2698449>,
    <-0.0486315, -0.9502014, -0.3078187>,
    <0.0375903, -0.8639618, 0.5021523>,
    <0.0682469, -0.8718607, 0.4849756>,
    <0.0541233, -0.8652367, 0.4984336>,
    <0.0295675, -0.8614521, 0.5069774>,
    <0.0466724, -0.8510786, 0.5229598>,
    <0.0743940, -0.8531072, 0.5164045>,
    <0.0909610, -0.8702520, 0.4841359>,
    <0.0636884, -0.8626178, 0.5018310>,
    <0.1022116, -0.8538868, 0.5103235>,
    <0.1545963, -0.8786634, 0.4517197>,
    <0.1107628, -0.8942821, 0.4335795>,
    <0.0774804, -0.8884999, 0.4522884>,
    <0.0331947, -0.8608616, 0.5077553>,
    <0.0447337, -0.8815196, 0.4700234>,
    <0.0632942, -0.9052430, 0.4201534>,
    <0.0916628, -0.9114577, 0.4010521>,
    <0.1015831, -0.9078970, 0.4066989>,
    <0.0867882, -0.9030935, 0.4205829>,
    <0.1239857, -0.9103910, 0.3947350>,
    <0.1275664, -0.9081062, 0.3988358>,
    <0.1594911, -0.9019705, 0.4012629>,
    <0.1595896, -0.9070568, 0.3895883>,
    <0.1188357, -0.9062633, 0.4056659>,
    <0.1596557, -0.9119260, 0.3780226>,
    <0.1212355, 0.9202641, 0.3720429>,
    <0.0897939, 0.9299036, 0.3566739>,
    <0.1037297, 0.9223094, 0.3722707>,
    <0.1292933, 0.9158254, 0.3801936>,
    <0.1602665, 0.9069375, 0.3895882>,
    <0.1586194, 0.9021241, 0.4012629>,
    <0.1552475, 0.8785485, 0.4517198>,
    <0.1099019, 0.9131661, 0.3924911>,
    <0.0805052, 0.9177249, 0.3889728>,
    <0.0654938, 0.9310313, 0.3590144>,
    <0.0931160, 0.9208908, 0.3785361>,
    <0.0509621, 0.9212055, 0.3857243>,
    <0.1251865, 0.9146137, 0.3844608>,
    <0.1618697, 0.9115357, 0.3780223>,
    <0.0948612, 0.9024814, 0.4201532>,
    <0.0680027, 0.9135278, 0.4010519>,
    <0.0576148, 0.9117438, 0.4066987>,
    <0.0713508, 0.9044441, 0.4205828>,
    <0.1090201, 0.8758954, 0.4700232>,
    <0.0779831, 0.8884560, 0.4522881>,
    <0.0359856, 0.9180901, 0.3947348>,
    <0.0320625, 0.9164618, 0.3988356>,
    <0.0462103, 0.8999298, 0.4335793>,
    <0.0403406, 0.9131309, 0.4056657>,
    <-0.0377005, 0.8657865, -0.4989914>,
    <-0.0295333, 0.8614609, -0.5069644>,
    <-0.0541523, 0.8652431, -0.4984195>,
    <-0.0684645, 0.8734191, -0.4821324>,
    <-0.0744179, 0.8531121, -0.5163930>,
    <-0.0467150, 0.8523336, -0.5209079>,
    <-0.0330877, 0.8591570, -0.5106412>,
    <-0.0636035, 0.8611087, -0.5044267>,
    <-0.0446719, 0.8804567, -0.4720174>,
    <-0.0775059, 0.8885083, -0.4522674>,
    <-0.0910601, 0.8702509, -0.4841192>,
    <-0.1109535, 0.8953111, -0.4314016>,
    <-0.1546300, 0.8786680, -0.4516991>,
    <-0.1021489, 0.8527313, -0.5122645>,
    <-0.0632441, 0.9052579, -0.4201289>,
    <-0.0866258, 0.9018338, -0.4233105>,
    <-0.1016109, 0.9079044, -0.4066753>,
    <-0.0918183, 0.9127427, -0.3980831>,
    <-0.1186843, 0.9048998, -0.4087424>,
    <-0.1276635, 0.9081024, -0.3988133>,
    <-0.1595328, 0.9113194, -0.3795341>,
    <-0.1596242, 0.9070597, -0.3895675>,
    <-0.1242845, 0.9117929, -0.3913913>,
    <-0.1596933, 0.9026371, -0.3996802>,
    <-0.1213833, -0.9215975, -0.3686789>,
    <-0.1293293, -0.9158279, -0.3801751>,
    <-0.1037054, -0.9223189, -0.3722540>,
    <-0.0898151, -0.9310480, -0.3536707>,
    <-0.0804846, -0.9177366, -0.3889497>,
    <-0.1100394, -0.9140985, -0.3902758>,
    <-0.1552174, -0.8785648, -0.4516984>,
    <-0.1586573, -0.9028200, -0.3996798>,
    <-0.1602349, -0.9069521, -0.3895674>,
    <-0.1250516, -0.9133146, -0.3875803>,
    <-0.0929774, -0.9197490, -0.3813357>,
    <-0.1617777, -0.9109235, -0.3795344>,
    <-0.0654019, -0.9310426, -0.3590018>,
    <-0.0508434, -0.9203346, -0.3878132>,
    <-0.0949129, -0.9024874, -0.4201285>,
    <-0.0712919, -0.9031755, -0.4233101>,
    <-0.0575886, -0.9117561, -0.4066748>,
    <-0.0680725, -0.9148204, -0.3980826>,
    <-0.0779593, -0.8884689, -0.4522669>,
    <-0.1088963, -0.8748380, -0.4720170>,
    <-0.0402528, -0.9117618, -0.4087421>,
    <-0.0319662, -0.9164750, -0.3988129>,
    <-0.0359347, -0.9195227, -0.3913908>,
    <-0.0462011, -0.9009764, -0.4314012>,
    <0.0328915, -0.7548459, 0.6550770>,
    <0.0606135, -0.7756276, 0.6282737>,
    <0.0480791, -0.7692499, 0.6371365>,
    <0.0261060, -0.7596984, 0.6497514>,
    <0.0413167, -0.7378280, 0.6737230>,
    <0.0659231, -0.7521200, 0.6557207>,
    <0.0814705, -0.7810722, 0.6191032>,
    <0.0569268, -0.7715689, 0.6335935>,
    <0.0909240, -0.7602679, 0.6432150>,
    <0.1406311, -0.7995952, 0.5838411>,
    <0.1011091, -0.8171777, 0.5674483>,
    <0.0704521, -0.8083661, 0.5844491>,
    <0.0296952, -0.7677483, 0.6400630>,
    <0.0405528, -0.7987550, 0.6002883>,
    <0.0583246, -0.8331419, 0.5499752>,
    <0.0846028, -0.8417238, 0.5332387>,
    <0.0938565, -0.8392940, 0.5355153>,
    <0.0801491, -0.8334680, 0.5467241>,
    <0.1145326, -0.8422009, 0.5268586>,
    <0.1180671, -0.8415861, 0.5270607>,
    <0.1473387, -0.8340220, 0.5316941>,
    <0.1482465, -0.8429841, 0.5171081>,
    <0.1101656, -0.8405685, 0.5303850>,
    <0.1490639, -0.8514589, 0.5027900>,
    <0.1130062, 0.8573639, 0.5021522>,
    <0.0841869, 0.8704662, 0.4849755>,
    <0.0969457, 0.8614904, 0.4984334>,
    <0.1204713, 0.8534991, 0.5069772>,
    <0.1490114, 0.8428492, 0.5171082>,
    <0.1467992, 0.8341172, 0.5316940>,
    <0.1413276, 0.7994724, 0.5838410>,
    <0.1018249, 0.8462533, 0.5229598>,
    <0.0748768, 0.8530649, 0.5164046>,
    <0.0615385, 0.8728262, 0.4841358>,
    <0.0870712, 0.8605722, 0.5018307>,
    <0.0476171, 0.8586632, 0.5103235>,
    <0.1167966, 0.8535475, 0.5077551>,
    <0.1511418, 0.8510924, 0.5027901>,
    <0.0872351, 0.8306124, 0.5499755>,
    <0.0628463, 0.8436270, 0.5332389>,
    <0.0533113, 0.8428411, 0.5355155>,
    <0.0657988, 0.8347234, 0.5467242>,
    <0.0987657, 0.7936618, 0.6002885>,
    <0.0709896, 0.8083188, 0.5844494>,
    <0.0334541, 0.8492942, 0.5268588>,
    <0.0298665, 0.8493025, 0.5270609>,
    <0.0423284, 0.8223202, 0.5674485>,
    <0.0374713, 0.8469283, 0.5303852>,
    <-0.0333887, 0.7676040, -0.6400541>,
    <-0.0263298, 0.7657672, -0.6425786>,
    <-0.0482916, 0.7721859, -0.6335588>,
    <-0.0610837, 0.7811386, -0.6213624>,
    <-0.0658221, 0.7548826, -0.6525486>,
    <-0.0411197, 0.7490003, -0.6612924>,
    <-0.0296233, 0.7669537, -0.6410183>,
    <-0.0568642, 0.7703506, -0.6350798>,
    <-0.0404765, 0.7974229, -0.6020618>,
    <-0.0704788, 0.8083721, -0.5844375>,
    <-0.0816278, 0.7816058, -0.6184086>,
    <-0.1013424, 0.8185176, -0.5654720>,
    <-0.1406664, 0.7995979, -0.5838289>,
    <-0.0908231, 0.7591914, -0.6444995>,
    <-0.0582718, 0.8331530, -0.5499641>,
    <-0.0799506, 0.8318430, -0.5492223>,
    <-0.0938864, 0.8392977, -0.5355042>,
    <-0.0848036, 0.8434377, -0.5304915>,
    <-0.1099645, 0.8388016, -0.5332163>,
    <-0.1181707, 0.8415788, -0.5270491>,
    <-0.1489085, 0.8506532, -0.5041978>,
    <-0.1482851, 0.8429850, -0.5170956>,
    <-0.1149049, 0.8440863, -0.5237510>,
    <-0.1475857, 0.8349050, -0.5302378>,
    <-0.1132144, -0.8591802, -0.4989909>,
    <-0.1205064, -0.8535021, -0.5069640>,
    <-0.0969181, -0.8615018, -0.4984190>,
    <-0.0842431, -0.8720389, -0.4821320>,
    <-0.0748539, -0.8530740, -0.5163928>,
    <-0.1020008, -0.8474969, -0.5209077>,
    <-0.1412954, -0.7994868, -0.5838292>,
    <-0.1468691, -0.8350312, -0.5302380>,
    <-0.1489753, -0.8428633, -0.5170955>,
    <-0.1166059, -0.8518504, -0.5106408>,
    <-0.0868926, -0.8590714, -0.5044263>,
    <-0.1510122, -0.8502825, -0.5041974>,
    <-0.0614406, -0.8728425, -0.4841189>,
    <-0.0474781, -0.8575145, -0.5122643>,
    <-0.0872889, -0.8306143, -0.5499641>,
    <-0.0657119, -0.8330887, -0.5492223>,
    <-0.0532823, -0.8428500, -0.5355044>,
    <-0.0629461, -0.8453499, -0.5304916>,
    <-0.0709643, -0.8083297, -0.5844375>,
    <-0.0986094, -0.7923371, -0.6020615>,
    <-0.0373624, -0.8451534, -0.5332164>,
    <-0.0297632, -0.8493133, -0.5270494>,
    <-0.0334148, -0.8512155, -0.5237514>,
    <-0.0423312, -0.8236803, -0.5654722>,
    <0.0074557, -0.3874822, 0.9218470>,
    <0.0272940, -0.4563183, 0.8893979>,
    <0.0254403, -0.4853648, 0.8739415>,
    <0.0135893, -0.4642327, 0.8856090>,
    <-0.0215119, -0.2840755, 0.9585606>,
    <0.0080492, -0.3503162, 0.9365969>,
    <0.0228564, -0.4006086, 0.9159641>,
    <0.0487947, -0.5380897, 0.8414741>,
    <0.0373448, -0.5459922, 0.8369575>,
    <0.0394461, -0.4503276, 0.8919916>,
    <0.0932876, -0.5735115, 0.8138685>,
    <0.0727448, -0.6435487, 0.7619405>,
    <0.0529862, -0.6382241, 0.7680251>,
    <0.0223978, -0.5416419, 0.8403109>,
    <0.0318077, -0.6272360, 0.7781795>,
    <0.0058809, -0.3104641, 0.9505669>,
    <0.0057868, -0.2854910, 0.9583639>,
    <0.0121397, -0.3120912, 0.9499746>,
    <0.0152632, -0.3405234, 0.9401121>,
    <-0.0215119, -0.2840755, 0.9585606>,
    <-0.0026136, -0.2754961, 0.9612986>,
    <-0.0026136, -0.2754961, 0.9612986>,
    <-0.0023734, -0.2501709, 0.9681988>,
    <0.0095140, -0.2762575, 0.9610366>,
    <0.0180363, -0.3205053, 0.9470750>,
    <-0.0023734, -0.2501709, 0.9681988>,
    <-0.0021363, -0.2251790, 0.9743151>,
    <-0.0021363, -0.2251790, 0.9743151>,
    <0.0259296, -0.2963704, 0.9547210>,
    <0.0282383, -0.3189362, 0.9473554>,
    <0.0343240, -0.3580395, 0.9330753>,
    <0.0246510, -0.3622651, 0.9317491>,
    <0.0449896, -0.4052813, 0.9130843>,
    <0.0498730, -0.7081127, 0.7043359>,
    <0.0685997, -0.7070824, 0.7037958>,
    <0.0789788, -0.7218166, 0.6875632>,
    <0.0697255, -0.7247543, 0.6854704>,
    <0.0904171, -0.7023916, 0.7060246>,
    <0.0991751, -0.7255719, 0.6809624>,
    <0.1197397, -0.6959032, 0.7080827>,
    <0.1272127, -0.7316918, 0.6696596>,
    <0.0962899, -0.7394585, 0.6662803>,
    <0.1322648, -0.7572354, 0.6396097>,
    <0.0988767, 0.7501552, 0.6538277>,
    <0.0750444, 0.7747962, 0.6277413>,
    <0.0862644, 0.7662156, 0.6367670>,
    <0.1063012, 0.7532246, 0.6491169>,
    <0.1309945, 0.7360094, 0.6641766>,
    <0.1265778, 0.7094349, 0.6933110>,
    <0.1177887, 0.6233131, 0.7730502>,
    <0.0877082, 0.7345754, 0.6728345>,
    <0.0657666, 0.7524180, 0.6553944>,
    <0.0554068, 0.7834517, 0.6189778>,
    <0.0779270, 0.7698055, 0.6335036>,
    <0.0424938, 0.7645677, 0.6431411>,
    <0.1040917, 0.7613552, 0.6399244>,
    <0.1347631, 0.7578922, 0.6383089>,
    <0.0739622, 0.7072823, 0.7030515>,
    <0.0548436, 0.7145384, 0.6974432>,
    <0.0472709, 0.7273805, 0.6846043>,
    <0.0571944, 0.7265727, 0.6847050>,
    <0.0776076, 0.6243370, 0.7772904>,
    <0.0579746, 0.6502292, 0.7575229>,
    <0.0317972, 0.7196139, 0.6936460>,
    <0.0277528, 0.7358716, 0.6765521>,
    <0.0388703, 0.6794516, 0.7326900>,
    <0.0334580, 0.7458388, 0.6652857>,
    <-0.0259128, 0.5834571, -0.8117305>,
    <-0.0208707, 0.6053602, -0.7956780>,
    <-0.0388002, 0.6207628, -0.7830377>,
    <-0.0487718, 0.6216384, -0.7817845>,
    <-0.0542025, 0.5991666, -0.7987875>,
    <-0.0366007, 0.5738994, -0.8181075>,
    <-0.0244574, 0.6290464, -0.7769829>,
    <-0.0468465, 0.6349356, -0.7711434>,
    <-0.0343290, 0.6751456, -0.7368853>,
    <-0.0599735, 0.6881525, -0.7230832>,
    <-0.0671303, 0.6444702, -0.7616769>,
    <-0.0866798, 0.7009641, -0.7079096>,
    <-0.1197499, 0.6808809, -0.7225380>,
    <-0.0744339, 0.6194650, -0.7814875>,
    <-0.0507865, 0.7242855, -0.6876272>,
    <-0.0700959, 0.7282361, -0.6817322>,
    <-0.0822393, 0.7354607, -0.6725580>,
    <-0.0739850, 0.7361257, -0.6727891>,
    <-0.0970950, 0.7409039, -0.6645555>,
    <-0.1038456, 0.7407503, -0.6637056>,
    <-0.1329597, 0.7593060, -0.6370056>,
    <-0.1311275, 0.7457039, -0.6532467>,
    <-0.1003895, 0.7388275, -0.6663752>,
    <-0.1290951, 0.7311005, -0.6699452>,
    <-0.1004115, -0.7617405, -0.6400538>,
    <-0.1070442, -0.7587060, -0.6425782>,
    <-0.0865307, -0.7688407, -0.6335585>,
    <-0.0754876, -0.7798786, -0.6213622>,
    <-0.0662619, -0.7548440, -0.6525488>,
    <-0.0895676, -0.7447616, -0.6612925>,
    <-0.1203469, -0.6807756, -0.7225380>,
    <-0.1287414, -0.7311628, -0.6699452>,
    <-0.1318262, -0.7455806, -0.6532468>,
    <-0.1040068, -0.7604463, -0.6410180>,
    <-0.0777697, -0.7685218, -0.6350796>,
    <-0.1347567, -0.7589890, -0.6370058>,
    <-0.0553368, -0.7839060, -0.6184086>,
    <-0.0423889, -0.7634287, -0.6444997>,
    <-0.0757560, -0.7221006, -0.6876276>,
    <-0.0574259, -0.7293442, -0.6817325>,
    <-0.0467216, -0.7385676, -0.6725585>,
    <-0.0549660, -0.7377891, -0.6727897>,
    <-0.0604341, -0.6881116, -0.7230838>,
    <-0.0834304, -0.6708493, -0.7368857>,
    <-0.0330368, -0.7465079, -0.6645559>,
    <-0.0263621, -0.7475287, -0.6637061>,
    <-0.0294318, -0.7450350, -0.6663758>,
    <-0.0363583, -0.7053662, -0.7079101>,
    <0.0550666, -0.4096429, 0.9105824>,
    <0.0690582, -0.4452987, 0.8927150>,
    <0.0697945, -0.4376000, 0.8964569>,
    <0.0561471, -0.4092269, 0.9107035>,
    <0.0259296, -0.2963704, 0.9547210>,
    <0.0649975, -0.4352199, 0.8979749>,
    <0.0649975, -0.4352199, 0.8979749>,
    <0.0672312, -0.4501763, 0.8904051>,
    <0.0722011, -0.4262435, 0.9017225>,
    <0.0790863, -0.4444488, 0.8923064>,
    <0.0672312, -0.4501763, 0.8904051>,
    <0.0608895, -0.4077127, 0.9110778>,
    <0.0608895, -0.4077127, 0.9110778>,
    <0.0504653, -0.3235362, 0.9448691>,
    <0.0760447, -0.3962743, 0.9149775>,
    <0.0917244, -0.4488561, 0.8888840>,
    <0.0712063, -0.4427867, 0.8937951>,
    <0.0978652, -0.4886101, 0.8669963>,
    <0.0563665, 0.4279209, 0.9020568>,
    <0.0493195, 0.5329964, 0.8446789>,
    <0.0575543, 0.5214410, 0.8513441>,
    <0.0662520, 0.4789227, 0.8753535>,
    <0.0811755, 0.4488212, 0.8899270>,
    <0.0722252, 0.3554131, 0.9319147>,
    <0.0702286, 0.3650889, 0.9283200>,
    <0.0435536, 0.4940300, 0.8683533>,
    <0.0423741, 0.5584927, 0.8284264>,
    <0.0435753, 0.6072943, 0.7932810>,
    <0.0568846, 0.5693667, 0.8201132>,
    <0.0381326, 0.5863934, 0.8091283>,
    <0.0717284, 0.5423052, 0.8371141>,
    <0.0914666, 0.5294714, 0.8433824>,
    <0.0388314, 0.6251981, 0.7794995>,
    <0.0424521, 0.6469753, 0.7613283>,
    <0.0431831, 0.6085616, 0.7923308>,
    <0.0413207, 0.5869696, 0.8085538>,
    <0.0702286, 0.3650889, 0.9283200>,
    <0.0326205, 0.7110934, 0.7023404>,
    <0.0326205, 0.7110934, 0.7023404>,
    <0.0401177, 0.6963668, 0.7165639>,
    <0.0475654, 0.6030652, 0.7962725>,
    <0.0448717, 0.5728765, 0.8184125>,
    <0.0401177, 0.6963668, 0.7165639>,
    <0.0474866, 0.6303391, 0.7748662>,
    <0.0474866, 0.6303391, 0.7748662>,
    <0.0536171, 0.5532002, 0.8313211>,
    <0.0408634, 0.5510829, 0.8334494>,
    <-0.0347894, 0.3951276, -0.9179673>,
    <-0.0347767, 0.3975164, -0.9169358>,
    <-0.0332040, 0.3795420, -0.9245785>,
    <-0.0331918, 0.3696132, -0.9285927>,
    <-0.0339420, 0.3603581, -0.9321963>,
    <-0.0344548, 0.3900485, -0.9201495>,
    <-0.0353323, 0.4039315, -0.9141066>,
    <-0.0353369, 0.4039407, -0.9141024>,
    <-0.0353369, 0.4039407, -0.9141024>,
    <-0.0353394, 0.4039468, -0.9140996>,
    <-0.0345149, 0.3951601, -0.9179636>,
    <-0.0332244, 0.3756869, -0.9261509>,
    <-0.0353394, 0.4039468, -0.9140996>,
    <-0.0353408, 0.4039515, -0.9140975>,
    <-0.0353408, 0.4039515, -0.9140975>,
    <-0.0353413, 0.4039531, -0.9140968>,
    <-0.0355166, 0.3997166, -0.9159504>,
    <-0.0371668, 0.3969143, -0.9171028>,
    <-0.0327337, 0.3522650, -0.9353277>,
    <-0.0419497, 0.3934436, -0.9183912>,
    <-0.0772204, 0.4240679, -0.9023322>,
    <-0.0361162, 0.3342907, -0.9417778>,
    <-0.0361584, 0.4089504, -0.9118400>,
    <-0.0351310, 0.4228333, -0.9055263>,
    <-0.0391972, 0.4368577, -0.8986762>,
    <-0.0405361, 0.4250789, -0.9042481>,
    <-0.0353413, 0.4039531, -0.9140968>,
    <-0.0340711, 0.4479554, -0.8934065>,
    <-0.0422220, 0.4633882, -0.8851489>,
    <-0.0371030, 0.5176571, -0.8547833>,
    <-0.0499806, 0.5256624, -0.8492237>,
    <-0.0482715, 0.4551974, -0.8890811>,
    <-0.0617625, 0.5162726, -0.8541943>,
    <-0.0465434, 0.5723443, -0.8186914>,
    <-0.0584796, 0.5790659, -0.8131807>,
    <-0.0655342, 0.5774818, -0.8137690>,
    <-0.0592743, 0.5708888, -0.8188849>,
    <-0.0784580, 0.5962824, -0.7989316>,
    <-0.0796003, 0.5769584, -0.8128855>,
    <-0.1084153, 0.6204297, -0.7767323>,
    <-0.1011040, 0.5815578, -0.8071979>,
    <-0.0729044, 0.5536226, -0.8295704>,
    <-0.0926612, 0.5351243, -0.8396760>,
    <-0.0755300, -0.5770518, -0.8132075>,
    <-0.0844620, -0.5989754, -0.7963006>,
    <-0.0694850, -0.6171934, -0.7837373>,
    <-0.0597482, -0.6191474, -0.7829985>,
    <-0.0504088, -0.5983373, -0.7996571>,
    <-0.0630503, -0.5691725, -0.8197971>,
    <-0.0712044, -0.4235951, -0.9030488>,
    <-0.0958690, -0.5339795, -0.8400446>,
    <-0.1038776, -0.5808740, -0.8073382>,
    <-0.0851205, -0.6235341, -0.7771485>,
    <-0.0640955, -0.6331749, -0.7713504>,
    <-0.1103174, -0.6200436, -0.7767728>,
    <-0.0457651, -0.6458698, -0.7620746>,
    <-0.0341988, -0.6226545, -0.7817492>,
    <-0.0529046, -0.5733718, -0.8175854>,
    <-0.0425730, -0.5816166, -0.8123483>,
    <-0.0350450, -0.5857361, -0.8097438>,
    <-0.0397401, -0.5804738, -0.8133086>,
    <-0.0406686, -0.5306153, -0.8466365>,
    <-0.0525823, -0.5183815, -0.8535314>,
    <-0.0260016, -0.6027204, -0.7975287>,
    <-0.0209776, -0.5899535, -0.8071647>,
    <-0.0227344, -0.5729363, -0.8192845>,
    <-0.0261278, -0.5287759, -0.8483592>,
    <-0.0348620, -0.4079708, -0.9123292>,
    <-0.0383912, -0.4236032, -0.9050340>,
    <-0.0362322, -0.4355342, -0.8994427>,
    <-0.0323374, -0.4221339, -0.9059565>,
    <-0.0353113, -0.4038178, -0.9141577>,
    <-0.0355215, -0.4029536, -0.9145308>,
    <-0.0370068, -0.4050787, -0.9135325>,
    <-0.0436328, -0.4488637, -0.8925344>,
    <-0.0375293, -0.4629487, -0.8855902>,
    <-0.0407504, -0.4041587, -0.9137807>,
    <-0.0290997, -0.4546302, -0.8902048>,
    <-0.0349635, -0.3998661, -0.9159065>,
    <-0.0350412, -0.4006459, -0.9155626>,
    <-0.0342704, -0.3918013, -0.9194114>,
    <-0.0345673, -0.3913653, -0.9195859>,
    <-0.0353113, -0.4038178, -0.9141577>,
    <-0.0353031, -0.4037315, -0.9141962>,
    <-0.0353031, -0.4037315, -0.9141962>,
    <-0.0353044, -0.4037049, -0.9142078>,
    <-0.0351140, -0.3992328, -0.9161769>,
    <-0.0345745, -0.3850451, -0.9222499>,
    <-0.0353044, -0.4037049, -0.9142078>,
    <-0.0353154, -0.4037121, -0.9142042>,
    <-0.0353154, -0.4037121, -0.9142042>,
    <-0.0353415, -0.4037519, -0.9141857>,
    <-0.0350792, -0.3949302, -0.9180412>,
    <-0.0364758, -0.3750880, -0.9262713>,
    <-0.0348413, -0.3767017, -0.9256792>,
    <-0.0409355, -0.3582649, -0.9327221>,
    <-0.0365139, 0.3873029, -0.9212292>,
    <-0.0393161, 0.3577339, -0.9329956>,
    <-0.0477576, 0.3630097, -0.9305607>,
    <-0.0431140, 0.3752953, -0.9259020>,
    <-0.0327948, 0.3750851, -0.9264101>,
    <-0.0349975, 0.4001729, -0.9157712>,
    <-0.0349975, 0.4001729, -0.9157712>,
    <-0.0353323, 0.4039315, -0.9141066>,
    <-0.0514043, 0.3410578, -0.9386358>,
    <-0.0614650, 0.3537750, -0.9333088>,
    <-0.0776228, 0.3546541, -0.9317699>,
    <-0.0797642, 0.3559038, -0.9311123>,
    <-0.0552477, 0.3488711, -0.9355408>,
    <-0.0765104, 0.3395460, -0.9374725>,
    <-0.0724124, 0.3211062, -0.9442707>,
    <-0.0275041, 0.3147131, -0.9487883>,
    <-0.0275041, 0.3147131, -0.9487883>,
    <-0.0327948, 0.3750851, -0.9264101>,
    <-0.0382798, -0.3896480, -0.9201680>,
    <-0.0473655, -0.3735353, -0.9264059>,
    <-0.0538161, -0.3646568, -0.9295855>,
    <-0.0440727, -0.3658827, -0.9296168>,
    <-0.0353415, -0.4037519, -0.9141857>,
    <-0.0349845, -0.3992475, -0.9161755>,
    <-0.0349845, -0.3992475, -0.9161755>,
    <-0.0323990, -0.3691728, -0.9287959>,
    <-0.0621782, -0.3481396, -0.9353784>,
    <-0.0679884, -0.3516382, -0.9336638>,
    <-0.0323990, -0.3691728, -0.9287959>,
    <-0.0263805, -0.2998620, -0.9536178>,
    <-0.0263805, -0.2998620, -0.9536178>,
    <-0.0789069, -0.3304965, -0.9405029>,
    <-0.0818216, -0.3430399, -0.9357504>,
    <-0.0823012, -0.3473987, -0.9340989>,
    <-0.0577644, -0.3443650, -0.9370571>,
    <-0.0771524, -0.3347772, -0.9391335>,
    <-0.1028421, 0.3853229, -0.9170331>,
    <-0.1007360, 0.3812140, -0.9189821>,
    <-0.0974512, 0.3726436, -0.9228434>,
    <-0.0986945, 0.3749062, -0.9217943>,
    <-0.1023666, 0.3903966, -0.9149380>,
    <-0.1039704, 0.3896010, -0.9150963>,
    <-0.1049497, 0.3916641, -0.9141033>,
    <-0.1046539, 0.3905545, -0.9146118>,
    <-0.1046539, 0.3905545, -0.9146118>,
    <-0.1026054, 0.3829051, -0.9180718>,
    <-0.0940525, 0.3663603, -0.9257075>,
    <-0.0915985, 0.3640569, -0.9268615>,
    <-0.1026054, 0.3829051, -0.9180718>,
    <-0.0968722, 0.3615049, -0.9273241>,
    <-0.0968722, 0.3615049, -0.9273241>,
    <-0.0724124, 0.3211062, -0.9442707>,
    <-0.0922054, 0.3643037, -0.9267044>,
    <-0.0980928, 0.3916205, -0.9148832>,
    <-0.1019594, -0.3814574, -0.9187462>,
    <-0.0956069, -0.3617425, -0.9273627>,
    <-0.0958336, -0.3636379, -0.9265978>,
    <-0.1008831, -0.3800759, -0.9194373>,
    <-0.1031337, -0.3849809, -0.9171440>,
    <-0.1047018, -0.3908341, -0.9144869>,
    <-0.1047018, -0.3908341, -0.9144869>,
    <-0.1048981, -0.3915684, -0.9141502>,
    <-0.1028935, -0.3863962, -0.9165757>,
    <-0.0997375, -0.3828020, -0.9184307>,
    <-0.0877206, -0.3430210, -0.9352228>,
    <-0.0904935, -0.3531066, -0.9311963>,
    <-0.0937706, -0.3812657, -0.9196975>,
    <-0.0955726, -0.3670549, -0.9252765>,
    <-0.0789069, -0.3304965, -0.9405029>,
    <-0.0986433, -0.3682212, -0.9244905>,
    <-0.0986433, -0.3682212, -0.9244905>,
    <-0.1031337, -0.3849809, -0.9171440>,
    <0.1409787, 0.5184551, 0.8434034>,
    <0.1244358, 0.4661904, 0.8758894>,
    <0.1194316, 0.4829108, 0.8674868>,
    <0.1283734, 0.5059707, 0.8529443>,
    <0.1383233, 0.5414888, 0.8292506>,
    <0.1493342, 0.5680938, 0.8093014>,
    <0.1541919, 0.5842066, 0.7968234>,
    <0.1460309, 0.5174534, 0.8431589>,
    <0.1460309, 0.5174534, 0.8431589>,
    <0.1296972, 0.4414090, 0.8878833>,
    <0.0999380, 0.3937888, 0.9137520>,
    <0.1035363, 0.4621549, 0.8807344>,
    <0.1296972, 0.4414090, 0.8878833>,
    <0.1039186, 0.3460547, 0.9324415>,
    <0.1039186, 0.3460547, 0.9324415>,
    <0.0702286, 0.3650889, 0.9283200>,
    <0.1134917, 0.5094109, 0.8530065>,
    <0.1267803, 0.5277752, 0.8398691>,
    <0.0883749, -0.3890839, 0.9169534>,
    <0.0853020, -0.3336883, 0.9388161>,
    <0.0767656, -0.3140449, 0.9462995>,
    <0.0758654, -0.3405386, 0.9371648>,
    <0.0883405, -0.4059692, 0.9096070>,
    <0.0807253, -0.3249827, 0.9422684>,
    <0.0759062, -0.2833207, 0.9560165>,
    <0.0717396, -0.2816379, 0.9568352>,
    <0.0812158, -0.2914148, 0.9531429>,
    <0.1015309, -0.2789512, 0.9549229>,
    <0.0709835, -0.2649093, 0.9616571>,
    <0.0709835, -0.2649093, 0.9616571>,
    <0.0733970, -0.2739167, 0.9589487>,
    <0.0737145, -0.3074253, 0.9487127>,
    <0.0733970, -0.2739167, 0.9589487>,
    <0.0816502, -0.3047174, 0.9489365>,
    <0.0816502, -0.3047174, 0.9489365>,
    <0.0513387, -0.2911494, 0.9552991>,
    <0.2123615, -0.9578613, 0.1934021>,
    <0.2479016, -0.9300200, 0.2713073>,
    <0.2174756, -0.9001738, 0.3773480>,
    <0.1880503, -0.9235015, 0.3343383>,
    <0.2256909, -0.9578209, 0.1778842>,
    <0.2556469, -0.9320434, 0.2567875>,
    <0.2505394, -0.8398434, 0.4815528>,
    <0.2031813, -0.8019893, 0.5617210>,
    <0.2704023, -0.8619913, 0.4287815>,
    <0.2256865, -0.6165122, 0.7543065>,
    <0.2097367, -0.6584631, 0.7227979>,
    <0.1747362, -0.6534483, 0.7365274>,
    <0.1668969, -0.8173631, 0.5514191>,
    <0.1360244, -0.6236117, 0.7698089>,
    <0.0972343, -0.4349011, 0.8952131>,
    <0.1410651, -0.4990746, 0.8550001>,
    <0.1175081, -0.3946964, 0.9112665>,
    <0.0850890, -0.3377405, 0.9373853>,
    <0.1673339, -0.4820668, 0.8600064>,
    <0.1345812, -0.3776285, 0.9161248>,
    <0.1635853, -0.4200847, 0.8926190>,
    <0.1368905, -0.3492804, 0.9269650>,
    <0.1016357, -0.3154905, 0.9434702>,
    <0.1294655, -0.3252322, 0.9367298>,
    <0.1015309, -0.2789512, 0.9549229>,
    <0.1196737, 0.4020433, 0.9077661>,
    <0.0964196, 0.3523667, 0.9308818>,
    <0.0946662, 0.3305829, 0.9390172>,
    <0.1085996, 0.3529551, 0.9293163>,
    <0.1228094, 0.3693073, 0.9211569>,
    <0.1454348, 0.4416370, 0.8853279>,
    <0.2188120, 0.6147911, 0.7577290>,
    <0.1248474, 0.3985015, 0.9086306>,
    <0.0956121, 0.3331893, 0.9379996>,
    <0.0784192, 0.2956755, 0.9520643>,
    <0.0819555, 0.2915026, 0.9530527>,
    <0.0772794, 0.2996364, 0.9509185>,
    <0.0725866, 0.2708977, 0.9598675>,
    <0.0730700, 0.2727054, 0.9593188>,
    <0.0730700, 0.2727054, 0.9593188>,
    <0.0756441, 0.2823131, 0.9563353>,
    <0.0932128, 0.3147180, 0.9445972>,
    <0.0756441, 0.2823131, 0.9563353>,
    <0.0842764, 0.3145301, 0.9454990>,
    <0.0842764, 0.3145301, 0.9454990>,
    <0.1044403, 0.2869520, 0.9522346>,
    <0.1133040, 0.3431997, 0.9324034>,
    <0.1309545, 0.4106359, 0.9023464>,
    <0.1246789, 0.4942620, 0.8603256>,
    <0.0933379, 0.3986410, 0.9123450>,
    <0.0970839, 0.3373740, 0.9363512>,
    <0.1895679, 0.5900274, 0.7848132>,
    <0.1734953, 0.6461555, 0.7432244>,
    <0.0933066, 0.4884443, 0.8675921>,
    <0.0689876, 0.3863647, 0.9197625>,
    <0.1456632, 0.6621791, 0.7350518>,
    <0.0685598, 0.3158279, 0.9463362>,
    <0.0725866, 0.2708977, 0.9598675>,
    <0.2094290, -0.9447126, 0.2523045>,
    <0.2430227, -0.9402793, 0.2383585>,
    <0.2271597, -0.9398730, 0.2550240>,
    <0.2000620, -0.9439899, 0.2624087>,
    <0.2187200, -0.9370658, 0.2721567>,
    <0.2489958, -0.9299080, 0.2706884>,
    <0.2671289, -0.9326126, 0.2426436>,
    <0.2371604, -0.9351694, 0.2630840>,
    <0.2789937, -0.9217419, 0.2693591>,
    <0.3338738, -0.9178853, 0.2145109>,
    <0.2879291, -0.9375287, 0.1952862>,
    <0.2526309, -0.9434108, 0.2148340>,
    <0.2036576, -0.9413796, 0.2689387>,
    <0.2172010, -0.9476885, 0.2339023>,
    <0.2367347, -0.9495174, 0.2058479>,
    <0.2670599, -0.9468661, 0.1792304>,
    <0.2748138, -0.9341670, 0.2276168>,
    <0.2569945, -0.9265063, 0.2748454>,
    <0.3002784, -0.9368609, 0.1792331>,
    <0.2989329, -0.9201005, 0.2530893>,
    <0.3340437, -0.9216828, 0.1972705>,
    <0.3217025, -0.9018414, 0.2884261>,
    <0.2792350, -0.8868899, 0.3680410>,
    <0.2929739, -0.8341851, 0.4672275>,
    <0.2951104, 0.9359989, 0.1918745>,
    <0.2507971, 0.9303486, 0.2674926>,
    <0.2624241, 0.8906069, 0.3714201>,
    <0.2992434, 0.8955454, 0.3293203>,
    <0.3334474, 0.8986182, 0.2851284>,
    <0.3365554, 0.9209334, 0.1964997>,
    <0.3342431, 0.9177509, 0.2145109>,
    <0.2835395, 0.9424153, 0.1773662>,
    <0.2449515, 0.9356108, 0.2542267>,
    <0.2032495, 0.8520789, 0.4823393>,
    <0.2250814, 0.7961771, 0.5616407>,
    <0.1984042, 0.8841340, 0.4230165>,
    <0.2637768, 0.7886176, 0.5554315>,
    <0.3113878, 0.8255895, 0.4705737>,
    <0.2697711, 0.9407797, 0.2053222>,
    <0.2421682, 0.9536025, 0.1788763>,
    <0.2291626, 0.9467284, 0.2262517>,
    <0.2408491, 0.9314688, 0.2726859>,
    <0.2857426, 0.9293227, 0.2339028>,
    <0.2529206, 0.9433331, 0.2148343>,
    <0.2084003, 0.9615714, 0.1787451>,
    <0.2012745, 0.9468315, 0.2509953>,
    <0.2194103, 0.9558883, 0.1952863>,
    <0.2021757, 0.9101870, 0.3615032>,
    <-0.0714184, 0.3144218, -0.9465930>,
    <-0.0587666, 0.2643442, -0.9626363>,
    <-0.0585917, 0.2396916, -0.9690794>,
    <-0.0664184, 0.2593220, -0.9635044>,
    <-0.0619669, 0.2520226, -0.9657353>,
    <-0.0717809, 0.3333783, -0.9400566>,
    <-0.0550381, 0.2298438, -0.9716700>,
    <-0.0532195, 0.2089278, -0.9764819>,
    <-0.0377933, 0.2143294, -0.9760300>,
    <-0.0603105, 0.2250761, -0.9724728>,
    <-0.0603105, 0.2250761, -0.9724728>,
    <-0.0539247, 0.2012446, -0.9780556>,
    <-0.0566861, 0.2112975, -0.9757766>,
    <-0.0539247, 0.2012446, -0.9780556>,
    <-0.0520753, 0.1943428, -0.9795504>,
    <-0.0520753, 0.1943428, -0.9795504>,
    <-0.0747538, 0.2053815, -0.9758229>,
    <-0.0603033, 0.2174689, -0.9742027>,
    <-0.2122661, 0.9573692, -0.1959266>,
    <-0.1864289, 0.9161561, -0.3548271>,
    <-0.2149100, 0.8895094, -0.4032205>,
    <-0.2470200, 0.9262593, -0.2846486>,
    <-0.2549007, 0.9291674, -0.2677191>,
    <-0.2256683, 0.9578736, -0.1776286>,
    <-0.1607734, 0.7889921, -0.5929952>,
    <-0.1956947, 0.7724057, -0.6042293>,
    <-0.1231099, 0.5662888, -0.8149607>,
    <-0.1604023, 0.5998251, -0.7838884>,
    <-0.2447006, 0.8192527, -0.5186006>,
    <-0.1935832, 0.6064957, -0.7711605>,
    <-0.2058990, 0.5624396, -0.8007917>,
    <-0.2659604, 0.8471055, -0.4600840>,
    <-0.0802410, 0.3639131, -0.9279702>,
    <-0.0655825, 0.2650748, -0.9619949>,
    <-0.0957671, 0.3216618, -0.9419991>,
    <-0.1215395, 0.4299824, -0.8946191>,
    <-0.0772386, 0.2397533, -0.9677564>,
    <-0.1094315, 0.3038513, -0.9464138>,
    <-0.0747538, 0.2053815, -0.9758229>,
    <-0.0982294, 0.2459850, -0.9642833>,
    <-0.1085075, 0.2752347, -0.9552340>,
    <-0.1444288, 0.4130207, -0.8991964>,
    <-0.1371350, 0.3502028, -0.9265808>,
    <-0.0969984, -0.3260517, -0.9403625>,
    <-0.0846416, -0.2747165, -0.9577926>,
    <-0.0723990, -0.2530289, -0.9647459>,
    <-0.0750064, -0.2749755, -0.9585210>,
    <-0.0746437, -0.2582525, -0.9631895>,
    <-0.1030327, -0.3266420, -0.9395155>,
    <-0.1997104, -0.5607673, -0.8035271>,
    <-0.1210073, -0.3694506, -0.9213379>,
    <-0.0965065, -0.2919412, -0.9515549>,
    <-0.0698248, -0.2355820, -0.9693429>,
    <-0.0607930, -0.2164421, -0.9744008>,
    <-0.0856059, -0.2601836, -0.9617568>,
    <-0.0769817, -0.2115092, -0.9743396>,
    <-0.0623364, -0.2326475, -0.9705613>,
    <-0.0623364, -0.2326475, -0.9705613>,
    <-0.0556239, -0.2075951, -0.9766321>,
    <-0.0585556, -0.2211007, -0.9734915>,
    <-0.0556239, -0.2075951, -0.9766321>,
    <-0.0536468, -0.2002158, -0.9782820>,
    <-0.0536468, -0.2002158, -0.9782820>,
    <-0.0976161, -0.3643092, 0.9261479>,
    <-0.0576562, -0.2249793, -0.9726562>,
    <-0.1100114, -0.3412257, -0.9335216>,
    <-0.0771622, -0.2634338, -0.9615865>,
    <-0.0760517, -0.3242097, -0.9429232>,
    <-0.1071332, -0.4245476, -0.8990450>,
    <-0.1590583, -0.5924088, -0.7897799>,
    <-0.1719804, -0.5340687, -0.8277641>,
    <-0.0503674, -0.2415172, -0.9690885>,
    <-0.0531444, -0.3126264, -0.9483883>,
    <-0.0976161, -0.3643092, 0.9261479>,
    <-0.0767316, -0.4211289, -0.9037493>,
    <-0.1312128, -0.6119952, -0.7799006>,
    <0.2008247, -0.9062304, 0.3720428>,
    <0.2336671, -0.9045349, 0.3566739>,
    <0.2179743, -0.9021650, 0.3722708>,
    <0.1917346, -0.9048152, 0.3801937>,
    <0.2090472, -0.8956842, 0.3924908>,
    <0.2382302, -0.8899139, 0.3889726>,
    <0.2568873, -0.8972833, 0.3590146>,
    <0.2274626, -0.8972017, 0.3785365>,
    <0.2671821, -0.8830802, 0.3857242>,
    <0.3227235, -0.8874808, 0.3289793>,
    <0.2790217, -0.9088515, 0.3100579>,
    <0.2441674, -0.9120578, 0.3294433>,
    <0.1951794, -0.9022719, 0.3844612>,
    <0.2093842, -0.9137753, 0.3480990>,
    <0.2307753, -0.9257124, 0.2996653>,
    <0.2605768, -0.9241470, 0.2793781>,
    <0.2702640, -0.9189738, 0.2871315>,
    <0.2545287, -0.9184957, 0.3026231>,
    <0.2934926, -0.9160802, 0.2732383>,
    <0.2967545, -0.9130463, 0.2797914>,
    <0.3288296, -0.9017008, 0.2807255>,
    <0.3289553, -0.9045788, 0.2711560>,
    <0.2874814, -0.9131738, 0.2889085>,
    <0.3290522, -0.9073526, 0.2616025>,
    <0.2909853, 0.9228596, 0.2523046>,
    <0.2596757, 0.9358171, 0.2383586>,
    <0.2732103, 0.9275337, 0.2550243>,
    <0.2987360, 0.9175501, 0.2624091>,
    <0.3294575, 0.9043961, 0.2711559>,
    <0.3277039, 0.9021106, 0.2807252>,
    <0.3232410, 0.8872926, 0.3289789>,
    <0.2791156, 0.9208829, 0.2721565>,
    <0.2493172, 0.9298219, 0.2706882>,
    <0.2349657, 0.9412307, 0.2426437>,
    <0.2621977, 0.9284605, 0.2630844>,
    <0.2192552, 0.9377489, 0.2693589>,
    <0.2943170, 0.9170873, 0.2689393>,
    <0.3311663, 0.9065832, 0.2616024>,
    <0.2629987, 0.9170783, 0.2996648>,
    <0.2364072, 0.9306234, 0.2793775>,
    <0.2254312, 0.9309869, 0.2871310>,
    <0.2388194, 0.9227052, 0.3026227>,
    <0.2755554, 0.8960450, 0.3480984>,
    <0.2445735, 0.9119492, 0.3294427>,
    <0.2038679, 0.9400952, 0.2732376>,
    <0.1995260, 0.9390988, 0.2797908>,
    <0.2127857, 0.9265995, 0.3100573>,
    <0.2076206, 0.9345726, 0.2889080>,
    <-0.2096401, 0.9455651, -0.2489128>,
    <-0.2000230, 0.9439948, -0.2624205>,
    <-0.2271777, 0.9398658, -0.2550346>,
    <-0.2432847, 0.9409724, -0.2353371>,
    <-0.2490106, 0.9299000, -0.2707023>,
    <-0.2188358, 0.9376855, -0.2699201>,
    <-0.2034182, 0.9404941, -0.2721981>,
    <-0.2369803, 0.9343890, -0.2660030>,
    <-0.2170672, 0.9471735, -0.2361021>,
    <-0.2526454, 0.9434069, -0.2148341>,
    <-0.2672093, 0.9325876, -0.2426510>,
    <-0.2881071, 0.9379427, -0.1930227>,
    <-0.3338924, 0.9178786, -0.2145103>,
    <-0.2788755, 0.9211341, -0.2715519>,
    <-0.2365740, 0.9491005, -0.2079446>,
    <-0.2559960, 0.9230775, -0.2870436>,
    <-0.2744352, 0.9328291, -0.2334848>,
    <-0.2671521, 0.9471388, -0.1776454>,
    <-0.2762741, 0.8774429, -0.3921309>,
    <-0.2982176, 0.9176570, -0.2626252>,
    <-0.2863185, 0.8159060, -0.5023139>,
    <-0.3201738, 0.8976347, -0.3028871>,
    <-0.3004320, 0.9370581, -0.1779403>,
    <-0.3339908, 0.9213529, -0.1988943>,
    <-0.2949575, -0.9355585, -0.1942428>,
    <-0.2970674, -0.8886446, -0.3493733>,
    <-0.2594256, -0.8804678, -0.3968309>,
    <-0.2497221, -0.9268107, -0.2804654>,
    <-0.2441838, -0.9328432, -0.2649109>,
    <-0.2835877, -0.9424588, -0.1770576>,
    <-0.3342247, -0.9177576, -0.2145107>,
    <-0.3363902, -0.9206625, -0.1980461>,
    <-0.3319682, -0.8945546, -0.2992810>,
    <-0.2548684, -0.7610840, -0.5964840>,
    <-0.2168386, -0.7670599, -0.6038213>,
    <-0.3047343, -0.8073991, -0.5052165>,
    <-0.1968712, -0.8317671, -0.5190425>,
    <-0.1921074, -0.8651499, -0.4632607>,
    <-0.2697053, -0.9403501, -0.2073661>,
    <-0.2400220, -0.9280871, -0.2846818>,
    <-0.2288313, -0.9454202, -0.2319847>,
    <-0.2422264, -0.9538905, -0.1772552>,
    <-0.2529062, -0.9433370, -0.2148341>,
    <-0.2856011, -0.9288099, -0.2361020>,
    <-0.1994439, -0.8979470, -0.3923179>,
    <-0.2006884, -0.9444329, -0.2603281>,
    <-0.2083678, -0.9618270, -0.1774026>,
    <-0.2194634, -0.9563357, -0.1930227>,
    <-0.2011418, 0.9075338, -0.3686794>,
    <-0.1917017, 0.9048299, -0.3801753>,
    <-0.2180003, 0.9021656, -0.3722542>,
    <-0.2340384, 0.9056173, -0.3536711>,
    <-0.2382534, 0.8899173, -0.3889505>,
    <-0.2092367, 0.8966071, -0.3902766>,
    <-0.1948619, 0.9010052, -0.3875802>,
    <-0.2272025, 0.8960815, -0.3813357>,
    <-0.2091962, 0.9130008, -0.3502377>,
    <-0.2441877, 0.9120522, -0.3294436>,
    <-0.2569776, 0.8972625, -0.3590020>,
    <-0.2792894, 0.9095302, -0.3078186>,
    <-0.3227491, 0.8874712, -0.3289801>,
    <-0.2669956, 0.8822209, -0.3878140>,
    <-0.2307242, 0.9257220, -0.2996752>,
    <-0.2542400, 0.9176171, -0.3055175>,
    <-0.2702840, 0.9189642, -0.2871433>,
    <-0.2608344, 0.9249813, -0.2763603>,
    <-0.2872061, 0.9122275, -0.2921534>,
    <-0.2968374, 0.9130157, -0.2798033>,
    <-0.3288851, 0.9069546, -0.2631879>,
    <-0.3289797, 0.9045664, -0.2711677>,
    <-0.2938778, 0.9169623, -0.2698445>,
    <-0.3290593, 0.9021124, -0.2791293>,
    <-0.2912290, -0.9237035, -0.2489129>,
    <-0.2987724, -0.9175350, -0.2624205>,
    <-0.2731913, -0.9275365, -0.2550346>,
    <-0.2597956, -0.9365483, -0.2353372>,
    <-0.2493006, -0.9298222, -0.2707025>,
    <-0.2793254, -0.9214772, -0.2699203>,
    <-0.3232154, -0.8873016, -0.3289797>,
    <-0.3277927, -0.9025735, -0.2791290>,
    <-0.3294311, -0.9044021, -0.2711677>,
    <-0.2940818, -0.9162009, -0.2721980>,
    <-0.2619636, -0.9276947, -0.2660029>,
    <-0.3310387, -0.9061707, -0.2631882>,
    <-0.2348839, -0.9412492, -0.2426511>,
    <-0.2190539, -0.9371632, -0.2715520>,
    <-0.2630481, -0.9170607, -0.2996755>,
    <-0.2386304, -0.9217996, -0.3055177>,
    <-0.2254095, -0.9309883, -0.2871436>,
    <-0.2366015, -0.9314744, -0.2763605>,
    <-0.2445535, -0.9119541, -0.3294439>,
    <-0.2753313, -0.8952798, -0.3502381>,
    <-0.2073861, -0.9336152, -0.2921535>,
    <-0.1994392, -0.9391134, -0.2798035>,
    <-0.2039756, -0.9410514, -0.2698447>,
    <-0.2128934, -0.9273208, -0.3078189>,
    <0.1870446, -0.8443089, 0.5021522>,
    <0.2186071, -0.8467643, 0.4849754>,
    <0.2035479, -0.8426936, 0.4984334>,
    <0.1787079, -0.8432305, 0.5069771>,
    <0.1937515, -0.8300442, 0.5229599>,
    <0.2214042, -0.8272282, 0.5164046>,
    <0.2406968, -0.8412358, 0.4841356>,
    <0.2125129, -0.8384536, 0.5018305>,
    <0.2489347, -0.8231656, 0.5103234>,
    <0.3048260, -0.8384693, 0.4517194>,
    <0.2643706, -0.8614624, 0.4335789>,
    <0.2305897, -0.8615475, 0.4522878>,
    <0.1821775, -0.8420192, 0.5077549>,
    <0.1971284, -0.8603597, 0.4700230>,
    <0.2195265, -0.8804997, 0.4201529>,
    <0.2485433, -0.8816938, 0.4010514>,
    <0.2576946, -0.8764645, 0.4066982>,
    <0.2422902, -0.8743031, 0.4205824>,
    <0.2801899, -0.8750306, 0.3947342>,
    <0.2833195, -0.8721586, 0.3988351>,
    <0.3136937, -0.8605724, 0.4012621>,
    <0.3146740, -0.8655644, 0.3895876>,
    <0.2744014, -0.8718598, 0.4056654>,
    <0.3155846, -0.8703481, 0.3780220>,
    <0.2791958, 0.8852312, 0.3720423>,
    <0.2499057, 0.9001840, 0.3566734>,
    <0.2623111, 0.8902852, 0.3722702>,
    <0.2863604, 0.8794606, 0.3801930>,
    <0.3153198, 0.8653294, 0.3895876>,
    <0.3128619, 0.8608751, 0.4012623>,
    <0.3054473, 0.8382430, 0.4517196>,
    <0.2668018, 0.8802090, 0.3924907>,
    <0.2386433, 0.8898032, 0.3889725>,
    <0.2261705, 0.9055141, 0.3590141>,
    <0.2516123, 0.8907311, 0.3785358>,
    <0.2101535, 0.8983610, 0.3857240>,
    <0.2821055, 0.8789804, 0.3844604>,
    <0.3176971, 0.8695793, 0.3780218>,
    <0.2501342, 0.8722982, 0.4201532>,
    <0.2256020, 0.8878406, 0.4010520>,
    <0.2150621, 0.8878876, 0.4066987>,
    <0.2273219, 0.8783137, 0.4205827>,
    <0.2594615, 0.8436574, 0.4700234>,
    <0.2310771, 0.8614166, 0.4522883>,
    <0.1948636, 0.8978933, 0.3947350>,
    <0.1907173, 0.8969710, 0.3988356>,
    <0.2017794, 0.8782334, 0.4335795>,
    <0.1982912, 0.8922533, 0.4056656>,
    <-0.1874702, 0.8460870, -0.4989906>,
    <-0.1786758, 0.8432452, -0.5069640>,
    <-0.2035776, 0.8426949, -0.4984190>,
    <-0.2190922, 0.8482615, -0.4821317>,
    <-0.2214289, 0.8272293, -0.5163922>,
    <-0.1940117, 0.8312733, -0.5209071>,
    <-0.1817761, 0.8403589, -0.5106411>,
    <-0.2121672, 0.8369820, -0.5044266>,
    <-0.1968829, 0.8593233, -0.4720177>,
    <-0.2306163, 0.8615510, -0.4522675>,
    <-0.2407944, 0.8412176, -0.4841188>,
    <-0.2647371, 0.8624424, -0.4314016>,
    <-0.3048601, 0.8384681, -0.4516985>,
    <-0.2486725, 0.8220388, -0.5122638>,
    <-0.2194797, 0.8805225, -0.4201294>,
    <-0.2419115, 0.8730902, -0.4233111>,
    <-0.2577231, 0.8764665, -0.4066759>,
    <-0.2489195, 0.8829318, -0.3980835>,
    <-0.2740154, 0.8705427, -0.4087431>,
    <-0.2834143, 0.8721375, -0.3988140>,
    <-0.3153580, 0.8697716, -0.3795349>,
    <-0.3147083, 0.8655608, -0.3895681>,
    <-0.2807275, 0.8763587, -0.3913917>,
    <-0.3140085, 0.8611935, -0.3996805>,
    <-0.2795730, -0.8865180, -0.3686797>,
    <-0.2863964, -0.8794563, -0.3801758>,
    <-0.2622890, -0.8902983, -0.3722546>,
    <-0.2501255, -0.9013067, -0.3536714>,
    <-0.2386252, -0.8898177, -0.3889504>,
    <-0.2670993, -0.8811028, -0.3902765>,
    <-0.3054206, -0.8382640, -0.4516988>,
    <-0.3130201, -0.8615532, -0.3996806>,
    <-0.3152912, -0.8653486, -0.3895680>,
    <-0.2817473, -0.8777241, -0.3875807>,
    <-0.2512777, -0.8896304, -0.3813361>,
    <-0.3175002, -0.8689920, -0.3795346>,
    <-0.2260822, -0.9055408, -0.3590023>,
    <-0.2098855, -0.8975235, -0.3878139>,
    <-0.2501863, -0.8722950, -0.4201289>,
    <-0.2270436, -0.8770742, -0.4233108>,
    <-0.2150385, -0.8879041, -0.4066752>,
    <-0.2258953, -0.8891015, -0.3980827>,
    <-0.2310560, -0.8614336, -0.4522667>,
    <-0.2591561, -0.8426376, -0.4720170>,
    <-0.1979671, -0.8909200, -0.4087427>,
    <-0.1906247, -0.8970006, -0.3988133>,
    <-0.1950622, -0.8993130, -0.3913909>,
    <-0.2019522, -0.8792659, -0.4314009>,
    <0.1617244, -0.7301738, 0.6638460>,
    <0.1936203, -0.7500933, 0.6323537>,
    <0.1803702, -0.7469070, 0.6399973>,
    <0.1567747, -0.7401257, 0.6539386>,
    <0.1682427, -0.7124164, 0.6812909>,
    <0.1954013, -0.7270244, 0.6582202>,
    <0.2156640, -0.7543327, 0.6200574>,
    <0.1899033, -0.7494087, 0.6342897>,
    <0.2215261, -0.7324492, 0.6437736>,
    <0.2773429, -0.7630272, 0.5838411>,
    <0.2414744, -0.7872054, 0.5674485>,
    <0.2097529, -0.7838511, 0.5844494>,
    <0.1623829, -0.7501556, 0.6410135>,
    <0.1786389, -0.7795780, 0.6002885>,
    <0.2021120, -0.8103565, 0.5499755>,
    <0.2294812, -0.8142448, 0.5332390>,
    <0.2381724, -0.8102451, 0.5355155>,
    <0.2236616, -0.8068879, 0.5467242>,
    <0.2590392, -0.8095174, 0.5268588>,
    <0.2624132, -0.8082983, 0.5270609>,
    <0.2899267, -0.7957661, 0.5316943>,
    <0.2923769, -0.8044344, 0.5171083>,
    <0.2544551, -0.8086682, 0.5303851>,
    <0.2946535, -0.8126386, 0.5027901>,
    <0.2601690, 0.8247152, 0.5021524>,
    <0.2340628, 0.8426229, 0.4849756>,
    <0.2450691, 0.8315678, 0.4984337>,
    <0.2668496, 0.8196128, 0.5069774>,
    <0.2931068, 0.8041687, 0.5171084>,
    <0.2894119, 0.7959535, 0.5316942>,
    <0.2780075, 0.7627854, 0.5838410>,
    <0.2472283, 0.8157151, 0.5229598>,
    <0.2218723, 0.8271028, 0.5164046>,
    <0.2121683, 0.8488799, 0.4841359>,
    <0.2351852, 0.8323783, 0.5018310>,
    <0.1959990, 0.8373496, 0.5103236>,
    <0.2632392, 0.8202985, 0.5077553>,
    <0.2966363, 0.8119168, 0.5027903>,
    <0.2301441, 0.8028455, 0.5499752>,
    <0.2083858, 0.8198975, 0.5332386>,
    <0.1988591, 0.8207792, 0.5355153>,
    <0.2097473, 0.8106163, 0.5467241>,
    <0.2350831, 0.7644541, 0.6002882>,
    <0.2102742, 0.7837117, 0.5844490>,
    <0.1804242, 0.8305824, 0.5268585>,
    <0.1768926, 0.8312136, 0.5270607>,
    <0.1844797, 0.8024773, 0.5674482>,
    <0.1839695, 0.8275548, 0.5303850>,
    <-0.1661747, 0.7501447, -0.6400538>,
    <-0.1589041, 0.7495618, -0.6425781>,
    <-0.1816468, 0.7520693, -0.6335583>,
    <-0.1957991, 0.7586645, -0.6213621>,
    <-0.1959060, 0.7319842, -0.6525488>,
    <-0.1705575, 0.7304809, -0.6612926>,
    <-0.1623536, 0.7501584, -0.6410176>,
    <-0.1897705, 0.7487734, -0.6350792>,
    <-0.1783328, 0.7782802, -0.6020610>,
    <-0.2097806, 0.7838531, -0.5844368>,
    <-0.2161122, 0.7555572, -0.6184083>,
    <-0.2419371, 0.7884849, -0.5654715>,
    <-0.2773780, 0.7630236, -0.5838290>,
    <-0.2212755, 0.7318862, -0.6444996>,
    <-0.2020623, 0.8103772, -0.5499632>,
    <-0.2231843, 0.8053227, -0.5492214>,
    <-0.2382029, 0.8102441, -0.5355033>,
    <-0.2299770, 0.8158985, -0.5304906>,
    <-0.2539506, 0.8069637, -0.5332155>,
    <-0.2625143, 0.8082737, -0.5270483>,
    <-0.2943610, 0.8118726, -0.5041969>,
    <-0.2924155, 0.8044291, -0.5170948>,
    <-0.2597335, 0.8113101, -0.5237503>,
    <-0.2903235, 0.7965932, -0.5302373>,
    <-0.2606896, -0.8264682, -0.4989903>,
    <-0.2668849, -0.8196100, -0.5069633>,
    <-0.2450441, -0.8315843, -0.4984184>,
    <-0.2343914, -0.8441623, -0.4821313>,
    <-0.2218516, -0.8271160, -0.5163923>,
    <-0.2476176, -0.8169095, -0.5209072>,
    <-0.2779783, -0.7628051, -0.5838291>,
    <-0.2896396, -0.7968420, -0.5302374>,
    <-0.2930738, -0.8041894, -0.5170949>,
    <-0.2627568, -0.8186606, -0.5106404>,
    <-0.2347488, -0.8309317, -0.5044259>,
    <-0.2963681, -0.8111419, -0.5041971>,
    <-0.2120748, -0.8489133, -0.4841183>,
    <-0.1956627, -0.8362427, -0.5122638>,
    <-0.2301976, -0.8028380, -0.5499638>,
    <-0.2093781, -0.8090217, -0.5492218>,
    <-0.1988323, -0.8207930, -0.5355040>,
    <-0.2087833, -0.8215768, -0.5304914>,
    <-0.2102512, -0.7837265, -0.5844376>,
    <-0.2346993, -0.7631763, -0.6020616>,
    <-0.1835542, -0.8258260, -0.5332159>,
    <-0.1767928, -0.8312423, -0.5270490>,
    <-0.1807192, -0.8324814, -0.5237511>,
    <-0.1847188, -0.8038160, -0.5654722>,
    <0.0606167, -0.3072160, 0.9497073>,
    <0.0550521, -0.2798987, 0.9584498>,
    <0.0657120, -0.3046208, 0.9502042>,
    <0.0744355, -0.3336162, 0.9397657>,
    <0.0943445, -0.3952112, 0.9137326>,
    <0.0759017, -0.3606719, 0.9295992>,
    <0.0504653, -0.3235362, 0.9448691>,
    <0.0453662, -0.2724195, 0.9611085>,
    <0.0453662, -0.2724195, 0.9611085>,
    <0.0411405, -0.2470445, 0.9681304>,
    <0.0567826, -0.2697935, 0.9612425>,
    <0.0724189, -0.3108869, 0.9476839>,
    <0.0411405, -0.2470445, 0.9681304>,
    <0.0371334, -0.2229821, 0.9741150>,
    <0.0371334, -0.2229821, 0.9741150>,
    <0.0753580, -0.2855168, 0.9554064>,
    <0.0811968, -0.3062917, 0.9484685>,
    <0.0935261, -0.3423098, 0.9349208>,
    <0.0863116, -0.3509726, 0.9323994>,
    <0.1120781, -0.3863904, 0.9155004>,
    <0.1893273, -0.5443448, 0.8172172>,
    <0.1167069, -0.4359221, 0.8923852>,
    <0.0898692, -0.4094429, 0.9078987>,
    <0.1123521, -0.4551469, 0.8832996>,
    <0.1171590, -0.4827980, 0.8678594>,
    <0.1052882, -0.4646018, 0.8792380>,
    <0.0504653, -0.3235362, 0.9448691>,
    <0.1430501, -0.5236503, 0.8398375>,
    <0.1356067, -0.5335292, 0.8348398>,
    <0.1835550, -0.6210885, 0.7619427>,
    <0.1645347, -0.6187519, 0.7681630>,
    <0.1196051, -0.5185475, 0.8466422>,
    <0.1407443, -0.6022431, 0.7858080>,
    <0.1729182, -0.6859149, 0.7068380>,
    <0.1908415, -0.6832852, 0.7047701>,
    <0.2034787, -0.6968127, 0.6877852>,
    <0.1950330, -0.7010724, 0.6859005>,
    <0.2108169, -0.6752246, 0.7068436>,
    <0.2236170, -0.6969944, 0.6813181>,
    <0.2382447, -0.6634546, 0.7092725>,
    <0.2521646, -0.6981290, 0.6700962>,
    <0.2233401, -0.7113583, 0.6663997>,
    <0.2617093, -0.7226854, 0.6397140>,
    <0.2273955, 0.7207078, 0.6548828>,
    <0.2083434, 0.7495859, 0.6282627>,
    <0.2179467, 0.7393952, 0.6370196>,
    <0.2353888, 0.7230154, 0.6494928>,
    <0.2567148, 0.7016977, 0.6646186>,
    <0.2475466, 0.6754972, 0.6945676>,
    <0.2229867, 0.5881917, 0.7773722>,
    <0.2134149, 0.7061297, 0.6751555>,
    <0.1952332, 0.7288541, 0.6562436>,
    <0.1905907, 0.7618451, 0.6190857>,
    <0.2104047, 0.7445302, 0.6335650>,
    <0.1745778, 0.7454586, 0.6432838>,
    <0.2346973, 0.7316462, 0.6400086>,
    <0.2643017, 0.7228925, 0.6384129>,
    <0.1947306, 0.6801852, 0.7067022>,
    <0.1770582, 0.6907994, 0.7010325>,
    <0.1723593, 0.7065252, 0.6863778>,
    <0.1821434, 0.7043638, 0.6860724>,
    <0.1827634, 0.5935735, 0.7837526>,
    <0.1679368, 0.6233244, 0.7637172>,
    <0.1555518, 0.7020657, 0.6949154>,
    <0.1548400, 0.7193232, 0.6771992>,
    <0.1544189, 0.6586581, 0.7364267>,
    <0.1623717, 0.7284592, 0.6655694>,
    <-0.1268351, 0.5700922, -0.8117313>,
    <-0.1256731, 0.5925384, -0.7956787>,
    <-0.1460048, 0.6045938, -0.7830383>,
    <-0.1559770, 0.6037245, -0.7817851>,
    <-0.1574231, 0.5806514, -0.7987878>,
    <-0.1357010, 0.5588239, -0.8181082>,
    <-0.1333183, 0.6152422, -0.7769834>,
    <-0.1563899, 0.6171541, -0.7711439>,
    <-0.1510450, 0.6589269, -0.7368858>,
    <-0.1785585, 0.6672829, -0.7230839>,
    <-0.1780213, 0.6230217, -0.7616774>,
    <-0.2070838, 0.6752625, -0.7079103>,
    <-0.2361643, 0.6497423, -0.7225382>,
    <-0.1808719, 0.5971284, -0.7814877>,
    <-0.1757856, 0.7044625, -0.6876278>,
    <-0.1954877, 0.7050001, -0.6817326>,
    <-0.2087011, 0.7100061, -0.6725587>,
    <-0.2006876, 0.7120943, -0.6727899>,
    <-0.2242763, 0.7127871, -0.6645560>,
    <-0.2308976, 0.7114634, -0.6637063>,
    <-0.2627915, 0.7246818, -0.6370063>,
    <-0.2586252, 0.7116043, -0.6532475>,
    <-0.2271601, 0.7101699, -0.6663760>,
    <-0.2540878, 0.6975757, -0.6699459>,
    <-0.2311608, -0.7327313, -0.6400543>,
    <-0.2371659, -0.7285910, -0.6425788>,
    <-0.2187239, -0.7421340, -0.6335590>,
    <-0.2097652, -0.7549219, -0.6213626>,
    <-0.1963325, -0.7318699, -0.6525488>,
    <-0.2175333, -0.7178937, -0.6612926>,
    <-0.2367340, -0.6495350, -0.7225381>,
    <-0.2537505, -0.6976986, -0.6699458>,
    <-0.2592921, -0.7113616, -0.6532475>,
    <-0.2344768, -0.7308324, -0.6410184>,
    <-0.2100406, -0.7433414, -0.6350799>,
    <-0.2645065, -0.7240576, -0.6370063>,
    <-0.1906199, -0.7623874, -0.6184088>,
    <-0.1743129, -0.7444697, -0.6444997>,
    <-0.1999965, -0.6979756, -0.6876274>,
    <-0.1832028, -0.7082922, -0.6817323>,
    <-0.1742627, -0.7192344, -0.6725581>,
    <-0.1822467, -0.7170361, -0.6727893>,
    <-0.1790053, -0.6671638, -0.7230834>,
    <-0.1986547, -0.6461704, -0.7368854>,
    <-0.1621646, -0.7294302, -0.6645556>,
    <-0.1557685, -0.7315948, -0.6637057>,
    <-0.1583586, -0.7286059, -0.6663753>,
    <-0.1582915, -0.6883369, -0.7079097>,
    <0.1203430, -0.3849444, 0.9150603>,
    <0.1385271, -0.4135952, 0.8998607>,
    <0.1387820, -0.4075636, 0.9025694>,
    <0.1218915, -0.3850221, 0.9148226>,
    <0.0753580, -0.2855168, 0.9554064>,
    <0.1331287, -0.4062657, 0.9040050>,
    <0.1331287, -0.4062657, 0.9040050>,
    <0.1367627, -0.4173554, 0.8983932>,
    <0.1381566, -0.3931252, 0.9090464>,
    <0.1490482, -0.4121494, 0.8988423>,
    <0.1367627, -0.4173554, 0.8983932>,
    <0.1230836, -0.3756113, 0.9185677>,
    <0.1230836, -0.3756113, 0.9185677>,
    <0.1201090, -0.3304397, 0.9361535>,
    <0.1393925, -0.3656237, 0.9202658>,
    <0.1632718, -0.4151177, 0.8949970>,
    <0.1424002, -0.4149304, 0.8986406>,
    <0.1766001, -0.4547573, 0.8729308>,
    <0.1261285, 0.4000782, 0.9077605>,
    <0.1376273, 0.5059982, 0.8514837>,
    <0.1437675, 0.4920650, 0.8586052>,
    <0.1447768, 0.4478142, 0.8823277>,
    <0.1541414, 0.4147075, 0.8968044>,
    <0.1293076, 0.3256875, 0.9365934>,
    <0.1297656, 0.3400039, 0.9314281>,
    <0.1252155, 0.4727762, 0.8722407>,
    <0.1358335, 0.5391469, 0.8311858>,
    <0.1454691, 0.5827352, 0.7995364>,
    <0.1519080, 0.5407897, 0.8273273>,
    <0.1375615, 0.5730181, 0.8079152>,
    <0.1616888, 0.5105208, 0.8445266>,
    <0.1788577, 0.4937361, 0.8510198>,
    <0.1456648, 0.6229827, 0.7685533>,
    <0.1560118, 0.6632932, 0.7319169>,
    <0.1488152, 0.6158207, 0.7737047>,
    <0.1413894, 0.5811059, 0.8014518>,
    <0.1297656, 0.3400039, 0.9314281>,
    <0.1555413, 0.7260430, 0.6698272>,
    <0.1555413, 0.7260430, 0.6698272>,
    <0.1634906, 0.7247592, 0.6693242>,
    <0.1555156, 0.6301608, 0.7607314>,
    <0.1454458, 0.5876908, 0.7959052>,
    <0.1634906, 0.7247592, 0.6693242>,
    <0.1610825, 0.6634191, 0.7307034>,
    <0.1610825, 0.6634191, 0.7307034>,
    <0.1541919, 0.5842066, 0.7968234>,
    <0.1358102, 0.5524103, 0.8224345>,
    <-0.1028626, 0.3830635, -0.9179769>,
    <-0.1032720, 0.3854288, -0.9169403>,
    <-0.0986027, 0.3680048, -0.9245810>,
    <-0.0968615, 0.3582213, -0.9285986>,
    <-0.0959830, 0.3489588, -0.9322097>,
    <-0.1016407, 0.3781047, -0.9201663>,
    <-0.1049151, 0.3916236, -0.9141246>,
    <-0.1049327, 0.3916472, -0.9141124>,
    <-0.1049327, 0.3916472, -0.9141124>,
    <-0.1049435, 0.3916636, -0.9141042>,
    <-0.1026090, 0.3831592, -0.9179654>,
    <-0.0979559, 0.3642083, -0.9261517>,
    <-0.1049435, 0.3916636, -0.9141042>,
    <-0.1049502, 0.3916743, -0.9140989>,
    <-0.1049502, 0.3916743, -0.9140989>,
    <-0.1049497, 0.3916641, -0.9141033>,
    <-0.1043862, 0.3874685, -0.9159540>,
    <-0.1055246, 0.3844266, -0.9171045>,
    <-0.0934013, 0.3412209, -0.9353312>,
    <-0.1096309, 0.3801774, -0.9183933>,
    <-0.1496809, 0.4042045, -0.9023383>,
    <-0.0936016, 0.3229131, -0.9417886>,
    <-0.1066213, 0.3964489, -0.9118444>,
    <-0.1080203, 0.4103002, -0.9055304>,
    <-0.1144606, 0.4234099, -0.8986784>,
    <-0.1137334, 0.4115773, -0.9042504>,
    <-0.1049497, 0.3916641, -0.9141033>,
    <-0.1113391, 0.4352273, -0.8934096>,
    <-0.1220466, 0.4490142, -0.8851502>,
    <-0.1264290, 0.5033472, -0.8547849>,
    <-0.1405012, 0.5089959, -0.8492247>,
    <-0.1265815, 0.4398976, -0.8890822>,
    <-0.1504731, 0.4977024, -0.8541956>,
    <-0.1452227, 0.5555661, -0.8186921>,
    <-0.1581448, 0.5601135, -0.8131809>,
    <-0.1648171, 0.5573281, -0.8137695>,
    <-0.1575072, 0.5519217, -0.8188857>,
    <-0.1808094, 0.5735993, -0.7989316>,
    <-0.1785785, 0.5543701, -0.8128859>,
    <-0.2145047, 0.5921779, -0.7767323>,
    <-0.2005543, 0.5551656, -0.8071983>,
    <-0.1679317, 0.5325505, -0.8295715>,
    <-0.1841761, 0.5109022, -0.8396774>,
    <-0.1038678, -0.3877233, -0.9159051>,
    <-0.1040767, -0.3884708, -0.9155646>,
    <-0.1017829, -0.3798982, -0.9194115>,
    <-0.1020015, -0.3794204, -0.9195846>,
    <-0.1067863, -0.3925033, -0.9135304>,
    <-0.1049552, -0.3906731, -0.9145266>,
    <-0.1048981, -0.3915684, -0.9141502>,
    <-0.1048715, -0.3914674, -0.9141965>,
    <-0.1048715, -0.3914674, -0.9141965>,
    <-0.1048661, -0.3914345, -0.9142112>,
    <-0.1038977, -0.3870585, -0.9161828>,
    <-0.1009055, -0.3731869, -0.9222525>,
    <-0.1048661, -0.3914345, -0.9142112>,
    <-0.1048738, -0.3914333, -0.9142109>,
    <-0.1048738, -0.3914333, -0.9142109>,
    <-0.1048967, -0.3914571, -0.9141980>,
    <-0.1031072, -0.3828166, -0.9180525>,
    <-0.1010399, -0.3630381, -0.9262798>,
    <-0.0997223, -0.3649270, -0.9256802>,
    <-0.1025141, -0.3456982, -0.9327291>,
    <-0.1436744, -0.4047841, -0.9030545>,
    <-0.1103117, -0.3909424, -0.9137808>,
    <-0.1745861, -0.5551680, -0.8132086>,
    <-0.1871896, -0.5752085, -0.7963010>,
    <-0.1756038, -0.5957508, -0.7837374>,
    <-0.1663542, -0.5993656, -0.7829988>,
    <-0.1535430, -0.5804934, -0.7996574>,
    <-0.1609276, -0.5495755, -0.8197982>,
    <-0.1871363, -0.5092168, -0.8400466>,
    <-0.2031669, -0.5540102, -0.8073388>,
    <-0.1921028, -0.5992804, -0.7771483>,
    <-0.1730714, -0.6124257, -0.7713501>,
    <-0.2163108, -0.5914674, -0.7767728>,
    <-0.1572239, -0.6281108, -0.7620745>,
    <-0.1418020, -0.6072564, -0.7817493>,
    <-0.1056585, -0.3964486, -0.9119566>,
    <-0.1116756, -0.4110875, -0.9047296>,
    <-0.1123235, -0.4241498, -0.8985991>,
    <-0.1065920, -0.4114370, -0.9051838>,
    <-0.1048981, -0.3915684, -0.9141502>,
    <-0.1213008, -0.4351711, -0.8921391>,
    <-0.1185775, -0.4506450, -0.8847929>,
    <-0.1419327, -0.5008469, -0.8538194>,
    <-0.1325861, -0.5121659, -0.8485912>,
    <-0.1094704, -0.4420908, -0.8902651>,
    <-0.1180657, -0.5060012, -0.8544140>,
    <-0.1514667, -0.5537207, -0.8188109>,
    <-0.1427929, -0.5640979, -0.8132673>,
    <-0.1357494, -0.5655730, -0.8134490>,
    <-0.1393006, -0.5575237, -0.8183903>,
    <-0.1301356, -0.5872671, -0.7988630>,
    <-0.1225008, -0.5698233, -0.8125854>,
    <-0.1207661, -0.5459060, -0.8290972>,
    <-0.1031780, 0.3750213, -0.9212564>,
    <-0.1008084, 0.3454200, -0.9330181>,
    <-0.1100285, 0.3491324, -0.9305914>,
    <-0.1075789, 0.3620234, -0.9259405>,
    <-0.0973665, 0.3635942, -0.9264551>,
    <-0.1039149, 0.3879554, -0.9158014>,
    <-0.1039149, 0.3879554, -0.9158014>,
    <-0.1049151, 0.3916236, -0.9141246>,
    <-0.1098217, 0.3269011, -0.9386559>,
    <-0.1219263, 0.3376545, -0.9333399>,
    <-0.1380104, 0.3357431, -0.9317884>,
    <-0.1403252, 0.3365753, -0.9311422>,
    <-0.1149337, 0.3338720, -0.9355852>,
    <-0.1342664, 0.3209979, -0.9375142>,
    <-0.1270205, 0.3035304, -0.9443173>,
    <-0.0816482, 0.3050079, -0.9488434>,
    <-0.0816482, 0.3050079, -0.9488434>,
    <-0.0973665, 0.3635942, -0.9264551>,
    <-0.1053282, -0.3770395, -0.9201887>,
    <-0.1114588, -0.3595596, -0.9264415>,
    <-0.1162790, -0.3497081, -0.9296147>,
    <-0.1069102, -0.3526322, -0.9296347>,
    <-0.1048967, -0.3914571, -0.9141980>,
    <-0.1037461, -0.3870635, -0.9161979>,
    <-0.1037461, -0.3870635, -0.9161979>,
    <-0.0959537, -0.3578590, -0.9288325>,
    <-0.1216186, -0.3319313, -0.9354306>,
    <-0.1279715, -0.3344088, -0.9336991>,
    <-0.0959537, -0.3578590, -0.9288325>,
    <-0.0779606, -0.2905852, -0.9536679>,
    <-0.0779606, -0.2905852, -0.9536679>,
    <-0.1350196, -0.3115924, -0.9405742>,
    <-0.1400809, -0.3234685, -0.9358127>,
    <-0.1413327, -0.3277296, -0.9341405>,
    <-0.1166591, -0.3290596, -0.9370755>,
    <-0.1340888, -0.3162361, -0.9391565>,
    <-0.1681767, 0.3615663, -0.9170531>,
    <-0.1653813, 0.3578654, -0.9190111>,
    <-0.1606607, 0.3500041, -0.9228679>,
    <-0.1622835, 0.3520316, -0.9218122>,
    <-0.1685957, 0.3666661, -0.9149489>,
    <-0.1700374, 0.3656028, -0.9151076>,
    <-0.1713630, 0.3674678, -0.9141128>,
    <-0.1708688, 0.3663989, -0.9146342>,
    <-0.1708688, 0.3663989, -0.9146342>,
    <-0.1675147, 0.3591992, -0.9181039>,
    <-0.1562124, 0.3443797, -0.9257431>,
    <-0.1534026, 0.3425575, -0.9268884>,
    <-0.1675147, 0.3591992, -0.9181039>,
    <-0.1581445, 0.3390997, -0.9273628>,
    <-0.1581445, 0.3390997, -0.9273628>,
    <-0.1270205, 0.3035304, -0.9443173>,
    <-0.1540509, 0.3427166, -0.9267220>,
    <-0.1645990, 0.3686152, -0.9148934>,
    <0.2242204, 0.4705849, 0.8533903>,
    <0.1988143, 0.4219191, 0.8845661>,
    <0.1972638, 0.4401120, 0.8760071>,
    <0.2105081, 0.4625530, 0.8612381>,
    <0.2271539, 0.4978776, 0.8369701>,
    <0.2416175, 0.5195544, 0.8195635>,
    <0.2487909, 0.5335274, 0.8083635>,
    <0.2286676, 0.4678776, 0.8536988>,
    <0.2286676, 0.4678776, 0.8536988>,
    <0.1996142, 0.3967894, 0.8959422>,
    <0.1627608, 0.3568433, 0.9198760>,
    <0.1783174, 0.4231414, 0.8883436>,
    <0.1996142, 0.3967894, 0.8959422>,
    <0.1585784, 0.3102732, 0.9373278>,
    <0.1585784, 0.3102732, 0.9373278>,
    <0.1297656, 0.3400039, 0.9314281>,
    <0.1970109, 0.4697028, 0.8605615>,
    <0.2142843, 0.4889300, 0.8455943>,
    <-0.1666219, -0.3578734, -0.9187839>,
    <-0.1569439, -0.3395698, -0.9273947>,
    <-0.1574875, -0.3413738, -0.9266400>,
    <-0.1653094, -0.3566688, -0.9194891>,
    <-0.1683744, -0.3610952, -0.9172025>,
    <-0.1709490, -0.3666214, -0.9145300>,
    <-0.1709490, -0.3666214, -0.9145300>,
    <-0.1712894, -0.3673594, -0.9141701>,
    <-0.1684116, -0.3626080, -0.9165986>,
    <-0.1646787, -0.3596190, -0.9184526>,
    <-0.1459273, -0.3225076, -0.9352508>,
    <-0.1503966, -0.3319254, -0.9312392>,
    <-0.1585370, -0.3591483, -0.9197165>,
    <-0.1578077, -0.3447449, -0.9253365>,
    <-0.1350196, -0.3115924, -0.9405742>,
    <-0.1610295, -0.3453414, -0.9245587>,
    <-0.1610295, -0.3453414, -0.9245587>,
    <-0.1683744, -0.3610952, -0.9172025>,
    <0.1551559, -0.3691596, 0.9163230>,
    <0.1424975, -0.3150249, 0.9383250>,
    <0.1306461, -0.2971119, 0.9458626>,
    <0.1343753, -0.3234551, 0.9366537>,
    <0.1580534, -0.3857568, 0.9089614>,
    <0.1364642, -0.3071844, 0.9418149>,
    <0.1244410, -0.2668907, 0.9556588>,
    <0.1200342, -0.2659626, 0.9564809>,
    <0.1311299, -0.2740046, 0.9527468>,
    <0.1490724, -0.2581986, 0.9545213>,
    <0.1163640, -0.2495409, 0.9613474>,
    <0.1163640, -0.2495409, 0.9613474>,
    <0.1203353, -0.2580573, 0.9586062>,
    <0.1265134, -0.2911816, 0.9482656>,
    <0.1203353, -0.2580573, 0.9586062>,
    <0.1339213, -0.2871924, 0.9484649>,
    <0.1339213, -0.2871924, 0.9484649>,
    <0.1015309, -0.2789512, 0.9549229>,
    <0.3754820, -0.9064711, 0.1931927>,
    <0.4056709, -0.8729990, 0.2707469>,
    <0.3706215, -0.8490461, 0.3765109>,
    <0.3456724, -0.8770267, 0.3336686>,
    <0.3885836, -0.9040938, 0.1778121>,
    <0.4136324, -0.8735924, 0.2564069>,
    <0.3928194, -0.7841631, 0.4803968>,
    <0.3396913, -0.7552629, 0.5605245>,
    <0.4161503, -0.8023521, 0.4278436>,
    <0.3300281, -0.5691875, 0.7530651>,
    <0.3215241, -0.6133059, 0.7214417>,
    <0.2861340, -0.6144285, 0.7352584>,
    <0.3066066, -0.7766511, 0.5502777>,
    <0.2427849, -0.5917610, 0.7686836>,
    <0.1718659, -0.4127136, 0.8944996>,
    <0.2262792, -0.4684330, 0.8540306>,
    <0.1849298, -0.3696311, 0.9105898>,
    <0.1430084, -0.3190084, 0.9369003>,
    <0.2492555, -0.4471346, 0.8590357>,
    <0.1988406, -0.3498818, 0.9154481>,
    <0.2348331, -0.3866461, 0.8918285>,
    <0.1962425, -0.3215180, 0.9263450>,
    <0.1555322, -0.2942898, 0.9429757>,
    <0.1848258, -0.2992040, 0.9361177>,
    <0.1490724, -0.2581986, 0.9545213>,
    <0.1876559, 0.3650860, 0.9118648>,
    <0.1536045, 0.3196668, 0.9349967>,
    <0.1474574, 0.2988285, 0.9428456>,
    <0.1658173, 0.3193983, 0.9330002>,
    <0.1847214, 0.3385382, 0.9226429>,
    <0.2219834, 0.4046495, 0.8871201>,
    <0.3321693, 0.5778022, 0.7455255>,
    <0.1983633, 0.3779086, 0.9043434>,
    <0.1512590, 0.3097454, 0.9387111>,
    <0.1276898, 0.2737752, 0.9532798>,
    <0.1299582, 0.2699178, 0.9540730>,
    <0.1288812, 0.2838939, 0.9501546>,
    <0.1044403, 0.2869520, 0.9522346>,
    <0.1193599, 0.2559683, 0.9592880>,
    <0.1193599, 0.2559683, 0.9592880>,
    <0.1235319, 0.2649152, 0.9563262>,
    <0.1458227, 0.2922994, 0.9451438>,
    <0.1235319, 0.2649152, 0.9563262>,
    <0.1378470, 0.2956141, 0.9453098>,
    <0.1378470, 0.2956141, 0.9453098>,
    <0.1530159, 0.2650321, 0.9520211>,
    <0.1712773, 0.3180484, 0.9324748>,
    <0.2099969, 0.4059114, 0.8894589>,
    <0.2175326, 0.4836511, 0.8477979>,
    <0.1679732, 0.3877775, 0.9063187>,
    <0.1560422, 0.3225438, 0.9336039>,
    <0.3014660, 0.5747659, 0.7607644>,
    <0.2905028, 0.6221623, 0.7269953>,
    <0.1851650, 0.4893601, 0.8521975>,
    <0.1432946, 0.3865148, 0.9110834>,
    <0.2654826, 0.6500831, 0.7119768>,
    <0.1286372, 0.3163076, 0.9398947>,
    <0.1044403, 0.2869520, 0.9522346>,
    <0.3702949, -0.8939932, 0.2523050>,
    <0.4026084, -0.8837938, 0.2383590>,
    <0.3869159, -0.8861481, 0.2550247>,
    <0.3609447, -0.8949080, 0.2624094>,
    <0.3781170, -0.8848492, 0.2721569>,
    <0.4066898, -0.8725428, 0.2706888>,
    <0.4250171, -0.8720575, 0.2426443>,
    <0.3959478, -0.8797794, 0.2630849>,
    <0.4348140, -0.8592917, 0.2693595>,
    <0.4881905, -0.8459638, 0.2145116>,
    <0.4463549, -0.8732870, 0.1952872>,
    <0.4126144, -0.8852092, 0.2148350>,
    <0.3640324, -0.8917129, 0.2689396>,
    <0.3784655, -0.8955742, 0.2339033>,
    <0.3980266, -0.8939979, 0.2057734>,
    <0.4274284, -0.8861152, 0.1791780>,
    <0.4328768, -0.8722977, 0.2274080>,
    <0.4140151, -0.8678874, 0.2745232>,
    <0.4584073, -0.8704975, 0.1791559>,
    <0.4542073, -0.8542902, 0.2527526>,
    <0.4890365, -0.8496907, 0.1971524>,
    <0.4735145, -0.8323971, 0.2879220>,
    <0.4291262, -0.8251708, 0.3673471>,
    <0.4336845, -0.7711086, 0.4661645>,
    <0.4531720, 0.8705537, 0.1917585>,
    <0.4085948, 0.8727390, 0.2671645>,
    <0.4131747, 0.8316786, 0.3709412>,
    <0.4502536, 0.8300964, 0.3289554>,
    <0.4844520, 0.8271335, 0.2848798>,
    <0.4913630, 0.8485124, 0.1964410>,
    <0.4885309, 0.8457675, 0.2145109>,
    <0.4428880, 0.8788662, 0.1773259>,
    <0.4037346, 0.8789089, 0.2540031>,
    <0.3493738, 0.8086380, 0.4733314>,
    <0.3625094, 0.7504404, 0.5526537>,
    <0.3467215, 0.8352917, 0.4266990>,
    <0.4001461, 0.7388587, 0.5421908>,
    <0.4524930, 0.7641642, 0.4596772>,
    <0.4290413, 0.8796498, 0.2052798>,
    <0.4040829, 0.8970682, 0.1788453>,
    <0.3900905, 0.8925783, 0.2261268>,
    <0.3989608, 0.8755433, 0.2724963>,
    <0.4427768, 0.8655854, 0.2339030>,
    <0.4128863, 0.8850825, 0.2148346>,
    <0.3722127, 0.9107826, 0.1786975>,
    <0.3626520, 0.8975462, 0.2507874>,
    <0.3820653, 0.9032659, 0.1952866>,
    <0.3563975, 0.8594212, 0.3665734>,
    <-0.1254126, 0.2983872, -0.9461695>,
    <-0.1042073, 0.2511537, -0.9623215>,
    <-0.0997324, 0.2268062, -0.9688201>,
    <-0.1108862, 0.2448421, -0.9632012>,
    <-0.1052195, 0.2383702, -0.9654577>,
    <-0.1290680, 0.3169805, -0.9396089>,
    <-0.0945311, 0.2177520, -0.9714154>,
    <-0.0890586, 0.1973274, -0.9762840>,
    <-0.0747538, 0.2053815, -0.9758229>,
    <-0.0989399, 0.2121742, -0.9722104>,
    <-0.0989399, 0.2121742, -0.9722104>,
    <-0.0884222, 0.1896192, -0.9778681>,
    <-0.0928950, 0.1990596, -0.9755746>,
    <-0.0884222, 0.1896192, -0.9778681>,
    <-0.0853780, 0.1830909, -0.9793816>,
    <-0.0853780, 0.1830909, -0.9793816>,
    <-0.1097754, 0.1901340, -0.9756016>,
    <-0.0975719, 0.2045615, -0.9739786>,
    <-0.3753045, 0.9060077, -0.1956950>,
    <-0.3428140, 0.8701104, -0.3540996>,
    <-0.3662655, 0.8390407, -0.4023185>,
    <-0.4041601, 0.8694709, -0.2840336>,
    <-0.4124047, 0.8709033, -0.2673010>,
    <-0.3885712, 0.9041510, -0.1775481>,
    <-0.2956853, 0.7498680, -0.5918347>,
    <-0.3272246, 0.7275253, -0.6030183>,
    <-0.2201211, 0.5375782, -0.8139757>,
    <-0.2627323, 0.5641652, -0.7827448>,
    <-0.3835382, 0.7649867, -0.5173913>,
    <-0.2966294, 0.5650007, -0.7699255>,
    <-0.3011748, 0.5194124, -0.7996903>,
    <-0.4092241, 0.7885270, -0.4590869>,
    <-0.1427401, 0.3456196, -0.9274548>,
    <-0.1110779, 0.2506243, -0.9616908>,
    <-0.1507487, 0.3013054, -0.9415359>,
    <-0.1950129, 0.4036991, -0.8938663>,
    <-0.1182201, 0.2236865, -0.9674649>,
    <-0.1611594, 0.2813980, -0.9459613>,
    <-0.1097754, 0.1901340, -0.9756016>,
    <-0.1401320, 0.2263039, -0.9639240>,
    <-0.1553045, 0.2533079, -0.9548380>,
    <-0.2146643, 0.3830224, -0.8984504>,
    <-0.1965705, 0.3222795, -0.9260108>,
    <-0.1519200, -0.2955663, -0.9431654>,
    <-0.1290207, -0.2482580, -0.9600633>,
    <-0.1126975, -0.2283892, -0.9670252>,
    <-0.1194481, -0.2488681, -0.9611435>,
    <-0.1179531, -0.2401389, -0.9635457>,
    <-0.1637783, -0.3104179, -0.9363853>,
    <-0.3036398, -0.5281895, -0.7929809>,
    <-0.1848948, -0.3385175, -0.9226157>,
    <-0.1453846, -0.2676842, -0.9524749>,
    <-0.1092417, -0.2188130, -0.9696325>,
    <-0.0965140, -0.2004578, -0.9749368>,
    <-0.1295724, -0.2412132, -0.9617833>,
    <-0.1127965, -0.1953708, -0.9742213>,
    <-0.1019767, -0.2186915, -0.9704508>,
    <-0.1019767, -0.2186915, -0.9704508>,
    <-0.0908549, -0.1948406, -0.9766179>,
    <-0.0952747, -0.2044493, -0.9742295>,
    <-0.0908549, -0.1948406, -0.9766179>,
    <-0.0876478, -0.1879629, -0.9782575>,
    <-0.0876478, -0.1879629, -0.9782575>,
    <-0.0769817, -0.2115092, -0.9743396>,
    <-0.0965310, -0.2119259, -0.9725066>,
    <-0.1769154, -0.3395903, -0.9237854>,
    <-0.1235733, -0.2527629, -0.9596044>,
    <-0.1371264, -0.3165718, -0.9386046>,
    <-0.1878174, -0.4175923, -0.8890114>,
    <-0.2672210, -0.5723124, -0.7752751>,
    <-0.2746493, -0.5227785, -0.8070133>,
    <-0.0978969, -0.2407144, -0.9656463>,
    <-0.1146329, -0.3122378, -0.9430625>,
    <-0.0769817, -0.2115092, -0.9743396>,
    <-0.1582327, -0.4208471, -0.8932246>,
    <-0.2448515, -0.6003415, -0.7613395>,
    <0.3551392, -0.8575902, 0.3720421>,
    <0.3871882, -0.8502174, 0.3566731>,
    <0.3713223, -0.8506084, 0.3722701>,
    <0.3459415, -0.8577749, 0.3801929>,
    <0.3614054, -0.8457763, 0.3924902>,
    <0.3891431, -0.8350260, 0.3889720>,
    <0.4087965, -0.8390437, 0.3590140>,
    <0.3798046, -0.8440729, 0.3785359>,
    <0.4164685, -0.8232687, 0.3857236>,
    <0.4719302, -0.8179578, 0.3289786>,
    <0.4326033, -0.8465924, 0.3100575>,
    <0.3988353, -0.8558024, 0.3294430>,
    <0.3488922, -0.8546720, 0.3844606>,
    <0.3648788, -0.8635339, 0.3480987>,
    <0.3880177, -0.8715750, 0.2996653>,
    <0.4170946, -0.8648584, 0.2793780>,
    <0.4257363, -0.8580816, 0.2871315>,
    <0.4101570, -0.8603432, 0.3026233>,
    <0.4481095, -0.8511985, 0.2732380>,
    <0.4507951, -0.8476441, 0.2797914>,
    <0.4804127, -0.8309013, 0.2807251>,
    <0.4810362, -0.8337137, 0.2711560>,
    <0.4416849, -0.8493799, 0.2889087>,
    <0.4816132, -0.8364285, 0.2616028>,
    <0.4468176, 0.8583101, 0.2523050>,
    <0.4182337, 0.8765076, 0.2383590>,
    <0.4301242, 0.8659998, 0.2550246>,
    <0.4535285, 0.8517354, 0.2624093>,
    <0.4814992, 0.8334464, 0.2711560>,
    <0.4793753, 0.8315002, 0.2807255>,
    <0.4724071, 0.8176822, 0.3289792>,
    <0.4347850, 0.8584245, 0.2721569>,
    <0.4069914, 0.8724022, 0.2706887>,
    <0.3948391, 0.8861297, 0.2426441>,
    <0.4194399, 0.8688249, 0.2630847>,
    <0.3787627, 0.8854289, 0.2693593>,
    <0.4490963, 0.8520470, 0.2689394>,
    <0.4835618, 0.8353037, 0.2616024>,
    <0.4182522, 0.8574764, 0.2996652>,
    <0.3944167, 0.8754333, 0.2793778>,
    <0.3836706, 0.8776972, 0.2871314>,
    <0.3954173, 0.8672165, 0.3026232>,
    <0.4269658, 0.8345823, 0.3480986>,
    <0.3992163, 0.8556248, 0.3294428>,
    <0.3640166, 0.8904117, 0.2732380>,
    <0.3595676, 0.8901843, 0.2797913>,
    <0.3704554, 0.8755725, 0.3100574>,
    <0.3667532, 0.8843212, 0.2889085>,
    <-0.3706508, 0.8947962, -0.2489131>,
    <-0.3609073, 0.8949198, -0.2624205>,
    <-0.3869323, 0.8861381, -0.2550346>,
    <-0.4029867, 0.8844309, -0.2353374>,
    <-0.4067028, 0.8725324, -0.2707030>,
    <-0.3783384, 0.8854393, -0.2699208>,
    <-0.3636430, 0.8908828, -0.2721978>,
    <-0.3956350, 0.8790423, -0.2660028>,
    <-0.3782445, 0.8950906, -0.2361017>,
    <-0.4126281, 0.8852031, -0.2148338>,
    <-0.4250919, 0.8720191, -0.2426511>,
    <-0.4466021, 0.8736640, -0.1930225>,
    <-0.4882076, 0.8459542, -0.2145105>,
    <-0.4345918, 0.8587137, -0.2715524>,
    <-0.3977967, 0.8936171, -0.2078613>,
    <-0.4124423, 0.8646965, -0.2866902>,
    <-0.4322745, 0.8710518, -0.2332541>,
    <-0.4275670, 0.8863688, -0.1775862>,
    <-0.4245903, 0.8164209, -0.3913821>,
    <-0.4530845, 0.8520193, -0.2622546>,
    <-0.4239983, 0.7543392, -0.5011964>,
    <-0.4712901, 0.8285404, -0.3023349>,
    <-0.4585934, 0.8706664, -0.1778539>,
    <-0.4889285, 0.8493775, -0.1987630>,
    <-0.4529461, -0.8701490, -0.1941146>,
    <-0.4469220, -0.8236961, -0.3489777>,
    <-0.4084748, -0.8222421, -0.3963159>,
    <-0.4069274, -0.8694543, -0.2801059>,
    <-0.4025013, -0.8763246, -0.2646656>,
    <-0.4429433, -0.8789015, -0.1770126>,
    <-0.4885140, -0.8457773, -0.2145109>,
    <-0.4911540, -0.8482755, -0.1979810>,
    <-0.4822953, -0.8233982, -0.2990094>,
    <-0.3869954, -0.7139019, -0.5835912>,
    <-0.3495776, -0.7236888, -0.5950378>,
    <-0.4430862, -0.7478454, -0.4943702>,
    <-0.3409346, -0.7897263, -0.5099961>,
    <-0.3407401, -0.8212884, -0.4575823>,
    <-0.4289024, -0.8792392, -0.2073192>,
    <-0.3975622, -0.8723639, -0.2844743>,
    <-0.3895385, -0.8913510, -0.2318472>,
    <-0.4041903, -0.8973422, -0.1772208>,
    <-0.4128727, -0.8850888, -0.2148347>,
    <-0.4425483, -0.8651050, -0.2361025>,
    <-0.3526664, -0.8504575, -0.3903185>,
    <-0.3616610, -0.8952929, -0.2600999>,
    <-0.3722252, -0.9110408, -0.1773501>,
    <-0.3821952, -0.9036974, -0.1930232>,
    <-0.3556775, 0.8588183, -0.3686795>,
    <-0.3459112, 0.8577947, -0.3801758>,
    <-0.3713477, 0.8506041, -0.3722546>,
    <-0.3877416, 0.8512186, -0.3536713>,
    <-0.3891664, 0.8350254, -0.3889501>,
    <-0.3617522, 0.8466522, -0.3902761>,
    <-0.3483592, 0.8534793, -0.3875809>,
    <-0.3793535, 0.8430145, -0.3813363>,
    <-0.3645587, 0.8628035, -0.3502385>,
    <-0.3988539, 0.8557932, -0.3294444>,
    <-0.4088813, 0.8390074, -0.3590023>,
    <-0.4329844, 0.8472141, -0.3078193>,
    <-0.4719535, 0.8179437, -0.3289801>,
    <-0.4161354, 0.8224548, -0.3878137>,
    <-0.3879686, 0.8715931, -0.2996761>,
    <-0.4097198, 0.8595279, -0.3055184>,
    <-0.4257539, 0.8580686, -0.2871443>,
    <-0.4174928, 0.8656351, -0.2763613>,
    <-0.4412492, 0.8484958, -0.2921542>,
    <-0.4508710, 0.8475995, -0.2798043>,
    <-0.4813793, 0.8360656, -0.2631887>,
    <-0.4810578, 0.8336972, -0.2711687>,
    <-0.4486417, 0.8520000, -0.2698455>,
    <-0.4807101, 0.8312666, -0.2791301>,
    <-0.4472039, -0.8590988, -0.2489135>,
    <-0.4535616, -0.8517141, -0.2624213>,
    <-0.4301058, -0.8660057, -0.2550354>,
    <-0.4184785, -0.8772068, -0.2353378>,
    <-0.4069750, -0.8724055, -0.2707028>,
    <-0.4350946, -0.8589736, -0.2699205>,
    <-0.4723833, -0.8176958, -0.3289795>,
    <-0.4795429, -0.8319406, -0.2791297>,
    <-0.4814740, -0.8334569, -0.2711686>,
    <-0.4487106, -0.8512148, -0.2721988>,
    <-0.4190762, -0.8681113, -0.2660037>,
    <-0.4833643, -0.8349195, -0.2631890>,
    <-0.3947616, -0.8861622, -0.2426517>,
    <-0.3784626, -0.8848872, -0.2715524>,
    <-0.4182976, -0.8574508, -0.2996752>,
    <-0.3950737, -0.8663577, -0.3055178>,
    <-0.3836493, -0.8777026, -0.2871434>,
    <-0.3947558, -0.8762380, -0.2763601>,
    <-0.3991973, -0.8556335, -0.3294432>,
    <-0.4266121, -0.8338680, -0.3502374>,
    <-0.3663559, -0.8834193, -0.2921536>,
    <-0.3594845, -0.8902140, -0.2798033>,
    <-0.3642886, -0.8913349, -0.2698443>,
    <-0.3706867, -0.8762644, -0.3078182>,
    <0.3308157, -0.7990019, 0.5021524>,
    <0.3623251, -0.7959392, 0.4849756>,
    <0.3467877, -0.7945453, 0.4984335>,
    <0.3224183, -0.7993875, 0.5069773>,
    <0.3349437, -0.7837893, 0.5229599>,
    <0.3616873, -0.7762142, 0.5164047>,
    <0.3831192, -0.7866589, 0.4841357>,
    <0.3548803, -0.7888130, 0.5018307>,
    <0.3880940, -0.7674327, 0.5103236>,
    <0.4457936, -0.7727984, 0.4517196>,
    <0.4099457, -0.8024673, 0.4335790>,
    <0.3766928, -0.8084172, 0.4522878>,
    <0.3256249, -0.7975922, 0.5077550>,
    <0.3435336, -0.8130579, 0.4700229>,
    <0.3690887, -0.8290027, 0.4201526>,
    <0.3978720, -0.8251398, 0.4010513>,
    <0.4059762, -0.8184009, 0.4066979>,
    <0.3904306, -0.8189473, 0.4205820>,
    <0.4278807, -0.8130824, 0.3947342>,
    <0.4304641, -0.8097107, 0.3988348>,
    <0.4583649, -0.7930260, 0.4012622>,
    <0.4601972, -0.7977720, 0.3895874>,
    <0.4216297, -0.8109651, 0.4056649>,
    <0.4619247, -0.8023249, 0.3780215>,
    <0.4286731, 0.8233007, 0.3720420>,
    <0.4024245, 0.8431126, 0.3566731>,
    <0.4129225, 0.8312100, 0.3722700>,
    <0.4347268, 0.8163737, 0.3801928>,
    <0.4607923, 0.7974284, 0.3895875>,
    <0.4575983, 0.7934687, 0.4012620>,
    <0.4463664, 0.7724680, 0.4517192>,
    <0.4155953, 0.8205071, 0.3924902>,
    <0.3895307, 0.8348453, 0.3889720>,
    <0.3799755, 0.8524832, 0.3590139>,
    <0.4024637, 0.8335068, 0.3785358>,
    <0.3629596, 0.8482202, 0.3857237>,
    <0.4304532, 0.8166396, 0.3844605>,
    <0.4638715, 0.8012008, 0.3780219>,
    <0.3978073, 0.8156109, 0.4201526>,
    <0.3763466, 0.8351772, 0.4010514>,
    <0.3659750, 0.8370538, 0.4066980>,
    <0.3763861, 0.8254963, 0.4205821>,
    <0.4020194, 0.7857855, 0.4700229>,
    <0.3771501, 0.8082039, 0.4522878>,
    <0.3478208, 0.8504149, 0.3947343>,
    <0.3435774, 0.8502266, 0.3988349>,
    <0.3512177, 0.8298526, 0.4335791>,
    <0.3502170, 0.8442653, 0.4056651>,
    <-0.3315437, 0.8006794, -0.4989903>,
    <-0.3223896, 0.7994080, -0.5069633>,
    <-0.3468175, 0.7945419, -0.4984183>,
    <-0.3630629, 0.7973297, -0.4821313>,
    <-0.3617117, 0.7762110, -0.5163923>,
    <-0.3354133, 0.7849545, -0.5209073>,
    <-0.3249417, 0.7960273, -0.5106402>,
    <-0.3542847, 0.7874243, -0.5044257>,
    <-0.3431121, 0.8120803, -0.4720166>,
    <-0.3767198, 0.8084165, -0.4522664>,
    <-0.3832123, 0.7866244, -0.4841182>,
    <-0.4104770, 0.8033693, -0.4314005>,
    <-0.4458272, 0.7727917, -0.4516981>,
    <-0.3876402, 0.7663687, -0.5122638>,
    <-0.3690467, 0.8290336, -0.4201284>,
    <-0.3898471, 0.8178188, -0.4233103>,
    <-0.4060049, 0.8183983, -0.4066747>,
    <-0.3984577, 0.8262941, -0.3980822>,
    <-0.4210209, 0.8097353, -0.4087423>,
    <-0.4305540, 0.8096738, -0.3988127>,
    <-0.4616015, 0.8017968, -0.3795340>,
    <-0.4602306, 0.7977628, -0.3895668>,
    <-0.4286410, 0.8142975, -0.3913904>,
    <-0.4587830, 0.7935834, -0.3996792>,
    <-0.4292680, -0.8245028, -0.3686788>,
    <-0.4347615, -0.8163637, -0.3801747>,
    <-0.4129030, -0.8312271, -0.3722536>,
    <-0.4028358, -0.8441803, -0.3536706>,
    <-0.3895152, -0.8348627, -0.3889500>,
    <-0.4160434, -0.8213357, -0.3902762>,
    <-0.4463435, -0.7724931, -0.4516988>,
    <-0.4578718, -0.7941093, -0.3996797>,
    <-0.4607676, -0.7974528, -0.3895668>,
    <-0.4298822, -0.8154651, -0.3875797>,
    <-0.4019429, -0.8324814, -0.3813352>,
    <-0.4635757, -0.8006571, -0.3795336>,
    <-0.3798931, -0.8525252, -0.3590015>,
    <-0.3625502, -0.8474420, -0.3878136>,
    <-0.3978579, -0.8155983, -0.4201292>,
    <-0.3758967, -0.8243237, -0.4233109>,
    <-0.3659545, -0.8370736, -0.4066757>,
    <-0.3768543, -0.8363674, -0.3980835>,
    <-0.3771321, -0.8082236, -0.4522676>,
    <-0.4015413, -0.7848337, -0.4720176>,
    <-0.3496662, -0.8430082, -0.4087429>,
    <-0.3434913, -0.8502713, -0.3988138>,
    <-0.3482629, -0.8517778, -0.3913917>,
    <-0.3515670, -0.8308389, -0.4314017>,
    <0.2856822, -0.6901710, 0.6648682>,
    <0.3207476, -0.7046972, 0.6328687>,
    <0.3072454, -0.7040472, 0.6402482>,
    <0.2827887, -0.7013622, 0.6543100>,
    <0.2884766, -0.6704851, 0.6835430>,
    <0.3183668, -0.6813807, 0.6590621>,
    <0.3433376, -0.7053470, 0.6201652>,
    <0.3171310, -0.7050011, 0.6343512>,
    <0.3453031, -0.6827428, 0.6439162>,
    <0.4056277, -0.7032751, 0.5838410>,
    <0.3745027, -0.7333145, 0.5674483>,
    <0.3426808, -0.7355196, 0.5844492>,
    <0.2901520, -0.7104966, 0.6410978>,
    <0.3112974, -0.7367142, 0.6002883>,
    <0.3397585, -0.7629490, 0.5499754>,
    <0.3673871, -0.7620256, 0.5332388>,
    <0.3752516, -0.7565774, 0.5355155>,
    <0.3603783, -0.7557910, 0.5467243>,
    <0.3956751, -0.7522374, 0.5268587>,
    <0.3987861, -0.7504508, 0.5270609>,
    <0.4237054, -0.7333315, 0.5316942>,
    <0.4276236, -0.7414425, 0.5171084>,
    <0.3910131, -0.7521970, 0.5303852>,
    <0.4312902, -0.7491266, 0.5027903>,
    <0.3994268, 0.7670079, 0.5021525>,
    <0.3768268, 0.7891769, 0.4849757>,
    <0.3857462, 0.7763787, 0.4984336>,
    <0.4051199, 0.7608231, 0.5069774>,
    <0.4282963, 0.7410541, 0.5171084>,
    <0.4232309, 0.7336052, 0.5316944>,
    <0.4062401, 0.7029212, 0.5838413>,
    <0.3851198, 0.7603917, 0.5229601>,
    <0.3621265, 0.7760094, 0.5164048>,
    <0.3563515, 0.7991409, 0.4841358>,
    <0.3761532, 0.7788932, 0.5018307>,
    <0.3384256, 0.7905934, 0.5103236>,
    <0.4016834, 0.7621255, 0.5077550>,
    <0.4331177, 0.7480717, 0.5027900>,
    <0.3660603, 0.7506842, 0.5499755>,
    <0.3475936, 0.7712554, 0.5332390>,
    <0.3383648, 0.7737780, 0.5355156>,
    <0.3473228, 0.7618788, 0.5467244>,
    <0.3642577, 0.7120183, 0.6002885>,
    <0.3431697, 0.7352914, 0.5844494>,
    <0.3219123, 0.7866335, 0.5268588>,
    <0.3185439, 0.7878683, 0.5270610>,
    <0.3210258, 0.7582511, 0.5674484>,
    <0.3248780, 0.7830363, 0.5303852>,
    <-0.2939111, 0.7098919, -0.6400545>,
    <-0.2866497, 0.7105803, -0.6425789>,
    <-0.3094823, 0.7091005, -0.6335591>,
    <-0.3245649, 0.7131381, -0.6213628>,
    <-0.3200374, 0.6868448, -0.6525491>,
    <-0.2948129, 0.6897660, -0.6612928>,
    <-0.2901504, 0.7105688, -0.6410185>,
    <-0.3169102, 0.7044439, -0.6350801>,
    <-0.3107701, 0.7354886, -0.6020618>,
    <-0.3427078, 0.7355160, -0.5844378>,
    <-0.3440298, 0.7065506, -0.6184090>,
    <-0.3751801, 0.7344936, -0.5654725>,
    <-0.4056615, 0.7032651, -0.5838295>,
    <-0.3450044, 0.6823429, -0.6444999>,
    <-0.3397128, 0.7629777, -0.5499639>,
    <-0.3596362, 0.7543322, -0.5492220>,
    <-0.3752811, 0.7565708, -0.5355042>,
    <-0.3681620, 0.7635675, -0.5304916>,
    <-0.3902200, 0.7506058, -0.5332160>,
    <-0.3988810, 0.7504086, -0.5270492>,
    <-0.4308690, 0.7484229, -0.5041974>,
    <-0.4276603, 0.7414302, -0.5170957>,
    <-0.3966697, 0.7538817, -0.5237514>,
    <-0.4242394, 0.7340765, -0.5302383>,
    <-0.4002437, -0.7686436, -0.4989909>,
    <-0.4051539, -0.7608138, -0.5069642>,
    <-0.3857243, -0.7763988, -0.4984192>,
    <-0.3774176, -0.7906356, -0.4821319>,
    <-0.3621083, -0.7760260, -0.5163924>,
    <-0.3857105, -0.7615004, -0.5209073>,
    <-0.4062148, -0.7029460, -0.5838292>,
    <-0.4236093, -0.7344404, -0.5302381>,
    <-0.4282672, -0.7410797, -0.5170958>,
    <-0.4009237, -0.7605957, -0.5106412>,
    <-0.3754721, -0.7775438, -0.5044267>,
    <-0.4327187, -0.7473547, -0.5041979>,
    <-0.3562651, -0.7991896, -0.4841190>,
    <-0.3379022, -0.7895617, -0.5122640>,
    <-0.3661117, -0.7506680, -0.5499635>,
    <-0.3466823, -0.7603729, -0.5492216>,
    <-0.3383409, -0.7737968, -0.5355035>,
    <-0.3482768, -0.7728407, -0.5304908>,
    <-0.3431498, -0.7353106, -0.5844370>,
    <-0.3636579, -0.7108271, -0.6020612>,
    <-0.3241689, -0.7814062, -0.5332156>,
    <-0.3184507, -0.7879144, -0.5270484>,
    <-0.3225327, -0.7884530, -0.5237505>,
    <-0.3214937, -0.7595285, -0.5654717>,
    <0.1640344, -0.3894562, 0.9063203>,
    <0.1994834, -0.4407670, 0.8751747>,
    <0.2016606, -0.4555433, 0.8670717>,
    <0.1828086, -0.4332210, 0.8825535>,
    <0.1201090, -0.3304397, 0.9361535>,
    <0.1609990, -0.3736501, 0.9134905>,
    <0.1849985, -0.4077365, 0.8941625>,
    <0.2402183, -0.5018688, 0.8309169>,
    <0.2265971, -0.4996313, 0.8360756>,
    <0.2112030, -0.4413693, 0.8721161>,
    <0.2896133, -0.5173896, 0.8052529>,
    <0.2924754, -0.5839141, 0.7572994>,
    <0.2687000, -0.5774721, 0.7709256>,
    <0.2042543, -0.4814886, 0.8523197>,
    <0.2401243, -0.5619735, 0.7915340>,
    <0.1552664, -0.3585005, 0.9205269>,
    <0.1502300, -0.3457141, 0.9262358>,
    <0.1581657, -0.3568596, 0.9206709>,
    <0.1658789, -0.3716259, 0.9134432>,
    <0.1201090, -0.3304397, 0.9361535>,
    <0.1439194, -0.3419165, 0.9286444>,
    <0.1439194, -0.3419165, 0.9286444>,
    <0.1370312, -0.3255519, 0.9355418>,
    <0.1496138, -0.3388943, 0.9288522>,
    <0.1628323, -0.3592848, 0.9189124>,
    <0.1370312, -0.3255519, 0.9355418>,
    <0.1293344, -0.3072661, 0.9427938>,
    <0.1293344, -0.3072661, 0.9427938>,
    <0.1626697, -0.3488314, 0.9229600>,
    <0.1676886, -0.3586199, 0.9182986>,
    <0.1779303, -0.3734329, 0.9104333>,
    <0.1748932, -0.3791795, 0.9086447>,
    <0.1965706, -0.3971306, 0.8964638>,
    <0.2880164, -0.6424521, 0.7101421>,
    <0.3060856, -0.6378453, 0.7067284>,
    <0.3210886, -0.6498014, 0.6889560>,
    <0.3133636, -0.6554917, 0.6871200>,
    <0.3262700, -0.6293449, 0.7053176>,
    <0.3416106, -0.6476185, 0.6810965>,
    <0.3522121, -0.6150328, 0.7054653>,
    <0.3703082, -0.6446391, 0.6688140>,
    <0.3435017, -0.6616648, 0.6664881>,
    <0.3833851, -0.6664623, 0.6394090>,
    <0.3485472, 0.6693370, 0.6561272>,
    <0.3351490, 0.7016360, 0.6287942>,
    <0.3428943, 0.6900424, 0.6373891>,
    <0.3570954, 0.6706849, 0.6501267>,
    <0.3741203, 0.6455243, 0.6658321>,
    <0.3598206, 0.6203606, 0.6969088>,
    <0.3205486, 0.5404674, 0.7779098>,
    <0.3322667, 0.6577038, 0.6760359>,
    <0.3186579, 0.6836479, 0.6565689>,
    <0.3199471, 0.7170852, 0.6192113>,
    <0.3364624, 0.6966161, 0.6336553>,
    <0.3013359, 0.7037668, 0.6433576>,
    <0.3581251, 0.6796745, 0.6401477>,
    <0.3857068, 0.6657999, 0.6387024>,
    <0.3096910, 0.6360492, 0.7067764>,
    <0.2941866, 0.6493260, 0.7013059>,
    <0.2923208, 0.6656669, 0.6866121>,
    <0.3015785, 0.6619760, 0.6861765>,
    <0.2831556, 0.5536205, 0.7831521>,
    <0.2736468, 0.5848204, 0.7636115>,
    <0.2749146, 0.6636290, 0.6957144>,
    <0.2773129, 0.6811807, 0.6775621>,
    <0.2663046, 0.6209958, 0.7371879>,
    <0.2863652, 0.6891287, 0.6656550>,
    <-0.2239033, 0.5394056, -0.8117320>,
    <-0.2266570, 0.5617133, -0.7956789>,
    <-0.2487734, 0.5700552, -0.7830382>,
    <-0.2584430, 0.5674673, -0.7817852>,
    <-0.2558606, 0.5444936, -0.7987879>,
    <-0.2306779, 0.5267689, -0.8181089>,
    <-0.2381288, 0.5827450, -0.7769833>,
    <-0.2611819, 0.5806216, -0.7711437>,
    <-0.2631719, 0.6226879, -0.7368856>,
    <-0.2917185, 0.6261394, -0.7230835>,
    <-0.2835035, 0.5826437, -0.7616771>,
    <-0.3211961, 0.6290443, -0.7079098>,
    <-0.3454031, 0.5988619, -0.7225380>,
    <-0.2818145, 0.5566488, -0.7814875>,
    <-0.2954438, 0.6632355, -0.6876276>,
    <-0.3149398, 0.6603436, -0.6817326>,
    <-0.3288219, 0.6629792, -0.6725584>,
    <-0.3212928, 0.6664272, -0.6727895>,
    <-0.3446433, 0.6630132, -0.6645559>,
    <-0.3509343, 0.6605600, -0.6637060>,
    <-0.3846389, 0.6680390, -0.6370061>,
    <-0.3782651, 0.6558839, -0.6532471>,
    <-0.3470290, 0.6599353, -0.6663755>,
    <-0.3713606, 0.6428564, -0.6699455>,
    <-0.3548865, -0.6814590, -0.6400541>,
    <-0.3600813, -0.6763390, -0.6425784>,
    <-0.3442712, -0.6928786, -0.6335586>,
    <-0.3376692, -0.7070277, -0.6213624>,
    <-0.3204376, -0.6866583, -0.6525490>,
    <-0.3388894, -0.6692129, -0.6612927>,
    <-0.3459281, -0.5985588, -0.7225380>,
    <-0.3710496, -0.6430360, -0.6699454>,
    <-0.3788796, -0.6555293, -0.6532470>,
    <-0.3578224, -0.6790134, -0.6410179>,
    <-0.3359295, -0.6955756, -0.6350795>,
    <-0.3862194, -0.6671268, -0.6370059>,
    <-0.3201112, -0.7177045, -0.6184085>,
    <-0.3009405, -0.7028904, -0.6444998>,
    <-0.3181602, -0.6526424, -0.6876278>,
    <-0.3034131, -0.6657184, -0.6817327>,
    <-0.2965088, -0.6780467, -0.6725587>,
    <-0.3039898, -0.6744953, -0.6727899>,
    <-0.2921374, -0.6259437, -0.7230838>,
    <-0.3078429, -0.6018573, -0.7368857>,
    <-0.2863651, -0.6901886, -0.6645561>,
    <-0.2804420, -0.6934307, -0.6637063>,
    <-0.2824737, -0.6900374, -0.6663760>,
    <-0.2754150, -0.6503920, -0.7079102>,
    <0.1961123, -0.3970189, 0.8966136>,
    <0.2044708, -0.3978253, 0.8943862>,
    <0.2090938, -0.3965886, 0.8938665>,
    <0.1980750, -0.3908662, 0.8988826>,
    <0.1626697, -0.3488314, 0.9229600>,
    <0.2029968, -0.4085996, 0.8898532>,
    <0.2029968, -0.4085996, 0.8898532>,
    <0.1960954, -0.3947082, 0.8976369>,
    <0.1919719, -0.3604643, 0.9128046>,
    <0.2157515, -0.3898044, 0.8952674>,
    <0.1960954, -0.3947082, 0.8976369>,
    <0.1687651, -0.3396968, 0.9252699>,
    <0.1687651, -0.3396968, 0.9252699>,
    <0.1430662, -0.2711131, 0.9518559>,
    <0.1851063, -0.3237589, 0.9278555>,
    <0.2263870, -0.3801522, 0.8967905>,
    <0.2198304, -0.4064665, 0.8868256>,
    <0.2564441, -0.4291861, 0.8660461>,
    <0.1937416, 0.3722297, 0.9076945>,
    <0.2234170, 0.4742708, 0.8515586>,
    <0.2271763, 0.4599688, 0.8583820>,
    <0.2205488, 0.4164862, 0.8819850>,
    <0.2242025, 0.3826466, 0.8962783>,
    <0.1839950, 0.2984988, 0.9365065>,
    <0.1868467, 0.3123314, 0.9314169>,
    <0.2054462, 0.4438584, 0.8722279>,
    <0.2273458, 0.5068635, 0.8315066>,
    <0.2444356, 0.5481990, 0.7998306>,
    <0.2436857, 0.5066318, 0.8270075>,
    <0.2345862, 0.5384978, 0.8093141>,
    <0.2482092, 0.4757655, 0.8438243>,
    <0.2625048, 0.4572726, 0.8497017>,
    <0.2513656, 0.5870848, 0.7695107>,
    <0.2671856, 0.6202832, 0.7374691>,
    <0.2524089, 0.5761728, 0.7773768>,
    <0.2398892, 0.5461618, 0.8025961>,
    <0.1868467, 0.3123314, 0.9314169>,
    <0.2787597, 0.6862237, 0.6718557>,
    <0.2787597, 0.6862237, 0.6718557>,
    <0.2849880, 0.6788174, 0.6767487>,
    <0.2594258, 0.5826138, 0.7702334>,
    <0.2432671, 0.5456727, 0.8019117>,
    <0.2849880, 0.6788174, 0.6767487>,
    <0.2704391, 0.6137776, 0.7417141>,
    <0.2704391, 0.6137776, 0.7417141>,
    <0.2487909, 0.5335274, 0.8083635>,
    <0.2286779, 0.5160830, 0.8254482>,
    <-0.1678411, 0.3594077, -0.9179627>,
    <-0.1686420, 0.3616505, -0.9169345>,
    <-0.1610151, 0.3452960, -0.9245782>,
    <-0.1576113, 0.3359752, -0.9285900>,
    <-0.1551587, 0.3270316, -0.9321889>,
    <-0.1657962, 0.3547564, -0.9201410>,
    <-0.1713689, 0.3675018, -0.9140980>,
    <-0.1713702, 0.3675030, -0.9140973>,
    <-0.1713702, 0.3675030, -0.9140973>,
    <-0.1713732, 0.3675052, -0.9140958>,
    <-0.1675865, 0.3595174, -0.9179662>,
    <-0.1597138, 0.3416631, -0.9261521>,
    <-0.1713732, 0.3675052, -0.9140958>,
    <-0.1713752, 0.3675029, -0.9140964>,
    <-0.1713752, 0.3675029, -0.9140964>,
    <-0.1713630, 0.3674678, -0.9141128>,
    <-0.1700801, 0.3634433, -0.9159595>,
    <-0.1706755, 0.3602567, -0.9171069>,
    <-0.1512452, 0.3198281, -0.9353261>,
    <-0.1739862, 0.3553678, -0.9183913>,
    <-0.2176084, 0.3720904, -0.9023277>,
    <-0.1482848, 0.3017930, -0.9417710>,
    <-0.1738404, 0.3718983, -0.9118504>,
    <-0.1776237, 0.3852976, -0.9055361>,
    <-0.1862447, 0.3970958, -0.8986812>,
    <-0.1834737, 0.3855693, -0.9042531>,
    <-0.1713630, 0.3674678, -0.9141128>,
    <-0.1852215, 0.4092732, -0.8934139>,
    <-0.1981626, 0.4209970, -0.8851515>,
    <-0.2119128, 0.4737432, -0.8547867>,
    <-0.2267533, 0.4768652, -0.8492247>,
    <-0.2010464, 0.4112331, -0.8890825>,
    <-0.2346137, 0.4640135, -0.8541943>,
    <-0.2394896, 0.5219078, -0.8186922>,
    <-0.2530051, 0.5241427, -0.8131807>,
    <-0.2590926, 0.5202414, -0.8137689>,
    <-0.2509551, 0.5161866, -0.8188852>,
    <-0.2776672, 0.5334881, -0.7989314>,
    <-0.2721315, 0.5149390, -0.8128852>,
    <-0.3140766, 0.5459333, -0.7767321>,
    <-0.2939116, 0.5119066, -0.8071974>,
    <-0.2578582, 0.4953008, -0.8295699>,
    <-0.2700973, 0.4711617, -0.8396750>,
    <-0.1696176, -0.3637880, -0.9159084>,
    <-0.1699586, -0.3644991, -0.9155624>,
    <-0.1662085, -0.3564513, -0.9194114>,
    <-0.1663377, -0.3559382, -0.9195867>,
    <-0.1733181, -0.3679856, -0.9135357>,
    <-0.1711933, -0.3664885, -0.9145376>,
    <-0.1712894, -0.3673594, -0.9141701>,
    <-0.1712622, -0.3673074, -0.9141961>,
    <-0.1712622, -0.3673074, -0.9141961>,
    <-0.1712544, -0.3672862, -0.9142061>,
    <-0.1695434, -0.3631476, -0.9161762>,
    <-0.1641834, -0.3499994, -0.9222495>,
    <-0.1712544, -0.3672862, -0.9142061>,
    <-0.1712654, -0.3672888, -0.9142030>,
    <-0.1712654, -0.3672888, -0.9142030>,
    <-0.1713019, -0.3673160, -0.9141852>,
    <-0.1680382, -0.3591159, -0.9180408>,
    <-0.1625638, -0.3399922, -0.9262712>,
    <-0.1615801, -0.3420672, -0.9256792>,
    <-0.1610004, -0.3226578, -0.9327223>,
    <-0.2117876, -0.3736945, -0.9030495>,
    <-0.1765227, -0.3658458, -0.9137815>,
    <-0.2683384, -0.5164185, -0.8132075>,
    <-0.2842300, -0.5339651, -0.7963006>,
    <-0.2763872, -0.5562069, -0.7837372>,
    <-0.2679059, -0.5613732, -0.7829985>,
    <-0.2520122, -0.5450123, -0.7996571>,
    <-0.2539163, -0.5132826, -0.8197973>,
    <-0.2727190, -0.4689871, -0.8400449>,
    <-0.2962836, -0.5103147, -0.8073382>,
    <-0.2932483, -0.5568175, -0.7771484>,
    <-0.2767886, -0.5730678, -0.7713503>,
    <-0.3157319, -0.5449198, -0.7767727>,
    <-0.2639056, -0.5912666, -0.7620746>,
    <-0.2450967, -0.5734072, -0.7817492>,
    <-0.1728869, -0.3720498, -0.9119699>,
    <-0.1813591, -0.3854362, -0.9047363>,
    <-0.1842651, -0.3981860, -0.8986068>,
    <-0.1764088, -0.3866493, -0.9051974>,
    <-0.1712894, -0.3673594, -0.9141701>,
    <-0.1950235, -0.4074921, -0.8921413>,
    <-0.1950271, -0.4231993, -0.8847976>,
    <-0.2267476, -0.4685905, -0.8538199>,
    <-0.2195074, -0.4813579, -0.8485936>,
    <-0.1845685, -0.4163448, -0.8902761>,
    <-0.2041353, -0.4778033, -0.8544196>,
    <-0.2453185, -0.5190064, -0.8188108>,
    <-0.2385783, -0.5307322, -0.8132673>,
    <-0.2318977, -0.5334075, -0.8134494>,
    <-0.2339969, -0.5248628, -0.8183914>,
    <-0.2301364, -0.5557473, -0.7988630>,
    <-0.2195883, -0.5398936, -0.8125859>,
    <-0.2137261, -0.5166388, -0.8290992>,
    <-0.1692379, -0.3530564, -0.9201683>,
    <-0.1722617, -0.3348044, -0.9264081>,
    <-0.1752867, -0.3242551, -0.9295876>,
    <-0.1665526, -0.3287422, -0.9296175>,
    <-0.1713019, -0.3673160, -0.9141852>,
    <-0.1694247, -0.3632046, -0.9161756>,
    <-0.1694247, -0.3632046, -0.9161756>,
    <-0.1567076, -0.3358264, -0.9287967>,
    <-0.1774903, -0.3058673, -0.9353836>,
    <-0.1841493, -0.3071709, -0.9336675>,
    <-0.1567076, -0.3358264, -0.9287967>,
    <-0.1273452, -0.2727522, -0.9536191>,
    <-0.1273452, -0.2727522, -0.9536191>,
    <-0.1871706, -0.2835564, -0.9405121>,
    <-0.1942015, -0.2943494, -0.9357586>,
    <-0.1961472, -0.2982875, -0.9341043>,
    <-0.1720580, -0.3038376, -0.9370586>,
    <-0.1869958, -0.2881937, -0.9391363>,
    <-0.1668026, 0.3514840, -0.9212144>,
    <-0.1593218, 0.3227409, -0.9329817>,
    <-0.1690688, 0.3248244, -0.9305401>,
    <-0.1689125, 0.3379619, -0.9258782>,
    <-0.1591489, 0.3412957, -0.9263848>,
    <-0.1697810, 0.3640964, -0.9157556>,
    <-0.1697810, 0.3640964, -0.9157556>,
    <-0.1713689, 0.3675018, -0.9140980>,
    <-0.1649779, 0.3029401, -0.9386211>,
    <-0.1787959, 0.3114689, -0.9332841>,
    <-0.1942642, 0.3067543, -0.9317528>,
    <-0.1967194, 0.3072204, -0.9310838>,
    <-0.1712929, 0.3090072, -0.9355070>,
    <-0.1880866, 0.2929921, -0.9374321>,
    <-0.1779405, 0.2770839, -0.9442254>,
    <-0.1335551, 0.2864094, -0.9487532>,
    <-0.1335551, 0.2864094, -0.9487532>,
    <-0.1591489, 0.3412957, -0.9263848>,
    <-0.2284515, 0.3269570, -0.9170109>,
    <-0.2250794, 0.3238365, -0.9189500>,
    <-0.2190568, 0.3168968, -0.9228166>,
    <-0.2209902, 0.3185827, -0.9217746>,
    <-0.2297289, 0.3318653, -0.9149262>,
    <-0.2309635, 0.3305707, -0.9150841>,
    <-0.2325848, 0.3321708, -0.9140935>,
    <-0.2319451, 0.3312592, -0.9145867>,
    <-0.2319451, 0.3312592, -0.9145867>,
    <-0.2274179, 0.3247950, -0.9180356>,
    <-0.2137294, 0.3121804, -0.9256690>,
    <-0.2106237, 0.3108340, -0.9268333>,
    <-0.2274179, 0.3247950, -0.9180356>,
    <-0.2147239, 0.3066665, -0.9272806>,
    <-0.2147239, 0.3066665, -0.9272806>,
    <-0.1779405, 0.2770839, -0.9442254>,
    <-0.2112665, 0.3108375, -0.9266858>,
    <-0.2261310, 0.3344744, -0.9148725>,
    <0.3055207, 0.4316180, 0.8487420>,
    <0.2699760, 0.3834549, 0.8832187>,
    <0.2722899, 0.4029033, 0.8738004>,
    <0.2905042, 0.4258474, 0.8568905>,
    <0.3150884, 0.4630561, 0.8284313>,
    <0.3348927, 0.4850439, 0.8078238>,
    <0.3450766, 0.4987554, 0.7950882>,
    <0.3090496, 0.4272795, 0.8496591>,
    <0.3090496, 0.4272795, 0.8496591>,
    <0.2659635, 0.3576672, 0.8951746>,
    <0.2225019, 0.3237812, 0.9195970>,
    <0.2500324, 0.3879257, 0.8871288>,
    <0.2659635, 0.3576672, 0.8951746>,
    <0.2100619, 0.2782138, 0.9372679>,
    <0.2100619, 0.2782138, 0.9372679>,
    <0.1868467, 0.3123314, 0.9314169>,
    <0.2772270, 0.4328378, 0.8577859>,
    <0.2981216, 0.4516198, 0.8409299>,
    <-0.2262691, -0.3235674, -0.9187527>,
    <-0.2135578, -0.3072163, -0.9273679>,
    <-0.2144173, -0.3089168, -0.9266043>,
    <-0.2247828, -0.3226335, -0.9194456>,
    <-0.2285743, -0.3264709, -0.9171535>,
    <-0.2320523, -0.3314390, -0.9144943>,
    <-0.2320523, -0.3314390, -0.9144943>,
    <-0.2324916, -0.3320678, -0.9141546>,
    <-0.2288383, -0.3278928, -0.9165802>,
    <-0.2246438, -0.3255959, -0.9184348>,
    <-0.1997450, -0.2923230, -0.9352268>,
    <-0.2057974, -0.3008475, -0.9312026>,
    <-0.2185124, -0.3261949, -0.9197006>,
    <-0.2153375, -0.3122121, -0.9252856>,
    <-0.1871706, -0.2835564, -0.9405121>,
    <-0.2186204, -0.3122546, -0.9245010>,
    <-0.2186204, -0.3122546, -0.9245010>,
    <-0.2285743, -0.3264709, -0.9171535>,
    <0.2177240, -0.3378835, 0.9156588>,
    <0.1958196, -0.2866480, 0.9378100>,
    <0.1809957, -0.2710222, 0.9454034>,
    <0.1892793, -0.2964185, 0.9361140>,
    <0.2234528, -0.3536878, 0.9082807>,
    <0.1884912, -0.2799143, 0.9413390>,
    <0.1695892, -0.2422212, 0.9552845>,
    <0.1650794, -0.2420828, 0.9561091>,
    <0.1774779, -0.2481204, 0.9523329>,
    <0.1924932, -0.2294027, 0.9541073>,
    <0.1585761, -0.2264686, 0.9610232>,
    <0.1585761, -0.2264686, 0.9610232>,
    <0.1640089, -0.2342273, 0.9582477>,
    <0.1759304, -0.2659584, 0.9477946>,
    <0.1640089, -0.2342273, 0.9582477>,
    <0.1826037, -0.2607833, 0.9479704>,
    <0.1826037, -0.2607833, 0.9479704>,
    <0.1490724, -0.2581986, 0.9545213>,
    <0.5272075, -0.8275343, 0.1929748>,
    <0.5511699, -0.7894436, 0.2701678>,
    <0.5126214, -0.7720835, 0.3756413>,
    <0.4928707, -0.8038721, 0.3329686>,
    <0.5396745, -0.8228978, 0.1777375>,
    <0.5590860, -0.7885933, 0.2560144>,
    <0.5233759, -0.7045847, 0.4792056>,
    <0.4661530, -0.6854967, 0.5592813>,
    <0.5494021, -0.7182831, 0.4268803>,
    <0.4247884, -0.5043424, 0.7517935>,
    <0.4240051, -0.5493253, 0.7200426>,
    <0.3893003, -0.5565784, 0.7339385>,
    <0.4372578, -0.7122606, 0.5490815>,
    <0.3426344, -0.5417946, 0.7675026>,
    <0.2417669, -0.3778377, 0.8937491>,
    <0.3051506, -0.4233644, 0.8530215>,
    <0.2472279, -0.3331450, 0.9098861>,
    <0.1970239, -0.2904340, 0.9363918>,
    <0.3241326, -0.3983887, 0.8580353>,
    <0.2575558, -0.3112828, 0.9147503>,
    <0.2994352, -0.3412109, 0.8910184>,
    <0.2501101, -0.2837408, 0.9257085>,
    <0.2051622, -0.2639561, 0.9424626>,
    <0.2350786, -0.2638164, 0.9354886>,
    <0.1924932, -0.2294027, 0.9541073>,
    <0.2485580, 0.3274253, 0.9115984>,
    <0.2071184, 0.2886075, 0.9347768>,
    <0.1974289, 0.2691222, 0.9426532>,
    <0.2190994, 0.2861987, 0.9327839>,
    <0.2410598, 0.3017577, 0.9224058>,
    <0.2892406, 0.3603928, 0.8868240>,
    <0.4277635, 0.5117114, 0.7450972>,
    <0.2613073, 0.3381734, 0.9040781>,
    <0.2030603, 0.2792172, 0.9385117>,
    <0.1735866, 0.2478662, 0.9531160>,
    <0.1751492, 0.2436622, 0.9539138>,
    <0.1765353, 0.2576663, 0.9499702>,
    <0.1530159, 0.2650321, 0.9520211>,
    <0.1622703, 0.2317485, 0.9591460>,
    <0.1622703, 0.2317485, 0.9591460>,
    <0.1679520, 0.2398628, 0.9561684>,
    <0.1947018, 0.2629963, 0.9449466>,
    <0.1679520, 0.2398628, 0.9561684>,
    <0.1874494, 0.2677083, 0.9450900>,
    <0.1874494, 0.2677083, 0.9450900>,
    <0.1970033, 0.2347817, 0.9518756>,
    <0.2242895, 0.2839602, 0.9322343>,
    <0.2776257, 0.3637440, 0.8891649>,
    <0.2986120, 0.4391151, 0.8473540>,
    <0.2331380, 0.3532925, 0.9059973>,
    <0.2099945, 0.2910064, 0.9333904>,
    <0.3970046, 0.5141051, 0.7603179>,
    <0.3944627, 0.5627437, 0.7264425>,
    <0.2680566, 0.4479814, 0.8529117>,
    <0.2086032, 0.3552316, 0.9112054>,
    <0.3753642, 0.5926453, 0.7126523>,
    <0.1819426, 0.2895509, 0.9397112>,
    <0.1530159, 0.2650321, 0.9520211>,
    <0.5199096, -0.8161105, 0.2523045>,
    <0.5499611, -0.8004549, 0.2383585>,
    <0.5349157, -0.8054984, 0.2550245>,
    <0.5108602, -0.8186350, 0.2624093>,
    <0.5260251, -0.8057473, 0.2721560>,
    <0.5520269, -0.7886662, 0.2706878>,
    <0.5699913, -0.7850056, 0.2426440>,
    <0.5427044, -0.7976580, 0.2630849>,
    <0.5774227, -0.7707327, 0.2693587>,
    <0.6276739, -0.7483384, 0.2145112>,
    <0.5912184, -0.7825111, 0.1952873>,
    <0.5600606, -0.8001112, 0.2148354>,
    <0.5133461, -0.8149523, 0.2689398>,
    <0.5282304, -0.8162485, 0.2339038>,
    <0.5472296, -0.8113131, 0.2056961>,
    <0.5748128, -0.7984391, 0.1791236>,
    <0.5778030, -0.7839177, 0.2271931>,
    <0.5584865, -0.7828871, 0.2741908>,
    <0.6026121, -0.7776826, 0.1790764>,
    <0.5957089, -0.7625098, 0.2524078>,
    <0.6291764, -0.7518747, 0.1970316>,
    <0.6109827, -0.7376292, 0.2874081>,
    <0.5660670, -0.7383406, 0.3666350>,
    <0.5613886, -0.6845033, 0.4650786>,
    <0.5974668, 0.7786479, 0.1916792>,
    <0.5539846, 0.7885741, 0.2669306>,
    <0.5513964, 0.7474038, 0.3706071>,
    <0.5876026, 0.7393735, 0.3287097>,
    <0.6207473, 0.7304851, 0.2847180>,
    <0.6312435, 0.7503050, 0.1964028>,
    <0.6279750, 0.7480859, 0.2145106>,
    <0.5887786, 0.7886097, 0.1772974>,
    <0.5502545, 0.7954777, 0.2538409>,
    <0.4851755, 0.7355663, 0.4728074>,
    <0.4875070, 0.6763571, 0.5521576>,
    <0.4884982, 0.7638278, 0.4218253>,
    <0.5225284, 0.6583735, 0.5417641>,
    <0.5784201, 0.6741219, 0.4593363>,
    <0.5752765, 0.7917890, 0.2052490>,
    <0.5537205, 0.8132751, 0.1788221>,
    <0.5391705, 0.8112976, 0.2260338>,
    <0.5449587, 0.7929953, 0.2723573>,
    <0.5863572, 0.7755481, 0.2339025>,
    <0.5603065, 0.7999394, 0.2148341>,
    <0.5247170, 0.8323173, 0.1786613>,
    <0.5130210, 0.8209715, 0.2506296>,
    <0.5331113, 0.8231984, 0.1952863>,
    <0.5009917, 0.7856873, 0.3629088>,
    <-0.1760273, 0.2731714, -0.9457229>,
    <-0.1468712, 0.2302312, -0.9619888>,
    <-0.1381927, 0.2069272, -0.9685473>,
    <-0.1523570, 0.2228078, -0.9628832>,
    <-0.1456275, 0.2173643, -0.9651660>,
    <-0.1828614, 0.2908350, -0.9391362>,
    <-0.1315129, 0.1989416, -0.9711470>,
    <-0.1224976, 0.1796368, -0.9760763>,
    <-0.1097754, 0.1901340, -0.9756016>,
    <-0.1349343, 0.1927040, -0.9719351>,
    <-0.1349343, 0.1927040, -0.9719351>,
    <-0.1205310, 0.1721341, -0.9776718>,
    <-0.1265863, 0.1806729, -0.9753631>,
    <-0.1205310, 0.1721341, -0.9776718>,
    <-0.1163646, 0.1661839, -0.9792049>,
    <-0.1163646, 0.1661839, -0.9792049>,
    <-0.1417741, 0.1689580, -0.9753734>,
    <-0.1322002, 0.1853241, -0.9737444>,
    <-0.5269552, 0.8271131, -0.1954535>,
    <-0.4888757, 0.7975918, -0.3533381>,
    <-0.5066266, 0.7630354, -0.4013807>,
    <-0.5490842, 0.7862522, -0.2833972>,
    <-0.5574193, 0.7861709, -0.2668690>,
    <-0.5396732, 0.8229575, -0.1774646>,
    <-0.4219059, 0.6878712, -0.5906172>,
    <-0.4491212, 0.6604365, -0.6017589>,
    <-0.3109209, 0.4923978, -0.8129407>,
    <-0.3575636, 0.5111960, -0.7815542>,
    <-0.5109668, 0.6873922, -0.5161442>,
    <-0.3911514, 0.5061398, -0.7686502>,
    <-0.3877617, 0.4603715, -0.7985606>,
    <-0.5402257, 0.7059289, -0.4580617>,
    <-0.2013436, 0.3166942, -0.9269118>,
    <-0.1535615, 0.2284376, -0.9613715>,
    <-0.2015805, 0.2716300, -0.9410539>,
    <-0.2630640, 0.3649680, -0.8930821>,
    <-0.1559753, 0.2006712, -0.9671622>,
    <-0.2084168, 0.2502044, -0.9454947>,
    <-0.1417741, 0.1689580, -0.9753734>,
    <-0.1781827, 0.1995327, -0.9635547>,
    <-0.1977819, 0.2234797, -0.9544313>,
    <-0.2788732, 0.3411724, -0.8976810>,
    <-0.2504728, 0.2843411, -0.9254261>,
    <-0.2012448, -0.2651024, -0.9429853>,
    <-0.1704474, -0.2224473, -0.9599296>,
    <-0.1509016, -0.2057008, -0.9669105>,
    <-0.1611263, -0.2247308, -0.9610070>,
    <-0.1581147, -0.2163676, -0.9634235>,
    <-0.2154873, -0.2776571, -0.9362007>,
    <-0.3910652, -0.4678212, -0.7925978>,
    <-0.2411978, -0.3016650, -0.9224001>,
    <-0.1899604, -0.2387414, -0.9523222>,
    <-0.1458428, -0.1968783, -0.9695199>,
    <-0.1300844, -0.1809704, -0.9748476>,
    <-0.1698003, -0.2154385, -0.9616414>,
    <-0.1452309, -0.1730815, -0.9741410>,
    <-0.1386850, -0.1980652, -0.9703281>,
    <-0.1386850, -0.1980652, -0.9703281>,
    <-0.1235334, -0.1764262, -0.9765313>,
    <-0.1295598, -0.1851277, -0.9741365>,
    <-0.1235334, -0.1764262, -0.9765313>,
    <-0.1191652, -0.1701876, -0.9781799>,
    <-0.1191652, -0.1701876, -0.9781799>,
    <-0.1127965, -0.1953708, -0.9742213>,
    <-0.1321099, -0.1923060, -0.9724019>,
    <-0.2334973, -0.3041272, -0.9235722>,
    <-0.1658457, -0.2278412, -0.9594705>,
    <-0.1903476, -0.2884539, -0.9383827>,
    <-0.2578580, -0.3791921, -0.8886634>,
    <-0.3628968, -0.5177207, -0.7747717>,
    <-0.3615783, -0.4675762, -0.8066187>,
    <-0.1384748, -0.2203779, -0.9655353>,
    <-0.1674012, -0.2871949, -0.9431309>,
    <-0.1127965, -0.1953708, -0.9742213>,
    <-0.2294688, -0.3854430, -0.8937437>,
    <-0.3462446, -0.5473770, -0.7619010>,
    <0.4986628, -0.7828921, 0.3720422>,
    <0.5289447, -0.7700661, 0.3566732>,
    <0.5133878, -0.7732064, 0.3722699>,
    <0.4896371, -0.7846713, 0.3801927>,
    <0.5027823, -0.7701695, 0.3924907>,
    <0.5282318, -0.7547659, 0.3889724>,
    <0.5482845, -0.7553100, 0.3590138>,
    <0.5206064, -0.7652973, 0.3785354>,
    <0.5531004, -0.7384423, 0.3857238>,
    <0.6067975, -0.7235814, 0.3289783>,
    <0.5730406, -0.7586102, 0.3100566>,
    <0.5413849, -0.7735440, 0.3294420>,
    <0.4920042, -0.7811033, 0.3844600>,
    <0.5092868, -0.7870545, 0.3480978>,
    <0.5334706, -0.7909555, 0.2996641>,
    <0.5609394, -0.7792918, 0.2793766>,
    <0.5682731, -0.7711174, 0.2871301>,
    <0.5533231, -0.7760499, 0.3026220>,
    <0.5891111, -0.7604537, 0.2732366>,
    <0.5911387, -0.7564871, 0.2797899>,
    <0.6173990, -0.7348555, 0.2807238>,
    <0.6185014, -0.7375169, 0.2711545>,
    <0.5824683, -0.7597784, 0.2889074>,
    <0.6195410, -0.7400902, 0.2616015>,
    <0.5890735, 0.7676817, 0.2523036>,
    <0.5640838, 0.7905663, 0.2383577>,
    <0.5739690, 0.7781534, 0.2550233>,
    <0.5945408, 0.7600416, 0.2624079>,
    <0.6189107, 0.7371735, 0.2711545>,
    <0.6164811, 0.7356256, 0.2807242>,
    <0.6072192, 0.7232273, 0.3289789>,
    <0.5772436, 0.7698837, 0.2721561>,
    <0.5522995, 0.7884754, 0.2706878>,
    <0.5427154, 0.8041046, 0.2426432>,
    <0.5639375, 0.7827908, 0.2630836>,
    <0.5267616, 0.8062060, 0.2693587>,
    <0.5902300, 0.7611181, 0.2689383>,
    <0.6212644, 0.7386443, 0.2616012>,
    <0.5607973, 0.7718208, 0.2996650>,
    <0.5404421, 0.7936436, 0.2793780>,
    <0.5302524, 0.7977393, 0.2871313>,
    <0.5400007, 0.7853781, 0.3026227>,
    <0.5654029, 0.7477612, 0.3480989>,
    <0.5417290, 0.7733025, 0.3294434>,
    <0.5131048, 0.8136734, 0.2732383>,
    <0.5086839, 0.8142220, 0.2797913>,
    <0.5168689, 0.7979414, 0.3100580>,
    <0.5147423, 0.8072004, 0.2889082>,
    <-0.5203993, 0.8168393, -0.2489139>,
    <-0.5108252, 0.8186529, -0.2624214>,
    <-0.5349300, 0.8054854, -0.2550354>,
    <-0.5504441, 0.8010164, -0.2353381>,
    <-0.5520376, 0.7886534, -0.2707034>,
    <-0.5263455, 0.8062897, -0.2699211>,
    <-0.5128184, 0.8142022, -0.2721985>,
    <-0.5422683, 0.7969863, -0.2660035>,
    <-0.5279288, 0.8158106, -0.2361021>,
    <-0.5600731, 0.8001027, -0.2148343>,
    <-0.5700582, 0.7849547, -0.2426517>,
    <-0.5915273, 0.7828395, -0.1930229>,
    <-0.6276891, 0.7483259, -0.2145106>,
    <-0.5771034, 0.7702017, -0.2715528>,
    <-0.5469383, 0.8109796, -0.2077754>,
    <-0.5563919, 0.7800294, -0.2863254>,
    <-0.5769976, 0.7828007, -0.2330168>,
    <-0.5749939, 0.7986655, -0.1775257>,
    <-0.5601086, 0.7305477, -0.3906129>,
    <-0.5942169, 0.7604786, -0.2618751>,
    <-0.5489940, 0.6697403, -0.5000535>,
    <-0.6081376, 0.7342359, -0.3017718>,
    <-0.6028258, 0.7778178, -0.1777657>,
    <-0.6290174, 0.7515873, -0.1986295>,
    <-0.5971753, -0.7782902, -0.1940257>,
    <-0.5832195, -0.7336604, -0.3487083>,
    <-0.5451430, -0.7389455, -0.3959529>,
    <-0.5517782, -0.7856376, -0.2798472>,
    <-0.5485948, -0.7931523, -0.2644866>,
    <-0.5888396, -0.7886354, -0.1769804>,
    <-0.6279600, -0.7480985, -0.2145106>,
    <-0.6309972, -0.7501088, -0.1979378>,
    <-0.6179800, -0.7271871, -0.2988305>,
    <-0.5052685, -0.6361099, -0.5831534>,
    <-0.4701532, -0.6522949, -0.5945312>,
    <-0.5663416, -0.6597062, -0.4940091>,
    <-0.4735573, -0.7184776, -0.5094443>,
    <-0.4802300, -0.7513012, -0.4526872>,
    <-0.5750689, -0.7914094, -0.2072848>,
    <-0.5430326, -0.7901119, -0.2843217>,
    <-0.5384154, -0.8101872, -0.2317445>,
    <-0.5538741, -0.8135266, -0.1771948>,
    <-0.5602942, -0.7999478, -0.2148344>,
    <-0.5860489, -0.7751145, -0.2361022>,
    <-0.4958327, -0.7776205, -0.3865959>,
    <-0.5116569, -0.8189295, -0.2599264>,
    <-0.5247747, -0.8325700, -0.1773099>,
    <-0.5333141, -0.8236007, -0.1930230>,
    <-0.4994065, 0.7840086, -0.3686783>,
    <-0.4896109, 0.7846964, -0.3801746>,
    <-0.5134123, 0.7731981, -0.3722534>,
    <-0.5296638, 0.7709564, -0.3536701>,
    <-0.5282550, 0.7547617, -0.3889491>,
    <-0.5032762, 0.7709723, -0.3902753>,
    <-0.4912722, 0.7800214, -0.3875799>,
    <-0.5199785, 0.7643335, -0.3813353>,
    <-0.5088447, 0.7863908, -0.3502379>,
    <-0.5414016, 0.7735317, -0.3294436>,
    <-0.5483619, 0.7552597, -0.3590013>,
    <-0.5735238, 0.7591563, -0.3078185>,
    <-0.6068181, 0.7235636, -0.3289795>,
    <-0.5526314, 0.7376990, -0.3878128>,
    <-0.5334251, 0.7909817, -0.2996759>,
    <-0.5527507, 0.7753226, -0.3055185>,
    <-0.5682879, 0.7711012, -0.2871441>,
    <-0.5614663, 0.7799874, -0.2763608>,
    <-0.5818854, 0.7589830, -0.2921543>,
    <-0.5912055, 0.7564296, -0.2798041>,
    <-0.6192474, 0.7397732, -0.2631888>,
    <-0.6185195, 0.7374966, -0.2711685>,
    <-0.5897742, 0.7611505, -0.2698449>,
    <-0.6177551, 0.7351634, -0.2791297>,
    <-0.5895907, -0.7683910, -0.2489136>,
    <-0.5945695, -0.7600146, -0.2624212>,
    <-0.5739518, -0.7781621, -0.2550354>,
    <-0.5644462, -0.7912120, -0.2353380>,
    <-0.5522837, -0.7884811, -0.2707033>,
    <-0.5776437, -0.7703704, -0.2699209>,
    <-0.6071982, -0.7232447, -0.3289795>,
    <-0.6167226, -0.7360298, -0.2791297>,
    <-0.6188876, -0.7371878, -0.2711685>,
    <-0.5897055, -0.7603653, -0.2721985>,
    <-0.5634554, -0.7821510, -0.2660035>,
    <-0.6210031, -0.7382999, -0.2631888>,
    <-0.5426447, -0.8041498, -0.2426518>,
    <-0.5263718, -0.8057243, -0.2715529>,
    <-0.5608375, -0.7717874, -0.2996758>,
    <-0.5395130, -0.7845917, -0.3055185>,
    <-0.5302322, -0.7977481, -0.2871441>,
    <-0.5409156, -0.7943772, -0.2763607>,
    <-0.5417118, -0.7733145, -0.3294435>,
    <-0.5649306, -0.7471192, -0.3502376>,
    <-0.5141942, -0.8063809, -0.2921544>,
    <-0.5086071, -0.8142656, -0.2798042>,
    <-0.5135328, -0.8145353, -0.2698449>,
    <-0.5172168, -0.7985829, -0.3078184>,
    <0.4645351, -0.7294178, 0.5021523>,
    <0.4950339, -0.7209301, 0.4849756>,
    <0.4794905, -0.7222553, 0.4984336>,
    <0.4563322, -0.7312557, 0.5069774>,
    <0.4659588, -0.7137195, 0.5229597>,
    <0.4909807, -0.7016156, 0.5164044>,
    <0.5139006, -0.7081798, 0.4841359>,
    <0.4864646, -0.7152048, 0.5018310>,
    <0.5154613, -0.6883819, 0.5103234>,
    <0.5732160, -0.6836466, 0.4517198>,
    <0.5430644, -0.7190895, 0.4335796>,
    <0.5113499, -0.7307233, 0.4522884>,
    <0.4591782, -0.7289307, 0.5077553>,
    <0.4795004, -0.7410516, 0.4700234>,
    <0.5074360, -0.7523164, 0.4201532>,
    <0.5351112, -0.7435141, 0.4010521>,
    <0.5419221, -0.7354703, 0.4066988>,
    <0.5267076, -0.7387079, 0.4205827>,
    <0.5625702, -0.7264289, 0.3947351>,
    <0.5645289, -0.7226598, 0.3988357>,
    <0.5891085, -0.7013837, 0.4012630>,
    <0.5917371, -0.7057394, 0.3895883>,
    <0.5560466, -0.7254293, 0.4056656>,
    <0.5942291, -0.7099233, 0.3780221>,
    <0.5651251, 0.7363543, 0.3720428>,
    <0.5427156, 0.7604232, 0.3566739>,
    <0.5509873, 0.7468785, 0.3722708>,
    <0.5698840, 0.7284813, 0.3801937>,
    <0.5922636, 0.7052976, 0.3895884>,
    <0.5884306, 0.7019527, 0.4012628>,
    <0.5737227, 0.6832217, 0.4517194>,
    <0.5517610, 0.7358742, 0.3924907>,
    <0.5285821, 0.7545206, 0.3889726>,
    <0.5222349, 0.7735497, 0.3590147>,
    <0.5410862, 0.7509566, 0.3785365>,
    <0.5047373, 0.7723064, 0.3857242>,
    <0.5657215, 0.7294853, 0.3844612>,
    <0.5959511, 0.7084781, 0.3780225>,
    <0.5333930, 0.7341414, 0.4201527>,
    <0.5156561, 0.7571372, 0.4010512>,
    <0.5057679, 0.7607861, 0.4066981>,
    <0.5140138, 0.7475963, 0.4205824>,
    <0.5323621, 0.7040378, 0.4700227>,
    <0.5117635, 0.7304342, 0.4522875>,
    <0.4902097, 0.7770968, 0.3947340>,
    <0.4859980, 0.7776482, 0.3988349>,
    <0.4899843, 0.7562571, 0.4335787>,
    <0.4915015, 0.7706244, 0.4056653>,
    <-0.4655430, 0.7309429, -0.4989912>,
    <-0.4563072, 0.7312805, -0.5069641>,
    <-0.4795190, 0.7222464, -0.4984191>,
    <-0.4960017, 0.7221709, -0.4821322>,
    <-0.4910039, 0.7016077, -0.5163931>,
    <-0.4666232, 0.7147850, -0.5209080>,
    <-0.4582335, 0.7275081, -0.5106407>,
    <-0.4856368, 0.7139405, -0.5044263>,
    <-0.4789156, 0.7401622, -0.4720168>,
    <-0.5113765, 0.7307181, -0.4522667>,
    <-0.5139861, 0.7081294, -0.4841189>,
    <-0.5437444, 0.7198856, -0.4314009>,
    <-0.5732478, 0.6836340, -0.4516984>,
    <-0.5148293, 0.6874125, -0.5122644>,
    <-0.5074003, 0.7523545, -0.4201281>,
    <-0.5259373, 0.7376983, -0.4233097>,
    <-0.5419502, 0.7354631, -0.4066743>,
    <-0.5358887, 0.7445495, -0.3980822>,
    <-0.5552338, 0.7243243, -0.4087416>,
    <-0.5646114, 0.7226083, -0.3988124>,
    <-0.5938194, 0.7094596, -0.3795334>,
    <-0.5917688, 0.7057250, -0.3895664>,
    <-0.5635303, 0.7274938, -0.3913903>,
    <-0.5896174, 0.7018603, -0.3996791>,
    <-0.5659200, -0.7374354, -0.3686782>,
    <-0.5699167, -0.7284658, -0.3801743>,
    <-0.5509712, -0.7468991, -0.3722532>,
    <-0.5433064, -0.7614038, -0.3536700>,
    <-0.5285702, -0.7545410, -0.3889492>,
    <-0.5523464, -0.7366129, -0.3902754>,
    <-0.5737046, -0.6832506, -0.4516986>,
    <-0.5888115, -0.7025365, -0.3996793>,
    <-0.5922438, -0.7053263, -0.3895665>,
    <-0.5649554, -0.7284281, -0.3875796>,
    <-0.5403955, -0.7500375, -0.3813351>,
    <-0.5955656, -0.7079943, -0.3795334>,
    <-0.5221612, -0.7736057, -0.3590012>,
    <-0.5041992, -0.7716116, -0.3878128>,
    <-0.5334408, -0.7341206, -0.4201284>,
    <-0.5133285, -0.7465270, -0.4233099>,
    <-0.5057513, -0.7608096, -0.4066747>,
    <-0.5163629, -0.7582214, -0.3980826>,
    <-0.5117492, -0.7304568, -0.4522671>,
    <-0.5317260, -0.7031836, -0.4720172>,
    <-0.4907410, -0.7694826, -0.4087418>,
    <-0.4859211, -0.7777076, -0.3988127>,
    <-0.4908818, -0.7783626, -0.3913908>,
    <-0.4904996, -0.7571678, -0.4314013>,
    <0.4025271, -0.6321175, 0.6621173>,
    <0.4388232, -0.6391777, 0.6315742>,
    <0.4252530, -0.6406294, 0.6393386>,
    <0.4009185, -0.6425472, 0.6529911>,
    <0.4014682, -0.6122486, 0.6811570>,
    <0.4321307, -0.6163974, 0.6582684>,
    <0.4607429, -0.6352068, 0.6198615>,
    <0.4348376, -0.6393718, 0.6341294>,
    <0.4586771, -0.6125488, 0.6437385>,
    <0.5215877, -0.6221542, 0.5838411>,
    <0.4961519, -0.6571421, 0.5674483>,
    <0.4651963, -0.6648395, 0.5844491>,
    <0.4092579, -0.6495287, 0.6407966>,
    <0.4344972, -0.6714657, 0.6002882>,
    <0.4670816, -0.6923598, 0.5499752>,
    <0.4941301, -0.6866528, 0.5332385>,
    <0.5009292, -0.6799217, 0.5355151>,
    <0.4861452, -0.6817300, 0.5467240>,
    <0.5202887, -0.6721011, 0.5268584>,
    <0.5230423, -0.6698015, 0.5270605>,
    <0.5446102, -0.6486150, 0.5316939>,
    <0.5498774, -0.6559225, 0.5171079>,
    <0.5156905, -0.6728709, 0.5303849>,
    <0.5548226, -0.6628531, 0.5027899>,
    <0.5265482, 0.6859958, 0.5021521>,
    <0.5081412, 0.7117525, 0.4849752>,
    <0.5147027, 0.6975998, 0.4984331>,
    <0.5310809, 0.6789164, 0.5069769>,
    <0.5504723, 0.6554232, 0.5171079>,
    <0.5441904, 0.6489670, 0.5316940>,
    <0.5221294, 0.6216994, 0.5838414>,
    <0.5113096, 0.6819644, 0.5229598>,
    <0.4913777, 0.7013376, 0.5164044>,
    <0.4897071, 0.7251206, 0.4841354>,
    <0.5056921, 0.7017420, 0.5018303>,
    <0.4705693, 0.7198157, 0.5103232>,
    <0.5279227, 0.6807957, 0.5077547>,
    <0.5564390, 0.6614969, 0.5027897>,
    <0.4908540, 0.6757139, 0.5499756>,
    <0.4762400, 0.6991792, 0.5332391>,
    <0.4675895, 0.7032661, 0.5355156>,
    <0.4743451, 0.6899923, 0.5467242>,
    <0.4823644, 0.6379483, 0.6002888>,
    <0.4656381, 0.6645297, 0.5844497>,
    <0.4536191, 0.7187832, 0.5268591>,
    <0.4505164, 0.7205843, 0.5270609>,
    <0.4478175, 0.6909858, 0.5674488>,
    <0.4559153, 0.7147258, 0.5303850>,
    <-0.4127175, 0.6480702, -0.6400541>,
    <-0.4056860, 0.6500090, -0.6425786>,
    <-0.4279147, 0.6445868, -0.6335589>,
    <-0.4434693, 0.6459440, -0.6213626>,
    <-0.4344446, 0.6208363, -0.6525490>,
    <-0.4101107, 0.6280933, -0.6612927>,
    <-0.4091314, 0.6493897, -0.6410183>,
    <-0.4344211, 0.6387111, -0.6350799>,
    <-0.4337651, 0.6703502, -0.6020619>,
    <-0.4652224, 0.6648313, -0.5844378>,
    <-0.4614945, 0.6360765, -0.6184089>,
    <-0.4970237, 0.6581856, -0.5654725>,
    <-0.5216191, 0.6221385, -0.5838298>,
    <-0.4582505, 0.6120672, -0.6444999>,
    <-0.4670413, 0.6923956, -0.5499643>,
    <-0.4851607, 0.6804217, -0.5492225>,
    <-0.5009568, 0.6799097, -0.5355046>,
    <-0.4951608, 0.6880364, -0.5304919>,
    <-0.5146328, 0.6714411, -0.5332165>,
    <-0.5231280, 0.6697430, -0.5270496>,
    <-0.5542852, 0.6622329, -0.5041979>,
    <-0.5499110, 0.6559035, -0.5170962>,
    <-0.5215535, 0.6735474, -0.5237517>,
    <-0.5452651, 0.6492557, -0.5302387>,
    <-0.5276364, -0.6874643, -0.4989916>,
    <-0.5311125, -0.6789009, -0.5069646>,
    <-0.5146844, -0.6976231, -0.4984195>,
    <-0.5089761, -0.7130860, -0.4821325>,
    <-0.4913624, -0.7013566, -0.5163932>,
    <-0.5120836, -0.6829532, -0.5209082>,
    <-0.5221085, -0.6217278, -0.5838297>,
    <-0.5447077, -0.6497234, -0.5302387>,
    <-0.5504478, -0.6554530, -0.5170962>,
    <-0.5269088, -0.6794208, -0.5106412>,
    <-0.5047869, -0.7005312, -0.5044267>,
    <-0.5559214, -0.6608598, -0.5041981>,
    <-0.4896303, -0.7251833, -0.4841192>,
    <-0.4698745, -0.7188902, -0.5122645>,
    <-0.4909015, -0.6756885, -0.5499643>,
    <-0.4734525, -0.6886199, -0.5492224>,
    <-0.4675688, -0.7032883, -0.5355044>,
    <-0.4771878, -0.7006214, -0.5304917>,
    <-0.4656216, -0.6645518, -0.5844377>,
    <-0.4815667, -0.6368791, -0.6020619>,
    <-0.4549335, -0.7132431, -0.5332164>,
    <-0.4504324, -0.7206453, -0.5270493>,
    <-0.4545458, -0.7204670, -0.5237513>,
    <-0.4485000, -0.6921624, -0.5654723>,
    <0.1653525, -0.2696157, 0.9486653>,
    <0.1529816, -0.2488754, 0.9563774>,
    <0.1709027, -0.2676528, 0.9482374>,
    <0.1870223, -0.2894303, 0.9387506>,
    <0.2220566, -0.3349406, 0.9156996>,
    <0.1894413, -0.3043662, 0.9335273>,
    <0.1430662, -0.2711131, 0.9518559>,
    <0.1413210, -0.2446700, 0.9592523>,
    <0.1413210, -0.2446700, 0.9592523>,
    <0.1290151, -0.2233647, 0.9661591>,
    <0.1520422, -0.2399134, 0.9588142>,
    <0.1804731, -0.2724771, 0.9450850>,
    <0.1290151, -0.2233647, 0.9661591>,
    <0.1166334, -0.2019281, 0.9724308>,
    <0.1166334, -0.2019281, 0.9724308>,
    <0.1760965, -0.2494954, 0.9522301>,
    <0.1890799, -0.2673248, 0.9448737>,
    <0.2129598, -0.2966899, 0.9309260>,
    <0.2055312, -0.3033246, 0.9304575>,
    <0.2445717, -0.3306095, 0.9115273>,
    <0.3677862, -0.4493641, 0.8141285>,
    <0.2592958, -0.3683387, 0.8928003>,
    <0.2102564, -0.3370050, 0.9177254>,
    <0.2534390, -0.3789790, 0.8900245>,
    <0.2657412, -0.4025299, 0.8759859>,
    <0.2463133, -0.3886119, 0.8878686>,
    <0.1430662, -0.2711131, 0.9518559>,
    <0.3087479, -0.4360016, 0.8453268>,
    <0.3028557, -0.4464708, 0.8419871>,
    <0.3820693, -0.5162491, 0.7664920>,
    <0.3616079, -0.5193518, 0.7742825>,
    <0.2836601, -0.4411016, 0.8514496>,
    <0.3346408, -0.5144559, 0.7895256>,
    <0.3949744, -0.5833143, 0.7097462>,
    <0.4106757, -0.5738753, 0.7085285>,
    <0.4282589, -0.5836450, 0.6898934>,
    <0.4221638, -0.5911822, 0.6872273>,
    <0.4277762, -0.5604216, 0.7091792>,
    <0.4478641, -0.5776011, 0.6824915>,
    <0.4507731, -0.5415976, 0.7095602>,
    <0.4755557, -0.5695059, 0.6704549>,
    <0.4529284, -0.5918155, 0.6667911>,
    <0.4930528, -0.5895357, 0.6398020>,
    <0.4586879, 0.5975265, 0.6576986>,
    <0.4515403, 0.6322553, 0.6295749>,
    <0.4573230, 0.6197633, 0.6377689>,
    <0.4678434, 0.5981006, 0.6506906>,
    <0.4801969, 0.5702597, 0.6664944>,
    <0.4610514, 0.5469485, 0.6987696>,
    <0.4051737, 0.4700116, 0.7841705>,
    <0.4396488, 0.5873928, 0.6794694>,
    <0.4318974, 0.6170208, 0.6578374>,
    <0.4395368, 0.6505253, 0.6193741>,
    <0.4522723, 0.6275449, 0.6337485>,
    <0.4188556, 0.6406051, 0.6435722>,
    <0.4706443, 0.6070765, 0.6402750>,
    <0.4953890, 0.5885983, 0.6388597>,
    <0.4122265, 0.5679056, 0.7124272>,
    <0.3988096, 0.5830235, 0.7078378>,
    <0.4016165, 0.6020124, 0.6901342>,
    <0.4107397, 0.5977972, 0.6884267>,
    <0.3681453, 0.4861519, 0.7925436>,
    <0.3643742, 0.5189215, 0.7732735>,
    <0.3832672, 0.6018799, 0.7006046>,
    <0.3902426, 0.6208536, 0.6798908>,
    <0.3644390, 0.5577085, 0.7457517>,
    <0.4013301, 0.6283837, 0.6663843>,
    <-0.3141698, 0.4923325, -0.8117303>,
    <-0.3207545, 0.5138219, -0.7956781>,
    <-0.3439833, 0.5181963, -0.7830377>,
    <-0.3530569, 0.5139689, -0.7817844>,
    <-0.3465242, 0.4917926, -0.7987872>,
    <-0.3186470, 0.4787115, -0.8181072>,
    <-0.3357037, 0.5325413, -0.7769831>,
    <-0.3580378, 0.5264470, -0.7711436>,
    <-0.3673023, 0.5675285, -0.7368856>,
    <-0.3960145, 0.5659705, -0.7230836>,
    <-0.3803715, 0.5245624, -0.7616770>,
    <-0.4255487, 0.5637126, -0.7079099>,
    <-0.4441469, 0.5297853, -0.7225379>,
    <-0.3741943, 0.4992557, -0.7814873>,
    <-0.4061249, 0.6018561, -0.6876277>,
    <-0.4248225, 0.5956227, -0.6817326>,
    <-0.4389513, 0.5958077, -0.6725585>,
    <-0.4321353, 0.6005107, -0.6727897>,
    <-0.4545382, 0.5930938, -0.6645561>,
    <-0.4603077, 0.5895854, -0.6637062>,
    <-0.4947989, 0.5910980, -0.6370064>,
    <-0.4864112, 0.5802344, -0.6532474>,
    <-0.4563532, 0.5896483, -0.6663757>,
    <-0.4773495, 0.5686038, -0.6699457>,
    <-0.4678290, -0.6094807, -0.6400541>,
    <-0.4720558, -0.6035362, -0.6425787>,
    <-0.4593579, -0.6225700, -0.6335589>,
    <-0.4553133, -0.6376507, -0.6213625>,
    <-0.4348064, -0.6205831, -0.6525488>,
    <-0.4499486, -0.6001987, -0.6612925>,
    <-0.4446114, -0.5293958, -0.7225377>,
    <-0.4770746, -0.5688347, -0.6699455>,
    <-0.4869549, -0.5797783, -0.6532473>,
    <-0.4702954, -0.6065621, -0.6410184>,
    <-0.4516112, -0.6266744, -0.6350800>,
    <-0.4961970, -0.5899250, -0.6370063>,
    <-0.4398759, -0.6512140, -0.6184088>,
    <-0.4184241, -0.6399542, -0.6444997>,
    <-0.4266569, -0.5874798, -0.6876274>,
    <-0.4144044, -0.6029178, -0.6817324>,
    <-0.4097459, -0.6162578, -0.6725582>,
    <-0.4164966, -0.6114615, -0.6727893>,
    <-0.3963934, -0.5657056, -0.7230833>,
    <-0.4076777, -0.5392578, -0.7368853>,
    <-0.4018647, -0.6299766, -0.6645557>,
    <-0.3965946, -0.6341981, -0.6637058>,
    <-0.3980062, -0.6305036, -0.6663754>,
    <-0.3841704, -0.5926863, -0.7079096>,
    <0.2555183, -0.3303444, 0.9086160>,
    <0.2837215, -0.3523832, 0.8918117>,
    <0.2810184, -0.3457455, 0.8952590>,
    <0.2561216, -0.3289892, 0.9089378>,
    <0.1760965, -0.2494954, 0.9522301>,
    <0.2759046, -0.3469276, 0.8963916>,
    <0.2759046, -0.3469276, 0.8963916>,
    <0.2839094, -0.3569930, 0.8899166>,
    <0.2767804, -0.3334933, 0.9012074>,
    <0.2926103, -0.3467832, 0.8911345>,
    <0.2839094, -0.3569930, 0.8899166>,
    <0.2557308, -0.3215607, 0.9117020>,
    <0.2557308, -0.3215607, 0.9117020>,
    <0.2954436, -0.3264197, 0.8978660>,
    <0.2724886, -0.3093727, 0.9110645>,
    <0.3091534, -0.3466052, 0.8856009>,
    <0.2852407, -0.3495864, 0.8924276>,
    <0.3310426, -0.3756958, 0.8656001>,
    <0.2449585, 0.3192787, 0.9154542>,
    <0.2923001, 0.4150578, 0.8615612>,
    <0.2933229, 0.3995380, 0.8685223>,
    <0.2787043, 0.3571499, 0.8914975>,
    <0.2759271, 0.3222367, 0.9055538>,
    <0.2228284, 0.2483445, 0.9426943>,
    <0.2309498, 0.2667229, 0.9356928>,
    <0.2717005, 0.3946688, 0.8777331>,
    <0.3056577, 0.4544520, 0.8366879>,
    <0.3274464, 0.4861171, 0.8102278>,
    <0.3189134, 0.4440259, 0.8373382>,
    <0.3204086, 0.4867135, 0.8126797>,
    <0.3173904, 0.4119213, 0.8541570>,
    <0.3278221, 0.3903195, 0.8603391>,
    <0.3533977, 0.5514066, 0.7556857>,
    <0.3812755, 0.5920661, 0.7099907>,
    <0.3551945, 0.5424745, 0.7612873>,
    <0.3326353, 0.5059224, 0.7958620>,
    <0.2309498, 0.2667229, 0.9356928>,
    <0.4067004, 0.6671389, 0.6241157>,
    <0.4067004, 0.6671389, 0.6241157>,
    <0.4156630, 0.6618827, 0.6238073>,
    <0.3672776, 0.5537653, 0.7472959>,
    <0.3408585, 0.5123278, 0.7882485>,
    <0.4156630, 0.6618827, 0.6238073>,
    <0.3869615, 0.5895634, 0.7089963>,
    <0.3869615, 0.5895634, 0.7089963>,
    <0.3450766, 0.4987554, 0.7950882>,
    <0.3168750, 0.4773520, 0.8195885>,
    <-0.2276894, 0.3247922, -0.9179693>,
    <-0.2288729, 0.3268679, -0.9169376>,
    <-0.2185243, 0.3120885, -0.9245799>,
    <-0.2135490, 0.3034956, -0.9285942>,
    <-0.2095696, 0.2951042, -0.9321985>,
    <-0.2248598, 0.3205607, -0.9201516>,
    <-0.2325616, 0.3321450, -0.9141087>,
    <-0.2325698, 0.3321505, -0.9141047>,
    <-0.2325698, 0.3321505, -0.9141047>,
    <-0.2325741, 0.3321542, -0.9141022>,
    <-0.2274687, 0.3249599, -0.9179646>,
    <-0.2166149, 0.3087405, -0.9261519>,
    <-0.2325741, 0.3321542, -0.9141022>,
    <-0.2325773, 0.3321586, -0.9140998>,
    <-0.2325773, 0.3321586, -0.9140998>,
    <-0.2325848, 0.3321708, -0.9140935>,
    <-0.2306171, 0.3284090, -0.9159494>,
    <-0.2306440, 0.3251543, -0.9171031>,
    <-0.2044787, 0.2887015, -0.9353288>,
    <-0.2330501, 0.3197559, -0.9183920>,
    <-0.2789039, 0.3286384, -0.9023355>,
    <-0.1984180, 0.2714414, -0.9417802>,
    <-0.2357905, 0.3360860, -0.9118383>,
    <-0.2418421, 0.3486223, -0.9055246>,
    <-0.2523744, 0.3587320, -0.8986760>,
    <-0.2476446, 0.3478617, -0.9042479>,
    <-0.2325848, 0.3321708, -0.9140935>,
    <-0.2534850, 0.3709074, -0.8934053>,
    <-0.2682589, 0.3801948, -0.8851492>,
    <-0.2909608, 0.4297533, -0.8547830>,
    <-0.3061153, 0.4302464, -0.8492240>,
    <-0.2694022, 0.3700759, -0.8890817>,
    <-0.3116237, 0.4162234, -0.8541948>,
    <-0.3264800, 0.4723933, -0.8186913>,
    <-0.3401779, 0.4722463, -0.8131804>,
    <-0.3454954, 0.4673471, -0.8137688>,
    <-0.3367775, 0.4647672, -0.8188848>,
    <-0.3660881, 0.4771671, -0.7989312>,
    <-0.3574153, 0.4598608, -0.8128852>,
    <-0.4041056, 0.4831006, -0.7767319>,
    <-0.3783377, 0.4530921, -0.8071977>,
    <-0.3399483, 0.4429990, -0.8295704>,
    <-0.3478087, 0.4171002, -0.8396764>,
    <-0.2302102, -0.3288116, -0.9159073>,
    <-0.2306603, -0.3294416, -0.9155676>,
    <-0.2255739, -0.3221724, -0.9194136>,
    <-0.2256173, -0.3216495, -0.9195860>,
    <-0.2345878, -0.3323058, -0.9135324>,
    <-0.2322402, -0.3312101, -0.9145296>,
    <-0.2324916, -0.3320678, -0.9141546>,
    <-0.2324342, -0.3319863, -0.9141988>,
    <-0.2324342, -0.3319863, -0.9141988>,
    <-0.2324157, -0.3319561, -0.9142145>,
    <-0.2300052, -0.3281734, -0.9161877>,
    <-0.2224515, -0.3161648, -0.9222555>,
    <-0.2324157, -0.3319561, -0.9142145>,
    <-0.2324186, -0.3319498, -0.9142160>,
    <-0.2324186, -0.3319498, -0.9142160>,
    <-0.2324422, -0.3319611, -0.9142059>,
    <-0.2278057, -0.3244544, -0.9180598>,
    <-0.2191002, -0.3065775, -0.9262858>,
    <-0.2185169, -0.3088092, -0.9256820>,
    <-0.2145570, -0.2897799, -0.9327341>,
    <-0.2734493, -0.3312276, -0.9030580>,
    <-0.2373670, -0.3296344, -0.9137823>,
    <-0.3539357, -0.4619751, -0.8132088>,
    <-0.3726336, -0.4764966, -0.7963009>,
    <-0.3687725, -0.4997628, -0.7837372>,
    <-0.3613170, -0.5063231, -0.7829987>,
    <-0.3428237, -0.4929707, -0.7996573>,
    <-0.3391881, -0.4613912, -0.8197985>,
    <-0.3500123, -0.4145019, -0.8400474>,
    <-0.3803970, -0.4511121, -0.8073388>,
    <-0.3854837, -0.4974365, -0.7771481>,
    <-0.3720959, -0.5162982, -0.7713500>,
    <-0.4055597, -0.4818151, -0.7767725>,
    <-0.3625688, -0.5364575, -0.7620743>,
    <-0.3409443, -0.5221354, -0.7817491>,
    <-0.2348761, -0.3363962, -0.9119599>,
    <-0.2455383, -0.3480966, -0.9047319>,
    <-0.2506149, -0.3601496, -0.8986014>,
    <-0.2408800, -0.3501620, -0.9051869>,
    <-0.2324916, -0.3320678, -0.9141546>,
    <-0.2628211, -0.3674376, -0.8921405>,
    <-0.2655545, -0.3829093, -0.8847945>,
    <-0.3046719, -0.4220970, -0.8538203>,
    <-0.2997603, -0.4359299, -0.8485923>,
    <-0.2540700, -0.3779843, -0.8902675>,
    <-0.2840070, -0.4351029, -0.8544153>,
    <-0.3317155, -0.4685222, -0.8188112>,
    <-0.3271143, -0.4812406, -0.8132673>,
    <-0.3210000, -0.4850356, -0.8134491>,
    <-0.3215837, -0.4762566, -0.8183908>,
    <-0.3231447, -0.5073417, -0.7988629>,
    <-0.3100041, -0.4935609, -0.8125854>,
    <-0.3001936, -0.4716788, -0.8290977>,
    <-0.2252682, 0.3171519, -0.9212323>,
    <-0.2129071, 0.2901408, -0.9329999>,
    <-0.2228482, 0.2904829, -0.9305688>,
    <-0.2249721, 0.3034464, -0.9259092>,
    <-0.2159376, 0.3084299, -0.9264135>,
    <-0.2303918, 0.3290571, -0.9157735>,
    <-0.2303918, 0.3290571, -0.9157735>,
    <-0.2325616, 0.3321450, -0.9141087>,
    <-0.2150314, 0.2696489, -0.9386431>,
    <-0.2300908, 0.2756205, -0.9333229>,
    <-0.2445279, 0.2683038, -0.9317828>,
    <-0.2469930, 0.2682998, -0.9311336>,
    <-0.2222488, 0.2744775, -0.9355574>,
    <-0.2359801, 0.2557430, -0.9375014>,
    <-0.2232027, 0.2418134, -0.9443023>,
    <-0.1811598, 0.2587839, -0.9487950>,
    <-0.1811598, 0.2587839, -0.9487950>,
    <-0.2159376, 0.3084299, -0.9264135>,
    <-0.2279074, -0.3182595, -0.9202006>,
    <-0.2276726, -0.2997226, -0.9264618>,
    <-0.2288381, -0.2888199, -0.9296323>,
    <-0.2210469, -0.2947828, -0.9296458>,
    <-0.2324422, -0.3319611, -0.9142059>,
    <-0.2298484, -0.3282204, -0.9162102>,
    <-0.2298484, -0.3282204, -0.9162102>,
    <-0.2125185, -0.3034288, -0.9288525>,
    <-0.2277472, -0.2702610, -0.9354626>,
    <-0.2345852, -0.2704340, -0.9337212>,
    <-0.2125185, -0.3034288, -0.9288525>,
    <-0.1725640, -0.2463332, -0.9536989>,
    <-0.1725640, -0.2463332, -0.9536989>,
    <-0.2333610, -0.2465294, -0.9406200>,
    <-0.2421939, -0.2559739, -0.9358523>,
    <-0.2448522, -0.2595757, -0.9341669>,
    <-0.2221440, -0.2692940, -0.9370874>,
    <-0.2341335, -0.2512734, -0.9391715>,
    <-0.2816957, 0.2822399, -0.9170541>,
    <-0.2778044, 0.2797199, -0.9190112>,
    <-0.2706810, 0.2739486, -0.9228673>,
    <-0.2728982, 0.2752975, -0.9218123>,
    <-0.2838340, 0.2868892, -0.9149496>,
    <-0.2848244, 0.2853961, -0.9151088>,
    <-0.2867077, 0.2866949, -0.9141142>,
    <-0.2858777, 0.2858595, -0.9146356>,
    <-0.2858777, 0.2858595, -0.9146356>,
    <-0.2802640, 0.2802420, -0.9181048>,
    <-0.2645809, 0.2701892, -0.9257401>,
    <-0.2613174, 0.2694379, -0.9268854>,
    <-0.2802640, 0.2802420, -0.9181048>,
    <-0.2645870, 0.2645624, -0.9273621>,
    <-0.2645870, 0.2645624, -0.9273621>,
    <-0.2232027, 0.2418134, -0.9443023>,
    <-0.2619787, 0.2693629, -0.9267205>,
    <-0.2807465, 0.2900894, -0.9148932>,
    <0.3618768, 0.3532936, 0.8626870>,
    <0.3187634, 0.3124356, 0.8948597>,
    <0.3253065, 0.3318800, 0.8854554>,
    <0.3482147, 0.3524913, 0.8686176>,
    <0.3805921, 0.3869629, 0.8398865>,
    <0.4011775, 0.4020169, 0.8230668>,
    <0.4124783, 0.4124834, 0.8122309>,
    <0.3637921, 0.3475730, 0.8642039>,
    <0.3637921, 0.3475730, 0.8642039>,
    <0.3104254, 0.2881658, 0.9058678>,
    <0.2636029, 0.2644102, 0.9276857>,
    <0.3016225, 0.3218932, 0.8974456>,
    <0.3104254, 0.2881658, 0.9058678>,
    <0.2443017, 0.2231874, 0.9436652>,
    <0.2443017, 0.2231874, 0.9436652>,
    <0.2309498, 0.2667229, 0.9356928>,
    <0.3377355, 0.3630539, 0.8684046>,
    <0.3644776, 0.3818441, 0.8493239>,
    <0.2741369, -0.2960742, 0.9149804>,
    <0.2436050, -0.2493019, 0.9372861>,
    <0.2262456, -0.2364542, 0.9449351>,
    <0.2388711, -0.2601246, 0.9355618>,
    <0.2825102, -0.3106080, 0.9075850>,
    <0.2351834, -0.2438884, 0.9408545>,
    <0.2099394, -0.2099602, 0.9549043>,
    <0.2054694, -0.2106212, 0.9557306>,
    <0.2188059, -0.2144411, 0.9519133>,
    <0.2304124, -0.1933379, 0.9536931>,
    <0.1963004, -0.1962988, 0.9606940>,
    <0.1963004, -0.1962988, 0.9606940>,
    <0.2030520, -0.2030503, 0.9578833>,
    <0.2204242, -0.2324014, 0.9473134>,
    <0.2030520, -0.2030503, 0.9578833>,
    <0.2261713, -0.2261694, 0.9474671>,
    <0.2261713, -0.2261694, 0.9474671>,
    <0.1924932, -0.2294027, 0.9541073>,
    <0.6629271, -0.7234455, 0.1927543>,
    <0.6799746, -0.6818781, 0.2695863>,
    <0.6391489, -0.6715951, 0.3747647>,
    <0.6251633, -0.7062400, 0.3322587>,
    <0.6743735, -0.7166985, 0.1776614>,
    <0.6875869, -0.6796195, 0.2556199>,
    <0.6386751, -0.6029909, 0.4780127>,
    <0.5786948, -0.5947408, 0.5580285>,
    <0.6650944, -0.6100920, 0.4306242>,
    <0.4987206, -0.4121591, 0.7624976>,
    <0.5162431, -0.4680459, 0.7172351>,
    <0.4810495, -0.4815373, 0.7326072>,
    <0.5548560, -0.6260807, 0.5478666>,
    <0.4324971, -0.4751091, 0.7663012>,
    <0.3047685, -0.3312047, 0.8929835>,
    <0.3752216, -0.3651024, 0.8520029>,
    <0.3024501, -0.2862210, 0.9091763>,
    <0.2454485, -0.2527712, 0.9358748>,
    <0.3922531, -0.3373476, 0.8557652>,
    <0.3100994, -0.2631496, 0.9135593>,
    <0.3616691, -0.2844382, 0.8878572>,
    <0.3013361, -0.2385890, 0.9231857>,
    <0.2491455, -0.2253581, 0.9418812>,
    <0.2796128, -0.2205391, 0.9344406>,
    <0.2304124, -0.1933379, 0.9536931>,
    <0.3018785, 0.2795111, 0.9114510>,
    <0.2543313, 0.2484933, 0.9346479>,
    <0.2413870, 0.2309654, 0.9425430>,
    <0.2656934, 0.2440116, 0.9326657>,
    <0.2900191, 0.2555040, 0.9222834>,
    <0.3476516, 0.3048803, 0.8866715>,
    <0.5103010, 0.4298070, 0.7448884>,
    <0.3162831, 0.2878701, 0.9039335>,
    <0.2486850, 0.2399362, 0.9383957>,
    <0.2142101, 0.2141758, 0.9530177>,
    <0.2150113, 0.2097521, 0.9538208>,
    <0.2188365, 0.2233448, 0.9498567>,
    <0.1970033, 0.2347817, 0.9518756>,
    <0.2002517, 0.2002533, 0.9590609>,
    <0.2002517, 0.2002533, 0.9590609>,
    <0.2072696, 0.2072713, 0.9560742>,
    <0.2376460, 0.2254127, 0.9448352>,
    <0.2072696, 0.2072713, 0.9560742>,
    <0.2313563, 0.2313582, 0.9449591>,
    <0.2313563, 0.2313582, 0.9449591>,
    <0.2349454, 0.1971444, 0.9518060>,
    <0.2704342, 0.2409126, 0.9321086>,
    <0.3367989, 0.3102310, 0.8890013>,
    <0.3706316, 0.3809045, 0.8470797>,
    <0.2912428, 0.3077572, 0.9057942>,
    <0.2575656, 0.2503547, 0.9332644>,
    <0.4804552, 0.4375528, 0.7600726>,
    <0.4864384, 0.4859459, 0.7261090>,
    <0.3421375, 0.3950243, 0.8525830>,
    <0.2674692, 0.3140040, 0.9109675>,
    <0.4728635, 0.5187675, 0.7122362>,
    <0.2297552, 0.2538872, 0.9395498>,
    <0.1970033, 0.2347817, 0.9518756>,
    <0.6537275, -0.7134308, 0.2523031>,
    <0.6806038, -0.6927946, 0.2383572>,
    <0.6666628, -0.7003741, 0.2550231>,
    <0.6452539, -0.7174883, 0.2624078>,
    <0.6579504, -0.7021630, 0.2721552>,
    <0.6805911, -0.6808263, 0.2706869>,
    <0.6976469, -0.6741018, 0.2426429>,
    <0.6729717, -0.6913003, 0.2630837>,
    <0.7024869, -0.6587552, 0.2693579>,
    <0.7480859, -0.6279750, 0.2145106>,
    <0.7181183, -0.6679590, 0.1952864>,
    <0.6904901, -0.6907022, 0.2148345>,
    <0.6470625, -0.7134299, 0.2689385>,
    <0.6619457, -0.7121217, 0.2339030>,
    <0.6798106, -0.7039738, 0.2056171>,
    <0.7047349, -0.6865008, 0.1790679>,
    <0.7051873, -0.6717085, 0.2269770>,
    <0.6860162, -0.6740805, 0.2738564>,
    <0.7285112, -0.6612351, 0.1789961>,
    <0.7191346, -0.6475411, 0.2520633>,
    <0.7502036, -0.6312056, 0.1969112>,
    <0.7299211, -0.6204070, 0.2868976>,
    <0.6848476, -0.6280648, 0.3694840>,
    <0.6673862, -0.5735492, 0.4750126>,
    <0.7236070, 0.6630752, 0.1916354>,
    <0.6825355, 0.6804177, 0.2667904>,
    <0.6728603, 0.6403531, 0.3704145>,
    <0.7070966, 0.6261390, 0.3285792>,
    <0.7381796, 0.6116132, 0.2846405>,
    <0.7519446, 0.6292952, 0.1963844>,
    <0.7483384, 0.6276739, 0.2145112>,
    <0.7167778, 0.6743891, 0.1772821>,
    <0.6800502, 0.6878557, 0.2537444>,
    <0.6056617, 0.6402610, 0.4724825>,
    <0.5976872, 0.5815619, 0.5518657>,
    <0.6138073, 0.6674831, 0.4215529>,
    <0.6290198, 0.5577376, 0.5415374>,
    <0.6867533, 0.5634955, 0.4591762>,
    <0.7040321, 0.6798666, 0.2052323>,
    <0.6865337, 0.7047687, 0.1788088>,
    <0.6718687, 0.7053555, 0.2259780>,
    <0.6743982, 0.6863332, 0.2722753>,
    <0.7121217, 0.6619457, 0.2339030>,
    <0.6907022, 0.6904901, 0.2148345>,
    <0.6612785, 0.7285594, 0.1786391>,
    <0.6478042, 0.7194332, 0.2505305>,
    <0.6679590, 0.7181183, 0.1952864>,
    <0.6298663, 0.6868121, 0.3627087>,
    <-0.2216894, 0.2394272, -0.9452663>,
    <-0.1854311, 0.2021094, -0.9616481>,
    <-0.1727731, 0.1805675, -0.9682690>,
    <-0.1895359, 0.1937927, -0.9625593>,
    <-0.1819299, 0.1895521, -0.9648687>,
    <-0.2314916, 0.2556237, -0.9386523>,
    <-0.1648288, 0.1738898, -0.9708727>,
    <-0.1524920, 0.1563146, -0.9758647>,
    <-0.1417741, 0.1689580, -0.9753734>,
    <-0.1671638, 0.1671620, -0.9716548>,
    <-0.1671638, 0.1671620, -0.9716548>,
    <-0.1492458, 0.1492443, -0.9774722>,
    <-0.1567061, 0.1566180, -0.9751482>,
    <-0.1492458, 0.1492443, -0.9774722>,
    <-0.1440658, 0.1440643, -0.9790253>,
    <-0.1440658, 0.1440643, -0.9790253>,
    <-0.1697312, 0.1424205, -0.9751450>,
    <-0.1631014, 0.1602582, -0.9735067>,
    <-0.2789397, -0.2792603, -0.9188070>,
    <-0.2635872, -0.2653745, -0.9274148>,
    <-0.2647048, -0.2668720, -0.9266665>,
    <-0.2772804, -0.2785617, -0.9195211>,
    <-0.2816698, -0.2816660, -0.9172385>,
    <-0.2859951, -0.2859959, -0.9145563>,
    <-0.2859951, -0.2859959, -0.9145563>,
    <-0.2865889, -0.2865973, -0.9141820>,
    <-0.2822553, -0.2831145, -0.9166123>,
    <-0.2777253, -0.2815840, -0.9184656>,
    <-0.2474003, -0.2531114, -0.9352688>,
    <-0.2548067, -0.2604160, -0.9312664>,
    <-0.2717950, -0.2832456, -0.9197279>,
    <-0.2661411, -0.2699107, -0.9253740>,
    <-0.2333610, -0.2465294, -0.9406200>,
    <-0.2693656, -0.2693592, -0.9246014>,
    <-0.2693656, -0.2693592, -0.9246014>,
    <-0.2816698, -0.2816660, -0.9172385>,
    <-0.6626090, 0.7230784, -0.1952097>,
    <-0.6201655, 0.7007798, -0.3525656>,
    <-0.6317148, 0.6637683, -0.4004348>,
    <-0.6773846, 0.6791154, -0.2827585>,
    <-0.6855360, 0.6775341, -0.2664356>,
    <-0.6743836, 0.7167586, -0.1773804>,
    <-0.5355731, 0.6048092, -0.5893787>,
    <-0.5576482, 0.5730992, -0.6004880>,
    <-0.3927090, 0.4319963, -0.8118860>,
    <-0.4419626, 0.4424037, -0.7803512>,
    <-0.6233086, 0.5885314, -0.5148953>,
    <-0.4753389, 0.4315102, -0.7667150>,
    <-0.4582587, 0.3807935, -0.8031160>,
    <-0.6543241, 0.6005545, -0.4595588>,
    <-0.2542321, 0.2779009, -0.9263569>,
    <-0.1917064, 0.1990952, -0.9610462>,
    <-0.2466676, 0.2334285, -0.9405670>,
    <-0.3235689, 0.3148382, -0.8922892>,
    <-0.1893849, 0.1713418, -0.9668378>,
    <-0.2502393, 0.2112463, -0.9448573>,
    <-0.1697312, 0.1424205, -0.9751450>,
    <-0.2115566, 0.1665984, -0.9630622>,
    <-0.2365415, 0.1872965, -0.9533982>,
    <-0.3362721, 0.2887585, -0.8964037>,
    <-0.3000776, 0.2372793, -0.9239329>,
    <-0.2444293, -0.2263209, -0.9428856>,
    <-0.2066696, -0.1896397, -0.9598565>,
    <-0.1845088, -0.1765442, -0.9668447>,
    <-0.1979022, -0.1935313, -0.9609268>,
    <-0.1934651, -0.1858029, -0.9633528>,
    <-0.2606219, -0.2362023, -0.9361008>,
    <-0.4665458, -0.3929623, -0.7924113>,
    <-0.2901210, -0.2553711, -0.9222882>,
    <-0.2287198, -0.2022899, -0.9522426>,
    <-0.1779977, -0.1687357, -0.9694561>,
    <-0.1596965, -0.1557912, -0.9747954>,
    <-0.2048278, -0.1828533, -0.9615666>,
    <-0.1732072, -0.1453396, -0.9741025>,
    <-0.1711796, -0.1711814, -0.9702548>,
    <-0.1711796, -0.1711814, -0.9702548>,
    <-0.1524587, -0.1524604, -0.9764795>,
    <-0.1599088, -0.1599869, -0.9740808>,
    <-0.1524587, -0.1524604, -0.9764795>,
    <-0.1470623, -0.1470639, -0.9781334>,
    <-0.1470623, -0.1470639, -0.9781334>,
    <-0.1452309, -0.1730815, -0.9741410>,
    <-0.1636821, -0.1666356, -0.9723378>,
    <-0.2829637, -0.2591575, -0.9234549>,
    <-0.2030760, -0.1957707, -0.9593925>,
    <-0.2378054, -0.2512934, -0.9382431>,
    <-0.3200757, -0.3289523, -0.8884492>,
    <-0.4475466, -0.4471008, -0.7744695>,
    <-0.4374926, -0.3978866, -0.8064034>,
    <-0.1748762, -0.1932464, -0.9654399>,
    <-0.2150327, -0.2541042, -0.9429698>,
    <-0.1452309, -0.1730815, -0.9741410>,
    <-0.2932572, -0.3401168, -0.8934880>,
    <-0.4363433, -0.4792632, -0.7615191>,
    <0.6270345, -0.6844061, 0.3720430>,
    <0.6546291, -0.6665166, 0.3566740>,
    <0.6398539, -0.6723106, 0.3722707>,
    <0.6184548, -0.6877256, 0.3801936>,
    <0.6288822, -0.6711615, 0.3924912>,
    <0.6512703, -0.6515727, 0.3889730>,
    <0.6711128, -0.6486265, 0.3590144>,
    <0.6455895, -0.6632682, 0.3785360>,
    <0.6729265, -0.6311787, 0.3857244>,
    <0.7232273, -0.6072192, 0.3289789>,
    <0.6960659, -0.6475777, 0.3100571>,
    <0.6674844, -0.6677816, 0.3294424>,
    <0.6201665, -0.6838008, 0.3844607>,
    <0.6382201, -0.6866607, 0.3480980>,
    <0.6627139, -0.6863030, 0.2996639>,
    <0.6877400, -0.6700465, 0.2793767>,
    <0.6935428, -0.6607229, 0.2871300>,
    <0.6796766, -0.6681765, 0.3026215>,
    <0.7122125, -0.6466026, 0.2732369>,
    <0.7135206, -0.6423442, 0.2797898>,
    <0.7356256, -0.6164811, 0.2807242>,
    <0.7371735, -0.6189107, 0.2711545>,
    <0.7055535, -0.6470912, 0.2889069>,
    <0.7386443, -0.6212644, 0.2616012>,
    <0.7134308, 0.6537275, 0.2523031>,
    <0.6927946, 0.6806038, 0.2383572>,
    <0.7003741, 0.6666628, 0.2550231>,
    <0.7174883, 0.6452539, 0.2624078>,
    <0.7375169, 0.6185014, 0.2711545>,
    <0.7348555, 0.6173990, 0.2807238>,
    <0.7235814, 0.6067975, 0.3289783>,
    <0.7021630, 0.6579504, 0.2721552>,
    <0.6808263, 0.6805911, 0.2706869>,
    <0.6741018, 0.6976469, 0.2426429>,
    <0.6913003, 0.6729717, 0.2630837>,
    <0.6587552, 0.7024869, 0.2693579>,
    <0.7134299, 0.6470625, 0.2689385>,
    <0.7400902, 0.6195410, 0.2616015>,
    <0.6863030, 0.6627139, 0.2996639>,
    <0.6700465, 0.6877400, 0.2793767>,
    <0.6607229, 0.6935428, 0.2871300>,
    <0.6681765, 0.6796766, 0.3026215>,
    <0.6866607, 0.6382201, 0.3480980>,
    <0.6677816, 0.6674844, 0.3294424>,
    <0.6466026, 0.7122125, 0.2732369>,
    <0.6423442, 0.7135206, 0.2797898>,
    <0.6475777, 0.6960659, 0.3100571>,
    <0.6470912, 0.7055535, 0.2889069>,
    <-0.6543360, 0.7140633, -0.2489136>,
    <-0.6452223, 0.7175119, -0.2624212>,
    <-0.6666744, 0.7003587, -0.2550353>,
    <-0.6811767, 0.6932636, -0.2353379>,
    <-0.6805992, 0.6808116, -0.2707032>,
    <-0.6583599, 0.7026414, -0.2699208>,
    <-0.6464123, 0.7127827, -0.2721985>,
    <-0.6724253, 0.6907144, -0.2660034>,
    <-0.6615724, 0.7117428, -0.2361021>,
    <-0.6905008, 0.6906917, -0.2148342>,
    <-0.6977037, 0.6740399, -0.2426516>,
    <-0.7184794, 0.6682287, -0.1930228>,
    <-0.7480985, 0.6279600, -0.2145106>,
    <-0.7020801, 0.6582877, -0.2715527>,
    <-0.6794670, 0.7036974, -0.2076886>,
    <-0.6834672, 0.6716398, -0.2859590>,
    <-0.7042049, 0.6707529, -0.2327791>,
    <-0.7049532, 0.6866930, -0.1774647>,
    <-0.6780950, 0.6218547, -0.3917703>,
    <-0.7173220, 0.6458084, -0.2614968>,
    <-0.6547152, 0.5626125, -0.5047922>,
    <-0.7265480, 0.6175749, -0.3012130>,
    <-0.7287460, 0.6613320, -0.1776776>,
    <-0.7499990, 0.6309520, -0.1984971>,
    <-0.7232587, -0.6627743, -0.1939770>,
    <-0.7017936, -0.6212786, -0.3485666>,
    <-0.6652424, -0.6331179, -0.3957452>,
    <-0.6798570, -0.6779132, -0.2796930>,
    <-0.6780148, -0.6858566, -0.2643797>,
    <-0.7168425, -0.6744042, -0.1769627>,
    <-0.7483259, -0.6276891, -0.2145106>,
    <-0.7516684, -0.6291451, -0.1979171>,
    <-0.7348843, -0.6088482, -0.2987456>,
    <-0.6081709, -0.5388222, -0.5829226>,
    <-0.5764373, -0.5608966, -0.5942348>,
    <-0.6723649, -0.5514043, -0.4938408>,
    <-0.5912717, -0.6254694, -0.5091029>,
    <-0.6035039, -0.6565982, -0.4523957>,
    <-0.7037621, -0.6795292, -0.2072655>,
    <-0.6720033, -0.6838307, -0.2842307>,
    <-0.6709336, -0.7043945, -0.2316819>,
    <-0.6867289, -0.7049900, -0.1771793>,
    <-0.6906917, -0.6905008, -0.2148342>,
    <-0.7117428, -0.6615724, -0.2361021>,
    <-0.6233939, -0.6797735, -0.3863781>,
    <-0.6461089, -0.7176621, -0.2598161>,
    <-0.6613795, -0.7287986, -0.1772843>,
    <-0.6682287, -0.7184794, -0.1930228>,
    <-0.6279611, 0.6853768, -0.3686781>,
    <-0.6184338, 0.6877552, -0.3801742>,
    <-0.6398769, 0.6722984, -0.3722531>,
    <-0.6554922, 0.6672688, -0.3536698>,
    <-0.6512926, 0.6515647, -0.3889490>,
    <-0.6295082, 0.6718665, -0.3902752>,
    <-0.6192581, 0.6828627, -0.3875795>,
    <-0.6448041, 0.6624283, -0.3813350>,
    <-0.6376696, 0.6860839, -0.3502375>,
    <-0.6674989, 0.6677667, -0.3294433>,
    <-0.6711806, 0.6485637, -0.3590010>,
    <-0.6966369, 0.6480316, -0.3078182>,
    <-0.7232447, 0.6071982, -0.3289795>,
    <-0.6723358, 0.6305282, -0.3878126>,
    <-0.6626738, 0.6863366, -0.2996757>,
    <-0.6789866, 0.6675596, -0.3055183>,
    <-0.6935547, 0.6607043, -0.2871440>,
    <-0.6883798, 0.6706401, -0.2763605>,
    <-0.7048413, 0.6464090, -0.2921543>,
    <-0.7135764, 0.6422760, -0.2798040>,
    <-0.7382999, 0.6210031, -0.2631888>,
    <-0.7371878, 0.6188876, -0.2711685>,
    <-0.7129867, 0.6471737, -0.2698448>,
    <-0.7360298, 0.6167226, -0.2791297>,
    <-0.7140633, -0.6543360, -0.2489136>,
    <-0.7175119, -0.6452223, -0.2624212>,
    <-0.7003587, -0.6666744, -0.2550353>,
    <-0.6932636, -0.6811767, -0.2353379>,
    <-0.6808116, -0.6805992, -0.2707032>,
    <-0.7026414, -0.6583599, -0.2699208>,
    <-0.7235636, -0.6068181, -0.3289795>,
    <-0.7351634, -0.6177551, -0.2791297>,
    <-0.7374966, -0.6185195, -0.2711685>,
    <-0.7127827, -0.6464123, -0.2721985>,
    <-0.6907144, -0.6724253, -0.2660034>,
    <-0.7397732, -0.6192474, -0.2631888>,
    <-0.6740399, -0.6977037, -0.2426516>,
    <-0.6582877, -0.7020801, -0.2715527>,
    <-0.6863366, -0.6626738, -0.2996757>,
    <-0.6675596, -0.6789866, -0.3055183>,
    <-0.6607043, -0.6935547, -0.2871440>,
    <-0.6706401, -0.6883798, -0.2763605>,
    <-0.6677667, -0.6674989, -0.3294433>,
    <-0.6860839, -0.6376696, -0.3502375>,
    <-0.6464090, -0.7048413, -0.2921543>,
    <-0.6422760, -0.7135764, -0.2798040>,
    <-0.6471737, -0.7129867, -0.2698448>,
    <-0.6480316, -0.6966369, -0.3078182>,
    <0.5841400, -0.6376707, 0.5021519>,
    <0.6127016, -0.6240159, 0.4849751>,
    <0.5976245, -0.6280201, 0.4984332>,
    <0.5763809, -0.6409052, 0.5069770>,
    <0.5828160, -0.6219637, 0.5229595>,
    <0.6053560, -0.6056987, 0.5164042>,
    <0.6290676, -0.6081832, 0.4841355>,
    <0.6032683, -0.6198656, 0.5018306>,
    <0.6271667, -0.5884150, 0.5103231>,
    <0.6832217, -0.5737227, 0.4517194>,
    <0.6596828, -0.6138629, 0.4335792>,
    <0.6304702, -0.6308270, 0.4522881>,
    <0.5787799, -0.6381212, 0.5077549>,
    <0.6008980, -0.6465290, 0.4700232>,
    <0.6303652, -0.6527717, 0.4201534>,
    <0.6560916, -0.6392974, 0.4010520>,
    <0.6614021, -0.6301931, 0.4066989>,
    <0.6469809, -0.6360233, 0.4205830>,
    <0.6801667, -0.6177036, 0.3947349>,
    <0.6814410, -0.6136516, 0.3988358>,
    <0.7019527, -0.5884306, 0.4012628>,
    <0.7052976, -0.5922636, 0.3895884>,
    <0.6735683, -0.6178518, 0.4056659>,
    <0.7084781, -0.5959511, 0.3780225>,
    <0.6844061, 0.6270345, 0.3720430>,
    <0.6665166, 0.6546291, 0.3566740>,
    <0.6723106, 0.6398539, 0.3722707>,
    <0.6877256, 0.6184548, 0.3801936>,
    <0.7057394, 0.5917371, 0.3895883>,
    <0.7013837, 0.5891085, 0.4012630>,
    <0.6836466, 0.5732160, 0.4517198>,
    <0.6711615, 0.6288822, 0.3924912>,
    <0.6515727, 0.6512703, 0.3889730>,
    <0.6486265, 0.6711128, 0.3590144>,
    <0.6632682, 0.6455895, 0.3785360>,
    <0.6311787, 0.6729265, 0.3857244>,
    <0.6838008, 0.6201665, 0.3844607>,
    <0.7099233, 0.5942291, 0.3780221>,
    <0.6527717, 0.6303652, 0.4201534>,
    <0.6392974, 0.6560916, 0.4010520>,
    <0.6301931, 0.6614021, 0.4066989>,
    <0.6360233, 0.6469809, 0.4205830>,
    <0.6465290, 0.6008980, 0.4700232>,
    <0.6308270, 0.6304702, 0.4522881>,
    <0.6177036, 0.6801667, 0.3947349>,
    <0.6136516, 0.6814410, 0.3988358>,
    <0.6138629, 0.6596828, 0.4335792>,
    <0.6178518, 0.6735683, 0.4056659>,
    <-0.5853970, 0.6389973, -0.4989917>,
    <-0.5763602, 0.6409336, -0.5069646>,
    <-0.5976506, 0.6280061, -0.4984196>,
    <-0.6138698, 0.6250696, -0.4821326>,
    <-0.6053772, 0.6056867, -0.5163934>,
    <-0.5836551, 0.6228974, -0.5209084>,
    <-0.5776022, 0.6368840, -0.5106412>,
    <-0.6022332, 0.6187640, -0.5044267>,
    <-0.6001675, 0.6457545, -0.4720170>,
    <-0.6304953, 0.6308171, -0.4522670>,
    <-0.6291427, 0.6081185, -0.4841192>,
    <-0.6604904, 0.6145286, -0.4314012>,
    <-0.6832506, 0.5737046, -0.4516986>,
    <-0.6263757, 0.5875699, -0.5122647>,
    <-0.6303367, 0.6528154, -0.4201282>,
    <-0.6460472, 0.6351630, -0.4233096>,
    <-0.6614285, 0.6301811, -0.4066744>,
    <-0.6570369, 0.6401820, -0.3980823>,
    <-0.6725762, 0.6169048, -0.4087416>,
    <-0.6815132, 0.6135865, -0.3988124>,
    <-0.7079943, 0.5955656, -0.3795334>,
    <-0.7053263, 0.5922438, -0.3895665>,
    <-0.6812969, 0.6185855, -0.3913905>,
    <-0.7025365, 0.5888115, -0.3996793>,
    <-0.6853768, -0.6279611, -0.3686781>,
    <-0.6877552, -0.6184338, -0.3801742>,
    <-0.6722984, -0.6398769, -0.3722531>,
    <-0.6672688, -0.6554922, -0.3536698>,
    <-0.6515647, -0.6512926, -0.3889490>,
    <-0.6718665, -0.6295082, -0.3902752>,
    <-0.6836340, -0.5732478, -0.4516984>,
    <-0.7018603, -0.5896174, -0.3996791>,
    <-0.7057250, -0.5917688, -0.3895664>,
    <-0.6828627, -0.6192581, -0.3875795>,
    <-0.6624283, -0.6448041, -0.3813350>,
    <-0.7094596, -0.5938194, -0.3795334>,
    <-0.6485637, -0.6711806, -0.3590010>,
    <-0.6305282, -0.6723358, -0.3878126>,
    <-0.6528154, -0.6303367, -0.4201282>,
    <-0.6351630, -0.6460472, -0.4233096>,
    <-0.6301811, -0.6614285, -0.4066744>,
    <-0.6401820, -0.6570369, -0.3980823>,
    <-0.6308171, -0.6304953, -0.4522670>,
    <-0.6457545, -0.6001675, -0.4720170>,
    <-0.6169048, -0.6725762, -0.4087416>,
    <-0.6135865, -0.6815132, -0.3988124>,
    <-0.6185855, -0.6812969, -0.3913905>,
    <-0.6145286, -0.6604904, -0.4314012>,
    <0.5046860, -0.5509375, 0.6646502>,
    <0.5425309, -0.5525814, 0.6327038>,
    <0.5295184, -0.5565079, 0.6402416>,
    <0.5056002, -0.5623059, 0.6543551>,
    <0.5016319, -0.5323803, 0.6818626>,
    <0.5326293, -0.5317598, 0.6584357>,
    <0.5638897, -0.5453928, 0.6201411>,
    <0.5391310, -0.5540199, 0.6343498>,
    <0.5580476, -0.5235212, 0.6438233>,
    <0.6216994, -0.5221294, 0.5838414>,
    <0.6027256, -0.5610026, 0.5674486>,
    <0.5735769, -0.5739585, 0.5844495>,
    <0.5156547, -0.5684043, 0.6411060>,
    <0.5444949, -0.5858148, 0.6002885>,
    <0.5802126, -0.6007334, 0.5499752>,
    <0.6058591, -0.5904161, 0.5332387>,
    <0.6113861, -0.5826067, 0.5355151>,
    <0.5971408, -0.5869548, 0.5467238>,
    <0.6290933, -0.5715432, 0.5268586>,
    <0.6314059, -0.5688004, 0.5270605>,
    <0.6489670, -0.5441904, 0.5316940>,
    <0.6554232, -0.5504723, 0.5171079>,
    <0.6246989, -0.5730998, 0.5303847>,
    <0.6614969, -0.5564390, 0.5027897>,
    <0.6376707, 0.5841400, 0.5021519>,
    <0.6240159, 0.6127016, 0.4849751>,
    <0.6280201, 0.5976245, 0.4984332>,
    <0.6409052, 0.5763809, 0.5069770>,
    <0.6559225, 0.5498774, 0.5171079>,
    <0.6486150, 0.5446102, 0.5316939>,
    <0.6221542, 0.5215877, 0.5838411>,
    <0.6219637, 0.5828160, 0.5229595>,
    <0.6056987, 0.6053560, 0.5164042>,
    <0.6081832, 0.6290676, 0.4841355>,
    <0.6198656, 0.6032683, 0.5018306>,
    <0.5884150, 0.6271667, 0.5103231>,
    <0.6381212, 0.5787799, 0.5077549>,
    <0.6628531, 0.5548226, 0.5027899>,
    <0.6007334, 0.5802126, 0.5499752>,
    <0.5904161, 0.6058591, 0.5332387>,
    <0.5826067, 0.6113861, 0.5355151>,
    <0.5869548, 0.5971408, 0.5467238>,
    <0.5858148, 0.5444949, 0.6002885>,
    <0.5739585, 0.5735769, 0.5844495>,
    <0.5715432, 0.6290933, 0.5268586>,
    <0.5688004, 0.6314059, 0.5270605>,
    <0.5610026, 0.6027256, 0.5674486>,
    <0.5730998, 0.6246989, 0.5303847>,
    <-0.5189835, 0.5665568, -0.6400543>,
    <-0.5123954, 0.5696871, -0.6425788>,
    <-0.5333449, 0.5604873, -0.6335591>,
    <-0.5488989, 0.5591229, -0.6213627>,
    <-0.5356515, 0.5359638, -0.6525491>,
    <-0.5129474, 0.5473362, -0.6612927>,
    <-0.5156810, 0.5684789, -0.6410186>,
    <-0.5387321, 0.5535710, -0.6350802>,
    <-0.5435801, 0.5848434, -0.6020622>,
    <-0.5736012, 0.5739458, -0.5844381>,
    <-0.5649368, 0.5462752, -0.6184091>,
    <-0.6037655, 0.5618789, -0.5654727>,
    <-0.6217278, 0.5221085, -0.5838297>,
    <-0.5575730, 0.5231940, -0.6445001>,
    <-0.5801790, 0.6007755, -0.5499647>,
    <-0.5959439, 0.5858372, -0.5492228>,
    <-0.6114111, 0.5825900, -0.5355048>,
    <-0.6071144, 0.5915997, -0.5304922>,
    <-0.6234088, 0.5718753, -0.5332167>,
    <-0.6314802, 0.5687278, -0.5270498>,
    <-0.6608598, 0.5559214, -0.5041981>,
    <-0.6554530, 0.5504478, -0.5170962>,
    <-0.6305902, 0.5727478, -0.5237518>,
    <-0.6497234, 0.5447077, -0.5302387>,
    <-0.6389973, -0.5853970, -0.4989917>,
    <-0.6409336, -0.5763602, -0.5069646>,
    <-0.6280061, -0.5976506, -0.4984196>,
    <-0.6250696, -0.6138698, -0.4821326>,
    <-0.6056867, -0.6053772, -0.5163934>,
    <-0.6228974, -0.5836551, -0.5209084>,
    <-0.6221385, -0.5216191, -0.5838298>,
    <-0.6492557, -0.5452651, -0.5302387>,
    <-0.6559035, -0.5499110, -0.5170962>,
    <-0.6368840, -0.5776022, -0.5106412>,
    <-0.6187640, -0.6022332, -0.5044267>,
    <-0.6622329, -0.5542852, -0.5041979>,
    <-0.6081185, -0.6291427, -0.4841192>,
    <-0.5875699, -0.6263757, -0.5122647>,
    <-0.6007755, -0.5801790, -0.5499647>,
    <-0.5858372, -0.5959439, -0.5492228>,
    <-0.5825900, -0.6114111, -0.5355048>,
    <-0.5915997, -0.6071144, -0.5304922>,
    <-0.5739458, -0.5736012, -0.5844381>,
    <-0.5848434, -0.5435801, -0.6020622>,
    <-0.5718753, -0.6234088, -0.5332167>,
    <-0.5687278, -0.6314802, -0.5270498>,
    <-0.5727478, -0.6305902, -0.5237518>,
    <-0.5618789, -0.6037655, -0.5654727>,
    <0.4604164, -0.4365704, 0.7729314>,
    <0.4682474, -0.4483334, 0.7614076>,
    <0.4383684, -0.4242143, 0.7923859>,
    <0.4257460, -0.4109339, 0.8061474>,
    <0.4082025, -0.3965328, 0.8222727>,
    <0.3765741, -0.3701104, 0.8492410>,
    <0.2954436, -0.3264197, 0.8978660>,
    <0.5258250, -0.4839958, 0.6994685>,
    <0.5258250, -0.4839958, 0.6994685>,
    <0.5075580, -0.4782750, 0.7166853>,
    <0.4313242, -0.4240223, 0.7963445>,
    <0.4099488, -0.4025698, 0.8184617>,
    <0.5075580, -0.4782750, 0.7166853>,
    <0.4522540, -0.4414825, 0.7749578>,
    <0.4522540, -0.4414825, 0.7749578>,
    <0.3892493, -0.3966125, 0.8313745>,
    <0.3803791, -0.3866831, 0.8401119>,
    <0.3694931, -0.3696259, 0.8525559>,
    <0.3961561, -0.3857322, 0.8332293>,
    <0.3709604, -0.3590170, 0.8564433>,
    <0.4697761, -0.4071224, 0.7833018>,
    <0.4253947, -0.4065039, 0.8085753>,
    <0.3248027, -0.3392825, 0.8828310>,
    <0.3903876, -0.3882373, 0.8347870>,
    <0.3756937, -0.3843312, 0.8432934>,
    <0.3406281, -0.3623434, 0.8675712>,
    <0.2954436, -0.3264197, 0.8978660>,
    <0.4408469, -0.4255382, 0.7902982>,
    <0.4053378, -0.4101620, 0.8169874>,
    <0.4966304, -0.4669654, 0.7316430>,
    <0.4626907, -0.4615267, 0.7569084>,
    <0.3683226, -0.3932523, 0.8424317>,
    <0.4251525, -0.4525558, 0.7838614>,
    <0.4939066, -0.5082833, 0.7054816>,
    <0.5124569, -0.5002181, 0.6979755>,
    <0.5272429, -0.5033585, 0.6845766>,
    <0.5200820, -0.5099763, 0.6851560>,
    <0.5309625, -0.4867406, 0.6936588>,
    <0.5459778, -0.4941674, 0.6765404>,
    <0.5496802, -0.4636726, 0.6948809>,
    <0.5716378, -0.4813593, 0.6644723>,
    <0.5499422, -0.5048735, 0.6653317>,
    <0.5889191, -0.4956292, 0.6383776>,
    <0.5568619, 0.5099522, 0.6556322>,
    <0.5549917, 0.5447309, 0.6286911>,
    <0.5583647, 0.5312852, 0.6371538>,
    <0.5652827, 0.5083597, 0.6496352>,
    <0.5733103, 0.4793662, 0.6644722>,
    <0.5520793, 0.4608135, 0.6948808>,
    <0.4825144, 0.3919443, 0.7833004>,
    <0.5361513, 0.5028250, 0.6780183>,
    <0.5328836, 0.5329120, 0.6572974>,
    <0.5459373, 0.5644349, 0.6191653>,
    <0.5544614, 0.5395606, 0.6335984>,
    <0.5238196, 0.5581988, 0.6434494>,
    <0.5690569, 0.5162543, 0.6400436>,
    <0.5903643, 0.4939070, 0.6383775>,
    <0.5047325, 0.4873659, 0.7125444>,
    <0.4937428, 0.5042970, 0.7084508>,
    <0.4999364, 0.5227587, 0.6904976>,
    <0.5084140, 0.5172740, 0.6884350>,
    <0.4463143, 0.4135395, 0.7935922>,
    <0.4484603, 0.4468761, 0.7740705>,
    <0.4813311, 0.5251329, 0.7018232>,
    <0.4918705, 0.5431995, 0.6804394>,
    <0.4549535, 0.4845608, 0.7471400>,
    <0.5043242, 0.5490321, 0.6664990>,
    <-0.3948882, 0.4302965, -0.8117316>,
    <-0.4051055, 0.4503169, -0.7956785>,
    <-0.4287411, 0.4505914, -0.7830380>,
    <-0.4369424, 0.4448523, -0.7817849>,
    <-0.4266583, 0.4241473, -0.7987877>,
    <-0.3969320, 0.4161044, -0.8181089>,
    <-0.4230786, 0.4661566, -0.7769830>,
    <-0.4440152, 0.4562766, -0.7711435>,
    <-0.4602726, 0.4951253, -0.7368854>,
    <-0.4882782, 0.4886051, -0.7230834>,
    <-0.4656822, 0.4505423, -0.7616769>,
    <-0.5169716, 0.4812529, -0.7079096>,
    <-0.5293958, 0.4446114, -0.7225377>,
    <-0.4552044, 0.4266928, -0.7814872>,
    <-0.5044662, 0.5221898, -0.6876276>,
    <-0.5217974, 0.5128042, -0.6817327>,
    <-0.5357437, 0.5105329, -0.6725585>,
    <-0.5298480, 0.5163482, -0.6727895>,
    <-0.5506225, 0.5051535, -0.6645561>,
    <-0.5556951, 0.5006967, -0.6637061>,
    <-0.5899250, 0.4961970, -0.6370063>,
    <-0.5797783, 0.4869549, -0.6532473>,
    <-0.5518117, 0.5014454, -0.6663755>,
    <-0.5688347, 0.4770746, -0.6699455>,
    <-0.5665568, -0.5189835, -0.6400543>,
    <-0.5696871, -0.5123954, -0.6425788>,
    <-0.5604873, -0.5333449, -0.6335591>,
    <-0.5591229, -0.5488989, -0.6213627>,
    <-0.5359638, -0.5356515, -0.6525491>,
    <-0.5473362, -0.5129474, -0.6612927>,
    <-0.5297853, -0.4441469, -0.7225379>,
    <-0.5686038, -0.4773495, -0.6699457>,
    <-0.5802344, -0.4864112, -0.6532474>,
    <-0.5684789, -0.5156810, -0.6410186>,
    <-0.5535710, -0.5387321, -0.6350802>,
    <-0.5910980, -0.4947989, -0.6370064>,
    <-0.5462752, -0.5649368, -0.6184091>,
    <-0.5231940, -0.5575730, -0.6445001>,
    <-0.5221898, -0.5044662, -0.6876276>,
    <-0.5128042, -0.5217974, -0.6817327>,
    <-0.5105329, -0.5357437, -0.6725585>,
    <-0.5163482, -0.5298480, -0.6727895>,
    <-0.4886051, -0.4882782, -0.7230834>,
    <-0.4951253, -0.4602726, -0.7368854>,
    <-0.5051535, -0.5506225, -0.6645561>,
    <-0.5006967, -0.5556951, -0.6637061>,
    <-0.5014454, -0.5518117, -0.6663755>,
    <-0.4812529, -0.5169716, -0.7079096>,
    <0.3433138, -0.3554402, 0.8693664>,
    <0.3089631, -0.3167414, 0.8967813>,
    <0.3266608, -0.3218920, 0.8886384>,
    <0.3427735, -0.3419717, 0.8749638>,
    <0.3892493, -0.3966125, 0.8313745>,
    <0.3388826, -0.3581942, 0.8699745>,
    <0.3388826, -0.3581942, 0.8699745>,
    <0.2859366, -0.3093063, 0.9069564>,
    <0.2635454, -0.2630713, 0.9280826>,
    <0.3188516, -0.2996096, 0.8992039>,
    <0.2859366, -0.3093063, 0.9069564>,
    <0.2229026, -0.2442355, 0.9437497>,
    <0.2229026, -0.2442355, 0.9437497>,
    <0.2667150, -0.2309423, 0.9356969>,
    <0.2480550, -0.2226300, 0.9428174>,
    <0.3208170, -0.2750721, 0.9063177>,
    <0.3565975, -0.3339835, 0.8725212>,
    <0.3872368, -0.3262809, 0.8623157>,
    <0.2964863, 0.2716195, 0.9155975>,
    <0.3596123, 0.3574516, 0.8619207>,
    <0.3577981, 0.3418821, 0.8689632>,
    <0.3358645, 0.3025064, 0.8920117>,
    <0.3266033, 0.2681776, 0.9063173>,
    <0.2623218, 0.2056261, 0.9428177>,
    <0.2737481, 0.2225593, 0.9356972>,
    <0.3361221, 0.3414476, 0.8777446>,
    <0.3795832, 0.3937643, 0.8371776>,
    <0.4063213, 0.4208603, 0.8110361>,
    <0.3906048, 0.3810239, 0.8380028>,
    <0.3985338, 0.4211836, 0.8147240>,
    <0.3830562, 0.3490913, 0.8552211>,
    <0.3885682, 0.3246966, 0.8623148>,
    <0.4427830, 0.4801322, 0.7572425>,
    <0.4728641, 0.5091905, 0.7191137>,
    <0.4401014, 0.4666567, 0.7671651>,
    <0.4142342, 0.4383499, 0.7976587>,
    <0.2737481, 0.2225593, 0.9356972>,
    <0.5147484, 0.5840612, 0.6276198>,
    <0.5147484, 0.5840612, 0.6276198>,
    <0.5182139, 0.5710904, 0.6366397>,
    <0.4476079, 0.4673816, 0.7623658>,
    <0.4176833, 0.4351584, 0.7976076>,
    <0.5182139, 0.5710904, 0.6366397>,
    <0.4724835, 0.4983335, 0.7269272>,
    <0.4724835, 0.4983335, 0.7269272>,
    <0.4124783, 0.4124834, 0.8122309>,
    <0.3912974, 0.4093942, 0.8241861>,
    <-0.2806266, 0.2803174, -0.9179711>,
    <-0.2821550, 0.2821556, -0.9169388>,
    <-0.2693969, 0.2693987, -0.9245808>,
    <-0.2630041, 0.2618008, -0.9285953>,
    <-0.2576262, 0.2542271, -0.9322002>,
    <-0.2771017, 0.2766401, -0.9201548>,
    <-0.2866970, 0.2867105, -0.9141126>,
    <-0.2867115, 0.2867167, -0.9141062>,
    <-0.2867115, 0.2867167, -0.9141062>,
    <-0.2867230, 0.2867219, -0.9141009>,
    <-0.2804392, 0.2805157, -0.9179678>,
    <-0.2669351, 0.2664320, -0.9261531>,
    <-0.2867230, 0.2867219, -0.9141009>,
    <-0.2867294, 0.2867225, -0.9140987>,
    <-0.2867294, 0.2867225, -0.9140987>,
    <-0.2867077, 0.2866949, -0.9141142>,
    <-0.2841261, 0.2833525, -0.9159605>,
    <-0.2835957, 0.2801548, -0.9171078>,
    <-0.2515037, 0.2488069, -0.9353294>,
    <-0.2850326, 0.2744273, -0.9183932>,
    <-0.3317351, 0.2752151, -0.9023350>,
    <-0.2425377, 0.2328617, -0.9417807>,
    <-0.2905511, 0.2900111, -0.9118518>,
    <-0.2986895, 0.3013087, -0.9055372>,
    <-0.3108259, 0.3094470, -0.8986823>,
    <-0.3042793, 0.2995631, -0.9042544>,
    <-0.2867077, 0.2866949, -0.9141142>,
    <-0.3140297, 0.3212403, -0.8934148>,
    <-0.3302002, 0.3278310, -0.8851524>,
    <-0.3611616, 0.3726936, -0.8547876>,
    <-0.3761750, 0.3705517, -0.8492255>,
    <-0.3295702, 0.3176697, -0.8890835>,
    <-0.3791652, 0.3557865, -0.8541954>,
    <-0.4035493, 0.4085224, -0.8186925>,
    <-0.4170146, 0.4060003, -0.8131806>,
    <-0.4214003, 0.4002521, -0.8137690>,
    <-0.4123663, 0.3992245, -0.8188857>,
    <-0.4433857, 0.4063473, -0.7989312>,
    <-0.4318392, 0.3908098, -0.8128854>,
    <-0.4818559, 0.4055891, -0.7767318>,
    <-0.4512685, 0.3805108, -0.8071978>,
    <-0.4117091, 0.3772370, -0.8295709>,
    <-0.4149532, 0.3503670, -0.8396766>,
    <-0.2838097, -0.2838320, -0.9159102>,
    <-0.2843755, -0.2843870, -0.9155625>,
    <-0.2780986, -0.2781075, -0.9194114>,
    <-0.2780440, -0.2775801, -0.9195873>,
    <-0.2887209, -0.2865107, -0.9135381>,
    <-0.2862073, -0.2858236, -0.9145437>,
    <-0.2865889, -0.2865973, -0.9141820>,
    <-0.2865632, -0.2865784, -0.9141960>,
    <-0.2865632, -0.2865784, -0.9141960>,
    <-0.2865490, -0.2865644, -0.9142049>,
    <-0.2835228, -0.2832600, -0.9161760>,
    <-0.2739891, -0.2727380, -0.9222494>,
    <-0.2865490, -0.2865644, -0.9142049>,
    <-0.2865579, -0.2865627, -0.9142026>,
    <-0.2865579, -0.2865627, -0.9142026>,
    <-0.2866003, -0.2865755, -0.9141853>,
    <-0.2807289, -0.2799863, -0.9180408>,
    <-0.2690442, -0.2638883, -0.9262711>,
    <-0.2688298, -0.2661746, -0.9256790>,
    <-0.2616465, -0.2481341, -0.9327221>,
    <-0.3268268, -0.2787229, -0.9030492>,
    <-0.2910036, -0.2834080, -0.9137816>,
    <-0.4287816, -0.3934980, -0.8132071>,
    <-0.4497161, -0.4045511, -0.7963001>,
    <-0.4499534, -0.4281340, -0.7837367>,
    <-0.4437506, -0.4358895, -0.7829979>,
    <-0.4232196, -0.4259512, -0.7996566>,
    <-0.4141567, -0.3954839, -0.8197968>,
    <-0.4166756, -0.3474288, -0.8400444>,
    <-0.4529539, -0.3782045, -0.8073377>,
    <-0.4660064, -0.4229408, -0.7771480>,
    <-0.4560973, -0.4438408, -0.7713499>,
    <-0.4830648, -0.4040707, -0.7767723>,
    <-0.4502156, -0.4653483, -0.7620741>,
    <-0.4264327, -0.4549989, -0.7817488>,
    <-0.2896989, -0.2904682, -0.9119774>,
    <-0.3022444, -0.3001576, -0.9047396>,
    <-0.3093356, -0.3111438, -0.8986106>,
    <-0.2980021, -0.3029834, -0.9052048>,
    <-0.2865889, -0.2865973, -0.9141820>,
    <-0.3226322, -0.3162147, -0.8921416>,
    <-0.3280062, -0.3309712, -0.8847994>,
    <-0.3733410, -0.3627793, -0.8538195>,
    <-0.3709032, -0.3772517, -0.8485942>,
    <-0.3158292, -0.3281014, -0.8902816>,
    <-0.3552403, -0.3791667, -0.8544220>,
    <-0.4080350, -0.4038030, -0.8188105>,
    <-0.4057117, -0.4171270, -0.8132669>,
    <-0.4003489, -0.4219255, -0.8134492>,
    <-0.3993988, -0.4131779, -0.8183915>,
    <-0.4063345, -0.4435207, -0.7988627>,
    <-0.3910001, -0.4322303, -0.8125859>,
    <-0.3775372, -0.4123821, -0.8290999>,
    <-0.2769096, 0.2732109, -0.9212366>,
    <-0.2600517, 0.2487597, -0.9330015>,
    <-0.2699042, 0.2473720, -0.9305691>,
    <-0.2742412, 0.2597666, -0.9259120>,
    <-0.2662002, 0.2662387, -0.9264202>,
    <-0.2840193, 0.2840441, -0.9157794>,
    <-0.2840193, 0.2840441, -0.9157794>,
    <-0.2866970, 0.2867105, -0.9141126>,
    <-0.2585924, 0.2282146, -0.9386416>,
    <-0.2744663, 0.2314845, -0.9333184>,
    <-0.2874153, 0.2217748, -0.9317770>,
    <-0.2898511, 0.2213494, -0.9311234>,
    <-0.2665454, 0.2317207, -0.9355528>,
    <-0.2768363, 0.2109043, -0.9374865>,
    <-0.2618414, 0.1994106, -0.9442852>,
    <-0.2233377, 0.2233898, -0.9487978>,
    <-0.2233377, 0.2233898, -0.9487978>,
    <-0.2662002, 0.2662387, -0.9264202>,
    <-0.2797840, -0.2738819, -0.9201683>,
    <-0.2763840, -0.2556969, -0.9264076>,
    <-0.2756187, -0.2447493, -0.9295870>,
    <-0.2689452, -0.2519527, -0.9296173>,
    <-0.2866003, -0.2865755, -0.9141853>,
    <-0.2834301, -0.2833540, -0.9161757>,
    <-0.2834301, -0.2833540, -0.9161757>,
    <-0.2621162, -0.2619765, -0.9287968>,
    <-0.2714026, -0.2267180, -0.9353820>,
    <-0.2781050, -0.2256650, -0.9336664>,
    <-0.2621162, -0.2619765, -0.9287968>,
    <-0.2129521, -0.2127488, -0.9536191>,
    <-0.2129521, -0.2127488, -0.9536191>,
    <-0.2728716, -0.2024444, -0.9405091>,
    <-0.2831690, -0.2101811, -0.9357560>,
    <-0.2863422, -0.2132149, -0.9341025>,
    <-0.2656013, -0.2266673, -0.9370581>,
    <-0.2742887, -0.2068585, -0.9391354>,
    <0.3337790, -0.2472325, 0.9096525>,
    <0.2954838, -0.2089620, 0.9322147>,
    <0.2755889, -0.1998014, 0.9402820>,
    <0.2914359, -0.2201936, 0.9309027>,
    <0.3277162, -0.2503579, 0.9110011>,
    <0.2769186, -0.2011442, 0.9396048>,
    <0.2486071, -0.1731315, 0.9530058>,
    <0.2432070, -0.1746212, 0.9541267>,
    <0.2534723, -0.1734275, 0.9516694>,
    <0.2927179, -0.2049632, 0.9339734>,
    <0.2287992, -0.1602063, 0.9602004>,
    <0.2287992, -0.1602063, 0.9602004>,
    <0.2367806, -0.1657948, 0.9573124>,
    <0.2606057, -0.1927402, 0.9460105>,
    <0.2367806, -0.1657948, 0.9573124>,
    <0.2634805, -0.1844901, 0.9468587>,
    <0.2634805, -0.1844901, 0.9468587>,
    <0.2304124, -0.1933379, 0.9536931>,
    <0.7785147, -0.5973646, 0.1925366>,
    <0.7881636, -0.5535588, 0.2690180>,
    <0.7463396, -0.5506113, 0.3739043>,
    <0.7385154, -0.5870814, 0.3315575>,
    <0.7885876, -0.5887214, 0.1775860>,
    <0.7952257, -0.5499740, 0.2552347>,
    <0.7303141, -0.4803754, 0.4856756>,
    <0.6689953, -0.4822439, 0.5655848>,
    <0.7597354, -0.4847654, 0.4333642>,
    <0.5519569, -0.3179284, 0.7708859>,
    <0.5721973, -0.3597485, 0.7370015>,
    <0.5439250, -0.3812807, 0.7475096>,
    <0.6483116, -0.5158087, 0.5600299>,
    <0.4847465, -0.3763870, 0.7895275>,
    <0.3359140, -0.2598753, 0.9053323>,
    <0.4176833, -0.2833676, 0.8632749>,
    <0.3400438, -0.2221943, 0.9137833>,
    <0.2797149, -0.2038705, 0.9381878>,
    <0.4280653, -0.2519835, 0.8679081>,
    <0.3416233, -0.1961532, 0.9191395>,
    <0.3840902, -0.2110877, 0.8988419>,
    <0.3178387, -0.1762694, 0.9316156>,
    <0.2745970, -0.1712178, 0.9461929>,
    <0.2727762, -0.1546158, 0.9495721>,
    <0.2927179, -0.2049632, 0.9339734>,
    <0.3458699, 0.2228706, 0.9114289>,
    <0.2936877, 0.2006016, 0.9346157>,
    <0.2778817, 0.1855771, 0.9425194>,
    <0.3040632, 0.1941894, 0.9326500>,
    <0.3299888, 0.2012659, 0.9222795>,
    <0.3953167, 0.2398824, 0.8866685>,
    <0.5771624, 0.3346523, 0.7449103>,
    <0.3614947, 0.2285936, 0.9039174>,
    <0.2866302, 0.1931482, 0.9383693>,
    <0.2482193, 0.1737754, 0.9529897>,
    <0.2482282, 0.1692704, 0.9537978>,
    <0.2543827, 0.1820145, 0.9498211>,
    <0.2349454, 0.1971444, 0.9518060>,
    <0.2320504, 0.1624851, 0.9590366>,
    <0.2320504, 0.1624851, 0.9590366>,
    <0.2401852, 0.1681811, 0.9560472>,
    <0.2732312, 0.1807568, 0.9448131>,
    <0.2401852, 0.1681811, 0.9560472>,
    <0.2681053, 0.1877312, 0.9449215>,
    <0.2681053, 0.1877312, 0.9449215>,
    <0.2655876, 0.1533387, 0.9518143>,
    <0.3081766, 0.1903026, 0.9321009>,
    <0.3855892, 0.2470579, 0.8889788>,
    <0.4312589, 0.3108407, 0.8469910>,
    <0.3403847, 0.2526005, 0.9057214>,
    <0.2971898, 0.2018710, 0.9332343>,
    <0.5491632, 0.3474930, 0.7600450>,
    <0.5635137, 0.3941513, 0.7260145>,
    <0.4057276, 0.3297588, 0.8524343>,
    <0.3181245, 0.2629393, 0.9108566>,
    <0.5558994, 0.4288754, 0.7120686>,
    <0.2704943, 0.2102441, 0.9394840>,
    <0.2349454, 0.1971444, 0.9518060>,
    <0.7676817, -0.5890735, 0.2523036>,
    <0.7905663, -0.5640838, 0.2383577>,
    <0.7781534, -0.5739690, 0.2550233>,
    <0.7600416, -0.5945408, 0.2624079>,
    <0.7698837, -0.5772436, 0.2721561>,
    <0.7884754, -0.5522995, 0.2706878>,
    <0.8041046, -0.5427154, 0.2426432>,
    <0.7827908, -0.5639375, 0.2630836>,
    <0.8062060, -0.5267616, 0.2693587>,
    <0.8457675, -0.4885309, 0.2145109>,
    <0.8231984, -0.5331113, 0.1952863>,
    <0.7999394, -0.5603065, 0.2148341>,
    <0.7611181, -0.5902300, 0.2689383>,
    <0.7755481, -0.5863572, 0.2339025>,
    <0.7917398, -0.5752405, 0.2055394>,
    <0.8132463, -0.5537008, 0.1790137>,
    <0.8111557, -0.5390762, 0.2267667>,
    <0.7927229, -0.5447675, 0.2735301>,
    <0.8322778, -0.5246922, 0.1789185>,
    <0.8207277, -0.5128722, 0.2517302>,
    <0.8484382, -0.4913493, 0.1967955>,
    <0.8267032, -0.4842859, 0.2864070>,
    <0.7836228, -0.4996753, 0.3691340>,
    <0.7573400, -0.4495360, 0.4736597>,
    <0.8277566, 0.5273492, 0.1916293>,
    <0.7903298, 0.5515641, 0.2667505>,
    <0.7738473, 0.5137924, 0.3703750>,
    <0.8050839, 0.4938419, 0.3285728>,
    <0.8331676, 0.4741357, 0.2846526>,
    <0.8497966, 0.4891607, 0.1963863>,
    <0.8459638, 0.4881905, 0.2145116>,
    <0.8229954, 0.5396765, 0.1772789>,
    <0.7891712, 0.5593191, 0.2537143>,
    <0.7076935, 0.5253962, 0.4723650>,
    <0.6896329, 0.4689657, 0.5517949>,
    <0.7204322, 0.5507833, 0.4214443>,
    <0.7163197, 0.4400403, 0.5415261>,
    <0.7741560, 0.4356723, 0.4592081>,
    <0.8113946, 0.5472843, 0.2052284>,
    <0.7984862, 0.5748466, 0.1788047>,
    <0.7841491, 0.5779735, 0.2259578>,
    <0.7833393, 0.5588024, 0.2722489>,
    <0.8162485, 0.5282304, 0.2339038>,
    <0.8001112, 0.5600606, 0.2148354>,
    <0.7777466, 0.6026620, 0.1786301>,
    <0.7628995, 0.5960200, 0.2504884>,
    <0.7825111, 0.5912184, 0.1952873>,
    <0.7395860, 0.5670218, 0.3626276>,
    <-0.2661691, 0.1992152, -0.9431158>,
    <-0.2229088, 0.1695118, -0.9599882>,
    <-0.2067730, 0.1505803, -0.9667319>,
    <-0.2262000, 0.1607488, -0.9607254>,
    <-0.2129726, 0.1552489, -0.9646452>,
    <-0.2702297, 0.2083281, -0.9399869>,
    <-0.1942309, 0.1437095, -0.9703721>,
    <-0.1793184, 0.1286538, -0.9753426>,
    <-0.1697312, 0.1424205, -0.9751450>,
    <-0.1946825, 0.1363176, -0.9713476>,
    <-0.1946825, 0.1363176, -0.9713476>,
    <-0.1738490, 0.1217299, -0.9772197>,
    <-0.1842271, 0.1285988, -0.9744346>,
    <-0.1738490, 0.1217299, -0.9772197>,
    <-0.1677564, 0.1174638, -0.9788054>,
    <-0.1677564, 0.1174638, -0.9788054>,
    <-0.1633459, 0.0878834, -0.9826467>,
    <-0.1905951, 0.1309085, -0.9729011>,
    <-0.7781417, 0.5970614, -0.1949699>,
    <-0.7326768, 0.5825973, -0.3518027>,
    <-0.7377059, 0.5442286, -0.3995063>,
    <-0.7851536, 0.5513018, -0.2821349>,
    <-0.7928560, 0.5482846, -0.2660140>,
    <-0.7886090, 0.5887795, -0.1772980>,
    <-0.6289044, 0.5002735, -0.5951518>,
    <-0.6466279, 0.4660891, -0.6038487>,
    <-0.4493318, 0.3485489, -0.8225659>,
    <-0.5050737, 0.3540360, -0.7871207>,
    <-0.7145035, 0.4698100, -0.5184238>,
    <-0.5347747, 0.3359841, -0.7753262>,
    <-0.5066167, 0.2896176, -0.8120722>,
    <-0.7473251, 0.4765124, -0.4630779>,
    <-0.2873156, 0.2223638, -0.9316674>,
    <-0.2195782, 0.1608619, -0.9622416>,
    <-0.2808184, 0.1844884, -0.9418625>,
    <-0.3657228, 0.2484231, -0.8969575>,
    <-0.2203961, 0.1373218, -0.9656957>,
    <-0.2861085, 0.1642738, -0.9440106>,
    <-0.1633459, 0.0878834, -0.9826467>,
    <-0.2458469, 0.1306902, -0.9604579>,
    <-0.2693052, 0.1449088, -0.9520904>,
    <-0.3756001, 0.2207250, -0.9001139>,
    <-0.3309497, 0.1785024, -0.9266117>,
    <-0.2800518, -0.1804608, -0.9428706>,
    <-0.2364881, -0.1508886, -0.9598469>,
    <-0.2124066, -0.1418520, -0.9668306>,
    <-0.2285599, -0.1562650, -0.9609067>,
    <-0.2228364, -0.1494172, -0.9633371>,
    <-0.2977017, -0.1873725, -0.9360904>,
    <-0.5276736, -0.3059649, -0.7924305>,
    <-0.3300652, -0.2011165, -0.9222847>,
    <-0.2603816, -0.1595054, -0.9522392>,
    <-0.2046356, -0.1352907, -0.9694435>,
    <-0.1843699, -0.1257251, -0.9747825>,
    <-0.2334832, -0.1445165, -0.9615615>,
    <-0.1957974, -0.1130451, -0.9741069>,
    <-0.1983733, -0.1389039, -0.9702339>,
    <-0.1983733, -0.1389039, -0.9702339>,
    <-0.1766721, -0.1237084, -0.9764646>,
    <-0.1853174, -0.1298279, -0.9740648>,
    <-0.1766721, -0.1237084, -0.9764646>,
    <-0.1704169, -0.1193284, -0.9781200>,
    <-0.1704169, -0.1193284, -0.9781200>,
    <-0.1732072, -0.1453396, -0.9741025>,
    <-0.1901988, -0.1357296, -0.9723178>,
    <-0.3236969, -0.2061045, -0.9234399>,
    <-0.2340352, -0.1575678, -0.9593747>,
    <-0.2779391, -0.2062626, -0.9381928>,
    <-0.3724445, -0.2684530, -0.8883794>,
    <-0.5184721, -0.3626531, -0.7743832>,
    <-0.4999659, -0.3158900, -0.8063793>,
    <-0.2058909, -0.1600325, -0.9654007>,
    <-0.2560604, -0.2130376, -0.9428935>,
    <-0.1732072, -0.1453396, -0.9741025>,
    <-0.3480473, -0.2841682, -0.8933709>,
    <-0.5130835, -0.3963204, -0.7613642>,
    <0.7363543, -0.5651251, 0.3720428>,
    <0.7604232, -0.5427156, 0.3566739>,
    <0.7468785, -0.5509873, 0.3722708>,
    <0.7284813, -0.5698840, 0.3801937>,
    <0.7358742, -0.5517610, 0.3924907>,
    <0.7545206, -0.5285821, 0.3889726>,
    <0.7735497, -0.5222349, 0.3590147>,
    <0.7509566, -0.5410862, 0.3785365>,
    <0.7723064, -0.5047373, 0.3857242>,
    <0.8176822, -0.4724071, 0.3289792>,
    <0.7979414, -0.5168689, 0.3100580>,
    <0.7733025, -0.5417290, 0.3294434>,
    <0.7294853, -0.5657215, 0.3844612>,
    <0.7477612, -0.5654029, 0.3480989>,
    <0.7718208, -0.5607973, 0.2996650>,
    <0.7936436, -0.5404421, 0.2793780>,
    <0.7977393, -0.5302524, 0.2871313>,
    <0.7853781, -0.5400007, 0.3026227>,
    <0.8136734, -0.5131048, 0.2732383>,
    <0.8142220, -0.5086839, 0.2797913>,
    <0.8315002, -0.4793753, 0.2807255>,
    <0.8334464, -0.4814992, 0.2711560>,
    <0.8072004, -0.5147423, 0.2889082>,
    <0.8353037, -0.4835618, 0.2616024>,
    <0.8161105, 0.5199096, 0.2523045>,
    <0.8004549, 0.5499611, 0.2383585>,
    <0.8054984, 0.5349157, 0.2550245>,
    <0.8186350, 0.5108602, 0.2624093>,
    <0.8337137, 0.4810362, 0.2711560>,
    <0.8309013, 0.4804127, 0.2807251>,
    <0.8179578, 0.4719302, 0.3289786>,
    <0.8057473, 0.5260251, 0.2721560>,
    <0.7886662, 0.5520269, 0.2706878>,
    <0.7850056, 0.5699913, 0.2426440>,
    <0.7976580, 0.5427044, 0.2630849>,
    <0.7707327, 0.5774227, 0.2693587>,
    <0.8149523, 0.5133461, 0.2689398>,
    <0.8364285, 0.4816132, 0.2616028>,
    <0.7909555, 0.5334706, 0.2996641>,
    <0.7792918, 0.5609394, 0.2793766>,
    <0.7711174, 0.5682731, 0.2871301>,
    <0.7760499, 0.5533231, 0.3026220>,
    <0.7870545, 0.5092868, 0.3480978>,
    <0.7735440, 0.5413849, 0.3294420>,
    <0.7604537, 0.5891111, 0.2732366>,
    <0.7564871, 0.5911387, 0.2797899>,
    <0.7586102, 0.5730406, 0.3100566>,
    <0.7597784, 0.5824683, 0.2889074>,
    <-0.7683910, 0.5895907, -0.2489136>,
    <-0.7600146, 0.5945695, -0.2624212>,
    <-0.7781621, 0.5739518, -0.2550354>,
    <-0.7912120, 0.5644462, -0.2353380>,
    <-0.7884811, 0.5522837, -0.2707033>,
    <-0.7703704, 0.5776437, -0.2699209>,
    <-0.7603653, 0.5897055, -0.2721985>,
    <-0.7821510, 0.5634554, -0.2660035>,
    <-0.7751145, 0.5860489, -0.2361022>,
    <-0.7999478, 0.5602942, -0.2148344>,
    <-0.8041498, 0.5426447, -0.2426518>,
    <-0.8236007, 0.5333141, -0.1930230>,
    <-0.8457773, 0.4885140, -0.2145109>,
    <-0.8057243, 0.5263718, -0.2715529>,
    <-0.7913547, 0.5750289, -0.2076041>,
    <-0.7897997, 0.5428140, -0.2856035>,
    <-0.8100272, 0.5383091, -0.2325494>,
    <-0.8134952, 0.5538527, -0.1774058>,
    <-0.7752822, 0.4943417, -0.3931460>,
    <-0.8186518, 0.5114869, -0.2611330>,
    <-0.7399517, 0.4393178, -0.5093833>,
    <-0.8229083, 0.4820937, -0.3006786>,
    <-0.8325267, 0.5247475, -0.1775930>,
    <-0.8481947, 0.4911362, -0.1983710>,
    <-0.8273614, -0.5271133, -0.1939708>,
    <-0.7990176, -0.4899763, -0.3485600>,
    <-0.7650910, -0.5079914, -0.3957027>,
    <-0.7872585, -0.5495636, -0.2796494>,
    <-0.7868204, -0.5577045, -0.2643470>,
    <-0.8230618, -0.5396801, -0.1769595>,
    <-0.8459542, -0.4882076, -0.2145105>,
    <-0.8494983, -0.4890607, -0.1979196>,
    <-0.8294417, -0.4719844, -0.2987594>,
    <-0.6925036, -0.4250330, -0.5829114>,
    <-0.6651228, -0.4523080, -0.5941626>,
    <-0.7578842, -0.4262619, -0.4938748>,
    <-0.6909618, -0.5133343, -0.5089791>,
    <-0.7084016, -0.5418579, -0.4522799>,
    <-0.8110702, -0.5469991, -0.2072610>,
    <-0.7805470, -0.5567545, -0.2842019>,
    <-0.7830617, -0.5771899, -0.2316595>,
    <-0.7987169, -0.5750309, -0.1771743>,
    <-0.8001027, -0.5600731, -0.2148343>,
    <-0.8158106, -0.5279288, -0.2361021>,
    <-0.7319937, -0.5612172, -0.3862906>,
    <-0.7609236, -0.5945713, -0.2597696>,
    <-0.7778877, -0.6028803, -0.1772739>,
    <-0.7828395, -0.5915273, -0.1930229>,
    <0.4096693, 0.2763832, 0.8693580>,
    <0.3655854, 0.2492679, 0.8967792>,
    <0.3737317, 0.2658040, 0.8886354>,
    <0.3963088, 0.2781890, 0.8749573>,
    <0.4281905, 0.2997080, 0.8525421>,
    <0.4468842, 0.3074702, 0.8400932>,
    <0.4582053, 0.3144829, 0.8313534>,
    <0.4116120, 0.2715402, 0.8699664>,
    <0.4116120, 0.2715402, 0.8699664>,
    <0.3542636, 0.2278799, 0.9069554>,
    <0.3048393, 0.2138572, 0.9280830>,
    <0.3504287, 0.2619813, 0.8992027>,
    <0.3542636, 0.2278799, 0.9069554>,
    <0.2792303, 0.1770995, 0.9437511>,
    <0.2792303, 0.1770995, 0.9437511>,
    <0.2737481, 0.2225593, 0.9356972>,
    <0.3908373, 0.2931873, 0.8725178>,
    <0.4179899, 0.3029900, 0.8564354>,
    <-0.3264450, 0.2290532, -0.9170432>,
    <-0.3221836, 0.2272538, -0.9189959>,
    <-0.3141622, 0.2228033, -0.9228547>,
    <-0.3165739, 0.2237417, -0.9218029>,
    <-0.3293493, 0.2332523, -0.9149439>,
    <-0.3300661, 0.2316110, -0.9151026>,
    <-0.3321441, 0.2325624, -0.9141089>,
    <-0.3311939, 0.2318940, -0.9146233>,
    <-0.3311939, 0.2318940, -0.9146233>,
    <-0.3247001, 0.2273448, -0.9180872>,
    <-0.3075118, 0.2201682, -0.9257227>,
    <-0.3041582, 0.2199871, -0.9268729>,
    <-0.3247001, 0.2273448, -0.9180872>,
    <-0.3065477, 0.2146329, -0.9273409>,
    <-0.3065477, 0.2146329, -0.9273409>,
    <-0.2618414, 0.1994106, -0.9442852>,
    <-0.3047885, 0.2197918, -0.9267122>,
    <-0.3268628, 0.2369381, -0.9148885>,
    <-0.7374354, 0.5659200, -0.3686782>,
    <-0.7284658, 0.5699167, -0.3801743>,
    <-0.7468991, 0.5509712, -0.3722532>,
    <-0.7614038, 0.5433064, -0.3536700>,
    <-0.7545410, 0.5285702, -0.3889492>,
    <-0.7366129, 0.5523464, -0.3902754>,
    <-0.7284281, 0.5649554, -0.3875796>,
    <-0.7500375, 0.5403955, -0.3813351>,
    <-0.7471192, 0.5649306, -0.3502376>,
    <-0.7733145, 0.5417118, -0.3294435>,
    <-0.7736057, 0.5221612, -0.3590012>,
    <-0.7985829, 0.5172168, -0.3078184>,
    <-0.8176958, 0.4723833, -0.3289795>,
    <-0.7716116, 0.5041992, -0.3878128>,
    <-0.7717874, 0.5608375, -0.2996758>,
    <-0.7845917, 0.5395130, -0.3055185>,
    <-0.7977481, 0.5302322, -0.2871441>,
    <-0.7943772, 0.5409156, -0.2763607>,
    <-0.8063809, 0.5141942, -0.2921544>,
    <-0.8142656, 0.5086071, -0.2798042>,
    <-0.8349195, 0.4833643, -0.2631890>,
    <-0.8334569, 0.4814740, -0.2711686>,
    <-0.8145353, 0.5135328, -0.2698449>,
    <-0.8319406, 0.4795429, -0.2791297>,
    <-0.8168393, -0.5203993, -0.2489139>,
    <-0.8186529, -0.5108252, -0.2624214>,
    <-0.8054854, -0.5349300, -0.2550354>,
    <-0.8010164, -0.5504441, -0.2353381>,
    <-0.7886534, -0.5520376, -0.2707034>,
    <-0.8062897, -0.5263455, -0.2699211>,
    <-0.8179437, -0.4719535, -0.3289801>,
    <-0.8312666, -0.4807101, -0.2791301>,
    <-0.8336972, -0.4810578, -0.2711687>,
    <-0.8142022, -0.5128184, -0.2721985>,
    <-0.7969863, -0.5422683, -0.2660035>,
    <-0.8360656, -0.4813793, -0.2631887>,
    <-0.7849547, -0.5700582, -0.2426517>,
    <-0.7702017, -0.5771034, -0.2715528>,
    <-0.7909817, -0.5334251, -0.2996759>,
    <-0.7753226, -0.5527507, -0.3055185>,
    <-0.7711012, -0.5682879, -0.2871441>,
    <-0.7799874, -0.5614663, -0.2763608>,
    <-0.7735317, -0.5414016, -0.3294436>,
    <-0.7863908, -0.5088447, -0.3502379>,
    <-0.7589830, -0.5818854, -0.2921543>,
    <-0.7564296, -0.5912055, -0.2798041>,
    <-0.7611505, -0.5897742, -0.2698449>,
    <-0.7591563, -0.5735238, -0.3078185>,
    <0.6859958, -0.5265482, 0.5021521>,
    <0.7117525, -0.5081412, 0.4849752>,
    <0.6975998, -0.5147027, 0.4984331>,
    <0.6789164, -0.5310809, 0.5069769>,
    <0.6819644, -0.5113096, 0.5229598>,
    <0.7013376, -0.4913777, 0.5164044>,
    <0.7251206, -0.4897071, 0.4841354>,
    <0.7017420, -0.5056921, 0.5018303>,
    <0.7198157, -0.4705693, 0.5103232>,
    <0.7724680, -0.4463664, 0.4517192>,
    <0.7562571, -0.4899843, 0.4335787>,
    <0.7304342, -0.5117635, 0.4522875>,
    <0.6807957, -0.5279227, 0.5077547>,
    <0.7040378, -0.5323621, 0.4700227>,
    <0.7341414, -0.5333930, 0.4201527>,
    <0.7571372, -0.5156561, 0.4010512>,
    <0.7607861, -0.5057679, 0.4066981>,
    <0.7475963, -0.5140138, 0.4205824>,
    <0.7770968, -0.4902097, 0.3947340>,
    <0.7776482, -0.4859980, 0.3988349>,
    <0.7934687, -0.4575983, 0.4012620>,
    <0.7974284, -0.4607923, 0.3895875>,
    <0.7706244, -0.4915015, 0.4056653>,
    <0.8012008, -0.4638715, 0.3780219>,
    <0.7828921, 0.4986628, 0.3720422>,
    <0.7700661, 0.5289447, 0.3566732>,
    <0.7732064, 0.5133878, 0.3722699>,
    <0.7846713, 0.4896371, 0.3801927>,
    <0.7977720, 0.4601972, 0.3895874>,
    <0.7930260, 0.4583649, 0.4012622>,
    <0.7727984, 0.4457936, 0.4517196>,
    <0.7701695, 0.5027823, 0.3924907>,
    <0.7547659, 0.5282318, 0.3889724>,
    <0.7553100, 0.5482845, 0.3590138>,
    <0.7652973, 0.5206064, 0.3785354>,
    <0.7384423, 0.5531004, 0.3857238>,
    <0.7811033, 0.4920042, 0.3844600>,
    <0.8023249, 0.4619247, 0.3780215>,
    <0.7523164, 0.5074360, 0.4201532>,
    <0.7435141, 0.5351112, 0.4010521>,
    <0.7354703, 0.5419221, 0.4066988>,
    <0.7387079, 0.5267076, 0.4205827>,
    <0.7410516, 0.4795004, 0.4700234>,
    <0.7307233, 0.5113499, 0.4522884>,
    <0.7264289, 0.5625702, 0.3947351>,
    <0.7226598, 0.5645289, 0.3988357>,
    <0.7190895, 0.5430644, 0.4335796>,
    <0.7254293, 0.5560466, 0.4056656>,
    <-0.3232943, -0.2266688, -0.9187503>,
    <-0.3057567, -0.2156508, -0.9273659>,
    <-0.3071467, -0.2169553, -0.9266020>,
    <-0.3215792, -0.2263002, -0.9194428>,
    <-0.3264550, -0.2286099, -0.9171503>,
    <-0.3314215, -0.2320882, -0.9144916>,
    <-0.3314215, -0.2320882, -0.9144916>,
    <-0.3320471, -0.2325274, -0.9141530>,
    <-0.3271870, -0.2298539, -0.9165784>,
    <-0.3224597, -0.2291298, -0.9184330>,
    <-0.2876823, -0.2063793, -0.9352254>,
    <-0.2962865, -0.2123206, -0.9312005>,
    <-0.3169022, -0.2317891, -0.9196993>,
    <-0.3091397, -0.2197380, -0.9252826>,
    <-0.2728716, -0.2024444, -0.9405091>,
    <-0.3122400, -0.2186560, -0.9244976>,
    <-0.3122400, -0.2186560, -0.9244976>,
    <-0.3264550, -0.2286099, -0.9171503>,
    <-0.6874643, 0.5276364, -0.4989916>,
    <-0.6789009, 0.5311125, -0.5069646>,
    <-0.6976231, 0.5146844, -0.4984195>,
    <-0.7130860, 0.5089761, -0.4821325>,
    <-0.7013566, 0.4913624, -0.5163932>,
    <-0.6829532, 0.5120836, -0.5209082>,
    <-0.6794208, 0.5269088, -0.5106412>,
    <-0.7005312, 0.5047869, -0.5044267>,
    <-0.7031836, 0.5317260, -0.4720172>,
    <-0.7304568, 0.5117492, -0.4522671>,
    <-0.7251833, 0.4896303, -0.4841192>,
    <-0.7571678, 0.4904996, -0.4314013>,
    <-0.7724931, 0.4463435, -0.4516988>,
    <-0.7188902, 0.4698745, -0.5122645>,
    <-0.7341206, 0.5334408, -0.4201284>,
    <-0.7465270, 0.5133285, -0.4233099>,
    <-0.7608096, 0.5057513, -0.4066747>,
    <-0.7582214, 0.5163629, -0.3980826>,
    <-0.7694826, 0.4907410, -0.4087418>,
    <-0.7777076, 0.4859211, -0.3988127>,
    <-0.8006571, 0.4635757, -0.3795336>,
    <-0.7974528, 0.4607676, -0.3895668>,
    <-0.7783626, 0.4908818, -0.3913908>,
    <-0.7941093, 0.4578718, -0.3996797>,
    <-0.7840086, -0.4994065, -0.3686783>,
    <-0.7846964, -0.4896109, -0.3801746>,
    <-0.7731981, -0.5134123, -0.3722534>,
    <-0.7709564, -0.5296638, -0.3536701>,
    <-0.7547617, -0.5282550, -0.3889491>,
    <-0.7709723, -0.5032762, -0.3902753>,
    <-0.7727917, -0.4458272, -0.4516981>,
    <-0.7935834, -0.4587830, -0.3996792>,
    <-0.7977628, -0.4602306, -0.3895668>,
    <-0.7800214, -0.4912722, -0.3875799>,
    <-0.7643335, -0.5199785, -0.3813353>,
    <-0.8017968, -0.4616015, -0.3795340>,
    <-0.7552597, -0.5483619, -0.3590013>,
    <-0.7376990, -0.5526314, -0.3878128>,
    <-0.7523545, -0.5074003, -0.4201281>,
    <-0.7376983, -0.5259373, -0.4233097>,
    <-0.7354631, -0.5419502, -0.4066743>,
    <-0.7445495, -0.5358887, -0.3980822>,
    <-0.7307181, -0.5113765, -0.4522667>,
    <-0.7401622, -0.4789156, -0.4720168>,
    <-0.7243243, -0.5552338, -0.4087416>,
    <-0.7226083, -0.5646114, -0.3988124>,
    <-0.7274938, -0.5635303, -0.3913903>,
    <-0.7198856, -0.5437444, -0.4314009>,
    <0.5989033, -0.4598499, 0.6556317>,
    <0.6328288, -0.4519689, 0.6286906>,
    <0.6201729, -0.4576253, 0.6371536>,
    <0.5987970, -0.4684191, 0.6496351>,
    <0.5882880, -0.4406916, 0.6780177>,
    <0.6173504, -0.4322490, 0.6572969>,
    <0.6506610, -0.4396303, 0.6191652>,
    <0.6276446, -0.4523442, 0.6335984>,
    <0.6406790, -0.4189316, 0.6434491>,
    <0.7029212, -0.4062401, 0.5838413>,
    <0.6909858, -0.4478175, 0.5674488>,
    <0.6645297, -0.4656381, 0.5844497>,
    <0.6072268, -0.4707650, 0.6400437>,
    <0.6379483, -0.4823644, 0.6002888>,
    <0.6757139, -0.4908540, 0.5499756>,
    <0.6991792, -0.4762400, 0.5332391>,
    <0.7032661, -0.4675895, 0.5355156>,
    <0.6899923, -0.4743451, 0.5467242>,
    <0.7187832, -0.4536191, 0.5268591>,
    <0.7205843, -0.4505164, 0.5270609>,
    <0.7336052, -0.4232309, 0.5316944>,
    <0.7410541, -0.4282963, 0.5171084>,
    <0.7147258, -0.4559153, 0.5303850>,
    <0.7480717, -0.4331177, 0.5027900>,
    <0.7294178, 0.4645351, 0.5021523>,
    <0.7209301, 0.4950339, 0.4849756>,
    <0.7222553, 0.4794905, 0.4984336>,
    <0.7312557, 0.4563322, 0.5069774>,
    <0.7414425, 0.4276236, 0.5171084>,
    <0.7333315, 0.4237054, 0.5316942>,
    <0.7032751, 0.4056277, 0.5838410>,
    <0.7137195, 0.4659588, 0.5229597>,
    <0.7016156, 0.4909807, 0.5164044>,
    <0.7081798, 0.5139006, 0.4841359>,
    <0.7152048, 0.4864646, 0.5018310>,
    <0.6883819, 0.5154613, 0.5103234>,
    <0.7289307, 0.4591782, 0.5077553>,
    <0.7491266, 0.4312902, 0.5027903>,
    <0.6923598, 0.4670816, 0.5499752>,
    <0.6866528, 0.4941301, 0.5332385>,
    <0.6799217, 0.5009292, 0.5355151>,
    <0.6817300, 0.4861452, 0.5467240>,
    <0.6714657, 0.4344972, 0.6002882>,
    <0.6648395, 0.4651963, 0.5844491>,
    <0.6721011, 0.5202887, 0.5268584>,
    <0.6698015, 0.5230423, 0.5270605>,
    <0.6571421, 0.4961519, 0.5674483>,
    <0.6728709, 0.5156905, 0.5303849>,
    <-0.6094807, 0.4678290, -0.6400541>,
    <-0.6035362, 0.4720558, -0.6425787>,
    <-0.6225700, 0.4593579, -0.6335589>,
    <-0.6376507, 0.4553133, -0.6213625>,
    <-0.6205831, 0.4348064, -0.6525488>,
    <-0.6001987, 0.4499486, -0.6612925>,
    <-0.6065621, 0.4702954, -0.6410184>,
    <-0.6266744, 0.4516112, -0.6350800>,
    <-0.6368791, 0.4815667, -0.6020619>,
    <-0.6645518, 0.4656216, -0.5844377>,
    <-0.6512140, 0.4398759, -0.6184088>,
    <-0.6921624, 0.4485000, -0.5654723>,
    <-0.7029460, 0.4062148, -0.5838292>,
    <-0.6399542, 0.4184241, -0.6444997>,
    <-0.6756885, 0.4909015, -0.5499643>,
    <-0.6886199, 0.4734525, -0.5492224>,
    <-0.7032883, 0.4675688, -0.5355044>,
    <-0.7006214, 0.4771878, -0.5304917>,
    <-0.7132431, 0.4549335, -0.5332164>,
    <-0.7206453, 0.4504324, -0.5270493>,
    <-0.7473547, 0.4327187, -0.5041979>,
    <-0.7410797, 0.4282672, -0.5170958>,
    <-0.7204670, 0.4545458, -0.5237513>,
    <-0.7344404, 0.4236093, -0.5302381>,
    <-0.7309429, -0.4655430, -0.4989912>,
    <-0.7312805, -0.4563072, -0.5069641>,
    <-0.7222464, -0.4795190, -0.4984191>,
    <-0.7221709, -0.4960017, -0.4821322>,
    <-0.7016077, -0.4910039, -0.5163931>,
    <-0.7147850, -0.4666232, -0.5209080>,
    <-0.7032651, -0.4056615, -0.5838295>,
    <-0.7340765, -0.4242394, -0.5302383>,
    <-0.7414302, -0.4276603, -0.5170957>,
    <-0.7275081, -0.4582335, -0.5106407>,
    <-0.7139405, -0.4856368, -0.5044263>,
    <-0.7484229, -0.4308690, -0.5041974>,
    <-0.7081294, -0.5139861, -0.4841189>,
    <-0.6874125, -0.5148293, -0.5122644>,
    <-0.6923956, -0.4670413, -0.5499643>,
    <-0.6804217, -0.4851607, -0.5492225>,
    <-0.6799097, -0.5009568, -0.5355046>,
    <-0.6880364, -0.4951608, -0.5304919>,
    <-0.6648313, -0.4652224, -0.5844378>,
    <-0.6703502, -0.4337651, -0.6020619>,
    <-0.6714411, -0.5146328, -0.5332165>,
    <-0.6697430, -0.5231280, -0.5270496>,
    <-0.6735474, -0.5215535, -0.5237517>,
    <-0.6581856, -0.4970237, -0.5654725>,
    <0.3190375, -0.2448288, 0.9155730>,
    <0.4148605, -0.2921934, 0.8616924>,
    <0.3989298, -0.2930007, 0.8689106>,
    <0.3562489, -0.2782280, 0.8920067>,
    <0.2667150, -0.2309423, 0.9356969>,
    <0.3946588, -0.2716907, 0.8777406>,
    <0.4544453, -0.3056503, 0.8366943>,
    <0.4858620, -0.3273147, 0.8104340>,
    <0.4432202, -0.3185112, 0.8379179>,
    <0.4867101, -0.3204039, 0.8126836>,
    <0.5404672, -0.3205472, 0.7779104>,
    <0.5575399, -0.3643776, 0.7459076>,
    <0.5183235, -0.3641697, 0.7737708>,
    <0.4103169, -0.3166051, 0.8552200>,
    <0.4848250, -0.3677451, 0.7935416>,
    <0.5514251, -0.3534017, 0.7556703>,
    <0.5920982, -0.3812875, 0.7099574>,
    <0.5424964, -0.3552020, 0.7612682>,
    <0.5059332, -0.3326369, 0.7958544>,
    <0.2667150, -0.2309423, 0.9356969>,
    <0.6671845, -0.4067148, 0.6240576>,
    <0.6671845, -0.4067148, 0.6240576>,
    <0.6619325, -0.4156825, 0.6237416>,
    <0.5537944, -0.3672898, 0.7472683>,
    <0.5123477, -0.3408660, 0.7882324>,
    <0.6619325, -0.4156825, 0.6237416>,
    <0.5896009, -0.3869777, 0.7089563>,
    <0.5896009, -0.3869777, 0.7089563>,
    <0.4987745, -0.3450851, 0.7950725>,
    <0.4850616, -0.3349004, 0.8078100>,
    <0.4630701, -0.3150941, 0.8284213>,
    <0.4773620, -0.3168773, 0.8195818>,
    <0.4516282, -0.2981241, 0.8409245>,
    <0.5677136, -0.4124845, 0.7124310>,
    <0.5828425, -0.3988753, 0.7079499>,
    <0.6019478, -0.4016990, 0.6901425>,
    <0.5977770, -0.4108993, 0.6883491>,
    <0.6018399, -0.3832849, 0.7006293>,
    <0.6208359, -0.3902630, 0.6798953>,
    <0.6203584, -0.3598192, 0.6969115>,
    <0.6455232, -0.3741197, 0.6658335>,
    <0.6283702, -0.4013638, 0.6663768>,
    <0.6657997, -0.3857067, 0.6387027>,
    <0.6334881, 0.4034008, 0.6602731>,
    <0.6397576, 0.4392262, 0.6307064>,
    <0.6409728, 0.4254809, 0.6388427>,
    <0.6431270, 0.4012761, 0.6522003>,
    <0.6455831, 0.3708971, 0.6675761>,
    <0.6173571, 0.3535732, 0.7027490>,
    <0.5220086, 0.2922076, 0.8013250>,
    <0.6144686, 0.4028981, 0.6783078>,
    <0.6171773, 0.4326299, 0.6572089>,
    <0.6353287, 0.4608323, 0.6196701>,
    <0.6394542, 0.4348936, 0.6340078>,
    <0.6126889, 0.4587591, 0.6435467>,
    <0.6496539, 0.4093359, 0.6406199>,
    <0.6666666, 0.3835244, 0.6391124>,
    <0.5874082, 0.3979805, 0.7046723>,
    <0.5819486, 0.4175600, 0.6978392>,
    <0.5873990, 0.4316296, 0.6845862>,
    <0.5928689, 0.4234608, 0.6849726>,
    <0.5220320, 0.3402405, 0.7821247>,
    <0.5348747, 0.3746648, 0.7573212>,
    <0.5716005, 0.4383012, 0.6936606>,
    <0.5815017, 0.4518225, 0.6765443>,
    <0.5458589, 0.4076029, 0.7320505>,
    <0.5927617, 0.4538638, 0.6653128>,
    <-0.4636092, 0.3551877, -0.8117316>,
    <-0.4771478, 0.3731298, -0.7956785>,
    <-0.5004720, 0.3692958, -0.7830379>,
    <-0.5075522, 0.3622198, -0.7817849>,
    <-0.4938287, 0.3436151, -0.7987877>,
    <-0.4631576, 0.3408565, -0.8181088>,
    <-0.4975984, 0.3856078, -0.7769829>,
    <-0.5165012, 0.3722422, -0.7711434>,
    <-0.5392578, 0.4076777, -0.7368853>,
    <-0.5657056, 0.3963934, -0.7230833>,
    <-0.5368433, 0.3628326, -0.7616769>,
    <-0.5926863, 0.3841704, -0.7079096>,
    <-0.5985588, 0.3459281, -0.7225380>,
    <-0.5223830, 0.3411648, -0.7814874>,
    <-0.5874798, 0.4266569, -0.6876274>,
    <-0.6029178, 0.4144044, -0.6817324>,
    <-0.6162578, 0.4097459, -0.6725582>,
    <-0.6114615, 0.4164966, -0.6727893>,
    <-0.6299766, 0.4018647, -0.6645557>,
    <-0.6341981, 0.3965946, -0.6637058>,
    <-0.6671268, 0.3862194, -0.6370059>,
    <-0.6555293, 0.3788796, -0.6532470>,
    <-0.6305036, 0.3980062, -0.6663754>,
    <-0.6430360, 0.3710496, -0.6699454>,
    <-0.6480702, -0.4127175, -0.6400541>,
    <-0.6500090, -0.4056860, -0.6425786>,
    <-0.6445868, -0.4279147, -0.6335589>,
    <-0.6459440, -0.4434693, -0.6213626>,
    <-0.6208363, -0.4344446, -0.6525490>,
    <-0.6280933, -0.4101107, -0.6612927>,
    <-0.5988619, -0.3454031, -0.7225380>,
    <-0.6428564, -0.3713606, -0.6699455>,
    <-0.6558839, -0.3782651, -0.6532471>,
    <-0.6493897, -0.4091314, -0.6410183>,
    <-0.6387111, -0.4344211, -0.6350799>,
    <-0.6680390, -0.3846389, -0.6370061>,
    <-0.6360765, -0.4614945, -0.6184089>,
    <-0.6120672, -0.4582505, -0.6444999>,
    <-0.6018561, -0.4061249, -0.6876277>,
    <-0.5956227, -0.4248225, -0.6817326>,
    <-0.5958077, -0.4389513, -0.6725585>,
    <-0.6005107, -0.4321353, -0.6727897>,
    <-0.5659705, -0.3960145, -0.7230836>,
    <-0.5675285, -0.3673023, -0.7368856>,
    <-0.5930938, -0.4545382, -0.6645561>,
    <-0.5895854, -0.4603077, -0.6637062>,
    <-0.5896483, -0.4563532, -0.6663757>,
    <-0.5637126, -0.4255487, -0.7079099>,
    <0.5078940, 0.3757837, 0.7751324>,
    <0.5228677, 0.3833123, 0.7613679>,
    <0.4939211, 0.3580701, 0.7923558>,
    <0.4778267, 0.3471685, 0.8069422>,
    <0.4592828, 0.3309329, 0.8243438>,
    <0.4218537, 0.2988968, 0.8559790>,
    <0.3555387, 0.2149576, 0.9096073>,
    <0.5672114, 0.4332337, 0.7004140>,
    <0.5672114, 0.4332337, 0.7004140>,
    <0.5591876, 0.4168334, 0.7166304>,
    <0.4925120, 0.3511676, 0.7963123>,
    <0.4676667, 0.3338366, 0.8184381>,
    <0.5591876, 0.4168334, 0.7166304>,
    <0.5133466, 0.3687522, 0.7749175>,
    <0.5133466, 0.3687522, 0.7749175>,
    <0.4582053, 0.3144829, 0.8313534>,
    <0.4485906, 0.3230841, 0.8332966>,
    <0.4740440, 0.3481391, 0.8087531>,
    <0.4316261, -0.3055240, 0.8487367>,
    <0.3834576, -0.2699770, 0.8832172>,
    <0.4029074, -0.2722916, 0.8737980>,
    <0.4258552, -0.2905075, 0.8568855>,
    <0.4987745, -0.3450851, 0.7950725>,
    <0.4272865, -0.3090525, 0.8496545>,
    <0.4272865, -0.3090525, 0.8496545>,
    <0.3576688, -0.2659640, 0.8951738>,
    <0.3233947, -0.2226015, 0.9197089>,
    <0.3874244, -0.2499508, 0.8873708>,
    <0.3576688, -0.2659640, 0.8951738>,
    <0.2787543, -0.2104699, 0.9370157>,
    <0.2787543, -0.2104699, 0.9370157>,
    <0.2595650, -0.1681183, 0.9509796>,
    <0.2941262, -0.1835543, 0.9379753>,
    <0.3795579, -0.2233163, 0.8978116>,
    <0.4327671, -0.2772167, 0.8578249>,
    <0.4565892, -0.2622602, 0.8501446>,
    <0.3812795, 0.2507797, 0.8897952>,
    <0.4466617, 0.3128641, 0.8382180>,
    <0.4410744, 0.2989624, 0.8462121>,
    <0.4134755, 0.2670380, 0.8704761>,
    <0.3947908, 0.2378211, 0.8874578>,
    <0.3401280, 0.1998277, 0.9189025>,
    <0.3555387, 0.2149576, 0.9096073>,
    <0.4947477, 0.3590887, 0.7913786>,
    <0.4735185, 0.3258457, 0.8182938>,
    <0.4540910, 0.2936603, 0.8411688>,
    <0.4382139, 0.2628571, 0.8595782>,
    <-0.3250453, 0.2273306, -0.9179686>,
    <-0.3268667, 0.2288749, -0.9169375>,
    <-0.3120864, 0.2185264, -0.9245801>,
    <-0.3044732, 0.2121543, -0.9285939>,
    <-0.2978662, 0.2056311, -0.9321972>,
    <-0.3209396, 0.2243224, -0.9201507>,
    <-0.3321384, 0.2325738, -0.9141081>,
    <-0.3321489, 0.2325762, -0.9141036>,
    <-0.3321489, 0.2325762, -0.9141036>,
    <-0.3321572, 0.2325783, -0.9141001>,
    <-0.3248911, 0.2275583, -0.9179668>,
    <-0.3091459, 0.2160321, -0.9261528>,
    <-0.3321572, 0.2325783, -0.9141001>,
    <-0.3321615, 0.2325780, -0.9140986>,
    <-0.3321615, 0.2325780, -0.9140986>,
    <-0.3321441, 0.2325624, -0.9141089>,
    <-0.3290180, 0.2297143, -0.9159577>,
    <-0.3279378, 0.2266546, -0.9171066>,
    <-0.2908897, 0.2013545, -0.9353286>,
    <-0.3283575, 0.2207634, -0.9183926>,
    <-0.3744908, 0.2134311, -0.9023324>,
    <-0.2792955, 0.1872102, -0.9417783>,
    <-0.3365024, 0.2351567, -0.9118484>,
    <-0.3464781, 0.2448687, -0.9055343>,
    <-0.3598408, 0.2507736, -0.8986808>,
    <-0.3516779, 0.2421768, -0.9042528>,
    <-0.3321441, 0.2325624, -0.9141089>,
    <-0.3650446, 0.2618320, -0.8934128>,
    <-0.3821117, 0.2655127, -0.8851517>,
    <-0.4203932, 0.3043173, -0.8547868>,
    <-0.4348058, 0.2996003, -0.8492253>,
    <-0.3797267, 0.2556148, -0.8890831>,
    <-0.4351870, 0.2845401, -0.8541950>,
    <-0.4683577, 0.3322405, -0.8186925>,
    <-0.4811801, 0.3274183, -0.8131808>,
    <-0.4845012, 0.3209959, -0.8137692>,
    <-0.4754262, 0.3215529, -0.8188856>,
    <-0.5072108, 0.3231806, -0.7989314>,
    <-0.4931419, 0.3098844, -0.8128854>,
    <-0.5449649, 0.3157537, -0.7767322>,
    <-0.5104877, 0.2963681, -0.8071978>,
    <-0.4709613, 0.3000136, -0.8295706>,
    <-0.4694906, 0.2729887, -0.8396760>,
    <-0.3287887, -0.2302461, -0.9159065>,
    <-0.3294346, -0.2306864, -0.9155635>,
    <-0.3221641, -0.2255916, -0.9194121>,
    <-0.3220217, -0.2250845, -0.9195863>,
    <-0.3340966, -0.2320318, -0.9135320>,
    <-0.3315164, -0.2318062, -0.9145287>,
    <-0.3320471, -0.2325274, -0.9141530>,
    <-0.3319659, -0.2324701, -0.9141971>,
    <-0.3319659, -0.2324701, -0.9141971>,
    <-0.3319456, -0.2324505, -0.9142094>,
    <-0.3283989, -0.2297218, -0.9161780>,
    <-0.3171841, -0.2210156, -0.9222507>,
    <-0.3319456, -0.2324505, -0.9142094>,
    <-0.3319592, -0.2324466, -0.9142055>,
    <-0.3319592, -0.2324466, -0.9142055>,
    <-0.3320071, -0.2324522, -0.9141867>,
    <-0.3250809, -0.2269828, -0.9180421>,
    <-0.3107789, -0.2131588, -0.9262720>,
    <-0.3109645, -0.2154484, -0.9256798>,
    <-0.3007587, -0.1989291, -0.9327226>,
    <-0.3702613, -0.2177355, -0.9030492>,
    <-0.3357965, -0.2285711, -0.9137811>,
    <-0.4905972, -0.3130624, -0.8132074>,
    <-0.5131330, -0.3203124, -0.7963005>,
    <-0.5174619, -0.3434958, -0.7837371>,
    <-0.5127000, -0.3522106, -0.7829983>,
    <-0.4907553, -0.3459885, -0.7996569>,
    <-0.4765394, -0.3175577, -0.8197971>,
    <-0.4706755, -0.2697954, -0.8400447>,
    <-0.5117466, -0.2938038, -0.8073381>,
    <-0.5323693, -0.3355940, -0.7771483>,
    <-0.5262400, -0.3578971, -0.7713502>,
    <-0.5458918, -0.3140484, -0.7767727>,
    <-0.5241824, -0.3800992, -0.7620744>,
    <-0.4989638, -0.3740370, -0.7817490>,
    <-0.3357682, -0.2357787, -0.9119584>,
    <-0.3497884, -0.2431259, -0.9047308>,
    <-0.3586814, -0.2527160, -0.8986002>,
    <-0.3461183, -0.2466608, -0.9051854>,
    <-0.3320471, -0.2325274, -0.9141530>,
    <-0.3726434, -0.2553887, -0.8921398>,
    <-0.3805038, -0.2689931, -0.8847935>,
    <-0.4306650, -0.2924380, -0.8538195>,
    <-0.4307807, -0.3071169, -0.8485913>,
    <-0.3680280, -0.2682935, -0.8902662>,
    <-0.4156945, -0.3117278, -0.8544143>,
    <-0.4719557, -0.3268140, -0.8188104>,
    <-0.4719814, -0.3403388, -0.8132669>,
    <-0.4675339, -0.3459963, -0.8134486>,
    <-0.4650802, -0.3375474, -0.8183900>,
    <-0.4771781, -0.3662235, -0.7988626>,
    <-0.4601169, -0.3577683, -0.8125849>,
    <-0.4434141, -0.3405615, -0.8290970>,
    <0.3594611, -0.1869842, 0.9142345>,
    <0.3372919, -0.1622143, 0.9273191>,
    <0.3175825, -0.1608524, 0.9344880>,
    <0.3188693, -0.1723158, 0.9320030>,
    <0.3644520, -0.1923083, 0.9111489>,
    <0.3115370, -0.1516253, 0.9380589>,
    <0.2946413, -0.1357828, 0.9459120>,
    <0.2738619, -0.1373618, 0.9519093>,
    <0.2927673, -0.1310636, 0.9471587>,
    <0.4384633, -0.1407173, 0.8876647>,
    <0.2758571, -0.1511897, 0.9492337>,
    <0.2927179, -0.2049632, 0.9339734>,
    <0.8704546, -0.4531204, 0.1923295>,
    <0.8724374, -0.4083752, 0.2684821>,
    <0.8309079, -0.4127918, 0.3730885>,
    <0.8294620, -0.4500066, 0.3308881>,
    <0.8788453, -0.4428536, 0.1775150>,
    <0.8787235, -0.4035895, 0.2548735>,
    <0.8054096, -0.3475959, 0.4800964>,
    <0.7460305, -0.3603982, 0.5599568>,
    <0.8334120, -0.3457571, 0.4311339>,
    <0.6048148, -0.2167631, 0.7662982>,
    <0.6376699, -0.2597804, 0.7251836>,
    <0.6111876, -0.2853825, 0.7382456>,
    <0.7318084, -0.3973184, 0.5537098>,
    <0.5549001, -0.2929197, 0.7786424>,
    <0.3872301, -0.2025529, 0.8994583>,
    <0.4711348, -0.2116113, 0.8563018>,
    <0.3809763, -0.1641055, 0.9099046>,
    <0.3153845, -0.1533667, 0.9364888>,
    <0.4784729, -0.1795854, 0.8595422>,
    <0.3859169, -0.1408952, 0.9117109>,
    <0.4301181, -0.1430017, 0.8913747>,
    <0.3688006, -0.1223320, 0.9214234>,
    <0.3187468, -0.1281859, 0.9391319>,
    <0.3491589, -0.1136838, 0.9301419>,
    <0.4384633, -0.1407173, 0.8876647>,
    <0.3791043, 0.1593361, 0.9115327>,
    <0.3239026, 0.1464853, 0.9346813>,
    <0.3057202, 0.1344318, 0.9425833>,
    <0.3329561, 0.1383523, 0.9327373>,
    <0.3596692, 0.1408100, 0.9223940>,
    <0.4307027, 0.1674952, 0.8868148>,
    <0.6262426, 0.2292488, 0.7451612>,
    <0.3954793, 0.1622537, 0.9040298>,
    <0.3156577, 0.1403686, 0.9384332>,
    <0.2745013, 0.1279757, 0.9530327>,
    <0.2737122, 0.1235323, 0.9538456>,
    <0.2820069, 0.1350191, 0.9498642>,
    <0.2655876, 0.1533387, 0.9518143>,
    <0.2566261, 0.1196684, 0.9590738>,
    <0.2566261, 0.1196684, 0.9590738>,
    <0.2656187, 0.1238618, 0.9560884>,
    <0.3002882, 0.1304863, 0.9448811>,
    <0.2656187, 0.1238618, 0.9560884>,
    <0.2964815, 0.1382536, 0.9449786>,
    <0.2964815, 0.1382536, 0.9449786>,
    <0.2879294, 0.1047992, 0.9519001>,
    <0.3362756, 0.1337936, 0.9322114>,
    <0.4224222, 0.1762528, 0.8890975>,
    <0.4785417, 0.2311624, 0.8470902>,
    <0.3789638, 0.1895992, 0.9057806>,
    <0.3275742, 0.1471233, 0.9333005>,
    <0.6009579, 0.2467646, 0.7602348>,
    <0.6232558, 0.2902448, 0.7261613>,
    <0.4567732, 0.2542680, 0.8524705>,
    <0.3589126, 0.2036828, 0.9108760>,
    <0.6218488, 0.3257898, 0.7121552>,
    <0.3028178, 0.1600394, 0.9395152>,
    <0.2655876, 0.1533387, 0.9518143>,
    <-0.3201607, 0.2209805, -0.9212300>,
    <-0.2993110, 0.1998277, -0.9329962>,
    <-0.3087789, 0.1967526, -0.9305611>,
    <-0.3152058, 0.2082067, -0.9259024>,
    <-0.3084124, 0.2159764, -0.9264103>,
    <-0.3290450, 0.2304146, -0.9157721>,
    <-0.3290450, 0.2304146, -0.9157721>,
    <-0.3321384, 0.2325738, -0.9141081>,
    <-0.2943066, 0.1798489, -0.9386362>,
    <-0.3105157, 0.1803165, -0.9333091>,
    <-0.3215750, 0.1685042, -0.9317703>,
    <-0.3239090, 0.1676670, -0.9311126>,
    <-0.3027636, 0.1819272, -0.9355409>,
    <-0.3092873, 0.1596453, -0.9374725>,
    <-0.2925278, 0.1509319, -0.9442706>,
    <-0.2587655, 0.1812240, -0.9487878>,
    <-0.2587655, 0.1812240, -0.9487878>,
    <-0.3084124, 0.2159764, -0.9264103>,
    <-0.3230921, -0.2211357, -0.9201687>,
    <-0.3165892, -0.2038187, -0.9264066>,
    <-0.3139343, -0.1931704, -0.9295862>,
    <-0.3086105, -0.2014223, -0.9296175>,
    <-0.3320071, -0.2324522, -0.9141867>,
    <-0.3283274, -0.2298305, -0.9161763>,
    <-0.3283274, -0.2298305, -0.9161763>,
    <-0.3036275, -0.2124796, -0.9287964>,
    <-0.3066560, -0.1761474, -0.9353792>,
    <-0.3130711, -0.1739456, -0.9336645>,
    <-0.3036275, -0.2124796, -0.9287964>,
    <-0.2466645, -0.1725384, -0.9536179>,
    <-0.2466645, -0.1725384, -0.9536179>,
    <-0.3038927, -0.1519913, -0.9405041>,
    <-0.3153752, -0.1578214, -0.9357515>,
    <-0.3190232, -0.1602561, -0.9340997>,
    <-0.3009281, -0.1771027, -0.9370576>,
    <-0.3060457, -0.1560878, -0.9391340>,
    <0.8583101, -0.4468176, 0.2523050>,
    <0.8765076, -0.4182337, 0.2383590>,
    <0.8659998, -0.4301242, 0.2550246>,
    <0.8517354, -0.4535285, 0.2624093>,
    <0.8584245, -0.4347850, 0.2721569>,
    <0.8724022, -0.4069914, 0.2706887>,
    <0.8861297, -0.3948391, 0.2426441>,
    <0.8688249, -0.4194399, 0.2630847>,
    <0.8854289, -0.3787627, 0.2693593>,
    <0.9177509, -0.3342431, 0.2145109>,
    <0.9032659, -0.3820653, 0.1952866>,
    <0.8850825, -0.4128863, 0.2148346>,
    <0.8520470, -0.4490963, 0.2689394>,
    <0.8655854, -0.4427768, 0.2339030>,
    <0.8796145, -0.4290240, 0.2054670>,
    <0.8970486, -0.4040741, 0.1789636>,
    <0.8924837, -0.3900491, 0.2265714>,
    <0.8753560, -0.3988732, 0.2732253>,
    <0.9107574, -0.3722025, 0.1788469>,
    <0.8973929, -0.3625920, 0.2514221>,
    <0.9208930, -0.3365551, 0.1966894>,
    <0.8983731, -0.3333993, 0.2859557>,
    <0.8586411, -0.3560740, 0.3687097>,
    <0.8237331, -0.3110016, 0.4740694>,
    <0.9067485, 0.3755969, 0.1916614>,
    <0.8740840, 0.4059413, 0.2668124>,
    <0.8512680, 0.3715915, 0.3704896>,
    <0.8785714, 0.3465182, 0.3286906>,
    <0.9028160, 0.3222397, 0.2847541>,
    <0.9218244, 0.3341606, 0.1964088>,
    <0.9178853, 0.3338738, 0.2145109>,
    <0.9042040, 0.3885665, 0.1772883>,
    <0.8742963, 0.4137818, 0.2537530>,
    <0.7881296, 0.3945050, 0.4724591>,
    <0.7604990, 0.3420464, 0.5519470>,
    <0.8051030, 0.4173030, 0.4215060>,
    <0.7817296, 0.3089132, 0.5417300>,
    <0.8379425, 0.2945775, 0.4594306>,
    <0.8941008, 0.3980721, 0.2052373>,
    <0.8861757, 0.4274576, 0.1788092>,
    <0.8725965, 0.4330251, 0.2259747>,
    <0.8684654, 0.4142839, 0.2722806>,
    <0.8955742, 0.3784655, 0.2339033>,
    <0.8852092, 0.4126144, 0.2148350>,
    <0.8705813, 0.4584517, 0.1786342>,
    <0.8548030, 0.4544870, 0.2505062>,
    <0.8732870, 0.4463549, 0.1952872>,
    <0.8267970, 0.4299719, 0.3626718>,
    <-0.2968893, 0.1506505, -0.9429534>,
    <-0.2533617, 0.1308217, -0.9584850>,
    <-0.2314541, 0.1134255, -0.9662110>,
    <-0.2548946, 0.1210484, -0.9593623>,
    <-0.2369306, 0.1161288, -0.9645610>,
    <-0.2982348, 0.1565834, -0.9415613>,
    <-0.2150531, 0.1061802, -0.9708130>,
    <-0.1847721, 0.0888531, -0.9787566>,
    <-0.1633459, 0.0878834, -0.9826467>,
    <-0.1922748, 0.0906312, -0.9771471>,
    <-0.8042889, 0.2390891, -0.5440182>,
    <-0.2085626, 0.0957206, -0.9733135>,
    <-0.8700385, 0.4528886, -0.1947434>,
    <-0.8229659, 0.4466223, -0.3510779>,
    <-0.8213444, 0.4080288, -0.3986299>,
    <-0.8691015, 0.4066845, -0.2815497>,
    <-0.8761088, 0.4023427, -0.2656195>,
    <-0.8788775, 0.4429075, -0.1772209>,
    <-0.7040632, 0.3826792, -0.5982071>,
    <-0.7170151, 0.3463812, -0.6049044>,
    <-0.4957394, 0.2622058, -0.8279436>,
    <-0.5558163, 0.2595242, -0.7897565>,
    <-0.7846659, 0.3381285, -0.5195850>,
    <-0.5812704, 0.2359582, -0.7787480>,
    <-0.5441485, 0.1955186, -0.8158890>,
    <-0.8181351, 0.3390666, -0.4644231>,
    <-0.3155808, 0.1668931, -0.9341067>,
    <-0.2425544, 0.1199420, -0.9626948>,
    <-0.3079373, 0.1322332, -0.9421725>,
    <-0.4001152, 0.1795800, -0.8986984>,
    <-0.2435617, 0.0976532, -0.9649568>,
    <-0.3124946, 0.1118401, -0.9433127>,
    <-0.8042889, 0.2390891, -0.5440182>,
    <-0.2693469, 0.0867352, -0.9591294>,
    <-0.2925872, 0.0962522, -0.9513823>,
    <-0.4058431, 0.1504043, -0.9014821>,
    <-0.3541553, 0.1173605, -0.9277934>,
    <-0.3069511, -0.1290120, -0.9429406>,
    <-0.2589258, -0.1074590, -0.9599010>,
    <-0.2336804, -0.1027551, -0.9668686>,
    <-0.2520949, -0.1141447, -0.9609470>,
    <-0.2452669, -0.1083923, -0.9633770>,
    <-0.3255217, -0.1327469, -0.9361698>,
    <-0.5725139, -0.2095870, -0.7926545>,
    <-0.3597392, -0.1406590, -0.9223897>,
    <-0.2839113, -0.1117870, -0.9523119>,
    <-0.2248784, -0.0976392, -0.9694825>,
    <-0.2032946, -0.0917517, -0.9748092>,
    <-0.2548193, -0.1016938, -0.9616265>,
    <-0.2122598, -0.0772572, -0.9741546>,
    <-0.2193644, -0.1022928, -0.9702657>,
    <-0.2193644, -0.1022928, -0.9702657>,
    <-0.1953774, -0.0911073, -0.9764871>,
    <-0.2049520, -0.0956317, -0.9740889>,
    <-0.1953774, -0.0911073, -0.9764871>,
    <-0.1884628, -0.0878829, -0.9781402>,
    <-0.1884628, -0.0878829, -0.9781402>,
    <-0.1957974, -0.1130451, -0.9741069>,
    <-0.2107863, -0.1005952, -0.9723424>,
    <-0.3543763, -0.1466773, -0.9235276>,
    <-0.2577092, -0.1144711, -0.9594177>,
    <-0.3094355, -0.1548163, -0.9382332>,
    <-0.4132684, -0.1996355, -0.8884565>,
    <-0.5734223, -0.2670434, -0.7745158>,
    <-0.5470142, -0.2241824, -0.8065468>,
    <-0.2304925, -0.1218171, -0.9654190>,
    <-0.2891359, -0.1653216, -0.9429047>,
    <-0.1957974, -0.1130451, -0.9741069>,
    <-0.3920593, -0.2193893, -0.8933968>,
    <-0.5740268, -0.3011622, -0.7614425>,
    <0.8233007, -0.4286731, 0.3720420>,
    <0.8431126, -0.4024245, 0.3566731>,
    <0.8312100, -0.4129225, 0.3722700>,
    <0.8163737, -0.4347268, 0.3801928>,
    <0.8205071, -0.4155953, 0.3924902>,
    <0.8348453, -0.3895307, 0.3889720>,
    <0.8524832, -0.3799755, 0.3590139>,
    <0.8335068, -0.4024637, 0.3785358>,
    <0.8482202, -0.3629596, 0.3857237>,
    <0.8872926, -0.3232410, 0.3289789>,
    <0.8755725, -0.3704554, 0.3100574>,
    <0.8556248, -0.3992163, 0.3294428>,
    <0.8166396, -0.4304532, 0.3844605>,
    <0.8345823, -0.4269658, 0.3480986>,
    <0.8574764, -0.4182522, 0.2996652>,
    <0.8754333, -0.3944167, 0.2793778>,
    <0.8776972, -0.3836706, 0.2871314>,
    <0.8672165, -0.3954173, 0.3026232>,
    <0.8904117, -0.3640166, 0.2732380>,
    <0.8901843, -0.3595676, 0.2797913>,
    <0.9021106, -0.3277039, 0.2807252>,
    <0.9043961, -0.3294575, 0.2711559>,
    <0.8843212, -0.3667532, 0.2889085>,
    <0.9065832, -0.3311663, 0.2616024>,
    <0.8939932, 0.3702949, 0.2523050>,
    <0.8837938, 0.4026084, 0.2383590>,
    <0.8861481, 0.3869159, 0.2550247>,
    <0.8949080, 0.3609447, 0.2624094>,
    <0.9045788, 0.3289553, 0.2711560>,
    <0.9017008, 0.3288296, 0.2807255>,
    <0.8874808, 0.3227235, 0.3289793>,
    <0.8848492, 0.3781170, 0.2721569>,
    <0.8725428, 0.4066898, 0.2706888>,
    <0.8720575, 0.4250171, 0.2426443>,
    <0.8797794, 0.3959478, 0.2630849>,
    <0.8592917, 0.4348140, 0.2693595>,
    <0.8917129, 0.3640324, 0.2689396>,
    <0.9073526, 0.3290522, 0.2616025>,
    <0.8715750, 0.3880177, 0.2996653>,
    <0.8648584, 0.4170946, 0.2793780>,
    <0.8580816, 0.4257363, 0.2871315>,
    <0.8603432, 0.4101570, 0.3026233>,
    <0.8635339, 0.3648788, 0.3480987>,
    <0.8558024, 0.3988353, 0.3294430>,
    <0.8511985, 0.4481095, 0.2732380>,
    <0.8476441, 0.4507951, 0.2797914>,
    <0.8465924, 0.4326033, 0.3100575>,
    <0.8493799, 0.4416849, 0.2889087>,
    <-0.8590988, 0.4472039, -0.2489135>,
    <-0.8517141, 0.4535616, -0.2624213>,
    <-0.8660057, 0.4301058, -0.2550354>,
    <-0.8772068, 0.4184785, -0.2353378>,
    <-0.8724055, 0.4069750, -0.2707028>,
    <-0.8589736, 0.4350946, -0.2699205>,
    <-0.8512148, 0.4487106, -0.2721988>,
    <-0.8681113, 0.4190762, -0.2660037>,
    <-0.8651050, 0.4425483, -0.2361025>,
    <-0.8850888, 0.4128727, -0.2148347>,
    <-0.8861622, 0.3947616, -0.2426517>,
    <-0.9036974, 0.3821952, -0.1930232>,
    <-0.9177576, 0.3342247, -0.2145107>,
    <-0.8848872, 0.3784626, -0.2715524>,
    <-0.8792000, 0.4288831, -0.2075251>,
    <-0.8721492, 0.3974621, -0.2852713>,
    <-0.8912443, 0.3894918, -0.2323355>,
    <-0.8973208, 0.4041806, -0.1773511>,
    <-0.8491861, 0.3521392, -0.3935493>,
    <-0.8951182, 0.3615923, -0.2607957>,
    <-0.8038619, 0.3039092, -0.5113171>,
    <-0.8942743, 0.3319067, -0.3001857>,
    <-0.9110133, 0.3722141, -0.1775147>,
    <-0.9206182, 0.3363883, -0.1982548>,
    <-0.9063175, -0.3754328, -0.1940074>,
    <-0.8719195, -0.3437622, -0.3486889>,
    <-0.8416302, -0.3673958, -0.3958268>,
    <-0.8707094, -0.4045032, -0.2797183>,
    <-0.8716993, -0.4125990, -0.2643905>,
    <-0.9042697, -0.3885583, -0.1769710>,
    <-0.9178786, -0.3338924, -0.2145103>,
    <-0.9215126, -0.3341137, -0.1979457>,
    <-0.8987684, -0.3207665, -0.2988715>,
    <-0.7556523, -0.2982628, -0.5831200>,
    <-0.7334565, -0.3298923, -0.5943170>,
    <-0.8202663, -0.2881295, -0.4941099>,
    <-0.7695506, -0.3855281, -0.5090776>,
    <-0.7917013, -0.4106000, -0.4523458>,
    <-0.8937315, -0.3978473, -0.2072716>,
    <-0.8653586, -0.4127512, -0.2842375>,
    <-0.8713891, -0.4324419, -0.2316788>,
    <-0.8864348, -0.4275988, -0.1771798>,
    <-0.8852031, -0.4126281, -0.2148338>,
    <-0.8950906, -0.3782445, -0.2361017>,
    <-0.8183095, -0.4255724, -0.3863389>,
    <-0.8526049, -0.4534029, -0.2597898>,
    <-0.8707581, -0.4586420, -0.1772789>,
    <-0.8736640, -0.4466021, -0.1930225>,
    <-0.8245028, 0.4292680, -0.3686788>,
    <-0.8163637, 0.4347615, -0.3801747>,
    <-0.8312271, 0.4129030, -0.3722536>,
    <-0.8441803, 0.4028358, -0.3536706>,
    <-0.8348627, 0.3895152, -0.3889500>,
    <-0.8213357, 0.4160434, -0.3902762>,
    <-0.8154651, 0.4298822, -0.3875797>,
    <-0.8324814, 0.4019429, -0.3813352>,
    <-0.8338680, 0.4266121, -0.3502374>,
    <-0.8556335, 0.3991973, -0.3294432>,
    <-0.8525252, 0.3798931, -0.3590015>,
    <-0.8762644, 0.3706867, -0.3078182>,
    <-0.8873016, 0.3232154, -0.3289797>,
    <-0.8474420, 0.3625502, -0.3878136>,
    <-0.8574508, 0.4182976, -0.2996752>,
    <-0.8663577, 0.3950737, -0.3055178>,
    <-0.8777026, 0.3836493, -0.2871434>,
    <-0.8762380, 0.3947558, -0.2763601>,
    <-0.8834193, 0.3663559, -0.2921536>,
    <-0.8902140, 0.3594845, -0.2798033>,
    <-0.9061707, 0.3310387, -0.2631882>,
    <-0.9044021, 0.3294311, -0.2711677>,
    <-0.8913349, 0.3642886, -0.2698443>,
    <-0.9025735, 0.3277927, -0.2791290>,
    <-0.8947962, -0.3706508, -0.2489131>,
    <-0.8949198, -0.3609073, -0.2624205>,
    <-0.8861381, -0.3869323, -0.2550346>,
    <-0.8844309, -0.4029867, -0.2353374>,
    <-0.8725324, -0.4067028, -0.2707030>,
    <-0.8854393, -0.3783384, -0.2699208>,
    <-0.8874712, -0.3227491, -0.3289801>,
    <-0.9021124, -0.3290593, -0.2791293>,
    <-0.9045664, -0.3289797, -0.2711677>,
    <-0.8908828, -0.3636430, -0.2721978>,
    <-0.8790423, -0.3956350, -0.2660028>,
    <-0.9069546, -0.3288851, -0.2631879>,
    <-0.8720191, -0.4250919, -0.2426511>,
    <-0.8587137, -0.4345918, -0.2715524>,
    <-0.8715931, -0.3879686, -0.2996761>,
    <-0.8595279, -0.4097198, -0.3055184>,
    <-0.8580686, -0.4257539, -0.2871443>,
    <-0.8656351, -0.4174928, -0.2763613>,
    <-0.8557932, -0.3988539, -0.3294444>,
    <-0.8628035, -0.3645587, -0.3502385>,
    <-0.8484958, -0.4412492, -0.2921542>,
    <-0.8475995, -0.4508710, -0.2798043>,
    <-0.8520000, -0.4486417, -0.2698455>,
    <-0.8472141, -0.4329844, -0.3078193>,
    <0.7670079, -0.3994268, 0.5021525>,
    <0.7891769, -0.3768268, 0.4849757>,
    <0.7763787, -0.3857462, 0.4984336>,
    <0.7608231, -0.4051199, 0.5069774>,
    <0.7603917, -0.3851198, 0.5229601>,
    <0.7760094, -0.3621265, 0.5164048>,
    <0.7991409, -0.3563515, 0.4841358>,
    <0.7788932, -0.3761532, 0.5018307>,
    <0.7905934, -0.3384256, 0.5103236>,
    <0.8382430, -0.3054473, 0.4517196>,
    <0.8298526, -0.3512177, 0.4335791>,
    <0.8082039, -0.3771501, 0.4522878>,
    <0.7621255, -0.4016834, 0.5077550>,
    <0.7857855, -0.4020194, 0.4700229>,
    <0.8156109, -0.3978073, 0.4201526>,
    <0.8351772, -0.3763466, 0.4010514>,
    <0.8370538, -0.3659750, 0.4066980>,
    <0.8254963, -0.3763861, 0.4205821>,
    <0.8504149, -0.3478208, 0.3947343>,
    <0.8502266, -0.3435774, 0.3988349>,
    <0.8608751, -0.3128619, 0.4012623>,
    <0.8653294, -0.3153198, 0.3895876>,
    <0.8442653, -0.3502170, 0.4056651>,
    <0.8695793, -0.3176971, 0.3780218>,
    <0.8575902, 0.3551392, 0.3720421>,
    <0.8502174, 0.3871882, 0.3566731>,
    <0.8506084, 0.3713223, 0.3722701>,
    <0.8577749, 0.3459415, 0.3801929>,
    <0.8655644, 0.3146740, 0.3895876>,
    <0.8605724, 0.3136937, 0.4012621>,
    <0.8384693, 0.3048260, 0.4517194>,
    <0.8457763, 0.3614054, 0.3924902>,
    <0.8350260, 0.3891431, 0.3889720>,
    <0.8390437, 0.4087965, 0.3590140>,
    <0.8440729, 0.3798046, 0.3785359>,
    <0.8232687, 0.4164685, 0.3857236>,
    <0.8546720, 0.3488922, 0.3844606>,
    <0.8703481, 0.3155846, 0.3780220>,
    <0.8290027, 0.3690887, 0.4201526>,
    <0.8251398, 0.3978720, 0.4010513>,
    <0.8184009, 0.4059762, 0.4066979>,
    <0.8189473, 0.3904306, 0.4205820>,
    <0.8130579, 0.3435336, 0.4700229>,
    <0.8084172, 0.3766928, 0.4522878>,
    <0.8130824, 0.4278807, 0.3947342>,
    <0.8097107, 0.4304641, 0.3988348>,
    <0.8024673, 0.4099457, 0.4335790>,
    <0.8109651, 0.4216297, 0.4056649>,
    <0.4022075, 0.2007038, 0.8932789>,
    <0.4085009, 0.2124598, 0.8876868>,
    <0.4053900, 0.2157034, 0.8883305>,
    <0.3958099, 0.2019486, 0.8958523>,
    <0.3727550, 0.1776074, 0.9107740>,
    <0.3536123, 0.1653450, 0.9206625>,
    <0.3409514, 0.1589927, 0.9265384>,
    <0.4165139, 0.2101551, 0.8845061>,
    <0.4165139, 0.2101551, 0.8845061>,
    <0.4068873, 0.2052980, 0.8901098>,
    <0.3726807, 0.2013277, 0.9058567>,
    <0.4002289, 0.2236880, 0.8886960>,
    <0.4068873, 0.2052980, 0.8901098>,
    <0.3508819, 0.1770400, 0.9195318>,
    <0.3508819, 0.1770400, 0.9195318>,
    <0.3555387, 0.2149576, 0.9096073>,
    <0.4129730, 0.2245709, 0.8826218>,
    <0.3992865, 0.1976416, 0.8952699>,
    <-0.7686436, 0.4002437, -0.4989909>,
    <-0.7608138, 0.4051539, -0.5069642>,
    <-0.7763988, 0.3857243, -0.4984192>,
    <-0.7906356, 0.3774176, -0.4821319>,
    <-0.7760260, 0.3621083, -0.5163924>,
    <-0.7615004, 0.3857105, -0.5209073>,
    <-0.7605957, 0.4009237, -0.5106412>,
    <-0.7775438, 0.3754721, -0.5044267>,
    <-0.7848337, 0.4015413, -0.4720176>,
    <-0.8082236, 0.3771321, -0.4522676>,
    <-0.7991896, 0.3562651, -0.4841190>,
    <-0.8308389, 0.3515670, -0.4314017>,
    <-0.8382640, 0.3054206, -0.4516988>,
    <-0.7895617, 0.3379022, -0.5122640>,
    <-0.8155983, 0.3978579, -0.4201292>,
    <-0.8243237, 0.3758967, -0.4233109>,
    <-0.8370736, 0.3659545, -0.4066757>,
    <-0.8363674, 0.3768543, -0.3980835>,
    <-0.8430082, 0.3496662, -0.4087429>,
    <-0.8502713, 0.3434913, -0.3988138>,
    <-0.8689920, 0.3175002, -0.3795346>,
    <-0.8653486, 0.3152912, -0.3895680>,
    <-0.8517778, 0.3482629, -0.3913917>,
    <-0.8615532, 0.3130201, -0.3996806>,
    <-0.8588183, -0.3556775, -0.3686795>,
    <-0.8577947, -0.3459112, -0.3801758>,
    <-0.8506041, -0.3713477, -0.3722546>,
    <-0.8512186, -0.3877416, -0.3536713>,
    <-0.8350254, -0.3891664, -0.3889501>,
    <-0.8466522, -0.3617522, -0.3902761>,
    <-0.8384681, -0.3048601, -0.4516985>,
    <-0.8611935, -0.3140085, -0.3996805>,
    <-0.8655608, -0.3147083, -0.3895681>,
    <-0.8534793, -0.3483592, -0.3875809>,
    <-0.8430145, -0.3793535, -0.3813363>,
    <-0.8697716, -0.3153580, -0.3795349>,
    <-0.8390074, -0.4088813, -0.3590023>,
    <-0.8224548, -0.4161354, -0.3878137>,
    <-0.8290336, -0.3690467, -0.4201284>,
    <-0.8178188, -0.3898471, -0.4233103>,
    <-0.8183983, -0.4060049, -0.4066747>,
    <-0.8262941, -0.3984577, -0.3980822>,
    <-0.8084165, -0.3767198, -0.4522664>,
    <-0.8120803, -0.3431121, -0.4720166>,
    <-0.8097353, -0.4210209, -0.4087423>,
    <-0.8096738, -0.4305540, -0.3988127>,
    <-0.8142975, -0.4286410, -0.3913904>,
    <-0.8033693, -0.4104770, -0.4314005>,
    <0.6693359, -0.3485466, 0.6561286>,
    <0.7016356, -0.3351487, 0.6287948>,
    <0.6900421, -0.3428942, 0.6373895>,
    <0.6706843, -0.3570951, 0.6501274>,
    <0.6577031, -0.3322661, 0.6760369>,
    <0.6836476, -0.3186577, 0.6565693>,
    <0.7170851, -0.3199471, 0.6192114>,
    <0.6966160, -0.3364624, 0.6336554>,
    <0.7037667, -0.3013359, 0.6433577>,
    <0.7627854, -0.2780075, 0.5838410>,
    <0.7582511, -0.3210258, 0.5674484>,
    <0.7352914, -0.3431697, 0.5844494>,
    <0.6796744, -0.3581250, 0.6401478>,
    <0.7120183, -0.3642577, 0.6002885>,
    <0.7506842, -0.3660603, 0.5499755>,
    <0.7712554, -0.3475936, 0.5332390>,
    <0.7737780, -0.3383648, 0.5355156>,
    <0.7618788, -0.3473228, 0.5467244>,
    <0.7866335, -0.3219123, 0.5268588>,
    <0.7878683, -0.3185439, 0.5270610>,
    <0.7959535, -0.2894119, 0.5316942>,
    <0.8041687, -0.2931068, 0.5171084>,
    <0.7830363, -0.3248780, 0.5303852>,
    <0.8119168, -0.2966363, 0.5027903>,
    <0.7990019, 0.3308157, 0.5021524>,
    <0.7959392, 0.3623251, 0.4849756>,
    <0.7945453, 0.3467877, 0.4984335>,
    <0.7993875, 0.3224183, 0.5069773>,
    <0.8044344, 0.2923769, 0.5171083>,
    <0.7957661, 0.2899267, 0.5316943>,
    <0.7630272, 0.2773429, 0.5838411>,
    <0.7837893, 0.3349437, 0.5229599>,
    <0.7762142, 0.3616873, 0.5164047>,
    <0.7866589, 0.3831192, 0.4841357>,
    <0.7888130, 0.3548803, 0.5018307>,
    <0.7674327, 0.3880940, 0.5103236>,
    <0.7975922, 0.3256249, 0.5077550>,
    <0.8126386, 0.2946535, 0.5027901>,
    <0.7629490, 0.3397585, 0.5499754>,
    <0.7620256, 0.3673871, 0.5332388>,
    <0.7565774, 0.3752516, 0.5355155>,
    <0.7557910, 0.3603783, 0.5467243>,
    <0.7367142, 0.3112974, 0.6002883>,
    <0.7355196, 0.3426808, 0.5844492>,
    <0.7522374, 0.3956751, 0.5268587>,
    <0.7504508, 0.3987861, 0.5270609>,
    <0.7333145, 0.3745027, 0.5674483>,
    <0.7521970, 0.3910131, 0.5303852>,
    <-0.3612794, 0.1688988, -0.9170335>,
    <-0.3567780, 0.1678710, -0.9189825>,
    <-0.3481014, 0.1648783, -0.9228437>,
    <-0.3506338, 0.1653804, -0.9217946>,
    <-0.3648606, 0.1725245, -0.9149383>,
    <-0.3652819, 0.1707844, -0.9150966>,
    <-0.3674917, 0.1713603, -0.9141037>,
    <-0.3664516, 0.1708737, -0.9146122>,
    <-0.3664516, 0.1708737, -0.9146122>,
    <-0.3592751, 0.1675260, -0.9180722>,
    <-0.3411035, 0.1634430, -0.9257077>,
    <-0.3377616, 0.1638423, -0.9268618>,
    <-0.3592751, 0.1675260, -0.9180722>,
    <-0.3391965, 0.1581621, -0.9273244>,
    <-0.3391965, 0.1581621, -0.9273244>,
    <-0.2925278, 0.1509319, -0.9442706>,
    <-0.3383407, 0.1635361, -0.9267047>,
    <-0.3630510, 0.1765852, -0.9148834>,
    <0.3946231, -0.1196475, 0.9110198>,
    <0.3499385, -0.0967019, 0.9317681>,
    <0.3289043, -0.0951185, 0.9395608>,
    <0.3511987, -0.1091148, 0.9299212>,
    <0.3936105, -0.1246085, 0.9107928>,
    <0.3308320, -0.0951787, 0.9388776>,
    <0.2944335, -0.0782727, 0.9524612>,
    <0.2903615, -0.0817698, 0.9534170>,
    <0.2991996, -0.0773288, 0.9510520>,
    <0.3332519, -0.0892942, 0.9385999>,
    <0.2716912, -0.0727983, 0.9596272>,
    <0.2716912, -0.0727983, 0.9596272>,
    <0.2815724, -0.0754457, 0.9565693>,
    <0.3163021, -0.0934269, 0.9440468>,
    <0.2815724, -0.0754457, 0.9565693>,
    <0.3153222, -0.0844887, 0.9452161>,
    <0.3153222, -0.0844887, 0.9452161>,
    <0.4384633, -0.1407173, 0.8876647>,
    <-0.6814590, 0.3548865, -0.6400541>,
    <-0.6763390, 0.3600813, -0.6425784>,
    <-0.6928786, 0.3442712, -0.6335586>,
    <-0.7070277, 0.3376692, -0.6213624>,
    <-0.6866583, 0.3204376, -0.6525490>,
    <-0.6692129, 0.3388894, -0.6612927>,
    <-0.6790134, 0.3578224, -0.6410179>,
    <-0.6955756, 0.3359295, -0.6350795>,
    <-0.7108271, 0.3636579, -0.6020612>,
    <-0.7353106, 0.3431498, -0.5844370>,
    <-0.7177045, 0.3201112, -0.6184085>,
    <-0.7595285, 0.3214937, -0.5654717>,
    <-0.7628051, 0.2779783, -0.5838291>,
    <-0.7028904, 0.3009405, -0.6444998>,
    <-0.7506680, 0.3661117, -0.5499635>,
    <-0.7603729, 0.3466823, -0.5492216>,
    <-0.7737968, 0.3383409, -0.5355035>,
    <-0.7728407, 0.3482768, -0.5304908>,
    <-0.7814062, 0.3241689, -0.5332156>,
    <-0.7879144, 0.3184507, -0.5270484>,
    <-0.8111419, 0.2963681, -0.5041971>,
    <-0.8041894, 0.2930738, -0.5170949>,
    <-0.7884530, 0.3225327, -0.5237505>,
    <-0.7968420, 0.2896396, -0.5302374>,
    <-0.8006794, -0.3315437, -0.4989903>,
    <-0.7994080, -0.3223896, -0.5069633>,
    <-0.7945419, -0.3468175, -0.4984183>,
    <-0.7973297, -0.3630629, -0.4821313>,
    <-0.7762110, -0.3617117, -0.5163923>,
    <-0.7849545, -0.3354133, -0.5209073>,
    <-0.7630236, -0.2773780, -0.5838290>,
    <-0.7965932, -0.2903235, -0.5302373>,
    <-0.8044291, -0.2924155, -0.5170948>,
    <-0.7960273, -0.3249417, -0.5106402>,
    <-0.7874243, -0.3542847, -0.5044257>,
    <-0.8118726, -0.2943610, -0.5041969>,
    <-0.7866244, -0.3832123, -0.4841182>,
    <-0.7663687, -0.3876402, -0.5122638>,
    <-0.7629777, -0.3397128, -0.5499639>,
    <-0.7543322, -0.3596362, -0.5492220>,
    <-0.7565708, -0.3752811, -0.5355042>,
    <-0.7635675, -0.3681620, -0.5304916>,
    <-0.7355160, -0.3427078, -0.5844378>,
    <-0.7354886, -0.3107701, -0.6020618>,
    <-0.7506058, -0.3902200, -0.5332160>,
    <-0.7504086, -0.3988810, -0.5270492>,
    <-0.7538817, -0.3966697, -0.5237514>,
    <-0.7344936, -0.3751801, -0.5654725>,
    <0.9359492, -0.2950947, 0.1921411>,
    <0.9302199, -0.2507342, 0.2679987>,
    <0.8902499, -0.2623189, 0.3723491>,
    <0.8952151, -0.2991776, 0.3302768>,
    <0.9424036, -0.2835260, 0.1774500>,
    <0.9355345, -0.2449109, 0.2545464>,
    <0.8520421, -0.2032694, 0.4823959>,
    <0.7958361, -0.2249819, 0.5621637>,
    <0.8841275, -0.1984140, 0.4230253>,
    <0.6546119, -0.1211696, 0.7461911>,
    <0.6630943, -0.1459649, 0.7341664>,
    <0.6462917, -0.1735312, 0.7430975>,
    <0.7877034, -0.2636408, 0.5567917>,
    <0.5892412, -0.1896380, 0.7853867>,
    <0.4097630, -0.1308189, 0.9027628>,
    <0.4946281, -0.1248219, 0.8600945>,
    <0.3990011, -0.0935994, 0.9121608>,
    <0.3359594, -0.0966746, 0.9369020>,
    <0.4900409, -0.0938219, 0.8666357>,
    <0.3895836, -0.0698798, 0.9183362>,
    <0.4318435, -0.0741762, 0.8988932>,
    <0.3617252, -0.0609546, 0.9302900>,
    <0.3190081, -0.0693809, 0.9452090>,
    <0.3182736, -0.0581766, 0.9462121>,
    <0.3332519, -0.0892942, 0.9385999>,
    <0.3966715, 0.0883633, 0.9136978>,
    <0.3439360, 0.0872290, 0.9349327>,
    <0.3246171, 0.0786436, 0.9425704>,
    <0.3524998, 0.0777665, 0.9325751>,
    <0.3799533, 0.0768818, 0.9218051>,
    <0.4441082, 0.0873748, 0.8917026>,
    <0.6470780, 0.1141403, 0.7538316>,
    <0.4137614, 0.0891124, 0.9060135>,
    <0.3344780, 0.0829632, 0.9387447>,
    <0.2922890, 0.0782411, 0.9531241>,
    <0.2910149, 0.0739784, 0.9538540>,
    <0.3008267, 0.0838789, 0.9499830>,
    <0.2879294, 0.1047992, 0.9519001>,
    <0.2731983, 0.0732046, 0.9591683>,
    <0.2731983, 0.0732046, 0.9591683>,
    <0.2830838, 0.0758535, 0.9560909>,
    <0.3210489, 0.0772444, 0.9439072>,
    <0.2830838, 0.0758535, 0.9560909>,
    <0.3176535, 0.0851166, 0.9443788>,
    <0.3176535, 0.0851166, 0.9443788>,
    <0.4133888, 0.0894293, 0.9061524>,
    <0.3627170, 0.0770142, 0.9287116>,
    <0.4452522, 0.0995694, 0.8898519>,
    <0.5109794, 0.1444302, 0.8473724>,
    <0.4057438, 0.1207974, 0.9059691>,
    <0.3475588, 0.0877590, 0.9335423>,
    <0.6330135, 0.1378594, 0.7617668>,
    <0.6637983, 0.1775040, 0.7265426>,
    <0.4936458, 0.1709800, 0.8526897>,
    <0.3885174, 0.1381615, 0.9110245>,
    <0.6686468, 0.2127603, 0.7124918>,
    <0.3256581, 0.1049010, 0.9396503>,
    <0.2879294, 0.1047992, 0.9519001>,
    <-0.3577499, -0.1670896, -0.9187470>,
    <-0.3385644, -0.1592836, -0.9273634>,
    <-0.3401615, -0.1603279, -0.9265987>,
    <-0.3559991, -0.1670257, -0.9194385>,
    <-0.3612029, -0.1684543, -0.9171454>,
    <-0.3666953, -0.1710159, -0.9144879>,
    <-0.3666953, -0.1710159, -0.9144879>,
    <-0.3673852, -0.1713381, -0.9141506>,
    <-0.3621343, -0.1695490, -0.9165762>,
    <-0.3573525, -0.1696565, -0.9184312>,
    <-0.3191538, -0.1532910, -0.9352233>,
    <-0.3286616, -0.1576494, -0.9311972>,
    <-0.3523403, -0.1732399, -0.9196979>,
    <-0.3426105, -0.1627239, -0.9252778>,
    <-0.3038927, -0.1519913, -0.9405041>,
    <-0.3454774, -0.1611211, -0.9244919>,
    <-0.3454774, -0.1611211, -0.9244919>,
    <-0.3612029, -0.1684543, -0.9171454>,
    <0.9228596, -0.2909853, 0.2523046>,
    <0.9358171, -0.2596757, 0.2383586>,
    <0.9275337, -0.2732103, 0.2550243>,
    <0.9175501, -0.2987360, 0.2624091>,
    <0.9208829, -0.2791156, 0.2721565>,
    <0.9298219, -0.2493172, 0.2706882>,
    <0.9412307, -0.2349657, 0.2426437>,
    <0.9284605, -0.2621977, 0.2630844>,
    <0.9377489, -0.2192552, 0.2693589>,
    <0.9618489, -0.1697994, 0.2145107>,
    <0.9558883, -0.2194103, 0.1952863>,
    <0.9433331, -0.2529206, 0.2148343>,
    <0.9170873, -0.2943170, 0.2689393>,
    <0.9293227, -0.2857426, 0.2339028>,
    <0.9407639, -0.2697665, 0.2054005>,
    <0.9535953, -0.2421664, 0.1789177>,
    <0.9466963, -0.2291548, 0.2263941>,
    <0.9313969, -0.2408298, 0.2729484>,
    <0.9615648, -0.2083989, 0.1787822>,
    <0.9467936, -0.2012669, 0.2511444>,
    <0.9653647, -0.1715272, 0.1965946>,
    <0.9427411, -0.1723357, 0.2855513>,
    <0.9101179, -0.2021604, 0.3616858>,
    <0.8764174, -0.1644249, 0.4526114>,
    <0.9581814, 0.2124325, 0.1917311>,
    <0.9312501, 0.2479879, 0.2669743>,
    <0.9027590, 0.2181002, 0.3707541>,
    <0.9253172, 0.1886646, 0.3289283>,
    <0.9450031, 0.1605535, 0.2849417>,
    <0.9658383, 0.1690063, 0.1964519>,
    <0.9619173, 0.1694125, 0.2145101>,
    <0.9579364, 0.2256515, 0.1773110>,
    <0.9328375, 0.2556745, 0.2538598>,
    <0.8445032, 0.2516179, 0.4727608>,
    <0.8081044, 0.2047307, 0.5523156>,
    <0.8652311, 0.2711350, 0.4217356>,
    <0.8227707, 0.1681354, 0.5429354>,
    <0.8748691, 0.1440566, 0.4624410>,
    <0.9496374, 0.2367643, 0.2052596>,
    <0.9469375, 0.2670800, 0.1788229>,
    <0.9345218, 0.2749181, 0.2260287>,
    <0.9271867, 0.2571760, 0.2723700>,
    <0.9476885, 0.2172010, 0.2339023>,
    <0.9434108, 0.2526309, 0.2148340>,
    <0.9369615, 0.3003109, 0.1786517>,
    <0.9207185, 0.2991409, 0.2505838>,
    <0.9375287, 0.2879291, 0.1952862>,
    <0.8888375, 0.2798482, 0.3628400>,
    <0.3461767, -0.1867014, 0.9194043>,
    <0.4276723, -0.2087507, 0.8794996>,
    <0.4373879, -0.2201613, 0.8719064>,
    <0.4052530, -0.2171349, 0.8880442>,
    <0.2595650, -0.1681183, 0.9509796>,
    <0.3507123, -0.1788352, 0.9192491>,
    <0.4060282, -0.1947207, 0.8928745>,
    <0.5071165, -0.2310099, 0.8303417>,
    <0.4917964, -0.2391503, 0.8372236>,
    <0.4522237, -0.2048384, 0.8680639>,
    <0.5571100, -0.2112034, 0.8031324>,
    <0.6003444, -0.2599106, 0.7563287>,
    <0.5770141, -0.2713712, 0.7703327>,
    <0.4722924, -0.2471848, 0.8460730>,
    <0.5524221, -0.2828511, 0.7841078>,
    <0.3615844, -0.1788888, 0.9150167>,
    <0.3568852, -0.1752978, 0.9175531>,
    <0.3664546, -0.1774887, 0.9133503>,
    <0.3769457, -0.1819899, 0.9081804>,
    <0.2595650, -0.1681183, 0.9509796>,
    <0.3500490, -0.1757438, 0.9200977>,
    <0.3500490, -0.1757438, 0.9200977>,
    <0.3378950, -0.1696419, 0.9257692>,
    <0.3525207, -0.1711758, 0.9200152>,
    <0.3702529, -0.1761622, 0.9120744>,
    <0.3378950, -0.1696419, 0.9257692>,
    <0.3223853, -0.1618551, 0.9326686>,
    <0.3223853, -0.1618551, 0.9326686>,
    <0.3663278, -0.1708232, 0.9146712>,
    <0.3736429, -0.1737615, 0.9111520>,
    <0.3864268, -0.1763049, 0.9053126>,
    <0.3878699, -0.1818174, 0.9036036>,
    <0.4124533, -0.1807665, 0.8928638>,
    <0.6351879, -0.3094383, 0.7076611>,
    <0.6451072, -0.2930189, 0.7056746>,
    <0.6636412, -0.2918593, 0.6887659>,
    <0.6614877, -0.3014635, 0.6866978>,
    <0.6552219, -0.2727743, 0.7044703>,
    <0.6781973, -0.2766883, 0.6808025>,
    <0.6659870, -0.2449734, 0.7045916>,
    <0.6983373, -0.2558682, 0.6684732>,
    <0.6884785, -0.2862396, 0.6663815>,
    <0.7221499, -0.2641207, 0.6393276>,
    <0.6922251, 0.2866585, 0.6623076>,
    <0.7056518, 0.3211784, 0.6315853>,
    <0.7046529, 0.3075098, 0.6394544>,
    <0.7021921, 0.2831873, 0.6532467>,
    <0.6984894, 0.2525479, 0.6695761>,
    <0.6657758, 0.2399570, 0.7065148>,
    <0.5633566, 0.1982666, 0.8020722>,
    <0.6737438, 0.2898180, 0.6797609>,
    <0.6824562, 0.3187751, 0.6577508>,
    <0.7055506, 0.3434368, 0.6198786>,
    <0.7051459, 0.3171962, 0.6341576>,
    <0.6829409, 0.3453712, 0.6436696>,
    <0.7106850, 0.2902362, 0.6408508>,
    <0.7227685, 0.2617748, 0.6395933>,
    <0.6467917, 0.2897865, 0.7054675>,
    <0.6423537, 0.3081213, 0.7017428>,
    <0.6520225, 0.3221350, 0.6863641>,
    <0.6569322, 0.3139253, 0.6854859>,
    <0.5731807, 0.2446660, 0.7820501>,
    <0.5852328, 0.2718970, 0.7639206>,
    <0.6328722, 0.3280815, 0.7013097>,
    <0.6491636, 0.3424722, 0.6791903>,
    <0.5901637, 0.2953185, 0.7513281>,
    <0.6621269, 0.3437248, 0.6659138>,
    <-0.3176000, 0.0969421, -0.9432563>,
    <-0.2744679, 0.0857840, -0.9577622>,
    <-0.2530478, 0.0734708, -0.9646600>,
    <-0.2738038, 0.0757052, -0.9588014>,
    <-0.2565430, 0.0745779, -0.9636513>,
    <-0.3197001, 0.1024140, -0.9419677>,
    <-0.2386491, 0.0705087, -0.9685428>,
    <-0.2161148, 0.0609251, -0.9744653>,
    <-0.8042889, 0.2390891, -0.5440182>,
    <-0.2341388, 0.0627361, -0.9701769>,
    <-0.2341388, 0.0627361, -0.9701769>,
    <-0.2072210, 0.0555237, -0.9767172>,
    <-0.2204883, 0.0584821, -0.9736348>,
    <-0.2072210, 0.0555237, -0.9767172>,
    <-0.1994903, 0.0534525, -0.9784408>,
    <-0.1994903, 0.0534525, -0.9784408>,
    <-0.3670285, 0.0983449, 0.9249964>,
    <-0.2242536, 0.0575108, -0.9728324>,
    <-0.9355030, 0.2949400, -0.1945365>,
    <-0.8882628, 0.2969840, -0.3504135>,
    <-0.8800519, 0.2593030, -0.3978323>,
    <-0.9266612, 0.2496538, -0.2810197>,
    <-0.9327550, 0.2441402, -0.2652613>,
    <-0.9424456, 0.2835739, -0.1771500>,
    <-0.7589107, 0.2544729, -0.5994148>,
    <-0.7661478, 0.2165808, -0.6050705>,
    <-0.5301199, 0.1713508, -0.8304287>,
    <-0.5911280, 0.1587144, -0.7908081>,
    <-0.8313065, 0.1967344, -0.5198318>,
    <-0.6113085, 0.1310498, -0.7804664>,
    <-0.5701225, 0.0988680, -0.8155890>,
    <-0.8648833, 0.1920276, -0.4637912>,
    <-0.3382466, 0.1095558, -0.9346586>,
    <-0.2619929, 0.0769095, -0.9620003>,
    <-0.3234124, 0.0758648, -0.9432121>,
    <-0.4234184, 0.1068483, -0.8996112>,
    <-0.2410739, 0.0502871, -0.9692031>,
    <-0.3124995, 0.0531188, -0.9484316>,
    <-0.3670285, 0.0983449, 0.9249964>,
    <-0.2254767, 0.0349580, -0.9736212>,
    <-0.2790561, 0.0428586, -0.9593179>,
    <-0.4208315, 0.0766668, -0.9038933>,
    <-0.3626347, 0.0543925, -0.9303427>,
    <-0.3242690, -0.0736552, -0.9430931>,
    <-0.2732652, -0.0607777, -0.9600168>,
    <-0.2476467, -0.0605363, -0.9669573>,
    <-0.2677502, -0.0685500, -0.9610467>,
    <-0.2600353, -0.0640696, -0.9634712>,
    <-0.3431960, -0.0741022, -0.9363361>,
    <-0.5996729, -0.1068915, -0.7930741>,
    <-0.3782079, -0.0759654, -0.9225985>,
    <-0.2985629, -0.0607041, -0.9524575>,
    <-0.2380739, -0.0570237, -0.9695716>,
    <-0.2158612, -0.0549856, -0.9748746>,
    <-0.2681542, -0.0558091, -0.9617581>,
    <-0.2220766, -0.0391593, -0.9742425>,
    <-0.2334695, -0.0625595, -0.9703496>,
    <-0.2334695, -0.0625595, -0.9703496>,
    <-0.2079701, -0.0557268, -0.9765464>,
    <-0.2181792, -0.0585187, -0.9741527>,
    <-0.2079701, -0.0557268, -0.9765464>,
    <-0.2006182, -0.0537568, -0.9781935>,
    <-0.2006182, -0.0537568, -0.9781935>,
    <-0.2122598, -0.0772572, -0.9741546>,
    <-0.2247772, -0.0623860, -0.9724110>,
    <-0.3740242, -0.0828012, -0.9237152>,
    <-0.2733357, -0.0678876, -0.9595201>,
    <-0.3312792, -0.0986304, -0.9383635>,
    <-0.4412430, -0.1247224, -0.8886782>,
    <-0.6106707, -0.1633026, -0.7748636>,
    <-0.5771622, -0.1256776, -0.8069009>,
    <-0.2478784, -0.0798561, -0.9654943>,
    <-0.3131859, -0.1125144, -0.9430032>,
    <-0.2122598, -0.0772572, -0.9741546>,
    <-0.4238805, -0.1478747, -0.8935650>,
    <-0.6172543, -0.1968040, -0.7617515>,
    <-0.5182442, 0.2692870, -0.8117312>,
    <-0.5346920, 0.2846053, -0.7956785>,
    <-0.5569960, 0.2767793, -0.7830381>,
    <-0.5627401, 0.2685814, -0.7817849>,
    <-0.5459945, 0.2526425, -0.7987877>,
    <-0.5153111, 0.2552521, -0.8181081>,
    <-0.5569984, 0.2933424, -0.7769833>,
    <-0.5732931, 0.2768974, -0.7711438>,
    <-0.6018573, 0.3078429, -0.7368857>,
    <-0.6259437, 0.2921374, -0.7230838>,
    <-0.5916923, 0.2640984, -0.7616773>,
    <-0.6503920, 0.2754150, -0.7079102>,
    <-0.6495350, 0.2367340, -0.7225381>,
    <-0.5736893, 0.2452709, -0.7814876>,
    <-0.6526424, 0.3181602, -0.6876278>,
    <-0.6657184, 0.3034131, -0.6817327>,
    <-0.6780467, 0.2965088, -0.6725587>,
    <-0.6744953, 0.3039898, -0.6727899>,
    <-0.6901886, 0.2863651, -0.6645561>,
    <-0.6934307, 0.2804420, -0.6637063>,
    <-0.7240576, 0.2645065, -0.6370063>,
    <-0.7113616, 0.2592921, -0.6532475>,
    <-0.6900374, 0.2824737, -0.6663760>,
    <-0.6976986, 0.2537505, -0.6699458>,
    <-0.7098919, -0.2939111, -0.6400545>,
    <-0.7105803, -0.2866497, -0.6425789>,
    <-0.7091005, -0.3094823, -0.6335591>,
    <-0.7131381, -0.3245649, -0.6213628>,
    <-0.6868448, -0.3200374, -0.6525491>,
    <-0.6897660, -0.2948129, -0.6612928>,
    <-0.6497423, -0.2361643, -0.7225382>,
    <-0.6975757, -0.2540878, -0.6699459>,
    <-0.7116043, -0.2586252, -0.6532475>,
    <-0.7105688, -0.2901504, -0.6410185>,
    <-0.7044439, -0.3169102, -0.6350801>,
    <-0.7246818, -0.2627915, -0.6370063>,
    <-0.7065506, -0.3440298, -0.6184090>,
    <-0.6823429, -0.3450044, -0.6444999>,
    <-0.6632355, -0.2954438, -0.6876276>,
    <-0.6603436, -0.3149398, -0.6817326>,
    <-0.6629792, -0.3288219, -0.6725584>,
    <-0.6664272, -0.3212928, -0.6727895>,
    <-0.6261394, -0.2917185, -0.7230835>,
    <-0.6226879, -0.2631719, -0.7368856>,
    <-0.6630132, -0.3446433, -0.6645559>,
    <-0.6605600, -0.3509343, -0.6637060>,
    <-0.6599353, -0.3470290, -0.6663755>,
    <-0.6290443, -0.3211961, -0.7079098>,
    <0.3930788, -0.0612745, 0.9174609>,
    <0.3616175, -0.0421718, 0.9313723>,
    <0.3564013, -0.0493319, 0.9330297>,
    <0.3635077, -0.0601553, 0.9296470>,
    <0.4328090, -0.0650195, 0.8991378>,
    <0.3558036, -0.0392381, 0.9337367>,
    <0.3234973, -0.0288492, 0.9457892>,
    <0.3308124, -0.0427118, 0.9427295>,
    <0.3135808, -0.0227135, 0.9492898>,
    <0.3416749, -0.0603999, 0.9378753>,
    <0.3332519, -0.0892942, 0.9385999>,
    <0.8852312, -0.2791958, 0.3720423>,
    <0.9001840, -0.2499057, 0.3566734>,
    <0.8902852, -0.2623111, 0.3722702>,
    <0.8794606, -0.2863604, 0.3801930>,
    <0.8802090, -0.2668018, 0.3924907>,
    <0.8898032, -0.2386433, 0.3889725>,
    <0.9055141, -0.2261705, 0.3590141>,
    <0.8907311, -0.2516123, 0.3785358>,
    <0.8983610, -0.2101535, 0.3857240>,
    <0.9299428, -0.1642536, 0.3289789>,
    <0.9265995, -0.2127857, 0.3100573>,
    <0.9119492, -0.2445735, 0.3294427>,
    <0.8789804, -0.2821055, 0.3844604>,
    <0.8960450, -0.2755554, 0.3480984>,
    <0.9170783, -0.2629987, 0.2996648>,
    <0.9306234, -0.2364072, 0.2793775>,
    <0.9309869, -0.2254312, 0.2871310>,
    <0.9227052, -0.2388194, 0.3026227>,
    <0.9400952, -0.2038679, 0.2732376>,
    <0.9390988, -0.1995260, 0.2797908>,
    <0.9453108, -0.1660755, 0.2807248>,
    <0.9478661, -0.1674057, 0.2711554>,
    <0.9345726, -0.2076206, 0.2889080>,
    <0.9503167, -0.1687087, 0.2616020>,
    <0.9447126, 0.2094290, 0.2523045>,
    <0.9402793, 0.2430227, 0.2383585>,
    <0.9398730, 0.2271597, 0.2550240>,
    <0.9439899, 0.2000620, 0.2624087>,
    <0.9479589, 0.1668794, 0.2711553>,
    <0.9451027, 0.1672553, 0.2807251>,
    <0.9300383, 0.1637112, 0.3289793>,
    <0.9370658, 0.2187200, 0.2721567>,
    <0.9299080, 0.2489958, 0.2706884>,
    <0.9326126, 0.2671289, 0.2426436>,
    <0.9351694, 0.2371604, 0.2630840>,
    <0.9217419, 0.2789937, 0.2693591>,
    <0.9413796, 0.2036576, 0.2689387>,
    <0.9507074, 0.1664932, 0.2616017>,
    <0.9257124, 0.2307753, 0.2996653>,
    <0.9241470, 0.2605768, 0.2793781>,
    <0.9189738, 0.2702640, 0.2871315>,
    <0.9184957, 0.2545287, 0.3026231>,
    <0.9137753, 0.2093842, 0.3480990>,
    <0.9120578, 0.2441674, 0.3294433>,
    <0.9160802, 0.2934926, 0.2732383>,
    <0.9130463, 0.2967545, 0.2797914>,
    <0.9088515, 0.2790217, 0.3100579>,
    <0.9131738, 0.2874814, 0.2889085>,
    <-0.9237035, 0.2912290, -0.2489129>,
    <-0.9175350, 0.2987724, -0.2624205>,
    <-0.9275365, 0.2731913, -0.2550346>,
    <-0.9365483, 0.2597956, -0.2353372>,
    <-0.9298222, 0.2493006, -0.2707025>,
    <-0.9214772, 0.2793254, -0.2699203>,
    <-0.9162009, 0.2940818, -0.2721980>,
    <-0.9276947, 0.2619636, -0.2660029>,
    <-0.9288099, 0.2856011, -0.2361020>,
    <-0.9433370, 0.2529062, -0.2148341>,
    <-0.9412492, 0.2348839, -0.2426511>,
    <-0.9563357, 0.2194634, -0.1930227>,
    <-0.9618524, 0.1697801, -0.2145103>,
    <-0.9371632, 0.2190539, -0.2715520>,
    <-0.9403326, 0.2697003, -0.2074522>,
    <-0.9280047, 0.2400000, -0.2849689>,
    <-0.9453839, 0.2288226, -0.2321411>,
    <-0.9538825, 0.2422243, -0.1773007>,
    <-0.8977820, 0.1994073, -0.3927139>,
    <-0.9443897, 0.2006796, -0.2604914>,
    <-0.8454362, 0.1598673, -0.5095881>,
    <-0.9384635, 0.1715811, -0.2997437>,
    <-0.9618198, 0.2083662, -0.1774434>,
    <-0.9650672, 0.1714113, -0.1981504>,
    <-0.9577266, -0.2123454, -0.1940856>,
    <-0.9182739, -0.1871028, -0.3489493>,
    <-0.8925211, -0.2156376, -0.3961142>,
    <-0.9276699, -0.2471557, -0.2798976>,
    <-0.9300702, -0.2549595, -0.2645090>,
    <-0.9579991, -0.2256319, -0.1769972>,
    <-0.9619137, -0.1694317, -0.2145107>,
    <-0.9655219, -0.1690139, -0.1979942>,
    <-0.9407524, -0.1598040, -0.2990780>,
    <-0.7956707, -0.1624404, -0.5835420>,
    <-0.7793288, -0.1974487, -0.5946938>,
    <-0.8575999, -0.1412614, -0.4945377>,
    <-0.8246225, -0.2459959, -0.5093956>,
    <-0.8508521, -0.2668556, -0.4525912>,
    <-0.9492339, -0.2366070, -0.2072975>,
    <-0.9238570, -0.2562051, -0.2843364>,
    <-0.9332296, -0.2745530, -0.2317396>,
    <-0.9472167, -0.2671740, -0.1771963>,
    <-0.9434069, -0.2526454, -0.2148341>,
    <-0.9471735, -0.2170672, -0.2361021>,
    <-0.8797044, -0.2769861, -0.3865214>,
    <-0.9183624, -0.2984540, -0.2598762>,
    <-0.9371681, -0.3004676, -0.1772995>,
    <-0.9379427, -0.2881071, -0.1930227>,
    <0.9730050, -0.1280899, 0.1919747>,
    <0.9597423, -0.0854270, 0.2675759>,
    <0.9225361, -0.1037726, 0.3716966>,
    <0.9337581, -0.1391842, 0.3297325>,
    <0.9773295, -0.1155796, 0.1773936>,
    <0.9639229, -0.0787601, 0.2542625>,
    <0.8846086, -0.0531091, 0.4633001>,
    <0.8354865, -0.0845795, 0.5429628>,
    <0.9076348, -0.0411468, 0.4177392>,
    <0.6822523, 0.0062094, 0.7310904>,
    <0.7282906, -0.0307243, 0.6845793>,
    <0.7055631, -0.0620800, 0.7059227>,
    <0.8397544, -0.1239337, 0.5286331>,
    <0.6788305, -0.0902906, 0.7287227>,
    <0.4946357, -0.0608989, 0.8669641>,
    <0.5586914, -0.0418125, 0.8283210>,
    <0.4386109, -0.0279483, 0.8982424>,
    <0.3762939, -0.0364581, 0.9257828>,
    <0.5492159, -0.0114633, 0.8356019>,
    <0.4117720, -0.0072283, 0.9112582>,
    <0.4899271, 0.0158807, 0.8716187>,
    <0.3841794, 0.0086054, 0.9232184>,
    <0.3285407, -0.0146903, 0.9443756>,
    <0.3262636, 0.0033709, 0.9452728>,
    <0.4315517, 0.0283392, 0.9016430>,
    <0.3783585, 0.0327983, 0.9250779>,
    <0.3529129, 0.0254312, 0.9353105>,
    <0.3673332, 0.0183009, 0.9299094>,
    <0.4311861, 0.0215841, 0.9020048>,
    <0.3493542, 0.0258739, 0.9366334>,
    <0.3345287, 0.0328348, 0.9418134>,
    <0.3187172, 0.0232636, 0.9475643>,
    <0.3250918, 0.0343157, 0.9450597>,
    <0.4133888, 0.0894293, 0.9061524>,
    <0.3191849, 0.0143132, 0.9475844>,
    <0.4438894, 0.0199755, 0.8958589>,
    <0.5173751, 0.0526684, 0.8541364>,
    <0.4152845, 0.0487556, 0.9083841>,
    <0.3534589, 0.0255434, 0.9351012>,
    <0.6360122, 0.0260067, 0.7712407>,
    <0.6751294, 0.0587178, 0.7353588>,
    <0.5060087, 0.0825413, 0.8585698>,
    <0.4069608, 0.0707160, 0.9107042>,
    <0.6841528, 0.0925931, 0.7234373>,
    <0.3453721, 0.0495976, 0.9371543>,
    <0.4133888, 0.0894293, 0.9061524>,
    <0.3531620, 0.1501003, 0.9234427>,
    <0.3375216, 0.1440180, 0.9302354>,
    <0.3516157, 0.1538248, 0.9234199>,
    <0.3689286, 0.1627292, 0.9151016>,
    <0.4100920, 0.1843500, 0.8932187>,
    <0.3723606, 0.1575188, 0.9146231>,
    <0.3226135, 0.1107528, 0.9400289>,
    <0.3329022, 0.1364092, 0.9330427>,
    <0.3329022, 0.1364092, 0.9330427>,
    <0.3136025, 0.1285010, 0.9408193>,
    <0.3294305, 0.1433656, 0.9332319>,
    <0.3547269, 0.1593632, 0.9212883>,
    <0.3136025, 0.1285010, 0.9408193>,
    <0.2925932, 0.1198923, 0.9486912>,
    <0.2925932, 0.1198923, 0.9486912>,
    <0.3409514, 0.1589927, 0.9265384>,
    <0.3780894, 0.1732405, 0.9094153>,
    <0.4449237, 0.2120486, 0.8701025>,
    <0.4110820, -0.1823220, 0.8931799>,
    <0.4131550, -0.1756825, 0.8935539>,
    <0.4170952, -0.1717746, 0.8924825>,
    <0.4078753, -0.1753649, 0.8960384>,
    <0.3663278, -0.1708232, 0.9146712>,
    <0.4216149, -0.1867839, 0.8873289>,
    <0.4216149, -0.1867839, 0.8873289>,
    <0.4030367, -0.1785534, 0.8975969>,
    <0.3771295, -0.1534997, 0.9133516>,
    <0.4168045, -0.1614166, 0.8945494>,
    <0.4030367, -0.1785534, 0.8975969>,
    <0.3434512, -0.1521558, 0.9267631>,
    <0.3434512, -0.1521558, 0.9267631>,
    <0.3348325, -0.1240685, 0.9340740>,
    <0.3519829, -0.1287268, 0.9271124>,
    <0.4202732, -0.1466026, 0.8954765>,
    <0.4328685, -0.1722132, 0.8848545>,
    <0.4745071, -0.1651564, 0.8646192>,
    <0.3915273, 0.1615961, 0.9058659>,
    <0.4470298, 0.2005951, 0.8717373>,
    <0.4638619, 0.2034054, 0.8622403>,
    <0.4429225, 0.1841546, 0.8774433>,
    <0.4285856, 0.1644160, 0.8884153>,
    <0.3658254, 0.1338666, 0.9210057>,
    <0.3226135, 0.1107528, 0.9400289>,
    <0.5096061, 0.2432244, 0.8253142>,
    <0.5090493, 0.2297843, 0.8294987>,
    <0.4963520, 0.2091637, 0.8425469>,
    <0.4794087, 0.1843249, 0.8580161>,
    <0.9593685, -0.1263119, 0.2523042>,
    <0.9666923, -0.0932279, 0.2383582>,
    <0.9608849, -0.1079952, 0.2550240>,
    <0.9554856, -0.1348667, 0.2624087>,
    <0.9553606, -0.1149658, 0.2721561>,
    <0.9589894, -0.0840678, 0.2706878>,
    <0.9677326, -0.0679532, 0.2426435>,
    <0.9598853, -0.0969890, 0.2630842>,
    <0.9615757, -0.0530860, 0.2693585>,
    <0.9767216, -0.0001965, 0.2145106>,
    <0.9794663, -0.0500889, 0.1952866>,
    <0.9729209, -0.0852702, 0.2148346>,
    <0.9542624, -0.1305953, 0.2689390>,
    <0.9648228, -0.1200264, 0.2339029>,
    <0.9733280, -0.1023076, 0.2053432>,
    <0.9811668, -0.0728979, 0.1788790>,
    <0.9721413, -0.0612837, 0.2262423>,
    <0.9591341, -0.0754418, 0.2727091>,
    <0.9831544, -0.0382594, 0.1787279>,
    <0.9674205, -0.0338019, 0.2509083>,
    <0.9804999, -0.0012820, 0.1965154>,
    <0.9584461, -0.0059965, 0.2852106>,
    <0.9309960, -0.0410313, 0.3627159>,
    <0.8881305, -0.0094084, 0.4594950>,
    <0.9804923, 0.0428177, 0.1918373>,
    <0.9600928, 0.0825181, 0.2672315>,
    <0.9267548, 0.0580140, 0.3711602>,
    <0.9438990, 0.0250998, 0.3292792>,
    <0.9825605, 0.0558830, 0.1773469>,
    <0.9630171, 0.0898112, 0.2540315>,
    <0.8727484, 0.1011846, 0.4775687>,
    <0.8281345, 0.0610379, 0.5571962>,
    <0.8975883, 0.1167543, 0.4250925>,
    <0.8365506, 0.0227929, 0.5474154>,
    <0.9763165, 0.0682641, 0.2052953>,
    <0.9789251, 0.0985882, 0.1788461>,
    <0.9680426, 0.1084613, 0.2261186>,
    <0.9577181, 0.0922612, 0.2725142>,
    <0.9710075, 0.0493369, 0.2339022>,
    <0.9729473, 0.0849714, 0.2148336>,
    <0.9748698, 0.1330462, 0.1786828>,
    <0.9586414, 0.1347100, 0.2507189>,
    <0.9732840, 0.1207548, 0.1952856>,
    <0.9234128, 0.1211840, 0.3641746>,
    <-0.8865180, 0.2795730, -0.3686797>,
    <-0.8794563, 0.2863964, -0.3801758>,
    <-0.8902983, 0.2622890, -0.3722546>,
    <-0.9013067, 0.2501255, -0.3536714>,
    <-0.8898177, 0.2386252, -0.3889504>,
    <-0.8811028, 0.2670993, -0.3902765>,
    <-0.8777241, 0.2817473, -0.3875807>,
    <-0.8896304, 0.2512777, -0.3813361>,
    <-0.8952798, 0.2753313, -0.3502381>,
    <-0.9119541, 0.2445535, -0.3294439>,
    <-0.9055408, 0.2260822, -0.3590023>,
    <-0.9273208, 0.2128934, -0.3078189>,
    <-0.9299472, 0.1642267, -0.3289800>,
    <-0.8975235, 0.2098855, -0.3878139>,
    <-0.9170607, 0.2630481, -0.2996755>,
    <-0.9217996, 0.2386304, -0.3055177>,
    <-0.9309883, 0.2254095, -0.2871436>,
    <-0.9314744, 0.2366015, -0.2763605>,
    <-0.9336152, 0.2073861, -0.2921535>,
    <-0.9391134, 0.1994392, -0.2798035>,
    <-0.9498883, 0.1686546, -0.2631880>,
    <-0.9478673, 0.1673785, -0.2711678>,
    <-0.9410514, 0.2039756, -0.2698447>,
    <-0.9457819, 0.1660825, -0.2791294>,
    <-0.9455651, -0.2096401, -0.2489128>,
    <-0.9439948, -0.2000230, -0.2624205>,
    <-0.9398658, -0.2271777, -0.2550346>,
    <-0.9409724, -0.2432847, -0.2353371>,
    <-0.9299000, -0.2490106, -0.2707023>,
    <-0.9376855, -0.2188358, -0.2699201>,
    <-0.9300335, -0.1637381, -0.3289795>,
    <-0.9455479, -0.1674100, -0.2791290>,
    <-0.9479508, -0.1669053, -0.2711678>,
    <-0.9404941, -0.2034182, -0.2721981>,
    <-0.9343890, -0.2369803, -0.2660030>,
    <-0.9502862, -0.1663974, -0.2631883>,
    <-0.9325876, -0.2672093, -0.2426510>,
    <-0.9211341, -0.2788755, -0.2715519>,
    <-0.9257220, -0.2307242, -0.2996752>,
    <-0.9176171, -0.2542400, -0.3055175>,
    <-0.9189642, -0.2702840, -0.2871433>,
    <-0.9249813, -0.2608344, -0.2763603>,
    <-0.9120522, -0.2441877, -0.3294436>,
    <-0.9130008, -0.2091962, -0.3502377>,
    <-0.9122275, -0.2872061, -0.2921534>,
    <-0.9130157, -0.2968374, -0.2798033>,
    <-0.9169623, -0.2938778, -0.2698445>,
    <-0.9095302, -0.2792894, -0.3078186>,
    <-0.3244189, 0.0413089, -0.9450111>,
    <-0.2643707, 0.0375871, -0.9636884>,
    <-0.2440774, 0.0286673, -0.9693319>,
    <-0.2784381, 0.0275369, -0.9600593>,
    <-0.2638923, 0.0283964, -0.9641341>,
    <-0.3332320, 0.0457652, -0.9417335>,
    <-0.2030341, 0.0273646, -0.9787892>,
    <-0.1875142, 0.0214885, -0.9820268>,
    <-0.3670285, 0.0983449, 0.9249964>,
    <-0.2090386, 0.0200937, -0.9777009>,
    <-0.9582360, -0.0635741, -0.2788227>,
    <-0.2307243, 0.0187513, -0.9728385>,
    <0.8247152, -0.2601690, 0.5021524>,
    <0.8426229, -0.2340628, 0.4849756>,
    <0.8315678, -0.2450691, 0.4984337>,
    <0.8196128, -0.2668496, 0.5069774>,
    <0.8157151, -0.2472283, 0.5229598>,
    <0.8271028, -0.2218723, 0.5164046>,
    <0.8488799, -0.2121683, 0.4841359>,
    <0.8323783, -0.2351852, 0.5018310>,
    <0.8373496, -0.1959990, 0.5103236>,
    <0.8785485, -0.1552475, 0.4517198>,
    <0.8782334, -0.2017794, 0.4335795>,
    <0.8614166, -0.2310771, 0.4522883>,
    <0.8202985, -0.2632392, 0.5077553>,
    <0.8436574, -0.2594615, 0.4700234>,
    <0.8722982, -0.2501342, 0.4201532>,
    <0.8878406, -0.2256020, 0.4010520>,
    <0.8878876, -0.2150621, 0.4066987>,
    <0.8783137, -0.2273219, 0.4205827>,
    <0.8978933, -0.1948636, 0.3947350>,
    <0.8969710, -0.1907173, 0.3988356>,
    <0.9021241, -0.1586194, 0.4012629>,
    <0.9069375, -0.1602665, 0.3895882>,
    <0.8922533, -0.1982912, 0.4056656>,
    <0.9115357, -0.1618697, 0.3780223>,
    <0.9062304, 0.2008247, 0.3720428>,
    <0.9045349, 0.2336671, 0.3566739>,
    <0.9021650, 0.2179743, 0.3722708>,
    <0.9048152, 0.1917346, 0.3801937>,
    <0.9070568, 0.1595896, 0.3895883>,
    <0.9019705, 0.1594911, 0.4012629>,
    <0.8786634, 0.1545963, 0.4517197>,
    <0.8956842, 0.2090472, 0.3924908>,
    <0.8899139, 0.2382302, 0.3889726>,
    <0.8972833, 0.2568873, 0.3590146>,
    <0.8972017, 0.2274626, 0.3785365>,
    <0.8830802, 0.2671821, 0.3857242>,
    <0.9022719, 0.1951794, 0.3844612>,
    <0.9119260, 0.1596557, 0.3780226>,
    <0.8804997, 0.2195265, 0.4201529>,
    <0.8816938, 0.2485433, 0.4010514>,
    <0.8764645, 0.2576946, 0.4066982>,
    <0.8743031, 0.2422902, 0.4205824>,
    <0.8603597, 0.1971284, 0.4700230>,
    <0.8615475, 0.2305897, 0.4522878>,
    <0.8750306, 0.2801899, 0.3947342>,
    <0.8721586, 0.2833195, 0.3988351>,
    <0.8614624, 0.2643706, 0.4335789>,
    <0.8718598, 0.2744014, 0.4056654>,
    <-0.9725425, 0.1280156, -0.1943528>,
    <-0.9265610, 0.1382361, -0.3498221>,
    <-0.9120122, 0.1025783, -0.3971289>,
    <-0.9560683, 0.0849825, -0.2805556>,
    <-0.9610631, 0.0784845, -0.2649487>,
    <-0.9773804, 0.1156194, -0.1770869>,
    <-0.7935094, 0.1190161, -0.5968065>,
    <-0.7937686, 0.0804131, -0.6028807>,
    <-0.5567908, 0.0772655, -0.8270514>,
    <-0.6134376, 0.0539822, -0.7878960>,
    <-0.8541236, 0.0500610, -0.5176550>,
    <-0.6279015, 0.0243805, -0.7779109>,
    <-0.5929239, 0.0005927, -0.8052583>,
    <-0.8878159, 0.0398115, -0.4584735>,
    <-0.3550748, 0.0492315, -0.9335406>,
    <-0.2706137, 0.0299265, -0.9622227>,
    <-0.3366801, 0.0190563, -0.9414262>,
    <-0.4398264, 0.0320795, -0.8975097>,
    <-0.2637351, 0.0086218, -0.9645566>,
    <-0.3330143, -0.0012809, -0.9429209>,
    <-0.9582360, -0.0635741, -0.2788227>,
    <-0.2837503, -0.0104573, -0.9588412>,
    <-0.3062258, -0.0083983, -0.9519219>,
    <-0.4334052, 0.0037900, -0.9011912>,
    <-0.3715510, -0.0075165, -0.9283821>,
    <-0.3252659, -0.0135917, -0.9455249>,
    <-0.2802568, -0.0113472, -0.9598580>,
    <-0.2545700, -0.0157173, -0.9669266>,
    <-0.2747723, -0.0200891, -0.9612994>,
    <-0.2660925, -0.0175066, -0.9637885>,
    <-0.3446913, -0.0115671, -0.9386448>,
    <-0.2479671, -0.0152654, -0.9686482>,
    <-0.2221448, -0.0164859, -0.9748743>,
    <-0.9582360, -0.0635741, -0.2788227>,
    <-0.2427939, -0.0212422, -0.9698453>,
    <-0.2427939, -0.0212422, -0.9698453>,
    <-0.2144618, -0.0187634, -0.9765521>,
    <-0.2246894, -0.0196472, -0.9742323>,
    <-0.2144618, -0.0187634, -0.9765521>,
    <-0.2065220, -0.0180687, -0.9782751>,
    <-0.2065220, -0.0180687, -0.9782751>,
    <-0.2220766, -0.0391593, -0.9742425>,
    <-0.2317501, -0.0223342, -0.9725189>,
    <-0.3805768, -0.0160154, -0.9246106>,
    <-0.2801374, -0.0192009, -0.9597679>,
    <-0.3427992, -0.0395399, -0.9385762>,
    <-0.4555147, -0.0461376, -0.8890319>,
    <-0.6290865, -0.0547222, -0.7754068>,
    <-0.5873125, -0.0228017, -0.8090390>,
    <-0.2574799, -0.0355177, -0.9656307>,
    <-0.3274590, -0.0563476, -0.9431837>,
    <-0.2220766, -0.0391593, -0.9742425>,
    <-0.4425229, -0.0719430, -0.8938667>,
    <-0.6414396, -0.0865580, -0.7622749>,
    <-0.3595591, 0.1674303, -0.9179784>,
    <-0.3616355, 0.1686373, -0.9169412>,
    <-0.3452870, 0.1610146, -0.9245816>,
    <-0.3366723, 0.1560595, -0.9285996>,
    <-0.3290101, 0.1507783, -0.9322115>,
    <-0.3549733, 0.1651788, -0.9201684>,
    <-0.3674340, 0.1713601, -0.9141269>,
    <-0.3674652, 0.1713620, -0.9141140>,
    <-0.3674652, 0.1713620, -0.9141140>,
    <-0.3674858, 0.1713645, -0.9141052>,
    <-0.3594716, 0.1676866, -0.9179659>,
    <-0.3419636, 0.1590698, -0.9261521>,
    <-0.3674858, 0.1713645, -0.9141052>,
    <-0.3674993, 0.1713664, -0.9140995>,
    <-0.3674993, 0.1713664, -0.9140995>,
    <-0.3674917, 0.1713603, -0.9141037>,
    <-0.3639155, 0.1690953, -0.9159543>,
    <-0.3623171, 0.1662679, -0.9171048>,
    <-0.3214259, 0.1477826, -0.9353319>,
    <-0.3617012, 0.1603909, -0.9183937>,
    <-0.4058505, 0.1451551, -0.9023388>,
    <-0.3075279, 0.1358606, -0.9417900>,
    <-0.3722317, 0.1731556, -0.9118447>,
    <-0.3837418, 0.1809874, -0.9055307>,
    <-0.3979242, 0.1844806, -0.8986786>,
    <-0.3883925, 0.1774318, -0.9042507>,
    <-0.3674917, 0.1713603, -0.9141037>,
    <-0.4049706, 0.1944679, -0.8934098>,
    <-0.4224146, 0.1951276, -0.8851503>,
    <-0.4668532, 0.2266951, -0.8547850>,
    <-0.4802258, 0.2195461, -0.8492248>,
    <-0.4183457, 0.1857935, -0.8890825>,
    <-0.4779842, 0.2046478, -0.8541958>,
    <-0.5189357, 0.2458640, -0.8186920>,
    <-0.5307254, 0.2388881, -0.8131808>,
    <-0.5328805, 0.2319864, -0.8137694>,
    <-0.5240402, 0.2341109, -0.8188858>,
    <-0.5556247, 0.2301945, -0.7989316>,
    <-0.5394602, 0.2195431, -0.8128859>,
    <-0.5915156, 0.2163245, -0.7767322>,
    <-0.5541953, 0.2032201, -0.8071983>,
    <-0.5159017, 0.2136737, -0.8295716>,
    <-0.5097597, 0.1873145, -0.8396775>,
    <-0.5375057, -0.2231147, -0.8132082>,
    <-0.5609586, -0.2263414, -0.7963008>,
    <-0.5692478, -0.2484210, -0.7837372>,
    <-0.5660715, -0.2578303, -0.7829985>,
    <-0.5433796, -0.2555133, -0.7996571>,
    <-0.5244422, -0.2299829, -0.8197977>,
    <-0.4024343, -0.1501291, -0.9030547>,
    <-0.5103717, -0.1839636, -0.8400465>,
    <-0.5549897, -0.2004761, -0.8073387>,
    <-0.5825567, -0.2380507, -0.7771483>,
    <-0.5803935, -0.2610793, -0.7713501>,
    <-0.5921322, -0.2144842, -0.7767728>,
    <-0.5822224, -0.2833014, -0.7620744>,
    <-0.5563341, -0.2817103, -0.7817491>,
    <-0.3716126, -0.1738928, -0.9119569>,
    <-0.3866947, -0.1786932, -0.9047298>,
    <-0.3971175, -0.1865932, -0.8985993>,
    <-0.3836945, -0.1828121, -0.9051841>,
    <-0.3673852, -0.1713381, -0.9141506>,
    <-0.3667363, -0.1707191, -0.9145269>,
    <-0.3693155, -0.1704929, -0.9135306>,
    <-0.4113310, -0.1868006, -0.8921392>,
    <-0.4214341, -0.1988332, -0.8847930>,
    <-0.3703865, -0.1667892, -0.9137807>,
    <-0.4749036, -0.2132113, -0.8538194>,
    <-0.4775664, -0.2276469, -0.8485913>,
    <-0.4090270, -0.2003110, -0.8902654>,
    <-0.4635104, -0.2348076, -0.8544141>,
    <-0.5215359, -0.2398946, -0.8188106>,
    <-0.5239098, -0.2532095, -0.8132672>,
    <-0.5205123, -0.2595533, -0.8134489>,
    <-0.5166287, -0.2516589, -0.8183902>,
    <-0.5335224, -0.2777984, -0.7988629>,
    <-0.5152521, -0.2724344, -0.8125853>,
    <-0.4958152, -0.2583894, -0.8290972>,
    <0.9202641, -0.1212355, 0.3720429>,
    <0.9299036, -0.0897939, 0.3566739>,
    <0.9223094, -0.1037297, 0.3722707>,
    <0.9158254, -0.1292933, 0.3801936>,
    <0.9131661, -0.1099019, 0.3924911>,
    <0.9177249, -0.0805052, 0.3889728>,
    <0.9310313, -0.0654938, 0.3590144>,
    <0.9208908, -0.0931160, 0.3785361>,
    <0.9212055, -0.0509621, 0.3857243>,
    <0.9443373, -0.0002753, 0.3289788>,
    <0.9494723, -0.0486508, 0.3100573>,
    <0.9405644, -0.0824997, 0.3294427>,
    <0.9146137, -0.1251865, 0.3844608>,
    <0.9302818, -0.1157726, 0.3480984>,
    <0.9488152, -0.0997543, 0.2996645>,
    <0.9575369, -0.0712147, 0.2793772>,
    <0.9559889, -0.0603424, 0.2871305>,
    <0.9501579, -0.0749653, 0.3026222>,
    <0.9612145, -0.0375250, 0.2732373>,
    <0.9594792, -0.0334221, 0.2797903>,
    <0.9597882, 0.0005991, 0.2807244>,
    <0.9625357, -0.0002671, 0.2711548>,
    <0.9564274, -0.0421796, 0.2889075>,
    <0.9651753, -0.0011248, 0.2616015>,
    <0.9667275, 0.0421998, 0.2523037>,
    <0.9681950, 0.0760530, 0.2383577>,
    <0.9650402, 0.0605016, 0.2550233>,
    <0.9643891, 0.0331006, 0.2624081>,
    <0.9608102, 0.0526776, 0.2721559>,
    <0.9590185, 0.0837363, 0.2706876>,
    <0.9648307, 0.1011244, 0.2426429>,
    <0.9621446, 0.0711671, 0.2630835>,
    <0.9561856, 0.1146965, 0.2693582>,
    <0.9624428, 0.0370948, 0.2689383>,
    <0.9517227, 0.0665213, 0.2996646>,
    <0.9553559, 0.0961418, 0.2793775>,
    <0.9519436, 0.1065801, 0.2871308>,
    <0.9487404, 0.0911669, 0.3026223>,
    <0.9362524, 0.0475280, 0.3480985>,
    <0.9406009, 0.0820810, 0.3294429>,
    <0.9531275, 0.1299582, 0.2732378>,
    <0.9507061, 0.1336975, 0.2797907>,
    <0.9434956, 0.1169624, 0.3100577>,
    <0.9492215, 0.1245431, 0.2889076>,
    <-0.3637782, -0.1696562, -0.9159051>,
    <-0.3644866, -0.1699770, -0.9155639>,
    <-0.3564443, -0.1662234, -0.9194114>,
    <-0.3562180, -0.1657487, -0.9195847>,
    <-0.3673852, -0.1713381, -0.9141506>,
    <-0.3672920, -0.1712942, -0.9141963>,
    <-0.3672920, -0.1712942, -0.9141963>,
    <-0.3672648, -0.1712775, -0.9142104>,
    <-0.3632918, -0.1692065, -0.9161814>,
    <-0.3507402, -0.1625816, -0.9222519>,
    <-0.3672648, -0.1712775, -0.9142104>,
    <-0.3672709, -0.1712710, -0.9142091>,
    <-0.3672709, -0.1712710, -0.9142091>,
    <-0.3673072, -0.1712686, -0.9141950>,
    <-0.3595368, -0.1670853, -0.9180500>,
    <-0.3430537, -0.1559554, -0.9262786>,
    <-0.3436512, -0.1581787, -0.9256799>,
    <-0.3307158, -0.1436803, -0.9327288>,
    <-0.9602417, 0.1264050, -0.2489131>,
    <-0.9554769, 0.1349050, -0.2624205>,
    <-0.9608843, 0.1079758, -0.2550345>,
    <-0.9674330, 0.0932187, -0.2353372>,
    <-0.9589867, 0.0840511, -0.2707027>,
    <-0.9559823, 0.1150689, -0.2699205>,
    <-0.9533486, 0.1305173, -0.2721978>,
    <-0.9590905, 0.0968911, -0.2660027>,
    <-0.9642934, 0.1199760, -0.2361015>,
    <-0.9729225, 0.0852551, -0.2148336>,
    <-0.9677367, 0.0678691, -0.2426509>,
    <-0.9799164, 0.0500631, -0.1930222>,
    <-0.9767217, 0.0001768, -0.2145103>,
    <-0.9609639, 0.0529892, -0.2715521>,
    <-0.9728933, 0.1023172, -0.2073879>,
    <-0.9556598, 0.0752141, -0.2847055>,
    <-0.9707962, 0.0611844, -0.2319723>,
    <-0.9814607, 0.0729049, -0.1772564>,
    <-0.9203430, 0.0405488, -0.3890046>,
    <-0.9649604, 0.0336409, -0.2602301>,
    <-0.8663071, 0.0102093, -0.4994075>,
    <-0.9541187, 0.0059960, -0.2993687>,
    <-0.9834011, 0.0381826, -0.1773818>,
    <-0.9801888, 0.0012192, -0.1980616>,
    <-0.9800273, -0.0428110, -0.1942000>,
    <-0.9366730, -0.0247847, -0.3493270>,
    <-0.9162197, -0.0573653, -0.3965484>,
    <-0.9564123, -0.0823195, -0.2801767>,
    <-0.9601616, -0.0895870, -0.2646959>,
    <-0.9826184, -0.0558528, -0.1770356>,
    <-0.8104392, -0.0214885, -0.5854285>,
    <-0.8013487, -0.0590887, -0.5952720>,
    <-0.8545032, -0.0990458, -0.5099159>,
    <-0.8840545, -0.1150402, -0.4530048>,
    <-0.9758910, -0.0681790, -0.2073366>,
    <-0.9542645, -0.0918825, -0.2844940>,
    <-0.9667039, -0.1083255, -0.2318388>,
    <-0.9792160, -0.0986320, -0.1772224>,
    <-0.9729458, -0.0849861, -0.2148344>,
    <-0.9704771, -0.0492944, -0.2361021>,
    <-0.9143093, -0.1200021, -0.3868306>,
    <-0.9561968, -0.1344418, -0.2600252>,
    <-0.9750998, -0.1331642, -0.1773347>,
    <-0.9737225, -0.1208579, -0.1930230>,
    <-0.8264682, 0.2606896, -0.4989903>,
    <-0.8196100, 0.2668849, -0.5069633>,
    <-0.8315843, 0.2450441, -0.4984184>,
    <-0.8441623, 0.2343914, -0.4821313>,
    <-0.8271160, 0.2218516, -0.5163923>,
    <-0.8169095, 0.2476176, -0.5209072>,
    <-0.8186606, 0.2627568, -0.5106404>,
    <-0.8309317, 0.2347488, -0.5044259>,
    <-0.8426376, 0.2591561, -0.4720170>,
    <-0.8614336, 0.2310560, -0.4522667>,
    <-0.8489133, 0.2120748, -0.4841183>,
    <-0.8792659, 0.2019522, -0.4314009>,
    <-0.8785648, 0.1552174, -0.4516984>,
    <-0.8362427, 0.1956627, -0.5122638>,
    <-0.8722950, 0.2501863, -0.4201289>,
    <-0.8770742, 0.2270436, -0.4233108>,
    <-0.8879041, 0.2150385, -0.4066752>,
    <-0.8891015, 0.2258953, -0.3980827>,
    <-0.8909200, 0.1979671, -0.4087427>,
    <-0.8970006, 0.1906247, -0.3988133>,
    <-0.9109235, 0.1617777, -0.3795344>,
    <-0.9069521, 0.1602349, -0.3895674>,
    <-0.8993130, 0.1950622, -0.3913909>,
    <-0.9028200, 0.1586573, -0.3996798>,
    <-0.9075338, -0.2011418, -0.3686794>,
    <-0.9048299, -0.1917017, -0.3801753>,
    <-0.9021656, -0.2180003, -0.3722542>,
    <-0.9056173, -0.2340384, -0.3536711>,
    <-0.8899173, -0.2382534, -0.3889505>,
    <-0.8966071, -0.2092367, -0.3902766>,
    <-0.8786680, -0.1546300, -0.4516991>,
    <-0.9026371, -0.1596933, -0.3996802>,
    <-0.9070597, -0.1596242, -0.3895675>,
    <-0.9010052, -0.1948619, -0.3875802>,
    <-0.8960815, -0.2272025, -0.3813357>,
    <-0.9113194, -0.1595328, -0.3795341>,
    <-0.8972625, -0.2569776, -0.3590020>,
    <-0.8822209, -0.2669956, -0.3878140>,
    <-0.8805225, -0.2194797, -0.4201294>,
    <-0.8730902, -0.2419115, -0.4233111>,
    <-0.8764665, -0.2577231, -0.4066759>,
    <-0.8829318, -0.2489195, -0.3980835>,
    <-0.8615510, -0.2306163, -0.4522675>,
    <-0.8593233, -0.1968829, -0.4720177>,
    <-0.8705427, -0.2740154, -0.4087431>,
    <-0.8721375, -0.2834143, -0.3988140>,
    <-0.8763587, -0.2807275, -0.3913917>,
    <-0.8624424, -0.2647371, -0.4314016>,
    <-0.3535970, 0.1620187, -0.9212595>,
    <-0.3293984, 0.1448065, -0.9330208>,
    <-0.3381665, 0.1401292, -0.9305951>,
    <-0.3464655, 0.1502918, -0.9259450>,
    <-0.3411030, 0.1591248, -0.9264600>,
    <-0.3639784, 0.1697683, -0.9158048>,
    <-0.3639784, 0.1697683, -0.9158048>,
    <-0.3674340, 0.1713601, -0.9141269>,
    <-0.3210061, 0.1259980, -0.9386584>,
    <-0.3370206, 0.1236365, -0.9333440>,
    <-0.3458993, 0.1100872, -0.9317910>,
    <-0.3480203, 0.1088475, -0.9311467>,
    <-0.3296239, 0.1265610, -0.9355910>,
    <-0.3321871, 0.1034741, -0.9375206>,
    <-0.3141454, 0.0977959, -0.9443244>,
    <-0.2861131, 0.1335054, -0.9488496>,
    <-0.2861131, 0.1335054, -0.9488496>,
    <-0.3411030, 0.1591248, -0.9264600>,
    <-0.3565409, -0.1616707, -0.9201854>,
    <-0.3470850, -0.1457384, -0.9264407>,
    <-0.3426306, -0.1357127, -0.9296162>,
    <-0.3388541, -0.1447698, -0.9296341>,
    <-0.3673072, -0.1712686, -0.9141950>,
    <-0.3632071, -0.1693258, -0.9161929>,
    <-0.3632071, -0.1693258, -0.9161929>,
    <-0.3358291, -0.1565235, -0.9288268>,
    <-0.3324289, -0.1201923, -0.9354383>,
    <-0.3384143, -0.1169189, -0.9337054>,
    <-0.3358291, -0.1565235, -0.9288268>,
    <-0.2727164, -0.1270638, -0.9536669>,
    <-0.2727164, -0.1270638, -0.9536669>,
    <-0.3254306, -0.0968413, -0.9405938>,
    <-0.3377909, -0.1006007, -0.9358295>,
    <-0.3418747, -0.1023851, -0.9341515>,
    <-0.3270549, -0.1221484, -0.9370778>,
    <-0.3284258, -0.1005500, -0.9391625>,
    <-0.9215975, 0.1213833, -0.3686789>,
    <-0.9158279, 0.1293293, -0.3801751>,
    <-0.9223189, 0.1037054, -0.3722540>,
    <-0.9310480, 0.0898151, -0.3536707>,
    <-0.9177366, 0.0804846, -0.3889497>,
    <-0.9140985, 0.1100394, -0.3902758>,
    <-0.9133146, 0.1250516, -0.3875803>,
    <-0.9197490, 0.0929774, -0.3813357>,
    <-0.9294893, 0.1156846, -0.3502380>,
    <-0.9405658, 0.0824788, -0.3294439>,
    <-0.9310426, 0.0654019, -0.3590018>,
    <-0.9502014, 0.0486315, -0.3078187>,
    <-0.9443370, 0.0002481, -0.3289796>,
    <-0.9203346, 0.0508434, -0.3878132>,
    <-0.9488063, 0.0998058, -0.2996756>,
    <-0.9492330, 0.0749361, -0.3055180>,
    <-0.9559863, 0.0603205, -0.2871439>,
    <-0.9584086, 0.0712580, -0.2763607>,
    <-0.9554436, 0.0421148, -0.2921538>,
    <-0.9594783, 0.0333339, -0.2798038>,
    <-0.9647438, 0.0011460, -0.2631884>,
    <-0.9625319, 0.0002403, -0.2711682>,
    <-0.9621747, 0.0374648, -0.2698449>,
    <-0.9602532, -0.0006739, -0.2791296>,
    <-0.9676034, -0.0422594, -0.2489134>,
    <-0.9643869, -0.0330611, -0.2624210>,
    <-0.9650360, -0.0605202, -0.2550351>,
    <-0.9689227, -0.0761903, -0.2353377>,
    <-0.9590128, -0.0837519, -0.2707028>,
    <-0.9614402, -0.0526837, -0.2699205>,
    <-0.9615291, -0.0370126, -0.2721983>,
    <-0.9613446, -0.0711250, -0.2660034>,
    <-0.9648198, -0.1012075, -0.2426515>,
    <-0.9555661, -0.1146853, -0.2715524>,
    <-0.9517230, -0.0664689, -0.2996753>,
    <-0.9478246, -0.0910348, -0.3055178>,
    <-0.9519374, -0.1066011, -0.2871435>,
    <-0.9562222, -0.0962503, -0.2763601>,
    <-0.9405990, -0.0821017, -0.3294432>,
    <-0.9354569, -0.0474770, -0.3502374>,
    <-0.9482415, -0.1244360, -0.2921538>,
    <-0.9506902, -0.1337842, -0.2798034>,
    <-0.9540630, -0.1301842, -0.2698443>,
    <-0.9442106, -0.1171080, -0.3078181>,
    <0.7151318, -0.2256362, 0.6615700>,
    <0.7472002, -0.2076246, 0.6313350>,
    <0.7376887, -0.2174437, 0.6391663>,
    <0.7203658, -0.2345822, 0.6527207>,
    <0.7014619, -0.2111344, 0.6807154>,
    <0.7273579, -0.1944774, 0.6581254>,
    <0.7612939, -0.1904475, 0.6198074>,
    <0.7441178, -0.2102882, 0.6340879>,
    <0.7451298, -0.1744192, 0.6437076>,
    <0.7994724, -0.1413276, 0.5838410>,
    <0.8024773, -0.1844797, 0.5674482>,
    <0.7837117, -0.2102742, 0.5844490>,
    <0.7310673, -0.2345171, 0.6407357>,
    <0.7644541, -0.2350831, 0.6002882>,
    <0.8028455, -0.2301441, 0.5499752>,
    <0.8198975, -0.2083858, 0.5332386>,
    <0.8207792, -0.1988591, 0.5355153>,
    <0.8106163, -0.2097473, 0.5467241>,
    <0.8305824, -0.1804242, 0.5268585>,
    <0.8312136, -0.1768926, 0.5270607>,
    <0.8341172, -0.1467992, 0.5316940>,
    <0.8428492, -0.1490114, 0.5171082>,
    <0.8275548, -0.1839695, 0.5303850>,
    <0.8510924, -0.1511418, 0.5027901>,
    <0.8443089, 0.1870446, 0.5021522>,
    <0.8467643, 0.2186071, 0.4849754>,
    <0.8426936, 0.2035479, 0.4984334>,
    <0.8432305, 0.1787079, 0.5069771>,
    <0.8429841, 0.1482465, 0.5171081>,
    <0.8340220, 0.1473387, 0.5316941>,
    <0.7995952, 0.1406311, 0.5838411>,
    <0.8300442, 0.1937515, 0.5229599>,
    <0.8272282, 0.2214042, 0.5164046>,
    <0.8412358, 0.2406968, 0.4841356>,
    <0.8384536, 0.2125129, 0.5018305>,
    <0.8231656, 0.2489347, 0.5103234>,
    <0.8420192, 0.1821775, 0.5077549>,
    <0.8514589, 0.1490639, 0.5027900>,
    <0.8103565, 0.2021120, 0.5499755>,
    <0.8142448, 0.2294812, 0.5332390>,
    <0.8102451, 0.2381724, 0.5355155>,
    <0.8068879, 0.2236616, 0.5467242>,
    <0.7795780, 0.1786389, 0.6002885>,
    <0.7838511, 0.2097529, 0.5844494>,
    <0.8095174, 0.2590392, 0.5268588>,
    <0.8082983, 0.2624132, 0.5270609>,
    <0.7872054, 0.2414744, 0.5674485>,
    <0.8086682, 0.2544551, 0.5303851>,
    <0.8573639, -0.1130062, 0.5021522>,
    <0.8704662, -0.0841869, 0.4849755>,
    <0.8614904, -0.0969457, 0.4984334>,
    <0.8534991, -0.1204713, 0.5069772>,
    <0.8462533, -0.1018249, 0.5229598>,
    <0.8530649, -0.0748768, 0.5164046>,
    <0.8728262, -0.0615385, 0.4841358>,
    <0.8605722, -0.0870712, 0.5018307>,
    <0.8586632, -0.0476171, 0.5103235>,
    <0.8921598, -0.0003306, 0.4517198>,
    <0.8999298, -0.0462103, 0.4335793>,
    <0.8884560, -0.0779831, 0.4522881>,
    <0.8535475, -0.1167966, 0.5077551>,
    <0.8758954, -0.1090201, 0.4700232>,
    <0.9024814, -0.0948612, 0.4201532>,
    <0.9135278, -0.0680027, 0.4010519>,
    <0.9117438, -0.0576148, 0.4066987>,
    <0.9044441, -0.0713508, 0.4205828>,
    <0.9180901, -0.0359856, 0.3947348>,
    <0.9164618, -0.0320625, 0.3988356>,
    <0.9159629, 0.0004426, 0.4012628>,
    <0.9209891, -0.0003436, 0.3895881>,
    <0.9131309, -0.0403406, 0.4056657>,
    <0.9257958, -0.0011240, 0.3780223>,
    <0.9273356, 0.0404085, 0.3720428>,
    <0.9313689, 0.0730464, 0.3566739>,
    <0.9263100, 0.0580036, 0.3722707>,
    <0.9243635, 0.0317024, 0.3801935>,
    <0.9183773, 0.0503374, 0.3924911>,
    <0.9177622, 0.0800791, 0.3889729>,
    <0.9282596, 0.0971731, 0.3590146>,
    <0.9230698, 0.0682096, 0.3785362>,
    <0.9160598, 0.1097778, 0.3857244>,
    <0.9224571, 0.0355365, 0.3844608>,
    <0.9052430, 0.0632942, 0.4201534>,
    <0.9114577, 0.0916628, 0.4010521>,
    <0.9078970, 0.1015831, 0.4066989>,
    <0.9030935, 0.0867882, 0.4205829>,
    <0.8815196, 0.0447337, 0.4700234>,
    <0.8884999, 0.0774804, 0.4522884>,
    <0.9103910, 0.1239857, 0.3947350>,
    <0.9081062, 0.1275664, 0.3988358>,
    <0.8942821, 0.1107628, 0.4335795>,
    <0.9062633, 0.1188357, 0.4056659>,
    <-0.7327313, 0.2311608, -0.6400543>,
    <-0.7285910, 0.2371659, -0.6425788>,
    <-0.7421340, 0.2187239, -0.6335590>,
    <-0.7549219, 0.2097652, -0.6213626>,
    <-0.7318699, 0.1963325, -0.6525488>,
    <-0.7178937, 0.2175333, -0.6612926>,
    <-0.7308324, 0.2344768, -0.6410184>,
    <-0.7433414, 0.2100406, -0.6350799>,
    <-0.7631763, 0.2346993, -0.6020616>,
    <-0.7837265, 0.2102512, -0.5844376>,
    <-0.7623874, 0.1906199, -0.6184088>,
    <-0.8038160, 0.1847188, -0.5654722>,
    <-0.7994868, 0.1412954, -0.5838292>,
    <-0.7444697, 0.1743129, -0.6444997>,
    <-0.8028380, 0.2301976, -0.5499638>,
    <-0.8090217, 0.2093781, -0.5492218>,
    <-0.8207930, 0.1988323, -0.5355040>,
    <-0.8215768, 0.2087833, -0.5304914>,
    <-0.8258260, 0.1835542, -0.5332159>,
    <-0.8312423, 0.1767928, -0.5270490>,
    <-0.8502825, 0.1510122, -0.5041974>,
    <-0.8428633, 0.1489753, -0.5170955>,
    <-0.8324814, 0.1807192, -0.5237511>,
    <-0.8350312, 0.1468691, -0.5302380>,
    <-0.8460870, -0.1874702, -0.4989906>,
    <-0.8432452, -0.1786758, -0.5069640>,
    <-0.8426949, -0.2035776, -0.4984190>,
    <-0.8482615, -0.2190922, -0.4821317>,
    <-0.8272293, -0.2214289, -0.5163922>,
    <-0.8312733, -0.1940117, -0.5209071>,
    <-0.7995979, -0.1406664, -0.5838289>,
    <-0.8349050, -0.1475857, -0.5302378>,
    <-0.8429850, -0.1482851, -0.5170956>,
    <-0.8403589, -0.1817761, -0.5106411>,
    <-0.8369820, -0.2121672, -0.5044266>,
    <-0.8506532, -0.1489085, -0.5041978>,
    <-0.8412176, -0.2407944, -0.4841188>,
    <-0.8220388, -0.2486725, -0.5122638>,
    <-0.8103772, -0.2020623, -0.5499632>,
    <-0.8053227, -0.2231843, -0.5492214>,
    <-0.8102441, -0.2382029, -0.5355033>,
    <-0.8158985, -0.2299770, -0.5304906>,
    <-0.7838531, -0.2097806, -0.5844368>,
    <-0.7782802, -0.1783328, -0.6020610>,
    <-0.8069637, -0.2539506, -0.5332155>,
    <-0.8082737, -0.2625143, -0.5270483>,
    <-0.8113101, -0.2597335, -0.5237503>,
    <-0.7884849, -0.2419371, -0.5654715>,
    <0.4426098, 0.1326534, 0.8868482>,
    <0.4434041, 0.1401293, 0.8853003>,
    <0.4424934, 0.1448143, 0.8850019>,
    <0.4348937, 0.1350724, 0.8902937>,
    <0.4142271, 0.1184754, 0.9024298>,
    <0.4018525, 0.1121234, 0.9088140>,
    <0.3929450, 0.1092450, 0.9130497>,
    <0.4552456, 0.1372152, 0.8797292>,
    <0.4552456, 0.1372152, 0.8797292>,
    <0.4385748, 0.1321904, 0.8889195>,
    <0.4028873, 0.1336261, 0.9054424>,
    <0.4360634, 0.1522018, 0.8869517>,
    <0.4385748, 0.1321904, 0.8889195>,
    <0.3773799, 0.1137458, 0.9190464>,
    <0.3773799, 0.1137458, 0.9190464>,
    <0.3226135, 0.1107528, 0.9400289>,
    <0.4518507, 0.1530401, 0.8788684>,
    <0.4363413, 0.1311543, 0.8901712>,
    <-0.8591802, 0.1132144, -0.4989909>,
    <-0.8535021, 0.1205064, -0.5069640>,
    <-0.8615018, 0.0969181, -0.4984190>,
    <-0.8720389, 0.0842431, -0.4821320>,
    <-0.8530740, 0.0748539, -0.5163928>,
    <-0.8474969, 0.1020008, -0.5209077>,
    <-0.8518504, 0.1166059, -0.5106408>,
    <-0.8590714, 0.0868926, -0.5044263>,
    <-0.8748380, 0.1088963, -0.4720170>,
    <-0.8884689, 0.0779593, -0.4522669>,
    <-0.8728425, 0.0614406, -0.4841189>,
    <-0.9009764, 0.0462011, -0.4314012>,
    <-0.8921705, 0.0002982, -0.4516987>,
    <-0.8575145, 0.0474781, -0.5122643>,
    <-0.9024874, 0.0949129, -0.4201285>,
    <-0.9031755, 0.0712919, -0.4233101>,
    <-0.9117561, 0.0575886, -0.4066748>,
    <-0.9148204, 0.0680725, -0.3980826>,
    <-0.9117618, 0.0402528, -0.4087421>,
    <-0.9164750, 0.0319662, -0.3988129>,
    <-0.9251772, 0.0011397, -0.3795338>,
    <-0.9209981, 0.0003100, -0.3895669>,
    <-0.9195227, 0.0359347, -0.3913908>,
    <-0.9166547, -0.0005260, -0.3996797>,
    <-0.9286744, -0.0404944, -0.3686788>,
    <-0.9243724, -0.0316672, -0.3801747>,
    <-0.9263152, -0.0580290, -0.3722536>,
    <-0.9324996, -0.0732240, -0.3536705>,
    <-0.9177700, -0.0801012, -0.3889498>,
    <-0.9193194, -0.0503637, -0.3902760>,
    <-0.9211545, -0.0354435, -0.3875797>,
    <-0.9219216, -0.0681478, -0.3813352>,
    <-0.9282550, -0.0972654, -0.3590014>,
    <-0.9151815, -0.1097433, -0.3878133>,
    <-0.9052579, -0.0632441, -0.4201289>,
    <-0.9018338, -0.0866258, -0.4233105>,
    <-0.9079044, -0.1016109, -0.4066753>,
    <-0.9127427, -0.0918183, -0.3980831>,
    <-0.8885083, -0.0775059, -0.4522674>,
    <-0.8804567, -0.0446719, -0.4720174>,
    <-0.9048998, -0.1186843, -0.4087424>,
    <-0.9081024, -0.1276635, -0.3988133>,
    <-0.9117929, -0.1242845, -0.3913913>,
    <-0.8953111, -0.1109535, -0.4314016>,
    <0.8306124, -0.0872351, 0.5499755>,
    <0.8436270, -0.0628463, 0.5332389>,
    <0.8428411, -0.0533113, 0.5355155>,
    <0.8347234, -0.0657988, 0.5467242>,
    <0.7936618, -0.0987657, 0.6002885>,
    <0.8083188, -0.0709896, 0.5844494>,
    <0.8492942, -0.0334541, 0.5268588>,
    <0.8493025, -0.0298665, 0.5270609>,
    <0.8223202, -0.0423284, 0.5674485>,
    <0.8118679, -0.0003536, 0.5838411>,
    <0.8469363, 0.0002739, 0.5316942>,
    <0.8559198, -0.0003884, 0.5171084>,
    <0.8469283, -0.0374713, 0.5303852>,
    <0.8644078, -0.0010551, 0.5027903>,
    <0.8639618, 0.0375903, 0.5021523>,
    <0.8718607, 0.0682469, 0.4849756>,
    <0.8652367, 0.0541233, 0.4984336>,
    <0.8614521, 0.0295675, 0.5069774>,
    <0.8510786, 0.0466724, 0.5229598>,
    <0.8531072, 0.0743940, 0.5164045>,
    <0.8702520, 0.0909610, 0.4841359>,
    <0.8626178, 0.0636884, 0.5018310>,
    <0.8538868, 0.1022116, 0.5103235>,
    <0.8608616, 0.0331947, 0.5077553>,
    <0.8331419, 0.0583246, 0.5499752>,
    <0.8417238, 0.0846028, 0.5332387>,
    <0.8392940, 0.0938565, 0.5355153>,
    <0.8334680, 0.0801491, 0.5467241>,
    <0.7987550, 0.0405528, 0.6002883>,
    <0.8083661, 0.0704521, 0.5844491>,
    <0.8422009, 0.1145326, 0.5268586>,
    <0.8415861, 0.1180671, 0.5270607>,
    <0.8171777, 0.1011091, 0.5674483>,
    <0.8405685, 0.1101656, 0.5303850>,
    <0.4027986, -0.1252833, 0.9066738>,
    <0.4811988, -0.1332301, 0.8664280>,
    <0.4841349, -0.1404524, 0.8636472>,
    <0.4492058, -0.1409118, 0.8822460>,
    <0.3348325, -0.1240685, 0.9340740>,
    <0.4198867, -0.1199767, 0.8996114>,
    <0.4693427, -0.1259661, 0.8739851>,
    <0.5554195, -0.1412326, 0.8194892>,
    <0.5334683, -0.1492716, 0.8325440>,
    <0.5088405, -0.1275984, 0.8513519>,
    <0.5959338, -0.1132697, 0.7950049>,
    <0.6440271, -0.1525034, 0.7496478>,
    <0.6183778, -0.1663446, 0.7680744>,
    <0.5045591, -0.1563524, 0.8491019>,
    <0.5885091, -0.1793471, 0.7883474>,
    <0.4537108, -0.1230212, 0.8826167>,
    <0.4639383, -0.1245098, 0.8770739>,
    <0.4559833, -0.1223219, 0.8815421>,
    <0.4540818, -0.1219342, 0.8825768>,
    <0.3348325, -0.1240685, 0.9340740>,
    <0.4636552, -0.1245183, 0.8772223>,
    <0.4636552, -0.1245183, 0.8772223>,
    <0.4662137, -0.1252054, 0.8757673>,
    <0.4633713, -0.1240807, 0.8774344>,
    <0.4542038, -0.1205748, 0.8827008>,
    <0.4662137, -0.1252054, 0.8757673>,
    <0.4656842, -0.1250633, 0.8760693>,
    <0.4656842, -0.1250633, 0.8760693>,
    <0.4669913, -0.1251295, 0.8753638>,
    <0.4599680, -0.1227351, 0.8794120>,
    <0.4516445, -0.1170076, 0.8844922>,
    <0.4538893, -0.1189162, 0.8830875>,
    <0.4633907, -0.1126733, 0.8789618>,
    <0.6783926, -0.1931650, 0.7088517>,
    <0.6873922, -0.1760726, 0.7046207>,
    <0.7050105, -0.1719320, 0.6880404>,
    <0.7038435, -0.1815753, 0.6867567>,
    <0.6955099, -0.1549476, 0.7016104>,
    <0.7169737, -0.1546768, 0.6797233>,
    <0.7016648, -0.1258984, 0.7012960>,
    <0.7333091, -0.1307994, 0.6671950>,
    <0.7279453, -0.1622383, 0.6661639>,
    <0.7572967, -0.1347245, 0.6390235>,
    <0.7453776, -0.0982812, 0.6593581>,
    <0.7727266, -0.0748182, 0.6303141>,
    <0.7648291, -0.0861083, 0.6384526>,
    <0.7510720, -0.1060395, 0.6516490>,
    <0.7291305, -0.0865959, 0.6788740>,
    <0.7506136, -0.0653798, 0.6574988>,
    <0.7829881, -0.0553720, 0.6195672>,
    <0.7694710, -0.0778932, 0.6339141>,
    <0.7642144, -0.0424120, 0.6435663>,
    <0.7608844, -0.1040314, 0.6404939>,
    <0.7279796, 0.1611522, 0.6663900>,
    <0.7490826, 0.1933331, 0.6336384>,
    <0.7463995, 0.1802477, 0.6406235>,
    <0.7393449, 0.1565936, 0.6548646>,
    <0.7307430, 0.1269438, 0.6707458>,
    <0.6930229, 0.1189369, 0.7110368>,
    <0.5622280, 0.0899212, 0.8220790>,
    <0.7073702, 0.1668033, 0.6868800>,
    <0.7252477, 0.1949223, 0.6603189>,
    <0.7541287, 0.2156021, 0.6203271>,
    <0.7492860, 0.1898722, 0.6344439>,
    <0.7321555, 0.2214611, 0.6441298>,
    <0.7499838, 0.1623442, 0.6412244>,
    <0.7570260, 0.1322037, 0.6398701>,
    <0.6773224, 0.1705684, 0.7156401>,
    <0.6754071, 0.1890902, 0.7127904>,
    <0.6926887, 0.2025425, 0.6922131>,
    <0.6979474, 0.1942350, 0.6893055>,
    <0.5838540, 0.1357658, 0.8004262>,
    <0.6045549, 0.1615295, 0.7800138>,
    <0.6725895, 0.2111455, 0.7092538>,
    <0.6953580, 0.2234647, 0.6830379>,
    <0.6177622, 0.1850229, 0.7642882>,
    <0.7107049, 0.2232272, 0.6671343>,
    <-0.3850717, 0.1035766, -0.9170560>,
    <-0.3804358, 0.1033377, -0.9190158>,
    <-0.3713810, 0.1019014, -0.9228718>,
    <-0.3739800, 0.1019627, -0.9218148>,
    <-0.3892515, 0.1065354, -0.9149500>,
    <-0.3893638, 0.1047473, -0.9151086>,
    <-0.3916458, 0.1049306, -0.9141133>,
    <-0.3905033, 0.1046200, -0.9146375>,
    <-0.3905033, 0.1046200, -0.9146375>,
    <-0.3828274, 0.1025600, -0.9181093>,
    <-0.3642082, 0.1016920, -0.9257489>,
    <-0.3610099, 0.1026746, -0.9268925>,
    <-0.3828274, 0.1025600, -0.9181093>,
    <-0.3614034, 0.0968170, -0.9273694>,
    <-0.3614034, 0.0968170, -0.9273694>,
    <-0.3141454, 0.0977959, -0.9443244>,
    <-0.3615522, 0.1022817, -0.9267246>,
    <-0.3881755, 0.1108500, -0.9148946>,
    <-0.5571309, 0.1752033, -0.8117321>,
    <-0.5759896, 0.1874330, -0.7956789>,
    <-0.5965960, 0.1758529, -0.7830383>,
    <-0.6008291, 0.1667821, -0.7817852>,
    <-0.5815702, 0.1539931, -0.7987879>,
    <-0.5518053, 0.1618909, -0.8181090>,
    <-0.5994748, 0.1921640, -0.7769832>,
    <-0.6126665, 0.1731394, -0.7711436>,
    <-0.6461704, 0.1986547, -0.7368854>,
    <-0.6671638, 0.1790053, -0.7230834>,
    <-0.6285635, 0.1573399, -0.7616771>,
    <-0.6883369, 0.1582915, -0.7079097>,
    <-0.6807756, 0.1203469, -0.7225380>,
    <-0.6075644, 0.1419245, -0.7814876>,
    <-0.6979756, 0.1999965, -0.6876274>,
    <-0.7082922, 0.1832028, -0.6817323>,
    <-0.7192344, 0.1742627, -0.6725581>,
    <-0.7170361, 0.1822467, -0.6727893>,
    <-0.7294302, 0.1621646, -0.6645556>,
    <-0.7315948, 0.1557685, -0.6637057>,
    <-0.7589890, 0.1347567, -0.6370058>,
    <-0.7455806, 0.1318262, -0.6532468>,
    <-0.7286059, 0.1583586, -0.6663753>,
    <-0.7311628, 0.1287414, -0.6699452>,
    <-0.7501447, -0.1661747, -0.6400538>,
    <-0.7495618, -0.1589041, -0.6425781>,
    <-0.7520693, -0.1816468, -0.6335583>,
    <-0.7586645, -0.1957991, -0.6213621>,
    <-0.7319842, -0.1959060, -0.6525488>,
    <-0.7304809, -0.1705575, -0.6612926>,
    <-0.6808809, -0.1197499, -0.7225380>,
    <-0.7311005, -0.1290951, -0.6699452>,
    <-0.7457039, -0.1311275, -0.6532467>,
    <-0.7501584, -0.1623536, -0.6410176>,
    <-0.7487734, -0.1897705, -0.6350792>,
    <-0.7593060, -0.1329597, -0.6370056>,
    <-0.7555572, -0.2161122, -0.6184083>,
    <-0.7318862, -0.2212755, -0.6444996>,
    <-0.7044625, -0.1757856, -0.6876278>,
    <-0.7050001, -0.1954877, -0.6817326>,
    <-0.7100061, -0.2087011, -0.6725587>,
    <-0.7120943, -0.2006876, -0.6727899>,
    <-0.6672829, -0.1785585, -0.7230839>,
    <-0.6589269, -0.1510450, -0.7368858>,
    <-0.7127871, -0.2242763, -0.6645560>,
    <-0.7114634, -0.2308976, -0.6637063>,
    <-0.7101699, -0.2271601, -0.6663760>,
    <-0.6752625, -0.2070838, -0.7079103>,
    <-0.7617405, 0.1004115, -0.6400538>,
    <-0.7587060, 0.1070442, -0.6425782>,
    <-0.7688407, 0.0865307, -0.6335585>,
    <-0.7798786, 0.0754876, -0.6213622>,
    <-0.7548440, 0.0662619, -0.6525488>,
    <-0.7447616, 0.0895676, -0.6612925>,
    <-0.7604463, 0.1040068, -0.6410180>,
    <-0.7685218, 0.0777697, -0.6350796>,
    <-0.7923371, 0.0986094, -0.6020615>,
    <-0.8083297, 0.0709643, -0.5844375>,
    <-0.7839060, 0.0553368, -0.6184086>,
    <-0.8236803, 0.0423312, -0.5654722>,
    <-0.8118763, 0.0003195, -0.5838294>,
    <-0.7634287, 0.0423889, -0.6444997>,
    <-0.8306143, 0.0872889, -0.5499641>,
    <-0.8330887, 0.0657119, -0.5492223>,
    <-0.8428500, 0.0532823, -0.5355044>,
    <-0.8453499, 0.0629461, -0.5304916>,
    <-0.8451534, 0.0373624, -0.5332164>,
    <-0.8493133, 0.0297632, -0.5270494>,
    <-0.8635875, 0.0010680, -0.5041979>,
    <-0.8559273, 0.0003504, -0.5170960>,
    <-0.8512155, 0.0334148, -0.5237514>,
    <-0.8478485, -0.0003638, -0.5302384>,
    <-0.8657865, -0.0377005, -0.4989914>,
    <-0.8614609, -0.0295333, -0.5069644>,
    <-0.8652431, -0.0541523, -0.4984195>,
    <-0.8734191, -0.0684645, -0.4821324>,
    <-0.8531121, -0.0744179, -0.5163930>,
    <-0.8523336, -0.0467150, -0.5209079>,
    <-0.8591570, -0.0330877, -0.5106412>,
    <-0.8611087, -0.0636035, -0.5044267>,
    <-0.8702509, -0.0910601, -0.4841192>,
    <-0.8527313, -0.1021489, -0.5122645>,
    <-0.8331530, -0.0582718, -0.5499641>,
    <-0.8318430, -0.0799506, -0.5492223>,
    <-0.8392977, -0.0938864, -0.5355042>,
    <-0.8434377, -0.0848036, -0.5304915>,
    <-0.8083721, -0.0704788, -0.5844375>,
    <-0.7974229, -0.0404765, -0.6020618>,
    <-0.8388016, -0.1099645, -0.5332163>,
    <-0.8415788, -0.1181707, -0.5270491>,
    <-0.8440863, -0.1149049, -0.5237510>,
    <-0.8185176, -0.1013424, -0.5654720>,
    <-0.3812245, -0.1023870, -0.9187953>,
    <-0.3609844, -0.0980367, -0.9274045>,
    <-0.3627089, -0.0987776, -0.9266527>,
    <-0.3794490, -0.1026152, -0.9195045>,
    <-0.3848060, -0.1031107, -0.9172200>,
    <-0.3907050, -0.1046940, -0.9145429>,
    <-0.3907050, -0.1046940, -0.9145429>,
    <-0.3915034, -0.1049125, -0.9141764>,
    <-0.3860118, -0.1040631, -0.9166056>,
    <-0.3813236, -0.1050021, -0.9184590>,
    <-0.3408346, -0.0955097, -0.9352592>,
    <-0.3509122, -0.0981363, -0.9312518>,
    <-0.3770180, -0.1094057, -0.9197216>,
    <-0.3654860, -0.1006956, -0.9253542>,
    <-0.3254306, -0.0968413, -0.9405938>,
    <-0.3680068, -0.0986078, -0.9245796>,
    <-0.3680068, -0.0986078, -0.9245796>,
    <-0.3848060, -0.1031107, -0.9172200>,
    <0.4598545, -0.1199968, 0.8798492>,
    <0.4419001, -0.1091413, 0.8904002>,
    <0.4495046, -0.1040670, 0.8871954>,
    <0.4521702, -0.1106285, 0.8850443>,
    <0.4669913, -0.1251295, 0.8753638>,
    <0.4629027, -0.1238429, 0.8777153>,
    <0.4629027, -0.1238429, 0.8777153>,
    <0.4264091, -0.1140795, 0.8973077>,
    <0.3920192, -0.0900573, 0.9155384>,
    <0.4417482, -0.0917507, 0.8924350>,
    <0.4264091, -0.1140795, 0.8973077>,
    <0.3533008, -0.0945205, 0.9307225>,
    <0.3533008, -0.0945205, 0.9307225>,
    <0.3833477, -0.0650130, 0.9213131>,
    <0.3621661, -0.0669072, 0.9297092>,
    <0.4394128, -0.0740721, 0.8952261>,
    <0.4693280, -0.1003262, 0.8773060>,
    <0.5032072, -0.0835259, 0.8601197>,
    <0.3950588, 0.0900648, 0.9142302>,
    <0.4546747, 0.1169931, 0.8829403>,
    <0.4676227, 0.1155757, 0.8763397>,
    <0.4407712, 0.1002749, 0.8920010>,
    <0.4183574, 0.0833558, 0.9044495>,
    <0.3642385, 0.0683276, 0.9287958>,
    <0.3359473, 0.0590849, 0.9400257>,
    <0.3884593, 0.0940572, 0.9166529>,
    <0.4283047, 0.1120316, 0.8966627>,
    <0.5240933, 0.1469490, 0.8388875>,
    <0.5169908, 0.1327578, 0.8456334>,
    <0.4689473, 0.1326615, 0.8732064>,
    <0.4942280, 0.1134254, 0.8619010>,
    <0.4635626, 0.0905888, 0.8814212>,
    <0.3877826, 0.0965748, 0.9166777>,
    <0.3820603, 0.0962298, 0.9191136>,
    <0.3904180, 0.1005966, 0.9151252>,
    <0.4000540, 0.1034057, 0.9106394>,
    <0.3359473, 0.0590849, 0.9400257>,
    <0.3772498, 0.0915658, 0.9215738>,
    <0.3772498, 0.0915658, 0.9215738>,
    <0.3646389, 0.0885049, 0.9269333>,
    <0.3791416, 0.0979519, 0.9201397>,
    <0.3960404, 0.1055962, 0.9121411>,
    <0.3646389, 0.0885049, 0.9269333>,
    <0.3470225, 0.0842290, 0.9340668>,
    <0.3470225, 0.0842290, 0.9340668>,
    <0.3929450, 0.1092450, 0.9130497>,
    <0.4111623, 0.1115373, 0.9047127>,
    <0.4306153, -0.0527042, 0.9009954>,
    <0.5284025, -0.0465232, 0.8477183>,
    <0.5148505, -0.0542860, 0.8555594>,
    <0.4719870, -0.0617872, 0.8794377>,
    <0.3833477, -0.0650130, 0.9213131>,
    <0.5000580, -0.0403459, 0.8650515>,
    <0.5582744, -0.0397277, 0.8287047>,
    <0.6007573, -0.0416729, 0.7983446>,
    <0.5608815, -0.0543881, 0.8261077>,
    <0.5885541, -0.0358956, 0.8076605>,
    <0.6343047, -0.0077626, 0.7730441>,
    <0.6759481, -0.0375402, 0.7359924>,
    <0.6433801, -0.0563967, 0.7634668>,
    <0.5278941, -0.0676396, 0.8466125>,
    <0.6131448, -0.0751899, 0.7863841>,
    <0.7027613, -0.0728080, 0.7076903>,
    <0.7108733, -0.0539780, 0.7012457>,
    <0.7257497, -0.0468138, 0.6863642>,
    <0.7251441, -0.0567213, 0.6862570>,
    <0.7184149, -0.0311813, 0.6949157>,
    <0.7352917, -0.0275175, 0.6771919>,
    <0.7206410, -0.0014627, 0.6933069>,
    <0.7475765, -0.0011976, 0.6641746>,
    <0.7455753, -0.0333269, 0.6655876>,
    <0.7697800, -0.0011090, 0.6383083>,
    <0.7559303, 0.0328886, 0.6538255>,
    <0.7760574, 0.0606377, 0.6277404>,
    <0.7695552, 0.0480981, 0.6367663>,
    <0.7602414, 0.0261100, 0.6491157>,
    <0.7386489, 0.0411822, 0.6728312>,
    <0.7524085, 0.0658886, 0.6553931>,
    <0.7811708, 0.0814799, 0.6189775>,
    <0.7716426, 0.0569323, 0.6335033>,
    <0.7603314, 0.0909176, 0.6431409>,
    <0.7678642, 0.0296977, 0.6399240>,
    <0.7079369, 0.0496282, 0.7045299>,
    <0.7062046, 0.0682561, 0.7047100>,
    <0.7212696, 0.0787460, 0.6881637>,
    <0.7246753, 0.0696041, 0.6855661>,
    <0.6263343, 0.0314242, 0.7789209>,
    <0.6372683, 0.0526153, 0.7688437>,
    <0.7004976, 0.0898026, 0.7079821>,
    <0.7247606, 0.0988932, 0.6818667>,
    <0.6412951, 0.0719238, 0.7639159>,
    <0.7392903, 0.0962087, 0.6664786>,
    <0.6423257, -0.0351014, 0.7656276>,
    <0.6803693, -0.0384635, 0.7318594>,
    <0.6323636, -0.0396201, 0.7736579>,
    <0.5982949, -0.0382443, 0.8003628>,
    <0.3833477, -0.0650130, 0.9213131>,
    <0.7433192, -0.0271489, 0.6683857>,
    <0.7433192, -0.0271489, 0.6683857>,
    <0.7421988, -0.0351548, 0.6692572>,
    <0.6476500, -0.0437300, 0.7606821>,
    <0.6040674, -0.0411876, 0.7958682>,
    <0.7421988, -0.0351548, 0.6692572>,
    <0.6813755, -0.0434368, 0.7306440>,
    <0.6813755, -0.0434368, 0.7306440>,
    <0.6021515, -0.0504092, 0.7967889>,
    <0.5854359, -0.0484228, 0.8092713>,
    <0.5573140, -0.0421977, 0.8292288>,
    <0.5678006, -0.0378124, 0.8222972>,
    <0.5417917, -0.0332097, 0.8398564>,
    <0.3863124, 0.0468678, 0.9211765>,
    <0.4119161, 0.0584110, 0.9093477>,
    <0.4084021, 0.0604430, 0.9107988>,
    <0.3876799, 0.0489673, 0.9204925>,
    <0.3465657, 0.0302585, 0.9375375>,
    <0.3110954, 0.0246436, 0.9500591>,
    <0.2912000, 0.0227303, 0.9563921>,
    <0.4063198, 0.0543444, 0.9121134>,
    <0.4063198, 0.0543444, 0.9121134>,
    <0.4133892, 0.0552899, 0.9088742>,
    <0.3900866, 0.0614514, 0.9187253>,
    <0.4136401, 0.0695906, 0.9077770>,
    <0.4133892, 0.0552899, 0.9088742>,
    <0.3694679, 0.0494155, 0.9279286>,
    <0.3694679, 0.0494155, 0.9279286>,
    <0.3359473, 0.0590849, 0.9400257>,
    <0.4198401, 0.0638545, 0.9053491>,
    <0.3922962, 0.0407987, 0.9189337>,
    <-0.7221006, 0.0757560, -0.6876276>,
    <-0.7293442, 0.0574259, -0.6817325>,
    <-0.7385676, 0.0467216, -0.6725585>,
    <-0.7377891, 0.0549660, -0.6727897>,
    <-0.6881116, 0.0604341, -0.7230838>,
    <-0.6708493, 0.0834304, -0.7368857>,
    <-0.7465079, 0.0330368, -0.6645559>,
    <-0.7475287, 0.0263621, -0.6637061>,
    <-0.7708582, 0.0009125, -0.6370062>,
    <-0.7571445, 0.0003548, -0.6532473>,
    <-0.7450350, 0.0294318, -0.6663758>,
    <-0.7424102, -0.0001795, -0.6699456>,
    <-0.6913312, 0.0003031, -0.7225379>,
    <-0.7053662, 0.0363583, -0.7079101>,
    <-0.7676040, -0.0333887, -0.6400541>,
    <-0.7657672, -0.0263298, -0.6425786>,
    <-0.7721859, -0.0482916, -0.6335588>,
    <-0.7811386, -0.0610837, -0.6213624>,
    <-0.7548826, -0.0658221, -0.6525486>,
    <-0.7490003, -0.0411197, -0.6612924>,
    <-0.7669537, -0.0296233, -0.6410183>,
    <-0.7703506, -0.0568642, -0.6350798>,
    <-0.7816058, -0.0816278, -0.6184086>,
    <-0.7591914, -0.0908231, -0.6444995>,
    <-0.7242855, -0.0507865, -0.6876272>,
    <-0.7282361, -0.0700959, -0.6817322>,
    <-0.7354607, -0.0822393, -0.6725580>,
    <-0.7361257, -0.0739850, -0.6727891>,
    <-0.6881525, -0.0599735, -0.7230832>,
    <-0.6751456, -0.0343290, -0.7368853>,
    <-0.7409039, -0.0970950, -0.6645555>,
    <-0.7407503, -0.1038456, -0.6637056>,
    <-0.7388275, -0.1003895, -0.6663752>,
    <-0.7009641, -0.0866798, -0.7079096>,
    <-0.3966332, 0.1058817, -0.9118504>,
    <-0.4093295, 0.1115964, -0.9055361>,
    <-0.4239099, 0.1125766, -0.8986806>,
    <-0.4132991, 0.1072902, -0.9042526>,
    <-0.3856821, 0.1008237, -0.9171062>,
    <-0.3877398, 0.1033277, -0.9159592>,
    <-0.3916458, 0.1049306, -0.9141133>,
    <-0.4325798, 0.1211877, -0.8934138>,
    <-0.4498800, 0.1188105, -0.8851509>,
    <-0.4991238, 0.1421817, -0.8547864>,
    <-0.5110550, 0.1328201, -0.8492241>,
    <-0.4442544, 0.1103254, -0.8890817>,
    <-0.5062628, 0.1185378, -0.8541936>,
    <-0.4249154, 0.0724775, -0.9023270>,
    <-0.3840652, 0.0951451, -0.9183906>,
    <-0.5537458, 0.1520162, -0.8186920>,
    <-0.5641451, 0.1430992, -0.8131807>,
    <-0.5650697, 0.1359283, -0.8137688>,
    <-0.5567332, 0.1395557, -0.8188849>,
    <-0.5871565, 0.1302141, -0.7989315>,
    <-0.5693890, 0.1225316, -0.8128851>,
    <-0.6200936, 0.1103225, -0.7767322>,
    <-0.5810659, 0.1038979, -0.8071974>,
    <-0.5451709, 0.1208424, -0.8295696>,
    <-0.5345464, 0.0959504, -0.8396747>,
    <-0.5790931, 0.0757972, -0.8117302>,
    <-0.5997873, 0.0845661, -0.7956782>,
    <-0.6180694, 0.0695837, -0.7830379>,
    <-0.6206635, 0.0599156, -0.7817845>,
    <-0.5994764, 0.0506652, -0.7987873>,
    <-0.5715371, 0.0636121, -0.8181069>,
    <-0.6237363, 0.0851470, -0.7769833>,
    <-0.6334239, 0.0641207, -0.7711438>,
    <-0.6463360, 0.0458007, -0.7616771>,
    <-0.6229793, 0.0342659, -0.7814874>,
    <-0.5680860, -0.1263886, -0.8132061>,
    <-0.5917414, -0.1254935, -0.7962999>,
    <-0.6037378, -0.1457981, -0.7837369>,
    <-0.6022439, -0.1556160, -0.7829980>,
    <-0.5794943, -0.1572746, -0.7996568>,
    <-0.5564131, -0.1354206, -0.8197961>,
    <-0.4224052, -0.0779655, -0.9030477>,
    <-0.5345706, -0.0925448, -0.8400415>,
    <-0.5813734, -0.1010580, -0.8073365>,
    <-0.6150434, -0.1332742, -0.7771484>,
    <-0.6169117, -0.1563285, -0.7713503>,
    <-0.6203817, -0.1084031, -0.7767724>,
    <-0.6225717, -0.1778954, -0.7620746>,
    <-0.5968005, -0.1808240, -0.7817492>,
    <-0.3961275, -0.1067065, -0.9119741>,
    <-0.4118314, -0.1088225, -0.9047389>,
    <-0.4234665, -0.1147918, -0.8986095>,
    <-0.4095761, -0.1133933, -0.9052013>,
    <-0.3915034, -0.1049125, -0.9141764>,
    <-0.3907794, -0.1044294, -0.9145414>,
    <-0.3932947, -0.1037653, -0.9135382>,
    <-0.4375128, -0.1125329, -0.8921429>,
    <-0.4495473, -0.1226266, -0.8847994>,
    <-0.3937160, -0.0999351, -0.9137837>,
    <-0.5047105, -0.1275046, -0.8538207>,
    <-0.5098368, -0.1412578, -0.8485945>,
    <-0.4375718, -0.1262317, -0.8902789>,
    <-0.4972325, -0.1507487, -0.8544207>,
    <-0.5552697, -0.1456858, -0.8188108>,
    <-0.5599196, -0.1583865, -0.8132673>,
    <-0.5576747, -0.1652236, -0.8134495>,
    <-0.5524782, -0.1581230, -0.8183917>,
    <-0.5736559, -0.1809327, -0.7988631>,
    <-0.5547310, -0.1788224, -0.8125860>,
    <-0.5331485, -0.1683651, -0.8290994>,
    <-0.3832114, 0.1024498, -0.9179613>,
    <-0.3854444, 0.1032777, -0.9169331>,
    <-0.3680130, 0.0986078, -0.9245772>,
    <-0.3586848, 0.0952239, -0.9285891>,
    <-0.3502567, 0.0913539, -0.9321881>,
    <-0.3783336, 0.1010265, -0.9201398>,
    <-0.3916796, 0.1049503, -0.9140966>,
    <-0.3916817, 0.1049500, -0.9140957>,
    <-0.3916817, 0.1049500, -0.9140957>,
    <-0.3916858, 0.1049490, -0.9140941>,
    <-0.3831313, 0.1027149, -0.9179652>,
    <-0.3643933, 0.0972693, -0.9261513>,
    <-0.3916858, 0.1049490, -0.9140941>,
    <-0.3916852, 0.1049456, -0.9140947>,
    <-0.3916852, 0.1049456, -0.9140947>,
    <-0.3916458, 0.1049306, -0.9141133>,
    <-0.3422227, 0.0897213, -0.9353255>,
    <-0.3265038, 0.0803963, -0.9417705>,
    <-0.3877019, -0.1039019, -0.9159103>,
    <-0.3884678, -0.1040986, -0.9155633>,
    <-0.3798910, -0.1017982, -0.9194128>,
    <-0.3795800, -0.1013690, -0.9195887>,
    <-0.3915034, -0.1049125, -0.9141764>,
    <-0.3914579, -0.1049041, -0.9141968>,
    <-0.3914579, -0.1049041, -0.9141968>,
    <-0.3914376, -0.1048977, -0.9142063>,
    <-0.3871660, -0.1035483, -0.9161770>,
    <-0.3736464, -0.0992021, -0.9222512>,
    <-0.3914376, -0.1048977, -0.9142063>,
    <-0.3914459, -0.1048913, -0.9142034>,
    <-0.3914459, -0.1048913, -0.9142034>,
    <-0.3914905, -0.1048807, -0.9141855>,
    <-0.3831097, -0.1021095, -0.9180417>,
    <-0.3649385, -0.0940092, -0.9262733>,
    <-0.3658948, -0.0960972, -0.9256815>,
    <-0.3506533, -0.0840631, -0.9327248>,
    <0.5350787, -0.0488153, 0.8433907>,
    <0.4807194, -0.0415987, 0.8758872>,
    <0.4963216, -0.0337653, 0.8674819>,
    <0.5205918, -0.0385672, 0.8529342>,
    <0.6021515, -0.0504092, 0.7967889>,
    <0.5349680, -0.0539662, 0.8431470>,
    <0.5349680, -0.0539662, 0.8431470>,
    <0.4572207, -0.0510858, 0.8878848>,
    <0.4046481, -0.0305292, 0.9139627>,
    <0.4722840, -0.0220245, 0.8811712>,
    <0.4572207, -0.0510858, 0.8878848>,
    <0.3600383, -0.0423980, 0.9319736>,
    <0.3600383, -0.0423980, 0.9319736>,
    <0.2840755, -0.0215119, 0.9585606>,
    <0.3554804, -0.0125208, 0.9345999>,
    <0.4506732, -0.0033404, 0.8926828>,
    <0.5212665, -0.0233583, 0.8530742>,
    <0.5360913, 0.0016425, 0.8441584>,
    <0.3872516, 0.0073827, 0.9219445>,
    <0.4556769, 0.0270400, 0.8897345>,
    <0.4848337, 0.0252522, 0.8742417>,
    <0.4635987, 0.0134375, 0.8859434>,
    <0.2840755, -0.0215119, 0.9585606>,
    <0.3503034, 0.0079922, 0.9366022>,
    <0.3998756, 0.0225118, 0.9162929>,
    <0.5367452, 0.0482459, 0.8423639>,
    <0.5452621, 0.0370603, 0.8374460>,
    <0.4471989, 0.0383754, 0.8936109>,
    <0.5405353, 0.0220978, 0.8410311>,
    <0.3103428, 0.0057458, 0.9506073>,
    <0.2848565, 0.0053631, 0.9585552>,
    <0.3104395, 0.0113452, 0.9505254>,
    <0.3394842, 0.0147215, 0.9404966>,
    <0.2840755, -0.0215119, 0.9585606>,
    <0.2756082, -0.0026147, 0.9612665>,
    <0.2756082, -0.0026147, 0.9612665>,
    <0.2509305, -0.0023806, 0.9680022>,
    <0.2745768, 0.0084209, 0.9615283>,
    <0.3161780, 0.0163027, 0.9485598>,
    <0.2509305, -0.0023806, 0.9680022>,
    <0.2274458, -0.0021578, 0.9737884>,
    <0.2274458, -0.0021578, 0.9737884>,
    <0.2912000, 0.0227303, 0.9563921>,
    <0.3577804, 0.0230580, 0.9335210>,
    <-0.3764735, 0.0981520, -0.9212133>,
    <-0.3496458, 0.0854067, -0.9329810>,
    <-0.3575069, 0.0792793, -0.9305394>,
    <-0.3674705, 0.0878437, -0.9258774>,
    <-0.3637485, 0.0974661, -0.9263841>,
    <-0.3880500, 0.1039777, -0.9157543>,
    <-0.3880500, 0.1039777, -0.9157543>,
    <-0.3916796, 0.1049503, -0.9140966>,
    <-0.3381129, 0.0683459, -0.9386205>,
    <-0.3535279, 0.0632429, -0.9332836>,
    <-0.3598595, 0.0483628, -0.9317522>,
    <-0.3617939, 0.0467815, -0.9310836>,
    <-0.3468184, 0.0674082, -0.9355069>,
    <-0.3453437, 0.0442486, -0.9374326>,
    <-0.3266345, 0.0417953, -0.9442262>,
    <-0.3052500, 0.0817914, -0.9487532>,
    <-0.3052500, 0.0817914, -0.9487532>,
    <-0.3637485, 0.0974661, -0.9263841>,
    <-0.3792399, -0.0972943, -0.9201689>,
    <-0.3672041, -0.0832427, -0.9264080>,
    <-0.3610665, -0.0741427, -0.9295880>,
    <-0.3588855, -0.0837199, -0.9296194>,
    <-0.3914905, -0.1048807, -0.9141855>,
    <-0.3871347, -0.1036755, -0.9161758>,
    <-0.3871347, -0.1036755, -0.9161758>,
    <-0.3579833, -0.0958173, -0.9287987>,
    <-0.3484032, -0.0606328, -0.9353817>,
    <-0.3536803, -0.0563694, -0.9336663>,
    <-0.3579833, -0.0958173, -0.9287987>,
    <-0.2907790, -0.0777632, -0.9536249>,
    <-0.2907790, -0.0777632, -0.9536249>,
    <-0.3375443, -0.0388743, -0.9405066>,
    <-0.3503320, -0.0404262, -0.9357528>,
    <-0.3545967, -0.0414680, -0.9340993>,
    <-0.3433475, -0.0634910, -0.9370600>,
    <-0.3409757, -0.0419917, -0.9391338>,
    <-0.5717324, 0.0535504, -0.8186906>,
    <-0.5804240, 0.0429626, -0.8131803>,
    <-0.5800893, 0.0357401, -0.8137684>,
    <-0.5725099, 0.0407601, -0.8188840>,
    <-0.5263572, 0.0420592, -0.8492227>,
    <-0.5162384, 0.0533513, -0.8547816>,
    <-0.6008480, 0.0262772, -0.7989312>,
    <-0.5820164, 0.0217967, -0.8128849>,
    <-0.6298306, 0.0009682, -0.7767319>,
    <-0.5902800, 0.0014184, -0.8071973>,
    <-0.5578729, 0.0243387, -0.8295694>,
    <-0.5430865, 0.0016697, -0.8396751>,
    <-0.4310413, -0.0024090, -0.9023290>,
    <-0.5191558, 0.0288255, -0.8541934>,
    <-0.5834568, -0.0259128, -0.8117307>,
    <-0.6053601, -0.0208707, -0.7956781>,
    <-0.6207628, -0.0388002, -0.7830378>,
    <-0.6216383, -0.0487718, -0.7817846>,
    <-0.5991665, -0.0542025, -0.7987876>,
    <-0.5738990, -0.0366007, -0.8181078>,
    <-0.6290464, -0.0244574, -0.7769829>,
    <-0.6349356, -0.0468465, -0.7711434>,
    <-0.6444701, -0.0671303, -0.7616769>,
    <-0.6194650, -0.0744339, -0.7814875>,
    <-0.5726573, -0.0466175, -0.8184683>,
    <-0.5792405, -0.0585237, -0.8130531>,
    <-0.5780472, -0.0656825, -0.8133555>,
    <-0.5717313, -0.0595080, -0.8182800>,
    <-0.5259815, -0.0501951, -0.8490135>,
    <-0.5177995, -0.0371782, -0.8546938>,
    <-0.5964076, -0.0784933, -0.7988347>,
    <-0.5773950, -0.0797205, -0.8125636>,
    <-0.5543617, -0.0731543, -0.8290546>,
    <-0.5156560, -0.0619964, -0.8545498>,
    <-0.3973116, 0.0351597, -0.9170100>,
    <-0.3927523, 0.0357369, -0.9189497>,
    <-0.3835652, 0.0358898, -0.9228162>,
    <-0.3861002, 0.0354925, -0.9217738>,
    <-0.4018936, 0.0373364, -0.9149249>,
    <-0.4016958, 0.0355585, -0.9150826>,
    <-0.4039640, 0.0353450, -0.9140918>,
    <-0.4028528, 0.0352488, -0.9145858>,
    <-0.4028528, 0.0352488, -0.9145858>,
    <-0.3949893, 0.0345614, -0.9180354>,
    <-0.3765264, 0.0369390, -0.9256692>,
    <-0.3734997, 0.0384528, -0.9268330>,
    <-0.3949893, 0.0345614, -0.9180354>,
    <-0.3729409, 0.0326325, -0.9272811>,
    <-0.3729409, 0.0326325, -0.9272811>,
    <-0.3266345, 0.0417953, -0.9442262>,
    <-0.3739164, 0.0379628, -0.9266851>,
    <-0.4015790, 0.0417697, -0.9148713>,
    <-0.4090240, 0.0354061, -0.9118365>,
    <-0.4225170, 0.0388285, -0.9055229>,
    <-0.4370314, 0.0372587, -0.8986742>,
    <-0.4256642, 0.0338945, -0.9042462>,
    <-0.3973412, 0.0323216, -0.9171016>,
    <-0.3998174, 0.0344345, -0.9159478>,
    <-0.4039640, 0.0353450, -0.9140918>,
    <-0.4470717, 0.0442341, -0.8934038>,
    <-0.4636825, 0.0388864, -0.8851477>,
    <-0.4566661, 0.0315061, -0.8890801>,
    <-0.3947538, 0.0270080, -0.9183899>,
    <-0.4086010, -0.0361775, -0.9119959>,
    <-0.4230671, -0.0352243, -0.9054134>,
    <-0.4362559, -0.0392461, -0.8989664>,
    <-0.4233182, -0.0404755, -0.9050765>,
    <-0.3941849, -0.0371917, -0.9182783>,
    <-0.3985494, -0.0354577, -0.9164612>,
    <-0.4039704, -0.0353464, -0.9140889>,
    <-0.4019226, -0.0347737, -0.9150131>,
    <-0.4026162, -0.0330915, -0.9147706>,
    <-0.4480185, -0.0341448, -0.8933720>,
    <-0.4628671, -0.0423267, -0.8854166>,
    <-0.4028955, -0.0286327, -0.9147980>,
    <-0.4527056, -0.0482250, -0.8903550>,
    <-0.3905053, -0.0422777, -0.9196294>,
    <-0.3934066, -0.0346433, -0.9187116>,
    <-0.3727156, -0.0338627, -0.9273276>,
    <-0.3745448, -0.0342974, -0.9265743>,
    <-0.3917219, -0.0351729, -0.9194111>,
    <-0.3970553, -0.0347434, -0.9171368>,
    <-0.4031246, -0.0352737, -0.9144650>,
    <-0.4031246, -0.0352737, -0.9144650>,
    <-0.4039704, -0.0353464, -0.9140889>,
    <-0.3523648, -0.0348703, -0.9352129>,
    <-0.3627866, -0.0357132, -0.9311877>,
    <-0.3776353, -0.0357089, -0.9252656>,
    <-0.3375443, -0.0388743, -0.9405066>,
    <-0.3797549, -0.0332301, -0.9244901>,
    <-0.3797549, -0.0332301, -0.9244901>,
    <-0.3970553, -0.0347434, -0.9171368>,
    <-0.3951776, 0.0343503, -0.9179623>,
    <-0.3975215, 0.0347794, -0.9169335>,
    <-0.3795451, 0.0332064, -0.9245771>,
    <-0.3697699, 0.0314930, -0.9285895>,
    <-0.3607973, 0.0291450, -0.9321888>,
    <-0.3901271, 0.0337952, -0.9201406>,
    <-0.4039515, 0.0353419, -0.9140974>,
    <-0.4039516, 0.0353419, -0.9140974>,
    <-0.4039516, 0.0353419, -0.9140974>,
    <-0.4039513, 0.0353422, -0.9140975>,
    <-0.3951527, 0.0346291, -0.9179625>,
    <-0.3757500, 0.0325175, -0.9261504>,
    <-0.4039513, 0.0353422, -0.9140975>,
    <-0.4039525, 0.0353430, -0.9140969>,
    <-0.4039525, 0.0353430, -0.9140969>,
    <-0.4039640, 0.0353450, -0.9140918>,
    <-0.3526030, 0.0289325, -0.9353256>,
    <-0.3355020, 0.0224786, -0.9417713>,
    <-0.3974240, -0.0343924, -0.9169904>,
    <-0.3930348, -0.0330463, -0.9189296>,
    <-0.3840226, -0.0312992, -0.9227931>,
    <-0.3864924, -0.0321367, -0.9217325>,
    <-0.4039704, -0.0353464, -0.9140889>,
    <-0.4028277, -0.0352451, -0.9145970>,
    <-0.4028277, -0.0352451, -0.9145970>,
    <-0.3949515, -0.0345549, -0.9180519>,
    <-0.3772238, -0.0290350, -0.9256669>,
    <-0.3745078, -0.0270151, -0.9268301>,
    <-0.3949515, -0.0345549, -0.9180519>,
    <-0.3728964, -0.0326247, -0.9272993>,
    <-0.3728964, -0.0326247, -0.9272993>,
    <-0.3288913, -0.0155572, -0.9442396>,
    <-0.3477458, -0.0163901, -0.9374456>,
    <-0.3643951, -0.0167527, -0.9310937>,
    <-0.3748514, -0.0275712, -0.9266748>,
    <-0.3627745, -0.0148599, -0.9317585>,
    <-0.3877945, 0.0312877, -0.9212147>,
    <-0.3591599, 0.0233948, -0.9329828>,
    <-0.3658328, 0.0159961, -0.9305431>,
    <-0.3771333, 0.0227003, -0.9258808>,
    <-0.3751435, 0.0328221, -0.9263855>,
    <-0.4002073, 0.0350146, -0.9157555>,
    <-0.4002073, 0.0350146, -0.9157555>,
    <-0.4039515, 0.0353419, -0.9140974>,
    <-0.3448356, 0.0085962, -0.9386237>,
    <-0.3591221, 0.0008948, -0.9332902>,
    <-0.3532355, 0.0061624, -0.9355142>,
    <-0.3288913, -0.0155572, -0.9442396>,
    <-0.3148117, 0.0275438, -0.9487544>,
    <-0.3148117, 0.0275438, -0.9487544>,
    <-0.3751435, 0.0328221, -0.9263855>
  }
  uv_vectors {
    52289,
    <1.0000000, -167.1040945>,
    <1.0000000, -167.0684463>,
    <0.9990142, -167.1040945>,
    <0.9802301, -167.1040945>,
    <0.9990140, -167.1040945>,
    <0.0267917, -167.1040945>,
    <0.0267920, -167.1040945>,
    <0.0277776, -167.1040945>,
    <0.0277778, -167.1040945>,
    <0.0277752, -167.1040945>,
    <0.0277752, -167.1040945>,
    <0.0277778, -167.0684463>,
    <0.0267920, -167.1040945>,
    <0.9722222, -167.0684463>,
    <0.9722248, -167.1040945>,
    <0.9722222, -167.1040945>,
    <0.9802300, -167.1040945>,
    <0.9712363, -167.1040945>,
    <0.0108027, -167.0684463>,
    <1.0000000, -167.0684463>,
    <0.9899284, -167.0684463>,
    <0.9899284, -167.0684463>,
    <0.9899284, -167.0684463>,
    <0.9722242, -167.0684463>,
    <0.9722242, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.0100734, -167.0684463>,
    <0.9722222, -167.0684463>,
    <0.9722222, -167.0684463>,
    <0.9621490, -167.0684463>,
    <0.9524507, -167.1040945>,
    <0.9712364, -167.1040945>,
    <0.9712362, -167.1040945>,
    <0.9524525, -167.1040945>,
    <0.9621490, -167.0684463>,
    <0.0545693, -167.1041136>,
    <0.0277778, -167.1041136>,
    <0.0545696, -167.1040945>,
    <0.0555556, -167.1041136>,
    <0.0555556, -167.1040945>,
    <0.0555553, -167.1041136>,
    <0.0555553, -167.1041136>,
    <0.0555524, -167.1041136>,
    <0.0555523, -167.1041136>,
    <0.0555556, -167.0684463>,
    <0.0545695, -167.1041136>,
    <0.9444444, -167.0684463>,
    <0.9524507, -167.1040945>,
    <0.9444444, -167.1040945>,
    <0.9444444, -167.1041136>,
    <0.9434584, -167.1041136>,
    <0.0555556, -167.0684463>,
    <0.0378510, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.9621490, -167.0684463>,
    <0.9444444, -167.0684463>,
    <0.0096133, -168.0684463>,
    <1.0000000, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.9757366, -168.0684463>,
    <1.0000000, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.9444444, -167.0684463>,
    <0.9343713, -167.0684463>,
    <0.0181645, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0096133, -168.0684463>,
    <0.0181645, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9757365, -168.0684463>,
    <0.0373913, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.9626087, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9343713, -167.0684463>,
    <0.9246744, -167.1040945>,
    <0.9434585, -167.1040945>,
    <0.9434582, -167.1041136>,
    <0.9246767, -167.1041136>,
    <0.0459421, -168.0684463>,
    <0.9540579, -168.0684463>,
    <0.0823476, -167.1040945>,
    <0.0823474, -167.1040945>,
    <0.0833331, -167.1040945>,
    <0.0833333, -167.1040945>,
    <0.0833310, -167.1040945>,
    <0.0833310, -167.1040945>,
    <0.0833333, -167.0684463>,
    <0.0823476, -167.1040945>,
    <0.9166667, -167.0684463>,
    <0.9166690, -167.1040945>,
    <0.9166667, -167.1040945>,
    <0.9156807, -167.1040945>,
    <0.0486194, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0486193, -168.0684463>,
    <0.0459421, -168.0684463>,
    <0.9479588, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9540579, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9479587, -168.0684463>,
    <0.0833333, -167.0684463>,
    <0.0656287, -167.0684463>,
    <0.0555556, -167.0684463>,
    <0.9343713, -167.0684463>,
    <0.9166667, -167.0684463>,
    <0.9348311, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.0737200, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.9262800, -168.0684463>,
    <0.8968956, -167.1040945>,
    <0.9156807, -167.1040945>,
    <0.9156805, -167.1040945>,
    <0.8968973, -167.1040945>,
    <0.0763972, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0763972, -168.0684463>,
    <0.9201809, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9201809, -168.0684463>,
    <0.0929468, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.9070532, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.1101252, -167.1040945>,
    <0.1111111, -167.1040945>,
    <0.1111111, -167.0684463>,
    <0.1101256, -167.1040945>,
    <0.9166667, -167.0684463>,
    <0.8888889, -167.0684463>,
    <0.8968957, -167.1040945>,
    <0.8888889, -167.1040945>,
    <0.1111174, -167.1041136>,
    <0.1111111, -167.1041136>,
    <0.8888889, -167.1041136>,
    <0.8879027, -167.1041136>,
    <0.1111111, -167.0684463>,
    <0.0833333, -167.0684463>,
    <0.8888889, -167.0684463>,
    <0.1014978, -168.0684463>,
    <0.8985022, -168.0684463>,
    <0.1041749, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1041749, -168.0684463>,
    <0.1014978, -168.0684463>,
    <0.8924032, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8985022, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8924032, -168.0684463>,
    <0.8691193, -167.1040945>,
    <0.8879030, -167.1040945>,
    <0.8879024, -167.1041136>,
    <0.8691234, -167.1041136>,
    <0.1379024, -167.1041136>,
    <0.1379029, -167.1040945>,
    <0.1388889, -167.1041136>,
    <0.1388889, -167.1040945>,
    <0.1388884, -167.1041136>,
    <0.1388829, -167.1041136>,
    <0.1388828, -167.1041136>,
    <0.1388889, -167.0684463>,
    <0.1379028, -167.1041136>,
    <0.8888889, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.8611141, -167.1040945>,
    <0.8611111, -167.1040945>,
    <0.8691194, -167.1040945>,
    <0.8601254, -167.1040945>,
    <0.1292754, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.8707246, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.1388889, -167.0684463>,
    <0.1111111, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.1319526, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1319526, -168.0684463>,
    <0.1292754, -168.0684463>,
    <0.8646254, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8707246, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8646255, -168.0684463>,
    <0.1496911, -167.0684463>,
    <0.1388889, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.8434063, -167.0684463>,
    <0.8514979, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.1485024, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.8413411, -167.1040945>,
    <0.8601252, -167.1040945>,
    <0.1570531, -168.0684463>,
    <0.8429467, -168.0684463>,
    <0.1656807, -167.1040945>,
    <0.1656805, -167.1040945>,
    <0.1666664, -167.1040945>,
    <0.1666667, -167.1040945>,
    <0.1666641, -167.1040945>,
    <0.1666642, -167.1040945>,
    <0.1666667, -167.0684463>,
    <0.1656809, -167.1040945>,
    <0.8333333, -167.0684463>,
    <0.8333358, -167.1040945>,
    <0.8333333, -167.1040945>,
    <0.8413411, -167.1040945>,
    <0.1666704, -167.1041136>,
    <0.1666667, -167.1041136>,
    <0.8323474, -167.1040945>,
    <0.1666667, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.1597303, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1570531, -168.0684463>,
    <0.8368476, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8429467, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8368476, -168.0684463>,
    <0.1774688, -167.0684463>,
    <0.1666667, -167.0684463>,
    <0.1762801, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.8237199, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8333333, -167.0684463>,
    <0.8156287, -167.0684463>,
    <0.8135618, -167.1040945>,
    <0.8323476, -167.1040945>,
    <0.8323474, -167.1040945>,
    <0.8135634, -167.1040945>,
    <0.1872539, -168.0684463>,
    <0.1934582, -167.1041136>,
    <0.1934585, -167.1040945>,
    <0.1944444, -167.1041136>,
    <0.1944444, -167.1040945>,
    <0.1944441, -167.1041136>,
    <0.1944441, -167.1041136>,
    <0.1944410, -167.1041136>,
    <0.1944410, -167.1041136>,
    <0.1944444, -167.0684463>,
    <0.1934583, -167.1041136>,
    <0.8055556, -167.0684463>,
    <0.8135618, -167.1040945>,
    <0.8055556, -167.1040945>,
    <0.8055495, -167.1041136>,
    <0.8055556, -167.1041136>,
    <0.8045696, -167.1041136>,
    <0.1944444, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.8055556, -168.0684463>,
    <0.1872539, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.2052464, -167.0684463>,
    <0.1944444, -167.0684463>,
    <0.7959423, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.2040578, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.8055556, -167.0684463>,
    <0.7878511, -167.0684463>,
    <0.7857857, -167.1040945>,
    <0.8045696, -167.1040945>,
    <0.8045693, -167.1041136>,
    <0.7857879, -167.1041136>,
    <0.7873912, -168.0684463>,
    <0.2126088, -168.0684463>,
    <0.2212365, -167.1040945>,
    <0.2212362, -167.1040945>,
    <0.2222220, -167.1040945>,
    <0.2222222, -167.1040945>,
    <0.2222195, -167.1040945>,
    <0.2222196, -167.1040945>,
    <0.2222222, -167.0684463>,
    <0.2212365, -167.1040945>,
    <0.7777778, -167.0684463>,
    <0.7777805, -167.1040945>,
    <0.7777778, -167.1040945>,
    <0.2222222, -167.0684463>,
    <0.7777778, -167.0684463>,
    <0.7767918, -167.1040945>,
    <0.2150318, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2150318, -168.0684463>,
    <0.2126088, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7812921, -168.0684463>,
    <0.7873913, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7812921, -168.0684463>,
    <0.7677055, -167.0684463>,
    <0.7677055, -167.0684463>,
    <0.7677055, -167.0684463>,
    <0.7681644, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7596135, -168.0684463>,
    <0.7580068, -167.1040945>,
    <0.7767920, -167.1040945>,
    <0.7767918, -167.1040945>,
    <0.7580086, -167.1040945>,
    <0.2490141, -167.1040945>,
    <0.2490139, -167.1040945>,
    <0.2499981, -167.0684463>,
    <0.2222222, -167.0684463>,
    <0.2500000, -167.1040945>,
    <0.2500000, -167.0684463>,
    <0.2490141, -167.1040945>,
    <0.2500000, -167.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7596134, -168.0684463>,
    <0.7500000, -167.0684463>,
    <0.7500000, -167.0684463>,
    <0.7580067, -167.1040945>,
    <0.7500000, -167.1040945>,
    <0.7490142, -167.1040945>,
    <0.2562759, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.7399284, -167.0684463>,
    <0.7399284, -167.0684463>,
    <0.2681645, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.7302293, -167.1040945>,
    <0.7490139, -167.1040945>,
    <0.7490141, -167.1040945>,
    <0.7302310, -167.1040945>,
    <0.2777778, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.2767918, -167.1040945>,
    <0.7399284, -167.0684463>,
    <0.7222242, -167.0684463>,
    <0.2777778, -167.0684463>,
    <0.2600734, -167.0684463>,
    <0.2500000, -167.0684463>,
    <0.2777775, -167.1040945>,
    <0.2777778, -167.1040945>,
    <0.2777752, -167.1040945>,
    <0.2777778, -167.0684463>,
    <0.2777752, -167.1040945>,
    <0.2767920, -167.1040945>,
    <0.7222242, -167.0684463>,
    <0.7222222, -167.0684463>,
    <0.7222222, -167.0684463>,
    <0.7222248, -167.1040945>,
    <0.7222222, -167.1040945>,
    <0.7302300, -167.1040945>,
    <0.2777815, -167.1041136>,
    <0.2777778, -167.1041136>,
    <0.7212363, -167.1040945>,
    <0.7126088, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7222222, -167.0684463>,
    <0.7121490, -167.0684463>,
    <0.7121490, -167.0684463>,
    <0.2959423, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.7024523, -167.1040945>,
    <0.7212362, -167.1040945>,
    <0.2983652, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.2983652, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3055556, -167.0684463>,
    <0.2878510, -167.0684463>,
    <0.2777778, -167.0684463>,
    <0.7121490, -167.0684463>,
    <0.6944444, -167.0684463>,
    <0.3045614, -167.1040945>,
    <0.3045696, -167.1041136>,
    <0.3055553, -167.1041136>,
    <0.3055555, -167.1040945>,
    <0.3055523, -167.1041136>,
    <0.3055555, -167.1041136>,
    <0.3055555, -167.0684463>,
    <0.3055524, -167.1041136>,
    <0.3045695, -167.1041136>,
    <0.7024507, -167.1040945>,
    <0.6944445, -167.0684463>,
    <0.6944445, -167.1040945>,
    <0.6944445, -167.1041136>,
    <0.6934584, -167.1041136>,
    <0.3118314, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.6944444, -167.0684463>,
    <0.6843713, -167.0684463>,
    <0.6843713, -167.0684463>,
    <0.3237199, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6746817, -167.1040945>,
    <0.6934584, -167.1041136>,
    <0.6934587, -167.1040945>,
    <0.6746751, -167.1041136>,
    <0.6746724, -167.1040945>,
    <0.6746817, -167.1040945>,
    <0.3261429, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.3261429, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6762800, -168.0684463>,
    <0.3333333, -167.0684463>,
    <0.3156287, -167.0684463>,
    <0.3055555, -167.0684463>,
    <0.6666667, -167.0684463>,
    <0.3396092, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3323474, -167.1040945>,
    <0.3333331, -167.1040945>,
    <0.3333333, -167.1040945>,
    <0.3333310, -167.1040945>,
    <0.3333333, -167.0684463>,
    <0.3333309, -167.1040945>,
    <0.3323476, -167.1040945>,
    <0.6666691, -167.1040945>,
    <0.6666667, -167.0684463>,
    <0.6666667, -167.1040945>,
    <0.6746744, -167.1040945>,
    <0.6656807, -167.1040945>,
    <0.6570532, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.6485023, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.6666667, -167.0684463>,
    <0.6565937, -167.0684463>,
    <0.6565937, -167.0684463>,
    <0.3611111, -168.0684463>,
    <0.6424032, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6424032, -168.0684463>,
    <0.3611111, -167.0684463>,
    <0.3434063, -167.0684463>,
    <0.6388889, -167.0684463>,
    <0.3601254, -167.1040945>,
    <0.3601252, -167.1040945>,
    <0.3611111, -167.0684463>,
    <0.3611111, -167.1040945>,
    <0.3601254, -167.1040945>,
    <0.6388889, -167.0684463>,
    <0.6656807, -167.1040945>,
    <0.6388889, -167.1040945>,
    <0.6656805, -167.1040945>,
    <0.6388857, -167.1041136>,
    <0.6388889, -167.1041136>,
    <0.3611174, -167.1041136>,
    <0.3611111, -167.1041136>,
    <0.6379027, -167.1041136>,
    <0.3792754, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.3816984, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6207246, -168.0684463>,
    <0.3951648, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.6191270, -167.1040945>,
    <0.6379027, -167.1041136>,
    <0.6379030, -167.1040945>,
    <0.6191213, -167.1041136>,
    <0.6191190, -167.1040945>,
    <0.6014977, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.3888889, -167.0684463>,
    <0.3611111, -167.0684463>,
    <0.3878952, -167.1040945>,
    <0.3879027, -167.1041136>,
    <0.4070531, -168.0684463>,
    <0.3888889, -167.0684463>,
    <0.3888889, -167.1041136>,
    <0.6111141, -167.1040945>,
    <0.6111111, -167.0684463>,
    <0.6111111, -167.1040945>,
    <0.6191193, -167.1040945>,
    <0.6111111, -167.0684463>,
    <0.6101254, -167.1040945>,
    <0.4070531, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.4094761, -168.0684463>,
    <0.4070530, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.5868476, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5929467, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.4094761, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5868477, -168.0684463>,
    <0.4238008, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.5737202, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5913395, -167.1040945>,
    <0.5913412, -167.1040945>,
    <0.6101252, -167.1040945>,
    <0.6101254, -167.1040945>,
    <0.5651689, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.4166667, -167.0684463>,
    <0.3888889, -167.0684463>,
    <0.4444444, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.4156807, -167.1040945>,
    <0.3888889, -167.1040945>,
    <0.4156805, -167.1040945>,
    <0.4166664, -167.1040945>,
    <0.4166667, -167.1040945>,
    <0.4166641, -167.1040945>,
    <0.4166667, -167.0684463>,
    <0.4166642, -167.1040945>,
    <0.4156809, -167.1040945>,
    <0.5833358, -167.1040945>,
    <0.5833333, -167.0684463>,
    <0.5833333, -167.1040945>,
    <0.5913411, -167.1040945>,
    <0.6111111, -167.0684463>,
    <0.5833333, -167.0684463>,
    <0.4166704, -167.1041136>,
    <0.4166667, -167.1041136>,
    <0.5823474, -167.1040945>,
    <0.4444444, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.4507202, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.5459422, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.4274688, -167.0684463>,
    <0.4166667, -167.0684463>,
    <0.4626088, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5373912, -168.0684463>,
    <0.5833333, -167.0684463>,
    <0.5656287, -167.0684463>,
    <0.4722222, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5181645, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5635633, -167.1040945>,
    <0.5823474, -167.1040945>,
    <0.5071342, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4444444, -167.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4434495, -167.1040945>,
    <0.4434584, -167.1041136>,
    <0.4444441, -167.1041136>,
    <0.4444444, -167.1040945>,
    <0.4444410, -167.1041136>,
    <0.4444444, -167.1041136>,
    <0.4444441, -167.1041136>,
    <0.4444444, -167.0684463>,
    <0.4444410, -167.1041136>,
    <0.4434583, -167.1041136>,
    <0.5635618, -167.1040945>,
    <0.5555556, -167.0684463>,
    <0.5555556, -167.1040945>,
    <0.5555556, -167.0684463>,
    <0.5555495, -167.1041136>,
    <0.5555556, -167.1041136>,
    <0.5545696, -167.1041136>,
    <0.4552461, -167.0684463>,
    <0.4444444, -167.0684463>,
    <0.4722200, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5378510, -167.0684463>,
    <0.5357922, -167.1040945>,
    <0.5545695, -167.1041136>,
    <0.5545698, -167.1040945>,
    <0.5357861, -167.1041136>,
    <0.5357836, -167.1040945>,
    <0.5357922, -167.1040945>,
    <0.4712363, -167.1040945>,
    <0.4722220, -167.1040945>,
    <0.4722222, -167.1040945>,
    <0.4722195, -167.1040945>,
    <0.4722222, -167.0684463>,
    <0.4722196, -167.1040945>,
    <0.4712365, -167.1040945>,
    <0.4722222, -167.0684463>,
    <0.4999981, -167.0684463>,
    <0.4722222, -167.0684463>,
    <0.5277805, -167.1040945>,
    <0.5277778, -167.0684463>,
    <0.5277778, -167.1040945>,
    <0.5357857, -167.1040945>,
    <0.5277778, -167.0684463>,
    <0.5267918, -167.1040945>,
    <0.5277778, -167.0684463>,
    <0.5100734, -167.0684463>,
    <0.4990142, -167.1040945>,
    <0.4990139, -167.1040945>,
    <0.5000000, -167.0684463>,
    <0.5000000, -167.1040945>,
    <0.4990142, -167.1040945>,
    <0.5000000, -167.0684463>,
    <0.5000000, -167.0684463>,
    <0.0124799, -167.1040945>,
    <0.0000000, -167.1040945>,
    <0.0000000, -167.1287564>,
    <0.9847022, -167.1040945>,
    <0.0240680, -167.1040945>,
    <0.0277778, -167.1287564>,
    <0.0124798, -167.1040945>,
    <0.9847021, -167.1041136>,
    <0.9722222, -167.1287564>,
    <0.9750789, -167.1041136>,
    <0.9750789, -167.1041136>,
    <0.0000000, -167.2024179>,
    <0.9836443, -167.0684463>,
    <0.0000000, -167.0684463>,
    <0.0000000, -167.1158246>,
    <0.9722222, -167.0684463>,
    <0.9836412, -167.0684463>,
    <0.0402577, -167.1040945>,
    <0.0277778, -167.2024179>,
    <0.9722222, -167.2024179>,
    <0.0000000, -167.3024008>,
    <0.9569245, -167.1040945>,
    <0.0114190, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.0277778, -167.1158246>,
    <0.0000000, -167.0684463>,
    <0.9722222, -167.1158246>,
    <0.0000000, -167.2258020>,
    <0.0277778, -167.3024008>,
    <0.9722222, -167.3024008>,
    <0.0000000, -167.4256532>,
    <0.0277778, -167.2258020>,
    <0.9722222, -167.2258020>,
    <0.0000000, -167.3613758>,
    <0.9558634, -167.0684463>,
    <0.0277778, -167.4256532>,
    <0.9722222, -167.4256532>,
    <0.0000000, -167.5684558>,
    <0.0518458, -167.1040945>,
    <0.0555556, -167.1287564>,
    <0.0518457, -167.1040945>,
    <0.0402576, -167.1040945>,
    <0.9569243, -167.1041136>,
    <0.9444444, -167.1287564>,
    <0.9473011, -167.1041136>,
    <0.9444444, -167.1040945>,
    <0.0277778, -167.3613758>,
    <0.9722222, -167.3613758>,
    <0.0000000, -167.5184453>,
    <0.0000014, -168.0684463>,
    <0.0000000, -168.0684463>,
    <0.0000000, -168.0684463>,
    <0.0277778, -167.5684558>,
    <0.9722222, -167.5684558>,
    <0.0000000, -167.7264218>,
    <0.9444444, -167.0684463>,
    <0.9558604, -167.0684463>,
    <0.0277778, -167.7264218>,
    <0.9722222, -167.7264218>,
    <0.0000000, -167.8948019>,
    <0.0277778, -167.5184453>,
    <0.9722222, -167.5184453>,
    <0.0000000, -167.6922232>,
    <0.0000000, -168.0684463>,
    <0.0000000, -168.0684463>,
    <0.0000013, -168.0684463>,
    <0.0555556, -167.2024179>,
    <0.9444444, -167.2024179>,
    <0.0277778, -167.8948019>,
    <0.9722222, -167.8948019>,
    <0.9722237, -168.0684463>,
    <0.0000000, -168.0684463>,
    <0.9722251, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0000014, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.0277792, -168.0684463>,
    <0.0391937, -167.0684463>,
    <0.0555556, -167.0684463>,
    <0.0555556, -167.1158246>,
    <0.0391968, -167.0684463>,
    <0.9444444, -167.1158246>,
    <0.0277778, -167.6922232>,
    <0.9722222, -167.6922232>,
    <0.0000000, -167.8774261>,
    <0.0680354, -167.1040945>,
    <0.0555556, -167.1040945>,
    <0.0277778, -167.8774261>,
    <0.9722222, -167.8774261>,
    <0.0555556, -167.3024008>,
    <0.9444444, -167.3024008>,
    <0.9722248, -168.0684463>,
    <0.0000000, -168.0684463>,
    <0.9722235, -168.0684463>,
    <0.0000013, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.0277791, -168.0684463>,
    <0.9291465, -167.1040945>,
    <0.0555556, -167.2258020>,
    <0.9444444, -167.2258020>,
    <0.0555555, -167.4256532>,
    <0.9444445, -167.4256532>,
    <0.0555556, -167.3613758>,
    <0.9444444, -167.3613758>,
    <0.0555556, -167.5684558>,
    <0.9444444, -167.5684558>,
    <0.9280857, -167.0684463>,
    <0.9444444, -167.0684463>,
    <0.0555556, -167.7264218>,
    <0.9444444, -167.7264218>,
    <0.0555556, -167.5184453>,
    <0.9444444, -167.5184453>,
    <0.0555556, -167.8948019>,
    <0.9444444, -167.8948019>,
    <0.0555556, -168.0684463>,
    <0.9444459, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.0555570, -168.0684463>,
    <0.0555556, -167.6922232>,
    <0.9444444, -167.6922232>,
    <0.0555556, -167.8774261>,
    <0.9444444, -167.8774261>,
    <0.0555556, -168.0684463>,
    <0.0555568, -168.0684463>,
    <0.0796235, -167.1040945>,
    <0.0833333, -167.1287564>,
    <0.0833333, -167.1040945>,
    <0.0796235, -167.1040945>,
    <0.0680354, -167.1040945>,
    <0.9291466, -167.1041136>,
    <0.9166667, -167.1287564>,
    <0.9195233, -167.1041136>,
    <0.9195233, -167.1041136>,
    <0.9166667, -167.0684463>,
    <0.0833333, -167.2024179>,
    <0.9166667, -167.2024179>,
    <0.0669746, -167.0684463>,
    <0.0833333, -167.0684463>,
    <0.0833333, -167.1158246>,
    <0.0555556, -167.0684463>,
    <0.0669745, -167.0684463>,
    <0.9166667, -167.1158246>,
    <0.0833333, -167.3024008>,
    <0.9166667, -167.3024008>,
    <0.0833333, -167.2258020>,
    <0.9166667, -167.2258020>,
    <0.0833333, -167.4256532>,
    <0.9166667, -167.4256532>,
    <0.0958132, -167.1040945>,
    <0.0833333, -167.3613758>,
    <0.9166667, -167.3613758>,
    <0.0833333, -167.5684558>,
    <0.9166667, -167.5684558>,
    <0.9013686, -167.1040945>,
    <0.9166667, -167.1040945>,
    <0.0833333, -167.7264218>,
    <0.9166667, -167.7264218>,
    <0.0833333, -167.5184453>,
    <0.9166667, -167.5184453>,
    <0.0833333, -167.8948019>,
    <0.9166667, -167.8948019>,
    <0.9166695, -168.0684463>,
    <0.9166681, -168.0684463>,
    <0.9166681, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.0833348, -168.0684463>,
    <0.0833333, -167.6922232>,
    <0.9166667, -167.6922232>,
    <0.0833333, -167.8774261>,
    <0.9166667, -167.8774261>,
    <0.9166680, -168.0684463>,
    <0.9166680, -168.0684463>,
    <0.9166693, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0555581, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166680, -168.0684463>,
    <0.0833346, -168.0684463>,
    <0.9003109, -167.0684463>,
    <0.9166667, -167.0684463>,
    <0.1074012, -167.1040945>,
    <0.1111111, -167.1287564>,
    <0.1074013, -167.1040945>,
    <0.0958131, -167.1040945>,
    <0.9013685, -167.1040945>,
    <0.8888889, -167.1287564>,
    <0.8888889, -167.1040945>,
    <0.8888889, -167.0684463>,
    <0.9003079, -167.0684463>,
    <0.1111111, -167.2024179>,
    <0.8888889, -167.2024179>,
    <0.0947523, -167.0684463>,
    <0.1111111, -167.0684463>,
    <0.1111111, -167.1158246>,
    <0.0833333, -167.0684463>,
    <0.0833385, -167.0684463>,
    <0.8888889, -167.1158246>,
    <0.1111111, -167.3024008>,
    <0.8888889, -167.3024008>,
    <0.1111111, -167.2258020>,
    <0.8888889, -167.2258020>,
    <0.1111111, -167.4256532>,
    <0.8888889, -167.4256532>,
    <0.1111111, -167.3613758>,
    <0.8888889, -167.3613758>,
    <0.1111111, -167.5684558>,
    <0.8888889, -167.5684558>,
    <0.1111111, -167.7264218>,
    <0.8888889, -167.7264218>,
    <0.1111111, -167.5184453>,
    <0.8888889, -167.5184453>,
    <0.1111111, -167.8948019>,
    <0.8888889, -167.8948019>,
    <0.1235909, -167.1040945>,
    <0.8888917, -168.0684463>,
    <0.8888903, -168.0684463>,
    <0.8888903, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.0833362, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.1111125, -168.0684463>,
    <0.1111125, -168.0684463>,
    <0.1111111, -167.6922232>,
    <0.8888889, -167.6922232>,
    <0.1111111, -167.8774261>,
    <0.8888889, -167.8774261>,
    <0.8888902, -168.0684463>,
    <0.8888902, -168.0684463>,
    <0.8888915, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.0833359, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.1111124, -168.0684463>,
    <0.1111124, -168.0684463>,
    <0.8735908, -167.1040945>,
    <0.8725301, -167.0684463>,
    <0.1235910, -167.1040945>,
    <0.1388889, -167.1287564>,
    <0.8735908, -167.1040945>,
    <0.8611111, -167.1287564>,
    <0.8611111, -167.1040945>,
    <0.8611162, -167.0684463>,
    <0.8725332, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.1388889, -167.2024179>,
    <0.8611111, -167.2024179>,
    <0.1225331, -167.0684463>,
    <0.1388889, -167.0684463>,
    <0.1388889, -167.1158246>,
    <0.1225301, -167.0684463>,
    <0.8611111, -167.1158246>,
    <0.1388889, -167.3024008>,
    <0.8611111, -167.3024008>,
    <0.1388889, -167.2258020>,
    <0.8611111, -167.2258020>,
    <0.1388889, -167.4256532>,
    <0.8611111, -167.4256532>,
    <0.1388889, -167.3613758>,
    <0.8611111, -167.3613758>,
    <0.1388889, -167.5684558>,
    <0.8611111, -167.5684558>,
    <0.1388889, -167.7264218>,
    <0.8611111, -167.7264218>,
    <0.1388889, -167.5184453>,
    <0.8611111, -167.5184453>,
    <0.1388889, -167.8948019>,
    <0.8611111, -167.8948019>,
    <0.8611125, -168.0684463>,
    <0.8611140, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.1388903, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388903, -168.0684463>,
    <0.1388889, -167.6922232>,
    <0.8611111, -167.6922232>,
    <0.1388889, -167.8774261>,
    <0.8611111, -167.8774261>,
    <0.8611137, -168.0684463>,
    <0.8611124, -168.0684463>,
    <0.8611124, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1111137, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.1388902, -168.0684463>,
    <0.1388902, -168.0684463>,
    <0.1513685, -167.1040945>,
    <0.1388889, -167.1040945>,
    <0.8458132, -167.1040945>,
    <0.8447523, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.1629568, -167.1040945>,
    <0.1666667, -167.1287564>,
    <0.1513685, -167.1040945>,
    <0.8458131, -167.1041136>,
    <0.8333333, -167.1287564>,
    <0.8361900, -167.1041136>,
    <0.8361901, -167.1041136>,
    <0.8333385, -167.0684463>,
    <0.8447554, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.1666667, -167.2024179>,
    <0.8333333, -167.2024179>,
    <0.1503109, -167.0684463>,
    <0.1666667, -167.0684463>,
    <0.1666667, -167.1158246>,
    <0.1388889, -167.0684463>,
    <0.1503079, -167.0684463>,
    <0.8333333, -167.1158246>,
    <0.1666667, -167.3024008>,
    <0.8333333, -167.3024008>,
    <0.1666667, -167.2258020>,
    <0.8333333, -167.2258020>,
    <0.1666667, -167.4256532>,
    <0.8333333, -167.4256532>,
    <0.1666667, -167.3613758>,
    <0.8333333, -167.3613758>,
    <0.1666667, -167.5684558>,
    <0.8333333, -167.5684558>,
    <0.1666667, -167.7264218>,
    <0.8333333, -167.7264218>,
    <0.1666667, -167.5184453>,
    <0.8333333, -167.5184453>,
    <0.1666667, -167.8948019>,
    <0.8333333, -167.8948019>,
    <0.8333348, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8333362, -168.0684463>,
    <0.8333348, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1388917, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.1666681, -168.0684463>,
    <0.1666667, -167.6922232>,
    <0.8333333, -167.6922232>,
    <0.1666667, -167.8774261>,
    <0.8333333, -167.8774261>,
    <0.8333359, -168.0684463>,
    <0.8333346, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.1666680, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1666680, -168.0684463>,
    <0.1791465, -167.1040945>,
    <0.8180354, -167.1040945>,
    <0.8169746, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.1907346, -167.1040945>,
    <0.1944444, -167.1287564>,
    <0.1907346, -167.1040945>,
    <0.1791465, -167.1040945>,
    <0.8180355, -167.1041136>,
    <0.8055556, -167.1287564>,
    <0.8084122, -167.1041136>,
    <0.8055556, -167.1040945>,
    <0.8055607, -167.0684463>,
    <0.8169746, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.1944444, -167.2024179>,
    <0.8055556, -167.2024179>,
    <0.1780857, -167.0684463>,
    <0.1944444, -167.0684463>,
    <0.1944444, -167.1158246>,
    <0.1666667, -167.0684463>,
    <0.8055556, -167.1158246>,
    <0.1944444, -167.3024008>,
    <0.8055556, -167.3024008>,
    <0.1944444, -167.2258020>,
    <0.8055556, -167.2258020>,
    <0.1944444, -167.4256532>,
    <0.8055556, -167.4256532>,
    <0.1944444, -167.3613758>,
    <0.8055556, -167.3613758>,
    <0.1944444, -167.5684558>,
    <0.8055556, -167.5684558>,
    <0.1944444, -167.7264218>,
    <0.8055556, -167.7264218>,
    <0.1944444, -167.5184453>,
    <0.8055556, -167.5184453>,
    <0.1944444, -167.8948019>,
    <0.8055556, -167.8948019>,
    <0.8055570, -168.0684463>,
    <0.8055584, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.1944459, -168.0684463>,
    <0.1944444, -167.6922232>,
    <0.8055556, -167.6922232>,
    <0.1944444, -167.8774261>,
    <0.8055556, -167.8774261>,
    <0.8055582, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8055569, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.2069243, -167.1040945>,
    <0.1944444, -167.1040945>,
    <0.7902576, -167.1040945>,
    <0.7891937, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.2185123, -167.1040945>,
    <0.2222222, -167.1287564>,
    <0.2069242, -167.1040945>,
    <0.7902577, -167.1041136>,
    <0.7777778, -167.1287564>,
    <0.7806345, -167.1041136>,
    <0.7806345, -167.1041136>,
    <0.7777778, -167.1040945>,
    <0.7777778, -167.0684463>,
    <0.7891968, -167.0684463>,
    <0.2222222, -167.2024179>,
    <0.7777778, -167.2024179>,
    <0.2058634, -167.0684463>,
    <0.2222222, -167.0684463>,
    <0.2222222, -167.1158246>,
    <0.1944444, -167.0684463>,
    <0.2058604, -167.0684463>,
    <0.7777778, -167.1158246>,
    <0.2222222, -167.3024008>,
    <0.7777778, -167.3024008>,
    <0.2222222, -167.2258020>,
    <0.7777778, -167.2258020>,
    <0.2222222, -167.4256532>,
    <0.7777778, -167.4256532>,
    <0.2222222, -167.3613758>,
    <0.7777778, -167.3613758>,
    <0.2222222, -167.5684558>,
    <0.7777778, -167.5684558>,
    <0.2222222, -167.7264218>,
    <0.7777778, -167.7264218>,
    <0.2222222, -167.5184453>,
    <0.7777778, -167.5184453>,
    <0.2222222, -167.8948019>,
    <0.7777778, -167.8948019>,
    <0.2222222, -168.0684463>,
    <0.7777792, -168.0684463>,
    <0.2222236, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2222222, -167.6922232>,
    <0.7777778, -167.6922232>,
    <0.2222222, -167.8774261>,
    <0.7777778, -167.8774261>,
    <0.7777778, -168.0684463>,
    <0.7777791, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2222235, -168.0684463>,
    <0.2347021, -167.1040945>,
    <0.2222222, -167.1040945>,
    <0.7624800, -167.1040945>,
    <0.7614190, -167.0684463>,
    <0.7500013, -168.0684463>,
    <0.7500000, -167.1287564>,
    <0.7624799, -167.1040945>,
    <0.7500000, -167.1040945>,
    <0.7500000, -167.0684463>,
    <0.7500000, -167.2024179>,
    <0.7500000, -167.1158246>,
    <0.7500000, -167.3024008>,
    <0.7500000, -167.2258020>,
    <0.7500000, -167.4256532>,
    <0.7500000, -167.3613758>,
    <0.7500000, -167.5684558>,
    <0.7500000, -167.7264218>,
    <0.7500000, -167.5184453>,
    <0.7500000, -167.8948019>,
    <0.7500014, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7500014, -168.0684463>,
    <0.7500000, -167.6922232>,
    <0.7500000, -167.8774261>,
    <0.7500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500013, -168.0684463>,
    <0.2222248, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -167.8774261>,
    <0.2500000, -167.6922232>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2222251, -168.0684463>,
    <0.2500000, -167.8948019>,
    <0.2500000, -167.5184453>,
    <0.2500000, -167.7264218>,
    <0.2500000, -167.5684558>,
    <0.2500000, -167.3613758>,
    <0.2500000, -167.4256532>,
    <0.2500000, -167.2258020>,
    <0.2500000, -167.3024008>,
    <0.2336412, -167.0684463>,
    <0.2500000, -167.1158246>,
    <0.2500000, -167.2024179>,
    <0.2336443, -167.0684463>,
    <0.2500000, -167.0684463>,
    <0.2462901, -167.1040945>,
    <0.2347022, -167.1040945>,
    <0.2500000, -167.1287564>,
    <0.2462902, -167.1040945>,
    <0.2500000, -167.1040945>,
    <0.2500013, -168.0684463>,
    <0.2500014, -168.0684463>,
    <0.2624799, -167.1040945>,
    <0.2500000, -167.1040945>,
    <0.7347022, -167.1040945>,
    <0.7500000, -167.1040945>,
    <0.7336443, -167.0684463>,
    <0.7500000, -167.0684463>,
    <0.7222248, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7222235, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2500013, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.2777791, -168.0684463>,
    <0.2777778, -167.8774261>,
    <0.7222222, -167.8774261>,
    <0.2777778, -167.6922232>,
    <0.7222222, -167.6922232>,
    <0.7222237, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7222251, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2500014, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.2777778, -167.8948019>,
    <0.7222222, -167.8948019>,
    <0.2777778, -167.5184453>,
    <0.7222222, -167.5184453>,
    <0.2777778, -167.7264218>,
    <0.7222222, -167.7264218>,
    <0.2777778, -167.5684558>,
    <0.7222222, -167.5684558>,
    <0.2777778, -167.3613758>,
    <0.7222222, -167.3613758>,
    <0.2777778, -167.4256532>,
    <0.7222222, -167.4256532>,
    <0.2777778, -167.2258020>,
    <0.7222222, -167.2258020>,
    <0.2777778, -167.3024008>,
    <0.7222222, -167.3024008>,
    <0.2500000, -167.0684463>,
    <0.2777778, -167.1158246>,
    <0.2614190, -167.0684463>,
    <0.7222222, -167.1158246>,
    <0.2777778, -167.2024179>,
    <0.7222222, -167.2024179>,
    <0.2777778, -167.0684463>,
    <0.7222222, -167.0684463>,
    <0.7336412, -167.0684463>,
    <0.2740679, -167.1040945>,
    <0.2624800, -167.1040945>,
    <0.2777778, -167.1287564>,
    <0.7222222, -167.1287564>,
    <0.7347021, -167.1041136>,
    <0.7250789, -167.1041136>,
    <0.2902576, -167.1040945>,
    <0.7069243, -167.1040945>,
    <0.7058635, -167.0684463>,
    <0.3055555, -168.0684463>,
    <0.3055568, -168.0684463>,
    <0.3055555, -167.8774261>,
    <0.6944445, -167.8774261>,
    <0.3055555, -167.6922232>,
    <0.6944445, -167.6922232>,
    <0.2777792, -168.0684463>,
    <0.6944459, -168.0684463>,
    <0.3055570, -168.0684463>,
    <0.3055555, -167.8948019>,
    <0.6944445, -167.8948019>,
    <0.3055555, -167.5184453>,
    <0.6944445, -167.5184453>,
    <0.3055555, -167.7264218>,
    <0.6944445, -167.7264218>,
    <0.3055555, -167.5684558>,
    <0.6944445, -167.5684558>,
    <0.3055555, -167.3613758>,
    <0.6944445, -167.3613758>,
    <0.3055555, -167.4256532>,
    <0.6944445, -167.4256532>,
    <0.3055555, -167.2258020>,
    <0.6944445, -167.2258020>,
    <0.3055555, -167.3024008>,
    <0.6944445, -167.3024008>,
    <0.2777778, -167.0684463>,
    <0.2891937, -167.0684463>,
    <0.3055555, -167.1158246>,
    <0.2777829, -167.0684463>,
    <0.6944445, -167.1158246>,
    <0.3055555, -167.2024179>,
    <0.6944445, -167.2024179>,
    <0.3055555, -167.0684463>,
    <0.6944445, -167.0684463>,
    <0.7058604, -167.0684463>,
    <0.3018457, -167.1040945>,
    <0.2902576, -167.1040945>,
    <0.3055555, -167.1287564>,
    <0.7069243, -167.1041136>,
    <0.6973011, -167.1041136>,
    <0.6944445, -167.1287564>,
    <0.3018457, -167.1040945>,
    <0.6944445, -167.1040945>,
    <0.3180354, -167.1040945>,
    <0.3055555, -167.1040945>,
    <0.6780857, -167.0684463>,
    <0.6944445, -167.0684463>,
    <0.6791465, -167.1040945>,
    <0.6666680, -168.0684463>,
    <0.6666680, -168.0684463>,
    <0.6666693, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3055581, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6666680, -168.0684463>,
    <0.3333346, -168.0684463>,
    <0.3333333, -167.8774261>,
    <0.6666667, -167.8774261>,
    <0.3333333, -167.6922232>,
    <0.6666667, -167.6922232>,
    <0.6666695, -168.0684463>,
    <0.6666681, -168.0684463>,
    <0.6666681, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3055584, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.3333348, -168.0684463>,
    <0.3333333, -167.8948019>,
    <0.6666667, -167.8948019>,
    <0.3333333, -167.5184453>,
    <0.6666667, -167.5184453>,
    <0.3333333, -167.7264218>,
    <0.6666667, -167.7264218>,
    <0.3333333, -167.5684558>,
    <0.6666667, -167.5684558>,
    <0.3333333, -167.3613758>,
    <0.6666667, -167.3613758>,
    <0.3333333, -167.4256532>,
    <0.6666667, -167.4256532>,
    <0.3333333, -167.2258020>,
    <0.6666667, -167.2258020>,
    <0.3333333, -167.3024008>,
    <0.6666667, -167.3024008>,
    <0.3055555, -167.0684463>,
    <0.3333333, -167.1158246>,
    <0.3169745, -167.0684463>,
    <0.6666667, -167.1158246>,
    <0.3333333, -167.2024179>,
    <0.6666667, -167.2024179>,
    <0.3169745, -167.0684463>,
    <0.3333333, -167.0684463>,
    <0.6666667, -167.0684463>,
    <0.3296235, -167.1040945>,
    <0.3180354, -167.1040945>,
    <0.3333333, -167.1287564>,
    <0.6791466, -167.1041136>,
    <0.6695233, -167.1041136>,
    <0.6666667, -167.1287564>,
    <0.6695233, -167.1041136>,
    <0.3296235, -167.1040945>,
    <0.3333333, -167.1040945>,
    <0.3458130, -167.1040945>,
    <0.6503109, -167.0684463>,
    <0.6666667, -167.0684463>,
    <0.6513686, -167.1040945>,
    <0.6666667, -167.1040945>,
    <0.6388902, -168.0684463>,
    <0.6388902, -168.0684463>,
    <0.6388915, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3333359, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.3611124, -168.0684463>,
    <0.3611111, -167.8774261>,
    <0.6388889, -167.8774261>,
    <0.3611111, -167.6922232>,
    <0.6388889, -167.6922232>,
    <0.6388918, -168.0684463>,
    <0.6388903, -168.0684463>,
    <0.6388903, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3333362, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.3611125, -168.0684463>,
    <0.3611111, -167.8948019>,
    <0.6388889, -167.8948019>,
    <0.3611111, -167.5184453>,
    <0.6388889, -167.5184453>,
    <0.3611111, -167.7264218>,
    <0.6388889, -167.7264218>,
    <0.3611111, -167.5684558>,
    <0.6388889, -167.5684558>,
    <0.3611111, -167.3613758>,
    <0.6388889, -167.3613758>,
    <0.3611111, -167.4256532>,
    <0.6388889, -167.4256532>,
    <0.3611111, -167.2258020>,
    <0.6388889, -167.2258020>,
    <0.3611111, -167.3024008>,
    <0.6388889, -167.3024008>,
    <0.3447523, -167.0684463>,
    <0.3611111, -167.1158246>,
    <0.3333333, -167.0684463>,
    <0.3333385, -167.0684463>,
    <0.6388889, -167.1158246>,
    <0.3611111, -167.2024179>,
    <0.6388889, -167.2024179>,
    <0.3611111, -167.0684463>,
    <0.6388889, -167.0684463>,
    <0.6503079, -167.0684463>,
    <0.3574013, -167.1040945>,
    <0.3458131, -167.1040945>,
    <0.3611111, -167.1287564>,
    <0.6513685, -167.1041136>,
    <0.6417456, -167.1041136>,
    <0.6388889, -167.1287564>,
    <0.3611111, -167.1040945>,
    <0.3735907, -167.1040945>,
    <0.6225332, -167.0684463>,
    <0.6388889, -167.0684463>,
    <0.6111124, -168.0684463>,
    <0.6111124, -168.0684463>,
    <0.6111137, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3611137, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.3888902, -168.0684463>,
    <0.3888902, -168.0684463>,
    <0.3888889, -167.8774261>,
    <0.6111111, -167.8774261>,
    <0.3888889, -167.6922232>,
    <0.6111111, -167.6922232>,
    <0.6111140, -168.0684463>,
    <0.6111125, -168.0684463>,
    <0.6111125, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3611139, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.3888903, -168.0684463>,
    <0.3888903, -168.0684463>,
    <0.6235910, -167.1040945>,
    <0.3888889, -167.8948019>,
    <0.6111111, -167.8948019>,
    <0.3888889, -167.5184453>,
    <0.6111111, -167.5184453>,
    <0.3888889, -167.7264218>,
    <0.6111111, -167.7264218>,
    <0.3888889, -167.5684558>,
    <0.6111111, -167.5684558>,
    <0.3888889, -167.3613758>,
    <0.6111111, -167.3613758>,
    <0.3888889, -167.4256532>,
    <0.6111111, -167.4256532>,
    <0.3888889, -167.2258020>,
    <0.6111111, -167.2258020>,
    <0.3888889, -167.3024008>,
    <0.6111111, -167.3024008>,
    <0.3725301, -167.0684463>,
    <0.3888889, -167.1158246>,
    <0.3611111, -167.0684463>,
    <0.3611162, -167.0684463>,
    <0.6111111, -167.1158246>,
    <0.3888889, -167.2024179>,
    <0.6111111, -167.2024179>,
    <0.3888889, -167.0684463>,
    <0.6111111, -167.0684463>,
    <0.6225301, -167.0684463>,
    <0.3851791, -167.1040945>,
    <0.3735908, -167.1040945>,
    <0.3888889, -167.1287564>,
    <0.6235909, -167.1041136>,
    <0.6139677, -167.1041136>,
    <0.6111111, -167.1287564>,
    <0.3851791, -167.1040945>,
    <0.6139677, -167.1041136>,
    <0.6111111, -167.1040945>,
    <0.5833359, -168.0684463>,
    <0.5833346, -168.0684463>,
    <0.5833346, -168.0684463>,
    <0.5833359, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.3888915, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.4166680, -168.0684463>,
    <0.4166680, -168.0684463>,
    <0.4166667, -167.8774261>,
    <0.5833333, -167.8774261>,
    <0.4166667, -167.6922232>,
    <0.5833333, -167.6922232>,
    <0.5833348, -168.0684463>,
    <0.5833362, -168.0684463>,
    <0.5833348, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.3888917, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.4166681, -168.0684463>,
    <0.4166667, -167.8948019>,
    <0.5833333, -167.8948019>,
    <0.4166667, -167.5184453>,
    <0.5833333, -167.5184453>,
    <0.4166667, -167.7264218>,
    <0.5833333, -167.7264218>,
    <0.5947523, -167.0684463>,
    <0.4013685, -167.1040945>,
    <0.3888889, -167.1040945>,
    <0.4166667, -167.5684558>,
    <0.5833333, -167.5684558>,
    <0.4166667, -167.3613758>,
    <0.5833333, -167.3613758>,
    <0.5958131, -167.1040945>,
    <0.4166667, -167.4256532>,
    <0.5833333, -167.4256532>,
    <0.4166667, -167.2258020>,
    <0.5833333, -167.2258020>,
    <0.4166667, -167.3024008>,
    <0.5833333, -167.3024008>,
    <0.4166667, -167.1158246>,
    <0.4003079, -167.0684463>,
    <0.5833333, -167.1158246>,
    <0.4166667, -167.2024179>,
    <0.5833333, -167.2024179>,
    <0.5833385, -167.0684463>,
    <0.5947554, -167.0684463>,
    <0.4003109, -167.0684463>,
    <0.4166667, -167.0684463>,
    <0.5833333, -167.0684463>,
    <0.4129568, -167.1040945>,
    <0.4013685, -167.1040945>,
    <0.4166667, -167.1287564>,
    <0.5958132, -167.1041136>,
    <0.5861900, -167.1041136>,
    <0.5833333, -167.1287564>,
    <0.5555582, -168.0684463>,
    <0.5555569, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.4444444, -167.8774261>,
    <0.5555556, -167.8774261>,
    <0.5861900, -167.1041136>,
    <0.4444444, -167.6922232>,
    <0.5555556, -167.6922232>,
    <0.5555570, -168.0684463>,
    <0.5555584, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444459, -168.0684463>,
    <0.4444444, -167.8948019>,
    <0.5555556, -167.8948019>,
    <0.4444444, -167.5184453>,
    <0.5555556, -167.5184453>,
    <0.4444444, -167.7264218>,
    <0.5555556, -167.7264218>,
    <0.4444444, -167.5684558>,
    <0.5555556, -167.5684558>,
    <0.4444444, -167.3613758>,
    <0.5555556, -167.3613758>,
    <0.5669746, -167.0684463>,
    <0.5833333, -167.0684463>,
    <0.4444444, -167.4256532>,
    <0.5555556, -167.4256532>,
    <0.4444444, -167.2258020>,
    <0.5555556, -167.2258020>,
    <0.4291465, -167.1040945>,
    <0.5277778, -168.0684463>,
    <0.5277791, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4722235, -168.0684463>,
    <0.4444444, -167.3024008>,
    <0.5555556, -167.3024008>,
    <0.4722222, -167.8774261>,
    <0.5277778, -167.8774261>,
    <0.5680354, -167.1040945>,
    <0.4722222, -167.6922232>,
    <0.5277778, -167.6922232>,
    <0.4166667, -167.0684463>,
    <0.4444444, -167.1158246>,
    <0.4280857, -167.0684463>,
    <0.5555556, -167.1158246>,
    <0.4722222, -168.0684463>,
    <0.5277792, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.4722236, -168.0684463>,
    <0.4722222, -167.8948019>,
    <0.5277778, -167.8948019>,
    <0.4444444, -167.2024179>,
    <0.5555556, -167.2024179>,
    <0.5000013, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4722248, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000013, -168.0684463>,
    <0.4722222, -167.5184453>,
    <0.5277778, -167.5184453>,
    <0.4722222, -167.7264218>,
    <0.5277778, -167.7264218>,
    <0.5000000, -167.8774261>,
    <0.5555607, -167.0684463>,
    <0.5669746, -167.0684463>,
    <0.4444444, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5000000, -167.6922232>,
    <0.4722222, -167.5684558>,
    <0.5277778, -167.5684558>,
    <0.5000000, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4722251, -168.0684463>,
    <0.5000014, -168.0684463>,
    <0.5000014, -168.0684463>,
    <0.4722222, -167.3613758>,
    <0.5277778, -167.3613758>,
    <0.5000000, -167.8948019>,
    <0.4407346, -167.1040945>,
    <0.4291465, -167.1040945>,
    <0.4444444, -167.1287564>,
    <0.5555556, -167.1287564>,
    <0.5680355, -167.1041136>,
    <0.5000000, -167.5184453>,
    <0.5584122, -167.1041136>,
    <0.5000000, -167.7264218>,
    <0.4722222, -167.4256532>,
    <0.5277778, -167.4256532>,
    <0.4407346, -167.1040945>,
    <0.5555556, -167.1040945>,
    <0.5000000, -167.5684558>,
    <0.4722222, -167.2258020>,
    <0.5277778, -167.2258020>,
    <0.5000000, -167.3613758>,
    <0.4722222, -167.3024008>,
    <0.5277778, -167.3024008>,
    <0.5391937, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5000000, -167.4256532>,
    <0.5000000, -167.2258020>,
    <0.4444444, -167.0684463>,
    <0.4722222, -167.1158246>,
    <0.4558604, -167.0684463>,
    <0.5277778, -167.1158246>,
    <0.4569243, -167.1040945>,
    <0.4444444, -167.1040945>,
    <0.4722222, -167.2024179>,
    <0.5277778, -167.2024179>,
    <0.5000000, -167.3024008>,
    <0.5402576, -167.1040945>,
    <0.4558634, -167.0684463>,
    <0.4722222, -167.0684463>,
    <0.5277778, -167.0684463>,
    <0.5391968, -167.0684463>,
    <0.5000000, -167.1158246>,
    <0.4836412, -167.0684463>,
    <0.5114190, -167.0684463>,
    <0.5000000, -167.2024179>,
    <0.4722222, -167.1287564>,
    <0.5277778, -167.1287564>,
    <0.5402577, -167.1041136>,
    <0.4685123, -167.1040945>,
    <0.4569245, -167.1040945>,
    <0.5306344, -167.1041136>,
    <0.4836443, -167.0684463>,
    <0.5000000, -167.0684463>,
    <0.5000000, -167.0684463>,
    <0.4722222, -167.1040945>,
    <0.5306344, -167.1041136>,
    <0.5000000, -167.1287564>,
    <0.4847021, -167.1040945>,
    <0.4722222, -167.1040945>,
    <0.5124799, -167.1040945>,
    <0.5124798, -167.1040945>,
    <0.4962902, -167.1040945>,
    <0.4847022, -167.1040945>,
    <0.5000000, -167.1040945>,
    <0.4962903, -167.1040945>,
    <0.5000000, -167.1040945>,
    <0.9996714, -167.0922118>,
    <1.0000000, -167.1040945>,
    <1.0000000, -167.0684463>,
    <0.9990142, -167.1040945>,
    <1.0000000, -167.0866834>,
    <0.9997076, -167.0790193>,
    <0.9991661, -167.1040945>,
    <0.9930814, -167.0922118>,
    <0.9802301, -167.1040945>,
    <0.9990140, -167.1040945>,
    <1.0000000, -167.0684463>,
    <0.9890793, -167.1040945>,
    <0.9997076, -167.0790193>,
    <0.9911505, -167.0844033>,
    <0.6755973, -167.0922118>,
    <0.0267920, -167.1040945>,
    <1.0000000, -167.0684463>,
    <1.0000000, -167.1040945>,
    <0.5401131, -167.0852918>,
    <1.0000000, -167.0866834>,
    <0.5799923, -167.1040945>,
    <0.0274483, -167.0922118>,
    <0.0277752, -167.1040945>,
    <0.0277778, -167.0684463>,
    <0.0267920, -167.1040945>,
    <0.0277765, -167.0866273>,
    <0.0275224, -167.0776799>,
    <0.0269074, -167.1040945>,
    <0.3515232, -167.0803290>,
    <0.0267920, -167.1040945>,
    <0.0277778, -167.0684463>,
    <1.0000000, -167.0684463>,
    <0.0275224, -167.0776799>,
    <0.5138889, -167.0684463>,
    <0.5401131, -167.0852918>,
    <0.9841508, -167.0803290>,
    <0.9802301, -167.1040945>,
    <1.0000000, -167.0684463>,
    <0.9722222, -167.0684463>,
    <0.9911505, -167.0844033>,
    <0.9861111, -167.0684463>,
    <0.9750946, -167.0812332>,
    <0.9748924, -167.0922118>,
    <0.9722248, -167.1040945>,
    <0.9802300, -167.1040945>,
    <0.9722222, -167.0684463>,
    <0.9768018, -167.1040945>,
    <0.9750946, -167.0812332>,
    <0.9722235, -167.0865214>,
    <0.9718936, -167.0922118>,
    <0.9722222, -167.1040945>,
    <0.9722222, -167.0684463>,
    <0.9712363, -167.1040945>,
    <0.9722222, -167.0865214>,
    <0.9719160, -167.0795187>,
    <0.9713884, -167.1040945>,
    <0.3461935, -167.0684463>,
    <0.0108027, -167.0684463>,
    <0.0277778, -167.0684463>,
    <1.0000000, -167.0684463>,
    <0.0192902, -167.0684463>,
    <0.5138889, -167.0684463>,
    <0.5054013, -167.0684463>,
    <0.3459504, -167.0684463>,
    <0.0277778, -167.0684463>,
    <1.0000000, -167.0684463>,
    <0.0100734, -167.0684463>,
    <0.5138889, -167.0684463>,
    <0.5050367, -167.0684463>,
    <0.0189256, -167.0684463>,
    <0.9653031, -167.0922118>,
    <0.9524507, -167.1040945>,
    <0.9712364, -167.1040945>,
    <0.9722222, -167.0684463>,
    <0.9613008, -167.1040945>,
    <0.9719160, -167.0795187>,
    <0.9633720, -167.0844033>,
    <0.0367084, -167.0922118>,
    <0.0545696, -167.1040945>,
    <0.0277778, -167.0684463>,
    <0.0277778, -167.1040945>,
    <0.0400546, -167.0847813>,
    <0.0277778, -167.0866273>,
    <0.0393404, -167.1040945>,
    <0.0552258, -167.0922245>,
    <0.0555523, -167.1041136>,
    <0.0555556, -167.0684463>,
    <0.0545695, -167.1041136>,
    <0.0555539, -167.0866460>,
    <0.0552936, -167.0779231>,
    <0.0546849, -167.1041136>,
    <0.0459676, -167.0803290>,
    <0.0545696, -167.1040945>,
    <0.0555556, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.0552936, -167.0779180>,
    <0.0416667, -167.0684463>,
    <0.0400546, -167.0847813>,
    <0.9563725, -167.0803290>,
    <0.9524507, -167.1040945>,
    <0.9722222, -167.0684463>,
    <0.9444444, -167.0684463>,
    <0.9633720, -167.0844033>,
    <0.9583333, -167.0684463>,
    <0.9473217, -167.0812574>,
    <0.9471132, -167.0922118>,
    <0.9524507, -167.1040945>,
    <0.9444444, -167.0684463>,
    <0.9444444, -167.1040945>,
    <0.9473217, -167.0812574>,
    <0.9444444, -167.0865447>,
    <0.9490221, -167.1040945>,
    <0.9441158, -167.0922245>,
    <0.9444444, -167.1041136>,
    <0.9444444, -167.0684463>,
    <0.9434584, -167.1041136>,
    <0.9444444, -167.0865543>,
    <0.9441436, -167.0793291>,
    <0.9436105, -167.1041136>,
    <0.0403948, -167.0684463>,
    <0.0555556, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.0378510, -167.0684463>,
    <0.0416667, -167.0684463>,
    <0.0328144, -167.0684463>,
    <0.0467033, -167.0684463>,
    <0.6698711, -168.0684463>,
    <0.0096133, -168.0684463>,
    <1.0000000, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.5418430, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.1769606, -168.0684463>,
    <0.9919122, -168.0684463>,
    <0.9757366, -168.0684463>,
    <1.0000000, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.9906383, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.9893194, -168.0684463>,
    <0.0153141, -168.0684463>,
    <0.0181645, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0163168, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0154703, -168.0684463>,
    <0.0124637, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0096133, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0114611, -168.0684463>,
    <0.0123076, -168.0684463>,
    <0.3411674, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0096133, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.0123076, -168.0684463>,
    <0.1769606, -168.0684463>,
    <0.2111020, -168.0684463>,
    <0.0245734, -168.0684463>,
    <0.0181645, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0197929, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0233307, -168.0684463>,
    <0.0199437, -168.0684463>,
    <0.0181645, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0154703, -168.0684463>,
    <0.0166668, -168.0684463>,
    <0.0197929, -168.0684463>,
    <0.9826529, -168.0684463>,
    <0.9757366, -168.0684463>,
    <0.9722222, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.9727098, -168.0684463>,
    <0.9850856, -168.0684463>,
    <0.9906383, -168.0684463>,
    <0.9733937, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9757365, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9727098, -168.0684463>,
    <0.9747238, -168.0684463>,
    <0.0309823, -168.0684463>,
    <0.0373913, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0325154, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0308767, -168.0684463>,
    <0.9690177, -168.0684463>,
    <0.9626087, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9679074, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9674847, -168.0684463>,
    <0.9375258, -167.0922118>,
    <0.9246744, -167.1040945>,
    <0.9434585, -167.1040945>,
    <0.9444444, -167.0684463>,
    <0.9335235, -167.1040945>,
    <0.9441436, -167.0793233>,
    <0.9355962, -167.0844009>,
    <0.0370370, -168.0684463>,
    <0.0459421, -168.0684463>,
    <0.0373913, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0411987, -168.0684463>,
    <0.0308767, -168.0684463>,
    <0.0333632, -168.0684463>,
    <0.9629629, -168.0684463>,
    <0.9626087, -168.0684463>,
    <0.9540579, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9585587, -168.0684463>,
    <0.9676410, -168.0684463>,
    <0.9679074, -168.0684463>,
    <0.0644862, -167.0922118>,
    <0.0823476, -167.1040945>,
    <0.0555556, -167.0684463>,
    <0.0555556, -167.1040945>,
    <0.0678363, -167.0847864>,
    <0.0555556, -167.0866363>,
    <0.0671182, -167.1040945>,
    <0.0830040, -167.0922118>,
    <0.0833310, -167.1040945>,
    <0.0833333, -167.0684463>,
    <0.0823476, -167.1040945>,
    <0.0833321, -167.0866432>,
    <0.0830643, -167.0781738>,
    <0.0824630, -167.1040945>,
    <0.0737455, -167.0803290>,
    <0.0823476, -167.1040945>,
    <0.0833333, -167.0684463>,
    <0.0555556, -167.0684463>,
    <0.0830643, -167.0781738>,
    <0.0694444, -167.0684463>,
    <0.0678363, -167.0847864>,
    <0.9285952, -167.0803290>,
    <0.9246744, -167.1040945>,
    <0.9444444, -167.0684463>,
    <0.9166667, -167.0684463>,
    <0.9355962, -167.0844009>,
    <0.9305556, -167.0684463>,
    <0.9195405, -167.0812396>,
    <0.9193367, -167.0922118>,
    <0.9166690, -167.1040945>,
    <0.9246744, -167.1040945>,
    <0.9166667, -167.0684463>,
    <0.9212459, -167.1040945>,
    <0.9195405, -167.0812396>,
    <0.9166679, -167.0865421>,
    <0.9163380, -167.0922118>,
    <0.9166667, -167.1040945>,
    <0.9166667, -167.0684463>,
    <0.9156807, -167.1040945>,
    <0.9166667, -167.0865421>,
    <0.9163658, -167.0793231>,
    <0.9158328, -167.1040945>,
    <0.0532435, -168.0684463>,
    <0.0486194, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0523719, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0523764, -168.0684463>,
    <0.0500390, -168.0684463>,
    <0.0486193, -168.0684463>,
    <0.0459421, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0472136, -168.0684463>,
    <0.0542256, -168.0684463>,
    <0.0523718, -168.0684463>,
    <0.0430918, -168.0684463>,
    <0.0459421, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0333632, -168.0684463>,
    <0.0456798, -168.0684463>,
    <0.0542256, -168.0684463>,
    <0.9488204, -168.0684463>,
    <0.9479588, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9540579, -168.0684463>,
    <0.9454570, -168.0684463>,
    <0.9456242, -168.0684463>,
    <0.9513222, -168.0684463>,
    <0.9569082, -168.0684463>,
    <0.9540579, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9456242, -168.0684463>,
    <0.9594863, -168.0684463>,
    <0.9676410, -168.0684463>,
    <0.9456159, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9479587, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9454570, -168.0684463>,
    <0.9463484, -168.0684463>,
    <0.0681725, -167.0684463>,
    <0.0833333, -167.0684463>,
    <0.0555556, -167.0684463>,
    <0.0656287, -167.0684463>,
    <0.0694444, -167.0684463>,
    <0.0605921, -167.0684463>,
    <0.0744810, -167.0684463>,
    <0.9412400, -168.0684463>,
    <0.9348311, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9403870, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9397069, -168.0684463>,
    <0.0616104, -168.0684463>,
    <0.0737200, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0635542, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0595359, -168.0684463>,
    <0.9351852, -168.0684463>,
    <0.9348311, -168.0684463>,
    <0.9262800, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9307809, -168.0684463>,
    <0.9400008, -168.0684463>,
    <0.9403870, -168.0684463>,
    <0.9097477, -167.0922118>,
    <0.8968956, -167.1040945>,
    <0.9156807, -167.1040945>,
    <0.9166667, -167.0684463>,
    <0.9057454, -167.1040945>,
    <0.9163658, -167.0793231>,
    <0.9078225, -167.0843929>,
    <0.0810213, -168.0684463>,
    <0.0763972, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0803383, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0801542, -168.0684463>,
    <0.0778168, -168.0684463>,
    <0.0763972, -168.0684463>,
    <0.0737200, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0746941, -168.0684463>,
    <0.0812101, -168.0684463>,
    <0.0803383, -168.0684463>,
    <0.0708696, -168.0684463>,
    <0.0737200, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0595359, -168.0684463>,
    <0.0701352, -168.0684463>,
    <0.0812101, -168.0684463>,
    <0.9210425, -168.0684463>,
    <0.9201809, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9262800, -168.0684463>,
    <0.9176792, -168.0684463>,
    <0.9178464, -168.0684463>,
    <0.9235443, -168.0684463>,
    <0.9291304, -168.0684463>,
    <0.9262800, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9178464, -168.0684463>,
    <0.9319411, -168.0684463>,
    <0.9400008, -168.0684463>,
    <0.9178381, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9201809, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9176792, -168.0684463>,
    <0.9185707, -168.0684463>,
    <0.0865378, -168.0684463>,
    <0.0929468, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0880710, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0868566, -168.0684463>,
    <0.9134622, -168.0684463>,
    <0.9070532, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9126094, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9119291, -168.0684463>,
    <0.0922639, -167.0922118>,
    <0.1101252, -167.1040945>,
    <0.0833333, -167.0684463>,
    <0.0833333, -167.1040945>,
    <0.0956079, -167.0847783>,
    <0.0833333, -167.0866432>,
    <0.0948961, -167.1040945>,
    <0.1107826, -167.0922118>,
    <0.1111111, -167.1040945>,
    <0.1111111, -167.0684463>,
    <0.1101256, -167.1040945>,
    <0.1111111, -167.0866197>,
    <0.1108511, -167.0778511>,
    <0.1102415, -167.1040945>,
    <0.1015232, -167.0803290>,
    <0.1101252, -167.1040945>,
    <0.1111111, -167.0684463>,
    <0.0833333, -167.0684463>,
    <0.1108510, -167.0778511>,
    <0.0972222, -167.0684463>,
    <0.0956079, -167.0847783>,
    <0.9008171, -167.0803290>,
    <0.8968956, -167.1040945>,
    <0.9166667, -167.0684463>,
    <0.8888889, -167.0684463>,
    <0.9078225, -167.0843929>,
    <0.9027778, -167.0684463>,
    <0.8917545, -167.0812048>,
    <0.8915578, -167.0922118>,
    <0.8968957, -167.1040945>,
    <0.8888889, -167.0684463>,
    <0.8888889, -167.1040945>,
    <0.8917545, -167.0812048>,
    <0.8888889, -167.0865760>,
    <0.8934667, -167.1040945>,
    <0.8885602, -167.0922245>,
    <0.8888889, -167.1041136>,
    <0.8888889, -167.0684463>,
    <0.8879027, -167.1041136>,
    <0.8888889, -167.0865857>,
    <0.8885964, -167.0790254>,
    <0.8880547, -167.1041136>,
    <0.0925926, -168.0684463>,
    <0.1014978, -168.0684463>,
    <0.0929468, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0967543, -168.0684463>,
    <0.0868566, -168.0684463>,
    <0.0871253, -168.0684463>,
    <0.9074074, -168.0684463>,
    <0.9070532, -168.0684463>,
    <0.8985022, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9030031, -168.0684463>,
    <0.9122231, -168.0684463>,
    <0.9126094, -168.0684463>,
    <0.1087991, -168.0684463>,
    <0.1041749, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1079257, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1079320, -168.0684463>,
    <0.1055946, -168.0684463>,
    <0.1041749, -168.0684463>,
    <0.1014978, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1027692, -168.0684463>,
    <0.1097808, -168.0684463>,
    <0.1079257, -168.0684463>,
    <0.0986474, -168.0684463>,
    <0.1014978, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.0871253, -168.0684463>,
    <0.0979343, -168.0684463>,
    <0.1097808, -168.0684463>,
    <0.8932648, -168.0684463>,
    <0.8924032, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8985022, -168.0684463>,
    <0.8899061, -168.0684463>,
    <0.8900704, -168.0684463>,
    <0.8957666, -168.0684463>,
    <0.9013526, -168.0684463>,
    <0.8985022, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.8900704, -168.0684463>,
    <0.9041714, -168.0684463>,
    <0.9122231, -168.0684463>,
    <0.8900603, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8924032, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8899061, -168.0684463>,
    <0.8907929, -168.0684463>,
    <0.8819704, -167.0922118>,
    <0.8691193, -167.1040945>,
    <0.8879030, -167.1040945>,
    <0.8888889, -167.0684463>,
    <0.8779682, -167.1040945>,
    <0.8885965, -167.0790198>,
    <0.8800396, -167.0844032>,
    <0.1200417, -167.0922118>,
    <0.1379029, -167.1040945>,
    <0.1111111, -167.0684463>,
    <0.1111111, -167.1040945>,
    <0.1233876, -167.0847809>,
    <0.1111111, -167.0866197>,
    <0.1226736, -167.1040945>,
    <0.1385582, -167.0922245>,
    <0.1388828, -167.1041136>,
    <0.1388889, -167.0684463>,
    <0.1379028, -167.1041136>,
    <0.1388858, -167.0866485>,
    <0.1386269, -167.0779227>,
    <0.1380178, -167.1041136>,
    <0.1293010, -167.0803290>,
    <0.1379029, -167.1040945>,
    <0.1388889, -167.0684463>,
    <0.1111111, -167.0684463>,
    <0.1386269, -167.0779177>,
    <0.1250000, -167.0684463>,
    <0.1233876, -167.0847809>,
    <0.8730398, -167.0803290>,
    <0.8691193, -167.1040945>,
    <0.8888889, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.8800396, -167.0844032>,
    <0.8750000, -167.0684463>,
    <0.8639838, -167.0812340>,
    <0.8637815, -167.0922118>,
    <0.8611141, -167.1040945>,
    <0.8691194, -167.1040945>,
    <0.8611111, -167.0684463>,
    <0.8656908, -167.1040945>,
    <0.8639838, -167.0812340>,
    <0.8611126, -167.0865230>,
    <0.8607825, -167.0922118>,
    <0.8611111, -167.1040945>,
    <0.8611111, -167.0684463>,
    <0.8601254, -167.1040945>,
    <0.8611111, -167.0865230>,
    <0.8608049, -167.0795193>,
    <0.8602774, -167.1040945>,
    <0.1171659, -168.0684463>,
    <0.1292754, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1191097, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1150907, -168.0684463>,
    <0.8828341, -168.0684463>,
    <0.8707246, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8841105, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8806290, -168.0684463>,
    <0.1365768, -168.0684463>,
    <0.1319526, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1358927, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1357097, -168.0684463>,
    <0.1333723, -168.0684463>,
    <0.1319526, -168.0684463>,
    <0.1292754, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1302495, -168.0684463>,
    <0.1367652, -168.0684463>,
    <0.1358927, -168.0684463>,
    <0.1264251, -168.0684463>,
    <0.1292754, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1150907, -168.0684463>,
    <0.1256949, -168.0684463>,
    <0.1367652, -168.0684463>,
    <0.8654870, -168.0684463>,
    <0.8646254, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8707246, -168.0684463>,
    <0.8621237, -168.0684463>,
    <0.8630808, -168.0684463>,
    <0.8684407, -168.0684463>,
    <0.8735749, -168.0684463>,
    <0.8707246, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8630808, -168.0684463>,
    <0.8763923, -168.0684463>,
    <0.8841105, -168.0684463>,
    <0.8622826, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8646255, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8621237, -168.0684463>,
    <0.8630151, -168.0684463>,
    <0.8579067, -168.0684463>,
    <0.8514979, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8570543, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8563737, -168.0684463>,
    <0.1420934, -168.0684463>,
    <0.1485024, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1436265, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1424113, -168.0684463>,
    <0.8541925, -167.0922118>,
    <0.8413411, -167.1040945>,
    <0.8601252, -167.1040945>,
    <0.8611111, -167.0684463>,
    <0.8501904, -167.1040945>,
    <0.8608049, -167.0795193>,
    <0.8522584, -167.0844090>,
    <0.1481481, -168.0684463>,
    <0.1570531, -168.0684463>,
    <0.1485024, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1523097, -168.0684463>,
    <0.1424113, -168.0684463>,
    <0.1426803, -168.0684463>,
    <0.8518519, -168.0684463>,
    <0.8514979, -168.0684463>,
    <0.8429467, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8474476, -168.0684463>,
    <0.8566677, -168.0684463>,
    <0.8570543, -168.0684463>,
    <0.1478195, -167.0922118>,
    <0.1656807, -167.1040945>,
    <0.1388889, -167.0684463>,
    <0.1388889, -167.1040945>,
    <0.1511669, -167.0847830>,
    <0.1388889, -167.0866388>,
    <0.1504515, -167.1040945>,
    <0.1663372, -167.0922118>,
    <0.1666642, -167.1040945>,
    <0.1666667, -167.0684463>,
    <0.1656809, -167.1040945>,
    <0.1666654, -167.0866345>,
    <0.1664019, -167.0780201>,
    <0.1657964, -167.1040945>,
    <0.1570787, -167.0803290>,
    <0.1656807, -167.1040945>,
    <0.1666667, -167.0684463>,
    <0.1388889, -167.0684463>,
    <0.1664019, -167.0780201>,
    <0.1527778, -167.0684463>,
    <0.1511669, -167.0847830>,
    <0.8459503, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.8434063, -167.0684463>,
    <0.8472222, -167.0684463>,
    <0.8383698, -167.0684463>,
    <0.8522587, -167.0684463>,
    <0.8452619, -167.0803290>,
    <0.8413411, -167.1040945>,
    <0.8611111, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.8522584, -167.0844090>,
    <0.8472222, -167.0684463>,
    <0.8362165, -167.0812811>,
    <0.8360034, -167.0922118>,
    <0.8333358, -167.1040945>,
    <0.8413411, -167.1040945>,
    <0.8333333, -167.0684463>,
    <0.8379129, -167.1040945>,
    <0.8362165, -167.0812811>,
    <0.8333346, -167.0865221>,
    <0.8330047, -167.0922118>,
    <0.8333333, -167.1040945>,
    <0.8333333, -167.0684463>,
    <0.8323474, -167.1040945>,
    <0.8333333, -167.0865221>,
    <0.8330271, -167.0795191>,
    <0.8324995, -167.1040945>,
    <0.1517489, -167.0684463>,
    <0.1496911, -167.0684463>,
    <0.1666667, -167.0684463>,
    <0.1388889, -167.0684463>,
    <0.1581789, -167.0684463>,
    <0.1527778, -167.0684463>,
    <0.1442900, -167.0684463>,
    <0.1643545, -168.0684463>,
    <0.1597303, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1636954, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1634874, -168.0684463>,
    <0.1611500, -168.0684463>,
    <0.1597303, -168.0684463>,
    <0.1570531, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1583246, -168.0684463>,
    <0.1653905, -168.0684463>,
    <0.1636954, -168.0684463>,
    <0.1542029, -168.0684463>,
    <0.1570531, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1426803, -168.0684463>,
    <0.1536910, -168.0684463>,
    <0.1653905, -168.0684463>,
    <0.8377092, -168.0684463>,
    <0.8368476, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8429467, -168.0684463>,
    <0.8343049, -168.0684463>,
    <0.8344911, -168.0684463>,
    <0.8402111, -168.0684463>,
    <0.8457971, -168.0684463>,
    <0.8429467, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8344911, -168.0684463>,
    <0.8484925, -168.0684463>,
    <0.8566677, -168.0684463>,
    <0.8345048, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8368476, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8343049, -168.0684463>,
    <0.8352374, -168.0684463>,
    <0.1698711, -168.0684463>,
    <0.1762801, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1715549, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1701022, -168.0684463>,
    <0.8301289, -168.0684463>,
    <0.8237199, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8296956, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8280472, -168.0684463>,
    <0.8264142, -167.0922118>,
    <0.8135618, -167.1040945>,
    <0.8323476, -167.1040945>,
    <0.8333333, -167.0684463>,
    <0.8224118, -167.1040945>,
    <0.8330271, -167.0795191>,
    <0.8244797, -167.0844095>,
    <0.1767336, -168.0684463>,
    <0.1872539, -168.0684463>,
    <0.1762801, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1816062, -168.0684463>,
    <0.1701022, -168.0684463>,
    <0.1718865, -168.0684463>,
    <0.1755973, -167.0922118>,
    <0.1934585, -167.1040945>,
    <0.1666667, -167.0684463>,
    <0.1666667, -167.1040945>,
    <0.1789445, -167.0847827>,
    <0.1666667, -167.0866345>,
    <0.1782292, -167.1040945>,
    <0.1941146, -167.0922245>,
    <0.1944410, -167.1041136>,
    <0.1944444, -167.0684463>,
    <0.1934583, -167.1041136>,
    <0.1944427, -167.0866461>,
    <0.1941796, -167.0780248>,
    <0.1935737, -167.1041136>,
    <0.1848565, -167.0803290>,
    <0.1934585, -167.1040945>,
    <0.1944444, -167.0684463>,
    <0.1666667, -167.0684463>,
    <0.1941797, -167.0780197>,
    <0.1805555, -167.0684463>,
    <0.1789445, -167.0847827>,
    <0.8181725, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.8156287, -167.0684463>,
    <0.8194445, -167.0684463>,
    <0.8105921, -167.0684463>,
    <0.8244810, -167.0684463>,
    <0.8174836, -167.0803290>,
    <0.8135618, -167.1040945>,
    <0.8333333, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.8244797, -167.0844095>,
    <0.8194445, -167.0684463>,
    <0.8084381, -167.0812810>,
    <0.8082243, -167.0922118>,
    <0.8135618, -167.1040945>,
    <0.8055556, -167.0684463>,
    <0.8055556, -167.1040945>,
    <0.8084381, -167.0812810>,
    <0.8055556, -167.0865302>,
    <0.8101330, -167.1040945>,
    <0.8052249, -167.0922245>,
    <0.8055495, -167.1041136>,
    <0.8055556, -167.0684463>,
    <0.8045696, -167.1041136>,
    <0.8055525, -167.0865398>,
    <0.8052493, -167.0795248>,
    <0.8047205, -167.1041136>,
    <0.1795266, -167.0684463>,
    <0.1774688, -167.0684463>,
    <0.1944444, -167.0684463>,
    <0.1666667, -167.0684463>,
    <0.1859566, -167.0684463>,
    <0.1805555, -167.0684463>,
    <0.1720677, -167.0684463>,
    <0.8208696, -168.0684463>,
    <0.8237199, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8140711, -168.0684463>,
    <0.8236942, -168.0684463>,
    <0.8296956, -168.0684463>,
    <0.1920476, -168.0684463>,
    <0.1872539, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1936413, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1906297, -168.0684463>,
    <0.1827883, -168.0684463>,
    <0.1872539, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1718865, -168.0684463>,
    <0.1812444, -168.0684463>,
    <0.1936414, -168.0684463>,
    <0.8148148, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8213346, -168.0684463>,
    <0.8236942, -168.0684463>,
    <0.8023511, -168.0684463>,
    <0.7959423, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8009175, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8008181, -168.0684463>,
    <0.1976489, -168.0684463>,
    <0.2040578, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1991820, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1980227, -168.0684463>,
    <0.7986370, -167.0922118>,
    <0.7857857, -167.1040945>,
    <0.8045696, -167.1040945>,
    <0.8055556, -167.0684463>,
    <0.7946346, -167.1040945>,
    <0.8052493, -167.0795188>,
    <0.7967190, -167.0843800>,
    <0.7962964, -168.0684463>,
    <0.7959423, -168.0684463>,
    <0.7873912, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.7918921, -168.0684463>,
    <0.8008119, -168.0684463>,
    <0.8009175, -168.0684463>,
    <0.2037037, -168.0684463>,
    <0.2126088, -168.0684463>,
    <0.2040578, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.2078462, -168.0684463>,
    <0.1980227, -168.0684463>,
    <0.1982430, -168.0684463>,
    <0.2033751, -167.0922118>,
    <0.2212365, -167.1040945>,
    <0.1944444, -167.0684463>,
    <0.1944444, -167.1040945>,
    <0.2067182, -167.0847772>,
    <0.1944444, -167.0866364>,
    <0.2060071, -167.1040945>,
    <0.2218927, -167.0922118>,
    <0.2222196, -167.1040945>,
    <0.2222222, -167.0684463>,
    <0.2212365, -167.1040945>,
    <0.2222209, -167.0866273>,
    <0.2219641, -167.0777821>,
    <0.2213518, -167.1040945>,
    <0.2126344, -167.0803290>,
    <0.2212365, -167.1040945>,
    <0.2222222, -167.0684463>,
    <0.1944444, -167.0684463>,
    <0.2219641, -167.0777821>,
    <0.2083333, -167.0684463>,
    <0.2067182, -167.0847772>,
    <0.7903948, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.7777778, -167.0684463>,
    <0.7878511, -167.0684463>,
    <0.7916667, -167.0684463>,
    <0.7828144, -167.0684463>,
    <0.7967033, -167.0684463>,
    <0.7897064, -167.0803290>,
    <0.7857857, -167.1040945>,
    <0.8055556, -167.0684463>,
    <0.7777778, -167.0684463>,
    <0.7967190, -167.0843800>,
    <0.7916667, -167.0684463>,
    <0.7806353, -167.0811668>,
    <0.7804480, -167.0922118>,
    <0.7777805, -167.1040945>,
    <0.7857857, -167.1040945>,
    <0.7777778, -167.0684463>,
    <0.7823573, -167.1040945>,
    <0.7806353, -167.0811668>,
    <0.7777792, -167.0866215>,
    <0.2073043, -167.0684463>,
    <0.2052464, -167.0684463>,
    <0.2222222, -167.0684463>,
    <0.1944444, -167.0684463>,
    <0.2137343, -167.0684463>,
    <0.2083333, -167.0684463>,
    <0.1998454, -167.0684463>,
    <0.7774491, -167.0922118>,
    <0.7777778, -167.1040945>,
    <0.7777778, -167.0684463>,
    <0.7767918, -167.1040945>,
    <0.7777778, -167.0866215>,
    <0.7775001, -167.0784881>,
    <0.7769439, -167.1040945>,
    <0.2198254, -168.0684463>,
    <0.2150318, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2183263, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2164998, -168.0684463>,
    <0.2166209, -168.0684463>,
    <0.2150318, -168.0684463>,
    <0.2126088, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2137672, -168.0684463>,
    <0.2207631, -168.0684463>,
    <0.2183263, -168.0684463>,
    <0.2097585, -168.0684463>,
    <0.2126088, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.1982430, -168.0684463>,
    <0.2086976, -168.0684463>,
    <0.2207631, -168.0684463>,
    <0.7902415, -168.0684463>,
    <0.7873912, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.7789575, -168.0684463>,
    <0.7925480, -168.0684463>,
    <0.8008119, -168.0684463>,
    <0.7821537, -168.0684463>,
    <0.7812921, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7873913, -168.0684463>,
    <0.7787902, -168.0684463>,
    <0.7789575, -168.0684463>,
    <0.7846555, -168.0684463>,
    <0.7789492, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7812921, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7787902, -168.0684463>,
    <0.7796818, -168.0684463>,
    <0.7745733, -168.0684463>,
    <0.7681644, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7737207, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7730403, -168.0684463>,
    <0.7685186, -168.0684463>,
    <0.7681644, -168.0684463>,
    <0.7596135, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7638890, -168.0684463>,
    <0.7729886, -168.0684463>,
    <0.7737207, -168.0684463>,
    <0.7708589, -167.0922118>,
    <0.7580068, -167.1040945>,
    <0.7767920, -167.1040945>,
    <0.7777778, -167.0684463>,
    <0.7668566, -167.1040945>,
    <0.7775001, -167.0784881>,
    <0.7689381, -167.0843847>,
    <0.2311529, -167.0922118>,
    <0.2490141, -167.1040945>,
    <0.2222222, -167.0684463>,
    <0.2222222, -167.1040945>,
    <0.2345019, -167.0847851>,
    <0.2222222, -167.0866273>,
    <0.2337849, -167.1040945>,
    <0.2496714, -167.0922118>,
    <0.2500000, -167.1040945>,
    <0.2500000, -167.0684463>,
    <0.2490141, -167.1040945>,
    <0.2500000, -167.0866383>,
    <0.2497338, -167.0780728>,
    <0.2491300, -167.1040945>,
    <0.2404121, -167.0803290>,
    <0.2490141, -167.1040945>,
    <0.2500000, -167.0684463>,
    <0.2222222, -167.0684463>,
    <0.2497338, -167.0780728>,
    <0.2361111, -167.0684463>,
    <0.2345019, -167.0847851>,
    <0.2407407, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2365021, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2344945, -168.0684463>,
    <0.2314815, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2356116, -168.0684463>,
    <0.2365021, -168.0684463>,
    <0.7624638, -168.0684463>,
    <0.7596135, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7511491, -168.0684463>,
    <0.7648812, -168.0684463>,
    <0.7729886, -168.0684463>,
    <0.7532045, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7596134, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7511491, -168.0684463>,
    <0.7593409, -168.0684463>,
    <0.7619282, -167.0803290>,
    <0.7580068, -167.1040945>,
    <0.7777778, -167.0684463>,
    <0.7500000, -167.0684463>,
    <0.7689381, -167.0843847>,
    <0.7638889, -167.0684463>,
    <0.7528494, -167.0811326>,
    <0.7526689, -167.0922118>,
    <0.7580067, -167.1040945>,
    <0.7500000, -167.0684463>,
    <0.7500000, -167.1040945>,
    <0.7528494, -167.0811326>,
    <0.7500000, -167.0865760>,
    <0.7545778, -167.1040945>,
    <0.7496714, -167.0922118>,
    <0.7500000, -167.1040945>,
    <0.7500000, -167.0684463>,
    <0.7490142, -167.1040945>,
    <0.7500000, -167.0865760>,
    <0.7497076, -167.0790194>,
    <0.7491661, -167.1040945>,
    <0.2520920, -168.0684463>,
    <0.2562759, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2534447, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2538694, -168.0684463>,
    <0.2581468, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2562759, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2625865, -168.0684463>,
    <0.2538694, -168.0684463>,
    <0.2632832, -168.0684463>,
    <0.2621097, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2585155, -168.0684463>,
    <0.2590823, -168.0684463>,
    <0.7430811, -167.0922118>,
    <0.7302293, -167.1040945>,
    <0.7490141, -167.1040945>,
    <0.7500000, -167.0684463>,
    <0.7390789, -167.1040945>,
    <0.7497076, -167.0790194>,
    <0.7411501, -167.0844033>,
    <0.2713689, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2729711, -168.0684463>,
    <0.2724858, -168.0684463>,
    <0.2745733, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2724858, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2724917, -168.0684463>,
    <0.7314815, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7413667, -168.0684463>,
    <0.7386842, -168.0684463>,
    <0.7407408, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7386842, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7363135, -168.0684463>,
    <0.2589306, -167.0922118>,
    <0.2767918, -167.1040945>,
    <0.2500000, -167.0684463>,
    <0.2500000, -167.1040945>,
    <0.2622813, -167.0847874>,
    <0.2500000, -167.0866383>,
    <0.2615626, -167.1040945>,
    <0.2626171, -167.0684463>,
    <0.2777778, -167.0684463>,
    <0.2500000, -167.0684463>,
    <0.2600734, -167.0684463>,
    <0.2638889, -167.0684463>,
    <0.2550367, -167.0684463>,
    <0.2689256, -167.0684463>,
    <0.2681899, -167.0803290>,
    <0.2767918, -167.1040945>,
    <0.2777778, -167.0684463>,
    <0.2500000, -167.0684463>,
    <0.2775069, -167.0782410>,
    <0.2638889, -167.0684463>,
    <0.2622813, -167.0847874>,
    <0.2774483, -167.0922118>,
    <0.2777752, -167.1040945>,
    <0.2777778, -167.0684463>,
    <0.2767920, -167.1040945>,
    <0.2777764, -167.0866416>,
    <0.2775069, -167.0782410>,
    <0.2769075, -167.1040945>,
    <0.7248924, -167.0922118>,
    <0.7222248, -167.1040945>,
    <0.7302300, -167.1040945>,
    <0.7222222, -167.0684463>,
    <0.7268018, -167.1040945>,
    <0.7250946, -167.0812332>,
    <0.7222235, -167.0865214>,
    <0.7341505, -167.0803290>,
    <0.7302293, -167.1040945>,
    <0.7500000, -167.0684463>,
    <0.7222222, -167.0684463>,
    <0.7411501, -167.0844033>,
    <0.7361111, -167.0684463>,
    <0.7250943, -167.0812332>,
    <0.7218936, -167.0922118>,
    <0.7222222, -167.1040945>,
    <0.7222222, -167.0684463>,
    <0.7212363, -167.1040945>,
    <0.7222222, -167.0865214>,
    <0.7219160, -167.0795188>,
    <0.7213884, -167.1040945>,
    <0.7190178, -168.0684463>,
    <0.7126088, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7146786, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7128820, -168.0684463>,
    <0.2838326, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2862783, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2862933, -168.0684463>,
    <0.7129630, -168.0684463>,
    <0.7126088, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7083334, -168.0684463>,
    <0.7100367, -168.0684463>,
    <0.7146786, -168.0684463>,
    <0.7101126, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7093980, -168.0684463>,
    <0.7100367, -168.0684463>,
    <0.2898874, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2857565, -168.0684463>,
    <0.2862783, -168.0684463>,
    <0.7153036, -167.0922118>,
    <0.7024523, -167.1040945>,
    <0.7212362, -167.1040945>,
    <0.7222222, -167.0684463>,
    <0.7113016, -167.1040945>,
    <0.7219160, -167.0795188>,
    <0.7133727, -167.0844033>,
    <0.2999543, -168.0684463>,
    <0.2983652, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.2968211, -168.0684463>,
    <0.3003615, -168.0684463>,
    <0.3018350, -168.0684463>,
    <0.2991467, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.3002695, -168.0684463>,
    <0.3003615, -168.0684463>,
    <0.7008534, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.6991957, -168.0684463>,
    <0.6997307, -168.0684463>,
    <0.6976489, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6991956, -168.0684463>,
    <0.6991820, -168.0684463>,
    <0.3031588, -168.0684463>,
    <0.2983652, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3018350, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.3022858, -168.0684463>,
    <0.2903948, -167.0684463>,
    <0.3055556, -167.0684463>,
    <0.2777778, -167.0684463>,
    <0.2878510, -167.0684463>,
    <0.2916667, -167.0684463>,
    <0.2828144, -167.0684463>,
    <0.2967033, -167.0684463>,
    <0.2867056, -167.0922118>,
    <0.3045614, -167.1040945>,
    <0.2777778, -167.0684463>,
    <0.2777778, -167.1040945>,
    <0.2900524, -167.0847835>,
    <0.2777778, -167.0866416>,
    <0.2893370, -167.1040945>,
    <0.2959676, -167.0803354>,
    <0.3045696, -167.1041136>,
    <0.3055555, -167.0684463>,
    <0.2777778, -167.0684463>,
    <0.3052889, -167.0780924>,
    <0.2916667, -167.0684463>,
    <0.2900561, -167.0847922>,
    <0.3052258, -167.0922245>,
    <0.3055524, -167.1041136>,
    <0.3055555, -167.0684463>,
    <0.3045695, -167.1041136>,
    <0.3055539, -167.0866464>,
    <0.3052889, -167.0780924>,
    <0.3046851, -167.1041136>,
    <0.6971132, -167.0922118>,
    <0.7024507, -167.1040945>,
    <0.6944445, -167.0684463>,
    <0.6944445, -167.1040945>,
    <0.6973217, -167.0812575>,
    <0.6944445, -167.0865447>,
    <0.6990220, -167.1040945>,
    <0.7063730, -167.0803290>,
    <0.7024523, -167.1040945>,
    <0.7222222, -167.0684463>,
    <0.6944445, -167.0684463>,
    <0.7133727, -167.0844033>,
    <0.7083333, -167.0684463>,
    <0.6973223, -167.0812575>,
    <0.6941158, -167.0922245>,
    <0.6944445, -167.1041136>,
    <0.6944445, -167.0684463>,
    <0.6934584, -167.1041136>,
    <0.6944445, -167.0865543>,
    <0.6941436, -167.0793296>,
    <0.6936104, -167.1041136>,
    <0.3076475, -168.0684463>,
    <0.3118314, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3090003, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3082560, -168.0684463>,
    <0.3137023, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3118314, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3181420, -168.0684463>,
    <0.3082560, -168.0684463>,
    <0.3146377, -168.0684463>,
    <0.3176651, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3135342, -168.0684463>,
    <0.3146377, -168.0684463>,
    <0.6823349, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6859291, -168.0684463>,
    <0.6859031, -168.0684463>,
    <0.6883897, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6859031, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6859292, -168.0684463>,
    <0.6875283, -167.0922118>,
    <0.6746817, -167.1040945>,
    <0.6934587, -167.1040945>,
    <0.6944445, -167.0684463>,
    <0.6835273, -167.1040945>,
    <0.6941437, -167.0793237>,
    <0.6855996, -167.0844007>,
    <0.3277320, -168.0684463>,
    <0.3261429, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3245988, -168.0684463>,
    <0.3281392, -168.0684463>,
    <0.3296127, -168.0684463>,
    <0.3269244, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3285266, -168.0684463>,
    <0.3281392, -168.0684463>,
    <0.6730756, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6720692, -168.0684463>,
    <0.6719530, -168.0684463>,
    <0.3309365, -168.0684463>,
    <0.3261429, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3296127, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3300636, -168.0684463>,
    <0.6698711, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6762800, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6720692, -168.0684463>,
    <0.6719530, -168.0684463>,
    <0.3181725, -167.0684463>,
    <0.3333333, -167.0684463>,
    <0.3055555, -167.0684463>,
    <0.3156287, -167.0684463>,
    <0.3194444, -167.0684463>,
    <0.3105921, -167.0684463>,
    <0.3244810, -167.0684463>,
    <0.3354253, -168.0684463>,
    <0.3396092, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3367780, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3360338, -168.0684463>,
    <0.3144862, -167.0922118>,
    <0.3323474, -167.1040945>,
    <0.3055555, -167.0684463>,
    <0.3055555, -167.1040945>,
    <0.3178333, -167.0847827>,
    <0.3055555, -167.0866366>,
    <0.3171181, -167.1040945>,
    <0.3237454, -167.0803290>,
    <0.3323474, -167.1040945>,
    <0.3333333, -167.0684463>,
    <0.3055555, -167.0684463>,
    <0.3330686, -167.0780197>,
    <0.3194444, -167.0684463>,
    <0.3178333, -167.0847827>,
    <0.3330040, -167.0922118>,
    <0.3333309, -167.1040945>,
    <0.3333333, -167.0684463>,
    <0.3323476, -167.1040945>,
    <0.3333321, -167.0866386>,
    <0.3330686, -167.0780197>,
    <0.3324630, -167.1040945>,
    <0.6693367, -167.0922118>,
    <0.6666691, -167.1040945>,
    <0.6746744, -167.1040945>,
    <0.6666667, -167.0684463>,
    <0.6712457, -167.1040945>,
    <0.6694534, -167.0808520>,
    <0.6666679, -167.0862277>,
    <0.6785945, -167.0803290>,
    <0.6746724, -167.1040945>,
    <0.6944445, -167.0684463>,
    <0.6666667, -167.0684463>,
    <0.6855954, -167.0844007>,
    <0.6805556, -167.0684463>,
    <0.6694527, -167.0808520>,
    <0.6663380, -167.0922118>,
    <0.6666667, -167.1040945>,
    <0.6666667, -167.0684463>,
    <0.6656807, -167.1040945>,
    <0.6666667, -167.0862277>,
    <0.6664047, -167.0779186>,
    <0.6657966, -167.1040945>,
    <0.6634622, -168.0684463>,
    <0.6570532, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6620246, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6619291, -168.0684463>,
    <0.3414801, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3396092, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3459198, -168.0684463>,
    <0.3360338, -168.0684463>,
    <0.3424155, -168.0684463>,
    <0.6574074, -168.0684463>,
    <0.6570532, -168.0684463>,
    <0.6485023, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6530031, -168.0684463>,
    <0.6587026, -168.0684463>,
    <0.6620246, -168.0684463>,
    <0.6545571, -168.0684463>,
    <0.6485023, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6581513, -168.0684463>,
    <0.6587026, -168.0684463>,
    <0.3454430, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3418488, -168.0684463>,
    <0.3424155, -168.0684463>,
    <0.3547022, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3563044, -168.0684463>,
    <0.3558191, -168.0684463>,
    <0.6432648, -168.0684463>,
    <0.6424032, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6404416, -168.0684463>,
    <0.6435509, -168.0684463>,
    <0.6457666, -168.0684463>,
    <0.6452978, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6485023, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6435509, -168.0684463>,
    <0.6441752, -168.0684463>,
    <0.3579067, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3558191, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3558251, -168.0684463>,
    <0.6400603, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6424032, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6404416, -168.0684463>,
    <0.6407929, -168.0684463>,
    <0.3459503, -167.0684463>,
    <0.3611111, -167.0684463>,
    <0.3333333, -167.0684463>,
    <0.3434063, -167.0684463>,
    <0.3472222, -167.0684463>,
    <0.3383698, -167.0684463>,
    <0.3522587, -167.0684463>,
    <0.3422640, -167.0922118>,
    <0.3601254, -167.1040945>,
    <0.3333333, -167.0684463>,
    <0.3333333, -167.1040945>,
    <0.3456143, -167.0847868>,
    <0.3333333, -167.0866386>,
    <0.3448962, -167.1040945>,
    <0.3515233, -167.0803290>,
    <0.3601254, -167.1040945>,
    <0.3611111, -167.0684463>,
    <0.3333333, -167.0684463>,
    <0.3608421, -167.0781749>,
    <0.3472222, -167.0684463>,
    <0.3456143, -167.0847868>,
    <0.3607825, -167.0922118>,
    <0.3611111, -167.1040945>,
    <0.3611111, -167.0684463>,
    <0.3601254, -167.1040945>,
    <0.3611111, -167.0866373>,
    <0.3608421, -167.0781749>,
    <0.3602413, -167.1040945>,
    <0.6478195, -167.0922118>,
    <0.6656807, -167.1040945>,
    <0.6388889, -167.0684463>,
    <0.6388889, -167.1040945>,
    <0.6515536, -167.0852975>,
    <0.6388889, -167.0866858>,
    <0.6504516, -167.1040945>,
    <0.6570788, -167.0803290>,
    <0.6656807, -167.1040945>,
    <0.6666667, -167.0684463>,
    <0.6388889, -167.0684463>,
    <0.6664047, -167.0779186>,
    <0.6527778, -167.0684463>,
    <0.6515536, -167.0852975>,
    <0.6385591, -167.0922245>,
    <0.6388857, -167.1041136>,
    <0.6388889, -167.0684463>,
    <0.6379027, -167.1041136>,
    <0.6388873, -167.0866956>,
    <0.6385964, -167.0790257>,
    <0.6380541, -167.1041136>,
    <0.3671659, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3696116, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3696265, -168.0684463>,
    <0.3732206, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3690898, -168.0684463>,
    <0.3696116, -168.0684463>,
    <0.6267793, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6303736, -168.0684463>,
    <0.6301017, -168.0684463>,
    <0.6328341, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6301017, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6303736, -168.0684463>,
    <0.3832876, -168.0684463>,
    <0.3816984, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3801543, -168.0684463>,
    <0.3836948, -168.0684463>,
    <0.3851683, -168.0684463>,
    <0.3824799, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3836027, -168.0684463>,
    <0.3836947, -168.0684463>,
    <0.6175200, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6165137, -168.0684463>,
    <0.6163974, -168.0684463>,
    <0.3864920, -168.0684463>,
    <0.3816984, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3851683, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3856191, -168.0684463>,
    <0.6143156, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6207246, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6165137, -168.0684463>,
    <0.6163975, -168.0684463>,
    <0.3909808, -168.0684463>,
    <0.3951648, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3923336, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3915894, -168.0684463>,
    <0.6319730, -167.0922118>,
    <0.6191270, -167.1040945>,
    <0.6379030, -167.1040945>,
    <0.6388889, -167.0684463>,
    <0.6279721, -167.1040945>,
    <0.6385965, -167.0790201>,
    <0.6300507, -167.0843893>,
    <0.6079067, -168.0684463>,
    <0.6014977, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6064691, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6063736, -168.0684463>,
    <0.3700392, -167.0922118>,
    <0.3878952, -167.1040945>,
    <0.3611111, -167.0684463>,
    <0.3611111, -167.1040945>,
    <0.3733815, -167.0847775>,
    <0.3611111, -167.0866373>,
    <0.3726708, -167.1040945>,
    <0.3970356, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.3951648, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.4014752, -168.0684463>,
    <0.3915894, -168.0684463>,
    <0.3979710, -168.0684463>,
    <0.3793009, -167.0803354>,
    <0.3879027, -167.1041136>,
    <0.3888889, -167.0684463>,
    <0.3611111, -167.0684463>,
    <0.3886287, -167.0778552>,
    <0.3750000, -167.0684463>,
    <0.3733849, -167.0847863>,
    <0.3885601, -167.0922245>,
    <0.3888889, -167.1041136>,
    <0.3888889, -167.0684463>,
    <0.3879027, -167.1041136>,
    <0.3888889, -167.0866347>,
    <0.3886287, -167.0778552>,
    <0.3880189, -167.1041136>,
    <0.6137815, -167.0922118>,
    <0.6111141, -167.1040945>,
    <0.6191193, -167.1040945>,
    <0.6111111, -167.0684463>,
    <0.6156906, -167.1040945>,
    <0.6139714, -167.0811790>,
    <0.6111126, -167.0865728>,
    <0.6230397, -167.0803290>,
    <0.6191190, -167.1040945>,
    <0.6388889, -167.0684463>,
    <0.6111111, -167.0684463>,
    <0.6300472, -167.0843893>,
    <0.6250000, -167.0684463>,
    <0.6139714, -167.0811790>,
    <0.6107825, -167.0922118>,
    <0.6111111, -167.1040945>,
    <0.6111111, -167.0684463>,
    <0.6101254, -167.1040945>,
    <0.6111111, -167.0865728>,
    <0.6108188, -167.0790191>,
    <0.6102774, -167.1040945>,
    <0.4009983, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.3968675, -168.0684463>,
    <0.3979710, -168.0684463>,
    <0.6018519, -168.0684463>,
    <0.6014977, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.5974476, -168.0684463>,
    <0.6031471, -168.0684463>,
    <0.6064691, -168.0684463>,
    <0.5990016, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.6025958, -168.0684463>,
    <0.6031471, -168.0684463>,
    <0.4110653, -168.0684463>,
    <0.4094761, -168.0684463>,
    <0.4070530, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4079319, -168.0684463>,
    <0.4082381, -168.0684463>,
    <0.4119248, -168.0684463>,
    <0.4102576, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4073187, -168.0684463>,
    <0.4082382, -168.0684463>,
    <0.5877092, -168.0684463>,
    <0.5868476, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5929467, -168.0684463>,
    <0.5849092, -168.0684463>,
    <0.5880618, -168.0684463>,
    <0.5902110, -168.0684463>,
    <0.5897423, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5880618, -168.0684463>,
    <0.5886197, -168.0684463>,
    <0.4142698, -168.0684463>,
    <0.4094761, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4119248, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4133968, -168.0684463>,
    <0.5845048, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5868477, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5849093, -168.0684463>,
    <0.5852374, -168.0684463>,
    <0.4190447, -168.0684463>,
    <0.4238008, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4209055, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4185305, -168.0684463>,
    <0.5801290, -168.0684463>,
    <0.5737202, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5786220, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5785959, -168.0684463>,
    <0.6041920, -167.0922118>,
    <0.5913395, -167.1040945>,
    <0.6101254, -167.1040945>,
    <0.6111111, -167.0684463>,
    <0.6001897, -167.1040945>,
    <0.6108188, -167.0790191>,
    <0.6022607, -167.0844035>,
    <0.5712237, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5748180, -168.0684463>,
    <0.5749956, -168.0684463>,
    <0.5740741, -168.0684463>,
    <0.5737202, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5694447, -168.0684463>,
    <0.5749956, -168.0684463>,
    <0.5786220, -168.0684463>,
    <0.4283040, -168.0684463>,
    <0.4238008, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4185305, -168.0684463>,
    <0.4314832, -168.0684463>,
    <0.4350353, -168.0684463>,
    <0.5619645, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5604311, -168.0684463>,
    <0.5608419, -168.0684463>,
    <0.3978195, -167.0922118>,
    <0.4156807, -167.1040945>,
    <0.3888889, -167.0684463>,
    <0.3888889, -167.1040945>,
    <0.4011657, -167.0847813>,
    <0.3888889, -167.0866249>,
    <0.4004515, -167.1040945>,
    <0.4070788, -167.0803290>,
    <0.4156807, -167.1040945>,
    <0.4166667, -167.0684463>,
    <0.3888889, -167.0684463>,
    <0.4164047, -167.0779181>,
    <0.4027778, -167.0684463>,
    <0.4011657, -167.0847813>,
    <0.4163373, -167.0922118>,
    <0.4166642, -167.1040945>,
    <0.4166667, -167.0684463>,
    <0.4156809, -167.1040945>,
    <0.4166654, -167.0866345>,
    <0.4164047, -167.0779181>,
    <0.4157964, -167.1040945>,
    <0.5860034, -167.0922118>,
    <0.5833358, -167.1040945>,
    <0.5913411, -167.1040945>,
    <0.5833333, -167.0684463>,
    <0.5879130, -167.1040945>,
    <0.5862057, -167.0812330>,
    <0.5833346, -167.0865221>,
    <0.5952613, -167.0803290>,
    <0.5913395, -167.1040945>,
    <0.6111111, -167.0684463>,
    <0.5833333, -167.0684463>,
    <0.6022607, -167.0844035>,
    <0.5972222, -167.0684463>,
    <0.5862051, -167.0812330>,
    <0.5830047, -167.0922118>,
    <0.5833333, -167.1040945>,
    <0.5833333, -167.0684463>,
    <0.5823474, -167.1040945>,
    <0.5833333, -167.0865221>,
    <0.5830271, -167.0795191>,
    <0.5824995, -167.1040945>,
    <0.4351852, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4305555, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4303082, -168.0684463>,
    <0.5587600, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5604311, -168.0684463>,
    <0.5602932, -168.0684463>,
    <0.4465364, -168.0684463>,
    <0.4507202, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4478891, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4469260, -168.0684463>,
    <0.5523511, -168.0684463>,
    <0.5459422, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5509135, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5508181, -168.0684463>,
    <0.4525912, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4507202, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4570308, -168.0684463>,
    <0.4469260, -168.0684463>,
    <0.4535266, -168.0684463>,
    <0.5462964, -168.0684463>,
    <0.5459422, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5416668, -168.0684463>,
    <0.5473463, -168.0684463>,
    <0.5509135, -168.0684463>,
    <0.5434460, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5470402, -168.0684463>,
    <0.5473463, -168.0684463>,
    <0.4565540, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4529599, -168.0684463>,
    <0.4535266, -168.0684463>,
    <0.4658133, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4628743, -168.0684463>,
    <0.4637241, -168.0684463>,
    <0.5341868, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5325291, -168.0684463>,
    <0.5330641, -168.0684463>,
    <0.4690177, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4637241, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4628273, -168.0684463>,
    <0.5309823, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5373912, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5325291, -168.0684463>,
    <0.5325153, -168.0684463>,
    <0.4814815, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4918090, -168.0684463>,
    <0.4886452, -168.0684463>,
    <0.5245734, -168.0684463>,
    <0.5181645, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5237624, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5224917, -168.0684463>,
    <0.5764147, -167.0922118>,
    <0.5635633, -167.1040945>,
    <0.5823474, -167.1040945>,
    <0.5833333, -167.0684463>,
    <0.5724125, -167.1040945>,
    <0.5830271, -167.0795191>,
    <0.5744804, -167.0844094>,
    <0.5116373, -168.0684463>,
    <0.5071342, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5018128, -168.0684463>,
    <0.5109544, -168.0684463>,
    <0.5183686, -168.0684463>,
    <0.4295266, -167.0684463>,
    <0.4274688, -167.0684463>,
    <0.4444444, -167.0684463>,
    <0.4166667, -167.0684463>,
    <0.4359566, -167.0684463>,
    <0.4305555, -167.0684463>,
    <0.4220677, -167.0684463>,
    <0.4907407, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4886452, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4843793, -168.0684463>,
    <0.5023781, -168.0684463>,
    <0.5071342, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5042389, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5018128, -168.0684463>,
    <0.5153141, -168.0684463>,
    <0.5181645, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5085155, -168.0684463>,
    <0.5138889, -168.0684463>,
    <0.5237624, -168.0684463>,
    <0.4255943, -167.0922118>,
    <0.4434495, -167.1040945>,
    <0.4166667, -167.0684463>,
    <0.4166667, -167.1040945>,
    <0.4289402, -167.0847825>,
    <0.4166667, -167.0866345>,
    <0.4282256, -167.1040945>,
    <0.4348565, -167.0803354>,
    <0.4434584, -167.1041136>,
    <0.4444444, -167.0684463>,
    <0.4166667, -167.0684463>,
    <0.4441797, -167.0780245>,
    <0.4305555, -167.0684463>,
    <0.4289443, -167.0847912>,
    <0.4441146, -167.0922245>,
    <0.4444410, -167.1041136>,
    <0.4444444, -167.0684463>,
    <0.4434583, -167.1041136>,
    <0.4444427, -167.0866463>,
    <0.4441796, -167.0780245>,
    <0.4435740, -167.1041136>,
    <0.5582243, -167.0922118>,
    <0.5635618, -167.1040945>,
    <0.5555556, -167.0684463>,
    <0.5555556, -167.1040945>,
    <0.5584381, -167.0812811>,
    <0.5555556, -167.0865301>,
    <0.5601330, -167.1040945>,
    <0.5681725, -167.0684463>,
    <0.5833333, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5656287, -167.0684463>,
    <0.5694444, -167.0684463>,
    <0.5605921, -167.0684463>,
    <0.5744810, -167.0684463>,
    <0.5674841, -167.0803290>,
    <0.5635633, -167.1040945>,
    <0.5833333, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5744804, -167.0844094>,
    <0.5694445, -167.0684463>,
    <0.5584387, -167.0812811>,
    <0.5552249, -167.0922245>,
    <0.5555495, -167.1041136>,
    <0.5555556, -167.0684463>,
    <0.5545696, -167.1041136>,
    <0.5555525, -167.0865398>,
    <0.5552493, -167.0795251>,
    <0.5547205, -167.1041136>,
    <0.4573035, -167.0684463>,
    <0.4552461, -167.0684463>,
    <0.4722200, -167.0684463>,
    <0.4444444, -167.0684463>,
    <0.4637330, -167.0684463>,
    <0.4583322, -167.0684463>,
    <0.4498452, -167.0684463>,
    <0.5486392, -167.0922118>,
    <0.5357922, -167.1040945>,
    <0.5545698, -167.1040945>,
    <0.5555556, -167.0684463>,
    <0.5446381, -167.1040945>,
    <0.5552494, -167.0795192>,
    <0.5467141, -167.0843941>,
    <0.4533750, -167.0922118>,
    <0.4712363, -167.1040945>,
    <0.4444444, -167.0684463>,
    <0.4444444, -167.1040945>,
    <0.4567224, -167.0847829>,
    <0.4444444, -167.0866365>,
    <0.4560070, -167.1040945>,
    <0.4626343, -167.0803290>,
    <0.4712363, -167.1040945>,
    <0.4722222, -167.0684463>,
    <0.4444444, -167.0684463>,
    <0.4719574, -167.0780199>,
    <0.4583333, -167.0684463>,
    <0.4567224, -167.0847829>,
    <0.4718928, -167.0922118>,
    <0.4722196, -167.1040945>,
    <0.4722222, -167.0684463>,
    <0.4712365, -167.1040945>,
    <0.4722209, -167.0866350>,
    <0.4719575, -167.0780199>,
    <0.4713519, -167.1040945>,
    <0.5304480, -167.0922118>,
    <0.5277805, -167.1040945>,
    <0.5357857, -167.1040945>,
    <0.5277778, -167.0684463>,
    <0.5323571, -167.1040945>,
    <0.5305610, -167.0808361>,
    <0.5277791, -167.0862680>,
    <0.5403948, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5277778, -167.0684463>,
    <0.5378510, -167.0684463>,
    <0.5416667, -167.0684463>,
    <0.5328144, -167.0684463>,
    <0.5467033, -167.0684463>,
    <0.5397057, -167.0803290>,
    <0.5357836, -167.1040945>,
    <0.5555556, -167.0684463>,
    <0.5277778, -167.0684463>,
    <0.5467103, -167.0843941>,
    <0.5416667, -167.0684463>,
    <0.5305603, -167.0808361>,
    <0.5274491, -167.0922118>,
    <0.5277778, -167.1040945>,
    <0.5277778, -167.0684463>,
    <0.5267918, -167.1040945>,
    <0.5277778, -167.0862680>,
    <0.5275177, -167.0778504>,
    <0.5269078, -167.1040945>,
    <0.4811529, -167.0922118>,
    <0.4990142, -167.1040945>,
    <0.4722222, -167.0684463>,
    <0.4722222, -167.1040945>,
    <0.4845031, -167.0847867>,
    <0.4722222, -167.0866350>,
    <0.4837849, -167.1040945>,
    <0.4904121, -167.0803290>,
    <0.4990142, -167.1040945>,
    <0.5000000, -167.0684463>,
    <0.4722222, -167.0684463>,
    <0.4997310, -167.0781741>,
    <0.4861111, -167.0684463>,
    <0.4845031, -167.0847867>,
    <0.4996714, -167.0922118>,
    <0.5000000, -167.1040945>,
    <0.5000000, -167.0684463>,
    <0.4990142, -167.1040945>,
    <0.5000000, -167.0866383>,
    <0.4997310, -167.0781741>,
    <0.4991300, -167.1040945>,
    <0.5089306, -167.0922118>,
    <0.5267918, -167.1040945>,
    <0.5000000, -167.0684463>,
    <0.5000000, -167.1040945>,
    <0.5122743, -167.0847781>,
    <0.5000000, -167.0866383>,
    <0.5115628, -167.1040945>,
    <0.5126171, -167.0684463>,
    <0.5277778, -167.0684463>,
    <0.5000000, -167.0684463>,
    <0.5100734, -167.0684463>,
    <0.5138889, -167.0684463>,
    <0.5050367, -167.0684463>,
    <0.5189256, -167.0684463>,
    <0.5181899, -167.0803290>,
    <0.5267918, -167.1040945>,
    <0.5277778, -167.0684463>,
    <0.5000000, -167.0684463>,
    <0.5275177, -167.0778504>,
    <0.5138889, -167.0684463>,
    <0.5122743, -167.0847781>,
    <0.0041600, -167.1123151>,
    <0.0124799, -167.1040945>,
    <0.0000000, -167.1040945>,
    <0.0000000, -167.1287564>,
    <0.0061825, -167.1040945>,
    <0.0000000, -167.1196784>,
    <0.0029324, -167.1229615>,
    <0.3282341, -167.1123151>,
    <0.9847022, -167.1040945>,
    <0.0000000, -167.1287564>,
    <0.0000000, -167.1040945>,
    <0.2234069, -167.1231612>,
    <0.0000000, -167.1196784>,
    <0.4683918, -167.1040945>,
    <0.0265412, -167.1123151>,
    <0.0240680, -167.1040945>,
    <0.0277778, -167.1287564>,
    <0.0277778, -167.1040945>,
    <0.0267756, -167.1220942>,
    <0.0277778, -167.1157255>,
    <0.0255357, -167.1040945>,
    <0.0214419, -167.1123151>,
    <0.0240680, -167.1040945>,
    <0.0124798, -167.1040945>,
    <0.0277778, -167.1287564>,
    <0.0176810, -167.1040945>,
    <0.0240782, -167.1227923>,
    <0.0267756, -167.1220942>,
    <0.0134192, -167.1205358>,
    <0.0124799, -167.1040945>,
    <0.0000000, -167.1287564>,
    <0.0277778, -167.1287564>,
    <0.0029324, -167.1229615>,
    <0.0130678, -167.1287564>,
    <0.0240782, -167.1227923>,
    <0.6523081, -167.1205421>,
    <0.9847021, -167.1041136>,
    <0.9722222, -167.1287564>,
    <0.0000000, -167.1287564>,
    <0.9753930, -167.1224953>,
    <0.5115619, -167.1287564>,
    <0.2234069, -167.1231655>,
    <0.9773344, -167.1123279>,
    <0.9847021, -167.1041136>,
    <0.9750789, -167.1041136>,
    <0.9722222, -167.1287564>,
    <0.9806788, -167.1041136>,
    <0.9732398, -167.1199785>,
    <0.9753930, -167.1224953>,
    <0.9731744, -167.1123215>,
    <0.9750789, -167.1041136>,
    <0.9722222, -167.1040945>,
    <0.9722222, -167.1287564>,
    <0.9739755, -167.1041062>,
    <0.9722222, -167.1186953>,
    <0.9732398, -167.1199785>,
    <0.3240741, -167.1533103>,
    <0.9722222, -167.1287564>,
    <0.0000000, -167.2024179>,
    <0.0000000, -167.1287564>,
    <0.4744807, -167.1664684>,
    <0.0000000, -167.1605800>,
    <0.5115619, -167.1287564>,
    <0.3278814, -167.0842391>,
    <0.9836443, -167.0684463>,
    <0.0000000, -167.0684463>,
    <0.0000000, -167.1158246>,
    <0.4724026, -167.0684463>,
    <0.0000000, -167.0943971>,
    <0.3974936, -167.0966789>,
    <0.6519545, -167.0842391>,
    <0.9722222, -167.0684463>,
    <0.9836412, -167.0684463>,
    <0.0000000, -167.1158246>,
    <0.9782212, -167.0684463>,
    <0.3974923, -167.0966789>,
    <0.3016562, -167.1011243>,
    <0.0319377, -167.1123151>,
    <0.0402577, -167.1040945>,
    <0.0277778, -167.1040945>,
    <0.0277778, -167.1287564>,
    <0.0339602, -167.1040945>,
    <0.0277778, -167.1157255>,
    <0.0306365, -167.1231073>,
    <0.0185185, -167.1533103>,
    <0.0000000, -167.1287564>,
    <0.0277778, -167.2024179>,
    <0.0277778, -167.1287564>,
    <0.0142983, -167.1666728>,
    <0.0277778, -167.1607154>,
    <0.0130678, -167.1287564>,
    <0.0092593, -167.1778641>,
    <0.0000000, -167.1287564>,
    <0.0000000, -167.2024179>,
    <0.0277778, -167.2024179>,
    <0.0000000, -167.1605800>,
    <0.0139007, -167.2024179>,
    <0.0142983, -167.1666728>,
    <0.3240741, -167.2357456>,
    <0.9722222, -167.2024179>,
    <0.0000000, -167.3024008>,
    <0.0000000, -167.2024179>,
    <0.4876776, -167.2522483>,
    <0.0000000, -167.2507837>,
    <0.4856978, -167.2024179>,
    <0.6481481, -167.1778641>,
    <0.9722222, -167.1287564>,
    <0.9722222, -167.2024179>,
    <0.0000000, -167.2024179>,
    <0.9722222, -167.1601023>,
    <0.4856978, -167.2024179>,
    <0.4744807, -167.1664684>,
    <0.9671230, -167.1123151>,
    <0.9569245, -167.1040945>,
    <0.9722222, -167.1287564>,
    <0.9722222, -167.1040945>,
    <0.9687225, -167.1231144>,
    <0.9722222, -167.1186953>,
    <0.9649456, -167.1040945>,
    <0.0223248, -167.0842391>,
    <0.0114190, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.0277778, -167.1158246>,
    <0.0195984, -167.0684463>,
    <0.0277778, -167.0957145>,
    <0.0206241, -167.0951061>,
    <0.0130656, -167.0842391>,
    <0.0000000, -167.0684463>,
    <0.0114190, -167.0684463>,
    <0.0277778, -167.1158246>,
    <0.0057095, -167.0684463>,
    <0.0206241, -167.0951061>,
    <0.0192474, -167.1012751>,
    <0.0092593, -167.1000319>,
    <0.0000000, -167.0684463>,
    <0.0277778, -167.1158246>,
    <0.0000000, -167.1158246>,
    <0.0192474, -167.1012751>,
    <0.0133120, -167.1158246>,
    <0.0000000, -167.0943971>,
    <0.6481482, -167.1000319>,
    <0.9722222, -167.0684463>,
    <0.0000000, -167.1158246>,
    <0.9722222, -167.1158246>,
    <0.3016562, -167.1011243>,
    <0.5059138, -167.1158246>,
    <0.9722222, -167.0946389>,
    <0.3240741, -167.1524837>,
    <0.9722222, -167.1158246>,
    <0.0000000, -167.1158246>,
    <0.0000000, -167.2258020>,
    <0.5059138, -167.1158246>,
    <0.0000000, -167.1673835>,
    <0.4976701, -167.1695057>,
    <0.0185185, -167.2357456>,
    <0.0000000, -167.2024179>,
    <0.0277778, -167.3024008>,
    <0.0277778, -167.2024179>,
    <0.0138441, -167.2522483>,
    <0.0277778, -167.2507837>,
    <0.0139007, -167.2024179>,
    <0.0092593, -167.2690732>,
    <0.0000000, -167.2024179>,
    <0.0000000, -167.3024008>,
    <0.0277778, -167.3024008>,
    <0.0000000, -167.2507837>,
    <0.0138995, -167.3024008>,
    <0.0138441, -167.2522483>,
    <0.3240741, -167.3434849>,
    <0.9722222, -167.3024008>,
    <0.0000000, -167.4256532>,
    <0.0000000, -167.3024008>,
    <0.4874476, -167.3638575>,
    <0.0000000, -167.3627833>,
    <0.4857402, -167.3024008>,
    <0.6481481, -167.2690732>,
    <0.9722222, -167.2024179>,
    <0.9722222, -167.3024008>,
    <0.0000000, -167.3024008>,
    <0.9722222, -167.2507837>,
    <0.4857402, -167.3024008>,
    <0.4876776, -167.2522483>,
    <0.0185185, -167.1524837>,
    <0.0000000, -167.1158246>,
    <0.0277778, -167.1158246>,
    <0.0277778, -167.2258020>,
    <0.0133120, -167.1158246>,
    <0.0277778, -167.1666572>,
    <0.0135586, -167.1695056>,
    <0.0092593, -167.1891429>,
    <0.0000000, -167.1158246>,
    <0.0277778, -167.2258020>,
    <0.0000000, -167.2258020>,
    <0.0135586, -167.1695056>,
    <0.0139006, -167.2258020>,
    <0.0000000, -167.1673835>,
    <0.3240741, -167.2709932>,
    <0.9722222, -167.2258020>,
    <0.0000000, -167.2258020>,
    <0.0000000, -167.3613758>,
    <0.4857005, -167.2258020>,
    <0.0000000, -167.2924560>,
    <0.4875682, -167.2933857>,
    <0.6481481, -167.1891429>,
    <0.9722222, -167.1158246>,
    <0.0000000, -167.2258020>,
    <0.9722222, -167.2258020>,
    <0.4976701, -167.1695057>,
    <0.4857005, -167.2258020>,
    <0.9722222, -167.1674336>,
    <0.9667693, -167.0842391>,
    <0.9558634, -167.0684463>,
    <0.9722222, -167.0684463>,
    <0.9722222, -167.1158246>,
    <0.9643632, -167.0684463>,
    <0.9722222, -167.0946389>,
    <0.9656116, -167.0966788>,
    <0.0185185, -167.3434849>,
    <0.0000000, -167.3024008>,
    <0.0277778, -167.4256532>,
    <0.0277778, -167.3024008>,
    <0.0138507, -167.3638575>,
    <0.0277778, -167.3627833>,
    <0.0138995, -167.3024008>,
    <0.0092593, -167.3845690>,
    <0.0000000, -167.3024008>,
    <0.0000000, -167.4256532>,
    <0.0277778, -167.4256532>,
    <0.0000000, -167.3627833>,
    <0.0138979, -167.4256532>,
    <0.0138507, -167.3638575>,
    <0.3240741, -167.4732541>,
    <0.9722222, -167.4256532>,
    <0.0000000, -167.5684558>,
    <0.0000000, -167.4256532>,
    <0.4871834, -167.4968970>,
    <0.0000000, -167.4961890>,
    <0.4857960, -167.4256532>,
    <0.6481481, -167.3845690>,
    <0.9722222, -167.3024008>,
    <0.9722222, -167.4256532>,
    <0.0000000, -167.4256532>,
    <0.9722222, -167.3627833>,
    <0.4857960, -167.4256532>,
    <0.4874476, -167.3638575>,
    <0.0543190, -167.1123151>,
    <0.0518458, -167.1040945>,
    <0.0555556, -167.1287564>,
    <0.0555556, -167.1040945>,
    <0.0545534, -167.1220942>,
    <0.0555556, -167.1157257>,
    <0.0533135, -167.1040945>,
    <0.0492196, -167.1123151>,
    <0.0518457, -167.1040945>,
    <0.0402576, -167.1040945>,
    <0.0555556, -167.1287564>,
    <0.0454588, -167.1040945>,
    <0.0518559, -167.1227921>,
    <0.0545534, -167.1220942>,
    <0.0411970, -167.1205358>,
    <0.0402577, -167.1040945>,
    <0.0277778, -167.1287564>,
    <0.0555556, -167.1287564>,
    <0.0306365, -167.1231073>,
    <0.0406971, -167.1287564>,
    <0.0518559, -167.1227921>,
    <0.9578637, -167.1205421>,
    <0.9569243, -167.1041136>,
    <0.9444444, -167.1287564>,
    <0.9722222, -167.1287564>,
    <0.9476153, -167.1224951>,
    <0.9575446, -167.1287564>,
    <0.9687224, -167.1231187>,
    <0.9495566, -167.1123279>,
    <0.9569243, -167.1041136>,
    <0.9473011, -167.1041136>,
    <0.9444444, -167.1287564>,
    <0.9529010, -167.1041136>,
    <0.9454620, -167.1199782>,
    <0.9476153, -167.1224951>,
    <0.9629630, -167.1533103>,
    <0.9444444, -167.1287564>,
    <0.9722222, -167.2024179>,
    <0.9722222, -167.1287564>,
    <0.9586656, -167.1664683>,
    <0.9722222, -167.1601023>,
    <0.9575446, -167.1287564>,
    <0.9453967, -167.1123215>,
    <0.9473011, -167.1041136>,
    <0.9444444, -167.1040945>,
    <0.9444444, -167.1287564>,
    <0.9461975, -167.1041062>,
    <0.9444444, -167.1186988>,
    <0.9454620, -167.1199782>,
    <0.0185185, -167.2709932>,
    <0.0000000, -167.2258020>,
    <0.0277778, -167.2258020>,
    <0.0277778, -167.3613758>,
    <0.0139006, -167.2258020>,
    <0.0277778, -167.2924560>,
    <0.0138473, -167.2933857>,
    <0.0092593, -167.3161845>,
    <0.0000000, -167.2258020>,
    <0.0277778, -167.3613758>,
    <0.0000000, -167.3613758>,
    <0.0138473, -167.2933857>,
    <0.0138989, -167.3613758>,
    <0.0000000, -167.2924560>,
    <0.3240741, -167.4137323>,
    <0.9722222, -167.3613758>,
    <0.0000000, -167.3613758>,
    <0.0000000, -167.5184453>,
    <0.4857617, -167.3613758>,
    <0.0000000, -167.4391507>,
    <0.4872775, -167.4397221>,
    <0.6481481, -167.3161845>,
    <0.9722222, -167.2258020>,
    <0.0000000, -167.3613758>,
    <0.9722222, -167.3613758>,
    <0.4875682, -167.2933857>,
    <0.4857617, -167.3613758>,
    <0.9722222, -167.2924560>,
    <0.0185185, -167.4732541>,
    <0.0000000, -167.4256532>,
    <0.0277778, -167.5684558>,
    <0.0277778, -167.4256532>,
    <0.0138583, -167.4968970>,
    <0.0277778, -167.4961890>,
    <0.0138979, -167.4256532>,
    <0.0092593, -167.5208549>,
    <0.0000000, -167.4256532>,
    <0.0000000, -167.5684558>,
    <0.0277778, -167.5684558>,
    <0.0000000, -167.4961890>,
    <0.0138960, -167.5684558>,
    <0.0138583, -167.4968970>,
    <0.3240741, -167.6211112>,
    <0.9722222, -167.5684558>,
    <0.0000000, -167.7264218>,
    <0.0000000, -167.5684558>,
    <0.4868937, -167.6473117>,
    <0.0000000, -167.6468904>,
    <0.4858635, -167.5684558>,
    <0.6481481, -167.5208549>,
    <0.9722222, -167.4256532>,
    <0.9722222, -167.5684558>,
    <0.0000000, -167.5684558>,
    <0.9722222, -167.4961890>,
    <0.4858635, -167.5684558>,
    <0.4871834, -167.4968970>,
    <0.9575090, -167.0842391>,
    <0.9444444, -167.0684463>,
    <0.9558604, -167.0684463>,
    <0.9722222, -167.1158246>,
    <0.9504396, -167.0684463>,
    <0.9656103, -167.0966788>,
    <0.9635993, -167.1011172>,
    <0.0185185, -167.6211112>,
    <0.0000000, -167.5684558>,
    <0.0277778, -167.7264218>,
    <0.0277778, -167.5684558>,
    <0.0138665, -167.6473117>,
    <0.0277778, -167.6468904>,
    <0.0138960, -167.5684558>,
    <0.0092593, -167.6737665>,
    <0.0000000, -167.5684558>,
    <0.0000000, -167.7264218>,
    <0.0277778, -167.7264218>,
    <0.0000000, -167.6468904>,
    <0.0138938, -167.7264218>,
    <0.0138665, -167.6473117>,
    <0.3240741, -167.7825485>,
    <0.9722222, -167.7264218>,
    <0.0000000, -167.8948019>,
    <0.0000000, -167.7264218>,
    <0.4886038, -167.8101802>,
    <0.0000000, -167.8064740>,
    <0.4859404, -167.7264218>,
    <0.6481481, -167.6737665>,
    <0.9722222, -167.5684558>,
    <0.9722222, -167.7264218>,
    <0.0000000, -167.7264218>,
    <0.9722222, -167.6468904>,
    <0.4859404, -167.7264218>,
    <0.4868937, -167.6473117>,
    <0.0185185, -167.4137323>,
    <0.0000000, -167.3613758>,
    <0.0277778, -167.3613758>,
    <0.0277778, -167.5184453>,
    <0.0138989, -167.3613758>,
    <0.0277778, -167.4391507>,
    <0.0138556, -167.4397221>,
    <0.0092593, -167.4660888>,
    <0.0000000, -167.3613758>,
    <0.0277778, -167.5184453>,
    <0.0000000, -167.5184453>,
    <0.0138556, -167.4397221>,
    <0.0138967, -167.5184453>,
    <0.0000000, -167.4391507>,
    <0.3240741, -167.5763713>,
    <0.9722222, -167.5184453>,
    <0.0000000, -167.5184453>,
    <0.0000000, -167.6922232>,
    <0.4858362, -167.5184453>,
    <0.0000000, -167.6048705>,
    <0.4869609, -167.6051824>,
    <0.6481481, -167.4660888>,
    <0.9722222, -167.3613758>,
    <0.0000000, -167.5184453>,
    <0.9722222, -167.5184453>,
    <0.4872775, -167.4397221>,
    <0.4858362, -167.5184453>,
    <0.9722222, -167.4391507>,
    <0.0462963, -167.1533103>,
    <0.0277778, -167.1287564>,
    <0.0555556, -167.2024179>,
    <0.0555556, -167.1287564>,
    <0.0419056, -167.1662209>,
    <0.0555556, -167.1607154>,
    <0.0406971, -167.1287564>,
    <0.0370370, -167.1778641>,
    <0.0277778, -167.1287564>,
    <0.0277778, -167.2024179>,
    <0.0555556, -167.2024179>,
    <0.0277778, -167.1607154>,
    <0.0416785, -167.2024179>,
    <0.0419056, -167.1662209>,
    <0.9629630, -167.2357456>,
    <0.9444444, -167.2024179>,
    <0.9722222, -167.3024008>,
    <0.9722222, -167.2024179>,
    <0.9582886, -167.2522483>,
    <0.9722222, -167.2507837>,
    <0.9583451, -167.2024179>,
    <0.9537037, -167.1778641>,
    <0.9444444, -167.1287564>,
    <0.9444444, -167.2024179>,
    <0.9722222, -167.2024179>,
    <0.9444444, -167.1601024>,
    <0.9583451, -167.2024179>,
    <0.9586656, -167.1664683>,
    <0.0185185, -167.7825485>,
    <0.0000000, -167.7264218>,
    <0.0277778, -167.8948019>,
    <0.0277778, -167.7264218>,
    <0.0138188, -167.8101870>,
    <0.0277778, -167.8064827>,
    <0.0138938, -167.7264218>,
    <0.0092593, -167.8386752>,
    <0.0000000, -167.7264218>,
    <0.0000000, -167.8948019>,
    <0.0277778, -167.8948019>,
    <0.0000000, -167.8064740>,
    <0.0139083, -167.8948019>,
    <0.0138188, -167.8101870>,
    <0.3240741, -167.9526834>,
    <0.9722222, -167.8948019>,
    <0.0000000, -168.0684463>,
    <0.0000000, -167.8948019>,
    <0.6096466, -167.9595600>,
    <0.0000000, -167.9523564>,
    <0.4854087, -167.8948019>,
    <0.6481481, -167.8386752>,
    <0.9722222, -167.7264218>,
    <0.9722222, -167.8948019>,
    <0.0000000, -167.8948019>,
    <0.9722222, -167.8064627>,
    <0.4854087, -167.8948019>,
    <0.4886038, -167.8101802>,
    <0.0185185, -167.9526834>,
    <0.0000000, -167.8948019>,
    <0.0277778, -168.0684463>,
    <0.0277778, -167.8948019>,
    <0.0103605, -167.9595672>,
    <0.0277778, -167.9524033>,
    <0.0139083, -167.8948019>,
    <0.0092593, -168.0105648>,
    <0.0000000, -167.8948019>,
    <0.0000000, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0000000, -167.9523564>,
    <0.0138889, -168.0684463>,
    <0.0103605, -167.9595672>,
    <0.6481482, -168.0105648>,
    <0.9722222, -167.8948019>,
    <0.9722222, -168.0684463>,
    <0.0000000, -168.0684463>,
    <0.9722222, -167.9523027>,
    <0.4861111, -168.0684463>,
    <0.6096466, -167.9595600>,
    <0.0501016, -167.0842391>,
    <0.0391937, -167.0684463>,
    <0.0555556, -167.0684463>,
    <0.0555556, -167.1158246>,
    <0.0473746, -167.0684463>,
    <0.0555556, -167.0953483>,
    <0.0484619, -167.0952839>,
    <0.0408434, -167.0842391>,
    <0.0277778, -167.0684463>,
    <0.0391968, -167.0684463>,
    <0.0555556, -167.1158246>,
    <0.0334873, -167.0684463>,
    <0.0484632, -167.0952839>,
    <0.0469930, -167.1012202>,
    <0.0370370, -167.1000319>,
    <0.0277778, -167.0684463>,
    <0.0555556, -167.1158246>,
    <0.0277778, -167.1158246>,
    <0.0469930, -167.1012202>,
    <0.0410767, -167.1158246>,
    <0.0277778, -167.0957145>,
    <0.9629630, -167.1524837>,
    <0.9444444, -167.1158246>,
    <0.9722222, -167.1158246>,
    <0.9722222, -167.2258020>,
    <0.9577681, -167.1158246>,
    <0.9722222, -167.1674336>,
    <0.9580028, -167.1695048>,
    <0.9537037, -167.1000319>,
    <0.9444444, -167.0684463>,
    <0.9722222, -167.1158246>,
    <0.9444444, -167.1158246>,
    <0.9635993, -167.1011172>,
    <0.9577681, -167.1158246>,
    <0.9444444, -167.0945365>,
    <0.0185185, -167.5763713>,
    <0.0000000, -167.5184453>,
    <0.0277778, -167.5184453>,
    <0.0277778, -167.6922232>,
    <0.0138967, -167.5184453>,
    <0.0277778, -167.6048705>,
    <0.0138646, -167.6051824>,
    <0.0092593, -167.6342972>,
    <0.0000000, -167.5184453>,
    <0.0277778, -167.6922232>,
    <0.0000000, -167.6922232>,
    <0.0138646, -167.6051824>,
    <0.0138943, -167.6922232>,
    <0.0000000, -167.6048705>,
    <0.3240741, -167.7539575>,
    <0.9722222, -167.6922232>,
    <0.0000000, -167.6922232>,
    <0.0000000, -167.8774261>,
    <0.4859215, -167.6922232>,
    <0.0000000, -167.7806198>,
    <0.4887264, -167.7843264>,
    <0.6481481, -167.6342972>,
    <0.9722222, -167.5184453>,
    <0.0000000, -167.6922232>,
    <0.9722222, -167.6922232>,
    <0.4869609, -167.6051824>,
    <0.4859215, -167.6922232>,
    <0.9722222, -167.6048705>,
    <0.0597155, -167.1123151>,
    <0.0680354, -167.1040945>,
    <0.0555556, -167.1040945>,
    <0.0555556, -167.1287564>,
    <0.0617380, -167.1040945>,
    <0.0555556, -167.1157257>,
    <0.0584142, -167.1231073>,
    <0.0185185, -167.7539575>,
    <0.0000000, -167.6922232>,
    <0.0277778, -167.6922232>,
    <0.0277778, -167.8774261>,
    <0.0138943, -167.6922232>,
    <0.0277778, -167.7806279>,
    <0.0138153, -167.7843340>,
    <0.0092593, -167.8156918>,
    <0.0000000, -167.6922232>,
    <0.0277778, -167.8774261>,
    <0.0000000, -167.8774261>,
    <0.0138153, -167.7843340>,
    <0.0139086, -167.8774261>,
    <0.0000000, -167.7806198>,
    <0.3240741, -167.9410995>,
    <0.9722222, -167.8774261>,
    <0.0000000, -167.8774261>,
    <0.0000000, -168.0684463>,
    <0.4853982, -167.8774261>,
    <0.0000000, -167.9813927>,
    <0.5997728, -167.9506042>,
    <0.6481481, -167.8156918>,
    <0.9722222, -167.6922232>,
    <0.0000000, -167.8774261>,
    <0.9722222, -167.8774261>,
    <0.4887264, -167.7843264>,
    <0.4853982, -167.8774261>,
    <0.9722222, -167.7806092>,
    <0.0462963, -167.2357456>,
    <0.0277778, -167.2024179>,
    <0.0555556, -167.3024008>,
    <0.0555556, -167.2024179>,
    <0.0416219, -167.2522483>,
    <0.0555556, -167.2507837>,
    <0.0416785, -167.2024179>,
    <0.0370370, -167.2690732>,
    <0.0277778, -167.2024179>,
    <0.0277778, -167.3024008>,
    <0.0555556, -167.3024008>,
    <0.0277778, -167.2507837>,
    <0.0416773, -167.3024008>,
    <0.0416219, -167.2522483>,
    <0.9629630, -167.3434849>,
    <0.9444444, -167.3024008>,
    <0.9722222, -167.4256532>,
    <0.9722222, -167.3024008>,
    <0.9582951, -167.3638575>,
    <0.9722222, -167.3627833>,
    <0.9583439, -167.3024008>,
    <0.9537037, -167.2690732>,
    <0.9444444, -167.2024179>,
    <0.9444444, -167.3024008>,
    <0.9722222, -167.3024008>,
    <0.9444444, -167.2507837>,
    <0.9583439, -167.3024008>,
    <0.9582886, -167.2522483>,
    <0.0185185, -167.9410995>,
    <0.0000000, -167.8774261>,
    <0.0277778, -167.8774261>,
    <0.0277778, -168.0684463>,
    <0.0139086, -167.8774261>,
    <0.0277778, -167.9788771>,
    <0.0033516, -167.9004739>,
    <0.0092593, -168.0047729>,
    <0.0000000, -167.8774261>,
    <0.0277778, -168.0684463>,
    <0.0000000, -168.0684463>,
    <0.0033516, -167.9004739>,
    <0.0138888, -168.0684463>,
    <0.0000000, -167.9813927>,
    <0.6481481, -168.0047729>,
    <0.9722222, -167.8774261>,
    <0.0000000, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.5997728, -167.9506042>,
    <0.5220048, -168.0684463>,
    <0.9722222, -167.9689421>,
    <0.9393451, -167.1123151>,
    <0.9291465, -167.1040945>,
    <0.9444444, -167.1287564>,
    <0.9444444, -167.1040945>,
    <0.9409447, -167.1231144>,
    <0.9444444, -167.1186988>,
    <0.9371677, -167.1040945>,
    <0.0462963, -167.1524837>,
    <0.0277778, -167.1158246>,
    <0.0555556, -167.1158246>,
    <0.0555556, -167.2258020>,
    <0.0410767, -167.1158246>,
    <0.0555556, -167.1669437>,
    <0.0413167, -167.1694277>,
    <0.0370370, -167.1891429>,
    <0.0277778, -167.1158246>,
    <0.0555556, -167.2258020>,
    <0.0277778, -167.2258020>,
    <0.0413167, -167.1694277>,
    <0.0416784, -167.2258020>,
    <0.0277778, -167.1666572>,
    <0.9629630, -167.2709932>,
    <0.9444444, -167.2258020>,
    <0.9722222, -167.2258020>,
    <0.9722222, -167.3613758>,
    <0.9583451, -167.2258020>,
    <0.9722222, -167.2924560>,
    <0.9582917, -167.2933857>,
    <0.9537037, -167.1891429>,
    <0.9444444, -167.1158246>,
    <0.9722222, -167.2258020>,
    <0.9444444, -167.2258020>,
    <0.9580028, -167.1695048>,
    <0.9583451, -167.2258020>,
    <0.9444444, -167.1673989>,
    <0.0462963, -167.3434849>,
    <0.0277778, -167.3024008>,
    <0.0555555, -167.4256532>,
    <0.0555556, -167.3024008>,
    <0.0416285, -167.3638575>,
    <0.0555556, -167.3627833>,
    <0.0416773, -167.3024008>,
    <0.0370370, -167.3845690>,
    <0.0277778, -167.3024008>,
    <0.0277778, -167.4256532>,
    <0.0555555, -167.4256532>,
    <0.0277778, -167.3627833>,
    <0.0416757, -167.4256532>,
    <0.0416285, -167.3638575>,
    <0.9629630, -167.4732541>,
    <0.9444445, -167.4256532>,
    <0.9722222, -167.5684558>,
    <0.9722222, -167.4256532>,
    <0.9583027, -167.4968970>,
    <0.9722222, -167.4961890>,
    <0.9583423, -167.4256532>,
    <0.9537037, -167.3845690>,
    <0.9444444, -167.3024008>,
    <0.9444445, -167.4256532>,
    <0.9722222, -167.4256532>,
    <0.9444444, -167.3627833>,
    <0.9583423, -167.4256532>,
    <0.9582951, -167.3638575>,
    <0.0462963, -167.2709932>,
    <0.0277778, -167.2258020>,
    <0.0555556, -167.2258020>,
    <0.0555556, -167.3613758>,
    <0.0416784, -167.2258020>,
    <0.0555556, -167.2924560>,
    <0.0416250, -167.2933857>,
    <0.0370370, -167.3161845>,
    <0.0277778, -167.2258020>,
    <0.0555556, -167.3613758>,
    <0.0277778, -167.3613758>,
    <0.0416250, -167.2933857>,
    <0.0416766, -167.3613758>,
    <0.0277778, -167.2924560>,
    <0.9629630, -167.4137323>,
    <0.9444444, -167.3613758>,
    <0.9722222, -167.3613758>,
    <0.9722222, -167.5184453>,
    <0.9583433, -167.3613758>,
    <0.9722222, -167.4391507>,
    <0.9583000, -167.4397221>,
    <0.9537037, -167.3161845>,
    <0.9444444, -167.2258020>,
    <0.9722222, -167.3613758>,
    <0.9444444, -167.3613758>,
    <0.9582917, -167.2933857>,
    <0.9583433, -167.3613758>,
    <0.9444444, -167.2924560>,
    <0.0462963, -167.4732541>,
    <0.0277778, -167.4256532>,
    <0.0555556, -167.5684558>,
    <0.0555555, -167.4256532>,
    <0.0416360, -167.4968970>,
    <0.0555556, -167.4961890>,
    <0.0416757, -167.4256532>,
    <0.0370370, -167.5208549>,
    <0.0277778, -167.4256532>,
    <0.0277778, -167.5684558>,
    <0.0555556, -167.5684558>,
    <0.0277778, -167.4961890>,
    <0.0416737, -167.5684558>,
    <0.0416360, -167.4968970>,
    <0.9629630, -167.6211112>,
    <0.9444444, -167.5684558>,
    <0.9722222, -167.7264218>,
    <0.9722222, -167.5684558>,
    <0.9583110, -167.6473117>,
    <0.9722222, -167.6468904>,
    <0.9583404, -167.5684558>,
    <0.9537037, -167.5208549>,
    <0.9444445, -167.4256532>,
    <0.9444444, -167.5684558>,
    <0.9722222, -167.5684558>,
    <0.9444444, -167.4961890>,
    <0.9583404, -167.5684558>,
    <0.9583027, -167.4968970>,
    <0.9389915, -167.0842391>,
    <0.9280857, -167.0684463>,
    <0.9444444, -167.0684463>,
    <0.9444444, -167.1158246>,
    <0.9365862, -167.0684463>,
    <0.9444444, -167.0945365>,
    <0.9378342, -167.0966801>,
    <0.0462963, -167.6211112>,
    <0.0277778, -167.5684558>,
    <0.0555556, -167.7264218>,
    <0.0555556, -167.5684558>,
    <0.0416443, -167.6473117>,
    <0.0555556, -167.6468904>,
    <0.0416737, -167.5684558>,
    <0.0370370, -167.6737665>,
    <0.0277778, -167.5684558>,
    <0.0277778, -167.7264218>,
    <0.0555556, -167.7264218>,
    <0.0277778, -167.6468904>,
    <0.0416715, -167.7264218>,
    <0.0416443, -167.6473117>,
    <0.9629630, -167.7825485>,
    <0.9444444, -167.7264218>,
    <0.9722222, -167.8948019>,
    <0.9722222, -167.7264218>,
    <0.9582611, -167.8101743>,
    <0.9722222, -167.8064627>,
    <0.9583382, -167.7264218>,
    <0.9537037, -167.6737665>,
    <0.9444444, -167.5684558>,
    <0.9444444, -167.7264218>,
    <0.9722222, -167.7264218>,
    <0.9444444, -167.6468904>,
    <0.9583382, -167.7264218>,
    <0.9583110, -167.6473117>,
    <0.0462963, -167.4137323>,
    <0.0277778, -167.3613758>,
    <0.0555556, -167.3613758>,
    <0.0555556, -167.5184453>,
    <0.0416766, -167.3613758>,
    <0.0555556, -167.4391507>,
    <0.0416333, -167.4397221>,
    <0.0370370, -167.4660888>,
    <0.0277778, -167.3613758>,
    <0.0555556, -167.5184453>,
    <0.0277778, -167.5184453>,
    <0.0416333, -167.4397221>,
    <0.0416745, -167.5184453>,
    <0.0277778, -167.4391507>,
    <0.9629630, -167.5763713>,
    <0.9444444, -167.5184453>,
    <0.9722222, -167.5184453>,
    <0.9722222, -167.6922232>,
    <0.9583412, -167.5184453>,
    <0.9722222, -167.6048705>,
    <0.9583091, -167.6051824>,
    <0.9537037, -167.4660888>,
    <0.9444444, -167.3613758>,
    <0.9722222, -167.5184453>,
    <0.9444444, -167.5184453>,
    <0.9583000, -167.4397221>,
    <0.9583412, -167.5184453>,
    <0.9444444, -167.4391507>,
    <0.0462963, -167.7825485>,
    <0.0277778, -167.7264218>,
    <0.0555556, -167.8948019>,
    <0.0555556, -167.7264218>,
    <0.0415978, -167.8101944>,
    <0.0555556, -167.8064884>,
    <0.0416715, -167.7264218>,
    <0.0370370, -167.8386752>,
    <0.0277778, -167.7264218>,
    <0.0277778, -167.8948019>,
    <0.0555556, -167.8948019>,
    <0.0277778, -167.8064827>,
    <0.0416854, -167.8948019>,
    <0.0415978, -167.8101944>,
    <0.9629630, -167.9526834>,
    <0.9444444, -167.8948019>,
    <0.9722222, -168.0684463>,
    <0.9722222, -167.8948019>,
    <0.9548028, -167.9595543>,
    <0.9722222, -167.9523027>,
    <0.9583539, -167.8948019>,
    <0.9537037, -167.8386752>,
    <0.9444444, -167.7264218>,
    <0.9444444, -167.8948019>,
    <0.9722222, -167.8948019>,
    <0.9444444, -167.8064491>,
    <0.9583539, -167.8948019>,
    <0.9582611, -167.8101743>,
    <0.0462963, -167.9526834>,
    <0.0277778, -167.8948019>,
    <0.0555556, -168.0684463>,
    <0.0555556, -167.8948019>,
    <0.0381394, -167.9595742>,
    <0.0555556, -167.9524416>,
    <0.0416854, -167.8948019>,
    <0.0370370, -168.0105648>,
    <0.0277778, -167.8948019>,
    <0.0277778, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0277778, -167.9524033>,
    <0.0416667, -168.0684463>,
    <0.0381394, -167.9595742>,
    <0.9537037, -168.0105648>,
    <0.9444444, -167.8948019>,
    <0.9444444, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9444444, -167.9522414>,
    <0.9583333, -168.0684463>,
    <0.9548028, -167.9595543>,
    <0.0462963, -167.5763713>,
    <0.0277778, -167.5184453>,
    <0.0555556, -167.5184453>,
    <0.0555556, -167.6922232>,
    <0.0416745, -167.5184453>,
    <0.0555556, -167.6048705>,
    <0.0416424, -167.6051824>,
    <0.0370370, -167.6342972>,
    <0.0277778, -167.5184453>,
    <0.0555556, -167.6922232>,
    <0.0277778, -167.6922232>,
    <0.0416424, -167.6051824>,
    <0.0416721, -167.6922232>,
    <0.0277778, -167.6048705>,
    <0.9629630, -167.7539575>,
    <0.9444444, -167.6922232>,
    <0.9722222, -167.6922232>,
    <0.9722222, -167.8774261>,
    <0.9583388, -167.6922232>,
    <0.9722222, -167.7806092>,
    <0.9582576, -167.7843199>,
    <0.9537037, -167.6342972>,
    <0.9444444, -167.5184453>,
    <0.9722222, -167.6922232>,
    <0.9444444, -167.6922232>,
    <0.9583091, -167.6051824>,
    <0.9583388, -167.6922232>,
    <0.9444444, -167.6048705>,
    <0.0462963, -167.7539575>,
    <0.0277778, -167.6922232>,
    <0.0555556, -167.6922232>,
    <0.0555556, -167.8774261>,
    <0.0416721, -167.6922232>,
    <0.0555556, -167.7806332>,
    <0.0415943, -167.7843422>,
    <0.0370370, -167.8156918>,
    <0.0277778, -167.6922232>,
    <0.0555556, -167.8774261>,
    <0.0277778, -167.8774261>,
    <0.0415943, -167.7843422>,
    <0.0416857, -167.8774261>,
    <0.0277778, -167.7806279>,
    <0.9629630, -167.9410995>,
    <0.9444444, -167.8774261>,
    <0.9722222, -167.8774261>,
    <0.9722222, -168.0684463>,
    <0.9583542, -167.8774261>,
    <0.9722222, -167.9689421>,
    <0.9575400, -167.9674805>,
    <0.9537037, -167.8156918>,
    <0.9444444, -167.6922232>,
    <0.9722222, -167.8774261>,
    <0.9444444, -167.8774261>,
    <0.9582576, -167.7843199>,
    <0.9583542, -167.8774261>,
    <0.9444444, -167.7805965>,
    <0.0462963, -167.9410995>,
    <0.0277778, -167.8774261>,
    <0.0555556, -167.8774261>,
    <0.0555556, -168.0684463>,
    <0.0416857, -167.8774261>,
    <0.0555556, -167.9645057>,
    <0.0412449, -167.9700362>,
    <0.0370370, -168.0047729>,
    <0.0277778, -167.8774261>,
    <0.0555556, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0412449, -167.9700362>,
    <0.0456798, -168.0684463>,
    <0.0277778, -167.9788771>,
    <0.9537037, -168.0047729>,
    <0.9444444, -167.8774261>,
    <0.9722222, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9575400, -167.9674805>,
    <0.9594863, -168.0684463>,
    <0.9444444, -167.9661475>,
    <0.0820967, -167.1123151>,
    <0.0796235, -167.1040945>,
    <0.0833333, -167.1287564>,
    <0.0833333, -167.1040945>,
    <0.0823311, -167.1220942>,
    <0.0833333, -167.1157258>,
    <0.0810912, -167.1040945>,
    <0.0769974, -167.1123151>,
    <0.0796235, -167.1040945>,
    <0.0680354, -167.1040945>,
    <0.0833333, -167.1287564>,
    <0.0732365, -167.1040945>,
    <0.0796336, -167.1227921>,
    <0.0823312, -167.1220942>,
    <0.0689748, -167.1205358>,
    <0.0680354, -167.1040945>,
    <0.0555556, -167.1287564>,
    <0.0833333, -167.1287564>,
    <0.0584142, -167.1231073>,
    <0.0684748, -167.1287564>,
    <0.0796337, -167.1227921>,
    <0.9300859, -167.1205421>,
    <0.9291466, -167.1041136>,
    <0.9166667, -167.1287564>,
    <0.9444444, -167.1287564>,
    <0.9198375, -167.1224954>,
    <0.9297668, -167.1287564>,
    <0.9409447, -167.1231187>,
    <0.9217789, -167.1123279>,
    <0.9291466, -167.1041136>,
    <0.9195233, -167.1041136>,
    <0.9166667, -167.1287564>,
    <0.9251232, -167.1041136>,
    <0.9176842, -167.1199784>,
    <0.9198375, -167.1224954>,
    <0.9351852, -167.1533103>,
    <0.9166667, -167.1287564>,
    <0.9444444, -167.2024179>,
    <0.9444444, -167.1287564>,
    <0.9308878, -167.1664683>,
    <0.9444444, -167.1601024>,
    <0.9297668, -167.1287564>,
    <0.9176189, -167.1123215>,
    <0.9195233, -167.1041136>,
    <0.9166667, -167.1040945>,
    <0.9166667, -167.1287564>,
    <0.9184198, -167.1041062>,
    <0.9166667, -167.1186966>,
    <0.9176842, -167.1199784>,
    <0.9297323, -167.0842391>,
    <0.9166667, -167.0684463>,
    <0.9280857, -167.0684463>,
    <0.9444444, -167.1158246>,
    <0.9226635, -167.0684463>,
    <0.9378342, -167.0966801>,
    <0.9358213, -167.1011169>,
    <0.0740741, -167.1533103>,
    <0.0555556, -167.1287564>,
    <0.0833333, -167.2024179>,
    <0.0833333, -167.1287564>,
    <0.0696834, -167.1662209>,
    <0.0833333, -167.1607154>,
    <0.0684748, -167.1287564>,
    <0.0648148, -167.1778641>,
    <0.0555556, -167.1287564>,
    <0.0555556, -167.2024179>,
    <0.0833333, -167.2024179>,
    <0.0555556, -167.1607154>,
    <0.0694563, -167.2024179>,
    <0.0696834, -167.1662209>,
    <0.9351852, -167.2357456>,
    <0.9166667, -167.2024179>,
    <0.9444444, -167.3024008>,
    <0.9444444, -167.2024179>,
    <0.9305108, -167.2522483>,
    <0.9444444, -167.2507837>,
    <0.9305674, -167.2024179>,
    <0.9259259, -167.1778641>,
    <0.9166667, -167.1287564>,
    <0.9166667, -167.2024179>,
    <0.9444444, -167.2024179>,
    <0.9166667, -167.1601023>,
    <0.9305674, -167.2024179>,
    <0.9308878, -167.1664683>,
    <0.0778804, -167.0842391>,
    <0.0669746, -167.0684463>,
    <0.0833333, -167.0684463>,
    <0.0833333, -167.1158246>,
    <0.0751539, -167.0684463>,
    <0.0833333, -167.0954613>,
    <0.0762358, -167.0952687>,
    <0.0686211, -167.0842391>,
    <0.0555556, -167.0684463>,
    <0.0669745, -167.0684463>,
    <0.0833333, -167.1158246>,
    <0.0612651, -167.0684463>,
    <0.0762358, -167.0952687>,
    <0.0747768, -167.1012305>,
    <0.0648148, -167.1000319>,
    <0.0555556, -167.0684463>,
    <0.0833333, -167.1158246>,
    <0.0555556, -167.1158246>,
    <0.0747768, -167.1012305>,
    <0.0688585, -167.1158246>,
    <0.0555556, -167.0953483>,
    <0.9351852, -167.1524837>,
    <0.9166667, -167.1158246>,
    <0.9444444, -167.1158246>,
    <0.9444444, -167.2258020>,
    <0.9299898, -167.1158246>,
    <0.9444444, -167.1673989>,
    <0.9302242, -167.1695015>,
    <0.9259259, -167.1000319>,
    <0.9166667, -167.0684463>,
    <0.9444444, -167.1158246>,
    <0.9166667, -167.1158246>,
    <0.9358213, -167.1011169>,
    <0.9299898, -167.1158246>,
    <0.9166667, -167.0945275>,
    <0.0740741, -167.2357456>,
    <0.0555556, -167.2024179>,
    <0.0833333, -167.3024008>,
    <0.0833333, -167.2024179>,
    <0.0693997, -167.2522483>,
    <0.0833333, -167.2507837>,
    <0.0694563, -167.2024179>,
    <0.0648148, -167.2690732>,
    <0.0555556, -167.2024179>,
    <0.0555556, -167.3024008>,
    <0.0833333, -167.3024008>,
    <0.0555556, -167.2507837>,
    <0.0694550, -167.3024008>,
    <0.0693997, -167.2522483>,
    <0.9351852, -167.3434849>,
    <0.9166667, -167.3024008>,
    <0.9444445, -167.4256532>,
    <0.9444444, -167.3024008>,
    <0.9305174, -167.3638575>,
    <0.9444444, -167.3627833>,
    <0.9305662, -167.3024008>,
    <0.9259259, -167.2690732>,
    <0.9166667, -167.2024179>,
    <0.9166667, -167.3024008>,
    <0.9444444, -167.3024008>,
    <0.9166667, -167.2507837>,
    <0.9305662, -167.3024008>,
    <0.9305108, -167.2522483>,
    <0.0740741, -167.1524837>,
    <0.0555556, -167.1158246>,
    <0.0833333, -167.1158246>,
    <0.0833333, -167.2258020>,
    <0.0688585, -167.1158246>,
    <0.0833333, -167.1670330>,
    <0.0691010, -167.1694536>,
    <0.0648148, -167.1891429>,
    <0.0555556, -167.1158246>,
    <0.0833333, -167.2258020>,
    <0.0555556, -167.2258020>,
    <0.0691010, -167.1694536>,
    <0.0694562, -167.2258020>,
    <0.0555556, -167.1669437>,
    <0.9351852, -167.2709932>,
    <0.9166667, -167.2258020>,
    <0.9444444, -167.2258020>,
    <0.9444444, -167.3613758>,
    <0.9305673, -167.2258020>,
    <0.9444444, -167.2924560>,
    <0.9305139, -167.2933857>,
    <0.9259259, -167.1891429>,
    <0.9166667, -167.1158246>,
    <0.9444444, -167.2258020>,
    <0.9166667, -167.2258020>,
    <0.9302242, -167.1695015>,
    <0.9305673, -167.2258020>,
    <0.9166667, -167.1673444>,
    <0.0740741, -167.3434849>,
    <0.0555556, -167.3024008>,
    <0.0833333, -167.4256532>,
    <0.0833333, -167.3024008>,
    <0.0694063, -167.3638575>,
    <0.0833333, -167.3627833>,
    <0.0694550, -167.3024008>,
    <0.0648148, -167.3845690>,
    <0.0555556, -167.3024008>,
    <0.0555555, -167.4256532>,
    <0.0833333, -167.4256532>,
    <0.0555556, -167.3627833>,
    <0.0694534, -167.4256532>,
    <0.0694063, -167.3638575>,
    <0.9351852, -167.4732541>,
    <0.9166667, -167.4256532>,
    <0.9444444, -167.5684558>,
    <0.9444445, -167.4256532>,
    <0.9305249, -167.4968970>,
    <0.9444444, -167.4961890>,
    <0.9305646, -167.4256532>,
    <0.9259259, -167.3845690>,
    <0.9166667, -167.3024008>,
    <0.9166667, -167.4256532>,
    <0.9444445, -167.4256532>,
    <0.9166667, -167.3627833>,
    <0.9305646, -167.4256532>,
    <0.9305174, -167.3638575>,
    <0.0874933, -167.1123151>,
    <0.0958132, -167.1040945>,
    <0.0833333, -167.1040945>,
    <0.0833333, -167.1287564>,
    <0.0895158, -167.1040945>,
    <0.0833333, -167.1157258>,
    <0.0861920, -167.1231073>,
    <0.0740741, -167.2709932>,
    <0.0555556, -167.2258020>,
    <0.0833333, -167.2258020>,
    <0.0833333, -167.3613758>,
    <0.0694562, -167.2258020>,
    <0.0833333, -167.2924560>,
    <0.0694028, -167.2933857>,
    <0.0648148, -167.3161845>,
    <0.0555556, -167.2258020>,
    <0.0833333, -167.3613758>,
    <0.0555556, -167.3613758>,
    <0.0694028, -167.2933857>,
    <0.0694544, -167.3613758>,
    <0.0555556, -167.2924560>,
    <0.9351852, -167.4137323>,
    <0.9166667, -167.3613758>,
    <0.9444444, -167.3613758>,
    <0.9444444, -167.5184453>,
    <0.9305655, -167.3613758>,
    <0.9444444, -167.4391507>,
    <0.9305222, -167.4397221>,
    <0.9259259, -167.3161845>,
    <0.9166667, -167.2258020>,
    <0.9444444, -167.3613758>,
    <0.9166667, -167.3613758>,
    <0.9305139, -167.2933857>,
    <0.9305655, -167.3613758>,
    <0.9166667, -167.2924560>,
    <0.0740741, -167.4732541>,
    <0.0555555, -167.4256532>,
    <0.0833333, -167.5684558>,
    <0.0833333, -167.4256532>,
    <0.0694138, -167.4968970>,
    <0.0833333, -167.4961891>,
    <0.0694534, -167.4256532>,
    <0.0648148, -167.5208549>,
    <0.0555555, -167.4256532>,
    <0.0555556, -167.5684558>,
    <0.0833333, -167.5684558>,
    <0.0555556, -167.4961890>,
    <0.0694515, -167.5684558>,
    <0.0694138, -167.4968970>,
    <0.9351852, -167.6211112>,
    <0.9166667, -167.5684558>,
    <0.9444444, -167.7264218>,
    <0.9444444, -167.5684558>,
    <0.9305332, -167.6473117>,
    <0.9444444, -167.6468904>,
    <0.9305626, -167.5684558>,
    <0.9259259, -167.5208549>,
    <0.9166667, -167.4256532>,
    <0.9166667, -167.5684558>,
    <0.9444444, -167.5684558>,
    <0.9166667, -167.4961890>,
    <0.9305626, -167.5684558>,
    <0.9305249, -167.4968970>,
    <0.9115673, -167.1123151>,
    <0.9013686, -167.1040945>,
    <0.9166667, -167.1287564>,
    <0.9166667, -167.1040945>,
    <0.9129000, -167.1226843>,
    <0.9166667, -167.1186966>,
    <0.9091975, -167.1040945>,
    <0.0740741, -167.6211112>,
    <0.0555556, -167.5684558>,
    <0.0833333, -167.7264218>,
    <0.0833333, -167.5684558>,
    <0.0694221, -167.6473117>,
    <0.0833333, -167.6468904>,
    <0.0694515, -167.5684558>,
    <0.0648148, -167.6737665>,
    <0.0555556, -167.5684558>,
    <0.0555556, -167.7264218>,
    <0.0833333, -167.7264218>,
    <0.0555556, -167.6468904>,
    <0.0694493, -167.7264218>,
    <0.0694221, -167.6473117>,
    <0.9351852, -167.7825485>,
    <0.9166667, -167.7264218>,
    <0.9444444, -167.8948019>,
    <0.9444444, -167.7264218>,
    <0.9304825, -167.8101693>,
    <0.9444444, -167.8064491>,
    <0.9305604, -167.7264218>,
    <0.9259259, -167.6737665>,
    <0.9166667, -167.5684558>,
    <0.9166667, -167.7264218>,
    <0.9444444, -167.7264218>,
    <0.9166667, -167.6468904>,
    <0.9305604, -167.7264218>,
    <0.9305332, -167.6473117>,
    <0.0740741, -167.4137323>,
    <0.0555556, -167.3613758>,
    <0.0833333, -167.3613758>,
    <0.0833333, -167.5184453>,
    <0.0694544, -167.3613758>,
    <0.0833333, -167.4391507>,
    <0.0694111, -167.4397221>,
    <0.0648148, -167.4660888>,
    <0.0555556, -167.3613758>,
    <0.0833333, -167.5184453>,
    <0.0555556, -167.5184453>,
    <0.0694111, -167.4397221>,
    <0.0694523, -167.5184453>,
    <0.0555556, -167.4391507>,
    <0.9351852, -167.5763713>,
    <0.9166667, -167.5184453>,
    <0.9444444, -167.5184453>,
    <0.9444444, -167.6922232>,
    <0.9305634, -167.5184453>,
    <0.9444444, -167.6048705>,
    <0.9305313, -167.6051824>,
    <0.9259259, -167.4660888>,
    <0.9166667, -167.3613758>,
    <0.9444444, -167.5184453>,
    <0.9166667, -167.5184453>,
    <0.9305222, -167.4397221>,
    <0.9305634, -167.5184453>,
    <0.9166667, -167.4391507>,
    <0.0740741, -167.7825485>,
    <0.0555556, -167.7264218>,
    <0.0833333, -167.8948019>,
    <0.0833333, -167.7264218>,
    <0.0693768, -167.8102021>,
    <0.0833333, -167.8064909>,
    <0.0694493, -167.7264218>,
    <0.0648148, -167.8386752>,
    <0.0555556, -167.7264218>,
    <0.0555556, -167.8948019>,
    <0.0833333, -167.8948019>,
    <0.0555556, -167.8064884>,
    <0.0694624, -167.8948019>,
    <0.0693768, -167.8102021>,
    <0.9351852, -167.9526834>,
    <0.9166667, -167.8948019>,
    <0.9444444, -168.0684463>,
    <0.9444444, -167.8948019>,
    <0.9270239, -167.9595473>,
    <0.9444444, -167.9522414>,
    <0.9305766, -167.8948019>,
    <0.9259259, -167.8386752>,
    <0.9166667, -167.7264218>,
    <0.9166667, -167.8948019>,
    <0.9444444, -167.8948019>,
    <0.9166667, -167.8064334>,
    <0.9305766, -167.8948019>,
    <0.9304825, -167.8101693>,
    <0.0740741, -167.9526834>,
    <0.0555556, -167.8948019>,
    <0.0833333, -168.0684463>,
    <0.0833333, -167.8948019>,
    <0.0659183, -167.9595813>,
    <0.0833333, -167.9524723>,
    <0.0694624, -167.8948019>,
    <0.0648148, -168.0105648>,
    <0.0555556, -167.8948019>,
    <0.0555556, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0555556, -167.9524416>,
    <0.0694444, -168.0684463>,
    <0.0659183, -167.9595813>,
    <0.9259259, -168.0105648>,
    <0.9166667, -167.8948019>,
    <0.9166667, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9166667, -167.9521780>,
    <0.9305556, -168.0684463>,
    <0.9270239, -167.9595473>,
    <0.0740741, -167.5763713>,
    <0.0555556, -167.5184453>,
    <0.0833333, -167.5184453>,
    <0.0833333, -167.6922232>,
    <0.0694523, -167.5184453>,
    <0.0833333, -167.6048705>,
    <0.0694202, -167.6051824>,
    <0.0648148, -167.6342972>,
    <0.0555556, -167.5184453>,
    <0.0833333, -167.6922232>,
    <0.0555556, -167.6922232>,
    <0.0694202, -167.6051824>,
    <0.0694499, -167.6922232>,
    <0.0555556, -167.6048705>,
    <0.9351852, -167.7539575>,
    <0.9166667, -167.6922232>,
    <0.9444444, -167.6922232>,
    <0.9444444, -167.8774261>,
    <0.9305610, -167.6922232>,
    <0.9444444, -167.7805965>,
    <0.9304790, -167.7843143>,
    <0.9259259, -167.6342972>,
    <0.9166667, -167.5184453>,
    <0.9444444, -167.6922232>,
    <0.9166667, -167.6922232>,
    <0.9305313, -167.6051824>,
    <0.9305610, -167.6922232>,
    <0.9166667, -167.6048705>,
    <0.0740741, -167.7539575>,
    <0.0555556, -167.6922232>,
    <0.0833333, -167.6922232>,
    <0.0833333, -167.8774261>,
    <0.0694499, -167.6922232>,
    <0.0833333, -167.7806356>,
    <0.0693734, -167.7843507>,
    <0.0648148, -167.8156918>,
    <0.0555556, -167.6922232>,
    <0.0833333, -167.8774261>,
    <0.0555556, -167.8774261>,
    <0.0693734, -167.7843507>,
    <0.0694628, -167.8774261>,
    <0.0555556, -167.7806332>,
    <0.9351852, -167.9410995>,
    <0.9166667, -167.8774261>,
    <0.9444444, -167.8774261>,
    <0.9444444, -168.0684463>,
    <0.9305769, -167.8774261>,
    <0.9444444, -167.9661475>,
    <0.9300317, -167.9693337>,
    <0.9259259, -167.8156918>,
    <0.9166667, -167.6922232>,
    <0.9444444, -167.8774261>,
    <0.9166667, -167.8774261>,
    <0.9304790, -167.7843143>,
    <0.9305769, -167.8774261>,
    <0.9166667, -167.7805818>,
    <0.0740741, -167.9410995>,
    <0.0555556, -167.8774261>,
    <0.0833333, -167.8774261>,
    <0.0833333, -168.0684463>,
    <0.0694628, -167.8774261>,
    <0.0833333, -167.9641320>,
    <0.0692081, -167.9713108>,
    <0.0648148, -168.0047729>,
    <0.0555556, -167.8774261>,
    <0.0833333, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0692081, -167.9713108>,
    <0.0701352, -168.0684463>,
    <0.0555556, -167.9645057>,
    <0.9259259, -168.0047729>,
    <0.9166667, -167.8774261>,
    <0.9444444, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9300317, -167.9693337>,
    <0.9319411, -168.0684463>,
    <0.9166667, -167.9661382>,
    <0.9112148, -167.0842391>,
    <0.9003109, -167.0684463>,
    <0.9166667, -167.0684463>,
    <0.9166667, -167.1158246>,
    <0.9088090, -167.0684463>,
    <0.9166667, -167.0945275>,
    <0.9100594, -167.0966849>,
    <0.1098745, -167.1123151>,
    <0.1074012, -167.1040945>,
    <0.1111111, -167.1287564>,
    <0.1111111, -167.1040945>,
    <0.1101089, -167.1220938>,
    <0.1111111, -167.1157357>,
    <0.1088694, -167.1040945>,
    <0.1047752, -167.1123151>,
    <0.1074013, -167.1040945>,
    <0.0958131, -167.1040945>,
    <0.1111111, -167.1287564>,
    <0.1010145, -167.1040945>,
    <0.1074114, -167.1227922>,
    <0.1101089, -167.1220938>,
    <0.0967526, -167.1205358>,
    <0.0958132, -167.1040945>,
    <0.0833333, -167.1287564>,
    <0.1111111, -167.1287564>,
    <0.0861920, -167.1231073>,
    <0.0962527, -167.1287564>,
    <0.1074115, -167.1227922>,
    <0.9023080, -167.1205358>,
    <0.9013685, -167.1040945>,
    <0.8888889, -167.1287564>,
    <0.9166667, -167.1287564>,
    <0.8921851, -167.1222425>,
    <0.9020531, -167.1287564>,
    <0.9129000, -167.1226843>,
    <0.9074074, -167.1533103>,
    <0.8888889, -167.1287564>,
    <0.9166667, -167.2024179>,
    <0.9166667, -167.1287564>,
    <0.9031871, -167.1666727>,
    <0.9166667, -167.1601023>,
    <0.9020531, -167.1287564>,
    <0.8930488, -167.1123151>,
    <0.9013685, -167.1040945>,
    <0.8888889, -167.1040945>,
    <0.8888889, -167.1287564>,
    <0.8952996, -167.1040945>,
    <0.8888889, -167.1196785>,
    <0.8921851, -167.1222425>,
    <0.9019545, -167.0842391>,
    <0.8888889, -167.0684463>,
    <0.9003079, -167.0684463>,
    <0.9166667, -167.1158246>,
    <0.8948829, -167.0684463>,
    <0.9100581, -167.0966849>,
    <0.9080364, -167.1011047>,
    <0.1018518, -167.1533103>,
    <0.0833333, -167.1287564>,
    <0.1111111, -167.2024179>,
    <0.1111111, -167.1287564>,
    <0.0974612, -167.1662209>,
    <0.1111111, -167.1607152>,
    <0.0962527, -167.1287564>,
    <0.0925926, -167.1778641>,
    <0.0833333, -167.1287564>,
    <0.0833333, -167.2024179>,
    <0.1111111, -167.2024179>,
    <0.0833333, -167.1607154>,
    <0.0972340, -167.2024179>,
    <0.0974612, -167.1662209>,
    <0.9074074, -167.2357456>,
    <0.8888889, -167.2024179>,
    <0.9166667, -167.3024008>,
    <0.9166667, -167.2024179>,
    <0.9027330, -167.2522483>,
    <0.9166667, -167.2507837>,
    <0.9027896, -167.2024179>,
    <0.8981482, -167.1778641>,
    <0.8888889, -167.1287564>,
    <0.8888889, -167.2024179>,
    <0.9166667, -167.2024179>,
    <0.8888889, -167.1605801>,
    <0.9027896, -167.2024179>,
    <0.9031871, -167.1666727>,
    <0.1056582, -167.0842391>,
    <0.0947523, -167.0684463>,
    <0.1111111, -167.0684463>,
    <0.1111111, -167.1158246>,
    <0.1032549, -167.0684463>,
    <0.1111111, -167.0943971>,
    <0.1045003, -167.0966785>,
    <0.0963989, -167.0842391>,
    <0.0833333, -167.0684463>,
    <0.0947523, -167.0684463>,
    <0.1111111, -167.1158246>,
    <0.0893325, -167.0684463>,
    <0.1045003, -167.0966785>,
    <0.1024926, -167.1011247>,
    <0.0925926, -167.1000319>,
    <0.0833333, -167.0684463>,
    <0.1111111, -167.1158246>,
    <0.0833333, -167.1158246>,
    <0.1024926, -167.1011247>,
    <0.0966456, -167.1158246>,
    <0.0833333, -167.0954613>,
    <0.9074074, -167.1524837>,
    <0.8888889, -167.1158246>,
    <0.9166667, -167.1158246>,
    <0.9166667, -167.2258020>,
    <0.9022144, -167.1158246>,
    <0.9166667, -167.1673444>,
    <0.9024475, -167.1695056>,
    <0.8981482, -167.1000319>,
    <0.8888889, -167.0684463>,
    <0.9166667, -167.1158246>,
    <0.8888889, -167.1158246>,
    <0.9080364, -167.1011047>,
    <0.9022144, -167.1158246>,
    <0.8888889, -167.0943969>,
    <0.1018518, -167.2357456>,
    <0.0833333, -167.2024179>,
    <0.1111111, -167.3024008>,
    <0.1111111, -167.2024179>,
    <0.0971775, -167.2522483>,
    <0.1111111, -167.2507837>,
    <0.0972340, -167.2024179>,
    <0.0925926, -167.2690732>,
    <0.0833333, -167.2024179>,
    <0.0833333, -167.3024008>,
    <0.1111111, -167.3024008>,
    <0.0833333, -167.2507837>,
    <0.0972328, -167.3024008>,
    <0.0971775, -167.2522483>,
    <0.9074074, -167.3434849>,
    <0.8888889, -167.3024008>,
    <0.9166667, -167.4256532>,
    <0.9166667, -167.3024008>,
    <0.9027396, -167.3638575>,
    <0.9166667, -167.3627833>,
    <0.9027884, -167.3024008>,
    <0.8981482, -167.2690732>,
    <0.8888889, -167.2024179>,
    <0.8888889, -167.3024008>,
    <0.9166667, -167.3024008>,
    <0.8888889, -167.2507837>,
    <0.9027884, -167.3024008>,
    <0.9027330, -167.2522483>,
    <0.1018518, -167.1524837>,
    <0.0833333, -167.1158246>,
    <0.1111111, -167.1158246>,
    <0.1111111, -167.2258020>,
    <0.0966456, -167.1158246>,
    <0.1111111, -167.1673834>,
    <0.0968799, -167.1694582>,
    <0.0925926, -167.1891429>,
    <0.0833333, -167.1158246>,
    <0.1111111, -167.2258020>,
    <0.0833333, -167.2258020>,
    <0.0968799, -167.1694582>,
    <0.0972339, -167.2258020>,
    <0.0833333, -167.1670330>,
    <0.9074074, -167.2709932>,
    <0.8888889, -167.2258020>,
    <0.9166667, -167.2258020>,
    <0.9166667, -167.3613758>,
    <0.9027895, -167.2258020>,
    <0.9166667, -167.2924560>,
    <0.9027362, -167.2933857>,
    <0.8981482, -167.1891429>,
    <0.8888889, -167.1158246>,
    <0.9166667, -167.2258020>,
    <0.8888889, -167.2258020>,
    <0.9024475, -167.1695056>,
    <0.9027895, -167.2258020>,
    <0.8888889, -167.1673836>,
    <0.1018518, -167.3434849>,
    <0.0833333, -167.3024008>,
    <0.1111111, -167.4256532>,
    <0.1111111, -167.3024008>,
    <0.0971840, -167.3638575>,
    <0.1111111, -167.3627833>,
    <0.0972328, -167.3024008>,
    <0.0925926, -167.3845690>,
    <0.0833333, -167.3024008>,
    <0.0833333, -167.4256532>,
    <0.1111111, -167.4256532>,
    <0.0833333, -167.3627833>,
    <0.0972312, -167.4256532>,
    <0.0971840, -167.3638575>,
    <0.9074074, -167.4732541>,
    <0.8888889, -167.4256532>,
    <0.9166667, -167.5684558>,
    <0.9166667, -167.4256532>,
    <0.9027471, -167.4968970>,
    <0.9166667, -167.4961890>,
    <0.9027868, -167.4256532>,
    <0.8981482, -167.3845690>,
    <0.8888889, -167.3024008>,
    <0.8888889, -167.4256532>,
    <0.9166667, -167.4256532>,
    <0.8888889, -167.3627833>,
    <0.9027868, -167.4256532>,
    <0.9027396, -167.3638575>,
    <0.1018518, -167.2709932>,
    <0.0833333, -167.2258020>,
    <0.1111111, -167.2258020>,
    <0.1111111, -167.3613758>,
    <0.0972339, -167.2258020>,
    <0.1111111, -167.2924560>,
    <0.0971806, -167.2933857>,
    <0.0925926, -167.3161845>,
    <0.0833333, -167.2258020>,
    <0.1111111, -167.3613758>,
    <0.0833333, -167.3613758>,
    <0.0971806, -167.2933857>,
    <0.0972322, -167.3613758>,
    <0.0833333, -167.2924560>,
    <0.9074074, -167.4137323>,
    <0.8888889, -167.3613758>,
    <0.9166667, -167.3613758>,
    <0.9166667, -167.5184453>,
    <0.9027878, -167.3613758>,
    <0.9166667, -167.4391507>,
    <0.9027445, -167.4397221>,
    <0.8981482, -167.3161845>,
    <0.8888889, -167.2258020>,
    <0.9166667, -167.3613758>,
    <0.8888889, -167.3613758>,
    <0.9027362, -167.2933857>,
    <0.9027878, -167.3613758>,
    <0.8888889, -167.2924560>,
    <0.1018518, -167.4732541>,
    <0.0833333, -167.4256532>,
    <0.1111111, -167.5684558>,
    <0.1111111, -167.4256532>,
    <0.0971916, -167.4968970>,
    <0.1111111, -167.4961890>,
    <0.0972312, -167.4256532>,
    <0.0925926, -167.5208549>,
    <0.0833333, -167.4256532>,
    <0.0833333, -167.5684558>,
    <0.1111111, -167.5684558>,
    <0.0833333, -167.4961891>,
    <0.0972293, -167.5684558>,
    <0.0971916, -167.4968970>,
    <0.9074074, -167.6211112>,
    <0.8888889, -167.5684558>,
    <0.9166667, -167.7264218>,
    <0.9166667, -167.5684558>,
    <0.9027554, -167.6473117>,
    <0.9166667, -167.6468904>,
    <0.9027849, -167.5684558>,
    <0.8981482, -167.5208549>,
    <0.8888889, -167.4256532>,
    <0.8888889, -167.5684558>,
    <0.9166667, -167.5684558>,
    <0.8888889, -167.4961890>,
    <0.9027849, -167.5684558>,
    <0.9027471, -167.4968970>,
    <0.1018518, -167.6211112>,
    <0.0833333, -167.5684558>,
    <0.1111111, -167.7264218>,
    <0.1111111, -167.5684558>,
    <0.0971999, -167.6473117>,
    <0.1111111, -167.6468904>,
    <0.0972293, -167.5684558>,
    <0.0925926, -167.6737665>,
    <0.0833333, -167.5684558>,
    <0.0833333, -167.7264218>,
    <0.1111111, -167.7264218>,
    <0.0833333, -167.6468904>,
    <0.0972271, -167.7264218>,
    <0.0971999, -167.6473117>,
    <0.9074074, -167.7825485>,
    <0.8888889, -167.7264218>,
    <0.9166667, -167.8948019>,
    <0.9166667, -167.7264218>,
    <0.9027041, -167.8101654>,
    <0.9166667, -167.8064334>,
    <0.9027827, -167.7264218>,
    <0.8981482, -167.6737665>,
    <0.8888889, -167.5684558>,
    <0.8888889, -167.7264218>,
    <0.9166667, -167.7264218>,
    <0.8888889, -167.6468904>,
    <0.9027827, -167.7264218>,
    <0.9027554, -167.6473117>,
    <0.1018518, -167.4137323>,
    <0.0833333, -167.3613758>,
    <0.1111111, -167.3613758>,
    <0.1111111, -167.5184453>,
    <0.0972322, -167.3613758>,
    <0.1111111, -167.4391506>,
    <0.0971889, -167.4397221>,
    <0.0925926, -167.4660888>,
    <0.0833333, -167.3613758>,
    <0.1111111, -167.5184453>,
    <0.0833333, -167.5184453>,
    <0.0971889, -167.4397221>,
    <0.0972301, -167.5184453>,
    <0.0833333, -167.4391507>,
    <0.9074074, -167.5763713>,
    <0.8888889, -167.5184453>,
    <0.9166667, -167.5184453>,
    <0.9166667, -167.6922232>,
    <0.9027856, -167.5184453>,
    <0.9166667, -167.6048705>,
    <0.9027535, -167.6051824>,
    <0.8981482, -167.4660888>,
    <0.8888889, -167.3613758>,
    <0.9166667, -167.5184453>,
    <0.8888889, -167.5184453>,
    <0.9027445, -167.4397221>,
    <0.9027856, -167.5184453>,
    <0.8888889, -167.4391507>,
    <0.1018518, -167.7825485>,
    <0.0833333, -167.7264218>,
    <0.1111111, -167.8948019>,
    <0.1111111, -167.7264218>,
    <0.0971559, -167.8102099>,
    <0.1111111, -167.8064902>,
    <0.0972271, -167.7264218>,
    <0.0925926, -167.8386752>,
    <0.0833333, -167.7264218>,
    <0.0833333, -167.8948019>,
    <0.1111111, -167.8948019>,
    <0.0833333, -167.8064909>,
    <0.0972395, -167.8948019>,
    <0.0971559, -167.8102099>,
    <0.9074074, -167.9526834>,
    <0.8888889, -167.8948019>,
    <0.9166667, -168.0684463>,
    <0.9166667, -167.8948019>,
    <0.8992453, -167.9595422>,
    <0.9166667, -167.9521780>,
    <0.9027991, -167.8948019>,
    <0.8981482, -167.8386752>,
    <0.8888889, -167.7264218>,
    <0.8888889, -167.8948019>,
    <0.9166667, -167.8948019>,
    <0.8888889, -167.8064163>,
    <0.9027991, -167.8948019>,
    <0.9027041, -167.8101654>,
    <0.1152711, -167.1123151>,
    <0.1235909, -167.1040945>,
    <0.1111111, -167.1040945>,
    <0.1111111, -167.1287564>,
    <0.1175219, -167.1040945>,
    <0.1111111, -167.1157357>,
    <0.1143272, -167.1224010>,
    <0.1018518, -167.9526834>,
    <0.0833333, -167.8948019>,
    <0.1111111, -168.0684463>,
    <0.1111111, -167.8948019>,
    <0.0936969, -167.9595867>,
    <0.1111111, -167.9524907>,
    <0.0972395, -167.8948019>,
    <0.0925926, -168.0105648>,
    <0.0833333, -167.8948019>,
    <0.0833333, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.0833333, -167.9524723>,
    <0.0972222, -168.0684463>,
    <0.0936969, -167.9595867>,
    <0.8981482, -168.0105648>,
    <0.8888889, -167.8948019>,
    <0.8888889, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.8888889, -167.9521104>,
    <0.9027778, -168.0684463>,
    <0.8992453, -167.9595422>,
    <0.1018518, -167.5763713>,
    <0.0833333, -167.5184453>,
    <0.1111111, -167.5184453>,
    <0.1111111, -167.6922232>,
    <0.0972301, -167.5184453>,
    <0.1111111, -167.6048705>,
    <0.0971979, -167.6051824>,
    <0.0925926, -167.6342972>,
    <0.0833333, -167.5184453>,
    <0.1111111, -167.6922232>,
    <0.0833333, -167.6922232>,
    <0.0971979, -167.6051824>,
    <0.0972276, -167.6922232>,
    <0.0833333, -167.6048705>,
    <0.9074074, -167.7539575>,
    <0.8888889, -167.6922232>,
    <0.9166667, -167.6922232>,
    <0.9166667, -167.8774261>,
    <0.9027832, -167.6922232>,
    <0.9166667, -167.7805818>,
    <0.9027006, -167.7843100>,
    <0.8981482, -167.6342972>,
    <0.8888889, -167.5184453>,
    <0.9166667, -167.6922232>,
    <0.8888889, -167.6922232>,
    <0.9027535, -167.6051824>,
    <0.9027832, -167.6922232>,
    <0.8888889, -167.6048705>,
    <0.1018518, -167.7539575>,
    <0.0833333, -167.6922232>,
    <0.1111111, -167.6922232>,
    <0.1111111, -167.8774261>,
    <0.0972276, -167.6922232>,
    <0.1111111, -167.7806351>,
    <0.0971524, -167.7843593>,
    <0.0925926, -167.8156918>,
    <0.0833333, -167.6922232>,
    <0.1111111, -167.8774261>,
    <0.0833333, -167.8774261>,
    <0.0971524, -167.7843593>,
    <0.0972398, -167.8774261>,
    <0.0833333, -167.7806356>,
    <0.9074074, -167.9410995>,
    <0.8888889, -167.8774261>,
    <0.9166667, -167.8774261>,
    <0.9166667, -168.0684463>,
    <0.9027994, -167.8774261>,
    <0.9166667, -167.9661382>,
    <0.9022529, -167.9693270>,
    <0.8981482, -167.8156918>,
    <0.8888889, -167.6922232>,
    <0.9166667, -167.8774261>,
    <0.8888889, -167.8774261>,
    <0.9027006, -167.7843100>,
    <0.9027994, -167.8774261>,
    <0.8888889, -167.7805659>,
    <0.1018518, -167.9410995>,
    <0.0833333, -167.8774261>,
    <0.1111111, -167.8774261>,
    <0.1111111, -168.0684463>,
    <0.0972398, -167.8774261>,
    <0.1111111, -167.9644214>,
    <0.0968024, -167.9700492>,
    <0.0925926, -168.0047729>,
    <0.0833333, -167.8774261>,
    <0.1111111, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0968024, -167.9700492>,
    <0.0979342, -168.0684463>,
    <0.0833333, -167.9641320>,
    <0.8981482, -168.0047729>,
    <0.8888889, -167.8774261>,
    <0.9166667, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.9022529, -167.9693270>,
    <0.9041714, -168.0684463>,
    <0.8888889, -167.9653134>,
    <0.8837895, -167.1123151>,
    <0.8735908, -167.1040945>,
    <0.8888889, -167.1287564>,
    <0.8888889, -167.1040945>,
    <0.8851529, -167.1227337>,
    <0.8888889, -167.1196785>,
    <0.8814198, -167.1040945>,
    <0.8834360, -167.0842391>,
    <0.8725301, -167.0684463>,
    <0.8888889, -167.0684463>,
    <0.8888889, -167.1158246>,
    <0.8810325, -167.0684463>,
    <0.8888889, -167.0943969>,
    <0.8822783, -167.0966789>,
    <0.1337896, -167.1123151>,
    <0.1235910, -167.1040945>,
    <0.1388889, -167.1287564>,
    <0.1388889, -167.1040945>,
    <0.1351531, -167.1227339>,
    <0.1388889, -167.1196840>,
    <0.1314198, -167.1040945>,
    <0.1245303, -167.1205358>,
    <0.1235909, -167.1040945>,
    <0.1111111, -167.1287564>,
    <0.1388889, -167.1287564>,
    <0.1143272, -167.1224010>,
    <0.1241882, -167.1287564>,
    <0.1351531, -167.1227339>,
    <0.8745303, -167.1205358>,
    <0.8735908, -167.1040945>,
    <0.8611111, -167.1287564>,
    <0.8888889, -167.1287564>,
    <0.8644072, -167.1222427>,
    <0.8743369, -167.1287564>,
    <0.8851529, -167.1227337>,
    <0.8796296, -167.1533103>,
    <0.8611111, -167.1287564>,
    <0.8888889, -167.2024179>,
    <0.8888889, -167.1287564>,
    <0.8754094, -167.1666728>,
    <0.8888889, -167.1605801>,
    <0.8743369, -167.1287564>,
    <0.8652710, -167.1123151>,
    <0.8735908, -167.1040945>,
    <0.8611111, -167.1040945>,
    <0.8611111, -167.1287564>,
    <0.8675219, -167.1040945>,
    <0.8611111, -167.1196763>,
    <0.8644072, -167.1222427>,
    <0.8741794, -167.0842391>,
    <0.8611162, -167.0684463>,
    <0.8725332, -167.0684463>,
    <0.8888889, -167.1158246>,
    <0.8671141, -167.0684463>,
    <0.8822795, -167.0966789>,
    <0.8802718, -167.1011244>,
    <0.1296296, -167.1533103>,
    <0.1111111, -167.1287564>,
    <0.1388889, -167.2024179>,
    <0.1388889, -167.1287564>,
    <0.1252390, -167.1662210>,
    <0.1388889, -167.1605805>,
    <0.1241882, -167.1287564>,
    <0.1203704, -167.1778641>,
    <0.1111111, -167.1287564>,
    <0.1111111, -167.2024179>,
    <0.1388889, -167.2024179>,
    <0.1111111, -167.1607152>,
    <0.1250118, -167.2024179>,
    <0.1252390, -167.1662210>,
    <0.8796296, -167.2357456>,
    <0.8611111, -167.2024179>,
    <0.8888889, -167.3024008>,
    <0.8888889, -167.2024179>,
    <0.8749553, -167.2522483>,
    <0.8888889, -167.2507837>,
    <0.8750118, -167.2024179>,
    <0.8703704, -167.1778641>,
    <0.8611111, -167.1287564>,
    <0.8611111, -167.2024179>,
    <0.8888889, -167.2024179>,
    <0.8611111, -167.1605800>,
    <0.8750118, -167.2024179>,
    <0.8754094, -167.1666728>,
    <0.1334370, -167.0842391>,
    <0.1225331, -167.0684463>,
    <0.1388889, -167.0684463>,
    <0.1388889, -167.1158246>,
    <0.1310312, -167.0684463>,
    <0.1388889, -167.0945275>,
    <0.1322816, -167.0966849>,
    <0.1241767, -167.0842391>,
    <0.1111111, -167.0684463>,
    <0.1225301, -167.0684463>,
    <0.1388889, -167.1158246>,
    <0.1171051, -167.0684463>,
    <0.1322803, -167.0966849>,
    <0.1302586, -167.1011047>,
    <0.1203704, -167.1000319>,
    <0.1111111, -167.0684463>,
    <0.1388889, -167.1158246>,
    <0.1111111, -167.1158246>,
    <0.1302586, -167.1011047>,
    <0.1244365, -167.1158246>,
    <0.1111111, -167.0943971>,
    <0.8796296, -167.1524837>,
    <0.8611111, -167.1158246>,
    <0.8888889, -167.1158246>,
    <0.8888889, -167.2258020>,
    <0.8744239, -167.1158246>,
    <0.8888889, -167.1673836>,
    <0.8746583, -167.1694605>,
    <0.8703704, -167.1000319>,
    <0.8611111, -167.0684463>,
    <0.8888889, -167.1158246>,
    <0.8611111, -167.1158246>,
    <0.8802702, -167.1011244>,
    <0.8744239, -167.1158246>,
    <0.8611111, -167.0954672>,
    <0.1296296, -167.2357456>,
    <0.1111111, -167.2024179>,
    <0.1388889, -167.3024008>,
    <0.1388889, -167.2024179>,
    <0.1249552, -167.2522483>,
    <0.1388889, -167.2507837>,
    <0.1250118, -167.2024179>,
    <0.1203704, -167.2690732>,
    <0.1111111, -167.2024179>,
    <0.1111111, -167.3024008>,
    <0.1388889, -167.3024008>,
    <0.1111111, -167.2507837>,
    <0.1250106, -167.3024008>,
    <0.1249552, -167.2522483>,
    <0.8796296, -167.3434849>,
    <0.8611111, -167.3024008>,
    <0.8888889, -167.4256532>,
    <0.8888889, -167.3024008>,
    <0.8749618, -167.3638575>,
    <0.8888889, -167.3627833>,
    <0.8750106, -167.3024008>,
    <0.8703704, -167.2690732>,
    <0.8611111, -167.2024179>,
    <0.8611111, -167.3024008>,
    <0.8888889, -167.3024008>,
    <0.8611111, -167.2507837>,
    <0.8750106, -167.3024008>,
    <0.8749553, -167.2522483>,
    <0.1296296, -167.1524837>,
    <0.1111111, -167.1158246>,
    <0.1388889, -167.1158246>,
    <0.1388889, -167.2258020>,
    <0.1244365, -167.1158246>,
    <0.1388889, -167.1673444>,
    <0.1246697, -167.1695055>,
    <0.1203704, -167.1891429>,
    <0.1111111, -167.1158246>,
    <0.1388889, -167.2258020>,
    <0.1111111, -167.2258020>,
    <0.1246697, -167.1695055>,
    <0.1250117, -167.2258020>,
    <0.1111111, -167.1673834>,
    <0.8796296, -167.2709932>,
    <0.8611111, -167.2258020>,
    <0.8888889, -167.2258020>,
    <0.8888889, -167.3613758>,
    <0.8750117, -167.2258020>,
    <0.8888889, -167.2924560>,
    <0.8749584, -167.2933857>,
    <0.8703704, -167.1891429>,
    <0.8611111, -167.1158246>,
    <0.8888889, -167.2258020>,
    <0.8611111, -167.2258020>,
    <0.8746583, -167.1694605>,
    <0.8750117, -167.2258020>,
    <0.8611111, -167.1670696>,
    <0.1296296, -167.3434849>,
    <0.1111111, -167.3024008>,
    <0.1388889, -167.4256532>,
    <0.1388889, -167.3024008>,
    <0.1249618, -167.3638575>,
    <0.1388889, -167.3627833>,
    <0.1250106, -167.3024008>,
    <0.1203704, -167.3845690>,
    <0.1111111, -167.3024008>,
    <0.1111111, -167.4256532>,
    <0.1388889, -167.4256532>,
    <0.1111111, -167.3627833>,
    <0.1250090, -167.4256532>,
    <0.1249618, -167.3638575>,
    <0.8796296, -167.4732541>,
    <0.8611111, -167.4256532>,
    <0.8888889, -167.5684558>,
    <0.8888889, -167.4256532>,
    <0.8749694, -167.4968970>,
    <0.8888889, -167.4961890>,
    <0.8750090, -167.4256532>,
    <0.8703704, -167.3845690>,
    <0.8611111, -167.3024008>,
    <0.8611111, -167.4256532>,
    <0.8888889, -167.4256532>,
    <0.8611111, -167.3627833>,
    <0.8750090, -167.4256532>,
    <0.8749618, -167.3638575>,
    <0.1296296, -167.2709932>,
    <0.1111111, -167.2258020>,
    <0.1388889, -167.2258020>,
    <0.1388889, -167.3613758>,
    <0.1250117, -167.2258020>,
    <0.1388889, -167.2924560>,
    <0.1249584, -167.2933857>,
    <0.1203704, -167.3161845>,
    <0.1111111, -167.2258020>,
    <0.1388889, -167.3613758>,
    <0.1111111, -167.3613758>,
    <0.1249584, -167.2933857>,
    <0.1250100, -167.3613758>,
    <0.1111111, -167.2924560>,
    <0.8796296, -167.4137323>,
    <0.8611111, -167.3613758>,
    <0.8888889, -167.3613758>,
    <0.8888889, -167.5184453>,
    <0.8750100, -167.3613758>,
    <0.8888889, -167.4391507>,
    <0.8749667, -167.4397221>,
    <0.8703704, -167.3161845>,
    <0.8611111, -167.2258020>,
    <0.8888889, -167.3613758>,
    <0.8611111, -167.3613758>,
    <0.8749584, -167.2933857>,
    <0.8750100, -167.3613758>,
    <0.8611111, -167.2924560>,
    <0.1296296, -167.4732541>,
    <0.1111111, -167.4256532>,
    <0.1388889, -167.5684558>,
    <0.1388889, -167.4256532>,
    <0.1249694, -167.4968970>,
    <0.1388889, -167.4961890>,
    <0.1250090, -167.4256532>,
    <0.1203704, -167.5208549>,
    <0.1111111, -167.4256532>,
    <0.1111111, -167.5684558>,
    <0.1388889, -167.5684558>,
    <0.1111111, -167.4961890>,
    <0.1250071, -167.5684558>,
    <0.1249694, -167.4968970>,
    <0.8796296, -167.6211112>,
    <0.8611111, -167.5684558>,
    <0.8888889, -167.7264218>,
    <0.8888889, -167.5684558>,
    <0.8749776, -167.6473117>,
    <0.8888889, -167.6468904>,
    <0.8750071, -167.5684558>,
    <0.8703704, -167.5208549>,
    <0.8611111, -167.4256532>,
    <0.8611111, -167.5684558>,
    <0.8888889, -167.5684558>,
    <0.8611111, -167.4961890>,
    <0.8750071, -167.5684558>,
    <0.8749694, -167.4968970>,
    <0.1296296, -167.6211112>,
    <0.1111111, -167.5684558>,
    <0.1388889, -167.7264218>,
    <0.1388889, -167.5684558>,
    <0.1249776, -167.6473117>,
    <0.1388889, -167.6468904>,
    <0.1250071, -167.5684558>,
    <0.1203704, -167.6737665>,
    <0.1111111, -167.5684558>,
    <0.1111111, -167.7264218>,
    <0.1388889, -167.7264218>,
    <0.1111111, -167.6468904>,
    <0.1250049, -167.7264218>,
    <0.1249776, -167.6473117>,
    <0.8796296, -167.7825485>,
    <0.8611111, -167.7264218>,
    <0.8888889, -167.8948019>,
    <0.8888889, -167.7264218>,
    <0.8749259, -167.8101628>,
    <0.8888889, -167.8064163>,
    <0.8750049, -167.7264218>,
    <0.8703704, -167.6737665>,
    <0.8611111, -167.5684558>,
    <0.8611111, -167.7264218>,
    <0.8888889, -167.7264218>,
    <0.8611111, -167.6468904>,
    <0.8750049, -167.7264218>,
    <0.8749776, -167.6473117>,
    <0.1296296, -167.4137323>,
    <0.1111111, -167.3613758>,
    <0.1388889, -167.3613758>,
    <0.1388889, -167.5184453>,
    <0.1250100, -167.3613758>,
    <0.1388889, -167.4391507>,
    <0.1249667, -167.4397221>,
    <0.1203704, -167.4660888>,
    <0.1111111, -167.3613758>,
    <0.1388889, -167.5184453>,
    <0.1111111, -167.5184453>,
    <0.1249667, -167.4397221>,
    <0.1250078, -167.5184453>,
    <0.1111111, -167.4391506>,
    <0.8796296, -167.5763713>,
    <0.8611111, -167.5184453>,
    <0.8888889, -167.5184453>,
    <0.8888889, -167.6922232>,
    <0.8750079, -167.5184453>,
    <0.8888889, -167.6048705>,
    <0.8749757, -167.6051824>,
    <0.8703704, -167.4660888>,
    <0.8611111, -167.3613758>,
    <0.8888889, -167.5184453>,
    <0.8611111, -167.5184453>,
    <0.8749667, -167.4397221>,
    <0.8750079, -167.5184453>,
    <0.8611111, -167.4391506>,
    <0.1296296, -167.7825485>,
    <0.1111111, -167.7264218>,
    <0.1388889, -167.8948019>,
    <0.1388889, -167.7264218>,
    <0.1249350, -167.8102176>,
    <0.1388889, -167.8064863>,
    <0.1250049, -167.7264218>,
    <0.1203704, -167.8386752>,
    <0.1111111, -167.7264218>,
    <0.1111111, -167.8948019>,
    <0.1388889, -167.8948019>,
    <0.1111111, -167.8064902>,
    <0.1250165, -167.8948019>,
    <0.1249350, -167.8102176>,
    <0.8796296, -167.9526834>,
    <0.8611111, -167.8948019>,
    <0.8888889, -168.0684463>,
    <0.8888889, -167.8948019>,
    <0.8714668, -167.9595373>,
    <0.8888889, -167.9521104>,
    <0.8750215, -167.8948019>,
    <0.8703704, -167.8386752>,
    <0.8611111, -167.7264218>,
    <0.8611111, -167.8948019>,
    <0.8888889, -167.8948019>,
    <0.8611111, -167.8063982>,
    <0.8750215, -167.8948019>,
    <0.8749259, -167.8101628>,
    <0.1296296, -167.9526834>,
    <0.1111111, -167.8948019>,
    <0.1388889, -168.0684463>,
    <0.1388889, -167.8948019>,
    <0.1214757, -167.9595930>,
    <0.1388889, -167.9525007>,
    <0.1250165, -167.8948019>,
    <0.1203704, -168.0105648>,
    <0.1111111, -167.8948019>,
    <0.1111111, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1111111, -167.9524907>,
    <0.1250000, -168.0684463>,
    <0.1214757, -167.9595930>,
    <0.8703704, -168.0105648>,
    <0.8611111, -167.8948019>,
    <0.8611111, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8611111, -167.9520428>,
    <0.8750000, -168.0684463>,
    <0.8714668, -167.9595373>,
    <0.1296296, -167.5763713>,
    <0.1111111, -167.5184453>,
    <0.1388889, -167.5184453>,
    <0.1388889, -167.6922232>,
    <0.1250078, -167.5184453>,
    <0.1388889, -167.6048705>,
    <0.1249757, -167.6051824>,
    <0.1203704, -167.6342972>,
    <0.1111111, -167.5184453>,
    <0.1388889, -167.6922232>,
    <0.1111111, -167.6922232>,
    <0.1249757, -167.6051824>,
    <0.1250054, -167.6922232>,
    <0.1111111, -167.6048705>,
    <0.8796296, -167.7539575>,
    <0.8611111, -167.6922232>,
    <0.8888889, -167.6922232>,
    <0.8888889, -167.8774261>,
    <0.8750054, -167.6922232>,
    <0.8888889, -167.7805659>,
    <0.8749224, -167.7843072>,
    <0.8703704, -167.6342972>,
    <0.8611111, -167.5184453>,
    <0.8888889, -167.6922232>,
    <0.8611111, -167.6922232>,
    <0.8749757, -167.6051824>,
    <0.8750054, -167.6922232>,
    <0.8611111, -167.6048705>,
    <0.1296296, -167.7539575>,
    <0.1111111, -167.6922232>,
    <0.1388889, -167.6922232>,
    <0.1388889, -167.8774261>,
    <0.1250054, -167.6922232>,
    <0.1388889, -167.7806315>,
    <0.1249315, -167.7843678>,
    <0.1203704, -167.8156918>,
    <0.1111111, -167.6922232>,
    <0.1388889, -167.8774261>,
    <0.1111111, -167.8774261>,
    <0.1249315, -167.7843678>,
    <0.1250168, -167.8774261>,
    <0.1111111, -167.7806351>,
    <0.8796296, -167.9410995>,
    <0.8611111, -167.8774261>,
    <0.8888889, -167.8774261>,
    <0.8888889, -168.0684463>,
    <0.8750218, -167.8774261>,
    <0.8888889, -167.9653134>,
    <0.8744798, -167.9693587>,
    <0.8703704, -167.8156918>,
    <0.8611111, -167.6922232>,
    <0.8888889, -167.8774261>,
    <0.8611111, -167.8774261>,
    <0.8749224, -167.7843072>,
    <0.8750218, -167.8774261>,
    <0.8611111, -167.7805491>,
    <0.1296296, -167.9410995>,
    <0.1111111, -167.8774261>,
    <0.1388889, -167.8774261>,
    <0.1388889, -168.0684463>,
    <0.1250168, -167.8774261>,
    <0.1388889, -167.9640898>,
    <0.1247654, -167.9713228>,
    <0.1203704, -168.0047729>,
    <0.1111111, -167.8774261>,
    <0.1388889, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1247654, -167.9713228>,
    <0.1256949, -168.0684463>,
    <0.1111111, -167.9644214>,
    <0.8703704, -168.0047729>,
    <0.8611111, -167.8774261>,
    <0.8888889, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8744798, -167.9693587>,
    <0.8763923, -168.0684463>,
    <0.8611111, -167.9660833>,
    <0.1430488, -167.1123151>,
    <0.1513685, -167.1040945>,
    <0.1388889, -167.1040945>,
    <0.1388889, -167.1287564>,
    <0.1450712, -167.1040945>,
    <0.1388889, -167.1196840>,
    <0.1418213, -167.1229615>,
    <0.8560118, -167.1123151>,
    <0.8458132, -167.1040945>,
    <0.8611111, -167.1287564>,
    <0.8611111, -167.1040945>,
    <0.8576403, -167.1231611>,
    <0.8611111, -167.1196763>,
    <0.8538344, -167.1040945>,
    <0.8556582, -167.0842391>,
    <0.8447523, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.8611111, -167.1158246>,
    <0.8529317, -167.0684463>,
    <0.8611111, -167.0954672>,
    <0.8540108, -167.0952605>,
    <0.1654300, -167.1123151>,
    <0.1629568, -167.1040945>,
    <0.1666667, -167.1287564>,
    <0.1666667, -167.1040945>,
    <0.1656645, -167.1220941>,
    <0.1666667, -167.1157282>,
    <0.1644246, -167.1040945>,
    <0.1603307, -167.1123151>,
    <0.1629568, -167.1040945>,
    <0.1513685, -167.1040945>,
    <0.1666667, -167.1287564>,
    <0.1565698, -167.1040945>,
    <0.1629668, -167.1227920>,
    <0.1656645, -167.1220941>,
    <0.1523080, -167.1205358>,
    <0.1513685, -167.1040945>,
    <0.1388889, -167.1287564>,
    <0.1666667, -167.1287564>,
    <0.1418213, -167.1229615>,
    <0.1519567, -167.1287564>,
    <0.1629668, -167.1227920>,
    <0.8467525, -167.1205421>,
    <0.8458131, -167.1041136>,
    <0.8333333, -167.1287564>,
    <0.8611111, -167.1287564>,
    <0.8365042, -167.1224952>,
    <0.8464951, -167.1287564>,
    <0.8576403, -167.1231655>,
    <0.8384455, -167.1123279>,
    <0.8458131, -167.1041136>,
    <0.8361900, -167.1041136>,
    <0.8333333, -167.1287564>,
    <0.8417899, -167.1041136>,
    <0.8343509, -167.1199784>,
    <0.8365042, -167.1224952>,
    <0.8518519, -167.1533103>,
    <0.8333333, -167.1287564>,
    <0.8611111, -167.2024179>,
    <0.8611111, -167.1287564>,
    <0.8475545, -167.1664684>,
    <0.8611111, -167.1605800>,
    <0.8464951, -167.1287564>,
    <0.8342856, -167.1123215>,
    <0.8361901, -167.1041136>,
    <0.8333333, -167.1040945>,
    <0.8333333, -167.1287564>,
    <0.8350866, -167.1041062>,
    <0.8333333, -167.1186954>,
    <0.8343509, -167.1199784>,
    <0.8464017, -167.0842391>,
    <0.8333385, -167.0684463>,
    <0.8447554, -167.0684463>,
    <0.8611111, -167.1158246>,
    <0.8390469, -167.0684463>,
    <0.8540121, -167.0952605>,
    <0.8525601, -167.1012372>,
    <0.1574074, -167.1533103>,
    <0.1388889, -167.1287564>,
    <0.1666667, -167.2024179>,
    <0.1666667, -167.1287564>,
    <0.1531871, -167.1666726>,
    <0.1666667, -167.1607154>,
    <0.1519567, -167.1287564>,
    <0.1481481, -167.1778641>,
    <0.1388889, -167.1287564>,
    <0.1388889, -167.2024179>,
    <0.1666667, -167.2024179>,
    <0.1388889, -167.1605805>,
    <0.1527896, -167.2024179>,
    <0.1531871, -167.1666726>,
    <0.8518519, -167.2357456>,
    <0.8333333, -167.2024179>,
    <0.8611111, -167.3024008>,
    <0.8611111, -167.2024179>,
    <0.8471775, -167.2522483>,
    <0.8611111, -167.2507837>,
    <0.8472340, -167.2024179>,
    <0.8425926, -167.1778641>,
    <0.8333333, -167.1287564>,
    <0.8333333, -167.2024179>,
    <0.8611111, -167.2024179>,
    <0.8333333, -167.1601023>,
    <0.8472340, -167.2024179>,
    <0.8475545, -167.1664684>,
    <0.1612147, -167.0842391>,
    <0.1503109, -167.0684463>,
    <0.1666667, -167.0684463>,
    <0.1666667, -167.1158246>,
    <0.1584888, -167.0684463>,
    <0.1666667, -167.0950187>,
    <0.1596341, -167.0954532>,
    <0.1519545, -167.0842391>,
    <0.1388889, -167.0684463>,
    <0.1503079, -167.0684463>,
    <0.1666667, -167.1158246>,
    <0.1445984, -167.0684463>,
    <0.1596328, -167.0954532>,
    <0.1580759, -167.1011721>,
    <0.1481481, -167.1000319>,
    <0.1388889, -167.0684463>,
    <0.1666667, -167.1158246>,
    <0.1388889, -167.1158246>,
    <0.1580759, -167.1011721>,
    <0.1522077, -167.1158246>,
    <0.1388889, -167.0945275>,
    <0.8518519, -167.1524837>,
    <0.8333333, -167.1158246>,
    <0.8611111, -167.1158246>,
    <0.8611111, -167.2258020>,
    <0.8466365, -167.1158246>,
    <0.8611111, -167.1670696>,
    <0.8468805, -167.1694605>,
    <0.8425926, -167.1000319>,
    <0.8333333, -167.0684463>,
    <0.8611111, -167.1158246>,
    <0.8333333, -167.1158246>,
    <0.8525585, -167.1012372>,
    <0.8466365, -167.1158246>,
    <0.8333333, -167.0954675>,
    <0.1574074, -167.2357456>,
    <0.1388889, -167.2024179>,
    <0.1666667, -167.3024008>,
    <0.1666667, -167.2024179>,
    <0.1527330, -167.2522483>,
    <0.1666667, -167.2507837>,
    <0.1527896, -167.2024179>,
    <0.1481481, -167.2690732>,
    <0.1388889, -167.2024179>,
    <0.1388889, -167.3024008>,
    <0.1666667, -167.3024008>,
    <0.1388889, -167.2507837>,
    <0.1527884, -167.3024008>,
    <0.1527330, -167.2522483>,
    <0.8518519, -167.3434849>,
    <0.8333333, -167.3024008>,
    <0.8611111, -167.4256532>,
    <0.8611111, -167.3024008>,
    <0.8471840, -167.3638575>,
    <0.8611111, -167.3627833>,
    <0.8472328, -167.3024008>,
    <0.8425926, -167.2690732>,
    <0.8333333, -167.2024179>,
    <0.8333333, -167.3024008>,
    <0.8611111, -167.3024008>,
    <0.8333333, -167.2507837>,
    <0.8472328, -167.3024008>,
    <0.8471775, -167.2522483>,
    <0.1574074, -167.1524837>,
    <0.1388889, -167.1158246>,
    <0.1666667, -167.1158246>,
    <0.1666667, -167.2258020>,
    <0.1522077, -167.1158246>,
    <0.1666667, -167.1671626>,
    <0.1524464, -167.1695015>,
    <0.1481481, -167.1891429>,
    <0.1388889, -167.1158246>,
    <0.1666667, -167.2258020>,
    <0.1388889, -167.2258020>,
    <0.1524464, -167.1695015>,
    <0.1527895, -167.2258020>,
    <0.1388889, -167.1673444>,
    <0.8518519, -167.2709932>,
    <0.8333333, -167.2258020>,
    <0.8611111, -167.2258020>,
    <0.8611111, -167.3613758>,
    <0.8472340, -167.2258020>,
    <0.8611111, -167.2924560>,
    <0.8471806, -167.2933857>,
    <0.8425926, -167.1891429>,
    <0.8333333, -167.1158246>,
    <0.8611111, -167.2258020>,
    <0.8333333, -167.2258020>,
    <0.8468805, -167.1694605>,
    <0.8472340, -167.2258020>,
    <0.8333333, -167.1670695>,
    <0.1574074, -167.3434849>,
    <0.1388889, -167.3024008>,
    <0.1666667, -167.4256532>,
    <0.1666667, -167.3024008>,
    <0.1527396, -167.3638575>,
    <0.1666667, -167.3627833>,
    <0.1527884, -167.3024008>,
    <0.1481481, -167.3845690>,
    <0.1388889, -167.3024008>,
    <0.1388889, -167.4256532>,
    <0.1666667, -167.4256532>,
    <0.1388889, -167.3627833>,
    <0.1527868, -167.4256532>,
    <0.1527396, -167.3638575>,
    <0.8518519, -167.4732541>,
    <0.8333333, -167.4256532>,
    <0.8611111, -167.5684558>,
    <0.8611111, -167.4256532>,
    <0.8471916, -167.4968970>,
    <0.8611111, -167.4961890>,
    <0.8472312, -167.4256532>,
    <0.8425926, -167.3845690>,
    <0.8333333, -167.3024008>,
    <0.8333333, -167.4256532>,
    <0.8611111, -167.4256532>,
    <0.8333333, -167.3627833>,
    <0.8472312, -167.4256532>,
    <0.8471840, -167.3638575>,
    <0.1574074, -167.2709932>,
    <0.1388889, -167.2258020>,
    <0.1666667, -167.2258020>,
    <0.1666667, -167.3613758>,
    <0.1527895, -167.2258020>,
    <0.1666667, -167.2924560>,
    <0.1527361, -167.2933857>,
    <0.1481481, -167.3161845>,
    <0.1388889, -167.2258020>,
    <0.1666667, -167.3613758>,
    <0.1388889, -167.3613758>,
    <0.1527361, -167.2933857>,
    <0.1527878, -167.3613758>,
    <0.1388889, -167.2924560>,
    <0.8518519, -167.4137323>,
    <0.8333333, -167.3613758>,
    <0.8611111, -167.3613758>,
    <0.8611111, -167.5184453>,
    <0.8472322, -167.3613758>,
    <0.8611111, -167.4391506>,
    <0.8471889, -167.4397221>,
    <0.8425926, -167.3161845>,
    <0.8333333, -167.2258020>,
    <0.8611111, -167.3613758>,
    <0.8333333, -167.3613758>,
    <0.8471806, -167.2933857>,
    <0.8472322, -167.3613758>,
    <0.8333333, -167.2924560>,
    <0.1574074, -167.4732541>,
    <0.1388889, -167.4256532>,
    <0.1666667, -167.5684558>,
    <0.1666667, -167.4256532>,
    <0.1527471, -167.4968970>,
    <0.1666667, -167.4961890>,
    <0.1527868, -167.4256532>,
    <0.1481481, -167.5208549>,
    <0.1388889, -167.4256532>,
    <0.1388889, -167.5684558>,
    <0.1666667, -167.5684558>,
    <0.1388889, -167.4961890>,
    <0.1527848, -167.5684558>,
    <0.1527471, -167.4968970>,
    <0.8518519, -167.6211112>,
    <0.8333333, -167.5684558>,
    <0.8611111, -167.7264218>,
    <0.8611111, -167.5684558>,
    <0.8471999, -167.6473117>,
    <0.8611111, -167.6468904>,
    <0.8472293, -167.5684558>,
    <0.8425926, -167.5208549>,
    <0.8333333, -167.4256532>,
    <0.8333333, -167.5684558>,
    <0.8611111, -167.5684558>,
    <0.8333333, -167.4961891>,
    <0.8472293, -167.5684558>,
    <0.8471916, -167.4968970>,
    <0.1574074, -167.6211112>,
    <0.1388889, -167.5684558>,
    <0.1666667, -167.7264218>,
    <0.1666667, -167.5684558>,
    <0.1527554, -167.6473117>,
    <0.1666667, -167.6468904>,
    <0.1527848, -167.5684558>,
    <0.1481481, -167.6737665>,
    <0.1388889, -167.5684558>,
    <0.1388889, -167.7264218>,
    <0.1666667, -167.7264218>,
    <0.1388889, -167.6468904>,
    <0.1527826, -167.7264218>,
    <0.1527554, -167.6473117>,
    <0.8518519, -167.7825485>,
    <0.8333333, -167.7264218>,
    <0.8611111, -167.8948019>,
    <0.8611111, -167.7264218>,
    <0.8471479, -167.8101615>,
    <0.8611111, -167.8063982>,
    <0.8472271, -167.7264218>,
    <0.8425926, -167.6737665>,
    <0.8333333, -167.5684558>,
    <0.8333333, -167.7264218>,
    <0.8611111, -167.7264218>,
    <0.8333333, -167.6468904>,
    <0.8472271, -167.7264218>,
    <0.8471999, -167.6473117>,
    <0.1574074, -167.4137323>,
    <0.1388889, -167.3613758>,
    <0.1666667, -167.3613758>,
    <0.1666667, -167.5184453>,
    <0.1527878, -167.3613758>,
    <0.1666667, -167.4391507>,
    <0.1527444, -167.4397221>,
    <0.1481481, -167.4660888>,
    <0.1388889, -167.3613758>,
    <0.1666667, -167.5184453>,
    <0.1388889, -167.5184453>,
    <0.1527444, -167.4397221>,
    <0.1527856, -167.5184453>,
    <0.1388889, -167.4391507>,
    <0.8518519, -167.5763713>,
    <0.8333333, -167.5184453>,
    <0.8611111, -167.5184453>,
    <0.8611111, -167.6922232>,
    <0.8472301, -167.5184453>,
    <0.8611111, -167.6048705>,
    <0.8471979, -167.6051824>,
    <0.8425926, -167.4660888>,
    <0.8333333, -167.3613758>,
    <0.8611111, -167.5184453>,
    <0.8333333, -167.5184453>,
    <0.8471889, -167.4397221>,
    <0.8472301, -167.5184453>,
    <0.8333333, -167.4391507>,
    <0.1574074, -167.7825485>,
    <0.1388889, -167.7264218>,
    <0.1666667, -167.8948019>,
    <0.1666667, -167.7264218>,
    <0.1527139, -167.8102249>,
    <0.1666667, -167.8064793>,
    <0.1527826, -167.7264218>,
    <0.1481481, -167.8386752>,
    <0.1388889, -167.7264218>,
    <0.1388889, -167.8948019>,
    <0.1666667, -167.8948019>,
    <0.1388889, -167.8064863>,
    <0.1527936, -167.8948019>,
    <0.1527139, -167.8102249>,
    <0.8518519, -167.9526834>,
    <0.8333333, -167.8948019>,
    <0.8611111, -168.0684463>,
    <0.8611111, -167.8948019>,
    <0.8436884, -167.9595332>,
    <0.8611111, -167.9520428>,
    <0.8472438, -167.8948019>,
    <0.8425926, -167.8386752>,
    <0.8333333, -167.7264218>,
    <0.8333333, -167.8948019>,
    <0.8611111, -167.8948019>,
    <0.8333333, -167.8063797>,
    <0.8472438, -167.8948019>,
    <0.8471479, -167.8101615>,
    <0.1574074, -167.9526834>,
    <0.1388889, -167.8948019>,
    <0.1666667, -168.0684463>,
    <0.1666667, -167.8948019>,
    <0.1492541, -167.9595971>,
    <0.1666667, -167.9524981>,
    <0.1527936, -167.8948019>,
    <0.1481481, -168.0105648>,
    <0.1388889, -167.8948019>,
    <0.1388889, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1388889, -167.9525007>,
    <0.1527778, -168.0684463>,
    <0.1492541, -167.9595971>,
    <0.8425926, -168.0105648>,
    <0.8333333, -167.8948019>,
    <0.8333333, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8333333, -167.9519769>,
    <0.8472222, -168.0684463>,
    <0.8436884, -167.9595332>,
    <0.1574074, -167.5763713>,
    <0.1388889, -167.5184453>,
    <0.1666667, -167.5184453>,
    <0.1666667, -167.6922232>,
    <0.1527856, -167.5184453>,
    <0.1666667, -167.6048705>,
    <0.1527535, -167.6051824>,
    <0.1481481, -167.6342972>,
    <0.1388889, -167.5184453>,
    <0.1666667, -167.6922232>,
    <0.1388889, -167.6922232>,
    <0.1527535, -167.6051824>,
    <0.1527832, -167.6922232>,
    <0.1388889, -167.6048705>,
    <0.8518519, -167.7539575>,
    <0.8333333, -167.6922232>,
    <0.8611111, -167.6922232>,
    <0.8611111, -167.8774261>,
    <0.8472277, -167.6922232>,
    <0.8611111, -167.7805491>,
    <0.8471444, -167.7843057>,
    <0.8425926, -167.6342972>,
    <0.8333333, -167.5184453>,
    <0.8611111, -167.6922232>,
    <0.8333333, -167.6922232>,
    <0.8471979, -167.6051824>,
    <0.8472277, -167.6922232>,
    <0.8333333, -167.6048705>,
    <0.1574074, -167.7539575>,
    <0.1388889, -167.6922232>,
    <0.1666667, -167.6922232>,
    <0.1666667, -167.8774261>,
    <0.1527832, -167.6922232>,
    <0.1666667, -167.7806251>,
    <0.1527105, -167.7843759>,
    <0.1481481, -167.8156918>,
    <0.1388889, -167.6922232>,
    <0.1666667, -167.8774261>,
    <0.1388889, -167.8774261>,
    <0.1527105, -167.7843759>,
    <0.1527938, -167.8774261>,
    <0.1388889, -167.7806315>,
    <0.8518519, -167.9410995>,
    <0.8333333, -167.8774261>,
    <0.8611111, -167.8774261>,
    <0.8611111, -168.0684463>,
    <0.8472441, -167.8774261>,
    <0.8611111, -167.9660833>,
    <0.8466958, -167.9693160>,
    <0.8425926, -167.8156918>,
    <0.8333333, -167.6922232>,
    <0.8611111, -167.8774261>,
    <0.8333333, -167.8774261>,
    <0.8471444, -167.7843057>,
    <0.8472441, -167.8774261>,
    <0.8333333, -167.7805319>,
    <0.1574074, -167.9410995>,
    <0.1388889, -167.8774261>,
    <0.1666667, -167.8774261>,
    <0.1666667, -168.0684463>,
    <0.1527938, -167.8774261>,
    <0.1666667, -167.9640663>,
    <0.1525699, -167.9715064>,
    <0.1481481, -168.0047729>,
    <0.1388889, -167.8774261>,
    <0.1666667, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1525699, -167.9715064>,
    <0.1536910, -168.0684463>,
    <0.1388889, -167.9640898>,
    <0.8425926, -168.0047729>,
    <0.8333333, -167.8774261>,
    <0.8611111, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8466958, -167.9693160>,
    <0.8484925, -168.0684463>,
    <0.8333333, -167.9676413>,
    <0.1708266, -167.1123151>,
    <0.1791465, -167.1040945>,
    <0.1666667, -167.1040945>,
    <0.1666667, -167.1287564>,
    <0.1728491, -167.1040945>,
    <0.1666667, -167.1157282>,
    <0.1695253, -167.1231073>,
    <0.8282340, -167.1123151>,
    <0.8180354, -167.1040945>,
    <0.8333333, -167.1287564>,
    <0.8333333, -167.1040945>,
    <0.8298335, -167.1231143>,
    <0.8333333, -167.1186954>,
    <0.8260566, -167.1040945>,
    <0.8278804, -167.0842391>,
    <0.8169746, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.8333333, -167.1158246>,
    <0.8251540, -167.0684463>,
    <0.8333333, -167.0954675>,
    <0.8262328, -167.0952600>,
    <0.1932078, -167.1123151>,
    <0.1907346, -167.1040945>,
    <0.1944444, -167.1287564>,
    <0.1944444, -167.1040945>,
    <0.1934423, -167.1220942>,
    <0.1944444, -167.1157255>,
    <0.1922023, -167.1040945>,
    <0.1881085, -167.1123151>,
    <0.1907346, -167.1040945>,
    <0.1791465, -167.1040945>,
    <0.1944444, -167.1287564>,
    <0.1843477, -167.1040945>,
    <0.1907448, -167.1227922>,
    <0.1934423, -167.1220942>,
    <0.1800859, -167.1205358>,
    <0.1791465, -167.1040945>,
    <0.1666667, -167.1287564>,
    <0.1944444, -167.1287564>,
    <0.1695253, -167.1231073>,
    <0.1795859, -167.1287564>,
    <0.1907448, -167.1227922>,
    <0.8189748, -167.1205421>,
    <0.8180355, -167.1041136>,
    <0.8055556, -167.1287564>,
    <0.8333333, -167.1287564>,
    <0.8087264, -167.1224952>,
    <0.8186557, -167.1287564>,
    <0.8298335, -167.1231187>,
    <0.8240741, -167.1533103>,
    <0.8055556, -167.1287564>,
    <0.8333333, -167.2024179>,
    <0.8333333, -167.1287564>,
    <0.8197767, -167.1664683>,
    <0.8333333, -167.1601023>,
    <0.8186557, -167.1287564>,
    <0.8106678, -167.1123279>,
    <0.8180355, -167.1041136>,
    <0.8084122, -167.1041136>,
    <0.8055556, -167.1287564>,
    <0.8140120, -167.1041136>,
    <0.8065732, -167.1199778>,
    <0.8087264, -167.1224952>,
    <0.8065078, -167.1123215>,
    <0.8084122, -167.1041136>,
    <0.8055556, -167.1040945>,
    <0.8055556, -167.1287564>,
    <0.8073085, -167.1041062>,
    <0.8055556, -167.1187029>,
    <0.8065732, -167.1199778>,
    <0.8186229, -167.0842391>,
    <0.8055607, -167.0684463>,
    <0.8169746, -167.0684463>,
    <0.8333333, -167.1158246>,
    <0.8112676, -167.0684463>,
    <0.8262328, -167.0952600>,
    <0.8247824, -167.1012374>,
    <0.1851852, -167.1533103>,
    <0.1666667, -167.1287564>,
    <0.1944444, -167.2024179>,
    <0.1944444, -167.1287564>,
    <0.1807945, -167.1662209>,
    <0.1944444, -167.1607154>,
    <0.1795859, -167.1287564>,
    <0.1759259, -167.1778641>,
    <0.1666667, -167.1287564>,
    <0.1666667, -167.2024179>,
    <0.1944444, -167.2024179>,
    <0.1666667, -167.1607154>,
    <0.1805674, -167.2024179>,
    <0.1807945, -167.1662209>,
    <0.8240741, -167.2357456>,
    <0.8055556, -167.2024179>,
    <0.8333333, -167.3024008>,
    <0.8333333, -167.2024179>,
    <0.8193997, -167.2522483>,
    <0.8333333, -167.2507837>,
    <0.8194563, -167.2024179>,
    <0.8148148, -167.1778641>,
    <0.8055556, -167.1287564>,
    <0.8055556, -167.2024179>,
    <0.8333333, -167.2024179>,
    <0.8055556, -167.1601026>,
    <0.8194563, -167.2024179>,
    <0.8197767, -167.1664683>,
    <0.1889915, -167.0842391>,
    <0.1780857, -167.0684463>,
    <0.1944444, -167.0684463>,
    <0.1944444, -167.1158246>,
    <0.1862650, -167.0684463>,
    <0.1944444, -167.0952665>,
    <0.1873807, -167.0953667>,
    <0.1797323, -167.0842391>,
    <0.1666667, -167.0684463>,
    <0.1780857, -167.0684463>,
    <0.1944444, -167.1158246>,
    <0.1723762, -167.0684463>,
    <0.1873807, -167.0953667>,
    <0.1858699, -167.1011998>,
    <0.1759259, -167.1000319>,
    <0.1666667, -167.0684463>,
    <0.1944444, -167.1158246>,
    <0.1666667, -167.1158246>,
    <0.1858699, -167.1011998>,
    <0.1799786, -167.1158246>,
    <0.1666667, -167.0950187>,
    <0.8240741, -167.1524837>,
    <0.8055556, -167.1158246>,
    <0.8333333, -167.1158246>,
    <0.8333333, -167.2258020>,
    <0.8188565, -167.1158246>,
    <0.8333333, -167.1670695>,
    <0.8190999, -167.1694491>,
    <0.8148148, -167.1000319>,
    <0.8055556, -167.0684463>,
    <0.8333333, -167.1158246>,
    <0.8055556, -167.1158246>,
    <0.8247809, -167.1012374>,
    <0.8188565, -167.1158246>,
    <0.8055556, -167.0954362>,
    <0.1851852, -167.2357456>,
    <0.1666667, -167.2024179>,
    <0.1944444, -167.3024008>,
    <0.1944444, -167.2024179>,
    <0.1805108, -167.2522483>,
    <0.1944444, -167.2507837>,
    <0.1805674, -167.2024179>,
    <0.1759259, -167.2690732>,
    <0.1666667, -167.2024179>,
    <0.1666667, -167.3024008>,
    <0.1944444, -167.3024008>,
    <0.1666667, -167.2507837>,
    <0.1805661, -167.3024008>,
    <0.1805108, -167.2522483>,
    <0.8240741, -167.3434849>,
    <0.8055556, -167.3024008>,
    <0.8333333, -167.4256532>,
    <0.8333333, -167.3024008>,
    <0.8194063, -167.3638575>,
    <0.8333333, -167.3627833>,
    <0.8194550, -167.3024008>,
    <0.8148148, -167.2690732>,
    <0.8055556, -167.2024179>,
    <0.8055556, -167.3024008>,
    <0.8333333, -167.3024008>,
    <0.8055556, -167.2507837>,
    <0.8194550, -167.3024008>,
    <0.8193997, -167.2522483>,
    <0.1851852, -167.1524837>,
    <0.1666667, -167.1158246>,
    <0.1944444, -167.1158246>,
    <0.1944444, -167.2258020>,
    <0.1799786, -167.1158246>,
    <0.1944444, -167.1670444>,
    <0.1802189, -167.1694805>,
    <0.1759259, -167.1891429>,
    <0.1666667, -167.1158246>,
    <0.1944444, -167.2258020>,
    <0.1666667, -167.2258020>,
    <0.1802189, -167.1694805>,
    <0.1805673, -167.2258020>,
    <0.1666667, -167.1671626>,
    <0.8240741, -167.2709932>,
    <0.8055556, -167.2258020>,
    <0.8333333, -167.2258020>,
    <0.8333333, -167.3613758>,
    <0.8194562, -167.2258020>,
    <0.8333333, -167.2924560>,
    <0.8194028, -167.2933857>,
    <0.8148148, -167.1891429>,
    <0.8055556, -167.1158246>,
    <0.8333333, -167.2258020>,
    <0.8055556, -167.2258020>,
    <0.8190999, -167.1694491>,
    <0.8194562, -167.2258020>,
    <0.8055556, -167.1668877>,
    <0.1851852, -167.3434849>,
    <0.1666667, -167.3024008>,
    <0.1944444, -167.4256532>,
    <0.1944444, -167.3024008>,
    <0.1805174, -167.3638575>,
    <0.1944444, -167.3627833>,
    <0.1805661, -167.3024008>,
    <0.1759259, -167.3845690>,
    <0.1666667, -167.3024008>,
    <0.1666667, -167.4256532>,
    <0.1944444, -167.4256532>,
    <0.1666667, -167.3627833>,
    <0.1805646, -167.4256532>,
    <0.1805174, -167.3638575>,
    <0.8240741, -167.4732541>,
    <0.8055556, -167.4256532>,
    <0.8333333, -167.5684558>,
    <0.8333333, -167.4256532>,
    <0.8194138, -167.4968970>,
    <0.8333333, -167.4961891>,
    <0.8194535, -167.4256532>,
    <0.8148148, -167.3845690>,
    <0.8055556, -167.3024008>,
    <0.8055556, -167.4256532>,
    <0.8333333, -167.4256532>,
    <0.8055556, -167.3627833>,
    <0.8194535, -167.4256532>,
    <0.8194063, -167.3638575>,
    <0.1851852, -167.2709932>,
    <0.1666667, -167.2258020>,
    <0.1944444, -167.2258020>,
    <0.1944444, -167.3613758>,
    <0.1805673, -167.2258020>,
    <0.1944444, -167.2924560>,
    <0.1805139, -167.2933857>,
    <0.1759259, -167.3161845>,
    <0.1666667, -167.2258020>,
    <0.1944444, -167.3613758>,
    <0.1666667, -167.3613758>,
    <0.1805139, -167.2933857>,
    <0.1805655, -167.3613758>,
    <0.1666667, -167.2924560>,
    <0.8240741, -167.4137323>,
    <0.8055556, -167.3613758>,
    <0.8333333, -167.3613758>,
    <0.8333333, -167.5184453>,
    <0.8194544, -167.3613758>,
    <0.8333333, -167.4391507>,
    <0.8194111, -167.4397221>,
    <0.8148148, -167.3161845>,
    <0.8055556, -167.2258020>,
    <0.8333333, -167.3613758>,
    <0.8055556, -167.3613758>,
    <0.8194028, -167.2933857>,
    <0.8194544, -167.3613758>,
    <0.8055556, -167.2924560>,
    <0.1851852, -167.4732541>,
    <0.1666667, -167.4256532>,
    <0.1944444, -167.5684558>,
    <0.1944444, -167.4256532>,
    <0.1805249, -167.4968970>,
    <0.1944444, -167.4961890>,
    <0.1805646, -167.4256532>,
    <0.1759259, -167.5208549>,
    <0.1666667, -167.4256532>,
    <0.1666667, -167.5684558>,
    <0.1944444, -167.5684558>,
    <0.1666667, -167.4961890>,
    <0.1805626, -167.5684558>,
    <0.1805249, -167.4968970>,
    <0.8240741, -167.6211112>,
    <0.8055556, -167.5684558>,
    <0.8333333, -167.7264218>,
    <0.8333333, -167.5684558>,
    <0.8194221, -167.6473117>,
    <0.8333333, -167.6468904>,
    <0.8194515, -167.5684558>,
    <0.8148148, -167.5208549>,
    <0.8055556, -167.4256532>,
    <0.8055556, -167.5684558>,
    <0.8333333, -167.5684558>,
    <0.8055556, -167.4961890>,
    <0.8194515, -167.5684558>,
    <0.8194138, -167.4968970>,
    <0.1851852, -167.6211112>,
    <0.1666667, -167.5684558>,
    <0.1944444, -167.7264218>,
    <0.1944444, -167.5684558>,
    <0.1805332, -167.6473117>,
    <0.1944444, -167.6468904>,
    <0.1805626, -167.5684558>,
    <0.1759259, -167.6737665>,
    <0.1666667, -167.5684558>,
    <0.1666667, -167.7264218>,
    <0.1944444, -167.7264218>,
    <0.1666667, -167.6468904>,
    <0.1805604, -167.7264218>,
    <0.1805332, -167.6473117>,
    <0.8240741, -167.7825485>,
    <0.8055556, -167.7264218>,
    <0.8333333, -167.8948019>,
    <0.8333333, -167.7264218>,
    <0.8193702, -167.8101615>,
    <0.8333333, -167.8063797>,
    <0.8194493, -167.7264218>,
    <0.8148148, -167.6737665>,
    <0.8055556, -167.5684558>,
    <0.8055556, -167.7264218>,
    <0.8333333, -167.7264218>,
    <0.8055556, -167.6468904>,
    <0.8194493, -167.7264218>,
    <0.8194221, -167.6473117>,
    <0.1851852, -167.4137323>,
    <0.1666667, -167.3613758>,
    <0.1944444, -167.3613758>,
    <0.1944444, -167.5184453>,
    <0.1805655, -167.3613758>,
    <0.1944444, -167.4391507>,
    <0.1805222, -167.4397221>,
    <0.1759259, -167.4660888>,
    <0.1666667, -167.3613758>,
    <0.1944444, -167.5184453>,
    <0.1666667, -167.5184453>,
    <0.1805222, -167.4397221>,
    <0.1805634, -167.5184453>,
    <0.1666667, -167.4391507>,
    <0.8240741, -167.5763713>,
    <0.8055556, -167.5184453>,
    <0.8333333, -167.5184453>,
    <0.8333333, -167.6922232>,
    <0.8194523, -167.5184453>,
    <0.8333333, -167.6048705>,
    <0.8194202, -167.6051824>,
    <0.8148148, -167.4660888>,
    <0.8055556, -167.3613758>,
    <0.8333333, -167.5184453>,
    <0.8055556, -167.5184453>,
    <0.8194111, -167.4397221>,
    <0.8194523, -167.5184453>,
    <0.8055556, -167.4391507>,
    <0.1851852, -167.7825485>,
    <0.1666667, -167.7264218>,
    <0.1944444, -167.8948019>,
    <0.1944444, -167.7264218>,
    <0.1804928, -167.8102318>,
    <0.1944444, -167.8064696>,
    <0.1805604, -167.7264218>,
    <0.1759259, -167.8386752>,
    <0.1666667, -167.7264218>,
    <0.1666667, -167.8948019>,
    <0.1944444, -167.8948019>,
    <0.1666667, -167.8064793>,
    <0.1805707, -167.8948019>,
    <0.1804928, -167.8102318>,
    <0.8240741, -167.9526834>,
    <0.8055556, -167.8948019>,
    <0.8333333, -168.0684463>,
    <0.8333333, -167.8948019>,
    <0.8159102, -167.9595305>,
    <0.8333333, -167.9519769>,
    <0.8194659, -167.8948019>,
    <0.8148148, -167.8386752>,
    <0.8055556, -167.7264218>,
    <0.8055556, -167.8948019>,
    <0.8333333, -167.8948019>,
    <0.8055556, -167.8063614>,
    <0.8194659, -167.8948019>,
    <0.8193702, -167.8101615>,
    <0.1851852, -167.9526834>,
    <0.1666667, -167.8948019>,
    <0.1944444, -168.0684463>,
    <0.1944444, -167.8948019>,
    <0.1770326, -167.9596014>,
    <0.1944444, -167.9524848>,
    <0.1805707, -167.8948019>,
    <0.1759259, -168.0105648>,
    <0.1666667, -167.8948019>,
    <0.1666667, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1666667, -167.9524981>,
    <0.1805555, -168.0684463>,
    <0.1770326, -167.9596014>,
    <0.8148148, -168.0105648>,
    <0.8055556, -167.8948019>,
    <0.8055556, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8055556, -167.9519140>,
    <0.8194445, -168.0684463>,
    <0.8159102, -167.9595305>,
    <0.1851852, -167.5763713>,
    <0.1666667, -167.5184453>,
    <0.1944444, -167.5184453>,
    <0.1944444, -167.6922232>,
    <0.1805634, -167.5184453>,
    <0.1944444, -167.6048705>,
    <0.1805313, -167.6051824>,
    <0.1759259, -167.6342972>,
    <0.1666667, -167.5184453>,
    <0.1944444, -167.6922232>,
    <0.1666667, -167.6922232>,
    <0.1805313, -167.6051824>,
    <0.1805610, -167.6922232>,
    <0.1666667, -167.6048705>,
    <0.8240741, -167.7539575>,
    <0.8055556, -167.6922232>,
    <0.8333333, -167.6922232>,
    <0.8333333, -167.8774261>,
    <0.8194499, -167.6922232>,
    <0.8333333, -167.7805319>,
    <0.8193666, -167.7843057>,
    <0.8148148, -167.6342972>,
    <0.8055556, -167.5184453>,
    <0.8333333, -167.6922232>,
    <0.8055556, -167.6922232>,
    <0.8194202, -167.6051824>,
    <0.8194499, -167.6922232>,
    <0.8055556, -167.6048705>,
    <0.1851852, -167.7539575>,
    <0.1666667, -167.6922232>,
    <0.1944444, -167.6922232>,
    <0.1944444, -167.8774261>,
    <0.1805610, -167.6922232>,
    <0.1944444, -167.7806161>,
    <0.1804894, -167.7843835>,
    <0.1759259, -167.8156918>,
    <0.1666667, -167.6922232>,
    <0.1944444, -167.8774261>,
    <0.1666667, -167.8774261>,
    <0.1804894, -167.7843835>,
    <0.1805710, -167.8774261>,
    <0.1666667, -167.7806251>,
    <0.8240741, -167.9410995>,
    <0.8055556, -167.8774261>,
    <0.8333333, -167.8774261>,
    <0.8333333, -168.0684463>,
    <0.8194662, -167.8774261>,
    <0.8333333, -167.9676413>,
    <0.8188107, -167.9685779>,
    <0.8148148, -167.8156918>,
    <0.8055556, -167.6922232>,
    <0.8333333, -167.8774261>,
    <0.8055556, -167.8774261>,
    <0.8193666, -167.7843057>,
    <0.8194662, -167.8774261>,
    <0.8055556, -167.7805148>,
    <0.1851852, -167.9410995>,
    <0.1666667, -167.8774261>,
    <0.1944444, -167.8774261>,
    <0.1944444, -168.0684463>,
    <0.1805710, -167.8774261>,
    <0.1944444, -167.9631301>,
    <0.1803954, -167.9718349>,
    <0.1759259, -168.0047729>,
    <0.1666667, -167.8774261>,
    <0.1944444, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1803954, -167.9718349>,
    <0.1812444, -168.0684463>,
    <0.1666667, -167.9640663>,
    <0.8148148, -168.0047729>,
    <0.8055556, -167.8774261>,
    <0.8333333, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8188107, -167.9685779>,
    <0.8213346, -168.0684463>,
    <0.8055556, -167.9736171>,
    <0.1986044, -167.1123151>,
    <0.2069243, -167.1040945>,
    <0.1944444, -167.1040945>,
    <0.1944444, -167.1287564>,
    <0.2006269, -167.1040945>,
    <0.1944444, -167.1157255>,
    <0.1973031, -167.1231073>,
    <0.8004562, -167.1123151>,
    <0.7902576, -167.1040945>,
    <0.8055556, -167.1287564>,
    <0.8055556, -167.1040945>,
    <0.8020558, -167.1231144>,
    <0.8055556, -167.1187029>,
    <0.7982787, -167.1040945>,
    <0.8001016, -167.0842391>,
    <0.7891937, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.8055556, -167.1158246>,
    <0.7973747, -167.0684463>,
    <0.8055556, -167.0954362>,
    <0.7984682, -167.0953019>,
    <0.2209856, -167.1123151>,
    <0.2185123, -167.1040945>,
    <0.2222222, -167.1287564>,
    <0.2222222, -167.1040945>,
    <0.2212200, -167.1220942>,
    <0.2222222, -167.1157254>,
    <0.2199801, -167.1040945>,
    <0.2158863, -167.1123151>,
    <0.2185123, -167.1040945>,
    <0.2069242, -167.1040945>,
    <0.2222222, -167.1287564>,
    <0.2121254, -167.1040945>,
    <0.2185225, -167.1227921>,
    <0.2212200, -167.1220942>,
    <0.2078637, -167.1205358>,
    <0.2069243, -167.1040945>,
    <0.1944444, -167.1287564>,
    <0.2222222, -167.1287564>,
    <0.1973031, -167.1231073>,
    <0.2073637, -167.1287564>,
    <0.2185225, -167.1227921>,
    <0.7911970, -167.1205421>,
    <0.7902577, -167.1041136>,
    <0.7777778, -167.1287564>,
    <0.8055556, -167.1287564>,
    <0.7809484, -167.1224956>,
    <0.7908779, -167.1287564>,
    <0.8020558, -167.1231188>,
    <0.7962963, -167.1533103>,
    <0.7777778, -167.1287564>,
    <0.8055556, -167.2024179>,
    <0.8055556, -167.1287564>,
    <0.7919990, -167.1664684>,
    <0.8055556, -167.1601026>,
    <0.7908779, -167.1287564>,
    <0.7828900, -167.1123279>,
    <0.7902577, -167.1041136>,
    <0.7806345, -167.1041136>,
    <0.7777778, -167.1287564>,
    <0.7862343, -167.1041136>,
    <0.7787954, -167.1199784>,
    <0.7809484, -167.1224956>,
    <0.7787300, -167.1123215>,
    <0.7806345, -167.1041136>,
    <0.7777778, -167.1040945>,
    <0.7777778, -167.1287564>,
    <0.7795310, -167.1041062>,
    <0.7777778, -167.1186964>,
    <0.7787954, -167.1199784>,
    <0.7908434, -167.0842391>,
    <0.7777778, -167.0684463>,
    <0.7891968, -167.0684463>,
    <0.8055556, -167.1158246>,
    <0.7834873, -167.0684463>,
    <0.7984695, -167.0953019>,
    <0.7969819, -167.1012012>,
    <0.2129630, -167.1533103>,
    <0.1944444, -167.1287564>,
    <0.2222222, -167.2024179>,
    <0.2222222, -167.1287564>,
    <0.2085723, -167.1662209>,
    <0.2222222, -167.1607154>,
    <0.2073637, -167.1287564>,
    <0.2037037, -167.1778641>,
    <0.1944444, -167.1287564>,
    <0.1944444, -167.2024179>,
    <0.2222222, -167.2024179>,
    <0.1944444, -167.1607154>,
    <0.2083451, -167.2024179>,
    <0.2085723, -167.1662209>,
    <0.7962963, -167.2357456>,
    <0.7777778, -167.2024179>,
    <0.8055556, -167.3024008>,
    <0.8055556, -167.2024179>,
    <0.7916219, -167.2522483>,
    <0.8055556, -167.2507837>,
    <0.7916785, -167.2024179>,
    <0.7870370, -167.1778641>,
    <0.7777778, -167.1287564>,
    <0.7777778, -167.2024179>,
    <0.8055556, -167.2024179>,
    <0.7777778, -167.1601023>,
    <0.7916785, -167.2024179>,
    <0.7919990, -167.1664684>,
    <0.2167693, -167.0842391>,
    <0.2058634, -167.0684463>,
    <0.2222222, -167.0684463>,
    <0.2222222, -167.1158246>,
    <0.2140428, -167.0684463>,
    <0.2222222, -167.0948736>,
    <0.2151889, -167.0954548>,
    <0.2075090, -167.0842391>,
    <0.1944444, -167.0684463>,
    <0.2058604, -167.0684463>,
    <0.2222222, -167.1158246>,
    <0.2001524, -167.0684463>,
    <0.2151876, -167.0954548>,
    <0.2136317, -167.1011725>,
    <0.2037037, -167.1000319>,
    <0.1944444, -167.0684463>,
    <0.2222222, -167.1158246>,
    <0.1944444, -167.1158246>,
    <0.2136317, -167.1011725>,
    <0.2077560, -167.1158246>,
    <0.1944444, -167.0952665>,
    <0.7962963, -167.1524837>,
    <0.7777778, -167.1158246>,
    <0.8055556, -167.1158246>,
    <0.8055556, -167.2258020>,
    <0.7910947, -167.1158246>,
    <0.8055556, -167.1668877>,
    <0.7913343, -167.1694972>,
    <0.7870370, -167.1000319>,
    <0.7777778, -167.0684463>,
    <0.8055556, -167.1158246>,
    <0.7777778, -167.1158246>,
    <0.7969819, -167.1012012>,
    <0.7910947, -167.1158246>,
    <0.7777778, -167.0941490>,
    <0.2129630, -167.2357456>,
    <0.1944444, -167.2024179>,
    <0.2222222, -167.3024008>,
    <0.2222222, -167.2024179>,
    <0.2082886, -167.2522483>,
    <0.2222222, -167.2507837>,
    <0.2083451, -167.2024179>,
    <0.2037037, -167.2690732>,
    <0.1944444, -167.2024179>,
    <0.1944444, -167.3024008>,
    <0.2222222, -167.3024008>,
    <0.1944444, -167.2507837>,
    <0.2083439, -167.3024008>,
    <0.2082886, -167.2522483>,
    <0.7962963, -167.3434849>,
    <0.7777778, -167.3024008>,
    <0.8055556, -167.4256532>,
    <0.8055556, -167.3024008>,
    <0.7916285, -167.3638575>,
    <0.8055556, -167.3627833>,
    <0.7916773, -167.3024008>,
    <0.7870370, -167.2690732>,
    <0.7777778, -167.2024179>,
    <0.7777778, -167.3024008>,
    <0.8055556, -167.3024008>,
    <0.7777778, -167.2507837>,
    <0.7916773, -167.3024008>,
    <0.7916219, -167.2522483>,
    <0.2129630, -167.1524837>,
    <0.1944444, -167.1158246>,
    <0.2222222, -167.1158246>,
    <0.2222222, -167.2258020>,
    <0.2077560, -167.1158246>,
    <0.2222222, -167.1671102>,
    <0.2079936, -167.1694682>,
    <0.2037037, -167.1891429>,
    <0.1944444, -167.1158246>,
    <0.2222222, -167.2258020>,
    <0.1944444, -167.2258020>,
    <0.2079936, -167.1694682>,
    <0.2083451, -167.2258020>,
    <0.1944444, -167.1670444>,
    <0.7962963, -167.2709932>,
    <0.7777778, -167.2258020>,
    <0.8055556, -167.2258020>,
    <0.8055556, -167.3613758>,
    <0.7916784, -167.2258020>,
    <0.8055556, -167.2924560>,
    <0.7916250, -167.2933857>,
    <0.7870370, -167.1891429>,
    <0.7777778, -167.1158246>,
    <0.8055556, -167.2258020>,
    <0.7777778, -167.2258020>,
    <0.7913343, -167.1694972>,
    <0.7916784, -167.2258020>,
    <0.7777778, -167.1672051>,
    <0.2129630, -167.3434849>,
    <0.1944444, -167.3024008>,
    <0.2222222, -167.4256532>,
    <0.2222222, -167.3024008>,
    <0.2082951, -167.3638575>,
    <0.2222222, -167.3627833>,
    <0.2083439, -167.3024008>,
    <0.2037037, -167.3845690>,
    <0.1944444, -167.3024008>,
    <0.1944444, -167.4256532>,
    <0.2222222, -167.4256532>,
    <0.1944444, -167.3627833>,
    <0.2083423, -167.4256532>,
    <0.2082951, -167.3638575>,
    <0.7962963, -167.4732541>,
    <0.7777778, -167.4256532>,
    <0.8055556, -167.5684558>,
    <0.8055556, -167.4256532>,
    <0.7916360, -167.4968970>,
    <0.8055556, -167.4961890>,
    <0.7916757, -167.4256532>,
    <0.7870370, -167.3845690>,
    <0.7777778, -167.3024008>,
    <0.7777778, -167.4256532>,
    <0.8055556, -167.4256532>,
    <0.7777778, -167.3627833>,
    <0.7916757, -167.4256532>,
    <0.7916285, -167.3638575>,
    <0.2129630, -167.2709932>,
    <0.1944444, -167.2258020>,
    <0.2222222, -167.2258020>,
    <0.2222222, -167.3613758>,
    <0.2083451, -167.2258020>,
    <0.2222222, -167.2924560>,
    <0.2082917, -167.2933857>,
    <0.2037037, -167.3161845>,
    <0.1944444, -167.2258020>,
    <0.2222222, -167.3613758>,
    <0.1944444, -167.3613758>,
    <0.2082917, -167.2933857>,
    <0.2083433, -167.3613758>,
    <0.1944444, -167.2924560>,
    <0.7962963, -167.4137323>,
    <0.7777778, -167.3613758>,
    <0.8055556, -167.3613758>,
    <0.8055556, -167.5184453>,
    <0.7916767, -167.3613758>,
    <0.8055556, -167.4391507>,
    <0.7916334, -167.4397221>,
    <0.7870370, -167.3161845>,
    <0.7777778, -167.2258020>,
    <0.8055556, -167.3613758>,
    <0.7777778, -167.3613758>,
    <0.7916250, -167.2933857>,
    <0.7916767, -167.3613758>,
    <0.7777778, -167.2924560>,
    <0.2129630, -167.4732541>,
    <0.1944444, -167.4256532>,
    <0.2222222, -167.5684558>,
    <0.2222222, -167.4256532>,
    <0.2083027, -167.4968970>,
    <0.2222222, -167.4961890>,
    <0.2083423, -167.4256532>,
    <0.2037037, -167.5208549>,
    <0.1944444, -167.4256532>,
    <0.1944444, -167.5684558>,
    <0.2222222, -167.5684558>,
    <0.1944444, -167.4961890>,
    <0.2083404, -167.5684558>,
    <0.2083027, -167.4968970>,
    <0.7962963, -167.6211112>,
    <0.7777778, -167.5684558>,
    <0.8055556, -167.7264218>,
    <0.8055556, -167.5684558>,
    <0.7916443, -167.6473117>,
    <0.8055556, -167.6468904>,
    <0.7916738, -167.5684558>,
    <0.7870370, -167.5208549>,
    <0.7777778, -167.4256532>,
    <0.7777778, -167.5684558>,
    <0.8055556, -167.5684558>,
    <0.7777778, -167.4961890>,
    <0.7916738, -167.5684558>,
    <0.7916360, -167.4968970>,
    <0.2129630, -167.6211112>,
    <0.1944444, -167.5684558>,
    <0.2222222, -167.7264218>,
    <0.2222222, -167.5684558>,
    <0.2083110, -167.6473117>,
    <0.2222222, -167.6468904>,
    <0.2083404, -167.5684558>,
    <0.2037037, -167.6737665>,
    <0.1944444, -167.5684558>,
    <0.1944444, -167.7264218>,
    <0.2222222, -167.7264218>,
    <0.1944444, -167.6468904>,
    <0.2083382, -167.7264218>,
    <0.2083110, -167.6473117>,
    <0.7962963, -167.7825485>,
    <0.7777778, -167.7264218>,
    <0.8055556, -167.8948019>,
    <0.8055556, -167.7264218>,
    <0.7915926, -167.8101630>,
    <0.8055556, -167.8063614>,
    <0.7916716, -167.7264218>,
    <0.7870370, -167.6737665>,
    <0.7777778, -167.5684558>,
    <0.7777778, -167.7264218>,
    <0.8055556, -167.7264218>,
    <0.7777778, -167.6468904>,
    <0.7916716, -167.7264218>,
    <0.7916443, -167.6473117>,
    <0.2129630, -167.4137323>,
    <0.1944444, -167.3613758>,
    <0.2222222, -167.3613758>,
    <0.2222222, -167.5184453>,
    <0.2083433, -167.3613758>,
    <0.2222222, -167.4391507>,
    <0.2083000, -167.4397221>,
    <0.2037037, -167.4660888>,
    <0.1944444, -167.3613758>,
    <0.2222222, -167.5184453>,
    <0.1944444, -167.5184453>,
    <0.2083000, -167.4397221>,
    <0.2083412, -167.5184453>,
    <0.1944444, -167.4391507>,
    <0.7962963, -167.5763713>,
    <0.7777778, -167.5184453>,
    <0.8055556, -167.5184453>,
    <0.8055556, -167.6922232>,
    <0.7916745, -167.5184453>,
    <0.8055556, -167.6048705>,
    <0.7916424, -167.6051824>,
    <0.7870370, -167.4660888>,
    <0.7777778, -167.3613758>,
    <0.8055556, -167.5184453>,
    <0.7777778, -167.5184453>,
    <0.7916334, -167.4397221>,
    <0.7916745, -167.5184453>,
    <0.7777778, -167.4391507>,
    <0.2129630, -167.7825485>,
    <0.1944444, -167.7264218>,
    <0.2222222, -167.8948019>,
    <0.2222222, -167.7264218>,
    <0.2082716, -167.8102378>,
    <0.2222222, -167.8064572>,
    <0.2083382, -167.7264218>,
    <0.2037037, -167.8386752>,
    <0.1944444, -167.7264218>,
    <0.1944444, -167.8948019>,
    <0.2222222, -167.8948019>,
    <0.1944444, -167.8064696>,
    <0.2083478, -167.8948019>,
    <0.2082716, -167.8102378>,
    <0.7962963, -167.9526834>,
    <0.7777778, -167.8948019>,
    <0.8055556, -168.0684463>,
    <0.8055556, -167.8948019>,
    <0.7881322, -167.9595294>,
    <0.8055556, -167.9519140>,
    <0.7916879, -167.8948019>,
    <0.7870370, -167.8386752>,
    <0.7777778, -167.7264218>,
    <0.7777778, -167.8948019>,
    <0.8055556, -167.8948019>,
    <0.7777778, -167.8063438>,
    <0.7916879, -167.8948019>,
    <0.7915926, -167.8101630>,
    <0.2129630, -167.9526834>,
    <0.1944444, -167.8948019>,
    <0.2222222, -168.0684463>,
    <0.2222222, -167.8948019>,
    <0.1989375, -167.9228891>,
    <0.2222222, -167.9821228>,
    <0.2083478, -167.8948019>,
    <0.2037037, -168.0105648>,
    <0.1944444, -167.8948019>,
    <0.1944444, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.1944444, -167.9524848>,
    <0.2057385, -168.0684463>,
    <0.1989375, -167.9228891>,
    <0.7870370, -168.0105648>,
    <0.7777778, -167.8948019>,
    <0.7777778, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.7777778, -167.9518560>,
    <0.7916667, -168.0684463>,
    <0.7881322, -167.9595294>,
    <0.2129630, -167.5763713>,
    <0.1944444, -167.5184453>,
    <0.2222222, -167.5184453>,
    <0.2222222, -167.6922232>,
    <0.2083412, -167.5184453>,
    <0.2222222, -167.6048705>,
    <0.2083090, -167.6051824>,
    <0.2037037, -167.6342972>,
    <0.1944444, -167.5184453>,
    <0.2222222, -167.6922232>,
    <0.1944444, -167.6922232>,
    <0.2083090, -167.6051824>,
    <0.2083387, -167.6922232>,
    <0.1944444, -167.6048705>,
    <0.7962963, -167.7539575>,
    <0.7777778, -167.6922232>,
    <0.8055556, -167.6922232>,
    <0.8055556, -167.8774261>,
    <0.7916721, -167.6922232>,
    <0.8055556, -167.7805148>,
    <0.7915891, -167.7843073>,
    <0.7870370, -167.6342972>,
    <0.7777778, -167.5184453>,
    <0.8055556, -167.6922232>,
    <0.7777778, -167.6922232>,
    <0.7916424, -167.6051824>,
    <0.7916721, -167.6922232>,
    <0.7777778, -167.6048705>,
    <0.2129630, -167.7539575>,
    <0.1944444, -167.6922232>,
    <0.2222222, -167.6922232>,
    <0.2222222, -167.8774261>,
    <0.2083387, -167.6922232>,
    <0.2222222, -167.7806046>,
    <0.2082682, -167.7843902>,
    <0.2037037, -167.8156918>,
    <0.1944444, -167.6922232>,
    <0.2222222, -167.8774261>,
    <0.1944444, -167.8774261>,
    <0.2082682, -167.7843902>,
    <0.2083480, -167.8774261>,
    <0.1944444, -167.7806161>,
    <0.7962963, -167.9410995>,
    <0.7777778, -167.8774261>,
    <0.8055556, -167.8774261>,
    <0.8055556, -168.0684463>,
    <0.7916882, -167.8774261>,
    <0.8055556, -167.9736171>,
    <0.7905558, -167.9652971>,
    <0.7870370, -167.8156918>,
    <0.7777778, -167.6922232>,
    <0.8055556, -167.8774261>,
    <0.7777778, -167.8774261>,
    <0.7915891, -167.7843073>,
    <0.7916882, -167.8774261>,
    <0.7777778, -167.7804984>,
    <0.2129630, -167.9410995>,
    <0.1944444, -167.8774261>,
    <0.2222222, -167.8774261>,
    <0.2222222, -168.0684463>,
    <0.2083480, -167.8774261>,
    <0.2222222, -167.9685482>,
    <0.2074488, -167.9668534>,
    <0.2037037, -168.0047729>,
    <0.1944444, -167.8774261>,
    <0.2222222, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.2074488, -167.9668534>,
    <0.2086976, -168.0684463>,
    <0.1944444, -167.9631301>,
    <0.7870370, -168.0047729>,
    <0.7777778, -167.8774261>,
    <0.8055556, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7905558, -167.9652971>,
    <0.7925480, -168.0684463>,
    <0.7777778, -167.9659130>,
    <0.2263822, -167.1123151>,
    <0.2347021, -167.1040945>,
    <0.2222222, -167.1040945>,
    <0.2222222, -167.1287564>,
    <0.2284047, -167.1040945>,
    <0.2222222, -167.1157254>,
    <0.2250809, -167.1231073>,
    <0.7726785, -167.1123151>,
    <0.7624800, -167.1040945>,
    <0.7777778, -167.1287564>,
    <0.7777778, -167.1040945>,
    <0.7740113, -167.1226843>,
    <0.7777778, -167.1186964>,
    <0.7703088, -167.1040945>,
    <0.7723249, -167.0842391>,
    <0.7614190, -167.0684463>,
    <0.7777778, -167.0684463>,
    <0.7777778, -167.1158246>,
    <0.7699234, -167.0684463>,
    <0.7777778, -167.0941490>,
    <0.7711704, -167.0966882>,
    <0.7685185, -167.1533103>,
    <0.7500000, -167.1287564>,
    <0.7777778, -167.2024179>,
    <0.7777778, -167.1287564>,
    <0.7642983, -167.1666728>,
    <0.7777778, -167.1601023>,
    <0.7631642, -167.1287564>,
    <0.7634192, -167.1205358>,
    <0.7624799, -167.1040945>,
    <0.7500000, -167.1287564>,
    <0.7777778, -167.1287564>,
    <0.7532963, -167.1222425>,
    <0.7631642, -167.1287564>,
    <0.7740112, -167.1226843>,
    <0.7541600, -167.1123151>,
    <0.7624799, -167.1040945>,
    <0.7500000, -167.1040945>,
    <0.7500000, -167.1287564>,
    <0.7564108, -167.1040945>,
    <0.7500000, -167.1196784>,
    <0.7532963, -167.1222425>,
    <0.7630656, -167.0842391>,
    <0.7500000, -167.0684463>,
    <0.7614190, -167.0684463>,
    <0.7777778, -167.1158246>,
    <0.7559955, -167.0684463>,
    <0.7711704, -167.0966882>,
    <0.7691477, -167.1011050>,
    <0.7685185, -167.2357456>,
    <0.7500000, -167.2024179>,
    <0.7777778, -167.3024008>,
    <0.7777778, -167.2024179>,
    <0.7638441, -167.2522483>,
    <0.7777778, -167.2507837>,
    <0.7639007, -167.2024179>,
    <0.7592593, -167.1778641>,
    <0.7500000, -167.1287564>,
    <0.7500000, -167.2024179>,
    <0.7777778, -167.2024179>,
    <0.7500000, -167.1605800>,
    <0.7639007, -167.2024179>,
    <0.7642983, -167.1666728>,
    <0.7685185, -167.1524837>,
    <0.7500000, -167.1158246>,
    <0.7777778, -167.1158246>,
    <0.7777778, -167.2258020>,
    <0.7633260, -167.1158246>,
    <0.7777778, -167.1672051>,
    <0.7635586, -167.1695056>,
    <0.7592593, -167.1000319>,
    <0.7500000, -167.0684463>,
    <0.7777778, -167.1158246>,
    <0.7500000, -167.1158246>,
    <0.7691477, -167.1011050>,
    <0.7633260, -167.1158246>,
    <0.7500000, -167.0943971>,
    <0.7685185, -167.3434849>,
    <0.7500000, -167.3024008>,
    <0.7777778, -167.4256532>,
    <0.7777778, -167.3024008>,
    <0.7638507, -167.3638575>,
    <0.7777778, -167.3627833>,
    <0.7638995, -167.3024008>,
    <0.7592593, -167.2690732>,
    <0.7500000, -167.2024179>,
    <0.7500000, -167.3024008>,
    <0.7777778, -167.3024008>,
    <0.7500000, -167.2507837>,
    <0.7638995, -167.3024008>,
    <0.7638441, -167.2522483>,
    <0.7685185, -167.2709932>,
    <0.7500000, -167.2258020>,
    <0.7777778, -167.2258020>,
    <0.7777778, -167.3613758>,
    <0.7639006, -167.2258020>,
    <0.7777778, -167.2924560>,
    <0.7638473, -167.2933857>,
    <0.7592593, -167.1891429>,
    <0.7500000, -167.1158246>,
    <0.7777778, -167.2258020>,
    <0.7500000, -167.2258020>,
    <0.7635586, -167.1695056>,
    <0.7639006, -167.2258020>,
    <0.7500000, -167.1673835>,
    <0.7685185, -167.4732541>,
    <0.7500000, -167.4256532>,
    <0.7777778, -167.5684558>,
    <0.7777778, -167.4256532>,
    <0.7638583, -167.4968970>,
    <0.7777778, -167.4961890>,
    <0.7638979, -167.4256532>,
    <0.7592593, -167.3845690>,
    <0.7500000, -167.3024008>,
    <0.7500000, -167.4256532>,
    <0.7777778, -167.4256532>,
    <0.7500000, -167.3627833>,
    <0.7638979, -167.4256532>,
    <0.7638507, -167.3638575>,
    <0.7685185, -167.4137323>,
    <0.7500000, -167.3613758>,
    <0.7777778, -167.3613758>,
    <0.7777778, -167.5184453>,
    <0.7638989, -167.3613758>,
    <0.7777778, -167.4391507>,
    <0.7638556, -167.4397221>,
    <0.7592593, -167.3161845>,
    <0.7500000, -167.2258020>,
    <0.7777778, -167.3613758>,
    <0.7500000, -167.3613758>,
    <0.7638473, -167.2933857>,
    <0.7638989, -167.3613758>,
    <0.7500000, -167.2924560>,
    <0.7685185, -167.6211112>,
    <0.7500000, -167.5684558>,
    <0.7777778, -167.7264218>,
    <0.7777778, -167.5684558>,
    <0.7638665, -167.6473117>,
    <0.7777778, -167.6468904>,
    <0.7638960, -167.5684558>,
    <0.7592593, -167.5208549>,
    <0.7500000, -167.4256532>,
    <0.7500000, -167.5684558>,
    <0.7777778, -167.5684558>,
    <0.7500000, -167.4961890>,
    <0.7638960, -167.5684558>,
    <0.7638583, -167.4968970>,
    <0.7685185, -167.7825485>,
    <0.7500000, -167.7264218>,
    <0.7777778, -167.8948019>,
    <0.7777778, -167.7264218>,
    <0.7638153, -167.8101657>,
    <0.7777778, -167.8063438>,
    <0.7638938, -167.7264218>,
    <0.7592593, -167.6737665>,
    <0.7500000, -167.5684558>,
    <0.7500000, -167.7264218>,
    <0.7777778, -167.7264218>,
    <0.7500000, -167.6468904>,
    <0.7638938, -167.7264218>,
    <0.7638665, -167.6473117>,
    <0.7685185, -167.5763713>,
    <0.7500000, -167.5184453>,
    <0.7777778, -167.5184453>,
    <0.7777778, -167.6922232>,
    <0.7638968, -167.5184453>,
    <0.7777778, -167.6048705>,
    <0.7638646, -167.6051824>,
    <0.7592593, -167.4660888>,
    <0.7500000, -167.3613758>,
    <0.7777778, -167.5184453>,
    <0.7500000, -167.5184453>,
    <0.7638556, -167.4397221>,
    <0.7638968, -167.5184453>,
    <0.7500000, -167.4391507>,
    <0.7685185, -167.9526834>,
    <0.7500000, -167.8948019>,
    <0.7777778, -168.0684463>,
    <0.7777778, -167.8948019>,
    <0.7603542, -167.9595283>,
    <0.7777778, -167.9518560>,
    <0.7639098, -167.8948019>,
    <0.7592593, -167.8386752>,
    <0.7500000, -167.7264218>,
    <0.7500000, -167.8948019>,
    <0.7777778, -167.8948019>,
    <0.7500000, -167.8063273>,
    <0.7639098, -167.8948019>,
    <0.7638153, -167.8101657>,
    <0.7592593, -168.0105648>,
    <0.7500000, -167.8948019>,
    <0.7500000, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7500000, -167.9893072>,
    <0.7666995, -168.0684463>,
    <0.7603542, -167.9595283>,
    <0.7685185, -167.7539575>,
    <0.7500000, -167.6922232>,
    <0.7777778, -167.6922232>,
    <0.7777778, -167.8774261>,
    <0.7638943, -167.6922232>,
    <0.7777778, -167.7804984>,
    <0.7638117, -167.7843102>,
    <0.7592593, -167.6342972>,
    <0.7500000, -167.5184453>,
    <0.7777778, -167.6922232>,
    <0.7500000, -167.6922232>,
    <0.7638646, -167.6051824>,
    <0.7638943, -167.6922232>,
    <0.7500000, -167.6048705>,
    <0.7685185, -167.9410995>,
    <0.7500000, -167.8774261>,
    <0.7777778, -167.8774261>,
    <0.7777778, -168.0684463>,
    <0.7639101, -167.8774261>,
    <0.7777778, -167.9659130>,
    <0.7633616, -167.9693101>,
    <0.7592593, -167.8156918>,
    <0.7500000, -167.6922232>,
    <0.7777778, -167.8774261>,
    <0.7500000, -167.8774261>,
    <0.7638117, -167.7843102>,
    <0.7639101, -167.8774261>,
    <0.7500000, -167.7804832>,
    <0.7592593, -168.0047729>,
    <0.7500000, -167.8774261>,
    <0.7777778, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7633616, -167.9693101>,
    <0.7648812, -168.0684463>,
    <0.7500000, -167.9706945>,
    <0.2314815, -168.0047729>,
    <0.2222222, -167.8774261>,
    <0.2500000, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2331132, -167.9523206>,
    <0.2356116, -168.0684463>,
    <0.2222222, -167.9685482>,
    <0.2314815, -167.8156918>,
    <0.2222222, -167.6922232>,
    <0.2500000, -167.8774261>,
    <0.2222222, -167.8774261>,
    <0.2360468, -167.7843957>,
    <0.2361253, -167.8774261>,
    <0.2222222, -167.7806046>,
    <0.2407407, -167.9410995>,
    <0.2222222, -167.8774261>,
    <0.2500000, -167.8774261>,
    <0.2500000, -168.0684463>,
    <0.2361253, -167.8774261>,
    <0.2500000, -167.9862701>,
    <0.2331132, -167.9523206>,
    <0.2314815, -167.6342972>,
    <0.2222222, -167.5184453>,
    <0.2500000, -167.6922232>,
    <0.2222222, -167.6922232>,
    <0.2360868, -167.6051824>,
    <0.2361165, -167.6922232>,
    <0.2222222, -167.6048705>,
    <0.2407407, -167.7539575>,
    <0.2222222, -167.6922232>,
    <0.2500000, -167.6922232>,
    <0.2500000, -167.8774261>,
    <0.2361165, -167.6922232>,
    <0.2500000, -167.7805911>,
    <0.2360468, -167.7843957>,
    <0.2314815, -168.0105648>,
    <0.2222222, -167.8948019>,
    <0.2222222, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2222222, -167.9821228>,
    <0.2344945, -168.0684463>,
    <0.2304274, -167.9460939>,
    <0.2314815, -167.8386752>,
    <0.2222222, -167.7264218>,
    <0.2222222, -167.8948019>,
    <0.2500000, -167.8948019>,
    <0.2222222, -167.8064572>,
    <0.2361251, -167.8948019>,
    <0.2360502, -167.8102428>,
    <0.2407407, -167.9526834>,
    <0.2222222, -167.8948019>,
    <0.2500000, -168.0684463>,
    <0.2500000, -167.8948019>,
    <0.2304274, -167.9460939>,
    <0.2500000, -167.9369669>,
    <0.2361251, -167.8948019>,
    <0.2314815, -167.4660888>,
    <0.2222222, -167.3613758>,
    <0.2500000, -167.5184453>,
    <0.2222222, -167.5184453>,
    <0.2360778, -167.4397221>,
    <0.2361190, -167.5184453>,
    <0.2222222, -167.4391507>,
    <0.2407407, -167.5763713>,
    <0.2222222, -167.5184453>,
    <0.2500000, -167.5184453>,
    <0.2500000, -167.6922232>,
    <0.2361190, -167.5184453>,
    <0.2500000, -167.6048705>,
    <0.2360868, -167.6051824>,
    <0.2314815, -167.6737665>,
    <0.2222222, -167.5684558>,
    <0.2222222, -167.7264218>,
    <0.2500000, -167.7264218>,
    <0.2222222, -167.6468904>,
    <0.2361160, -167.7264218>,
    <0.2360887, -167.6473117>,
    <0.2407407, -167.7825485>,
    <0.2222222, -167.7264218>,
    <0.2500000, -167.8948019>,
    <0.2500000, -167.7264218>,
    <0.2360502, -167.8102428>,
    <0.2500000, -167.8064426>,
    <0.2361160, -167.7264218>,
    <0.2314815, -167.5208549>,
    <0.2222222, -167.4256532>,
    <0.2222222, -167.5684558>,
    <0.2500000, -167.5684558>,
    <0.2222222, -167.4961890>,
    <0.2361182, -167.5684558>,
    <0.2360805, -167.4968970>,
    <0.2407407, -167.6211112>,
    <0.2222222, -167.5684558>,
    <0.2500000, -167.7264218>,
    <0.2500000, -167.5684558>,
    <0.2360887, -167.6473117>,
    <0.2500000, -167.6468904>,
    <0.2361182, -167.5684558>,
    <0.2314815, -167.3161845>,
    <0.2222222, -167.2258020>,
    <0.2500000, -167.3613758>,
    <0.2222222, -167.3613758>,
    <0.2360695, -167.2933857>,
    <0.2361211, -167.3613758>,
    <0.2222222, -167.2924560>,
    <0.2407407, -167.4137323>,
    <0.2222222, -167.3613758>,
    <0.2500000, -167.3613758>,
    <0.2500000, -167.5184453>,
    <0.2361211, -167.3613758>,
    <0.2500000, -167.4391507>,
    <0.2360778, -167.4397221>,
    <0.2314815, -167.3845690>,
    <0.2222222, -167.3024008>,
    <0.2222222, -167.4256532>,
    <0.2500000, -167.4256532>,
    <0.2222222, -167.3627833>,
    <0.2361201, -167.4256532>,
    <0.2360729, -167.3638575>,
    <0.2407407, -167.4732541>,
    <0.2222222, -167.4256532>,
    <0.2500000, -167.5684558>,
    <0.2500000, -167.4256532>,
    <0.2360805, -167.4968970>,
    <0.2500000, -167.4961890>,
    <0.2361201, -167.4256532>,
    <0.2314815, -167.1891429>,
    <0.2222222, -167.1158246>,
    <0.2500000, -167.2258020>,
    <0.2222222, -167.2258020>,
    <0.2357740, -167.1694788>,
    <0.2361228, -167.2258020>,
    <0.2222222, -167.1671102>,
    <0.2407407, -167.2709932>,
    <0.2222222, -167.2258020>,
    <0.2500000, -167.2258020>,
    <0.2500000, -167.3613758>,
    <0.2361228, -167.2258020>,
    <0.2500000, -167.2924560>,
    <0.2360695, -167.2933857>,
    <0.2314815, -167.2690732>,
    <0.2222222, -167.2024179>,
    <0.2222222, -167.3024008>,
    <0.2500000, -167.3024008>,
    <0.2222222, -167.2507837>,
    <0.2361217, -167.3024008>,
    <0.2360663, -167.2522483>,
    <0.2407407, -167.3434849>,
    <0.2222222, -167.3024008>,
    <0.2500000, -167.4256532>,
    <0.2500000, -167.3024008>,
    <0.2360729, -167.3638575>,
    <0.2500000, -167.3627833>,
    <0.2361217, -167.3024008>,
    <0.2352878, -167.0842391>,
    <0.2222222, -167.0684463>,
    <0.2336412, -167.0684463>,
    <0.2500000, -167.1158246>,
    <0.2282159, -167.0684463>,
    <0.2433911, -167.0966841>,
    <0.2413697, -167.1011047>,
    <0.2314815, -167.1000319>,
    <0.2222222, -167.0684463>,
    <0.2500000, -167.1158246>,
    <0.2222222, -167.1158246>,
    <0.2413697, -167.1011047>,
    <0.2355417, -167.1158246>,
    <0.2222222, -167.0948736>,
    <0.2407407, -167.1524837>,
    <0.2222222, -167.1158246>,
    <0.2500000, -167.1158246>,
    <0.2500000, -167.2258020>,
    <0.2355417, -167.1158246>,
    <0.2500000, -167.1673791>,
    <0.2357740, -167.1694788>,
    <0.2314815, -167.1778641>,
    <0.2222222, -167.1287564>,
    <0.2222222, -167.2024179>,
    <0.2500000, -167.2024179>,
    <0.2222222, -167.1607154>,
    <0.2361229, -167.2024179>,
    <0.2363501, -167.1662209>,
    <0.2407407, -167.2357456>,
    <0.2222222, -167.2024179>,
    <0.2500000, -167.3024008>,
    <0.2500000, -167.2024179>,
    <0.2360663, -167.2522483>,
    <0.2500000, -167.2507837>,
    <0.2361229, -167.2024179>,
    <0.2445481, -167.0842391>,
    <0.2336443, -167.0684463>,
    <0.2500000, -167.0684463>,
    <0.2500000, -167.1158246>,
    <0.2421413, -167.0684463>,
    <0.2500000, -167.0946262>,
    <0.2433924, -167.0966841>,
    <0.2436641, -167.1123151>,
    <0.2462901, -167.1040945>,
    <0.2347022, -167.1040945>,
    <0.2500000, -167.1287564>,
    <0.2399033, -167.1040945>,
    <0.2463004, -167.1227921>,
    <0.2489978, -167.1220941>,
    <0.2356414, -167.1205358>,
    <0.2347021, -167.1040945>,
    <0.2222222, -167.1287564>,
    <0.2500000, -167.1287564>,
    <0.2250809, -167.1231073>,
    <0.2351415, -167.1287564>,
    <0.2463003, -167.1227921>,
    <0.2407407, -167.1533103>,
    <0.2222222, -167.1287564>,
    <0.2500000, -167.2024179>,
    <0.2500000, -167.1287564>,
    <0.2363501, -167.1662209>,
    <0.2500000, -167.1607153>,
    <0.2351415, -167.1287564>,
    <0.2487634, -167.1123151>,
    <0.2462902, -167.1040945>,
    <0.2500000, -167.1287564>,
    <0.2500000, -167.1040945>,
    <0.2489978, -167.1220941>,
    <0.2500000, -167.1157289>,
    <0.2477580, -167.1040945>,
    <0.2541599, -167.1123151>,
    <0.2624799, -167.1040945>,
    <0.2500000, -167.1040945>,
    <0.2500000, -167.1287564>,
    <0.2561825, -167.1040945>,
    <0.2500000, -167.1157289>,
    <0.2528587, -167.1231073>,
    <0.7449007, -167.1123151>,
    <0.7347022, -167.1040945>,
    <0.7500000, -167.1287564>,
    <0.7500000, -167.1040945>,
    <0.7465293, -167.1231612>,
    <0.7500000, -167.1196784>,
    <0.7427233, -167.1040945>,
    <0.7445481, -167.0842391>,
    <0.7336443, -167.0684463>,
    <0.7500000, -167.0684463>,
    <0.7500000, -167.1158246>,
    <0.7421450, -167.0684463>,
    <0.7500000, -167.0943971>,
    <0.7433906, -167.0966789>,
    <0.2592592, -168.0047729>,
    <0.2500000, -167.8774261>,
    <0.2777778, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2603637, -167.9486945>,
    <0.2675076, -168.0684463>,
    <0.2500000, -167.9862701>,
    <0.2592592, -167.8156918>,
    <0.2500000, -167.6922232>,
    <0.2777778, -167.8774261>,
    <0.2500000, -167.8774261>,
    <0.2638252, -167.7844001>,
    <0.2639026, -167.8774261>,
    <0.2500000, -167.7805911>,
    <0.2685185, -167.9410995>,
    <0.2500000, -167.8774261>,
    <0.2777778, -167.8774261>,
    <0.2777778, -168.0684463>,
    <0.2639026, -167.8774261>,
    <0.2777778, -167.9408490>,
    <0.2603637, -167.9486945>,
    <0.7314815, -168.0047729>,
    <0.7222222, -167.8774261>,
    <0.7500000, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7351919, -167.9666152>,
    <0.7413667, -168.0684463>,
    <0.7222222, -167.9852586>,
    <0.7407408, -167.9410995>,
    <0.7222222, -167.8774261>,
    <0.7500000, -167.8774261>,
    <0.7500000, -168.0684463>,
    <0.7361319, -167.8774261>,
    <0.7500000, -167.9706945>,
    <0.7351919, -167.9666152>,
    <0.2592592, -167.6342972>,
    <0.2500000, -167.5184453>,
    <0.2777778, -167.6922232>,
    <0.2500000, -167.6922232>,
    <0.2638646, -167.6051824>,
    <0.2638943, -167.6922232>,
    <0.2500000, -167.6048705>,
    <0.2685185, -167.7539575>,
    <0.2500000, -167.6922232>,
    <0.2777778, -167.6922232>,
    <0.2777778, -167.8774261>,
    <0.2638943, -167.6922232>,
    <0.2777778, -167.7805759>,
    <0.2638252, -167.7844001>,
    <0.7314815, -167.8156918>,
    <0.7222222, -167.6922232>,
    <0.7500000, -167.8774261>,
    <0.7222222, -167.8774261>,
    <0.7360346, -167.7843145>,
    <0.7361319, -167.8774261>,
    <0.7222222, -167.7804696>,
    <0.7407408, -167.7539575>,
    <0.7222222, -167.6922232>,
    <0.7500000, -167.6922232>,
    <0.7500000, -167.8774261>,
    <0.7361165, -167.6922232>,
    <0.7500000, -167.7804832>,
    <0.7360346, -167.7843145>,
    <0.2592592, -168.0105648>,
    <0.2500000, -167.8948019>,
    <0.2500000, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2500000, -167.9369669>,
    <0.2638889, -168.0684463>,
    <0.2603668, -167.9596070>,
    <0.2592592, -167.8386752>,
    <0.2500000, -167.7264218>,
    <0.2500000, -167.8948019>,
    <0.2777778, -167.8948019>,
    <0.2500000, -167.8064426>,
    <0.2639024, -167.8948019>,
    <0.2638287, -167.8102469>,
    <0.2685185, -167.9526834>,
    <0.2500000, -167.8948019>,
    <0.2777778, -168.0684463>,
    <0.2777778, -167.8948019>,
    <0.2603668, -167.9596070>,
    <0.2777778, -167.9523852>,
    <0.2639024, -167.8948019>,
    <0.7314815, -168.0105648>,
    <0.7222222, -167.8948019>,
    <0.7222222, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7222222, -167.9865060>,
    <0.7363135, -168.0684463>,
    <0.7331532, -167.9631338>,
    <0.7407408, -167.9526834>,
    <0.7222222, -167.8948019>,
    <0.7500000, -168.0684463>,
    <0.7500000, -167.8948019>,
    <0.7331532, -167.9631338>,
    <0.7500000, -167.9893072>,
    <0.7361316, -167.8948019>,
    <0.2592593, -167.4660888>,
    <0.2500000, -167.3613758>,
    <0.2777778, -167.5184453>,
    <0.2500000, -167.5184453>,
    <0.2638556, -167.4397221>,
    <0.2638967, -167.5184453>,
    <0.2500000, -167.4391507>,
    <0.2685185, -167.5763713>,
    <0.2500000, -167.5184453>,
    <0.2777778, -167.5184453>,
    <0.2777778, -167.6922232>,
    <0.2638967, -167.5184453>,
    <0.2777778, -167.6048705>,
    <0.2638646, -167.6051824>,
    <0.7314815, -167.6342972>,
    <0.7222222, -167.5184453>,
    <0.7500000, -167.6922232>,
    <0.7222222, -167.6922232>,
    <0.7360868, -167.6051824>,
    <0.7361165, -167.6922232>,
    <0.7222222, -167.6048705>,
    <0.7407408, -167.5763713>,
    <0.7222222, -167.5184453>,
    <0.7500000, -167.5184453>,
    <0.7500000, -167.6922232>,
    <0.7361190, -167.5184453>,
    <0.7500000, -167.6048705>,
    <0.7360868, -167.6051824>,
    <0.2592592, -167.6737665>,
    <0.2500000, -167.5684558>,
    <0.2500000, -167.7264218>,
    <0.2777778, -167.7264218>,
    <0.2500000, -167.6468904>,
    <0.2638938, -167.7264218>,
    <0.2638665, -167.6473117>,
    <0.2685185, -167.7825485>,
    <0.2500000, -167.7264218>,
    <0.2777778, -167.8948019>,
    <0.2777778, -167.7264218>,
    <0.2638287, -167.8102469>,
    <0.2777778, -167.8064264>,
    <0.2638938, -167.7264218>,
    <0.7314815, -167.8386752>,
    <0.7222222, -167.7264218>,
    <0.7222222, -167.8948019>,
    <0.7500000, -167.8948019>,
    <0.7222222, -167.8063127>,
    <0.7361316, -167.8948019>,
    <0.7360381, -167.8101695>,
    <0.7407408, -167.7825485>,
    <0.7222222, -167.7264218>,
    <0.7500000, -167.8948019>,
    <0.7500000, -167.7264218>,
    <0.7360381, -167.8101695>,
    <0.7500000, -167.8063273>,
    <0.7361160, -167.7264218>,
    <0.2592592, -167.5208549>,
    <0.2500000, -167.4256532>,
    <0.2500000, -167.5684558>,
    <0.2777778, -167.5684558>,
    <0.2500000, -167.4961890>,
    <0.2638960, -167.5684558>,
    <0.2638582, -167.4968970>,
    <0.2685185, -167.6211112>,
    <0.2500000, -167.5684558>,
    <0.2777778, -167.7264218>,
    <0.2777778, -167.5684558>,
    <0.2638665, -167.6473117>,
    <0.2777778, -167.6468904>,
    <0.2638960, -167.5684558>,
    <0.7314815, -167.6737665>,
    <0.7222222, -167.5684558>,
    <0.7222222, -167.7264218>,
    <0.7500000, -167.7264218>,
    <0.7222222, -167.6468904>,
    <0.7361160, -167.7264218>,
    <0.7360888, -167.6473117>,
    <0.7407408, -167.6211112>,
    <0.7222222, -167.5684558>,
    <0.7500000, -167.7264218>,
    <0.7500000, -167.5684558>,
    <0.7360888, -167.6473117>,
    <0.7500000, -167.6468904>,
    <0.7361182, -167.5684558>,
    <0.2592592, -167.3161845>,
    <0.2500000, -167.2258020>,
    <0.2777778, -167.3613758>,
    <0.2500000, -167.3613758>,
    <0.2638472, -167.2933857>,
    <0.2638989, -167.3613758>,
    <0.2500000, -167.2924560>,
    <0.2685185, -167.4137323>,
    <0.2500000, -167.3613758>,
    <0.2777778, -167.3613758>,
    <0.2777778, -167.5184453>,
    <0.2638989, -167.3613758>,
    <0.2777778, -167.4391507>,
    <0.2638556, -167.4397221>,
    <0.7314815, -167.4660888>,
    <0.7222222, -167.3613758>,
    <0.7500000, -167.5184453>,
    <0.7222222, -167.5184453>,
    <0.7360778, -167.4397221>,
    <0.7361190, -167.5184453>,
    <0.7222222, -167.4391507>,
    <0.7407408, -167.4137323>,
    <0.7222222, -167.3613758>,
    <0.7500000, -167.3613758>,
    <0.7500000, -167.5184453>,
    <0.7361211, -167.3613758>,
    <0.7500000, -167.4391507>,
    <0.7360778, -167.4397221>,
    <0.2592592, -167.3845690>,
    <0.2500000, -167.3024008>,
    <0.2500000, -167.4256532>,
    <0.2777778, -167.4256532>,
    <0.2500000, -167.3627833>,
    <0.2638979, -167.4256532>,
    <0.2638507, -167.3638575>,
    <0.2685185, -167.4732541>,
    <0.2500000, -167.4256532>,
    <0.2777778, -167.5684558>,
    <0.2777778, -167.4256532>,
    <0.2638582, -167.4968970>,
    <0.2777778, -167.4961890>,
    <0.2638979, -167.4256532>,
    <0.7314815, -167.5208549>,
    <0.7222222, -167.4256532>,
    <0.7222222, -167.5684558>,
    <0.7500000, -167.5684558>,
    <0.7222222, -167.4961890>,
    <0.7361182, -167.5684558>,
    <0.7360805, -167.4968970>,
    <0.7407408, -167.4732541>,
    <0.7222222, -167.4256532>,
    <0.7500000, -167.5684558>,
    <0.7500000, -167.4256532>,
    <0.7360805, -167.4968970>,
    <0.7500000, -167.4961890>,
    <0.7361201, -167.4256532>,
    <0.2592593, -167.1891429>,
    <0.2500000, -167.1158246>,
    <0.2777778, -167.2258020>,
    <0.2500000, -167.2258020>,
    <0.2635578, -167.1695025>,
    <0.2639006, -167.2258020>,
    <0.2500000, -167.1673791>,
    <0.2685185, -167.2709932>,
    <0.2500000, -167.2258020>,
    <0.2777778, -167.2258020>,
    <0.2777778, -167.3613758>,
    <0.2639006, -167.2258020>,
    <0.2777778, -167.2924560>,
    <0.2638472, -167.2933857>,
    <0.7314815, -167.3161845>,
    <0.7222222, -167.2258020>,
    <0.7500000, -167.3613758>,
    <0.7222222, -167.3613758>,
    <0.7360695, -167.2933857>,
    <0.7361211, -167.3613758>,
    <0.7222222, -167.2924560>,
    <0.7407407, -167.2709932>,
    <0.7222222, -167.2258020>,
    <0.7500000, -167.2258020>,
    <0.7500000, -167.3613758>,
    <0.7361229, -167.2258020>,
    <0.7500000, -167.2924560>,
    <0.7360695, -167.2933857>,
    <0.2592592, -167.2690732>,
    <0.2500000, -167.2024179>,
    <0.2500000, -167.3024008>,
    <0.2777778, -167.3024008>,
    <0.2500000, -167.2507837>,
    <0.2638995, -167.3024008>,
    <0.2638441, -167.2522483>,
    <0.2685185, -167.3434849>,
    <0.2500000, -167.3024008>,
    <0.2777778, -167.4256532>,
    <0.2777778, -167.3024008>,
    <0.2638507, -167.3638575>,
    <0.2777778, -167.3627833>,
    <0.2638995, -167.3024008>,
    <0.7314815, -167.3845690>,
    <0.7222222, -167.3024008>,
    <0.7222222, -167.4256532>,
    <0.7500000, -167.4256532>,
    <0.7222222, -167.3627833>,
    <0.7361201, -167.4256532>,
    <0.7360729, -167.3638575>,
    <0.7407408, -167.3434849>,
    <0.7222222, -167.3024008>,
    <0.7500000, -167.4256532>,
    <0.7500000, -167.3024008>,
    <0.7360729, -167.3638575>,
    <0.7500000, -167.3627833>,
    <0.7361217, -167.3024008>,
    <0.2592592, -167.1000319>,
    <0.2500000, -167.0684463>,
    <0.2777778, -167.1158246>,
    <0.2500000, -167.1158246>,
    <0.2692576, -167.1012925>,
    <0.2633084, -167.1158246>,
    <0.2500000, -167.0946262>,
    <0.2630656, -167.0842391>,
    <0.2500000, -167.0684463>,
    <0.2614190, -167.0684463>,
    <0.2777778, -167.1158246>,
    <0.2557095, -167.0684463>,
    <0.2706130, -167.0950739>,
    <0.2692576, -167.1012925>,
    <0.2685185, -167.1524837>,
    <0.2500000, -167.1158246>,
    <0.2777778, -167.1158246>,
    <0.2777778, -167.2258020>,
    <0.2633084, -167.1158246>,
    <0.2777778, -167.1668695>,
    <0.2635578, -167.1695025>,
    <0.7314815, -167.1891429>,
    <0.7222222, -167.1158246>,
    <0.7500000, -167.2258020>,
    <0.7222222, -167.2258020>,
    <0.7357809, -167.1695057>,
    <0.7361229, -167.2258020>,
    <0.7222222, -167.1674336>,
    <0.7407408, -167.1524837>,
    <0.7222222, -167.1158246>,
    <0.7500000, -167.1158246>,
    <0.7500000, -167.2258020>,
    <0.7355453, -167.1158246>,
    <0.7500000, -167.1673835>,
    <0.7357809, -167.1695057>,
    <0.2592593, -167.1778641>,
    <0.2500000, -167.1287564>,
    <0.2500000, -167.2024179>,
    <0.2777778, -167.2024179>,
    <0.2500000, -167.1607153>,
    <0.2639007, -167.2024179>,
    <0.2641279, -167.1662209>,
    <0.2685185, -167.2357456>,
    <0.2500000, -167.2024179>,
    <0.2777778, -167.3024008>,
    <0.2777778, -167.2024179>,
    <0.2638441, -167.2522483>,
    <0.2777778, -167.2507837>,
    <0.2639007, -167.2024179>,
    <0.7314815, -167.2690732>,
    <0.7222222, -167.2024179>,
    <0.7222222, -167.3024008>,
    <0.7500000, -167.3024008>,
    <0.7222222, -167.2507837>,
    <0.7361217, -167.3024008>,
    <0.7360664, -167.2522483>,
    <0.7407407, -167.2357456>,
    <0.7222222, -167.2024179>,
    <0.7500000, -167.3024008>,
    <0.7500000, -167.2024179>,
    <0.7360664, -167.2522483>,
    <0.7500000, -167.2507837>,
    <0.7361229, -167.2024179>,
    <0.2723248, -167.0842391>,
    <0.2614190, -167.0684463>,
    <0.2777778, -167.0684463>,
    <0.2777778, -167.1158246>,
    <0.2695984, -167.0684463>,
    <0.2777778, -167.0959009>,
    <0.2706130, -167.0950739>,
    <0.7314815, -167.1000319>,
    <0.7222222, -167.0684463>,
    <0.7500000, -167.1158246>,
    <0.7222222, -167.1158246>,
    <0.7413813, -167.1011243>,
    <0.7355453, -167.1158246>,
    <0.7222222, -167.0946389>,
    <0.7352878, -167.0842391>,
    <0.7222222, -167.0684463>,
    <0.7336412, -167.0684463>,
    <0.7500000, -167.1158246>,
    <0.7282212, -167.0684463>,
    <0.7433894, -167.0966789>,
    <0.7413813, -167.1011243>,
    <0.2714419, -167.1123151>,
    <0.2740679, -167.1040945>,
    <0.2624800, -167.1040945>,
    <0.2777778, -167.1287564>,
    <0.2676812, -167.1040945>,
    <0.2740782, -167.1227923>,
    <0.2767756, -167.1220941>,
    <0.2634192, -167.1205358>,
    <0.2624799, -167.1040945>,
    <0.2500000, -167.1287564>,
    <0.2777778, -167.1287564>,
    <0.2528587, -167.1231073>,
    <0.2629193, -167.1287564>,
    <0.2740782, -167.1227923>,
    <0.2685185, -167.1533103>,
    <0.2500000, -167.1287564>,
    <0.2777778, -167.2024179>,
    <0.2777778, -167.1287564>,
    <0.2641279, -167.1662209>,
    <0.2777778, -167.1607153>,
    <0.2629193, -167.1287564>,
    <0.7314815, -167.1778641>,
    <0.7222222, -167.1287564>,
    <0.7222222, -167.2024179>,
    <0.7500000, -167.2024179>,
    <0.7222222, -167.1601023>,
    <0.7361229, -167.2024179>,
    <0.7364434, -167.1664684>,
    <0.7407408, -167.1533103>,
    <0.7222222, -167.1287564>,
    <0.7500000, -167.2024179>,
    <0.7500000, -167.1287564>,
    <0.7364434, -167.1664684>,
    <0.7500000, -167.1605800>,
    <0.7353840, -167.1287564>,
    <0.7356415, -167.1205421>,
    <0.7347021, -167.1041136>,
    <0.7222222, -167.1287564>,
    <0.7500000, -167.1287564>,
    <0.7253930, -167.1224954>,
    <0.7353840, -167.1287564>,
    <0.7465293, -167.1231655>,
    <0.7273344, -167.1123279>,
    <0.7347021, -167.1041136>,
    <0.7250789, -167.1041136>,
    <0.7222222, -167.1287564>,
    <0.7306788, -167.1041136>,
    <0.7232398, -167.1199785>,
    <0.7253930, -167.1224954>,
    <0.2765412, -167.1123151>,
    <0.2740679, -167.1040945>,
    <0.2777778, -167.1287564>,
    <0.2777778, -167.1040945>,
    <0.2767756, -167.1220941>,
    <0.2777778, -167.1157281>,
    <0.2755358, -167.1040945>,
    <0.7231745, -167.1123215>,
    <0.7250789, -167.1041136>,
    <0.7222222, -167.1040945>,
    <0.7222222, -167.1287564>,
    <0.7239755, -167.1041062>,
    <0.7222222, -167.1186953>,
    <0.7232398, -167.1199785>,
    <0.2819377, -167.1123151>,
    <0.2902576, -167.1040945>,
    <0.2777778, -167.1040945>,
    <0.2777778, -167.1287564>,
    <0.2839603, -167.1040945>,
    <0.2777778, -167.1157281>,
    <0.2806364, -167.1231073>,
    <0.7171229, -167.1123151>,
    <0.7069243, -167.1040945>,
    <0.7222222, -167.1287564>,
    <0.7222222, -167.1040945>,
    <0.7187224, -167.1231143>,
    <0.7222222, -167.1186953>,
    <0.7149455, -167.1040945>,
    <0.7167693, -167.0842391>,
    <0.7058635, -167.0684463>,
    <0.7222222, -167.0684463>,
    <0.7222222, -167.1158246>,
    <0.7143632, -167.0684463>,
    <0.7222222, -167.0946389>,
    <0.7156116, -167.0966788>,
    <0.2870370, -168.0047729>,
    <0.2777778, -167.8774261>,
    <0.3055555, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2881415, -167.9486944>,
    <0.2916667, -168.0684463>,
    <0.2777778, -167.9408490>,
    <0.2870370, -167.8156918>,
    <0.2777778, -167.6922232>,
    <0.3055555, -167.8774261>,
    <0.2777778, -167.8774261>,
    <0.2916034, -167.7844031>,
    <0.2916800, -167.8774261>,
    <0.2777778, -167.7805759>,
    <0.2962963, -167.9410995>,
    <0.2777778, -167.8774261>,
    <0.3055555, -167.8774261>,
    <0.3055555, -168.0684463>,
    <0.2916800, -167.8774261>,
    <0.3055555, -167.9407972>,
    <0.2881415, -167.9486944>,
    <0.7037037, -168.0047729>,
    <0.6944445, -167.8774261>,
    <0.7222222, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6975117, -167.8985187>,
    <0.7047146, -168.0684463>,
    <0.6944445, -167.9401814>,
    <0.7129630, -167.9410995>,
    <0.6944445, -167.8774261>,
    <0.7222222, -167.8774261>,
    <0.7222222, -168.0684463>,
    <0.7083535, -167.8774261>,
    <0.7222222, -167.9852586>,
    <0.6975117, -167.8985187>,
    <0.2870370, -167.6342972>,
    <0.2777778, -167.5184453>,
    <0.3055555, -167.6922232>,
    <0.2777778, -167.6922232>,
    <0.2916424, -167.6051824>,
    <0.2916721, -167.6922232>,
    <0.2777778, -167.6048705>,
    <0.2962963, -167.7539575>,
    <0.2777778, -167.6922232>,
    <0.3055555, -167.6922232>,
    <0.3055555, -167.8774261>,
    <0.2916721, -167.6922232>,
    <0.3055555, -167.7805596>,
    <0.2916034, -167.7844031>,
    <0.7037037, -167.8156918>,
    <0.6944445, -167.6922232>,
    <0.7222222, -167.8774261>,
    <0.6944445, -167.8774261>,
    <0.7082577, -167.7843202>,
    <0.7083535, -167.8774261>,
    <0.6944445, -167.7804581>,
    <0.7129630, -167.7539575>,
    <0.6944445, -167.6922232>,
    <0.7222222, -167.6922232>,
    <0.7222222, -167.8774261>,
    <0.7083388, -167.6922232>,
    <0.7222222, -167.7804696>,
    <0.7082577, -167.7843202>,
    <0.2870370, -168.0105648>,
    <0.2777778, -167.8948019>,
    <0.2777778, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.2777778, -167.9523852>,
    <0.2916667, -168.0684463>,
    <0.2881446, -167.9596072>,
    <0.2870370, -167.8386752>,
    <0.2777778, -167.7264218>,
    <0.2777778, -167.8948019>,
    <0.3055555, -167.8948019>,
    <0.2777778, -167.8064264>,
    <0.2916798, -167.8948019>,
    <0.2916069, -167.8102497>,
    <0.2962963, -167.9526834>,
    <0.2777778, -167.8948019>,
    <0.3055555, -168.0684463>,
    <0.3055555, -167.8948019>,
    <0.2881446, -167.9596072>,
    <0.3055555, -167.9523352>,
    <0.2916798, -167.8948019>,
    <0.7037037, -168.0105648>,
    <0.6944445, -167.8948019>,
    <0.6944445, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.6944445, -167.9517372>,
    <0.7055227, -168.0684463>,
    <0.6986317, -167.9209770>,
    <0.7129630, -167.9526834>,
    <0.6944445, -167.8948019>,
    <0.7222222, -168.0684463>,
    <0.7222222, -167.8948019>,
    <0.6986317, -167.9209770>,
    <0.7222222, -167.9865060>,
    <0.7083532, -167.8948019>,
    <0.2870370, -167.4660888>,
    <0.2777778, -167.3613758>,
    <0.3055555, -167.5184453>,
    <0.2777778, -167.5184453>,
    <0.2916333, -167.4397221>,
    <0.2916745, -167.5184453>,
    <0.2777778, -167.4391507>,
    <0.2962963, -167.5763713>,
    <0.2777778, -167.5184453>,
    <0.3055555, -167.5184453>,
    <0.3055555, -167.6922232>,
    <0.2916745, -167.5184453>,
    <0.3055555, -167.6048705>,
    <0.2916424, -167.6051824>,
    <0.7037037, -167.6342972>,
    <0.6944445, -167.5184453>,
    <0.7222222, -167.6922232>,
    <0.6944445, -167.6922232>,
    <0.7083091, -167.6051824>,
    <0.7083388, -167.6922232>,
    <0.6944445, -167.6048705>,
    <0.7129630, -167.5763713>,
    <0.6944445, -167.5184453>,
    <0.7222222, -167.5184453>,
    <0.7222222, -167.6922232>,
    <0.7083412, -167.5184453>,
    <0.7222222, -167.6048705>,
    <0.7083091, -167.6051824>,
    <0.2870370, -167.6737665>,
    <0.2777778, -167.5684558>,
    <0.2777778, -167.7264218>,
    <0.3055555, -167.7264218>,
    <0.2777778, -167.6468904>,
    <0.2916715, -167.7264218>,
    <0.2916443, -167.6473117>,
    <0.2962963, -167.7825485>,
    <0.2777778, -167.7264218>,
    <0.3055555, -167.8948019>,
    <0.3055555, -167.7264218>,
    <0.2916069, -167.8102497>,
    <0.3055555, -167.8064088>,
    <0.2916715, -167.7264218>,
    <0.7037037, -167.8386752>,
    <0.6944445, -167.7264218>,
    <0.6944445, -167.8948019>,
    <0.7222222, -167.8948019>,
    <0.6944445, -167.8063003>,
    <0.7083532, -167.8948019>,
    <0.7082612, -167.8101747>,
    <0.7129630, -167.7825485>,
    <0.6944445, -167.7264218>,
    <0.7222222, -167.8948019>,
    <0.7222222, -167.7264218>,
    <0.7082612, -167.8101747>,
    <0.7222222, -167.8063127>,
    <0.7083382, -167.7264218>,
    <0.2870370, -167.5208549>,
    <0.2777778, -167.4256532>,
    <0.2777778, -167.5684558>,
    <0.3055555, -167.5684558>,
    <0.2777778, -167.4961890>,
    <0.2916737, -167.5684558>,
    <0.2916360, -167.4968970>,
    <0.2962963, -167.6211112>,
    <0.2777778, -167.5684558>,
    <0.3055555, -167.7264218>,
    <0.3055555, -167.5684558>,
    <0.2916443, -167.6473117>,
    <0.3055555, -167.6468904>,
    <0.2916737, -167.5684558>,
    <0.7037037, -167.6737665>,
    <0.6944445, -167.5684558>,
    <0.6944445, -167.7264218>,
    <0.7222222, -167.7264218>,
    <0.6944445, -167.6468904>,
    <0.7083382, -167.7264218>,
    <0.7083110, -167.6473117>,
    <0.7129630, -167.6211112>,
    <0.6944445, -167.5684558>,
    <0.7222222, -167.7264218>,
    <0.7222222, -167.5684558>,
    <0.7083110, -167.6473117>,
    <0.7222222, -167.6468904>,
    <0.7083404, -167.5684558>,
    <0.2870370, -167.3161845>,
    <0.2777778, -167.2258020>,
    <0.3055555, -167.3613758>,
    <0.2777778, -167.3613758>,
    <0.2916250, -167.2933857>,
    <0.2916766, -167.3613758>,
    <0.2777778, -167.2924560>,
    <0.2962963, -167.4137323>,
    <0.2777778, -167.3613758>,
    <0.3055555, -167.3613758>,
    <0.3055555, -167.5184453>,
    <0.2916766, -167.3613758>,
    <0.3055555, -167.4391507>,
    <0.2916333, -167.4397221>,
    <0.7037037, -167.4660888>,
    <0.6944445, -167.3613758>,
    <0.7222222, -167.5184453>,
    <0.6944445, -167.5184453>,
    <0.7083000, -167.4397221>,
    <0.7083412, -167.5184453>,
    <0.6944445, -167.4391507>,
    <0.7129630, -167.4137323>,
    <0.6944445, -167.3613758>,
    <0.7222222, -167.3613758>,
    <0.7222222, -167.5184453>,
    <0.7083433, -167.3613758>,
    <0.7222222, -167.4391507>,
    <0.7083000, -167.4397221>,
    <0.2870370, -167.3845690>,
    <0.2777778, -167.3024008>,
    <0.2777778, -167.4256532>,
    <0.3055555, -167.4256532>,
    <0.2777778, -167.3627833>,
    <0.2916757, -167.4256532>,
    <0.2916285, -167.3638575>,
    <0.2962963, -167.4732541>,
    <0.2777778, -167.4256532>,
    <0.3055555, -167.5684558>,
    <0.3055555, -167.4256532>,
    <0.2916360, -167.4968970>,
    <0.3055555, -167.4961890>,
    <0.2916757, -167.4256532>,
    <0.7037037, -167.5208549>,
    <0.6944445, -167.4256532>,
    <0.6944445, -167.5684558>,
    <0.7222222, -167.5684558>,
    <0.6944445, -167.4961890>,
    <0.7083404, -167.5684558>,
    <0.7083027, -167.4968970>,
    <0.7129630, -167.4732541>,
    <0.6944445, -167.4256532>,
    <0.7222222, -167.5684558>,
    <0.7222222, -167.4256532>,
    <0.7083027, -167.4968970>,
    <0.7222222, -167.4961890>,
    <0.7083423, -167.4256532>,
    <0.2870370, -167.1891429>,
    <0.2777778, -167.1158246>,
    <0.3055555, -167.2258020>,
    <0.2777778, -167.2258020>,
    <0.2913189, -167.1694365>,
    <0.2916784, -167.2258020>,
    <0.2777778, -167.1668695>,
    <0.2962963, -167.2709932>,
    <0.2777778, -167.2258020>,
    <0.3055555, -167.2258020>,
    <0.3055555, -167.3613758>,
    <0.2916784, -167.2258020>,
    <0.3055555, -167.2924560>,
    <0.2916250, -167.2933857>,
    <0.7037037, -167.3161845>,
    <0.6944445, -167.2258020>,
    <0.7222222, -167.3613758>,
    <0.6944445, -167.3613758>,
    <0.7082917, -167.2933857>,
    <0.7083433, -167.3613758>,
    <0.6944445, -167.2924560>,
    <0.7129630, -167.2709932>,
    <0.6944445, -167.2258020>,
    <0.7222222, -167.2258020>,
    <0.7222222, -167.3613758>,
    <0.7083451, -167.2258020>,
    <0.7222222, -167.2924560>,
    <0.7082917, -167.2933857>,
    <0.2870370, -167.2690732>,
    <0.2777778, -167.2024179>,
    <0.2777778, -167.3024008>,
    <0.3055555, -167.3024008>,
    <0.2777778, -167.2507837>,
    <0.2916773, -167.3024008>,
    <0.2916219, -167.2522483>,
    <0.2962963, -167.3434849>,
    <0.2777778, -167.3024008>,
    <0.3055555, -167.4256532>,
    <0.3055555, -167.3024008>,
    <0.2916285, -167.3638575>,
    <0.3055555, -167.3627833>,
    <0.2916773, -167.3024008>,
    <0.7037037, -167.3845690>,
    <0.6944445, -167.3024008>,
    <0.6944445, -167.4256532>,
    <0.7222222, -167.4256532>,
    <0.6944445, -167.3627833>,
    <0.7083423, -167.4256532>,
    <0.7082952, -167.3638575>,
    <0.7129630, -167.3434849>,
    <0.6944445, -167.3024008>,
    <0.7222222, -167.4256532>,
    <0.7222222, -167.3024008>,
    <0.7082952, -167.3638575>,
    <0.7222222, -167.3627833>,
    <0.7083439, -167.3024008>,
    <0.2908423, -167.0842391>,
    <0.2777778, -167.0684463>,
    <0.2891937, -167.0684463>,
    <0.3055555, -167.1158246>,
    <0.2834857, -167.0684463>,
    <0.2983904, -167.0950767>,
    <0.2970358, -167.1012933>,
    <0.2870370, -167.1000319>,
    <0.2777778, -167.0684463>,
    <0.3055555, -167.1158246>,
    <0.2777778, -167.1158246>,
    <0.2970358, -167.1012933>,
    <0.2910710, -167.1158246>,
    <0.2777778, -167.0959009>,
    <0.2962963, -167.1524837>,
    <0.2777778, -167.1158246>,
    <0.3055555, -167.1158246>,
    <0.3055555, -167.2258020>,
    <0.2910710, -167.1158246>,
    <0.3055555, -167.1668348>,
    <0.2913189, -167.1694365>,
    <0.7037037, -167.1891429>,
    <0.6944445, -167.1158246>,
    <0.7222222, -167.2258020>,
    <0.6944445, -167.2258020>,
    <0.7080028, -167.1695048>,
    <0.7083451, -167.2258020>,
    <0.6944445, -167.1673989>,
    <0.7129630, -167.1524837>,
    <0.6944445, -167.1158246>,
    <0.7222222, -167.1158246>,
    <0.7222222, -167.2258020>,
    <0.7077681, -167.1158246>,
    <0.7222222, -167.1674336>,
    <0.7080028, -167.1695048>,
    <0.2870370, -167.1778641>,
    <0.2777778, -167.1287564>,
    <0.2777778, -167.2024179>,
    <0.3055555, -167.2024179>,
    <0.2777778, -167.1607153>,
    <0.2916785, -167.2024179>,
    <0.2919056, -167.1662209>,
    <0.2962963, -167.2357456>,
    <0.2777778, -167.2024179>,
    <0.3055555, -167.3024008>,
    <0.3055555, -167.2024179>,
    <0.2916219, -167.2522483>,
    <0.3055555, -167.2507837>,
    <0.2916785, -167.2024179>,
    <0.7037037, -167.2690732>,
    <0.6944445, -167.2024179>,
    <0.6944445, -167.3024008>,
    <0.7222222, -167.3024008>,
    <0.6944445, -167.2507837>,
    <0.7083439, -167.3024008>,
    <0.7082886, -167.2522483>,
    <0.7129630, -167.2357456>,
    <0.6944445, -167.2024179>,
    <0.7222222, -167.3024008>,
    <0.7222222, -167.2024179>,
    <0.7082886, -167.2522483>,
    <0.7222222, -167.2507837>,
    <0.7083452, -167.2024179>,
    <0.3001016, -167.0842391>,
    <0.2891937, -167.0684463>,
    <0.3055555, -167.0684463>,
    <0.3055555, -167.1158246>,
    <0.2973746, -167.0684463>,
    <0.3055555, -167.0957980>,
    <0.2983904, -167.0950767>,
    <0.7037037, -167.1000319>,
    <0.6944445, -167.0684463>,
    <0.7222222, -167.1158246>,
    <0.6944445, -167.1158246>,
    <0.7135993, -167.1011172>,
    <0.7077681, -167.1158246>,
    <0.6944445, -167.0945365>,
    <0.7075090, -167.0842391>,
    <0.6944445, -167.0684463>,
    <0.7058604, -167.0684463>,
    <0.7222222, -167.1158246>,
    <0.7004396, -167.0684463>,
    <0.7156103, -167.0966788>,
    <0.7135993, -167.1011172>,
    <0.2992196, -167.1123151>,
    <0.3018457, -167.1040945>,
    <0.2902576, -167.1040945>,
    <0.3055555, -167.1287564>,
    <0.2954588, -167.1040945>,
    <0.3018559, -167.1227922>,
    <0.3045534, -167.1220942>,
    <0.2911970, -167.1205358>,
    <0.2902576, -167.1040945>,
    <0.2777778, -167.1287564>,
    <0.3055555, -167.1287564>,
    <0.2806364, -167.1231073>,
    <0.2906971, -167.1287564>,
    <0.3018559, -167.1227922>,
    <0.2962963, -167.1533103>,
    <0.2777778, -167.1287564>,
    <0.3055555, -167.2024179>,
    <0.3055555, -167.1287564>,
    <0.2919056, -167.1662209>,
    <0.3055555, -167.1607154>,
    <0.2906971, -167.1287564>,
    <0.6995566, -167.1123279>,
    <0.7069243, -167.1041136>,
    <0.6973011, -167.1041136>,
    <0.6944445, -167.1287564>,
    <0.7029010, -167.1041136>,
    <0.6954621, -167.1199782>,
    <0.6976153, -167.1224952>,
    <0.7037037, -167.1778641>,
    <0.6944445, -167.1287564>,
    <0.6944445, -167.2024179>,
    <0.7222222, -167.2024179>,
    <0.6944445, -167.1601024>,
    <0.7083452, -167.2024179>,
    <0.7086656, -167.1664683>,
    <0.7078637, -167.1205421>,
    <0.7069243, -167.1041136>,
    <0.6944445, -167.1287564>,
    <0.7222222, -167.1287564>,
    <0.6976153, -167.1224952>,
    <0.7075446, -167.1287564>,
    <0.7187224, -167.1231187>,
    <0.7129630, -167.1533103>,
    <0.6944445, -167.1287564>,
    <0.7222222, -167.2024179>,
    <0.7222222, -167.1287564>,
    <0.7086656, -167.1664683>,
    <0.7222222, -167.1601023>,
    <0.7075446, -167.1287564>,
    <0.3043189, -167.1123151>,
    <0.3018457, -167.1040945>,
    <0.3055555, -167.1287564>,
    <0.3055555, -167.1040945>,
    <0.3045534, -167.1220942>,
    <0.3055555, -167.1157254>,
    <0.3033135, -167.1040945>,
    <0.6953967, -167.1123215>,
    <0.6973011, -167.1041136>,
    <0.6944445, -167.1040945>,
    <0.6944445, -167.1287564>,
    <0.6961975, -167.1041062>,
    <0.6944445, -167.1186987>,
    <0.6954621, -167.1199782>,
    <0.3097155, -167.1123151>,
    <0.3180354, -167.1040945>,
    <0.3055555, -167.1040945>,
    <0.3055555, -167.1287564>,
    <0.3117380, -167.1040945>,
    <0.3055555, -167.1157254>,
    <0.3084142, -167.1231073>,
    <0.6889915, -167.0842391>,
    <0.6780857, -167.0684463>,
    <0.6944445, -167.0684463>,
    <0.6944445, -167.1158246>,
    <0.6865862, -167.0684463>,
    <0.6944445, -167.0945365>,
    <0.6878343, -167.0966801>,
    <0.6893451, -167.1123151>,
    <0.6791465, -167.1040945>,
    <0.6944445, -167.1287564>,
    <0.6944445, -167.1040945>,
    <0.6909447, -167.1231144>,
    <0.6944445, -167.1186987>,
    <0.6871677, -167.1040945>,
    <0.3148148, -168.0047729>,
    <0.3055555, -167.8774261>,
    <0.3333333, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3159189, -167.9486921>,
    <0.3194444, -168.0684463>,
    <0.3055555, -167.9407972>,
    <0.3148148, -167.8156918>,
    <0.3055555, -167.6922232>,
    <0.3333333, -167.8774261>,
    <0.3055555, -167.8774261>,
    <0.3193814, -167.7844046>,
    <0.3194576, -167.8774261>,
    <0.3055555, -167.7805596>,
    <0.3240741, -167.9410995>,
    <0.3055555, -167.8774261>,
    <0.3333333, -167.8774261>,
    <0.3333333, -168.0684463>,
    <0.3194576, -167.8774261>,
    <0.3333333, -167.9407369>,
    <0.3159189, -167.9486921>,
    <0.6759259, -168.0047729>,
    <0.6666667, -167.8774261>,
    <0.6944445, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6770185, -167.9486128>,
    <0.6805556, -168.0684463>,
    <0.6666667, -167.9401659>,
    <0.6851852, -167.9410995>,
    <0.6666667, -167.8774261>,
    <0.6944445, -167.8774261>,
    <0.6944445, -168.0684463>,
    <0.6805752, -167.8774261>,
    <0.6944445, -167.9401814>,
    <0.6770185, -167.9486128>,
    <0.3148148, -167.6342972>,
    <0.3055555, -167.5184453>,
    <0.3333333, -167.6922232>,
    <0.3055555, -167.6922232>,
    <0.3194202, -167.6051824>,
    <0.3194499, -167.6922232>,
    <0.3055555, -167.6048705>,
    <0.3240741, -167.7539575>,
    <0.3055555, -167.6922232>,
    <0.3333333, -167.6922232>,
    <0.3333333, -167.8774261>,
    <0.3194499, -167.6922232>,
    <0.3333333, -167.7805425>,
    <0.3193814, -167.7844046>,
    <0.6759259, -167.8156918>,
    <0.6666667, -167.6922232>,
    <0.6944445, -167.8774261>,
    <0.6666667, -167.8774261>,
    <0.6804809, -167.7843268>,
    <0.6805752, -167.8774261>,
    <0.6666667, -167.7804489>,
    <0.6851852, -167.7539575>,
    <0.6666667, -167.6922232>,
    <0.6944445, -167.6922232>,
    <0.6944445, -167.8774261>,
    <0.6805610, -167.6922232>,
    <0.6944445, -167.7804581>,
    <0.6804809, -167.7843268>,
    <0.3148148, -168.0105648>,
    <0.3055555, -167.8948019>,
    <0.3055555, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3055555, -167.9523352>,
    <0.3194444, -168.0684463>,
    <0.3159220, -167.9596049>,
    <0.3148148, -167.8386752>,
    <0.3055555, -167.7264218>,
    <0.3055555, -167.8948019>,
    <0.3333333, -167.8948019>,
    <0.3055555, -167.8064088>,
    <0.3194574, -167.8948019>,
    <0.3193849, -167.8102511>,
    <0.3240741, -167.9526834>,
    <0.3055555, -167.8948019>,
    <0.3333333, -168.0684463>,
    <0.3333333, -167.8948019>,
    <0.3159220, -167.9596049>,
    <0.3333333, -167.9522766>,
    <0.3194574, -167.8948019>,
    <0.6759259, -168.0105648>,
    <0.6666667, -167.8948019>,
    <0.6666667, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6666667, -167.9517210>,
    <0.6805556, -168.0684463>,
    <0.6770218, -167.9595339>,
    <0.6851852, -167.9526834>,
    <0.6666667, -167.8948019>,
    <0.6944445, -168.0684463>,
    <0.6944445, -167.8948019>,
    <0.6770218, -167.9595339>,
    <0.6944445, -167.9517372>,
    <0.6805749, -167.8948019>,
    <0.3148148, -167.4660888>,
    <0.3055555, -167.3613758>,
    <0.3333333, -167.5184453>,
    <0.3055555, -167.5184453>,
    <0.3194111, -167.4397221>,
    <0.3194523, -167.5184453>,
    <0.3055555, -167.4391507>,
    <0.3240741, -167.5763713>,
    <0.3055555, -167.5184453>,
    <0.3333333, -167.5184453>,
    <0.3333333, -167.6922232>,
    <0.3194523, -167.5184453>,
    <0.3333333, -167.6048705>,
    <0.3194202, -167.6051824>,
    <0.6759259, -167.6342972>,
    <0.6666667, -167.5184453>,
    <0.6944445, -167.6922232>,
    <0.6666667, -167.6922232>,
    <0.6805313, -167.6051824>,
    <0.6805610, -167.6922232>,
    <0.6666667, -167.6048705>,
    <0.6851852, -167.5763713>,
    <0.6666667, -167.5184453>,
    <0.6944445, -167.5184453>,
    <0.6944445, -167.6922232>,
    <0.6805634, -167.5184453>,
    <0.6944445, -167.6048705>,
    <0.6805313, -167.6051824>,
    <0.3148148, -167.6737665>,
    <0.3055555, -167.5684558>,
    <0.3055555, -167.7264218>,
    <0.3333333, -167.7264218>,
    <0.3055555, -167.6468904>,
    <0.3194493, -167.7264218>,
    <0.3194221, -167.6473117>,
    <0.3240741, -167.7825485>,
    <0.3055555, -167.7264218>,
    <0.3333333, -167.8948019>,
    <0.3333333, -167.7264218>,
    <0.3193849, -167.8102511>,
    <0.3333333, -167.8063904>,
    <0.3194493, -167.7264218>,
    <0.6759259, -167.8386752>,
    <0.6666667, -167.7264218>,
    <0.6666667, -167.8948019>,
    <0.6944445, -167.8948019>,
    <0.6666667, -167.8062904>,
    <0.6805749, -167.8948019>,
    <0.6804844, -167.8101807>,
    <0.6851852, -167.7825485>,
    <0.6666667, -167.7264218>,
    <0.6944445, -167.8948019>,
    <0.6944445, -167.7264218>,
    <0.6804844, -167.8101807>,
    <0.6944445, -167.8063003>,
    <0.6805604, -167.7264218>,
    <0.3148148, -167.5208549>,
    <0.3055555, -167.4256532>,
    <0.3055555, -167.5684558>,
    <0.3333333, -167.5684558>,
    <0.3055555, -167.4961890>,
    <0.3194515, -167.5684558>,
    <0.3194138, -167.4968970>,
    <0.3240741, -167.6211112>,
    <0.3055555, -167.5684558>,
    <0.3333333, -167.7264218>,
    <0.3333333, -167.5684558>,
    <0.3194221, -167.6473117>,
    <0.3333333, -167.6468904>,
    <0.3194515, -167.5684558>,
    <0.6759259, -167.6737665>,
    <0.6666667, -167.5684558>,
    <0.6666667, -167.7264218>,
    <0.6944445, -167.7264218>,
    <0.6666667, -167.6468904>,
    <0.6805604, -167.7264218>,
    <0.6805332, -167.6473117>,
    <0.6851852, -167.6211112>,
    <0.6666667, -167.5684558>,
    <0.6944445, -167.7264218>,
    <0.6944445, -167.5684558>,
    <0.6805332, -167.6473117>,
    <0.6944445, -167.6468904>,
    <0.6805626, -167.5684558>,
    <0.3148148, -167.3161845>,
    <0.3055555, -167.2258020>,
    <0.3333333, -167.3613758>,
    <0.3055555, -167.3613758>,
    <0.3194028, -167.2933857>,
    <0.3194544, -167.3613758>,
    <0.3055555, -167.2924560>,
    <0.3240741, -167.4137323>,
    <0.3055555, -167.3613758>,
    <0.3333333, -167.3613758>,
    <0.3333333, -167.5184453>,
    <0.3194544, -167.3613758>,
    <0.3333333, -167.4391507>,
    <0.3194111, -167.4397221>,
    <0.6759259, -167.4660888>,
    <0.6666667, -167.3613758>,
    <0.6944445, -167.5184453>,
    <0.6666667, -167.5184453>,
    <0.6805222, -167.4397221>,
    <0.6805634, -167.5184453>,
    <0.6666667, -167.4391507>,
    <0.6851852, -167.4137323>,
    <0.6666667, -167.3613758>,
    <0.6944445, -167.3613758>,
    <0.6944445, -167.5184453>,
    <0.6805655, -167.3613758>,
    <0.6944445, -167.4391507>,
    <0.6805222, -167.4397221>,
    <0.3148148, -167.3845690>,
    <0.3055555, -167.3024008>,
    <0.3055555, -167.4256532>,
    <0.3333333, -167.4256532>,
    <0.3055555, -167.3627833>,
    <0.3194534, -167.4256532>,
    <0.3194062, -167.3638575>,
    <0.3240741, -167.4732541>,
    <0.3055555, -167.4256532>,
    <0.3333333, -167.5684558>,
    <0.3333333, -167.4256532>,
    <0.3194138, -167.4968970>,
    <0.3333333, -167.4961891>,
    <0.3194534, -167.4256532>,
    <0.6759259, -167.5208549>,
    <0.6666667, -167.4256532>,
    <0.6666667, -167.5684558>,
    <0.6944445, -167.5684558>,
    <0.6666667, -167.4961890>,
    <0.6805626, -167.5684558>,
    <0.6805249, -167.4968970>,
    <0.6851852, -167.4732541>,
    <0.6666667, -167.4256532>,
    <0.6944445, -167.5684558>,
    <0.6944445, -167.4256532>,
    <0.6805249, -167.4968970>,
    <0.6944445, -167.4961890>,
    <0.6805646, -167.4256532>,
    <0.3148148, -167.1891429>,
    <0.3055555, -167.1158246>,
    <0.3333333, -167.2258020>,
    <0.3055555, -167.2258020>,
    <0.3190964, -167.1694354>,
    <0.3194562, -167.2258020>,
    <0.3055555, -167.1668348>,
    <0.3240741, -167.2709932>,
    <0.3055555, -167.2258020>,
    <0.3333333, -167.2258020>,
    <0.3333333, -167.3613758>,
    <0.3194562, -167.2258020>,
    <0.3333333, -167.2924560>,
    <0.3194028, -167.2933857>,
    <0.6759259, -167.3161845>,
    <0.6666667, -167.2258020>,
    <0.6944445, -167.3613758>,
    <0.6666667, -167.3613758>,
    <0.6805139, -167.2933857>,
    <0.6805655, -167.3613758>,
    <0.6666667, -167.2924560>,
    <0.6851852, -167.2709932>,
    <0.6666667, -167.2258020>,
    <0.6944445, -167.2258020>,
    <0.6944445, -167.3613758>,
    <0.6805673, -167.2258020>,
    <0.6944445, -167.2924560>,
    <0.6805139, -167.2933857>,
    <0.3148148, -167.2690732>,
    <0.3055555, -167.2024179>,
    <0.3055555, -167.3024008>,
    <0.3333333, -167.3024008>,
    <0.3055555, -167.2507837>,
    <0.3194550, -167.3024008>,
    <0.3193997, -167.2522483>,
    <0.3240741, -167.3434849>,
    <0.3055555, -167.3024008>,
    <0.3333333, -167.4256532>,
    <0.3333333, -167.3024008>,
    <0.3194062, -167.3638575>,
    <0.3333333, -167.3627833>,
    <0.3194550, -167.3024008>,
    <0.6759259, -167.3845690>,
    <0.6666667, -167.3024008>,
    <0.6666667, -167.4256532>,
    <0.6944445, -167.4256532>,
    <0.6666667, -167.3627833>,
    <0.6805646, -167.4256532>,
    <0.6805174, -167.3638575>,
    <0.6851852, -167.3434849>,
    <0.6666667, -167.3024008>,
    <0.6944445, -167.4256532>,
    <0.6944445, -167.3024008>,
    <0.6805174, -167.3638575>,
    <0.6944445, -167.3627833>,
    <0.6805662, -167.3024008>,
    <0.3148148, -167.1000319>,
    <0.3055555, -167.0684463>,
    <0.3333333, -167.1158246>,
    <0.3055555, -167.1158246>,
    <0.3247768, -167.1012305>,
    <0.3188543, -167.1158246>,
    <0.3055555, -167.0957980>,
    <0.3186211, -167.0842391>,
    <0.3055555, -167.0684463>,
    <0.3169745, -167.0684463>,
    <0.3333333, -167.1158246>,
    <0.3112650, -167.0684463>,
    <0.3262367, -167.0952715>,
    <0.3247768, -167.1012305>,
    <0.3240741, -167.1524837>,
    <0.3055555, -167.1158246>,
    <0.3333333, -167.1158246>,
    <0.3333333, -167.2258020>,
    <0.3188543, -167.1158246>,
    <0.3333333, -167.1669985>,
    <0.3190964, -167.1694354>,
    <0.6759259, -167.1891429>,
    <0.6666667, -167.1158246>,
    <0.6944445, -167.2258020>,
    <0.6666667, -167.2258020>,
    <0.6802242, -167.1695015>,
    <0.6805673, -167.2258020>,
    <0.6666667, -167.1673444>,
    <0.6851852, -167.1524837>,
    <0.6666667, -167.1158246>,
    <0.6944445, -167.1158246>,
    <0.6944445, -167.2258020>,
    <0.6799898, -167.1158246>,
    <0.6944445, -167.1673989>,
    <0.6802242, -167.1695015>,
    <0.3148148, -167.1778641>,
    <0.3055555, -167.1287564>,
    <0.3055555, -167.2024179>,
    <0.3333333, -167.2024179>,
    <0.3055555, -167.1607154>,
    <0.3194562, -167.2024179>,
    <0.3196834, -167.1662209>,
    <0.3240741, -167.2357456>,
    <0.3055555, -167.2024179>,
    <0.3333333, -167.3024008>,
    <0.3333333, -167.2024179>,
    <0.3193997, -167.2522483>,
    <0.3333333, -167.2507837>,
    <0.3194562, -167.2024179>,
    <0.6759259, -167.2690732>,
    <0.6666667, -167.2024179>,
    <0.6666667, -167.3024008>,
    <0.6944445, -167.3024008>,
    <0.6666667, -167.2507837>,
    <0.6805662, -167.3024008>,
    <0.6805108, -167.2522483>,
    <0.6851852, -167.2357456>,
    <0.6666667, -167.2024179>,
    <0.6944445, -167.3024008>,
    <0.6944445, -167.2024179>,
    <0.6805108, -167.2522483>,
    <0.6944445, -167.2507837>,
    <0.6805674, -167.2024179>,
    <0.3278804, -167.0842391>,
    <0.3169745, -167.0684463>,
    <0.3333333, -167.0684463>,
    <0.3333333, -167.1158246>,
    <0.3251539, -167.0684463>,
    <0.3333333, -167.0953622>,
    <0.3262367, -167.0952715>,
    <0.6759259, -167.1000319>,
    <0.6666667, -167.0684463>,
    <0.6944445, -167.1158246>,
    <0.6666667, -167.1158246>,
    <0.6858213, -167.1011169>,
    <0.6799898, -167.1158246>,
    <0.6666667, -167.0945275>,
    <0.6797323, -167.0842391>,
    <0.6666667, -167.0684463>,
    <0.6780857, -167.0684463>,
    <0.6944445, -167.1158246>,
    <0.6726635, -167.0684463>,
    <0.6878343, -167.0966801>,
    <0.6858213, -167.1011169>,
    <0.3269974, -167.1123151>,
    <0.3296235, -167.1040945>,
    <0.3180354, -167.1040945>,
    <0.3333333, -167.1287564>,
    <0.3232365, -167.1040945>,
    <0.3296336, -167.1227921>,
    <0.3323312, -167.1220942>,
    <0.3189748, -167.1205358>,
    <0.3180354, -167.1040945>,
    <0.3055555, -167.1287564>,
    <0.3333333, -167.1287564>,
    <0.3084142, -167.1231073>,
    <0.3184748, -167.1287564>,
    <0.3296336, -167.1227921>,
    <0.3240741, -167.1533103>,
    <0.3055555, -167.1287564>,
    <0.3333333, -167.2024179>,
    <0.3333333, -167.1287564>,
    <0.3196834, -167.1662209>,
    <0.3333333, -167.1607154>,
    <0.3184748, -167.1287564>,
    <0.6717789, -167.1123279>,
    <0.6791466, -167.1041136>,
    <0.6695233, -167.1041136>,
    <0.6666667, -167.1287564>,
    <0.6751233, -167.1041136>,
    <0.6676842, -167.1199784>,
    <0.6698375, -167.1224954>,
    <0.6759259, -167.1778641>,
    <0.6666667, -167.1287564>,
    <0.6666667, -167.2024179>,
    <0.6944445, -167.2024179>,
    <0.6666667, -167.1601024>,
    <0.6805674, -167.2024179>,
    <0.6808878, -167.1664683>,
    <0.6800859, -167.1205421>,
    <0.6791466, -167.1041136>,
    <0.6666667, -167.1287564>,
    <0.6944445, -167.1287564>,
    <0.6698375, -167.1224954>,
    <0.6797668, -167.1287564>,
    <0.6909447, -167.1231187>,
    <0.6851852, -167.1533103>,
    <0.6666667, -167.1287564>,
    <0.6944445, -167.2024179>,
    <0.6944445, -167.1287564>,
    <0.6808878, -167.1664683>,
    <0.6944445, -167.1601024>,
    <0.6797668, -167.1287564>,
    <0.6676189, -167.1123215>,
    <0.6695233, -167.1041136>,
    <0.6666667, -167.1040945>,
    <0.6666667, -167.1287564>,
    <0.6684198, -167.1041062>,
    <0.6666667, -167.1186966>,
    <0.6676842, -167.1199784>,
    <0.3320967, -167.1123151>,
    <0.3296235, -167.1040945>,
    <0.3333333, -167.1287564>,
    <0.3333333, -167.1040945>,
    <0.3323311, -167.1220942>,
    <0.3333333, -167.1157259>,
    <0.3310912, -167.1040945>,
    <0.3374932, -167.1123151>,
    <0.3458130, -167.1040945>,
    <0.3333333, -167.1040945>,
    <0.3333333, -167.1287564>,
    <0.3395157, -167.1040945>,
    <0.3333333, -167.1157259>,
    <0.3361920, -167.1231073>,
    <0.6612148, -167.0842391>,
    <0.6503109, -167.0684463>,
    <0.6666667, -167.0684463>,
    <0.6666667, -167.1158246>,
    <0.6588090, -167.0684463>,
    <0.6666667, -167.0945275>,
    <0.6600594, -167.0966849>,
    <0.6615673, -167.1123151>,
    <0.6513686, -167.1040945>,
    <0.6666667, -167.1287564>,
    <0.6666667, -167.1040945>,
    <0.6631668, -167.1231143>,
    <0.6666667, -167.1186966>,
    <0.6593899, -167.1040945>,
    <0.3425926, -168.0047729>,
    <0.3333333, -167.8774261>,
    <0.3611111, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3436963, -167.9486892>,
    <0.3472222, -168.0684463>,
    <0.3333333, -167.9407369>,
    <0.3425926, -167.8156918>,
    <0.3333333, -167.6922232>,
    <0.3611111, -167.8774261>,
    <0.3333333, -167.8774261>,
    <0.3471592, -167.7844046>,
    <0.3472353, -167.8774261>,
    <0.3333333, -167.7805425>,
    <0.3518518, -167.9410995>,
    <0.3333333, -167.8774261>,
    <0.3611111, -167.8774261>,
    <0.3611111, -168.0684463>,
    <0.3472353, -167.8774261>,
    <0.3611111, -167.9406711>,
    <0.3436963, -167.9486892>,
    <0.6481482, -168.0047729>,
    <0.6388889, -167.8774261>,
    <0.6666667, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6492415, -167.9486183>,
    <0.6527778, -168.0684463>,
    <0.6388889, -167.9401608>,
    <0.6574074, -167.9410995>,
    <0.6388889, -167.8774261>,
    <0.6666667, -167.8774261>,
    <0.6666667, -168.0684463>,
    <0.6527967, -167.8774261>,
    <0.6666667, -167.9401659>,
    <0.6492415, -167.9486183>,
    <0.3425926, -167.6342972>,
    <0.3333333, -167.5184453>,
    <0.3611111, -167.6922232>,
    <0.3333333, -167.6922232>,
    <0.3471979, -167.6051824>,
    <0.3472276, -167.6922232>,
    <0.3333333, -167.6048705>,
    <0.3518518, -167.7539575>,
    <0.3333333, -167.6922232>,
    <0.3611111, -167.6922232>,
    <0.3611111, -167.8774261>,
    <0.3472276, -167.6922232>,
    <0.3611111, -167.7805253>,
    <0.3471592, -167.7844046>,
    <0.6481482, -167.8156918>,
    <0.6388889, -167.6922232>,
    <0.6666667, -167.8774261>,
    <0.6388889, -167.8774261>,
    <0.6527042, -167.7843343>,
    <0.6527967, -167.8774261>,
    <0.6388889, -167.7804425>,
    <0.6574074, -167.7539575>,
    <0.6388889, -167.6922232>,
    <0.6666667, -167.6922232>,
    <0.6666667, -167.8774261>,
    <0.6527832, -167.6922232>,
    <0.6666667, -167.7804489>,
    <0.6527042, -167.7843343>,
    <0.3425926, -168.0105648>,
    <0.3333333, -167.8948019>,
    <0.3333333, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3333333, -167.9522766>,
    <0.3472222, -168.0684463>,
    <0.3436994, -167.9596023>,
    <0.3425926, -167.8386752>,
    <0.3333333, -167.7264218>,
    <0.3333333, -167.8948019>,
    <0.3611111, -167.8948019>,
    <0.3333333, -167.8063904>,
    <0.3472351, -167.8948019>,
    <0.3471627, -167.8102511>,
    <0.3518518, -167.9526834>,
    <0.3333333, -167.8948019>,
    <0.3611111, -168.0684463>,
    <0.3611111, -167.8948019>,
    <0.3436994, -167.9596023>,
    <0.3611111, -167.9522128>,
    <0.3472351, -167.8948019>,
    <0.6481482, -168.0105648>,
    <0.6388889, -167.8948019>,
    <0.6388889, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6388889, -167.9517162>,
    <0.6527778, -168.0684463>,
    <0.6492448, -167.9595385>,
    <0.6574074, -167.9526834>,
    <0.6388889, -167.8948019>,
    <0.6666667, -168.0684463>,
    <0.6666667, -167.8948019>,
    <0.6492448, -167.9595385>,
    <0.6666667, -167.9517210>,
    <0.6527964, -167.8948019>,
    <0.3425926, -167.4660888>,
    <0.3333333, -167.3613758>,
    <0.3611111, -167.5184453>,
    <0.3333333, -167.5184453>,
    <0.3471889, -167.4397221>,
    <0.3472301, -167.5184453>,
    <0.3333333, -167.4391507>,
    <0.3518518, -167.5763713>,
    <0.3333333, -167.5184453>,
    <0.3611111, -167.5184453>,
    <0.3611111, -167.6922232>,
    <0.3472301, -167.5184453>,
    <0.3611111, -167.6048705>,
    <0.3471979, -167.6051824>,
    <0.6481482, -167.6342972>,
    <0.6388889, -167.5184453>,
    <0.6666667, -167.6922232>,
    <0.6388889, -167.6922232>,
    <0.6527535, -167.6051824>,
    <0.6527832, -167.6922232>,
    <0.6388889, -167.6048705>,
    <0.6574074, -167.5763713>,
    <0.6388889, -167.5184453>,
    <0.6666667, -167.5184453>,
    <0.6666667, -167.6922232>,
    <0.6527856, -167.5184453>,
    <0.6666667, -167.6048705>,
    <0.6527535, -167.6051824>,
    <0.3425926, -167.6737665>,
    <0.3333333, -167.5684558>,
    <0.3333333, -167.7264218>,
    <0.3611111, -167.7264218>,
    <0.3333333, -167.6468904>,
    <0.3472271, -167.7264218>,
    <0.3471999, -167.6473117>,
    <0.3518518, -167.7825485>,
    <0.3333333, -167.7264218>,
    <0.3611111, -167.8948019>,
    <0.3611111, -167.7264218>,
    <0.3471627, -167.8102511>,
    <0.3611111, -167.8063719>,
    <0.3472271, -167.7264218>,
    <0.6481482, -167.8386752>,
    <0.6388889, -167.7264218>,
    <0.6388889, -167.8948019>,
    <0.6666667, -167.8948019>,
    <0.6388889, -167.8062834>,
    <0.6527964, -167.8948019>,
    <0.6527078, -167.8101876>,
    <0.6574074, -167.7825485>,
    <0.6388889, -167.7264218>,
    <0.6666667, -167.8948019>,
    <0.6666667, -167.7264218>,
    <0.6527078, -167.8101876>,
    <0.6666667, -167.8062904>,
    <0.6527827, -167.7264218>,
    <0.3425926, -167.5208549>,
    <0.3333333, -167.4256532>,
    <0.3333333, -167.5684558>,
    <0.3611111, -167.5684558>,
    <0.3333333, -167.4961891>,
    <0.3472293, -167.5684558>,
    <0.3471916, -167.4968970>,
    <0.3518518, -167.6211112>,
    <0.3333333, -167.5684558>,
    <0.3611111, -167.7264218>,
    <0.3611111, -167.5684558>,
    <0.3471999, -167.6473117>,
    <0.3611111, -167.6468904>,
    <0.3472293, -167.5684558>,
    <0.6481482, -167.6737665>,
    <0.6388889, -167.5684558>,
    <0.6388889, -167.7264218>,
    <0.6666667, -167.7264218>,
    <0.6388889, -167.6468904>,
    <0.6527827, -167.7264218>,
    <0.6527554, -167.6473117>,
    <0.6574074, -167.6211112>,
    <0.6388889, -167.5684558>,
    <0.6666667, -167.7264218>,
    <0.6666667, -167.5684558>,
    <0.6527554, -167.6473117>,
    <0.6666667, -167.6468904>,
    <0.6527849, -167.5684558>,
    <0.3425926, -167.3161845>,
    <0.3333333, -167.2258020>,
    <0.3611111, -167.3613758>,
    <0.3333333, -167.3613758>,
    <0.3471806, -167.2933857>,
    <0.3472322, -167.3613758>,
    <0.3333333, -167.2924560>,
    <0.3518518, -167.4137323>,
    <0.3333333, -167.3613758>,
    <0.3611111, -167.3613758>,
    <0.3611111, -167.5184453>,
    <0.3472322, -167.3613758>,
    <0.3611111, -167.4391506>,
    <0.3471889, -167.4397221>,
    <0.6481482, -167.4660888>,
    <0.6388889, -167.3613758>,
    <0.6666667, -167.5184453>,
    <0.6388889, -167.5184453>,
    <0.6527445, -167.4397221>,
    <0.6527856, -167.5184453>,
    <0.6388889, -167.4391507>,
    <0.6574074, -167.4137323>,
    <0.6388889, -167.3613758>,
    <0.6666667, -167.3613758>,
    <0.6666667, -167.5184453>,
    <0.6527878, -167.3613758>,
    <0.6666667, -167.4391507>,
    <0.6527445, -167.4397221>,
    <0.3425926, -167.3845690>,
    <0.3333333, -167.3024008>,
    <0.3333333, -167.4256532>,
    <0.3611111, -167.4256532>,
    <0.3333333, -167.3627833>,
    <0.3472312, -167.4256532>,
    <0.3471840, -167.3638575>,
    <0.3518518, -167.4732541>,
    <0.3333333, -167.4256532>,
    <0.3611111, -167.5684558>,
    <0.3611111, -167.4256532>,
    <0.3471916, -167.4968970>,
    <0.3611111, -167.4961890>,
    <0.3472312, -167.4256532>,
    <0.6481482, -167.5208549>,
    <0.6388889, -167.4256532>,
    <0.6388889, -167.5684558>,
    <0.6666667, -167.5684558>,
    <0.6388889, -167.4961890>,
    <0.6527849, -167.5684558>,
    <0.6527471, -167.4968970>,
    <0.6574074, -167.4732541>,
    <0.6388889, -167.4256532>,
    <0.6666667, -167.5684558>,
    <0.6666667, -167.4256532>,
    <0.6527471, -167.4968970>,
    <0.6666667, -167.4961890>,
    <0.6527868, -167.4256532>,
    <0.3425926, -167.1891429>,
    <0.3333333, -167.1158246>,
    <0.3611111, -167.2258020>,
    <0.3333333, -167.2258020>,
    <0.3468797, -167.1694571>,
    <0.3472339, -167.2258020>,
    <0.3333333, -167.1669985>,
    <0.3518518, -167.2709932>,
    <0.3333333, -167.2258020>,
    <0.3611111, -167.2258020>,
    <0.3611111, -167.3613758>,
    <0.3472339, -167.2258020>,
    <0.3611111, -167.2924560>,
    <0.3471806, -167.2933857>,
    <0.6481482, -167.3161845>,
    <0.6388889, -167.2258020>,
    <0.6666667, -167.3613758>,
    <0.6388889, -167.3613758>,
    <0.6527362, -167.2933857>,
    <0.6527878, -167.3613758>,
    <0.6388889, -167.2924560>,
    <0.6574074, -167.2709932>,
    <0.6388889, -167.2258020>,
    <0.6666667, -167.2258020>,
    <0.6666667, -167.3613758>,
    <0.6527895, -167.2258020>,
    <0.6666667, -167.2924560>,
    <0.6527362, -167.2933857>,
    <0.3425926, -167.2690732>,
    <0.3333333, -167.2024179>,
    <0.3333333, -167.3024008>,
    <0.3611111, -167.3024008>,
    <0.3333333, -167.2507837>,
    <0.3472328, -167.3024008>,
    <0.3471775, -167.2522483>,
    <0.3518518, -167.3434849>,
    <0.3333333, -167.3024008>,
    <0.3611111, -167.4256532>,
    <0.3611111, -167.3024008>,
    <0.3471840, -167.3638575>,
    <0.3611111, -167.3627833>,
    <0.3472328, -167.3024008>,
    <0.6481482, -167.3845690>,
    <0.6388889, -167.3024008>,
    <0.6388889, -167.4256532>,
    <0.6666667, -167.4256532>,
    <0.6388889, -167.3627833>,
    <0.6527868, -167.4256532>,
    <0.6527396, -167.3638575>,
    <0.6574074, -167.3434849>,
    <0.6388889, -167.3024008>,
    <0.6666667, -167.4256532>,
    <0.6666667, -167.3024008>,
    <0.6527396, -167.3638575>,
    <0.6666667, -167.3627833>,
    <0.6527884, -167.3024008>,
    <0.3463989, -167.0842391>,
    <0.3333333, -167.0684463>,
    <0.3447523, -167.0684463>,
    <0.3611111, -167.1158246>,
    <0.3390428, -167.0684463>,
    <0.3539493, -167.0950827>,
    <0.3525877, -167.1012870>,
    <0.3425926, -167.1000319>,
    <0.3333333, -167.0684463>,
    <0.3611111, -167.1158246>,
    <0.3333333, -167.1158246>,
    <0.3525877, -167.1012870>,
    <0.3466322, -167.1158246>,
    <0.3333333, -167.0953622>,
    <0.3518518, -167.1524837>,
    <0.3333333, -167.1158246>,
    <0.3611111, -167.1158246>,
    <0.3611111, -167.2258020>,
    <0.3466322, -167.1158246>,
    <0.3611111, -167.1668335>,
    <0.3468797, -167.1694571>,
    <0.6481482, -167.1891429>,
    <0.6388889, -167.1158246>,
    <0.6666667, -167.2258020>,
    <0.6388889, -167.2258020>,
    <0.6524461, -167.1695000>,
    <0.6527895, -167.2258020>,
    <0.6388889, -167.1672922>,
    <0.6574074, -167.1524837>,
    <0.6388889, -167.1158246>,
    <0.6666667, -167.1158246>,
    <0.6666667, -167.2258020>,
    <0.6522133, -167.1158246>,
    <0.6666667, -167.1673444>,
    <0.6524461, -167.1695000>,
    <0.3425926, -167.1778641>,
    <0.3333333, -167.1287564>,
    <0.3333333, -167.2024179>,
    <0.3611111, -167.2024179>,
    <0.3333333, -167.1607154>,
    <0.3472340, -167.2024179>,
    <0.3474612, -167.1662209>,
    <0.3518518, -167.2357456>,
    <0.3333333, -167.2024179>,
    <0.3611111, -167.3024008>,
    <0.3611111, -167.2024179>,
    <0.3471775, -167.2522483>,
    <0.3611111, -167.2507837>,
    <0.3472340, -167.2024179>,
    <0.6481482, -167.2690732>,
    <0.6388889, -167.2024179>,
    <0.6388889, -167.3024008>,
    <0.6666667, -167.3024008>,
    <0.6388889, -167.2507837>,
    <0.6527884, -167.3024008>,
    <0.6527330, -167.2522483>,
    <0.6574074, -167.2357456>,
    <0.6388889, -167.2024179>,
    <0.6666667, -167.3024008>,
    <0.6666667, -167.2024179>,
    <0.6527330, -167.2522483>,
    <0.6666667, -167.2507837>,
    <0.6527896, -167.2024179>,
    <0.3556582, -167.0842391>,
    <0.3447523, -167.0684463>,
    <0.3611111, -167.0684463>,
    <0.3611111, -167.1158246>,
    <0.3529317, -167.0684463>,
    <0.3611111, -167.0958943>,
    <0.3539493, -167.0950827>,
    <0.6481482, -167.1000319>,
    <0.6388889, -167.0684463>,
    <0.6666667, -167.1158246>,
    <0.6388889, -167.1158246>,
    <0.6580364, -167.1011047>,
    <0.6522133, -167.1158246>,
    <0.6388889, -167.0943815>,
    <0.6519545, -167.0842391>,
    <0.6388889, -167.0684463>,
    <0.6503079, -167.0684463>,
    <0.6666667, -167.1158246>,
    <0.6448829, -167.0684463>,
    <0.6600581, -167.0966849>,
    <0.6580364, -167.1011047>,
    <0.3547752, -167.1123151>,
    <0.3574013, -167.1040945>,
    <0.3458131, -167.1040945>,
    <0.3611111, -167.1287564>,
    <0.3510145, -167.1040945>,
    <0.3574114, -167.1227922>,
    <0.3601089, -167.1220939>,
    <0.3467525, -167.1205358>,
    <0.3458130, -167.1040945>,
    <0.3333333, -167.1287564>,
    <0.3611111, -167.1287564>,
    <0.3361920, -167.1231073>,
    <0.3462526, -167.1287564>,
    <0.3574114, -167.1227922>,
    <0.3518518, -167.1533103>,
    <0.3333333, -167.1287564>,
    <0.3611111, -167.2024179>,
    <0.3611111, -167.1287564>,
    <0.3474612, -167.1662209>,
    <0.3611111, -167.1607152>,
    <0.3462526, -167.1287564>,
    <0.6440010, -167.1123279>,
    <0.6513685, -167.1041136>,
    <0.6417456, -167.1041136>,
    <0.6388889, -167.1287564>,
    <0.6473453, -167.1041136>,
    <0.6399065, -167.1199779>,
    <0.6420597, -167.1224953>,
    <0.6481482, -167.1778641>,
    <0.6388889, -167.1287564>,
    <0.6388889, -167.2024179>,
    <0.6666667, -167.2024179>,
    <0.6388889, -167.1601026>,
    <0.6527896, -167.2024179>,
    <0.6531100, -167.1664683>,
    <0.6523080, -167.1205421>,
    <0.6513685, -167.1041136>,
    <0.6388889, -167.1287564>,
    <0.6666667, -167.1287564>,
    <0.6420597, -167.1224953>,
    <0.6519890, -167.1287564>,
    <0.6631668, -167.1231187>,
    <0.6574074, -167.1533103>,
    <0.6388889, -167.1287564>,
    <0.6666667, -167.2024179>,
    <0.6666667, -167.1287564>,
    <0.6531100, -167.1664683>,
    <0.6666667, -167.1601024>,
    <0.6519890, -167.1287564>,
    <0.3598745, -167.1123151>,
    <0.3574013, -167.1040945>,
    <0.3611111, -167.1287564>,
    <0.3611111, -167.1040945>,
    <0.3601089, -167.1220939>,
    <0.3611111, -167.1157341>,
    <0.3588693, -167.1040945>,
    <0.6398411, -167.1123215>,
    <0.6417456, -167.1041136>,
    <0.6388889, -167.1040945>,
    <0.6388889, -167.1287564>,
    <0.6406419, -167.1041062>,
    <0.6388889, -167.1187016>,
    <0.6399065, -167.1199779>,
    <0.3652710, -167.1123151>,
    <0.3735907, -167.1040945>,
    <0.3611111, -167.1040945>,
    <0.3611111, -167.1287564>,
    <0.3672936, -167.1040945>,
    <0.3611111, -167.1157341>,
    <0.3639697, -167.1231074>,
    <0.6334370, -167.0842391>,
    <0.6225332, -167.0684463>,
    <0.6388889, -167.0684463>,
    <0.6388889, -167.1158246>,
    <0.6310328, -167.0684463>,
    <0.6388889, -167.0943815>,
    <0.6322821, -167.0966863>,
    <0.3703704, -168.0047729>,
    <0.3611111, -167.8774261>,
    <0.3888889, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3714735, -167.9486851>,
    <0.3750000, -168.0684463>,
    <0.3611111, -167.9406711>,
    <0.3703704, -167.8156918>,
    <0.3611111, -167.6922232>,
    <0.3888889, -167.8774261>,
    <0.3611111, -167.8774261>,
    <0.3749368, -167.7844032>,
    <0.3750131, -167.8774261>,
    <0.3611111, -167.7805253>,
    <0.3796296, -167.9410995>,
    <0.3611111, -167.8774261>,
    <0.3888889, -167.8774261>,
    <0.3888889, -168.0684463>,
    <0.3750131, -167.8774261>,
    <0.3888889, -167.9406021>,
    <0.3714735, -167.9486851>,
    <0.6203704, -168.0047729>,
    <0.6111111, -167.8774261>,
    <0.6388889, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6214645, -167.9486237>,
    <0.6250000, -168.0684463>,
    <0.6111111, -167.9401705>,
    <0.6296296, -167.9410995>,
    <0.6111111, -167.8774261>,
    <0.6388889, -167.8774261>,
    <0.6388889, -168.0684463>,
    <0.6250182, -167.8774261>,
    <0.6388889, -167.9401608>,
    <0.6214645, -167.9486237>,
    <0.3703704, -167.6342972>,
    <0.3611111, -167.5184453>,
    <0.3888889, -167.6922232>,
    <0.3611111, -167.6922232>,
    <0.3749757, -167.6051824>,
    <0.3750054, -167.6922232>,
    <0.3611111, -167.6048705>,
    <0.3796296, -167.7539575>,
    <0.3611111, -167.6922232>,
    <0.3888889, -167.6922232>,
    <0.3888889, -167.8774261>,
    <0.3750054, -167.6922232>,
    <0.3888889, -167.7805085>,
    <0.3749368, -167.7844032>,
    <0.6203704, -167.8156918>,
    <0.6111111, -167.6922232>,
    <0.6388889, -167.8774261>,
    <0.6111111, -167.8774261>,
    <0.6249277, -167.7843426>,
    <0.6250182, -167.8774261>,
    <0.6111111, -167.7804389>,
    <0.6296296, -167.7539575>,
    <0.6111111, -167.6922232>,
    <0.6388889, -167.6922232>,
    <0.6388889, -167.8774261>,
    <0.6250054, -167.6922232>,
    <0.6388889, -167.7804425>,
    <0.6249277, -167.7843426>,
    <0.3703704, -168.0105648>,
    <0.3611111, -167.8948019>,
    <0.3611111, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3611111, -167.9522128>,
    <0.3750000, -168.0684463>,
    <0.3714766, -167.9595985>,
    <0.6337896, -167.1123151>,
    <0.6235910, -167.1040945>,
    <0.6388889, -167.1287564>,
    <0.6388889, -167.1040945>,
    <0.6353891, -167.1231144>,
    <0.6388889, -167.1187016>,
    <0.6316121, -167.1040945>,
    <0.3703704, -167.8386752>,
    <0.3611111, -167.7264218>,
    <0.3611111, -167.8948019>,
    <0.3888889, -167.8948019>,
    <0.3611111, -167.8063719>,
    <0.3750129, -167.8948019>,
    <0.3749402, -167.8102497>,
    <0.3796296, -167.9526834>,
    <0.3611111, -167.8948019>,
    <0.3888889, -168.0684463>,
    <0.3888889, -167.8948019>,
    <0.3714766, -167.9595985>,
    <0.3888889, -167.9521458>,
    <0.3750129, -167.8948019>,
    <0.6203704, -168.0105648>,
    <0.6111111, -167.8948019>,
    <0.6111111, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6111111, -167.9517252>,
    <0.6250000, -168.0684463>,
    <0.6214678, -167.9595434>,
    <0.6296296, -167.9526834>,
    <0.6111111, -167.8948019>,
    <0.6388889, -168.0684463>,
    <0.6388889, -167.8948019>,
    <0.6214678, -167.9595434>,
    <0.6388889, -167.9517162>,
    <0.6250179, -167.8948019>,
    <0.3703704, -167.4660888>,
    <0.3611111, -167.3613758>,
    <0.3888889, -167.5184453>,
    <0.3611111, -167.5184453>,
    <0.3749667, -167.4397221>,
    <0.3750078, -167.5184453>,
    <0.3611111, -167.4391506>,
    <0.3796296, -167.5763713>,
    <0.3611111, -167.5184453>,
    <0.3888889, -167.5184453>,
    <0.3888889, -167.6922232>,
    <0.3750078, -167.5184453>,
    <0.3888889, -167.6048705>,
    <0.3749757, -167.6051824>,
    <0.6203704, -167.6342972>,
    <0.6111111, -167.5184453>,
    <0.6388889, -167.6922232>,
    <0.6111111, -167.6922232>,
    <0.6249757, -167.6051824>,
    <0.6250054, -167.6922232>,
    <0.6111111, -167.6048705>,
    <0.6296296, -167.5763713>,
    <0.6111111, -167.5184453>,
    <0.6388889, -167.5184453>,
    <0.6388889, -167.6922232>,
    <0.6250079, -167.5184453>,
    <0.6388889, -167.6048705>,
    <0.6249757, -167.6051824>,
    <0.3703704, -167.6737665>,
    <0.3611111, -167.5684558>,
    <0.3611111, -167.7264218>,
    <0.3888889, -167.7264218>,
    <0.3611111, -167.6468904>,
    <0.3750049, -167.7264218>,
    <0.3749776, -167.6473117>,
    <0.3796296, -167.7825485>,
    <0.3611111, -167.7264218>,
    <0.3888889, -167.8948019>,
    <0.3888889, -167.7264218>,
    <0.3749402, -167.8102497>,
    <0.3888889, -167.8063538>,
    <0.3750049, -167.7264218>,
    <0.6203704, -167.8386752>,
    <0.6111111, -167.7264218>,
    <0.6111111, -167.8948019>,
    <0.6388889, -167.8948019>,
    <0.6111111, -167.8062795>,
    <0.6250179, -167.8948019>,
    <0.6249312, -167.8101950>,
    <0.6296296, -167.7825485>,
    <0.6111111, -167.7264218>,
    <0.6388889, -167.8948019>,
    <0.6388889, -167.7264218>,
    <0.6249312, -167.8101950>,
    <0.6388889, -167.8062834>,
    <0.6250049, -167.7264218>,
    <0.3703704, -167.5208549>,
    <0.3611111, -167.4256532>,
    <0.3611111, -167.5684558>,
    <0.3888889, -167.5684558>,
    <0.3611111, -167.4961890>,
    <0.3750071, -167.5684558>,
    <0.3749694, -167.4968970>,
    <0.3796296, -167.6211112>,
    <0.3611111, -167.5684558>,
    <0.3888889, -167.7264218>,
    <0.3888889, -167.5684558>,
    <0.3749776, -167.6473117>,
    <0.3888889, -167.6468904>,
    <0.3750071, -167.5684558>,
    <0.6203704, -167.6737665>,
    <0.6111111, -167.5684558>,
    <0.6111111, -167.7264218>,
    <0.6388889, -167.7264218>,
    <0.6111111, -167.6468904>,
    <0.6250049, -167.7264218>,
    <0.6249776, -167.6473117>,
    <0.6296296, -167.6211112>,
    <0.6111111, -167.5684558>,
    <0.6388889, -167.7264218>,
    <0.6388889, -167.5684558>,
    <0.6249776, -167.6473117>,
    <0.6388889, -167.6468904>,
    <0.6250071, -167.5684558>,
    <0.3703704, -167.3161845>,
    <0.3611111, -167.2258020>,
    <0.3888889, -167.3613758>,
    <0.3611111, -167.3613758>,
    <0.3749584, -167.2933857>,
    <0.3750100, -167.3613758>,
    <0.3611111, -167.2924560>,
    <0.3796296, -167.4137323>,
    <0.3611111, -167.3613758>,
    <0.3888889, -167.3613758>,
    <0.3888889, -167.5184453>,
    <0.3750100, -167.3613758>,
    <0.3888889, -167.4391507>,
    <0.3749667, -167.4397221>,
    <0.6203704, -167.4660888>,
    <0.6111111, -167.3613758>,
    <0.6388889, -167.5184453>,
    <0.6111111, -167.5184453>,
    <0.6249667, -167.4397221>,
    <0.6250079, -167.5184453>,
    <0.6111111, -167.4391506>,
    <0.6296296, -167.4137323>,
    <0.6111111, -167.3613758>,
    <0.6388889, -167.3613758>,
    <0.6388889, -167.5184453>,
    <0.6250100, -167.3613758>,
    <0.6388889, -167.4391507>,
    <0.6249667, -167.4397221>,
    <0.3703704, -167.3845690>,
    <0.3611111, -167.3024008>,
    <0.3611111, -167.4256532>,
    <0.3888889, -167.4256532>,
    <0.3611111, -167.3627833>,
    <0.3750090, -167.4256532>,
    <0.3749618, -167.3638575>,
    <0.3796296, -167.4732541>,
    <0.3611111, -167.4256532>,
    <0.3888889, -167.5684558>,
    <0.3888889, -167.4256532>,
    <0.3749694, -167.4968970>,
    <0.3888889, -167.4961890>,
    <0.3750090, -167.4256532>,
    <0.6203704, -167.5208549>,
    <0.6111111, -167.4256532>,
    <0.6111111, -167.5684558>,
    <0.6388889, -167.5684558>,
    <0.6111111, -167.4961890>,
    <0.6250071, -167.5684558>,
    <0.6249694, -167.4968970>,
    <0.6296296, -167.4732541>,
    <0.6111111, -167.4256532>,
    <0.6388889, -167.5684558>,
    <0.6388889, -167.4256532>,
    <0.6249694, -167.4968970>,
    <0.6388889, -167.4961890>,
    <0.6250090, -167.4256532>,
    <0.3703704, -167.1891429>,
    <0.3611111, -167.1158246>,
    <0.3888889, -167.2258020>,
    <0.3611111, -167.2258020>,
    <0.3746517, -167.1694344>,
    <0.3750117, -167.2258020>,
    <0.3611111, -167.1668335>,
    <0.3796296, -167.2709932>,
    <0.3611111, -167.2258020>,
    <0.3888889, -167.2258020>,
    <0.3888889, -167.3613758>,
    <0.3750117, -167.2258020>,
    <0.3888889, -167.2924560>,
    <0.3749584, -167.2933857>,
    <0.6203704, -167.3161845>,
    <0.6111111, -167.2258020>,
    <0.6388889, -167.3613758>,
    <0.6111111, -167.3613758>,
    <0.6249584, -167.2933857>,
    <0.6250100, -167.3613758>,
    <0.6111111, -167.2924560>,
    <0.6296296, -167.2709932>,
    <0.6111111, -167.2258020>,
    <0.6388889, -167.2258020>,
    <0.6388889, -167.3613758>,
    <0.6250117, -167.2258020>,
    <0.6388889, -167.2924560>,
    <0.6249584, -167.2933857>,
    <0.3703704, -167.2690732>,
    <0.3611111, -167.2024179>,
    <0.3611111, -167.3024008>,
    <0.3888889, -167.3024008>,
    <0.3611111, -167.2507837>,
    <0.3750106, -167.3024008>,
    <0.3749552, -167.2522483>,
    <0.3796296, -167.3434849>,
    <0.3611111, -167.3024008>,
    <0.3888889, -167.4256532>,
    <0.3888889, -167.3024008>,
    <0.3749618, -167.3638575>,
    <0.3888889, -167.3627833>,
    <0.3750106, -167.3024008>,
    <0.6203704, -167.3845690>,
    <0.6111111, -167.3024008>,
    <0.6111111, -167.4256532>,
    <0.6388889, -167.4256532>,
    <0.6111111, -167.3627833>,
    <0.6250090, -167.4256532>,
    <0.6249618, -167.3638575>,
    <0.6296296, -167.3434849>,
    <0.6111111, -167.3024008>,
    <0.6388889, -167.4256532>,
    <0.6388889, -167.3024008>,
    <0.6249618, -167.3638575>,
    <0.6388889, -167.3627833>,
    <0.6250106, -167.3024008>,
    <0.3741767, -167.0842391>,
    <0.3611111, -167.0684463>,
    <0.3725301, -167.0684463>,
    <0.3888889, -167.1158246>,
    <0.3671103, -167.0684463>,
    <0.3822781, -167.0966785>,
    <0.3802704, -167.1011247>,
    <0.3703704, -167.1000319>,
    <0.3611111, -167.0684463>,
    <0.3888889, -167.1158246>,
    <0.3611111, -167.1158246>,
    <0.3802704, -167.1011247>,
    <0.3744180, -167.1158246>,
    <0.3611111, -167.0958943>,
    <0.3796296, -167.1524837>,
    <0.3611111, -167.1158246>,
    <0.3888889, -167.1158246>,
    <0.3888889, -167.2258020>,
    <0.3744180, -167.1158246>,
    <0.3888889, -167.1673834>,
    <0.3746517, -167.1694344>,
    <0.6203704, -167.1891429>,
    <0.6111111, -167.1158246>,
    <0.6388889, -167.2258020>,
    <0.6111111, -167.2258020>,
    <0.6246697, -167.1695056>,
    <0.6250117, -167.2258020>,
    <0.6111111, -167.1673836>,
    <0.6296296, -167.1524837>,
    <0.6111111, -167.1158246>,
    <0.6388889, -167.1158246>,
    <0.6388889, -167.2258020>,
    <0.6244368, -167.1158246>,
    <0.6388889, -167.1672922>,
    <0.6246697, -167.1695056>,
    <0.3703704, -167.1778641>,
    <0.3611111, -167.1287564>,
    <0.3611111, -167.2024179>,
    <0.3888889, -167.2024179>,
    <0.3611111, -167.1607152>,
    <0.3750118, -167.2024179>,
    <0.3752390, -167.1662210>,
    <0.3796296, -167.2357456>,
    <0.3611111, -167.2024179>,
    <0.3888889, -167.3024008>,
    <0.3888889, -167.2024179>,
    <0.3749552, -167.2522483>,
    <0.3888889, -167.2507837>,
    <0.3750118, -167.2024179>,
    <0.6203704, -167.2690732>,
    <0.6111111, -167.2024179>,
    <0.6111111, -167.3024008>,
    <0.6388889, -167.3024008>,
    <0.6111111, -167.2507837>,
    <0.6250106, -167.3024008>,
    <0.6249553, -167.2522483>,
    <0.6296296, -167.2357456>,
    <0.6111111, -167.2024179>,
    <0.6388889, -167.3024008>,
    <0.6388889, -167.2024179>,
    <0.6249553, -167.2522483>,
    <0.6388889, -167.2507837>,
    <0.6250118, -167.2024179>,
    <0.3834360, -167.0842391>,
    <0.3725301, -167.0684463>,
    <0.3888889, -167.0684463>,
    <0.3888889, -167.1158246>,
    <0.3810326, -167.0684463>,
    <0.3888889, -167.0943971>,
    <0.3822781, -167.0966785>,
    <0.6203704, -167.1000319>,
    <0.6111111, -167.0684463>,
    <0.6388889, -167.1158246>,
    <0.6111111, -167.1158246>,
    <0.6302586, -167.1011046>,
    <0.6244368, -167.1158246>,
    <0.6111111, -167.0943969>,
    <0.6241767, -167.0842391>,
    <0.6111111, -167.0684463>,
    <0.6225301, -167.0684463>,
    <0.6388889, -167.1158246>,
    <0.6171056, -167.0684463>,
    <0.6322808, -167.0966863>,
    <0.6302586, -167.1011046>,
    <0.3825529, -167.1123151>,
    <0.3851791, -167.1040945>,
    <0.3735908, -167.1040945>,
    <0.3888889, -167.1287564>,
    <0.3787922, -167.1040945>,
    <0.3851894, -167.1227925>,
    <0.3878867, -167.1220941>,
    <0.3745302, -167.1205358>,
    <0.3735907, -167.1040945>,
    <0.3611111, -167.1287564>,
    <0.3888889, -167.1287564>,
    <0.3639697, -167.1231074>,
    <0.3740304, -167.1287564>,
    <0.3851894, -167.1227925>,
    <0.3796296, -167.1533103>,
    <0.3611111, -167.1287564>,
    <0.3888889, -167.2024179>,
    <0.3888889, -167.1287564>,
    <0.3752390, -167.1662210>,
    <0.3888889, -167.1607153>,
    <0.3740304, -167.1287564>,
    <0.6162233, -167.1123279>,
    <0.6235909, -167.1041136>,
    <0.6139677, -167.1041136>,
    <0.6111111, -167.1287564>,
    <0.6195676, -167.1041136>,
    <0.6121287, -167.1199784>,
    <0.6142818, -167.1224956>,
    <0.6203704, -167.1778641>,
    <0.6111111, -167.1287564>,
    <0.6111111, -167.2024179>,
    <0.6388889, -167.2024179>,
    <0.6111111, -167.1601023>,
    <0.6250118, -167.2024179>,
    <0.6253323, -167.1664684>,
    <0.6245303, -167.1205421>,
    <0.6235909, -167.1041136>,
    <0.6111111, -167.1287564>,
    <0.6388889, -167.1287564>,
    <0.6142818, -167.1224956>,
    <0.6242112, -167.1287564>,
    <0.6353891, -167.1231188>,
    <0.6296296, -167.1533103>,
    <0.6111111, -167.1287564>,
    <0.6388889, -167.2024179>,
    <0.6388889, -167.1287564>,
    <0.6253323, -167.1664684>,
    <0.6388889, -167.1601026>,
    <0.6242112, -167.1287564>,
    <0.3876523, -167.1123151>,
    <0.3851791, -167.1040945>,
    <0.3888889, -167.1287564>,
    <0.3888889, -167.1040945>,
    <0.3878867, -167.1220941>,
    <0.3888889, -167.1157290>,
    <0.3866469, -167.1040945>,
    <0.6120633, -167.1123215>,
    <0.6139677, -167.1041136>,
    <0.6111111, -167.1040945>,
    <0.6111111, -167.1287564>,
    <0.6128643, -167.1041062>,
    <0.6111111, -167.1186961>,
    <0.6121287, -167.1199784>,
    <0.3981481, -168.0047729>,
    <0.3888889, -167.8774261>,
    <0.4166667, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3926760, -167.9034689>,
    <0.3999671, -168.0684463>,
    <0.3888889, -167.9406021>,
    <0.3981481, -167.8156918>,
    <0.3888889, -167.6922232>,
    <0.4166667, -167.8774261>,
    <0.3888889, -167.8774261>,
    <0.4027141, -167.7844001>,
    <0.4027911, -167.8774261>,
    <0.3888889, -167.7805085>,
    <0.4074074, -167.9410995>,
    <0.3888889, -167.8774261>,
    <0.4166667, -167.8774261>,
    <0.4166667, -168.0684463>,
    <0.4027911, -167.8774261>,
    <0.4166667, -167.9745941>,
    <0.3926760, -167.9034689>,
    <0.5925926, -168.0047729>,
    <0.5833333, -167.8774261>,
    <0.6111111, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5936877, -167.9486301>,
    <0.5972222, -168.0684463>,
    <0.5833333, -167.9401931>,
    <0.6018519, -167.9410995>,
    <0.5833333, -167.8774261>,
    <0.6111111, -167.8774261>,
    <0.6111111, -168.0684463>,
    <0.5972396, -167.8774261>,
    <0.6111111, -167.9401705>,
    <0.5936877, -167.9486301>,
    <0.3981481, -167.6342972>,
    <0.3888889, -167.5184453>,
    <0.4166667, -167.6922232>,
    <0.3888889, -167.6922232>,
    <0.4027535, -167.6051824>,
    <0.4027832, -167.6922232>,
    <0.3888889, -167.6048705>,
    <0.4074074, -167.7539575>,
    <0.3888889, -167.6922232>,
    <0.4166667, -167.6922232>,
    <0.4166667, -167.8774261>,
    <0.4027832, -167.6922232>,
    <0.4166667, -167.7804924>,
    <0.4027141, -167.7844001>,
    <0.5925926, -167.8156918>,
    <0.5833333, -167.6922232>,
    <0.6111111, -167.8774261>,
    <0.5833333, -167.8774261>,
    <0.5971512, -167.7843511>,
    <0.5972396, -167.8774261>,
    <0.5833333, -167.7804384>,
    <0.6018519, -167.7539575>,
    <0.5833333, -167.6922232>,
    <0.6111111, -167.6922232>,
    <0.6111111, -167.8774261>,
    <0.5972276, -167.6922232>,
    <0.6111111, -167.7804389>,
    <0.5971512, -167.7843511>,
    <0.3981481, -168.0105648>,
    <0.3888889, -167.8948019>,
    <0.3888889, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.3888889, -167.9521458>,
    <0.4027778, -168.0684463>,
    <0.3978052, -167.9505394>,
    <0.3981481, -167.8386752>,
    <0.3888889, -167.7264218>,
    <0.3888889, -167.8948019>,
    <0.4166667, -167.8948019>,
    <0.3888889, -167.8063538>,
    <0.4027909, -167.8948019>,
    <0.4027176, -167.8102470>,
    <0.4074074, -167.9526834>,
    <0.3888889, -167.8948019>,
    <0.4166667, -168.0684463>,
    <0.4166667, -167.8948019>,
    <0.3978052, -167.9505394>,
    <0.4166667, -167.9417080>,
    <0.4027909, -167.8948019>,
    <0.5925926, -168.0105648>,
    <0.5833333, -167.8948019>,
    <0.5833333, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.5833333, -167.9517471>,
    <0.5972222, -168.0684463>,
    <0.5936909, -167.9595492>,
    <0.6018519, -167.9526834>,
    <0.5833333, -167.8948019>,
    <0.6111111, -168.0684463>,
    <0.6111111, -167.8948019>,
    <0.5936909, -167.9595492>,
    <0.6111111, -167.9517252>,
    <0.5972393, -167.8948019>,
    <0.3981481, -167.4660888>,
    <0.3888889, -167.3613758>,
    <0.4166667, -167.5184453>,
    <0.3888889, -167.5184453>,
    <0.4027444, -167.4397221>,
    <0.4027856, -167.5184453>,
    <0.3888889, -167.4391507>,
    <0.4074074, -167.5763713>,
    <0.3888889, -167.5184453>,
    <0.4166667, -167.5184453>,
    <0.4166667, -167.6922232>,
    <0.4027856, -167.5184453>,
    <0.4166667, -167.6048705>,
    <0.4027535, -167.6051824>,
    <0.5925926, -167.6342972>,
    <0.5833333, -167.5184453>,
    <0.6111111, -167.6922232>,
    <0.5833333, -167.6922232>,
    <0.5971979, -167.6051824>,
    <0.5972276, -167.6922232>,
    <0.5833333, -167.6048705>,
    <0.6018519, -167.5763713>,
    <0.5833333, -167.5184453>,
    <0.6111111, -167.5184453>,
    <0.6111111, -167.6922232>,
    <0.5972301, -167.5184453>,
    <0.6111111, -167.6048705>,
    <0.5971979, -167.6051824>,
    <0.3981481, -167.6737665>,
    <0.3888889, -167.5684558>,
    <0.3888889, -167.7264218>,
    <0.4166667, -167.7264218>,
    <0.3888889, -167.6468904>,
    <0.4027826, -167.7264218>,
    <0.4027554, -167.6473117>,
    <0.4074074, -167.7825485>,
    <0.3888889, -167.7264218>,
    <0.4166667, -167.8948019>,
    <0.4166667, -167.7264218>,
    <0.4027176, -167.8102470>,
    <0.4166667, -167.8063366>,
    <0.4027826, -167.7264218>,
    <0.5925926, -167.8386752>,
    <0.5833333, -167.7264218>,
    <0.5833333, -167.8948019>,
    <0.6111111, -167.8948019>,
    <0.5833333, -167.8062788>,
    <0.5972393, -167.8948019>,
    <0.5971547, -167.8102027>,
    <0.6018519, -167.7825485>,
    <0.5833333, -167.7264218>,
    <0.6111111, -167.8948019>,
    <0.6111111, -167.7264218>,
    <0.5971547, -167.8102027>,
    <0.6111111, -167.8062795>,
    <0.5972271, -167.7264218>,
    <0.6056582, -167.0842391>,
    <0.5947523, -167.0684463>,
    <0.6111111, -167.0684463>,
    <0.6111111, -167.1158246>,
    <0.6032547, -167.0684463>,
    <0.6111111, -167.0943969>,
    <0.6045005, -167.0966789>,
    <0.3930488, -167.1123151>,
    <0.4013685, -167.1040945>,
    <0.3888889, -167.1040945>,
    <0.3888889, -167.1287564>,
    <0.3950713, -167.1040945>,
    <0.3888889, -167.1157290>,
    <0.3917475, -167.1231074>,
    <0.3981481, -167.5208549>,
    <0.3888889, -167.4256532>,
    <0.3888889, -167.5684558>,
    <0.4166667, -167.5684558>,
    <0.3888889, -167.4961890>,
    <0.4027848, -167.5684558>,
    <0.4027471, -167.4968970>,
    <0.4074074, -167.6211112>,
    <0.3888889, -167.5684558>,
    <0.4166667, -167.7264218>,
    <0.4166667, -167.5684558>,
    <0.4027554, -167.6473117>,
    <0.4166667, -167.6468904>,
    <0.4027848, -167.5684558>,
    <0.5925926, -167.6737665>,
    <0.5833333, -167.5684558>,
    <0.5833333, -167.7264218>,
    <0.6111111, -167.7264218>,
    <0.5833333, -167.6468904>,
    <0.5972271, -167.7264218>,
    <0.5971999, -167.6473117>,
    <0.6018519, -167.6211112>,
    <0.5833333, -167.5684558>,
    <0.6111111, -167.7264218>,
    <0.6111111, -167.5684558>,
    <0.5971999, -167.6473117>,
    <0.6111111, -167.6468904>,
    <0.5972293, -167.5684558>,
    <0.3981481, -167.3161845>,
    <0.3888889, -167.2258020>,
    <0.4166667, -167.3613758>,
    <0.3888889, -167.3613758>,
    <0.4027361, -167.2933857>,
    <0.4027878, -167.3613758>,
    <0.3888889, -167.2924560>,
    <0.4074074, -167.4137323>,
    <0.3888889, -167.3613758>,
    <0.4166667, -167.3613758>,
    <0.4166667, -167.5184453>,
    <0.4027878, -167.3613758>,
    <0.4166667, -167.4391507>,
    <0.4027444, -167.4397221>,
    <0.5925926, -167.4660888>,
    <0.5833333, -167.3613758>,
    <0.6111111, -167.5184453>,
    <0.5833333, -167.5184453>,
    <0.5971889, -167.4397221>,
    <0.5972301, -167.5184453>,
    <0.5833333, -167.4391507>,
    <0.6018519, -167.4137323>,
    <0.5833333, -167.3613758>,
    <0.6111111, -167.3613758>,
    <0.6111111, -167.5184453>,
    <0.5972322, -167.3613758>,
    <0.6111111, -167.4391506>,
    <0.5971889, -167.4397221>,
    <0.6060118, -167.1123151>,
    <0.5958131, -167.1040945>,
    <0.6111111, -167.1287564>,
    <0.6111111, -167.1040945>,
    <0.6076113, -167.1231144>,
    <0.6111111, -167.1186961>,
    <0.6038344, -167.1040945>,
    <0.3981481, -167.3845690>,
    <0.3888889, -167.3024008>,
    <0.3888889, -167.4256532>,
    <0.4166667, -167.4256532>,
    <0.3888889, -167.3627833>,
    <0.4027868, -167.4256532>,
    <0.4027396, -167.3638575>,
    <0.4074074, -167.4732541>,
    <0.3888889, -167.4256532>,
    <0.4166667, -167.5684558>,
    <0.4166667, -167.4256532>,
    <0.4027471, -167.4968970>,
    <0.4166667, -167.4961890>,
    <0.4027868, -167.4256532>,
    <0.5925926, -167.5208549>,
    <0.5833333, -167.4256532>,
    <0.5833333, -167.5684558>,
    <0.6111111, -167.5684558>,
    <0.5833333, -167.4961891>,
    <0.5972293, -167.5684558>,
    <0.5971916, -167.4968970>,
    <0.6018519, -167.4732541>,
    <0.5833333, -167.4256532>,
    <0.6111111, -167.5684558>,
    <0.6111111, -167.4256532>,
    <0.5971916, -167.4968970>,
    <0.6111111, -167.4961890>,
    <0.5972312, -167.4256532>,
    <0.3981481, -167.1891429>,
    <0.3888889, -167.1158246>,
    <0.4166667, -167.2258020>,
    <0.3888889, -167.2258020>,
    <0.4024475, -167.1695055>,
    <0.4027895, -167.2258020>,
    <0.3888889, -167.1673834>,
    <0.4074074, -167.2709932>,
    <0.3888889, -167.2258020>,
    <0.4166667, -167.2258020>,
    <0.4166667, -167.3613758>,
    <0.4027895, -167.2258020>,
    <0.4166667, -167.2924560>,
    <0.4027361, -167.2933857>,
    <0.5925926, -167.3161845>,
    <0.5833333, -167.2258020>,
    <0.6111111, -167.3613758>,
    <0.5833333, -167.3613758>,
    <0.5971806, -167.2933857>,
    <0.5972322, -167.3613758>,
    <0.5833333, -167.2924560>,
    <0.6018519, -167.2709932>,
    <0.5833333, -167.2258020>,
    <0.6111111, -167.2258020>,
    <0.6111111, -167.3613758>,
    <0.5972340, -167.2258020>,
    <0.6111111, -167.2924560>,
    <0.5971806, -167.2933857>,
    <0.3981481, -167.2690732>,
    <0.3888889, -167.2024179>,
    <0.3888889, -167.3024008>,
    <0.4166667, -167.3024008>,
    <0.3888889, -167.2507837>,
    <0.4027884, -167.3024008>,
    <0.4027330, -167.2522483>,
    <0.4074074, -167.3434849>,
    <0.3888889, -167.3024008>,
    <0.4166667, -167.4256532>,
    <0.4166667, -167.3024008>,
    <0.4027396, -167.3638575>,
    <0.4166667, -167.3627833>,
    <0.4027884, -167.3024008>,
    <0.5925926, -167.3845690>,
    <0.5833333, -167.3024008>,
    <0.5833333, -167.4256532>,
    <0.6111111, -167.4256532>,
    <0.5833333, -167.3627833>,
    <0.5972312, -167.4256532>,
    <0.5971840, -167.3638575>,
    <0.6018519, -167.3434849>,
    <0.5833333, -167.3024008>,
    <0.6111111, -167.4256532>,
    <0.6111111, -167.3024008>,
    <0.5971840, -167.3638575>,
    <0.6111111, -167.3627833>,
    <0.5972328, -167.3024008>,
    <0.3981481, -167.1000319>,
    <0.3888889, -167.0684463>,
    <0.4166667, -167.1158246>,
    <0.3888889, -167.1158246>,
    <0.4080364, -167.1011047>,
    <0.4022143, -167.1158246>,
    <0.3888889, -167.0943971>,
    <0.4019545, -167.0842391>,
    <0.3888889, -167.0684463>,
    <0.4003079, -167.0684463>,
    <0.4166667, -167.1158246>,
    <0.3948829, -167.0684463>,
    <0.4100581, -167.0966849>,
    <0.4080364, -167.1011047>,
    <0.4074074, -167.1524837>,
    <0.3888889, -167.1158246>,
    <0.4166667, -167.1158246>,
    <0.4166667, -167.2258020>,
    <0.4022143, -167.1158246>,
    <0.4166667, -167.1673444>,
    <0.4024475, -167.1695055>,
    <0.5925926, -167.1891429>,
    <0.5833333, -167.1158246>,
    <0.6111111, -167.2258020>,
    <0.5833333, -167.2258020>,
    <0.5968805, -167.1694605>,
    <0.5972340, -167.2258020>,
    <0.5833333, -167.1670695>,
    <0.6018519, -167.1524837>,
    <0.5833333, -167.1158246>,
    <0.6111111, -167.1158246>,
    <0.6111111, -167.2258020>,
    <0.5966461, -167.1158246>,
    <0.6111111, -167.1673836>,
    <0.5968805, -167.1694605>,
    <0.3981481, -167.1778641>,
    <0.3888889, -167.1287564>,
    <0.3888889, -167.2024179>,
    <0.4166667, -167.2024179>,
    <0.3888889, -167.1607153>,
    <0.4027896, -167.2024179>,
    <0.4030168, -167.1662209>,
    <0.4074074, -167.2357456>,
    <0.3888889, -167.2024179>,
    <0.4166667, -167.3024008>,
    <0.4166667, -167.2024179>,
    <0.4027330, -167.2522483>,
    <0.4166667, -167.2507837>,
    <0.4027896, -167.2024179>,
    <0.5925926, -167.2690732>,
    <0.5833333, -167.2024179>,
    <0.5833333, -167.3024008>,
    <0.6111111, -167.3024008>,
    <0.5833333, -167.2507837>,
    <0.5972328, -167.3024008>,
    <0.5971775, -167.2522483>,
    <0.6018519, -167.2357456>,
    <0.5833333, -167.2024179>,
    <0.6111111, -167.3024008>,
    <0.6111111, -167.2024179>,
    <0.5971775, -167.2522483>,
    <0.6111111, -167.2507837>,
    <0.5972340, -167.2024179>,
    <0.5964017, -167.0842391>,
    <0.5833385, -167.0684463>,
    <0.5947554, -167.0684463>,
    <0.6111111, -167.1158246>,
    <0.5893364, -167.0684463>,
    <0.6045017, -167.0966789>,
    <0.6024940, -167.1011244>,
    <0.4112148, -167.0842391>,
    <0.4003109, -167.0684463>,
    <0.4166667, -167.0684463>,
    <0.4166667, -167.1158246>,
    <0.4088090, -167.0684463>,
    <0.4166667, -167.0945275>,
    <0.4100593, -167.0966849>,
    <0.5925926, -167.1000319>,
    <0.5833333, -167.0684463>,
    <0.6111111, -167.1158246>,
    <0.5833333, -167.1158246>,
    <0.6024924, -167.1011244>,
    <0.5966461, -167.1158246>,
    <0.5833333, -167.0954675>,
    <0.4103307, -167.1123151>,
    <0.4129568, -167.1040945>,
    <0.4013685, -167.1040945>,
    <0.4166667, -167.1287564>,
    <0.4065699, -167.1040945>,
    <0.4129670, -167.1227923>,
    <0.4156645, -167.1220941>,
    <0.4023080, -167.1205358>,
    <0.4013685, -167.1040945>,
    <0.3888889, -167.1287564>,
    <0.4166667, -167.1287564>,
    <0.3917475, -167.1231074>,
    <0.4018082, -167.1287564>,
    <0.4129670, -167.1227923>,
    <0.4074074, -167.1533103>,
    <0.3888889, -167.1287564>,
    <0.4166667, -167.2024179>,
    <0.4166667, -167.1287564>,
    <0.4030168, -167.1662209>,
    <0.4166667, -167.1607154>,
    <0.4018082, -167.1287564>,
    <0.5884455, -167.1123279>,
    <0.5958132, -167.1041136>,
    <0.5861900, -167.1041136>,
    <0.5833333, -167.1287564>,
    <0.5917900, -167.1041136>,
    <0.5843509, -167.1199784>,
    <0.5865042, -167.1224952>,
    <0.5925926, -167.1778641>,
    <0.5833333, -167.1287564>,
    <0.5833333, -167.2024179>,
    <0.6111111, -167.2024179>,
    <0.5833333, -167.1601023>,
    <0.5972340, -167.2024179>,
    <0.5975545, -167.1664684>,
    <0.5967526, -167.1205421>,
    <0.5958132, -167.1041136>,
    <0.5833333, -167.1287564>,
    <0.6111111, -167.1287564>,
    <0.5865042, -167.1224952>,
    <0.5964335, -167.1287564>,
    <0.6076113, -167.1231187>,
    <0.6018519, -167.1533103>,
    <0.5833333, -167.1287564>,
    <0.6111111, -167.2024179>,
    <0.6111111, -167.1287564>,
    <0.5975545, -167.1664684>,
    <0.6111111, -167.1601023>,
    <0.5964335, -167.1287564>,
    <0.4259259, -168.0047729>,
    <0.4166667, -167.8774261>,
    <0.4444444, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4255794, -167.9387168>,
    <0.4314833, -168.0684463>,
    <0.4166667, -167.9745941>,
    <0.4259259, -167.8156918>,
    <0.4166667, -167.6922232>,
    <0.4444444, -167.8774261>,
    <0.4166667, -167.8774261>,
    <0.4304912, -167.7843959>,
    <0.4305692, -167.8774261>,
    <0.4166667, -167.7804924>,
    <0.4351852, -167.9410995>,
    <0.4166667, -167.8774261>,
    <0.4444444, -167.8774261>,
    <0.4444444, -168.0684463>,
    <0.4305692, -167.8774261>,
    <0.4444444, -167.9292172>,
    <0.4255794, -167.9387168>,
    <0.5648148, -168.0047729>,
    <0.5555556, -167.8774261>,
    <0.5833333, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5659110, -167.9486373>,
    <0.5694444, -168.0684463>,
    <0.5555556, -167.9402278>,
    <0.5740741, -167.9410995>,
    <0.5555556, -167.8774261>,
    <0.5833333, -167.8774261>,
    <0.5833333, -168.0684463>,
    <0.5694611, -167.8774261>,
    <0.5833333, -167.9401931>,
    <0.5659110, -167.9486373>,
    <0.4154300, -167.1123151>,
    <0.4129568, -167.1040945>,
    <0.4166667, -167.1287564>,
    <0.4166667, -167.1040945>,
    <0.4156645, -167.1220941>,
    <0.4166667, -167.1157282>,
    <0.4144246, -167.1040945>,
    <0.5842856, -167.1123215>,
    <0.5861900, -167.1041136>,
    <0.5833333, -167.1040945>,
    <0.5833333, -167.1287564>,
    <0.5850866, -167.1041062>,
    <0.5833333, -167.1186955>,
    <0.5843509, -167.1199784>,
    <0.4259259, -167.6342972>,
    <0.4166667, -167.5184453>,
    <0.4444444, -167.6922232>,
    <0.4166667, -167.6922232>,
    <0.4305313, -167.6051824>,
    <0.4305610, -167.6922232>,
    <0.4166667, -167.6048705>,
    <0.4351852, -167.7539575>,
    <0.4166667, -167.6922232>,
    <0.4444444, -167.6922232>,
    <0.4444444, -167.8774261>,
    <0.4305610, -167.6922232>,
    <0.4444444, -167.7804778>,
    <0.4304912, -167.7843959>,
    <0.5648148, -167.8156918>,
    <0.5555556, -167.6922232>,
    <0.5833333, -167.8774261>,
    <0.5555556, -167.8774261>,
    <0.5693747, -167.7843598>,
    <0.5694611, -167.8774261>,
    <0.5555556, -167.7804408>,
    <0.5740741, -167.7539575>,
    <0.5555556, -167.6922232>,
    <0.5833333, -167.6922232>,
    <0.5833333, -167.8774261>,
    <0.5694499, -167.6922232>,
    <0.5833333, -167.7804384>,
    <0.5693747, -167.7843598>,
    <0.4259259, -168.0105648>,
    <0.4166667, -167.8948019>,
    <0.4166667, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4166667, -167.9417080>,
    <0.4303082, -168.0684463>,
    <0.4248695, -167.9460793>,
    <0.4259259, -167.8386752>,
    <0.4166667, -167.7264218>,
    <0.4166667, -167.8948019>,
    <0.4444444, -167.8948019>,
    <0.4166667, -167.8063366>,
    <0.4305690, -167.8948019>,
    <0.4304947, -167.8102432>,
    <0.4351852, -167.9526834>,
    <0.4166667, -167.8948019>,
    <0.4444444, -168.0684463>,
    <0.4444444, -167.8948019>,
    <0.4248695, -167.9460793>,
    <0.4444444, -167.9365451>,
    <0.4305690, -167.8948019>,
    <0.5648148, -168.0105648>,
    <0.5555556, -167.8948019>,
    <0.5555556, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5555556, -167.9517813>,
    <0.5694445, -168.0684463>,
    <0.5659141, -167.9595553>,
    <0.5740741, -167.9526834>,
    <0.5555556, -167.8948019>,
    <0.5833333, -168.0684463>,
    <0.5833333, -167.8948019>,
    <0.5659141, -167.9595553>,
    <0.5833333, -167.9517471>,
    <0.5694608, -167.8948019>,
    <0.4259259, -167.4660888>,
    <0.4166667, -167.3613758>,
    <0.4444444, -167.5184453>,
    <0.4166667, -167.5184453>,
    <0.4305222, -167.4397221>,
    <0.4305634, -167.5184453>,
    <0.4166667, -167.4391507>,
    <0.4351852, -167.5763713>,
    <0.4166667, -167.5184453>,
    <0.4444444, -167.5184453>,
    <0.4444444, -167.6922232>,
    <0.4305634, -167.5184453>,
    <0.4444444, -167.6048705>,
    <0.4305313, -167.6051824>,
    <0.5648148, -167.6342972>,
    <0.5555556, -167.5184453>,
    <0.5833333, -167.6922232>,
    <0.5555556, -167.6922232>,
    <0.5694202, -167.6051824>,
    <0.5694499, -167.6922232>,
    <0.5555556, -167.6048705>,
    <0.5740741, -167.5763713>,
    <0.5555556, -167.5184453>,
    <0.5833333, -167.5184453>,
    <0.5833333, -167.6922232>,
    <0.5694523, -167.5184453>,
    <0.5833333, -167.6048705>,
    <0.5694202, -167.6051824>,
    <0.4259259, -167.6737665>,
    <0.4166667, -167.5684558>,
    <0.4166667, -167.7264218>,
    <0.4444444, -167.7264218>,
    <0.4166667, -167.6468904>,
    <0.4305604, -167.7264218>,
    <0.4305332, -167.6473117>,
    <0.4351852, -167.7825485>,
    <0.4166667, -167.7264218>,
    <0.4444444, -167.8948019>,
    <0.4444444, -167.7264218>,
    <0.4304947, -167.8102432>,
    <0.4444444, -167.8063209>,
    <0.4305604, -167.7264218>,
    <0.5648148, -167.8386752>,
    <0.5555556, -167.7264218>,
    <0.5555556, -167.8948019>,
    <0.5833333, -167.8948019>,
    <0.5555556, -167.8062814>,
    <0.5694608, -167.8948019>,
    <0.5693782, -167.8102106>,
    <0.5740741, -167.7825485>,
    <0.5555556, -167.7264218>,
    <0.5833333, -167.8948019>,
    <0.5833333, -167.7264218>,
    <0.5693782, -167.8102106>,
    <0.5833333, -167.8062788>,
    <0.5694493, -167.7264218>,
    <0.4259259, -167.5208549>,
    <0.4166667, -167.4256532>,
    <0.4166667, -167.5684558>,
    <0.4444444, -167.5684558>,
    <0.4166667, -167.4961890>,
    <0.4305626, -167.5684558>,
    <0.4305249, -167.4968970>,
    <0.4351852, -167.6211112>,
    <0.4166667, -167.5684558>,
    <0.4444444, -167.7264218>,
    <0.4444444, -167.5684558>,
    <0.4305332, -167.6473117>,
    <0.4444444, -167.6468904>,
    <0.4305626, -167.5684558>,
    <0.5648148, -167.6737665>,
    <0.5555556, -167.5684558>,
    <0.5555556, -167.7264218>,
    <0.5833333, -167.7264218>,
    <0.5555556, -167.6468904>,
    <0.5694493, -167.7264218>,
    <0.5694221, -167.6473117>,
    <0.5740741, -167.6211112>,
    <0.5555556, -167.5684558>,
    <0.5833333, -167.7264218>,
    <0.5833333, -167.5684558>,
    <0.5694221, -167.6473117>,
    <0.5833333, -167.6468904>,
    <0.5694515, -167.5684558>,
    <0.4259259, -167.3161845>,
    <0.4166667, -167.2258020>,
    <0.4444444, -167.3613758>,
    <0.4166667, -167.3613758>,
    <0.4305139, -167.2933857>,
    <0.4305655, -167.3613758>,
    <0.4166667, -167.2924560>,
    <0.4351852, -167.4137323>,
    <0.4166667, -167.3613758>,
    <0.4444444, -167.3613758>,
    <0.4444444, -167.5184453>,
    <0.4305655, -167.3613758>,
    <0.4444444, -167.4391507>,
    <0.4305222, -167.4397221>,
    <0.5648148, -167.4660888>,
    <0.5555556, -167.3613758>,
    <0.5833333, -167.5184453>,
    <0.5555556, -167.5184453>,
    <0.5694111, -167.4397221>,
    <0.5694523, -167.5184453>,
    <0.5555556, -167.4391507>,
    <0.5740741, -167.4137323>,
    <0.5555556, -167.3613758>,
    <0.5833333, -167.3613758>,
    <0.5833333, -167.5184453>,
    <0.5694544, -167.3613758>,
    <0.5833333, -167.4391507>,
    <0.5694111, -167.4397221>,
    <0.5778804, -167.0842391>,
    <0.5669746, -167.0684463>,
    <0.5833333, -167.0684463>,
    <0.5833333, -167.1158246>,
    <0.5751539, -167.0684463>,
    <0.5833333, -167.0954675>,
    <0.5762328, -167.0952600>,
    <0.4259259, -167.3845690>,
    <0.4166667, -167.3024008>,
    <0.4166667, -167.4256532>,
    <0.4444444, -167.4256532>,
    <0.4166667, -167.3627833>,
    <0.4305646, -167.4256532>,
    <0.4305174, -167.3638575>,
    <0.4351852, -167.4732541>,
    <0.4166667, -167.4256532>,
    <0.4444444, -167.5684558>,
    <0.4444444, -167.4256532>,
    <0.4305249, -167.4968970>,
    <0.4444444, -167.4961890>,
    <0.4305646, -167.4256532>,
    <0.5648148, -167.5208549>,
    <0.5555556, -167.4256532>,
    <0.5555556, -167.5684558>,
    <0.5833333, -167.5684558>,
    <0.5555556, -167.4961890>,
    <0.5694515, -167.5684558>,
    <0.5694138, -167.4968970>,
    <0.5740741, -167.4732541>,
    <0.5555556, -167.4256532>,
    <0.5833333, -167.5684558>,
    <0.5833333, -167.4256532>,
    <0.5694138, -167.4968970>,
    <0.5833333, -167.4961891>,
    <0.5694535, -167.4256532>,
    <0.4259259, -167.1891429>,
    <0.4166667, -167.1158246>,
    <0.4444444, -167.2258020>,
    <0.4166667, -167.2258020>,
    <0.4302242, -167.1695015>,
    <0.4305673, -167.2258020>,
    <0.4166667, -167.1673444>,
    <0.4351852, -167.2709932>,
    <0.4166667, -167.2258020>,
    <0.4444444, -167.2258020>,
    <0.4444444, -167.3613758>,
    <0.4305673, -167.2258020>,
    <0.4444444, -167.2924560>,
    <0.4305139, -167.2933857>,
    <0.5648148, -167.3161845>,
    <0.5555556, -167.2258020>,
    <0.5833333, -167.3613758>,
    <0.5555556, -167.3613758>,
    <0.5694028, -167.2933857>,
    <0.5694544, -167.3613758>,
    <0.5555556, -167.2924560>,
    <0.5740741, -167.2709932>,
    <0.5555556, -167.2258020>,
    <0.5833333, -167.2258020>,
    <0.5833333, -167.3613758>,
    <0.5694562, -167.2258020>,
    <0.5833333, -167.2924560>,
    <0.5694028, -167.2933857>,
    <0.4208266, -167.1123151>,
    <0.4291465, -167.1040945>,
    <0.4166667, -167.1040945>,
    <0.4166667, -167.1287564>,
    <0.4228491, -167.1040945>,
    <0.4166667, -167.1157282>,
    <0.4195253, -167.1231073>,
    <0.4537037, -168.0047729>,
    <0.4444444, -167.8774261>,
    <0.4722222, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4486794, -167.9065484>,
    <0.4555227, -168.0684463>,
    <0.4444444, -167.9292172>,
    <0.4259259, -167.2690732>,
    <0.4166667, -167.2024179>,
    <0.4166667, -167.3024008>,
    <0.4444444, -167.3024008>,
    <0.4166667, -167.2507837>,
    <0.4305661, -167.3024008>,
    <0.4305108, -167.2522483>,
    <0.4351852, -167.3434849>,
    <0.4166667, -167.3024008>,
    <0.4444444, -167.4256532>,
    <0.4444444, -167.3024008>,
    <0.4305174, -167.3638575>,
    <0.4444444, -167.3627833>,
    <0.4305661, -167.3024008>,
    <0.5648148, -167.3845690>,
    <0.5555556, -167.3024008>,
    <0.5555556, -167.4256532>,
    <0.5833333, -167.4256532>,
    <0.5555556, -167.3627833>,
    <0.5694535, -167.4256532>,
    <0.5694063, -167.3638575>,
    <0.5740741, -167.3434849>,
    <0.5555556, -167.3024008>,
    <0.5833333, -167.4256532>,
    <0.5833333, -167.3024008>,
    <0.5694063, -167.3638575>,
    <0.5833333, -167.3627833>,
    <0.5694550, -167.3024008>,
    <0.4537037, -167.8156918>,
    <0.4444444, -167.6922232>,
    <0.4722222, -167.8774261>,
    <0.4444444, -167.8774261>,
    <0.4582682, -167.7843904>,
    <0.4583474, -167.8774261>,
    <0.4444444, -167.7804778>,
    <0.4629630, -167.9410995>,
    <0.4444444, -167.8774261>,
    <0.4722222, -167.8774261>,
    <0.4722222, -168.0684463>,
    <0.4583474, -167.8774261>,
    <0.4722222, -167.9762380>,
    <0.4486794, -167.9065484>,
    <0.5370370, -168.0047729>,
    <0.5277778, -167.8774261>,
    <0.5555556, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5381343, -167.9486450>,
    <0.5416667, -168.0684463>,
    <0.5277778, -167.9290301>,
    <0.5462963, -167.9410995>,
    <0.5277778, -167.8774261>,
    <0.5555556, -167.8774261>,
    <0.5555556, -168.0684463>,
    <0.5416826, -167.8774261>,
    <0.5555556, -167.9402278>,
    <0.5381343, -167.9486450>,
    <0.5782340, -167.1123151>,
    <0.5680354, -167.1040945>,
    <0.5833333, -167.1287564>,
    <0.5833333, -167.1040945>,
    <0.5798335, -167.1231143>,
    <0.5833333, -167.1186955>,
    <0.5760566, -167.1040945>,
    <0.4537037, -167.6342972>,
    <0.4444444, -167.5184453>,
    <0.4722222, -167.6922232>,
    <0.4444444, -167.6922232>,
    <0.4583091, -167.6051824>,
    <0.4583387, -167.6922232>,
    <0.4444444, -167.6048705>,
    <0.4629630, -167.7539575>,
    <0.4444444, -167.6922232>,
    <0.4722222, -167.6922232>,
    <0.4722222, -167.8774261>,
    <0.4583387, -167.6922232>,
    <0.4722222, -167.7804649>,
    <0.4582682, -167.7843904>,
    <0.5370370, -167.8156918>,
    <0.5277778, -167.6922232>,
    <0.5555556, -167.8774261>,
    <0.5277778, -167.8774261>,
    <0.5415982, -167.7843683>,
    <0.5416826, -167.8774261>,
    <0.5277778, -167.7804462>,
    <0.5462963, -167.7539575>,
    <0.5277778, -167.6922232>,
    <0.5555556, -167.6922232>,
    <0.5555556, -167.8774261>,
    <0.5416721, -167.6922232>,
    <0.5555556, -167.7804408>,
    <0.5415982, -167.7843683>,
    <0.4259259, -167.1000319>,
    <0.4166667, -167.0684463>,
    <0.4444444, -167.1158246>,
    <0.4166667, -167.1158246>,
    <0.4358699, -167.1011998>,
    <0.4299833, -167.1158246>,
    <0.4166667, -167.0945275>,
    <0.4297323, -167.0842391>,
    <0.4166667, -167.0684463>,
    <0.4280857, -167.0684463>,
    <0.4444444, -167.1158246>,
    <0.4223762, -167.0684463>,
    <0.4373807, -167.0953667>,
    <0.4358699, -167.1011998>,
    <0.4351852, -167.1524837>,
    <0.4166667, -167.1158246>,
    <0.4444444, -167.1158246>,
    <0.4444444, -167.2258020>,
    <0.4299833, -167.1158246>,
    <0.4444444, -167.1670444>,
    <0.4302242, -167.1695015>,
    <0.5648148, -167.1891429>,
    <0.5555556, -167.1158246>,
    <0.5833333, -167.2258020>,
    <0.5555556, -167.2258020>,
    <0.5691013, -167.1694547>,
    <0.5694562, -167.2258020>,
    <0.5555556, -167.1669784>,
    <0.5740741, -167.1524837>,
    <0.5555556, -167.1158246>,
    <0.5833333, -167.1158246>,
    <0.5833333, -167.2258020>,
    <0.5688576, -167.1158246>,
    <0.5833333, -167.1670695>,
    <0.5691013, -167.1694547>,
    <0.4537037, -168.0105648>,
    <0.4444444, -167.8948019>,
    <0.4444444, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4444444, -167.9365451>,
    <0.4555227, -168.0684463>,
    <0.4486646, -167.9211829>,
    <0.4537037, -167.8386752>,
    <0.4444444, -167.7264218>,
    <0.4444444, -167.8948019>,
    <0.4722222, -167.8948019>,
    <0.4444444, -167.8063209>,
    <0.4583471, -167.8948019>,
    <0.4582717, -167.8102383>,
    <0.4629630, -167.9526834>,
    <0.4444444, -167.8948019>,
    <0.4722222, -168.0684463>,
    <0.4722222, -167.8948019>,
    <0.4486646, -167.9211829>,
    <0.4722222, -167.9859616>,
    <0.4583471, -167.8948019>,
    <0.5370370, -168.0105648>,
    <0.5277778, -167.8948019>,
    <0.5277778, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5277778, -167.9518248>,
    <0.5416667, -168.0684463>,
    <0.5381375, -167.9595627>,
    <0.5462963, -167.9526834>,
    <0.5277778, -167.8948019>,
    <0.5555556, -168.0684463>,
    <0.5555556, -167.8948019>,
    <0.5381375, -167.9595627>,
    <0.5555556, -167.9517813>,
    <0.5416823, -167.8948019>,
    <0.4259259, -167.1778641>,
    <0.4166667, -167.1287564>,
    <0.4166667, -167.2024179>,
    <0.4444444, -167.2024179>,
    <0.4166667, -167.1607154>,
    <0.4305674, -167.2024179>,
    <0.4307945, -167.1662209>,
    <0.4351852, -167.2357456>,
    <0.4166667, -167.2024179>,
    <0.4444444, -167.3024008>,
    <0.4444444, -167.2024179>,
    <0.4305108, -167.2522483>,
    <0.4444444, -167.2507837>,
    <0.4305674, -167.2024179>,
    <0.5648148, -167.2690732>,
    <0.5555556, -167.2024179>,
    <0.5555556, -167.3024008>,
    <0.5833333, -167.3024008>,
    <0.5555556, -167.2507837>,
    <0.5694550, -167.3024008>,
    <0.5693997, -167.2522483>,
    <0.5740741, -167.2357456>,
    <0.5555556, -167.2024179>,
    <0.5833333, -167.3024008>,
    <0.5833333, -167.2024179>,
    <0.5693997, -167.2522483>,
    <0.5833333, -167.2507837>,
    <0.5694563, -167.2024179>,
    <0.4814815, -168.0047729>,
    <0.4722222, -167.8774261>,
    <0.5000000, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4851526, -167.9663445>,
    <0.4918090, -168.0684463>,
    <0.4722222, -167.9762380>,
    <0.4537037, -167.4660888>,
    <0.4444444, -167.3613758>,
    <0.4722222, -167.5184453>,
    <0.4444444, -167.5184453>,
    <0.4583000, -167.4397221>,
    <0.4583412, -167.5184453>,
    <0.4444444, -167.4391507>,
    <0.4629630, -167.5763713>,
    <0.4444444, -167.5184453>,
    <0.4722222, -167.5184453>,
    <0.4722222, -167.6922232>,
    <0.4583412, -167.5184453>,
    <0.4722222, -167.6048705>,
    <0.4583091, -167.6051824>,
    <0.5370370, -167.6342972>,
    <0.5277778, -167.5184453>,
    <0.5555556, -167.6922232>,
    <0.5277778, -167.6922232>,
    <0.5416424, -167.6051824>,
    <0.5416721, -167.6922232>,
    <0.5277778, -167.6048705>,
    <0.5462963, -167.5763713>,
    <0.5277778, -167.5184453>,
    <0.5555556, -167.5184453>,
    <0.5555556, -167.6922232>,
    <0.5416745, -167.5184453>,
    <0.5555556, -167.6048705>,
    <0.5416424, -167.6051824>,
    <0.4537037, -167.6737665>,
    <0.4444444, -167.5684558>,
    <0.4444444, -167.7264218>,
    <0.4722222, -167.7264218>,
    <0.4444444, -167.6468904>,
    <0.4583382, -167.7264218>,
    <0.4583110, -167.6473117>,
    <0.4629630, -167.7825485>,
    <0.4444444, -167.7264218>,
    <0.4722222, -167.8948019>,
    <0.4722222, -167.7264218>,
    <0.4582717, -167.8102383>,
    <0.4722222, -167.8063071>,
    <0.4583382, -167.7264218>,
    <0.5370370, -167.8386752>,
    <0.5277778, -167.7264218>,
    <0.5277778, -167.8948019>,
    <0.5555556, -167.8948019>,
    <0.5277778, -167.8062871>,
    <0.5416823, -167.8948019>,
    <0.5416017, -167.8102183>,
    <0.5462963, -167.7825485>,
    <0.5277778, -167.7264218>,
    <0.5555556, -167.8948019>,
    <0.5555556, -167.7264218>,
    <0.5416017, -167.8102183>,
    <0.5555556, -167.8062814>,
    <0.5416715, -167.7264218>,
    <0.4814815, -167.8156918>,
    <0.4722222, -167.6922232>,
    <0.5000000, -167.8774261>,
    <0.4722222, -167.8774261>,
    <0.4860450, -167.7843838>,
    <0.4861257, -167.8774261>,
    <0.4722222, -167.7804649>,
    <0.4907407, -167.9410995>,
    <0.4722222, -167.8774261>,
    <0.5000000, -167.8774261>,
    <0.5000000, -168.0684463>,
    <0.4861257, -167.8774261>,
    <0.5000000, -167.9707722>,
    <0.4851526, -167.9663445>,
    <0.5092593, -168.0047729>,
    <0.5000000, -167.8774261>,
    <0.5277778, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5089101, -167.9386982>,
    <0.5109544, -168.0684463>,
    <0.5000000, -167.9707722>,
    <0.5185185, -167.9410995>,
    <0.5000000, -167.8774261>,
    <0.5277778, -167.8774261>,
    <0.5277778, -168.0684463>,
    <0.5139041, -167.8774261>,
    <0.5277778, -167.9290301>,
    <0.5089101, -167.9386982>,
    <0.5686229, -167.0842391>,
    <0.5555607, -167.0684463>,
    <0.5669746, -167.0684463>,
    <0.5833333, -167.1158246>,
    <0.5612676, -167.0684463>,
    <0.5762328, -167.0952600>,
    <0.5747824, -167.1012374>,
    <0.4389915, -167.0842391>,
    <0.4280857, -167.0684463>,
    <0.4444444, -167.0684463>,
    <0.4444444, -167.1158246>,
    <0.4362651, -167.0684463>,
    <0.4444444, -167.0952665>,
    <0.4373807, -167.0953667>,
    <0.5648148, -167.1000319>,
    <0.5555556, -167.0684463>,
    <0.5833333, -167.1158246>,
    <0.5555556, -167.1158246>,
    <0.5747809, -167.1012374>,
    <0.5688576, -167.1158246>,
    <0.5555556, -167.0954519>,
    <0.4814815, -167.6342972>,
    <0.4722222, -167.5184453>,
    <0.5000000, -167.6922232>,
    <0.4722222, -167.6922232>,
    <0.4860868, -167.6051824>,
    <0.4861165, -167.6922232>,
    <0.4722222, -167.6048705>,
    <0.4907407, -167.7539575>,
    <0.4722222, -167.6922232>,
    <0.5000000, -167.6922232>,
    <0.5000000, -167.8774261>,
    <0.4861165, -167.6922232>,
    <0.5000000, -167.7804543>,
    <0.4860450, -167.7843838>,
    <0.5092593, -167.8156918>,
    <0.5000000, -167.6922232>,
    <0.5277778, -167.8774261>,
    <0.5000000, -167.8774261>,
    <0.5138217, -167.7843763>,
    <0.5139041, -167.8774261>,
    <0.5000000, -167.7804543>,
    <0.5185185, -167.7539575>,
    <0.5000000, -167.6922232>,
    <0.5277778, -167.6922232>,
    <0.5277778, -167.8774261>,
    <0.5138943, -167.6922232>,
    <0.5277778, -167.7804462>,
    <0.5138217, -167.7843763>,
    <0.4537037, -167.5208549>,
    <0.4444444, -167.4256532>,
    <0.4444444, -167.5684558>,
    <0.4722222, -167.5684558>,
    <0.4444444, -167.4961890>,
    <0.4583404, -167.5684558>,
    <0.4583027, -167.4968970>,
    <0.4629630, -167.6211112>,
    <0.4444444, -167.5684558>,
    <0.4722222, -167.7264218>,
    <0.4722222, -167.5684558>,
    <0.4583110, -167.6473117>,
    <0.4722222, -167.6468904>,
    <0.4583404, -167.5684558>,
    <0.5370370, -167.6737665>,
    <0.5277778, -167.5684558>,
    <0.5277778, -167.7264218>,
    <0.5555556, -167.7264218>,
    <0.5277778, -167.6468904>,
    <0.5416715, -167.7264218>,
    <0.5416443, -167.6473117>,
    <0.5462963, -167.6211112>,
    <0.5277778, -167.5684558>,
    <0.5555556, -167.7264218>,
    <0.5555556, -167.5684558>,
    <0.5416443, -167.6473117>,
    <0.5555556, -167.6468904>,
    <0.5416737, -167.5684558>,
    <0.4814815, -168.0105648>,
    <0.4722222, -167.8948019>,
    <0.4722222, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4722222, -167.9859616>,
    <0.4843793, -168.0684463>,
    <0.4804233, -167.9460688>,
    <0.4537037, -167.3161845>,
    <0.4444444, -167.2258020>,
    <0.4722222, -167.3613758>,
    <0.4444444, -167.3613758>,
    <0.4582917, -167.2933857>,
    <0.4583433, -167.3613758>,
    <0.4444444, -167.2924560>,
    <0.4629630, -167.4137323>,
    <0.4444444, -167.3613758>,
    <0.4722222, -167.3613758>,
    <0.4722222, -167.5184453>,
    <0.4583433, -167.3613758>,
    <0.4722222, -167.4391507>,
    <0.4583000, -167.4397221>,
    <0.5370370, -167.4660888>,
    <0.5277778, -167.3613758>,
    <0.5555556, -167.5184453>,
    <0.5277778, -167.5184453>,
    <0.5416333, -167.4397221>,
    <0.5416745, -167.5184453>,
    <0.5277778, -167.4391507>,
    <0.5462963, -167.4137323>,
    <0.5277778, -167.3613758>,
    <0.5555556, -167.3613758>,
    <0.5555556, -167.5184453>,
    <0.5416767, -167.3613758>,
    <0.5555556, -167.4391507>,
    <0.5416333, -167.4397221>,
    <0.4814815, -167.8386752>,
    <0.4722222, -167.7264218>,
    <0.4722222, -167.8948019>,
    <0.5000000, -167.8948019>,
    <0.4722222, -167.8063071>,
    <0.4861255, -167.8948019>,
    <0.4860485, -167.8102322>,
    <0.4907407, -167.9526834>,
    <0.4722222, -167.8948019>,
    <0.5000000, -168.0684463>,
    <0.5000000, -167.8948019>,
    <0.4804233, -167.9460688>,
    <0.5000000, -167.9364144>,
    <0.4861255, -167.8948019>,
    <0.5092593, -168.0105648>,
    <0.5000000, -167.8948019>,
    <0.5000000, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5000000, -167.9364144>,
    <0.5138889, -168.0684463>,
    <0.5103607, -167.9595688>,
    <0.5185185, -167.9526834>,
    <0.5000000, -167.8948019>,
    <0.5277778, -168.0684463>,
    <0.5277778, -167.8948019>,
    <0.5103607, -167.9595688>,
    <0.5277778, -167.9518248>,
    <0.5139039, -167.8948019>,
    <0.4381085, -167.1123151>,
    <0.4407346, -167.1040945>,
    <0.4291465, -167.1040945>,
    <0.4444444, -167.1287564>,
    <0.4343477, -167.1040945>,
    <0.4407448, -167.1227922>,
    <0.4434422, -167.1220942>,
    <0.4300859, -167.1205358>,
    <0.4291465, -167.1040945>,
    <0.4166667, -167.1287564>,
    <0.4444444, -167.1287564>,
    <0.4195253, -167.1231073>,
    <0.4295859, -167.1287564>,
    <0.4407448, -167.1227922>,
    <0.4351852, -167.1533103>,
    <0.4166667, -167.1287564>,
    <0.4444444, -167.2024179>,
    <0.4444444, -167.1287564>,
    <0.4307945, -167.1662209>,
    <0.4444444, -167.1607154>,
    <0.4295859, -167.1287564>,
    <0.5648148, -167.1778641>,
    <0.5555556, -167.1287564>,
    <0.5555556, -167.2024179>,
    <0.5833333, -167.2024179>,
    <0.5555556, -167.1601026>,
    <0.5694563, -167.2024179>,
    <0.5697767, -167.1664683>,
    <0.5689748, -167.1205421>,
    <0.5680355, -167.1041136>,
    <0.5555556, -167.1287564>,
    <0.5833333, -167.1287564>,
    <0.5587264, -167.1224952>,
    <0.5686557, -167.1287564>,
    <0.5798335, -167.1231187>,
    <0.5740741, -167.1533103>,
    <0.5555556, -167.1287564>,
    <0.5833333, -167.2024179>,
    <0.5833333, -167.1287564>,
    <0.5697767, -167.1664683>,
    <0.5833333, -167.1601023>,
    <0.5686557, -167.1287564>,
    <0.4814815, -167.4660888>,
    <0.4722222, -167.3613758>,
    <0.5000000, -167.5184453>,
    <0.4722222, -167.5184453>,
    <0.4860778, -167.4397221>,
    <0.4861190, -167.5184453>,
    <0.4722222, -167.4391507>,
    <0.4907407, -167.5763713>,
    <0.4722222, -167.5184453>,
    <0.5000000, -167.5184453>,
    <0.5000000, -167.6922232>,
    <0.4861190, -167.5184453>,
    <0.5000000, -167.6048705>,
    <0.4860868, -167.6051824>,
    <0.5092593, -167.6342972>,
    <0.5000000, -167.5184453>,
    <0.5277778, -167.6922232>,
    <0.5000000, -167.6922232>,
    <0.5138646, -167.6051824>,
    <0.5138943, -167.6922232>,
    <0.5000000, -167.6048705>,
    <0.5185185, -167.5763713>,
    <0.5000000, -167.5184453>,
    <0.5277778, -167.5184453>,
    <0.5277778, -167.6922232>,
    <0.5138967, -167.5184453>,
    <0.5277778, -167.6048705>,
    <0.5138646, -167.6051824>,
    <0.5606678, -167.1123279>,
    <0.5680355, -167.1041136>,
    <0.5584122, -167.1041136>,
    <0.5555556, -167.1287564>,
    <0.5640120, -167.1041136>,
    <0.5565732, -167.1199778>,
    <0.5587264, -167.1224952>,
    <0.4814815, -167.6737665>,
    <0.4722222, -167.5684558>,
    <0.4722222, -167.7264218>,
    <0.5000000, -167.7264218>,
    <0.4722222, -167.6468904>,
    <0.4861160, -167.7264218>,
    <0.4860887, -167.6473117>,
    <0.4907407, -167.7825485>,
    <0.4722222, -167.7264218>,
    <0.5000000, -167.8948019>,
    <0.5000000, -167.7264218>,
    <0.4860485, -167.8102322>,
    <0.5000000, -167.8062957>,
    <0.4861160, -167.7264218>,
    <0.5092593, -167.8386752>,
    <0.5000000, -167.7264218>,
    <0.5000000, -167.8948019>,
    <0.5277778, -167.8948019>,
    <0.5000000, -167.8062957>,
    <0.5139039, -167.8948019>,
    <0.5138252, -167.8102256>,
    <0.5185185, -167.7825485>,
    <0.5000000, -167.7264218>,
    <0.5277778, -167.8948019>,
    <0.5277778, -167.7264218>,
    <0.5138252, -167.8102256>,
    <0.5277778, -167.8062871>,
    <0.5138938, -167.7264218>,
    <0.4537037, -167.3845690>,
    <0.4444444, -167.3024008>,
    <0.4444444, -167.4256532>,
    <0.4722222, -167.4256532>,
    <0.4444444, -167.3627833>,
    <0.4583423, -167.4256532>,
    <0.4582951, -167.3638575>,
    <0.4629630, -167.4732541>,
    <0.4444444, -167.4256532>,
    <0.4722222, -167.5684558>,
    <0.4722222, -167.4256532>,
    <0.4583027, -167.4968970>,
    <0.4722222, -167.4961890>,
    <0.4583423, -167.4256532>,
    <0.5370370, -167.5208549>,
    <0.5277778, -167.4256532>,
    <0.5277778, -167.5684558>,
    <0.5555556, -167.5684558>,
    <0.5277778, -167.4961890>,
    <0.5416737, -167.5684558>,
    <0.5416360, -167.4968970>,
    <0.5462963, -167.4732541>,
    <0.5277778, -167.4256532>,
    <0.5555556, -167.5684558>,
    <0.5555556, -167.4256532>,
    <0.5416360, -167.4968970>,
    <0.5555556, -167.4961890>,
    <0.5416757, -167.4256532>,
    <0.4432078, -167.1123151>,
    <0.4407346, -167.1040945>,
    <0.4444444, -167.1287564>,
    <0.4444444, -167.1040945>,
    <0.4434422, -167.1220942>,
    <0.4444444, -167.1157255>,
    <0.4422023, -167.1040945>,
    <0.5565078, -167.1123215>,
    <0.5584122, -167.1041136>,
    <0.5555556, -167.1040945>,
    <0.5555556, -167.1287564>,
    <0.5573085, -167.1041062>,
    <0.5555556, -167.1187029>,
    <0.5565732, -167.1199778>,
    <0.4814815, -167.5208549>,
    <0.4722222, -167.4256532>,
    <0.4722222, -167.5684558>,
    <0.5000000, -167.5684558>,
    <0.4722222, -167.4961890>,
    <0.4861182, -167.5684558>,
    <0.4860805, -167.4968970>,
    <0.4907407, -167.6211112>,
    <0.4722222, -167.5684558>,
    <0.5000000, -167.7264218>,
    <0.5000000, -167.5684558>,
    <0.4860887, -167.6473117>,
    <0.5000000, -167.6468904>,
    <0.4861182, -167.5684558>,
    <0.5092593, -167.6737665>,
    <0.5000000, -167.5684558>,
    <0.5000000, -167.7264218>,
    <0.5277778, -167.7264218>,
    <0.5000000, -167.6468904>,
    <0.5138938, -167.7264218>,
    <0.5138665, -167.6473117>,
    <0.5185185, -167.6211112>,
    <0.5000000, -167.5684558>,
    <0.5277778, -167.7264218>,
    <0.5277778, -167.5684558>,
    <0.5138665, -167.6473117>,
    <0.5277778, -167.6468904>,
    <0.5138960, -167.5684558>,
    <0.4537037, -167.1891429>,
    <0.4444444, -167.1158246>,
    <0.4722222, -167.2258020>,
    <0.4444444, -167.2258020>,
    <0.4579936, -167.1694682>,
    <0.4583451, -167.2258020>,
    <0.4444444, -167.1670444>,
    <0.4629630, -167.2709932>,
    <0.4444444, -167.2258020>,
    <0.4722222, -167.2258020>,
    <0.4722222, -167.3613758>,
    <0.4583451, -167.2258020>,
    <0.4722222, -167.2924560>,
    <0.4582917, -167.2933857>,
    <0.5370370, -167.3161845>,
    <0.5277778, -167.2258020>,
    <0.5555556, -167.3613758>,
    <0.5277778, -167.3613758>,
    <0.5416250, -167.2933857>,
    <0.5416767, -167.3613758>,
    <0.5277778, -167.2924560>,
    <0.5462963, -167.2709932>,
    <0.5277778, -167.2258020>,
    <0.5555556, -167.2258020>,
    <0.5555556, -167.3613758>,
    <0.5416784, -167.2258020>,
    <0.5555556, -167.2924560>,
    <0.5416250, -167.2933857>,
    <0.4814815, -167.3161845>,
    <0.4722222, -167.2258020>,
    <0.5000000, -167.3613758>,
    <0.4722222, -167.3613758>,
    <0.4860695, -167.2933857>,
    <0.4861211, -167.3613758>,
    <0.4722222, -167.2924560>,
    <0.4907407, -167.4137323>,
    <0.4722222, -167.3613758>,
    <0.5000000, -167.3613758>,
    <0.5000000, -167.5184453>,
    <0.4861211, -167.3613758>,
    <0.5000000, -167.4391507>,
    <0.4860778, -167.4397221>,
    <0.5092593, -167.4660888>,
    <0.5000000, -167.3613758>,
    <0.5277778, -167.5184453>,
    <0.5000000, -167.5184453>,
    <0.5138556, -167.4397221>,
    <0.5138967, -167.5184453>,
    <0.5000000, -167.4391507>,
    <0.5185185, -167.4137323>,
    <0.5000000, -167.3613758>,
    <0.5277778, -167.3613758>,
    <0.5277778, -167.5184453>,
    <0.5138989, -167.3613758>,
    <0.5277778, -167.4391507>,
    <0.5138556, -167.4397221>,
    <0.4537037, -167.2690732>,
    <0.4444444, -167.2024179>,
    <0.4444444, -167.3024008>,
    <0.4722222, -167.3024008>,
    <0.4444444, -167.2507837>,
    <0.4583439, -167.3024008>,
    <0.4582886, -167.2522483>,
    <0.4629630, -167.3434849>,
    <0.4444444, -167.3024008>,
    <0.4722222, -167.4256532>,
    <0.4722222, -167.3024008>,
    <0.4582951, -167.3638575>,
    <0.4722222, -167.3627833>,
    <0.4583439, -167.3024008>,
    <0.5370370, -167.3845690>,
    <0.5277778, -167.3024008>,
    <0.5277778, -167.4256532>,
    <0.5555556, -167.4256532>,
    <0.5277778, -167.3627833>,
    <0.5416757, -167.4256532>,
    <0.5416285, -167.3638575>,
    <0.5462963, -167.3434849>,
    <0.5277778, -167.3024008>,
    <0.5555556, -167.4256532>,
    <0.5555556, -167.3024008>,
    <0.5416285, -167.3638575>,
    <0.5555556, -167.3627833>,
    <0.5416773, -167.3024008>,
    <0.5501016, -167.0842391>,
    <0.5391937, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5555556, -167.1158246>,
    <0.5473746, -167.0684463>,
    <0.5555556, -167.0954519>,
    <0.5484609, -167.0952809>,
    <0.4814815, -167.3845690>,
    <0.4722222, -167.3024008>,
    <0.4722222, -167.4256532>,
    <0.5000000, -167.4256532>,
    <0.4722222, -167.3627833>,
    <0.4861201, -167.4256532>,
    <0.4860729, -167.3638575>,
    <0.4907407, -167.4732541>,
    <0.4722222, -167.4256532>,
    <0.5000000, -167.5684558>,
    <0.5000000, -167.4256532>,
    <0.4860805, -167.4968970>,
    <0.5000000, -167.4961890>,
    <0.4861201, -167.4256532>,
    <0.5092593, -167.5208549>,
    <0.5000000, -167.4256532>,
    <0.5000000, -167.5684558>,
    <0.5277778, -167.5684558>,
    <0.5000000, -167.4961890>,
    <0.5138960, -167.5684558>,
    <0.5138583, -167.4968970>,
    <0.5185185, -167.4732541>,
    <0.5000000, -167.4256532>,
    <0.5277778, -167.5684558>,
    <0.5277778, -167.4256532>,
    <0.5138583, -167.4968970>,
    <0.5277778, -167.4961890>,
    <0.5138979, -167.4256532>,
    <0.4907407, -167.2709932>,
    <0.4722222, -167.2258020>,
    <0.5000000, -167.2258020>,
    <0.5000000, -167.3613758>,
    <0.4861228, -167.2258020>,
    <0.5000000, -167.2924560>,
    <0.4860695, -167.2933857>,
    <0.5092593, -167.3161845>,
    <0.5000000, -167.2258020>,
    <0.5277778, -167.3613758>,
    <0.5000000, -167.3613758>,
    <0.5138473, -167.2933857>,
    <0.5138989, -167.3613758>,
    <0.5000000, -167.2924560>,
    <0.5185185, -167.2709932>,
    <0.5000000, -167.2258020>,
    <0.5277778, -167.2258020>,
    <0.5277778, -167.3613758>,
    <0.5139006, -167.2258020>,
    <0.5277778, -167.2924560>,
    <0.5138473, -167.2933857>,
    <0.4537037, -167.1000319>,
    <0.4444444, -167.0684463>,
    <0.4722222, -167.1158246>,
    <0.4444444, -167.1158246>,
    <0.4636317, -167.1011725>,
    <0.4577558, -167.1158246>,
    <0.4444444, -167.0952665>,
    <0.4575090, -167.0842391>,
    <0.4444444, -167.0684463>,
    <0.4558604, -167.0684463>,
    <0.4722222, -167.1158246>,
    <0.4501524, -167.0684463>,
    <0.4651866, -167.0954520>,
    <0.4636317, -167.1011725>,
    <0.4629630, -167.1524837>,
    <0.4444444, -167.1158246>,
    <0.4722222, -167.1158246>,
    <0.4722222, -167.2258020>,
    <0.4577558, -167.1158246>,
    <0.4722222, -167.1671622>,
    <0.4579936, -167.1694682>,
    <0.4814815, -167.1891429>,
    <0.4722222, -167.1158246>,
    <0.5000000, -167.2258020>,
    <0.4722222, -167.2258020>,
    <0.4857744, -167.1694803>,
    <0.4861228, -167.2258020>,
    <0.4722222, -167.1671622>,
    <0.5370370, -167.1891429>,
    <0.5277778, -167.1158246>,
    <0.5555556, -167.2258020>,
    <0.5277778, -167.2258020>,
    <0.5413182, -167.1694338>,
    <0.5416784, -167.2258020>,
    <0.5277778, -167.1667832>,
    <0.5462963, -167.1524837>,
    <0.5277778, -167.1158246>,
    <0.5555556, -167.1158246>,
    <0.5555556, -167.2258020>,
    <0.5410776, -167.1158246>,
    <0.5555556, -167.1669784>,
    <0.5413182, -167.1694338>,
    <0.4486044, -167.1123151>,
    <0.4569243, -167.1040945>,
    <0.4444444, -167.1040945>,
    <0.4444444, -167.1287564>,
    <0.4506269, -167.1040945>,
    <0.4444444, -167.1157255>,
    <0.4473031, -167.1231073>,
    <0.4537037, -167.1778641>,
    <0.4444444, -167.1287564>,
    <0.4444444, -167.2024179>,
    <0.4722222, -167.2024179>,
    <0.4444444, -167.1607154>,
    <0.4583451, -167.2024179>,
    <0.4585723, -167.1662209>,
    <0.4629630, -167.2357456>,
    <0.4444444, -167.2024179>,
    <0.4722222, -167.3024008>,
    <0.4722222, -167.2024179>,
    <0.4582886, -167.2522483>,
    <0.4722222, -167.2507837>,
    <0.4583451, -167.2024179>,
    <0.5370370, -167.2690732>,
    <0.5277778, -167.2024179>,
    <0.5277778, -167.3024008>,
    <0.5555556, -167.3024008>,
    <0.5277778, -167.2507837>,
    <0.5416773, -167.3024008>,
    <0.5416219, -167.2522483>,
    <0.5462963, -167.2357456>,
    <0.5277778, -167.2024179>,
    <0.5555556, -167.3024008>,
    <0.5555556, -167.2024179>,
    <0.5416219, -167.2522483>,
    <0.5555556, -167.2507837>,
    <0.5416785, -167.2024179>,
    <0.4814815, -167.2690732>,
    <0.4722222, -167.2024179>,
    <0.4722222, -167.3024008>,
    <0.5000000, -167.3024008>,
    <0.4722222, -167.2507837>,
    <0.4861217, -167.3024008>,
    <0.4860664, -167.2522483>,
    <0.4907407, -167.3434849>,
    <0.4722222, -167.3024008>,
    <0.5000000, -167.4256532>,
    <0.5000000, -167.3024008>,
    <0.4860729, -167.3638575>,
    <0.5000000, -167.3627833>,
    <0.4861217, -167.3024008>,
    <0.5092593, -167.3845690>,
    <0.5000000, -167.3024008>,
    <0.5000000, -167.4256532>,
    <0.5277778, -167.4256532>,
    <0.5000000, -167.3627833>,
    <0.5138979, -167.4256532>,
    <0.5138507, -167.3638575>,
    <0.5185185, -167.3434849>,
    <0.5000000, -167.3024008>,
    <0.5277778, -167.4256532>,
    <0.5277778, -167.3024008>,
    <0.5138507, -167.3638575>,
    <0.5277778, -167.3627833>,
    <0.5138995, -167.3024008>,
    <0.5504562, -167.1123151>,
    <0.5402576, -167.1040945>,
    <0.5555556, -167.1287564>,
    <0.5555556, -167.1040945>,
    <0.5520558, -167.1231144>,
    <0.5555556, -167.1187029>,
    <0.5482787, -167.1040945>,
    <0.4667693, -167.0842391>,
    <0.4558634, -167.0684463>,
    <0.4722222, -167.0684463>,
    <0.4722222, -167.1158246>,
    <0.4640428, -167.0684463>,
    <0.4722222, -167.0950173>,
    <0.4651880, -167.0954520>,
    <0.5370370, -167.1000319>,
    <0.5277778, -167.0684463>,
    <0.5555556, -167.1158246>,
    <0.5277778, -167.1158246>,
    <0.5469930, -167.1012202>,
    <0.5410776, -167.1158246>,
    <0.5277778, -167.0956495>,
    <0.5408434, -167.0842391>,
    <0.5277778, -167.0684463>,
    <0.5391968, -167.0684463>,
    <0.5555556, -167.1158246>,
    <0.5334873, -167.0684463>,
    <0.5484622, -167.0952809>,
    <0.5469930, -167.1012202>,
    <0.4814815, -167.1000319>,
    <0.4722222, -167.0684463>,
    <0.5000000, -167.1158246>,
    <0.4722222, -167.1158246>,
    <0.4913766, -167.1011164>,
    <0.4855405, -167.1158246>,
    <0.4722222, -167.0950173>,
    <0.4907407, -167.1524837>,
    <0.4722222, -167.1158246>,
    <0.5000000, -167.1158246>,
    <0.5000000, -167.2258020>,
    <0.4855405, -167.1158246>,
    <0.5000000, -167.1674339>,
    <0.4857744, -167.1694803>,
    <0.5092593, -167.1891429>,
    <0.5000000, -167.1158246>,
    <0.5277778, -167.2258020>,
    <0.5000000, -167.2258020>,
    <0.5135587, -167.1695059>,
    <0.5139006, -167.2258020>,
    <0.5000000, -167.1674339>,
    <0.5185185, -167.1524837>,
    <0.5000000, -167.1158246>,
    <0.5277778, -167.1158246>,
    <0.5277778, -167.2258020>,
    <0.5133094, -167.1158246>,
    <0.5277778, -167.1667832>,
    <0.5135587, -167.1695059>,
    <0.4852878, -167.0842391>,
    <0.4722222, -167.0684463>,
    <0.4836412, -167.0684463>,
    <0.5000000, -167.1158246>,
    <0.4782185, -167.0684463>,
    <0.4933897, -167.0966798>,
    <0.4913766, -167.1011164>,
    <0.5223249, -167.0842391>,
    <0.5114190, -167.0684463>,
    <0.5277778, -167.0684463>,
    <0.5277778, -167.1158246>,
    <0.5195984, -167.0684463>,
    <0.5277778, -167.0956495>,
    <0.5206163, -167.0950836>,
    <0.4907407, -167.2357456>,
    <0.4722222, -167.2024179>,
    <0.5000000, -167.3024008>,
    <0.5000000, -167.2024179>,
    <0.4860664, -167.2522483>,
    <0.5000000, -167.2507837>,
    <0.4861229, -167.2024179>,
    <0.5092593, -167.2690732>,
    <0.5000000, -167.2024179>,
    <0.5000000, -167.3024008>,
    <0.5277778, -167.3024008>,
    <0.5000000, -167.2507837>,
    <0.5138995, -167.3024008>,
    <0.5138441, -167.2522483>,
    <0.5185185, -167.2357456>,
    <0.5000000, -167.2024179>,
    <0.5277778, -167.3024008>,
    <0.5277778, -167.2024179>,
    <0.5138441, -167.2522483>,
    <0.5277778, -167.2507837>,
    <0.5139007, -167.2024179>,
    <0.4578637, -167.1205358>,
    <0.4569243, -167.1040945>,
    <0.4444444, -167.1287564>,
    <0.4722222, -167.1287564>,
    <0.4473031, -167.1231073>,
    <0.4573637, -167.1287564>,
    <0.4685226, -167.1227921>,
    <0.4629630, -167.1533103>,
    <0.4444444, -167.1287564>,
    <0.4722222, -167.2024179>,
    <0.4722222, -167.1287564>,
    <0.4585723, -167.1662209>,
    <0.4722222, -167.1607154>,
    <0.4573637, -167.1287564>,
    <0.4814815, -167.1778641>,
    <0.4722222, -167.1287564>,
    <0.4722222, -167.2024179>,
    <0.5000000, -167.2024179>,
    <0.4722222, -167.1607154>,
    <0.4861229, -167.2024179>,
    <0.4863501, -167.1662209>,
    <0.5370370, -167.1778641>,
    <0.5277778, -167.1287564>,
    <0.5277778, -167.2024179>,
    <0.5555556, -167.2024179>,
    <0.5277778, -167.1601023>,
    <0.5416785, -167.2024179>,
    <0.5419990, -167.1664684>,
    <0.5411970, -167.1205421>,
    <0.5402577, -167.1041136>,
    <0.5277778, -167.1287564>,
    <0.5555556, -167.1287564>,
    <0.5309484, -167.1224956>,
    <0.5408779, -167.1287564>,
    <0.5520558, -167.1231188>,
    <0.5462963, -167.1533103>,
    <0.5277778, -167.1287564>,
    <0.5555556, -167.2024179>,
    <0.5555556, -167.1287564>,
    <0.5419990, -167.1664684>,
    <0.5555556, -167.1601026>,
    <0.5408779, -167.1287564>,
    <0.4658863, -167.1123151>,
    <0.4685123, -167.1040945>,
    <0.4569245, -167.1040945>,
    <0.4722222, -167.1287564>,
    <0.4621255, -167.1040945>,
    <0.4685226, -167.1227921>,
    <0.4712200, -167.1220942>,
    <0.5328900, -167.1123279>,
    <0.5402577, -167.1041136>,
    <0.5306344, -167.1041136>,
    <0.5277778, -167.1287564>,
    <0.5362343, -167.1041136>,
    <0.5287953, -167.1199785>,
    <0.5309484, -167.1224956>,
    <0.4945481, -167.0842391>,
    <0.4836443, -167.0684463>,
    <0.5000000, -167.0684463>,
    <0.5000000, -167.1158246>,
    <0.4921420, -167.0684463>,
    <0.5000000, -167.0946348>,
    <0.4933909, -167.0966798>,
    <0.5092593, -167.1000319>,
    <0.5000000, -167.0684463>,
    <0.5277778, -167.1158246>,
    <0.5000000, -167.1158246>,
    <0.5192576, -167.1012925>,
    <0.5133094, -167.1158246>,
    <0.5000000, -167.0946348>,
    <0.5130656, -167.0842391>,
    <0.5000000, -167.0684463>,
    <0.5114190, -167.0684463>,
    <0.5277778, -167.1158246>,
    <0.5057095, -167.0684463>,
    <0.5206163, -167.0950836>,
    <0.5192576, -167.1012925>,
    <0.4709856, -167.1123151>,
    <0.4685123, -167.1040945>,
    <0.4722222, -167.1287564>,
    <0.4722222, -167.1040945>,
    <0.4712200, -167.1220942>,
    <0.4722222, -167.1157260>,
    <0.4699801, -167.1040945>,
    <0.5287300, -167.1123215>,
    <0.5306344, -167.1041136>,
    <0.5277778, -167.1040945>,
    <0.5277778, -167.1287564>,
    <0.5295310, -167.1041062>,
    <0.5277778, -167.1186952>,
    <0.5287953, -167.1199785>,
    <0.4907407, -167.1533103>,
    <0.4722222, -167.1287564>,
    <0.5000000, -167.2024179>,
    <0.5000000, -167.1287564>,
    <0.4863501, -167.1662209>,
    <0.5000000, -167.1607153>,
    <0.4851415, -167.1287564>,
    <0.5092593, -167.1778641>,
    <0.5000000, -167.1287564>,
    <0.5000000, -167.2024179>,
    <0.5277778, -167.2024179>,
    <0.5000000, -167.1607153>,
    <0.5139007, -167.2024179>,
    <0.5141279, -167.1662209>,
    <0.5185185, -167.1533103>,
    <0.5000000, -167.1287564>,
    <0.5277778, -167.2024179>,
    <0.5277778, -167.1287564>,
    <0.5141279, -167.1662209>,
    <0.5277778, -167.1601023>,
    <0.5130155, -167.1287564>,
    <0.4763822, -167.1123151>,
    <0.4847021, -167.1040945>,
    <0.4722222, -167.1040945>,
    <0.4722222, -167.1287564>,
    <0.4784047, -167.1040945>,
    <0.4722222, -167.1157260>,
    <0.4750809, -167.1231073>,
    <0.4856414, -167.1205358>,
    <0.4847021, -167.1040945>,
    <0.4722222, -167.1287564>,
    <0.5000000, -167.1287564>,
    <0.4750809, -167.1231073>,
    <0.4851415, -167.1287564>,
    <0.4963004, -167.1227922>,
    <0.5134192, -167.1205358>,
    <0.5124799, -167.1040945>,
    <0.5000000, -167.1287564>,
    <0.5277778, -167.1287564>,
    <0.5032165, -167.1224002>,
    <0.5130155, -167.1287564>,
    <0.5240112, -167.1226843>,
    <0.5226785, -167.1123151>,
    <0.5124798, -167.1040945>,
    <0.5277778, -167.1287564>,
    <0.5277778, -167.1040945>,
    <0.5240112, -167.1226843>,
    <0.5277778, -167.1186952>,
    <0.5203087, -167.1040945>,
    <0.4936641, -167.1123151>,
    <0.4962902, -167.1040945>,
    <0.4847022, -167.1040945>,
    <0.5000000, -167.1287564>,
    <0.4899034, -167.1040945>,
    <0.4963004, -167.1227922>,
    <0.4989978, -167.1220941>,
    <0.5041600, -167.1123151>,
    <0.5124799, -167.1040945>,
    <0.5000000, -167.1040945>,
    <0.5000000, -167.1287564>,
    <0.5064108, -167.1040945>,
    <0.5000000, -167.1157290>,
    <0.5032165, -167.1224002>,
    <0.4987634, -167.1123151>,
    <0.4962903, -167.1040945>,
    <0.5000000, -167.1287564>,
    <0.5000000, -167.1040945>,
    <0.4989978, -167.1220941>,
    <0.5000000, -167.1157290>,
    <0.4977581, -167.1040945>,
    <0.9997094, -167.0967710>,
    <0.9996714, -167.0922118>,
    <0.9991661, -167.1040945>,
    <1.0000000, -167.1040945>,
    <1.0000000, -167.0866834>,
    <0.9993959, -167.0986910>,
    <0.9994332, -167.1040945>,
    <1.0000000, -167.1003723>,
    <0.9998852, -167.0886142>,
    <0.9998447, -167.0815902>,
    <0.9996714, -167.0922118>,
    <1.0000000, -167.0866834>,
    <1.0000000, -167.0684463>,
    <0.9997076, -167.0790193>,
    <0.9998852, -167.0886142>,
    <1.0000000, -167.0767419>,
    <0.9998453, -167.0740418>,
    <0.9996941, -167.0839438>,
    <0.9993898, -167.0948550>,
    <0.9996714, -167.0922118>,
    <0.9997076, -167.0790193>,
    <0.9990142, -167.1040945>,
    <0.9991661, -167.1040945>,
    <0.9996941, -167.0839438>,
    <0.9993867, -167.0906218>,
    <0.9990690, -167.1040945>,
    <0.9993959, -167.0986910>,
    <0.9883853, -167.0962010>,
    <0.9930814, -167.0922118>,
    <0.9911505, -167.0844033>,
    <0.9802301, -167.1040945>,
    <0.9890793, -167.1040945>,
    <0.9918212, -167.0871157>,
    <0.9870173, -167.0918561>,
    <0.9847864, -167.1040945>,
    <0.9907250, -167.0992080>,
    <0.9952206, -167.0948550>,
    <0.9930814, -167.0922118>,
    <0.9890793, -167.1040945>,
    <0.9990140, -167.1040945>,
    <0.9997076, -167.0790193>,
    <0.9907250, -167.0992080>,
    <0.9935545, -167.1040945>,
    <0.9993867, -167.0906218>,
    <0.9964297, -167.0855453>,
    <0.9959849, -167.0810202>,
    <0.9930814, -167.0922118>,
    <0.9997076, -167.0790193>,
    <1.0000000, -167.0684463>,
    <0.9911505, -167.0844033>,
    <0.9964297, -167.0855453>,
    <0.9998452, -167.0740418>,
    <0.9947460, -167.0779200>,
    <0.9918212, -167.0871157>,
    <0.4556237, -167.0964231>,
    <0.6755973, -167.0922118>,
    <0.5799923, -167.1040945>,
    <0.0267920, -167.1040945>,
    <0.5401131, -167.0852918>,
    <0.6207080, -167.0990340>,
    <0.3376430, -167.1040945>,
    <0.3454498, -167.0924222>,
    <0.5929622, -167.0879911>,
    <0.8039276, -167.0831583>,
    <0.6755973, -167.0922118>,
    <0.5401131, -167.0852918>,
    <1.0000000, -167.0684463>,
    <1.0000000, -167.0866834>,
    <0.5929622, -167.0879911>,
    <0.7189428, -167.0787413>,
    <1.0000000, -167.0767419>,
    <0.8418408, -167.0893787>,
    <0.8138974, -167.0967710>,
    <0.6755973, -167.0922118>,
    <1.0000000, -167.0866834>,
    <1.0000000, -167.1040945>,
    <0.5799923, -167.1040945>,
    <0.8418408, -167.0893787>,
    <1.0000000, -167.1003723>,
    <0.7965125, -167.1040945>,
    <0.6207080, -167.0990340>,
    <0.0274768, -167.0967570>,
    <0.0274483, -167.0922118>,
    <0.0269074, -167.1040945>,
    <0.0277752, -167.1040945>,
    <0.0277765, -167.0866273>,
    <0.0271462, -167.0988479>,
    <0.0271465, -167.1040945>,
    <0.0277754, -167.1003898>,
    <0.0276555, -167.0886851>,
    <0.0276312, -167.0812413>,
    <0.0274483, -167.0922118>,
    <0.0277765, -167.0866273>,
    <0.0277778, -167.0684463>,
    <0.0275224, -167.0776799>,
    <0.0276555, -167.0886851>,
    <0.0277772, -167.0764658>,
    <0.0276535, -167.0729413>,
    <0.0274963, -167.0828109>,
    <0.0271676, -167.0945202>,
    <0.0274483, -167.0922118>,
    <0.0275224, -167.0776799>,
    <0.0267920, -167.1040945>,
    <0.0269074, -167.1040945>,
    <0.0274963, -167.0828109>,
    <0.0272381, -167.0879623>,
    <0.0268328, -167.1040945>,
    <0.0271462, -167.0988479>,
    <0.2364877, -167.0868488>,
    <0.3515232, -167.0803290>,
    <0.5401131, -167.0852918>,
    <0.0267920, -167.1040945>,
    <0.0275224, -167.0776799>,
    <0.4591341, -167.0831608>,
    <0.3454498, -167.0924222>,
    <0.0272381, -167.0879623>,
    <0.1904146, -167.0790118>,
    <0.2301781, -167.0737254>,
    <0.3515232, -167.0803290>,
    <0.0275224, -167.0776799>,
    <0.0277778, -167.0684463>,
    <0.5138889, -167.0684463>,
    <0.1904146, -167.0790118>,
    <0.0276535, -167.0729413>,
    <0.2708333, -167.0684463>,
    <0.4509379, -167.0730534>,
    <0.6013813, -167.0756283>,
    <0.3515232, -167.0803290>,
    <0.5138889, -167.0684463>,
    <1.0000000, -167.0684463>,
    <0.5401131, -167.0852918>,
    <0.4509379, -167.0730534>,
    <0.7569444, -167.0684463>,
    <0.7189428, -167.0787413>,
    <0.4591341, -167.0831608>,
    <0.9826565, -167.0875150>,
    <0.9841508, -167.0803290>,
    <0.9750946, -167.0812332>,
    <0.9802301, -167.1040945>,
    <0.9911505, -167.0844033>,
    <0.9795255, -167.0807908>,
    <0.9769943, -167.0896900>,
    <0.9870173, -167.0918561>,
    <0.9879403, -167.0825348>,
    <0.9903531, -167.0754062>,
    <0.9841508, -167.0803290>,
    <0.9911505, -167.0844033>,
    <1.0000000, -167.0684463>,
    <0.9861111, -167.0684463>,
    <0.9879403, -167.0825348>,
    <0.9947460, -167.0779200>,
    <0.9930556, -167.0684463>,
    <0.9853301, -167.0731804>,
    <0.9793947, -167.0746137>,
    <0.9841508, -167.0803290>,
    <0.9861111, -167.0684463>,
    <0.9722222, -167.0684463>,
    <0.9750946, -167.0812332>,
    <0.9853301, -167.0731804>,
    <0.9791667, -167.0684463>,
    <0.9737792, -167.0753776>,
    <0.9795255, -167.0807908>,
    <0.9740356, -167.0967305>,
    <0.9748924, -167.0922118>,
    <0.9722235, -167.0865214>,
    <0.9722248, -167.1040945>,
    <0.9768018, -167.1040945>,
    <0.9736150, -167.0894883>,
    <0.9722243, -167.0971569>,
    <0.9746053, -167.1040945>,
    <0.9760710, -167.0995468>,
    <0.9767547, -167.0954085>,
    <0.9748924, -167.0922118>,
    <0.9768018, -167.1040945>,
    <0.9802300, -167.1040945>,
    <0.9750946, -167.0812332>,
    <0.9760710, -167.0995468>,
    <0.9786723, -167.1040945>,
    <0.9769943, -167.0896900>,
    <0.9750282, -167.0848382>,
    <0.9736082, -167.0821032>,
    <0.9748924, -167.0922118>,
    <0.9750946, -167.0812332>,
    <0.9722222, -167.0684463>,
    <0.9722235, -167.0865214>,
    <0.9750282, -167.0848382>,
    <0.9737792, -167.0753776>,
    <0.9722229, -167.0783496>,
    <0.9736150, -167.0894883>,
    <0.9719316, -167.0967305>,
    <0.9718936, -167.0922118>,
    <0.9713884, -167.1040945>,
    <0.9722222, -167.1040945>,
    <0.9722222, -167.0865214>,
    <0.9716078, -167.0989345>,
    <0.9716556, -167.1040945>,
    <0.9722222, -167.0971569>,
    <0.9720784, -167.0890117>,
    <0.9720635, -167.0816745>,
    <0.9718936, -167.0922118>,
    <0.9722222, -167.0865214>,
    <0.9722222, -167.0684463>,
    <0.9719160, -167.0795187>,
    <0.9720784, -167.0890117>,
    <0.9722222, -167.0783496>,
    <0.9720714, -167.0738980>,
    <0.9719086, -167.0836846>,
    <0.9716086, -167.0949799>,
    <0.9718936, -167.0922118>,
    <0.9719160, -167.0795187>,
    <0.9712363, -167.1040945>,
    <0.9713884, -167.1040945>,
    <0.9719086, -167.0836846>,
    <0.9715927, -167.0912080>,
    <0.9712912, -167.1040945>,
    <0.9716078, -167.0989345>,
    <0.2204219, -167.0684463>,
    <0.3461935, -167.0684463>,
    <0.5054013, -167.0684463>,
    <0.0108027, -167.0684463>,
    <0.0192902, -167.0684463>,
    <0.4357479, -167.0684463>,
    <0.2581020, -167.0684463>,
    <0.0150464, -167.0684463>,
    <0.1623104, -167.0684463>,
    <0.2267876, -167.0684463>,
    <0.3461935, -167.0684463>,
    <0.0192902, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.5138889, -167.0684463>,
    <0.1623104, -167.0684463>,
    <0.0235340, -167.0684463>,
    <0.2708333, -167.0684463>,
    <0.4405221, -167.0684463>,
    <0.5913709, -167.0684463>,
    <0.3461935, -167.0684463>,
    <0.5138889, -167.0684463>,
    <1.0000000, -167.0684463>,
    <0.5054013, -167.0684463>,
    <0.4405221, -167.0684463>,
    <0.7569444, -167.0684463>,
    <0.7527007, -167.0684463>,
    <0.4357479, -167.0684463>,
    <0.2266357, -167.0684463>,
    <0.3459504, -167.0684463>,
    <0.0189256, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.5138889, -167.0684463>,
    <0.1619990, -167.0684463>,
    <0.0233517, -167.0684463>,
    <0.2708333, -167.0684463>,
    <0.4404158, -167.0684463>,
    <0.5912190, -167.0684463>,
    <0.3459504, -167.0684463>,
    <0.5138889, -167.0684463>,
    <1.0000000, -167.0684463>,
    <0.5050367, -167.0684463>,
    <0.4404158, -167.0684463>,
    <0.7569444, -167.0684463>,
    <0.7525184, -167.0684463>,
    <0.4354365, -167.0684463>,
    <0.2199965, -167.0684463>,
    <0.3459504, -167.0684463>,
    <0.5050367, -167.0684463>,
    <0.0100734, -167.0684463>,
    <0.0189256, -167.0684463>,
    <0.4354365, -167.0684463>,
    <0.2575551, -167.0684463>,
    <0.0144995, -167.0684463>,
    <0.1619990, -167.0684463>,
    <0.9606066, -167.0962010>,
    <0.9653031, -167.0922118>,
    <0.9633720, -167.0844033>,
    <0.9524507, -167.1040945>,
    <0.9613008, -167.1040945>,
    <0.9640440, -167.0871207>,
    <0.9592383, -167.0918563>,
    <0.9570075, -167.1040945>,
    <0.9629475, -167.0992056>,
    <0.9674391, -167.0949799>,
    <0.9653031, -167.0922118>,
    <0.9613008, -167.1040945>,
    <0.9712364, -167.1040945>,
    <0.9719160, -167.0795187>,
    <0.9629475, -167.0992056>,
    <0.9657765, -167.1040945>,
    <0.9715928, -167.0912080>,
    <0.9686183, -167.0858486>,
    <0.9682033, -167.0811450>,
    <0.9653031, -167.0922118>,
    <0.9719160, -167.0795187>,
    <0.9722222, -167.0684463>,
    <0.9633720, -167.0844033>,
    <0.9686183, -167.0858486>,
    <0.9720715, -167.0738980>,
    <0.9669676, -167.0779204>,
    <0.9640440, -167.0871207>,
    <0.0426682, -167.0962955>,
    <0.0367084, -167.0922118>,
    <0.0393404, -167.1040945>,
    <0.0545696, -167.1040945>,
    <0.0400546, -167.0847813>,
    <0.0382273, -167.0990693>,
    <0.0460121, -167.1040945>,
    <0.0455427, -167.0920837>,
    <0.0387324, -167.0877173>,
    <0.0330796, -167.0830167>,
    <0.0367084, -167.0922118>,
    <0.0400546, -167.0847813>,
    <0.0277778, -167.0684463>,
    <0.0277778, -167.0866273>,
    <0.0387324, -167.0877173>,
    <0.0349836, -167.0780340>,
    <0.0277778, -167.0764658>,
    <0.0321354, -167.0893522>,
    <0.0329011, -167.0967570>,
    <0.0367084, -167.0922118>,
    <0.0277778, -167.0866273>,
    <0.0277778, -167.1040945>,
    <0.0393404, -167.1040945>,
    <0.0321354, -167.0893522>,
    <0.0277778, -167.1003898>,
    <0.0333797, -167.1040945>,
    <0.0382273, -167.0990693>,
    <0.0552542, -167.0967744>,
    <0.0552258, -167.0922245>,
    <0.0546849, -167.1041136>,
    <0.0555523, -167.1041136>,
    <0.0555539, -167.0866460>,
    <0.0549237, -167.0988637>,
    <0.0549238, -167.1041136>,
    <0.0555526, -167.1003143>,
    <0.0554329, -167.0887027>,
    <0.0554072, -167.0813100>,
    <0.0552258, -167.0922245>,
    <0.0555539, -167.0866460>,
    <0.0555556, -167.0684463>,
    <0.0552936, -167.0779231>,
    <0.0554329, -167.0887027>,
    <0.0555548, -167.0765241>,
    <0.0554278, -167.0730671>,
    <0.0552696, -167.0829837>,
    <0.0549434, -167.0945937>,
    <0.0552258, -167.0922245>,
    <0.0552936, -167.0779231>,
    <0.0545695, -167.1041136>,
    <0.0546849, -167.1041136>,
    <0.0552696, -167.0829837>,
    <0.0550070, -167.0882875>,
    <0.0546102, -167.1041136>,
    <0.0549237, -167.0988637>,
    <0.0489713, -167.0867807>,
    <0.0459676, -167.0803290>,
    <0.0400546, -167.0847813>,
    <0.0545696, -167.1040945>,
    <0.0552936, -167.0779180>,
    <0.0425771, -167.0828820>,
    <0.0455427, -167.0920837>,
    <0.0550071, -167.0882769>,
    <0.0506192, -167.0791265>,
    <0.0496209, -167.0737849>,
    <0.0459676, -167.0803290>,
    <0.0552936, -167.0779180>,
    <0.0555556, -167.0684463>,
    <0.0416667, -167.0684463>,
    <0.0506192, -167.0791265>,
    <0.0554278, -167.0730647>,
    <0.0486111, -167.0684463>,
    <0.0433504, -167.0730981>,
    <0.0388667, -167.0755007>,
    <0.0459676, -167.0803290>,
    <0.0416667, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.0400546, -167.0847813>,
    <0.0433504, -167.0730981>,
    <0.0347222, -167.0684463>,
    <0.0349836, -167.0780340>,
    <0.0425771, -167.0828820>,
    <0.9548792, -167.0875211>,
    <0.9563725, -167.0803290>,
    <0.9473217, -167.0812574>,
    <0.9524507, -167.1040945>,
    <0.9633720, -167.0844033>,
    <0.9517498, -167.0808032>,
    <0.9492242, -167.0897286>,
    <0.9592383, -167.0918563>,
    <0.9601624, -167.0825351>,
    <0.9625750, -167.0754062>,
    <0.9563725, -167.0803290>,
    <0.9633720, -167.0844033>,
    <0.9722222, -167.0684463>,
    <0.9583333, -167.0684463>,
    <0.9601624, -167.0825351>,
    <0.9669676, -167.0779204>,
    <0.9652778, -167.0684463>,
    <0.9575515, -167.0731842>,
    <0.9516180, -167.0746197>,
    <0.9563725, -167.0803290>,
    <0.9583333, -167.0684463>,
    <0.9444444, -167.0684463>,
    <0.9473217, -167.0812574>,
    <0.9575515, -167.0731842>,
    <0.9513889, -167.0684463>,
    <0.9460039, -167.0753898>,
    <0.9517498, -167.0808032>,
    <0.9489769, -167.0954145>,
    <0.9471132, -167.0922118>,
    <0.9490221, -167.1040945>,
    <0.9524507, -167.1040945>,
    <0.9473217, -167.0812574>,
    <0.9482931, -167.0995570>,
    <0.9508928, -167.1040945>,
    <0.9492243, -167.0897286>,
    <0.9472533, -167.0848525>,
    <0.9458309, -167.0821150>,
    <0.9471132, -167.0922118>,
    <0.9473217, -167.0812574>,
    <0.9444444, -167.0684463>,
    <0.9444444, -167.0865447>,
    <0.9472533, -167.0848525>,
    <0.9460039, -167.0753898>,
    <0.9444444, -167.0783376>,
    <0.9458356, -167.0894987>,
    <0.9462560, -167.0967364>,
    <0.9471132, -167.0922118>,
    <0.9444444, -167.0865447>,
    <0.9444444, -167.1040945>,
    <0.9490221, -167.1040945>,
    <0.9458356, -167.0894987>,
    <0.9444444, -167.0972382>,
    <0.9468253, -167.1040945>,
    <0.9482931, -167.0995570>,
    <0.9441538, -167.0967515>,
    <0.9441158, -167.0922245>,
    <0.9436105, -167.1041136>,
    <0.9444444, -167.1041136>,
    <0.9444444, -167.0865543>,
    <0.9438297, -167.0989551>,
    <0.9438776, -167.1041136>,
    <0.9444444, -167.0972536>,
    <0.9443008, -167.0890331>,
    <0.9442871, -167.0816386>,
    <0.9441158, -167.0922245>,
    <0.9444444, -167.0865543>,
    <0.9444444, -167.0684463>,
    <0.9441436, -167.0793291>,
    <0.9443008, -167.0890331>,
    <0.9444444, -167.0783429>,
    <0.9442967, -167.0737899>,
    <0.9441345, -167.0835543>,
    <0.9438321, -167.0949452>,
    <0.9441158, -167.0922245>,
    <0.9441436, -167.0793291>,
    <0.9434584, -167.1041136>,
    <0.9436105, -167.1041136>,
    <0.9441345, -167.0835543>,
    <0.9438186, -167.0910862>,
    <0.9435133, -167.1041136>,
    <0.9438297, -167.0989551>,
    <0.0460801, -167.0684463>,
    <0.0403948, -167.0684463>,
    <0.0467033, -167.0684463>,
    <0.0555556, -167.0684463>,
    <0.0416667, -167.0684463>,
    <0.0439433, -167.0684463>,
    <0.0511294, -167.0684463>,
    <0.0486111, -167.0684463>,
    <0.0411102, -167.0684463>,
    <0.0356634, -167.0684463>,
    <0.0403948, -167.0684463>,
    <0.0416667, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.0328144, -167.0684463>,
    <0.0411102, -167.0684463>,
    <0.0347222, -167.0684463>,
    <0.0302961, -167.0684463>,
    <0.0361308, -167.0684463>,
    <0.0394408, -167.0684463>,
    <0.0403948, -167.0684463>,
    <0.0328144, -167.0684463>,
    <0.0378510, -167.0684463>,
    <0.0467033, -167.0684463>,
    <0.0361308, -167.0684463>,
    <0.0353327, -167.0684463>,
    <0.0422771, -167.0684463>,
    <0.0439433, -167.0684463>,
    <0.3495720, -168.0684463>,
    <0.6698711, -168.0684463>,
    <0.1769606, -168.0684463>,
    <0.0096133, -168.0684463>,
    <0.5418430, -168.0684463>,
    <0.3960643, -168.0684463>,
    <0.1053933, -168.0684463>,
    <0.2921951, -168.0684463>,
    <0.5969591, -168.0684463>,
    <0.8029285, -168.0684463>,
    <0.6698711, -168.0684463>,
    <0.5418430, -168.0684463>,
    <1.0000000, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.5969591, -168.0684463>,
    <0.7749773, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.8765062, -168.0684463>,
    <0.7117079, -168.0684463>,
    <0.6698711, -168.0684463>,
    <1.0000000, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.1769606, -168.0684463>,
    <0.8765062, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.7419199, -168.0684463>,
    <0.3960643, -168.0684463>,
    <0.9869016, -168.0684463>,
    <0.9919122, -168.0684463>,
    <0.9893194, -168.0684463>,
    <0.9757366, -168.0684463>,
    <0.9906383, -168.0684463>,
    <0.9905019, -168.0684463>,
    <0.9832443, -168.0684463>,
    <0.9852547, -168.0684463>,
    <0.9911271, -168.0684463>,
    <0.9956376, -168.0684463>,
    <0.9919122, -168.0684463>,
    <0.9906383, -168.0684463>,
    <1.0000000, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.9911271, -168.0684463>,
    <0.9946115, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.9962311, -168.0684463>,
    <0.9953079, -168.0684463>,
    <0.9919122, -168.0684463>,
    <1.0000000, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.9893194, -168.0684463>,
    <0.9962311, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.9948062, -168.0684463>,
    <0.9905019, -168.0684463>,
    <0.0163164, -168.0684463>,
    <0.0153141, -168.0684463>,
    <0.0154703, -168.0684463>,
    <0.0181645, -168.0684463>,
    <0.0163168, -168.0684463>,
    <0.0154160, -168.0684463>,
    <0.0164872, -168.0684463>,
    <0.0173210, -168.0684463>,
    <0.0159132, -168.0684463>,
    <0.0148522, -168.0684463>,
    <0.0153141, -168.0684463>,
    <0.0163168, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0159132, -168.0684463>,
    <0.0151487, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0145536, -168.0684463>,
    <0.0146406, -168.0684463>,
    <0.0153141, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0154703, -168.0684463>,
    <0.0145536, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0147322, -168.0684463>,
    <0.0154160, -168.0684463>,
    <0.0131373, -168.0684463>,
    <0.0124637, -168.0684463>,
    <0.0123076, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0123618, -168.0684463>,
    <0.0130458, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0132243, -168.0684463>,
    <0.0129257, -168.0684463>,
    <0.0124637, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0114611, -168.0684463>,
    <0.0132243, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0126291, -168.0684463>,
    <0.0118647, -168.0684463>,
    <0.0114614, -168.0684463>,
    <0.0124637, -168.0684463>,
    <0.0114611, -168.0684463>,
    <0.0096133, -168.0684463>,
    <0.0123076, -168.0684463>,
    <0.0118647, -168.0684463>,
    <0.0104568, -168.0684463>,
    <0.0112890, -168.0684463>,
    <0.0123618, -168.0684463>,
    <0.1446165, -168.0684463>,
    <0.3411674, -168.0684463>,
    <0.2111020, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0123076, -168.0684463>,
    <0.2669550, -168.0684463>,
    <0.1022943, -168.0684463>,
    <0.0130458, -168.0684463>,
    <0.1643921, -168.0684463>,
    <0.1350122, -168.0684463>,
    <0.3411674, -168.0684463>,
    <0.0123076, -168.0684463>,
    <0.0096133, -168.0684463>,
    <0.1769606, -168.0684463>,
    <0.1643921, -168.0684463>,
    <0.0112890, -168.0684463>,
    <0.1053933, -168.0684463>,
    <0.2490709, -168.0684463>,
    <0.4323075, -168.0684463>,
    <0.3411674, -168.0684463>,
    <0.1769606, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.2111020, -168.0684463>,
    <0.2490709, -168.0684463>,
    <0.7419199, -168.0684463>,
    <0.3864334, -168.0684463>,
    <0.2669550, -168.0684463>,
    <0.0214654, -168.0684463>,
    <0.0245734, -168.0684463>,
    <0.0233307, -168.0684463>,
    <0.0181645, -168.0684463>,
    <0.0197929, -168.0684463>,
    <0.0238191, -168.0684463>,
    <0.0209074, -168.0684463>,
    <0.0190906, -168.0684463>,
    <0.0217690, -168.0684463>,
    <0.0249805, -168.0684463>,
    <0.0245734, -168.0684463>,
    <0.0197929, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0217690, -168.0684463>,
    <0.0253361, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0264207, -168.0684463>,
    <0.0258649, -168.0684463>,
    <0.0245734, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0233307, -168.0684463>,
    <0.0264207, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0255936, -168.0684463>,
    <0.0238191, -168.0684463>,
    <0.0183429, -168.0684463>,
    <0.0199437, -168.0684463>,
    <0.0197929, -168.0684463>,
    <0.0181645, -168.0684463>,
    <0.0154703, -168.0684463>,
    <0.0198600, -168.0684463>,
    <0.0190906, -168.0684463>,
    <0.0164872, -168.0684463>,
    <0.0175406, -168.0684463>,
    <0.0164924, -168.0684463>,
    <0.0199437, -168.0684463>,
    <0.0154703, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0166668, -168.0684463>,
    <0.0175406, -168.0684463>,
    <0.0147322, -168.0684463>,
    <0.0151342, -168.0684463>,
    <0.0180716, -168.0684463>,
    <0.0210453, -168.0684463>,
    <0.0199437, -168.0684463>,
    <0.0166668, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0197929, -168.0684463>,
    <0.0180716, -168.0684463>,
    <0.0191356, -168.0684463>,
    <0.0253361, -168.0684463>,
    <0.0198600, -168.0684463>,
    <0.9804344, -168.0684463>,
    <0.9826529, -168.0684463>,
    <0.9906383, -168.0684463>,
    <0.9757366, -168.0684463>,
    <0.9727098, -168.0684463>,
    <0.9872666, -168.0684463>,
    <0.9852547, -168.0684463>,
    <0.9737097, -168.0684463>,
    <0.9779188, -168.0684463>,
    <0.9781676, -168.0684463>,
    <0.9826529, -168.0684463>,
    <0.9727098, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9850856, -168.0684463>,
    <0.9779188, -168.0684463>,
    <0.9723522, -168.0684463>,
    <0.9780082, -168.0684463>,
    <0.9837295, -168.0684463>,
    <0.9895942, -168.0684463>,
    <0.9826529, -168.0684463>,
    <0.9850856, -168.0684463>,
    <1.0000000, -168.0684463>,
    <0.9906383, -168.0684463>,
    <0.9837295, -168.0684463>,
    <0.9916189, -168.0684463>,
    <0.9946115, -168.0684463>,
    <0.9872666, -168.0684463>,
    <0.9731405, -168.0684463>,
    <0.9733937, -168.0684463>,
    <0.9747238, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9742484, -168.0684463>,
    <0.9736672, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9727700, -168.0684463>,
    <0.9726370, -168.0684463>,
    <0.9733937, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9727098, -168.0684463>,
    <0.9727700, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9723522, -168.0684463>,
    <0.9729350, -168.0684463>,
    <0.9741409, -168.0684463>,
    <0.9733937, -168.0684463>,
    <0.9727098, -168.0684463>,
    <0.9757365, -168.0684463>,
    <0.9747238, -168.0684463>,
    <0.9729350, -168.0684463>,
    <0.9737097, -168.0684463>,
    <0.9753353, -168.0684463>,
    <0.9742484, -168.0684463>,
    <0.0329414, -168.0684463>,
    <0.0309823, -168.0684463>,
    <0.0308767, -168.0684463>,
    <0.0373913, -168.0684463>,
    <0.0325154, -168.0684463>,
    <0.0309100, -168.0684463>,
    <0.0338441, -168.0684463>,
    <0.0349266, -168.0684463>,
    <0.0317737, -168.0684463>,
    <0.0297633, -168.0684463>,
    <0.0309823, -168.0684463>,
    <0.0325154, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0317737, -168.0684463>,
    <0.0301381, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0292038, -168.0684463>,
    <0.0293536, -168.0684463>,
    <0.0309823, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0308767, -168.0684463>,
    <0.0292038, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0293660, -168.0684463>,
    <0.0309100, -168.0684463>,
    <0.9667546, -168.0684463>,
    <0.9690177, -168.0684463>,
    <0.9674847, -168.0684463>,
    <0.9626087, -168.0684463>,
    <0.9679074, -168.0684463>,
    <0.9680637, -168.0684463>,
    <0.9650735, -168.0684463>,
    <0.9652186, -168.0684463>,
    <0.9683100, -168.0684463>,
    <0.9703424, -168.0684463>,
    <0.9690177, -168.0684463>,
    <0.9679074, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9683100, -168.0684463>,
    <0.9705414, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9706977, -168.0684463>,
    <0.9702367, -168.0684463>,
    <0.9690177, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9674847, -168.0684463>,
    <0.9706977, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9698619, -168.0684463>,
    <0.9680637, -168.0684463>,
    <0.9328300, -167.0962004>,
    <0.9375258, -167.0922118>,
    <0.9355962, -167.0844009>,
    <0.9246744, -167.1040945>,
    <0.9335235, -167.1040945>,
    <0.9362672, -167.0871170>,
    <0.9314630, -167.0918537>,
    <0.9292306, -167.1040945>,
    <0.9351697, -167.0992069>,
    <0.9396628, -167.0949310>,
    <0.9375258, -167.0922118>,
    <0.9335235, -167.1040945>,
    <0.9434585, -167.1040945>,
    <0.9441436, -167.0793233>,
    <0.9351697, -167.0992069>,
    <0.9379989, -167.1040945>,
    <0.9438186, -167.0910741>,
    <0.9408434, -167.0857506>,
    <0.9404275, -167.0810956>,
    <0.9375258, -167.0922118>,
    <0.9441436, -167.0793233>,
    <0.9444444, -167.0684463>,
    <0.9355962, -167.0844009>,
    <0.9408434, -167.0857506>,
    <0.9442967, -167.0737870>,
    <0.9391913, -167.0779184>,
    <0.9362672, -167.0871170>,
    <0.0393853, -168.0684463>,
    <0.0370370, -168.0684463>,
    <0.0333632, -168.0684463>,
    <0.0459421, -168.0684463>,
    <0.0411987, -168.0684463>,
    <0.0340823, -168.0684463>,
    <0.0374641, -168.0684463>,
    <0.0433704, -168.0684463>,
    <0.0393358, -168.0684463>,
    <0.0366259, -168.0684463>,
    <0.0370370, -168.0684463>,
    <0.0411987, -168.0684463>,
    <0.0373913, -168.0684463>,
    <0.0308767, -168.0684463>,
    <0.0393358, -168.0684463>,
    <0.0392322, -168.0684463>,
    <0.0338441, -168.0684463>,
    <0.0339048, -168.0684463>,
    <0.0322637, -168.0684463>,
    <0.0370370, -168.0684463>,
    <0.0308767, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0333632, -168.0684463>,
    <0.0339048, -168.0684463>,
    <0.0293660, -168.0684463>,
    <0.0309715, -168.0684463>,
    <0.0340823, -168.0684463>,
    <0.9630094, -168.0684463>,
    <0.9629629, -168.0684463>,
    <0.9679074, -168.0684463>,
    <0.9626087, -168.0684463>,
    <0.9585587, -168.0684463>,
    <0.9653863, -168.0684463>,
    <0.9652186, -168.0684463>,
    <0.9606250, -168.0684463>,
    <0.9602443, -168.0684463>,
    <0.9608051, -168.0684463>,
    <0.9629629, -168.0684463>,
    <0.9585587, -168.0684463>,
    <0.9540579, -168.0684463>,
    <0.9676410, -168.0684463>,
    <0.9602443, -168.0684463>,
    <0.9563832, -168.0684463>,
    <0.9627408, -168.0684463>,
    <0.9660614, -168.0684463>,
    <0.9676834, -168.0684463>,
    <0.9629629, -168.0684463>,
    <0.9676410, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9679074, -168.0684463>,
    <0.9660614, -168.0684463>,
    <0.9704809, -168.0684463>,
    <0.9705414, -168.0684463>,
    <0.9653863, -168.0684463>,
    <0.0704471, -167.0962968>,
    <0.0644862, -167.0922118>,
    <0.0671182, -167.1040945>,
    <0.0823476, -167.1040945>,
    <0.0678363, -167.0847864>,
    <0.0660049, -167.0990684>,
    <0.0737900, -167.1040945>,
    <0.0733250, -167.0920894>,
    <0.0665118, -167.0877221>,
    <0.0608584, -167.0830202>,
    <0.0644862, -167.0922118>,
    <0.0678363, -167.0847864>,
    <0.0555556, -167.0684463>,
    <0.0555556, -167.0866363>,
    <0.0665118, -167.0877221>,
    <0.0627643, -167.0780379>,
    <0.0555556, -167.0765198>,
    <0.0599131, -167.0893567>,
    <0.0606789, -167.0967593>,
    <0.0644862, -167.0922118>,
    <0.0555556, -167.0866363>,
    <0.0555556, -167.1040945>,
    <0.0671182, -167.1040945>,
    <0.0599131, -167.0893567>,
    <0.0555556, -167.1002972>,
    <0.0611575, -167.1040945>,
    <0.0660049, -167.0990684>,
    <0.0830325, -167.0967610>,
    <0.0830040, -167.0922118>,
    <0.0824630, -167.1040945>,
    <0.0833310, -167.1040945>,
    <0.0833321, -167.0866432>,
    <0.0827022, -167.0988413>,
    <0.0827021, -167.1040945>,
    <0.0833312, -167.1002363>,
    <0.0832111, -167.0886966>,
    <0.0831834, -167.0813688>,
    <0.0830040, -167.0922118>,
    <0.0833321, -167.0866432>,
    <0.0833333, -167.0684463>,
    <0.0830643, -167.0781738>,
    <0.0832111, -167.0886966>,
    <0.0833328, -167.0765513>,
    <0.0832019, -167.0731995>,
    <0.0830430, -167.0831435>,
    <0.0827197, -167.0946436>,
    <0.0830040, -167.0922118>,
    <0.0830643, -167.0781738>,
    <0.0823476, -167.1040945>,
    <0.0824630, -167.1040945>,
    <0.0830430, -167.0831435>,
    <0.0827787, -167.0885050>,
    <0.0823884, -167.1040945>,
    <0.0827022, -167.0988413>,
    <0.0767484, -167.0868459>,
    <0.0737455, -167.0803290>,
    <0.0678363, -167.0847864>,
    <0.0823476, -167.1040945>,
    <0.0830643, -167.0781738>,
    <0.0703567, -167.0828852>,
    <0.0733250, -167.0920894>,
    <0.0827787, -167.0885050>,
    <0.0783938, -167.0792540>,
    <0.0773969, -167.0738489>,
    <0.0737455, -167.0803290>,
    <0.0830643, -167.0781738>,
    <0.0833333, -167.0684463>,
    <0.0694444, -167.0684463>,
    <0.0783938, -167.0792540>,
    <0.0832019, -167.0731995>,
    <0.0763889, -167.0684463>,
    <0.0711291, -167.0731005>,
    <0.0666454, -167.0755020>,
    <0.0737455, -167.0803290>,
    <0.0694444, -167.0684463>,
    <0.0555556, -167.0684463>,
    <0.0678363, -167.0847864>,
    <0.0711291, -167.0731005>,
    <0.0625000, -167.0684463>,
    <0.0627643, -167.0780379>,
    <0.0703567, -167.0828852>,
    <0.9271016, -167.0875160>,
    <0.9285952, -167.0803290>,
    <0.9195405, -167.0812396>,
    <0.9246744, -167.1040945>,
    <0.9355962, -167.0844009>,
    <0.9239706, -167.0807941>,
    <0.9214421, -167.0897052>,
    <0.9314630, -167.0918537>,
    <0.9323857, -167.0825336>,
    <0.9347978, -167.0754056>,
    <0.9285952, -167.0803290>,
    <0.9355962, -167.0844009>,
    <0.9444444, -167.0684463>,
    <0.9305556, -167.0684463>,
    <0.9323857, -167.0825336>,
    <0.9391913, -167.0779184>,
    <0.9375000, -167.0684463>,
    <0.9297744, -167.0731815>,
    <0.9238395, -167.0746153>,
    <0.9285952, -167.0803290>,
    <0.9305556, -167.0684463>,
    <0.9166667, -167.0684463>,
    <0.9195405, -167.0812396>,
    <0.9297744, -167.0731815>,
    <0.9236111, -167.0684463>,
    <0.9182241, -167.0753796>,
    <0.9239706, -167.0807941>,
    <0.9184799, -167.0967357>,
    <0.9193367, -167.0922118>,
    <0.9166679, -167.0865421>,
    <0.9166690, -167.1040945>,
    <0.9212459, -167.1040945>,
    <0.9180591, -167.0894976>,
    <0.9166686, -167.0972383>,
    <0.9190494, -167.1040945>,
    <0.9205175, -167.0995612>,
    <0.9211994, -167.0954101>,
    <0.9193367, -167.0922118>,
    <0.9212459, -167.1040945>,
    <0.9246744, -167.1040945>,
    <0.9195405, -167.0812396>,
    <0.9205175, -167.0995612>,
    <0.9231165, -167.1040945>,
    <0.9214421, -167.0897052>,
    <0.9194736, -167.0848401>,
    <0.9180529, -167.0821099>,
    <0.9193367, -167.0922118>,
    <0.9195405, -167.0812396>,
    <0.9166667, -167.0684463>,
    <0.9166679, -167.0865421>,
    <0.9194736, -167.0848401>,
    <0.9182241, -167.0753796>,
    <0.9166673, -167.0783294>,
    <0.9180591, -167.0894976>,
    <0.9163760, -167.0967357>,
    <0.9163380, -167.0922118>,
    <0.9158328, -167.1040945>,
    <0.9166667, -167.1040945>,
    <0.9166667, -167.0865421>,
    <0.9160520, -167.0989386>,
    <0.9161000, -167.1040945>,
    <0.9166667, -167.0972383>,
    <0.9165230, -167.0890206>,
    <0.9165093, -167.0816308>,
    <0.9163380, -167.0922118>,
    <0.9166667, -167.0865421>,
    <0.9166667, -167.0684463>,
    <0.9163658, -167.0793231>,
    <0.9165230, -167.0890206>,
    <0.9166667, -167.0783294>,
    <0.9165190, -167.0737851>,
    <0.9163567, -167.0835462>,
    <0.9160543, -167.0949310>,
    <0.9163380, -167.0922118>,
    <0.9163658, -167.0793231>,
    <0.9156807, -167.1040945>,
    <0.9158328, -167.1040945>,
    <0.9163567, -167.0835462>,
    <0.9160408, -167.0910758>,
    <0.9157356, -167.1040945>,
    <0.9160520, -167.0989386>,
    <0.0516528, -168.0684463>,
    <0.0532435, -168.0684463>,
    <0.0523764, -168.0684463>,
    <0.0486194, -168.0684463>,
    <0.0523719, -168.0684463>,
    <0.0527700, -168.0684463>,
    <0.0506289, -168.0684463>,
    <0.0504841, -168.0684463>,
    <0.0527453, -168.0684463>,
    <0.0541816, -168.0684463>,
    <0.0532435, -168.0684463>,
    <0.0523719, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0527453, -168.0684463>,
    <0.0541585, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0546811, -168.0684463>,
    <0.0541827, -168.0684463>,
    <0.0532435, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0523764, -168.0684463>,
    <0.0546811, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0539971, -168.0684463>,
    <0.0527700, -168.0684463>,
    <0.0495609, -168.0684463>,
    <0.0500390, -168.0684463>,
    <0.0523718, -168.0684463>,
    <0.0486193, -168.0684463>,
    <0.0472136, -168.0684463>,
    <0.0511558, -168.0684463>,
    <0.0504840, -168.0684463>,
    <0.0479542, -168.0684463>,
    <0.0482296, -168.0684463>,
    <0.0493551, -168.0684463>,
    <0.0500390, -168.0684463>,
    <0.0472136, -168.0684463>,
    <0.0459421, -168.0684463>,
    <0.0542256, -168.0684463>,
    <0.0482296, -168.0684463>,
    <0.0465185, -168.0684463>,
    <0.0522820, -168.0684463>,
    <0.0530981, -168.0684463>,
    <0.0530480, -168.0684463>,
    <0.0500390, -168.0684463>,
    <0.0542256, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0523718, -168.0684463>,
    <0.0530981, -168.0684463>,
    <0.0551558, -168.0684463>,
    <0.0541585, -168.0684463>,
    <0.0511558, -168.0684463>,
    <0.0441557, -168.0684463>,
    <0.0430918, -168.0684463>,
    <0.0542256, -168.0684463>,
    <0.0459421, -168.0684463>,
    <0.0333632, -168.0684463>,
    <0.0480562, -168.0684463>,
    <0.0522820, -168.0684463>,
    <0.0374641, -168.0684463>,
    <0.0373522, -168.0684463>,
    <0.0374781, -168.0684463>,
    <0.0430918, -168.0684463>,
    <0.0333632, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0456798, -168.0684463>,
    <0.0373522, -168.0684463>,
    <0.0309715, -168.0684463>,
    <0.0380114, -168.0684463>,
    <0.0445620, -168.0684463>,
    <0.0496382, -168.0684463>,
    <0.0430918, -168.0684463>,
    <0.0456798, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0542256, -168.0684463>,
    <0.0445620, -168.0684463>,
    <0.0514609, -168.0684463>,
    <0.0551558, -168.0684463>,
    <0.0480562, -168.0684463>,
    <0.9483896, -168.0684463>,
    <0.9488204, -168.0684463>,
    <0.9513222, -168.0684463>,
    <0.9479588, -168.0684463>,
    <0.9454570, -168.0684463>,
    <0.9504415, -168.0684463>,
    <0.9497383, -168.0684463>,
    <0.9466155, -168.0684463>,
    <0.9472402, -168.0684463>,
    <0.9460865, -168.0684463>,
    <0.9488204, -168.0684463>,
    <0.9454570, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9456242, -168.0684463>,
    <0.9472402, -168.0684463>,
    <0.9447219, -168.0684463>,
    <0.9448302, -168.0684463>,
    <0.9466802, -168.0684463>,
    <0.9499561, -168.0684463>,
    <0.9488204, -168.0684463>,
    <0.9456242, -168.0684463>,
    <0.9540579, -168.0684463>,
    <0.9513222, -168.0684463>,
    <0.9466802, -168.0684463>,
    <0.9478683, -168.0684463>,
    <0.9527530, -168.0684463>,
    <0.9504415, -168.0684463>,
    <0.9560578, -168.0684463>,
    <0.9569082, -168.0684463>,
    <0.9676410, -168.0684463>,
    <0.9540579, -168.0684463>,
    <0.9456242, -168.0684463>,
    <0.9623336, -168.0684463>,
    <0.9627408, -168.0684463>,
    <0.9478683, -168.0684463>,
    <0.9506292, -168.0684463>,
    <0.9516158, -168.0684463>,
    <0.9569082, -168.0684463>,
    <0.9456242, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9594863, -168.0684463>,
    <0.9506292, -168.0684463>,
    <0.9448302, -168.0684463>,
    <0.9510083, -168.0684463>,
    <0.9589649, -168.0684463>,
    <0.9640644, -168.0684463>,
    <0.9569082, -168.0684463>,
    <0.9594863, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9676410, -168.0684463>,
    <0.9589649, -168.0684463>,
    <0.9670675, -168.0684463>,
    <0.9704809, -168.0684463>,
    <0.9623336, -168.0684463>,
    <0.9452133, -168.0684463>,
    <0.9456159, -168.0684463>,
    <0.9463484, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9460243, -168.0684463>,
    <0.9454177, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9449183, -168.0684463>,
    <0.9449904, -168.0684463>,
    <0.9456159, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9454570, -168.0684463>,
    <0.9449183, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9447219, -168.0684463>,
    <0.9455152, -168.0684463>,
    <0.9463450, -168.0684463>,
    <0.9456159, -168.0684463>,
    <0.9454570, -168.0684463>,
    <0.9479587, -168.0684463>,
    <0.9463484, -168.0684463>,
    <0.9455152, -168.0684463>,
    <0.9466154, -168.0684463>,
    <0.9471993, -168.0684463>,
    <0.9460243, -168.0684463>,
    <0.0738578, -167.0684463>,
    <0.0681725, -167.0684463>,
    <0.0744810, -167.0684463>,
    <0.0833333, -167.0684463>,
    <0.0694444, -167.0684463>,
    <0.0717210, -167.0684463>,
    <0.0789072, -167.0684463>,
    <0.0763889, -167.0684463>,
    <0.0688880, -167.0684463>,
    <0.0634412, -167.0684463>,
    <0.0681725, -167.0684463>,
    <0.0694444, -167.0684463>,
    <0.0555556, -167.0684463>,
    <0.0605921, -167.0684463>,
    <0.0688880, -167.0684463>,
    <0.0625000, -167.0684463>,
    <0.0580738, -167.0684463>,
    <0.0639085, -167.0684463>,
    <0.0672186, -167.0684463>,
    <0.0681725, -167.0684463>,
    <0.0605921, -167.0684463>,
    <0.0656287, -167.0684463>,
    <0.0744810, -167.0684463>,
    <0.0639085, -167.0684463>,
    <0.0631104, -167.0684463>,
    <0.0700548, -167.0684463>,
    <0.0717210, -167.0684463>,
    <0.9390413, -168.0684463>,
    <0.9412400, -168.0684463>,
    <0.9397069, -168.0684463>,
    <0.9348311, -168.0684463>,
    <0.9403870, -168.0684463>,
    <0.9402960, -168.0684463>,
    <0.9372958, -168.0684463>,
    <0.9376064, -168.0684463>,
    <0.9406944, -168.0684463>,
    <0.9426290, -168.0684463>,
    <0.9412400, -168.0684463>,
    <0.9403870, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9406944, -168.0684463>,
    <0.9429183, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9428947, -168.0684463>,
    <0.9424590, -168.0684463>,
    <0.9412400, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9397069, -168.0684463>,
    <0.9428947, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9420841, -168.0684463>,
    <0.9402960, -168.0684463>,
    <0.0646051, -168.0684463>,
    <0.0616104, -168.0684463>,
    <0.0595359, -168.0684463>,
    <0.0737200, -168.0684463>,
    <0.0635542, -168.0684463>,
    <0.0603950, -168.0684463>,
    <0.0640009, -168.0684463>,
    <0.0681026, -168.0684463>,
    <0.0628187, -168.0684463>,
    <0.0590689, -168.0684463>,
    <0.0616104, -168.0684463>,
    <0.0635542, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0628187, -168.0684463>,
    <0.0594454, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0585167, -168.0684463>,
    <0.0580643, -168.0684463>,
    <0.0616104, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0595359, -168.0684463>,
    <0.0585167, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0570165, -168.0684463>,
    <0.0603950, -168.0684463>,
    <0.9352960, -168.0684463>,
    <0.9351852, -168.0684463>,
    <0.9403870, -168.0684463>,
    <0.9348311, -168.0684463>,
    <0.9307809, -168.0684463>,
    <0.9377339, -168.0684463>,
    <0.9376064, -168.0684463>,
    <0.9328472, -168.0684463>,
    <0.9324772, -168.0684463>,
    <0.9330617, -168.0684463>,
    <0.9351852, -168.0684463>,
    <0.9307809, -168.0684463>,
    <0.9262800, -168.0684463>,
    <0.9400008, -168.0684463>,
    <0.9324772, -168.0684463>,
    <0.9286053, -168.0684463>,
    <0.9350969, -168.0684463>,
    <0.9383867, -168.0684463>,
    <0.9400043, -168.0684463>,
    <0.9351852, -168.0684463>,
    <0.9400008, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9403870, -168.0684463>,
    <0.9383867, -168.0684463>,
    <0.9427777, -168.0684463>,
    <0.9429183, -168.0684463>,
    <0.9377339, -168.0684463>,
    <0.9050528, -167.0961984>,
    <0.9097477, -167.0922118>,
    <0.9078225, -167.0843929>,
    <0.8968956, -167.1040945>,
    <0.9057454, -167.1040945>,
    <0.9084918, -167.0871114>,
    <0.9036895, -167.0918448>,
    <0.9014522, -167.1040945>,
    <0.9073913, -167.0992078>,
    <0.9118849, -167.0949310>,
    <0.9097477, -167.0922118>,
    <0.9057454, -167.1040945>,
    <0.9156807, -167.1040945>,
    <0.9163658, -167.0793231>,
    <0.9073913, -167.0992078>,
    <0.9102209, -167.1040945>,
    <0.9160408, -167.0910758>,
    <0.9130654, -167.0857507>,
    <0.9126507, -167.0810935>,
    <0.9097477, -167.0922118>,
    <0.9163658, -167.0793231>,
    <0.9166667, -167.0684463>,
    <0.9078225, -167.0843929>,
    <0.9130654, -167.0857507>,
    <0.9165190, -167.0737851>,
    <0.9114165, -167.0779126>,
    <0.9084918, -167.0871114>,
    <0.0794778, -168.0684463>,
    <0.0810213, -168.0684463>,
    <0.0801542, -168.0684463>,
    <0.0763972, -168.0684463>,
    <0.0803383, -168.0684463>,
    <0.0805296, -168.0684463>,
    <0.0784067, -168.0684463>,
    <0.0783695, -168.0684463>,
    <0.0806121, -168.0684463>,
    <0.0820066, -168.0684463>,
    <0.0810213, -168.0684463>,
    <0.0803383, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0806121, -168.0684463>,
    <0.0822184, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0823643, -168.0684463>,
    <0.0819605, -168.0684463>,
    <0.0810213, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0801542, -168.0684463>,
    <0.0823643, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0817749, -168.0684463>,
    <0.0805296, -168.0684463>,
    <0.0773116, -168.0684463>,
    <0.0778168, -168.0684463>,
    <0.0803383, -168.0684463>,
    <0.0763972, -168.0684463>,
    <0.0746941, -168.0684463>,
    <0.0789991, -168.0684463>,
    <0.0783695, -168.0684463>,
    <0.0755295, -168.0684463>,
    <0.0758257, -168.0684463>,
    <0.0768603, -168.0684463>,
    <0.0778168, -168.0684463>,
    <0.0746941, -168.0684463>,
    <0.0737200, -168.0684463>,
    <0.0812101, -168.0684463>,
    <0.0758257, -168.0684463>,
    <0.0741175, -168.0684463>,
    <0.0781687, -168.0684463>,
    <0.0802220, -168.0684463>,
    <0.0806746, -168.0684463>,
    <0.0778168, -168.0684463>,
    <0.0812101, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0803383, -168.0684463>,
    <0.0802220, -168.0684463>,
    <0.0826155, -168.0684463>,
    <0.0822184, -168.0684463>,
    <0.0789991, -168.0684463>,
    <0.0713339, -168.0684463>,
    <0.0708696, -168.0684463>,
    <0.0812101, -168.0684463>,
    <0.0737200, -168.0684463>,
    <0.0595359, -168.0684463>,
    <0.0760217, -168.0684463>,
    <0.0781687, -168.0684463>,
    <0.0640009, -168.0684463>,
    <0.0641203, -168.0684463>,
    <0.0640241, -168.0684463>,
    <0.0708696, -168.0684463>,
    <0.0595359, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0701352, -168.0684463>,
    <0.0641203, -168.0684463>,
    <0.0570165, -168.0684463>,
    <0.0617326, -168.0684463>,
    <0.0703841, -168.0684463>,
    <0.0763871, -168.0684463>,
    <0.0708696, -168.0684463>,
    <0.0701352, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0812101, -168.0684463>,
    <0.0703841, -168.0684463>,
    <0.0779680, -168.0684463>,
    <0.0826155, -168.0684463>,
    <0.0760217, -168.0684463>,
    <0.9206118, -168.0684463>,
    <0.9210425, -168.0684463>,
    <0.9235443, -168.0684463>,
    <0.9201809, -168.0684463>,
    <0.9176792, -168.0684463>,
    <0.9226637, -168.0684463>,
    <0.9219605, -168.0684463>,
    <0.9188376, -168.0684463>,
    <0.9194624, -168.0684463>,
    <0.9183087, -168.0684463>,
    <0.9210425, -168.0684463>,
    <0.9176792, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9178464, -168.0684463>,
    <0.9194624, -168.0684463>,
    <0.9169442, -168.0684463>,
    <0.9170524, -168.0684463>,
    <0.9189025, -168.0684463>,
    <0.9221783, -168.0684463>,
    <0.9210425, -168.0684463>,
    <0.9178464, -168.0684463>,
    <0.9262800, -168.0684463>,
    <0.9235443, -168.0684463>,
    <0.9189025, -168.0684463>,
    <0.9200906, -168.0684463>,
    <0.9249751, -168.0684463>,
    <0.9226637, -168.0684463>,
    <0.9283144, -168.0684463>,
    <0.9291304, -168.0684463>,
    <0.9400008, -168.0684463>,
    <0.9262800, -168.0684463>,
    <0.9178464, -168.0684463>,
    <0.9346216, -168.0684463>,
    <0.9350969, -168.0684463>,
    <0.9200906, -168.0684463>,
    <0.9228735, -168.0684463>,
    <0.9238961, -168.0684463>,
    <0.9291304, -168.0684463>,
    <0.9178464, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9319411, -168.0684463>,
    <0.9228735, -168.0684463>,
    <0.9170524, -168.0684463>,
    <0.9233633, -168.0684463>,
    <0.9313105, -168.0684463>,
    <0.9363792, -168.0684463>,
    <0.9291304, -168.0684463>,
    <0.9319411, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9400008, -168.0684463>,
    <0.9313105, -168.0684463>,
    <0.9394431, -168.0684463>,
    <0.9427777, -168.0684463>,
    <0.9346216, -168.0684463>,
    <0.9174355, -168.0684463>,
    <0.9178381, -168.0684463>,
    <0.9185707, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9182465, -168.0684463>,
    <0.9176399, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9171405, -168.0684463>,
    <0.9172127, -168.0684463>,
    <0.9178381, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9176792, -168.0684463>,
    <0.9171405, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9169442, -168.0684463>,
    <0.9177375, -168.0684463>,
    <0.9185672, -168.0684463>,
    <0.9178381, -168.0684463>,
    <0.9176792, -168.0684463>,
    <0.9201809, -168.0684463>,
    <0.9185707, -168.0684463>,
    <0.9177375, -168.0684463>,
    <0.9188376, -168.0684463>,
    <0.9194215, -168.0684463>,
    <0.9182465, -168.0684463>,
    <0.0886030, -168.0684463>,
    <0.0865378, -168.0684463>,
    <0.0868566, -168.0684463>,
    <0.0929468, -168.0684463>,
    <0.0880710, -168.0684463>,
    <0.0867408, -168.0684463>,
    <0.0897965, -168.0684463>,
    <0.0904821, -168.0684463>,
    <0.0874408, -168.0684463>,
    <0.0853189, -168.0684463>,
    <0.0865378, -168.0684463>,
    <0.0880710, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0874408, -168.0684463>,
    <0.0856937, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0848184, -168.0684463>,
    <0.0850153, -168.0684463>,
    <0.0865378, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0868566, -168.0684463>,
    <0.0848184, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0845094, -168.0684463>,
    <0.0867408, -168.0684463>,
    <0.9112635, -168.0684463>,
    <0.9134622, -168.0684463>,
    <0.9119291, -168.0684463>,
    <0.9070532, -168.0684463>,
    <0.9126094, -168.0684463>,
    <0.9125182, -168.0684463>,
    <0.9095180, -168.0684463>,
    <0.9098287, -168.0684463>,
    <0.9129167, -168.0684463>,
    <0.9148512, -168.0684463>,
    <0.9134622, -168.0684463>,
    <0.9126094, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9129167, -168.0684463>,
    <0.9151407, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9151169, -168.0684463>,
    <0.9146812, -168.0684463>,
    <0.9134622, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9119291, -168.0684463>,
    <0.9151169, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9143063, -168.0684463>,
    <0.9125182, -168.0684463>,
    <0.0982233, -167.0962948>,
    <0.0922639, -167.0922118>,
    <0.0948961, -167.1040945>,
    <0.1101252, -167.1040945>,
    <0.0956079, -167.0847783>,
    <0.0937830, -167.0990692>,
    <0.1015679, -167.1040945>,
    <0.1010964, -167.0920811>,
    <0.0942853, -167.0877183>,
    <0.0886346, -167.0830199>,
    <0.0922639, -167.0922118>,
    <0.0956079, -167.0847783>,
    <0.0833333, -167.0684463>,
    <0.0833333, -167.0866432>,
    <0.0942853, -167.0877183>,
    <0.0905374, -167.0780317>,
    <0.0833333, -167.0765513>,
    <0.0876910, -167.0893604>,
    <0.0884567, -167.0967610>,
    <0.0922639, -167.0922118>,
    <0.0833333, -167.0866432>,
    <0.0833333, -167.1040945>,
    <0.0948961, -167.1040945>,
    <0.0876910, -167.0893604>,
    <0.0833333, -167.1002363>,
    <0.0889354, -167.1040945>,
    <0.0937830, -167.0990692>,
    <0.1108116, -167.0967551>,
    <0.1107826, -167.0922118>,
    <0.1102415, -167.1040945>,
    <0.1111111, -167.1040945>,
    <0.1111111, -167.0866197>,
    <0.1104809, -167.0988365>,
    <0.1104814, -167.1040945>,
    <0.1111111, -167.1003869>,
    <0.1109901, -167.0886795>,
    <0.1109640, -167.0812822>,
    <0.1107826, -167.0922118>,
    <0.1111111, -167.0866197>,
    <0.1111111, -167.0684463>,
    <0.1108511, -167.0778511>,
    <0.1109901, -167.0886795>,
    <0.1111111, -167.0764652>,
    <0.1109847, -167.0730199>,
    <0.1108269, -167.0829300>,
    <0.1105002, -167.0945630>,
    <0.1107826, -167.0922118>,
    <0.1108511, -167.0778511>,
    <0.1101256, -167.1040945>,
    <0.1102415, -167.1040945>,
    <0.1108269, -167.0829300>,
    <0.1105614, -167.0883290>,
    <0.1101665, -167.1040945>,
    <0.1104809, -167.0988365>,
    <0.1045268, -167.0867632>,
    <0.1015232, -167.0803290>,
    <0.0956079, -167.0847783>,
    <0.1101252, -167.1040945>,
    <0.1108510, -167.0778511>,
    <0.0981306, -167.0828809>,
    <0.1010964, -167.0920811>,
    <0.1105612, -167.0883290>,
    <0.1061757, -167.0790931>,
    <0.1051769, -167.0737682>,
    <0.1015232, -167.0803290>,
    <0.1108510, -167.0778511>,
    <0.1111111, -167.0684463>,
    <0.0972222, -167.0684463>,
    <0.1061757, -167.0790931>,
    <0.1109846, -167.0730199>,
    <0.1041667, -167.0684463>,
    <0.0989061, -167.0730984>,
    <0.0944217, -167.0755000>,
    <0.1015232, -167.0803290>,
    <0.0972222, -167.0684463>,
    <0.0833333, -167.0684463>,
    <0.0956079, -167.0847783>,
    <0.0989061, -167.0730984>,
    <0.0902778, -167.0684463>,
    <0.0905374, -167.0780317>,
    <0.0981306, -167.0828809>,
    <0.8993224, -167.0875053>,
    <0.9008171, -167.0803290>,
    <0.8917545, -167.0812048>,
    <0.8968956, -167.1040945>,
    <0.9078225, -167.0843929>,
    <0.8961888, -167.0807763>,
    <0.8936563, -167.0896721>,
    <0.9036895, -167.0918448>,
    <0.9046099, -167.0825293>,
    <0.9070210, -167.0754036>,
    <0.9008171, -167.0803290>,
    <0.9078225, -167.0843929>,
    <0.9166667, -167.0684463>,
    <0.9027778, -167.0684463>,
    <0.9046099, -167.0825293>,
    <0.9114165, -167.0779126>,
    <0.9097222, -167.0684463>,
    <0.9019972, -167.0731767>,
    <0.8960596, -167.0746066>,
    <0.9008171, -167.0803290>,
    <0.9027778, -167.0684463>,
    <0.8888889, -167.0684463>,
    <0.8917545, -167.0812048>,
    <0.9019972, -167.0731767>,
    <0.8958333, -167.0684463>,
    <0.8904410, -167.0753567>,
    <0.8961888, -167.0807763>,
    <0.8934187, -167.0954014>,
    <0.8915578, -167.0922118>,
    <0.8934667, -167.1040945>,
    <0.8968957, -167.1040945>,
    <0.8917545, -167.0812048>,
    <0.8927437, -167.0995938>,
    <0.8953376, -167.1040945>,
    <0.8936563, -167.0896721>,
    <0.8916901, -167.0848121>,
    <0.8902725, -167.0821097>,
    <0.8915578, -167.0922118>,
    <0.8917545, -167.0812048>,
    <0.8888889, -167.0684463>,
    <0.8888889, -167.0865760>,
    <0.8916901, -167.0848121>,
    <0.8904410, -167.0753567>,
    <0.8888889, -167.0782794>,
    <0.8902800, -167.0895135>,
    <0.8907006, -167.0967442>,
    <0.8915578, -167.0922118>,
    <0.8888889, -167.0865760>,
    <0.8888889, -167.1040945>,
    <0.8934667, -167.1040945>,
    <0.8902800, -167.0895135>,
    <0.8888889, -167.0973708>,
    <0.8912698, -167.1040945>,
    <0.8927437, -167.0995938>,
    <0.8885982, -167.0967593>,
    <0.8885602, -167.0922245>,
    <0.8880547, -167.1041136>,
    <0.8888889, -167.1041136>,
    <0.8888889, -167.0865857>,
    <0.8882737, -167.0989628>,
    <0.8883220, -167.1041136>,
    <0.8888889, -167.0973863>,
    <0.8887454, -167.0890471>,
    <0.8887336, -167.0815705>,
    <0.8885602, -167.0922245>,
    <0.8888889, -167.0865857>,
    <0.8888889, -167.0684463>,
    <0.8885964, -167.0790254>,
    <0.8887454, -167.0890471>,
    <0.8888889, -167.0782846>,
    <0.8887458, -167.0736208>,
    <0.8885845, -167.0833398>,
    <0.8882785, -167.0948693>,
    <0.8885602, -167.0922245>,
    <0.8885964, -167.0790254>,
    <0.8879027, -167.1041136>,
    <0.8880547, -167.1041136>,
    <0.8885845, -167.0833398>,
    <0.8882687, -167.0908745>,
    <0.8879576, -167.1041136>,
    <0.8882737, -167.0989628>,
    <0.0944925, -168.0684463>,
    <0.0925926, -168.0684463>,
    <0.0871253, -168.0684463>,
    <0.1014978, -168.0684463>,
    <0.0967543, -168.0684463>,
    <0.0889568, -168.0684463>,
    <0.0917250, -168.0684463>,
    <0.0989261, -168.0684463>,
    <0.0951245, -168.0684463>,
    <0.0922876, -168.0684463>,
    <0.0925926, -168.0684463>,
    <0.0967543, -168.0684463>,
    <0.0929468, -168.0684463>,
    <0.0868566, -168.0684463>,
    <0.0951245, -168.0684463>,
    <0.0947878, -168.0684463>,
    <0.0897965, -168.0684463>,
    <0.0897719, -168.0684463>,
    <0.0874770, -168.0684463>,
    <0.0925926, -168.0684463>,
    <0.0868566, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0871253, -168.0684463>,
    <0.0897719, -168.0684463>,
    <0.0845094, -168.0684463>,
    <0.0847172, -168.0684463>,
    <0.0889568, -168.0684463>,
    <0.9075183, -168.0684463>,
    <0.9074074, -168.0684463>,
    <0.9126094, -168.0684463>,
    <0.9070532, -168.0684463>,
    <0.9030031, -168.0684463>,
    <0.9099562, -168.0684463>,
    <0.9098287, -168.0684463>,
    <0.9050694, -168.0684463>,
    <0.9046994, -168.0684463>,
    <0.9052839, -168.0684463>,
    <0.9074074, -168.0684463>,
    <0.9030031, -168.0684463>,
    <0.8985022, -168.0684463>,
    <0.9122231, -168.0684463>,
    <0.9046994, -168.0684463>,
    <0.9008276, -168.0684463>,
    <0.9073193, -168.0684463>,
    <0.9106090, -168.0684463>,
    <0.9122266, -168.0684463>,
    <0.9074074, -168.0684463>,
    <0.9122231, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9126094, -168.0684463>,
    <0.9106090, -168.0684463>,
    <0.9150000, -168.0684463>,
    <0.9151407, -168.0684463>,
    <0.9099562, -168.0684463>,
    <0.1072079, -168.0684463>,
    <0.1087991, -168.0684463>,
    <0.1079320, -168.0684463>,
    <0.1041749, -168.0684463>,
    <0.1079257, -168.0684463>,
    <0.1083255, -168.0684463>,
    <0.1061845, -168.0684463>,
    <0.1060386, -168.0684463>,
    <0.1082999, -168.0684463>,
    <0.1097367, -168.0684463>,
    <0.1087991, -168.0684463>,
    <0.1079257, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1082999, -168.0684463>,
    <0.1097838, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1102366, -168.0684463>,
    <0.1097383, -168.0684463>,
    <0.1087991, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1079320, -168.0684463>,
    <0.1102366, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1095527, -168.0684463>,
    <0.1083255, -168.0684463>,
    <0.1051161, -168.0684463>,
    <0.1055946, -168.0684463>,
    <0.1079257, -168.0684463>,
    <0.1041749, -168.0684463>,
    <0.1027692, -168.0684463>,
    <0.1067106, -168.0684463>,
    <0.1060386, -168.0684463>,
    <0.1035098, -168.0684463>,
    <0.1037852, -168.0684463>,
    <0.1049106, -168.0684463>,
    <0.1055946, -168.0684463>,
    <0.1027692, -168.0684463>,
    <0.1014978, -168.0684463>,
    <0.1097808, -168.0684463>,
    <0.1037852, -168.0684463>,
    <0.1020742, -168.0684463>,
    <0.1073356, -168.0684463>,
    <0.1085765, -168.0684463>,
    <0.1086031, -168.0684463>,
    <0.1055946, -168.0684463>,
    <0.1097808, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1079257, -168.0684463>,
    <0.1085765, -168.0684463>,
    <0.1106671, -168.0684463>,
    <0.1097837, -168.0684463>,
    <0.1067106, -168.0684463>,
    <0.0992628, -168.0684463>,
    <0.0986474, -168.0684463>,
    <0.1097808, -168.0684463>,
    <0.1014978, -168.0684463>,
    <0.0871253, -168.0684463>,
    <0.1042963, -168.0684463>,
    <0.1073356, -168.0684463>,
    <0.0917250, -168.0684463>,
    <0.0922318, -168.0684463>,
    <0.0917601, -168.0684463>,
    <0.0986474, -168.0684463>,
    <0.0871253, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0979343, -168.0684463>,
    <0.0922318, -168.0684463>,
    <0.0847172, -168.0684463>,
    <0.0896019, -168.0684463>,
    <0.0982001, -168.0684463>,
    <0.1043684, -168.0684463>,
    <0.0986474, -168.0684463>,
    <0.0979343, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1097808, -168.0684463>,
    <0.0982001, -168.0684463>,
    <0.1057030, -168.0684463>,
    <0.1106671, -168.0684463>,
    <0.1042963, -168.0684463>,
    <0.8928352, -168.0684463>,
    <0.8932648, -168.0684463>,
    <0.8957666, -168.0684463>,
    <0.8924032, -168.0684463>,
    <0.8899061, -168.0684463>,
    <0.8948867, -168.0684463>,
    <0.8941827, -168.0684463>,
    <0.8910521, -168.0684463>,
    <0.8916758, -168.0684463>,
    <0.8905325, -168.0684463>,
    <0.8932648, -168.0684463>,
    <0.8899061, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8900704, -168.0684463>,
    <0.8916758, -168.0684463>,
    <0.8891836, -168.0684463>,
    <0.8892762, -168.0684463>,
    <0.8911260, -168.0684463>,
    <0.8944010, -168.0684463>,
    <0.8932648, -168.0684463>,
    <0.8900704, -168.0684463>,
    <0.8985022, -168.0684463>,
    <0.8957666, -168.0684463>,
    <0.8911260, -168.0684463>,
    <0.8923161, -168.0684463>,
    <0.8971974, -168.0684463>,
    <0.8948867, -168.0684463>,
    <0.9005371, -168.0684463>,
    <0.9013526, -168.0684463>,
    <0.9122231, -168.0684463>,
    <0.8985022, -168.0684463>,
    <0.8900704, -168.0684463>,
    <0.9068447, -168.0684463>,
    <0.9073193, -168.0684463>,
    <0.8923161, -168.0684463>,
    <0.8950966, -168.0684463>,
    <0.8961208, -168.0684463>,
    <0.9013526, -168.0684463>,
    <0.8900704, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.9041714, -168.0684463>,
    <0.8950966, -168.0684463>,
    <0.8892762, -168.0684463>,
    <0.8956044, -168.0684463>,
    <0.9035358, -168.0684463>,
    <0.9086035, -168.0684463>,
    <0.9013526, -168.0684463>,
    <0.9041714, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9122231, -168.0684463>,
    <0.9035358, -168.0684463>,
    <0.9116690, -168.0684463>,
    <0.9150000, -168.0684463>,
    <0.9068447, -168.0684463>,
    <0.8896578, -168.0684463>,
    <0.8900603, -168.0684463>,
    <0.8907929, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8904453, -168.0684463>,
    <0.8898621, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8893106, -168.0684463>,
    <0.8894361, -168.0684463>,
    <0.8900603, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8899061, -168.0684463>,
    <0.8893106, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8891836, -168.0684463>,
    <0.8899678, -168.0684463>,
    <0.8907906, -168.0684463>,
    <0.8900603, -168.0684463>,
    <0.8899061, -168.0684463>,
    <0.8924032, -168.0684463>,
    <0.8907929, -168.0684463>,
    <0.8899678, -168.0684463>,
    <0.8910521, -168.0684463>,
    <0.8916437, -168.0684463>,
    <0.8904453, -168.0684463>,
    <0.8772744, -167.0962010>,
    <0.8819704, -167.0922118>,
    <0.8800396, -167.0844032>,
    <0.8691193, -167.1040945>,
    <0.8779682, -167.1040945>,
    <0.8807103, -167.0871155>,
    <0.8759064, -167.0918560>,
    <0.8736753, -167.1040945>,
    <0.8796140, -167.0992080>,
    <0.8841095, -167.0948551>,
    <0.8819704, -167.0922118>,
    <0.8779682, -167.1040945>,
    <0.8879030, -167.1040945>,
    <0.8885965, -167.0790198>,
    <0.8796140, -167.0992080>,
    <0.8824434, -167.1040945>,
    <0.8882689, -167.0908625>,
    <0.8852923, -167.0855981>,
    <0.8848738, -167.0810202>,
    <0.8819704, -167.0922118>,
    <0.8885965, -167.0790198>,
    <0.8888889, -167.0684463>,
    <0.8800396, -167.0844032>,
    <0.8852923, -167.0855981>,
    <0.8887459, -167.0736180>,
    <0.8836351, -167.0779198>,
    <0.8807103, -167.0871155>,
    <0.1260014, -167.0962954>,
    <0.1200417, -167.0922118>,
    <0.1226736, -167.1040945>,
    <0.1379029, -167.1040945>,
    <0.1233876, -167.0847809>,
    <0.1215606, -167.0990693>,
    <0.1293453, -167.1040945>,
    <0.1288758, -167.0920834>,
    <0.1220656, -167.0877170>,
    <0.1164129, -167.0830147>,
    <0.1200417, -167.0922118>,
    <0.1233876, -167.0847809>,
    <0.1111111, -167.0684463>,
    <0.1111111, -167.0866197>,
    <0.1220656, -167.0877170>,
    <0.1183167, -167.0780338>,
    <0.1111111, -167.0764652>,
    <0.1154688, -167.0893484>,
    <0.1162344, -167.0967551>,
    <0.1200417, -167.0922118>,
    <0.1111111, -167.0866197>,
    <0.1111111, -167.1040945>,
    <0.1226736, -167.1040945>,
    <0.1154688, -167.0893484>,
    <0.1111111, -167.1003869>,
    <0.1167130, -167.1040945>,
    <0.1215606, -167.0990693>,
    <0.1385861, -167.0967750>,
    <0.1385582, -167.0922245>,
    <0.1380178, -167.1041136>,
    <0.1388828, -167.1041136>,
    <0.1388858, -167.0866485>,
    <0.1382564, -167.0988637>,
    <0.1382560, -167.1041136>,
    <0.1388835, -167.1003152>,
    <0.1387650, -167.0887043>,
    <0.1387399, -167.0813105>,
    <0.1385582, -167.0922245>,
    <0.1388858, -167.0866485>,
    <0.1388889, -167.0684463>,
    <0.1386269, -167.0779227>,
    <0.1387650, -167.0887043>,
    <0.1388875, -167.0765229>,
    <0.1387611, -167.0730669>,
    <0.1386026, -167.0829834>,
    <0.1382764, -167.0945936>,
    <0.1385582, -167.0922245>,
    <0.1386269, -167.0779227>,
    <0.1379028, -167.1041136>,
    <0.1380178, -167.1041136>,
    <0.1386026, -167.0829834>,
    <0.1383404, -167.0882868>,
    <0.1379434, -167.1041136>,
    <0.1382564, -167.0988637>,
    <0.1323046, -167.0867805>,
    <0.1293010, -167.0803290>,
    <0.1233876, -167.0847809>,
    <0.1379029, -167.1040945>,
    <0.1386269, -167.0779177>,
    <0.1259103, -167.0828817>,
    <0.1288758, -167.0920834>,
    <0.1383404, -167.0882762>,
    <0.1339525, -167.0791263>,
    <0.1329542, -167.0737848>,
    <0.1293010, -167.0803290>,
    <0.1386269, -167.0779177>,
    <0.1388889, -167.0684463>,
    <0.1250000, -167.0684463>,
    <0.1339525, -167.0791263>,
    <0.1387611, -167.0730645>,
    <0.1319444, -167.0684463>,
    <0.1266837, -167.0730982>,
    <0.1221999, -167.0755006>,
    <0.1293010, -167.0803290>,
    <0.1250000, -167.0684463>,
    <0.1111111, -167.0684463>,
    <0.1233876, -167.0847809>,
    <0.1266837, -167.0730982>,
    <0.1180555, -167.0684463>,
    <0.1183167, -167.0780338>,
    <0.1259103, -167.0828817>,
    <0.8715456, -167.0875152>,
    <0.8730398, -167.0803290>,
    <0.8639838, -167.0812340>,
    <0.8691193, -167.1040945>,
    <0.8800396, -167.0844032>,
    <0.8684146, -167.0807912>,
    <0.8658835, -167.0896905>,
    <0.8759064, -167.0918560>,
    <0.8768293, -167.0825347>,
    <0.8792421, -167.0754062>,
    <0.8730398, -167.0803290>,
    <0.8800396, -167.0844032>,
    <0.8888889, -167.0684463>,
    <0.8750000, -167.0684463>,
    <0.8768293, -167.0825347>,
    <0.8836351, -167.0779198>,
    <0.8819445, -167.0684463>,
    <0.8742190, -167.0731805>,
    <0.8682837, -167.0746139>,
    <0.8730398, -167.0803290>,
    <0.8750000, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.8639838, -167.0812340>,
    <0.8742190, -167.0731805>,
    <0.8680556, -167.0684463>,
    <0.8626683, -167.0753782>,
    <0.8684146, -167.0807912>,
    <0.8629247, -167.0967309>,
    <0.8637815, -167.0922118>,
    <0.8611126, -167.0865230>,
    <0.8611141, -167.1040945>,
    <0.8656908, -167.1040945>,
    <0.8625041, -167.0894890>,
    <0.8611135, -167.0971583>,
    <0.8634944, -167.1040945>,
    <0.8649601, -167.0995467>,
    <0.8656439, -167.0954087>,
    <0.8637815, -167.0922118>,
    <0.8656908, -167.1040945>,
    <0.8691194, -167.1040945>,
    <0.8639838, -167.0812340>,
    <0.8649601, -167.0995467>,
    <0.8675614, -167.1040945>,
    <0.8658835, -167.0896905>,
    <0.8639174, -167.0848389>,
    <0.8624973, -167.0821038>,
    <0.8637815, -167.0922118>,
    <0.8639838, -167.0812340>,
    <0.8611111, -167.0684463>,
    <0.8611126, -167.0865230>,
    <0.8639174, -167.0848389>,
    <0.8626683, -167.0753782>,
    <0.8611119, -167.0783504>,
    <0.8625041, -167.0894890>,
    <0.8608206, -167.0967309>,
    <0.8607825, -167.0922118>,
    <0.8602774, -167.1040945>,
    <0.8611111, -167.1040945>,
    <0.8611111, -167.0865230>,
    <0.8604968, -167.0989346>,
    <0.8605446, -167.1040945>,
    <0.8611111, -167.0971583>,
    <0.8609673, -167.0890125>,
    <0.8609524, -167.0816751>,
    <0.8607825, -167.0922118>,
    <0.8611111, -167.0865230>,
    <0.8611111, -167.0684463>,
    <0.8608049, -167.0795193>,
    <0.8609673, -167.0890125>,
    <0.8611111, -167.0783504>,
    <0.8609603, -167.0738997>,
    <0.8607976, -167.0836850>,
    <0.8604976, -167.0949800>,
    <0.8607825, -167.0922118>,
    <0.8608049, -167.0795193>,
    <0.8601254, -167.1040945>,
    <0.8602774, -167.1040945>,
    <0.8607976, -167.0836850>,
    <0.8604817, -167.0912071>,
    <0.8601803, -167.1040945>,
    <0.8604968, -167.0989346>,
    <0.1201604, -168.0684463>,
    <0.1171659, -168.0684463>,
    <0.1150907, -168.0684463>,
    <0.1292754, -168.0684463>,
    <0.1191097, -168.0684463>,
    <0.1159501, -168.0684463>,
    <0.1195555, -168.0684463>,
    <0.1236580, -168.0684463>,
    <0.1183742, -168.0684463>,
    <0.1146244, -168.0684463>,
    <0.1171659, -168.0684463>,
    <0.1191097, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1183742, -168.0684463>,
    <0.1150009, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1140722, -168.0684463>,
    <0.1136197, -168.0684463>,
    <0.1171659, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1150907, -168.0684463>,
    <0.1140722, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1125895, -168.0684463>,
    <0.1159501, -168.0684463>,
    <0.8795746, -168.0684463>,
    <0.8828341, -168.0684463>,
    <0.8806290, -168.0684463>,
    <0.8707246, -168.0684463>,
    <0.8841105, -168.0684463>,
    <0.8814123, -168.0684463>,
    <0.8760560, -168.0684463>,
    <0.8793319, -168.0684463>,
    <0.8835898, -168.0684463>,
    <0.8861806, -168.0684463>,
    <0.8828341, -168.0684463>,
    <0.8841105, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8835898, -168.0684463>,
    <0.8870366, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8858436, -168.0684463>,
    <0.8853102, -168.0684463>,
    <0.8828341, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8806290, -168.0684463>,
    <0.8858436, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8848465, -168.0684463>,
    <0.8814123, -168.0684463>,
    <0.1350329, -168.0684463>,
    <0.1365768, -168.0684463>,
    <0.1357097, -168.0684463>,
    <0.1319526, -168.0684463>,
    <0.1358927, -168.0684463>,
    <0.1360851, -168.0684463>,
    <0.1339622, -168.0684463>,
    <0.1339242, -168.0684463>,
    <0.1361669, -168.0684463>,
    <0.1375618, -168.0684463>,
    <0.1365768, -168.0684463>,
    <0.1358927, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1361669, -168.0684463>,
    <0.1377730, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1379199, -168.0684463>,
    <0.1375161, -168.0684463>,
    <0.1365768, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1357097, -168.0684463>,
    <0.1379199, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1373305, -168.0684463>,
    <0.1360851, -168.0684463>,
    <0.1328668, -168.0684463>,
    <0.1333723, -168.0684463>,
    <0.1358927, -168.0684463>,
    <0.1319526, -168.0684463>,
    <0.1302495, -168.0684463>,
    <0.1345540, -168.0684463>,
    <0.1339242, -168.0684463>,
    <0.1310849, -168.0684463>,
    <0.1313811, -168.0684463>,
    <0.1324156, -168.0684463>,
    <0.1333723, -168.0684463>,
    <0.1302495, -168.0684463>,
    <0.1292754, -168.0684463>,
    <0.1367652, -168.0684463>,
    <0.1313811, -168.0684463>,
    <0.1296728, -168.0684463>,
    <0.1337236, -168.0684463>,
    <0.1357772, -168.0684463>,
    <0.1362297, -168.0684463>,
    <0.1333723, -168.0684463>,
    <0.1367652, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1358927, -168.0684463>,
    <0.1357772, -168.0684463>,
    <0.1381709, -168.0684463>,
    <0.1377730, -168.0684463>,
    <0.1345540, -168.0684463>,
    <0.1268891, -168.0684463>,
    <0.1264251, -168.0684463>,
    <0.1367652, -168.0684463>,
    <0.1292754, -168.0684463>,
    <0.1150907, -168.0684463>,
    <0.1315764, -168.0684463>,
    <0.1337236, -168.0684463>,
    <0.1195555, -168.0684463>,
    <0.1196745, -168.0684463>,
    <0.1195805, -168.0684463>,
    <0.1264251, -168.0684463>,
    <0.1150907, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1256949, -168.0684463>,
    <0.1196745, -168.0684463>,
    <0.1125895, -168.0684463>,
    <0.1173585, -168.0684463>,
    <0.1259424, -168.0684463>,
    <0.1319435, -168.0684463>,
    <0.1264251, -168.0684463>,
    <0.1256949, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1367652, -168.0684463>,
    <0.1259424, -168.0684463>,
    <0.1335260, -168.0684463>,
    <0.1381709, -168.0684463>,
    <0.1315764, -168.0684463>,
    <0.8651692, -168.0684463>,
    <0.8654870, -168.0684463>,
    <0.8684407, -168.0684463>,
    <0.8646254, -168.0684463>,
    <0.8621237, -168.0684463>,
    <0.8674012, -168.0684463>,
    <0.8667381, -168.0684463>,
    <0.8632821, -168.0684463>,
    <0.8639264, -168.0684463>,
    <0.8629507, -168.0684463>,
    <0.8654870, -168.0684463>,
    <0.8621237, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8630808, -168.0684463>,
    <0.8639264, -168.0684463>,
    <0.8613887, -168.0684463>,
    <0.8617738, -168.0684463>,
    <0.8638837, -168.0684463>,
    <0.8669333, -168.0684463>,
    <0.8654870, -168.0684463>,
    <0.8630808, -168.0684463>,
    <0.8707246, -168.0684463>,
    <0.8684407, -168.0684463>,
    <0.8638837, -168.0684463>,
    <0.8660418, -168.0684463>,
    <0.8697296, -168.0684463>,
    <0.8674012, -168.0684463>,
    <0.8728727, -168.0684463>,
    <0.8735749, -168.0684463>,
    <0.8841105, -168.0684463>,
    <0.8707246, -168.0684463>,
    <0.8630808, -168.0684463>,
    <0.8793981, -168.0684463>,
    <0.8793319, -168.0684463>,
    <0.8660418, -168.0684463>,
    <0.8678537, -168.0684463>,
    <0.8685398, -168.0684463>,
    <0.8735749, -168.0684463>,
    <0.8630808, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8763923, -168.0684463>,
    <0.8678537, -168.0684463>,
    <0.8617738, -168.0684463>,
    <0.8678243, -168.0684463>,
    <0.8760725, -168.0684463>,
    <0.8807416, -168.0684463>,
    <0.8735749, -168.0684463>,
    <0.8763923, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8841105, -168.0684463>,
    <0.8760725, -168.0684463>,
    <0.8838453, -168.0684463>,
    <0.8870366, -168.0684463>,
    <0.8793981, -168.0684463>,
    <0.8618800, -168.0684463>,
    <0.8622826, -168.0684463>,
    <0.8630151, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8626910, -168.0684463>,
    <0.8620844, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8615850, -168.0684463>,
    <0.8616571, -168.0684463>,
    <0.8622826, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8621237, -168.0684463>,
    <0.8615850, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8613887, -168.0684463>,
    <0.8621820, -168.0684463>,
    <0.8630117, -168.0684463>,
    <0.8622826, -168.0684463>,
    <0.8621237, -168.0684463>,
    <0.8646255, -168.0684463>,
    <0.8630151, -168.0684463>,
    <0.8621820, -168.0684463>,
    <0.8632822, -168.0684463>,
    <0.8638660, -168.0684463>,
    <0.8626910, -168.0684463>,
    <0.8557081, -168.0684463>,
    <0.8579067, -168.0684463>,
    <0.8563737, -168.0684463>,
    <0.8514979, -168.0684463>,
    <0.8570543, -168.0684463>,
    <0.8569627, -168.0684463>,
    <0.8539626, -168.0684463>,
    <0.8542735, -168.0684463>,
    <0.8573615, -168.0684463>,
    <0.8592958, -168.0684463>,
    <0.8579067, -168.0684463>,
    <0.8570543, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8573615, -168.0684463>,
    <0.8595854, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8595614, -168.0684463>,
    <0.8591256, -168.0684463>,
    <0.8579067, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8563737, -168.0684463>,
    <0.8595614, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8587508, -168.0684463>,
    <0.8569627, -168.0684463>,
    <0.1441584, -168.0684463>,
    <0.1420934, -168.0684463>,
    <0.1424113, -168.0684463>,
    <0.1485024, -168.0684463>,
    <0.1436265, -168.0684463>,
    <0.1422959, -168.0684463>,
    <0.1453515, -168.0684463>,
    <0.1460376, -168.0684463>,
    <0.1429963, -168.0684463>,
    <0.1408744, -168.0684463>,
    <0.1420934, -168.0684463>,
    <0.1436265, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1429963, -168.0684463>,
    <0.1412493, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1403740, -168.0684463>,
    <0.1405706, -168.0684463>,
    <0.1420934, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1424113, -168.0684463>,
    <0.1403740, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1400645, -168.0684463>,
    <0.1422959, -168.0684463>,
    <0.8494956, -167.0962024>,
    <0.8541925, -167.0922118>,
    <0.8522584, -167.0844090>,
    <0.8413411, -167.1040945>,
    <0.8501904, -167.1040945>,
    <0.8529315, -167.0871246>,
    <0.8481248, -167.0918625>,
    <0.8458975, -167.1040945>,
    <0.8518372, -167.0992049>,
    <0.8563282, -167.0949800>,
    <0.8541925, -167.0922118>,
    <0.8501904, -167.1040945>,
    <0.8601252, -167.1040945>,
    <0.8608049, -167.0795193>,
    <0.8518372, -167.0992049>,
    <0.8546657, -167.1040945>,
    <0.8604816, -167.0912071>,
    <0.8575074, -167.0858487>,
    <0.8570917, -167.0811466>,
    <0.8541925, -167.0922118>,
    <0.8608049, -167.0795193>,
    <0.8611111, -167.0684463>,
    <0.8522584, -167.0844090>,
    <0.8575074, -167.0858487>,
    <0.8609603, -167.0738997>,
    <0.8558547, -167.0779245>,
    <0.8529315, -167.0871246>,
    <0.1500478, -168.0684463>,
    <0.1481481, -168.0684463>,
    <0.1426803, -168.0684463>,
    <0.1570531, -168.0684463>,
    <0.1523097, -168.0684463>,
    <0.1445120, -168.0684463>,
    <0.1472798, -168.0684463>,
    <0.1544815, -168.0684463>,
    <0.1506799, -168.0684463>,
    <0.1478429, -168.0684463>,
    <0.1481481, -168.0684463>,
    <0.1523097, -168.0684463>,
    <0.1485024, -168.0684463>,
    <0.1424113, -168.0684463>,
    <0.1506799, -168.0684463>,
    <0.1503433, -168.0684463>,
    <0.1453515, -168.0684463>,
    <0.1453270, -168.0684463>,
    <0.1430322, -168.0684463>,
    <0.1481481, -168.0684463>,
    <0.1424113, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1426803, -168.0684463>,
    <0.1453270, -168.0684463>,
    <0.1400645, -168.0684463>,
    <0.1402725, -168.0684463>,
    <0.1445120, -168.0684463>,
    <0.8519629, -168.0684463>,
    <0.8518519, -168.0684463>,
    <0.8570543, -168.0684463>,
    <0.8514979, -168.0684463>,
    <0.8474476, -168.0684463>,
    <0.8544009, -168.0684463>,
    <0.8542735, -168.0684463>,
    <0.8495140, -168.0684463>,
    <0.8491440, -168.0684463>,
    <0.8497285, -168.0684463>,
    <0.8518519, -168.0684463>,
    <0.8474476, -168.0684463>,
    <0.8429467, -168.0684463>,
    <0.8566677, -168.0684463>,
    <0.8491440, -168.0684463>,
    <0.8452721, -168.0684463>,
    <0.8517640, -168.0684463>,
    <0.8550536, -168.0684463>,
    <0.8566712, -168.0684463>,
    <0.8518519, -168.0684463>,
    <0.8566677, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8570543, -168.0684463>,
    <0.8550536, -168.0684463>,
    <0.8594445, -168.0684463>,
    <0.8595854, -168.0684463>,
    <0.8544009, -168.0684463>,
    <0.1537796, -167.0962959>,
    <0.1478195, -167.0922118>,
    <0.1504515, -167.1040945>,
    <0.1656807, -167.1040945>,
    <0.1511669, -167.0847830>,
    <0.1493383, -167.0990688>,
    <0.1571232, -167.1040945>,
    <0.1566553, -167.0920857>,
    <0.1498435, -167.0877200>,
    <0.1441910, -167.0830199>,
    <0.1478195, -167.0922118>,
    <0.1511669, -167.0847830>,
    <0.1388889, -167.0684463>,
    <0.1388889, -167.0866388>,
    <0.1498435, -167.0877200>,
    <0.1460956, -167.0780353>,
    <0.1388889, -167.0765186>,
    <0.1432465, -167.0893580>,
    <0.1440122, -167.0967599>,
    <0.1478195, -167.0922118>,
    <0.1388889, -167.0866388>,
    <0.1388889, -167.1040945>,
    <0.1504515, -167.1040945>,
    <0.1432465, -167.0893580>,
    <0.1388889, -167.1002982>,
    <0.1444908, -167.1040945>,
    <0.1493383, -167.0990688>,
    <0.1663658, -167.0967588>,
    <0.1663372, -167.0922118>,
    <0.1657964, -167.1040945>,
    <0.1666642, -167.1040945>,
    <0.1666654, -167.0866345>,
    <0.1660355, -167.0988409>,
    <0.1660356, -167.1040945>,
    <0.1666644, -167.1002964>,
    <0.1665444, -167.0886903>,
    <0.1665178, -167.0813282>,
    <0.1663372, -167.0922118>,
    <0.1666654, -167.0866345>,
    <0.1666667, -167.0684463>,
    <0.1664019, -167.0780201>,
    <0.1665444, -167.0886903>,
    <0.1666661, -167.0765184>,
    <0.1665376, -167.0731151>,
    <0.1663790, -167.0830421>,
    <0.1660541, -167.0946052>,
    <0.1663372, -167.0922118>,
    <0.1664019, -167.0780201>,
    <0.1656809, -167.1040945>,
    <0.1657964, -167.1040945>,
    <0.1663790, -167.0830421>,
    <0.1661148, -167.0884035>,
    <0.1657217, -167.1040945>,
    <0.1660355, -167.0988409>,
    <0.1600820, -167.0868066>,
    <0.1570787, -167.0803290>,
    <0.1511669, -167.0847830>,
    <0.1656807, -167.1040945>,
    <0.1664019, -167.0780201>,
    <0.1536884, -167.0828833>,
    <0.1566553, -167.0920857>,
    <0.1661147, -167.0884035>,
    <0.1617290, -167.0791773>,
    <0.1607313, -167.0738104>,
    <0.1570787, -167.0803290>,
    <0.1664019, -167.0780201>,
    <0.1666667, -167.0684463>,
    <0.1527778, -167.0684463>,
    <0.1617290, -167.0791773>,
    <0.1665375, -167.0731151>,
    <0.1597222, -167.0684463>,
    <0.1544619, -167.0730993>,
    <0.1499781, -167.0755011>,
    <0.1570787, -167.0803290>,
    <0.1527778, -167.0684463>,
    <0.1388889, -167.0684463>,
    <0.1511669, -167.0847830>,
    <0.1544619, -167.0730993>,
    <0.1458333, -167.0684463>,
    <0.1460956, -167.0780353>,
    <0.1536884, -167.0828833>,
    <0.8516356, -167.0684463>,
    <0.8459503, -167.0684463>,
    <0.8522587, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.8472222, -167.0684463>,
    <0.8494988, -167.0684463>,
    <0.8566849, -167.0684463>,
    <0.8541667, -167.0684463>,
    <0.8466657, -167.0684463>,
    <0.8412189, -167.0684463>,
    <0.8459503, -167.0684463>,
    <0.8472222, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.8383698, -167.0684463>,
    <0.8466657, -167.0684463>,
    <0.8402778, -167.0684463>,
    <0.8358516, -167.0684463>,
    <0.8416863, -167.0684463>,
    <0.8449963, -167.0684463>,
    <0.8459503, -167.0684463>,
    <0.8383698, -167.0684463>,
    <0.8434063, -167.0684463>,
    <0.8522587, -167.0684463>,
    <0.8416863, -167.0684463>,
    <0.8408881, -167.0684463>,
    <0.8478325, -167.0684463>,
    <0.8494988, -167.0684463>,
    <0.8437695, -167.0875284>,
    <0.8452619, -167.0803290>,
    <0.8362165, -167.0812811>,
    <0.8413411, -167.1040945>,
    <0.8522584, -167.0844090>,
    <0.8406418, -167.0808153>,
    <0.8381191, -167.0897510>,
    <0.8481248, -167.0918625>,
    <0.8490503, -167.0825382>,
    <0.8514634, -167.0754076>,
    <0.8452619, -167.0803290>,
    <0.8522584, -167.0844090>,
    <0.8611111, -167.0684463>,
    <0.8472222, -167.0684463>,
    <0.8490503, -167.0825382>,
    <0.8558547, -167.0779245>,
    <0.8541667, -167.0684463>,
    <0.8464401, -167.0731873>,
    <0.8405085, -167.0746257>,
    <0.8452619, -167.0803290>,
    <0.8472222, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.8362165, -167.0812811>,
    <0.8464401, -167.0731873>,
    <0.8402778, -167.0684463>,
    <0.8348966, -167.0754054>,
    <0.8406418, -167.0808153>,
    <0.8351467, -167.0967307>,
    <0.8360034, -167.0922118>,
    <0.8333346, -167.0865221>,
    <0.8333358, -167.1040945>,
    <0.8379129, -167.1040945>,
    <0.8347259, -167.0894881>,
    <0.8333353, -167.0971542>,
    <0.8357164, -167.1040945>,
    <0.8371804, -167.0995360>,
    <0.8378685, -167.0954205>,
    <0.8360034, -167.0922118>,
    <0.8379129, -167.1040945>,
    <0.8413411, -167.1040945>,
    <0.8362165, -167.0812811>,
    <0.8371804, -167.0995360>,
    <0.8397834, -167.1040945>,
    <0.8381191, -167.0897510>,
    <0.8361465, -167.0848716>,
    <0.8347220, -167.0821153>,
    <0.8360034, -167.0922118>,
    <0.8362165, -167.0812811>,
    <0.8333333, -167.0684463>,
    <0.8333346, -167.0865221>,
    <0.8361465, -167.0848716>,
    <0.8348966, -167.0754054>,
    <0.8333340, -167.0783664>,
    <0.8347259, -167.0894881>,
    <0.8330427, -167.0967307>,
    <0.8330047, -167.0922118>,
    <0.8324995, -167.1040945>,
    <0.8333333, -167.1040945>,
    <0.8333333, -167.0865221>,
    <0.8327189, -167.0989345>,
    <0.8327667, -167.1040945>,
    <0.8333333, -167.0971542>,
    <0.8331895, -167.0890121>,
    <0.8331746, -167.0816748>,
    <0.8330047, -167.0922118>,
    <0.8333333, -167.0865221>,
    <0.8333333, -167.0684463>,
    <0.8330271, -167.0795191>,
    <0.8331895, -167.0890121>,
    <0.8333333, -167.0783664>,
    <0.8331825, -167.0738995>,
    <0.8330197, -167.0836848>,
    <0.8327197, -167.0949800>,
    <0.8330047, -167.0922118>,
    <0.8330271, -167.0795191>,
    <0.8323474, -167.1040945>,
    <0.8324995, -167.1040945>,
    <0.8330197, -167.0836848>,
    <0.8327038, -167.0912070>,
    <0.8324023, -167.1040945>,
    <0.8327189, -167.0989345>,
    <0.1509772, -167.0684463>,
    <0.1517489, -167.0684463>,
    <0.1442900, -167.0684463>,
    <0.1496911, -167.0684463>,
    <0.1581789, -167.0684463>,
    <0.1475532, -167.0684463>,
    <0.1469905, -167.0684463>,
    <0.1539350, -167.0684463>,
    <0.1553657, -167.0684463>,
    <0.1573430, -167.0684463>,
    <0.1517489, -167.0684463>,
    <0.1581789, -167.0684463>,
    <0.1666667, -167.0684463>,
    <0.1527778, -167.0684463>,
    <0.1553657, -167.0684463>,
    <0.1624228, -167.0684463>,
    <0.1597222, -167.0684463>,
    <0.1523276, -167.0684463>,
    <0.1469264, -167.0684463>,
    <0.1517489, -167.0684463>,
    <0.1527778, -167.0684463>,
    <0.1388889, -167.0684463>,
    <0.1442900, -167.0684463>,
    <0.1523276, -167.0684463>,
    <0.1458333, -167.0684463>,
    <0.1415894, -167.0684463>,
    <0.1475532, -167.0684463>,
    <0.1628169, -168.0684463>,
    <0.1643545, -168.0684463>,
    <0.1634874, -168.0684463>,
    <0.1597303, -168.0684463>,
    <0.1636954, -168.0684463>,
    <0.1638634, -168.0684463>,
    <0.1617399, -168.0684463>,
    <0.1617182, -168.0684463>,
    <0.1639594, -168.0684463>,
    <0.1653458, -168.0684463>,
    <0.1643545, -168.0684463>,
    <0.1636954, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1639594, -168.0684463>,
    <0.1655717, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1656991, -168.0684463>,
    <0.1652938, -168.0684463>,
    <0.1643545, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1634874, -168.0684463>,
    <0.1656991, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1651082, -168.0684463>,
    <0.1638634, -168.0684463>,
    <0.1607251, -168.0684463>,
    <0.1611500, -168.0684463>,
    <0.1636954, -168.0684463>,
    <0.1597303, -168.0684463>,
    <0.1583246, -168.0684463>,
    <0.1623596, -168.0684463>,
    <0.1617182, -168.0684463>,
    <0.1590652, -168.0684463>,
    <0.1593508, -168.0684463>,
    <0.1604795, -168.0684463>,
    <0.1611500, -168.0684463>,
    <0.1583246, -168.0684463>,
    <0.1570531, -168.0684463>,
    <0.1653905, -168.0684463>,
    <0.1593508, -168.0684463>,
    <0.1576295, -168.0684463>,
    <0.1629734, -168.0684463>,
    <0.1641825, -168.0684463>,
    <0.1642256, -168.0684463>,
    <0.1611500, -168.0684463>,
    <0.1653905, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1636954, -168.0684463>,
    <0.1641825, -168.0684463>,
    <0.1662508, -168.0684463>,
    <0.1655717, -168.0684463>,
    <0.1623596, -168.0684463>,
    <0.1548317, -168.0684463>,
    <0.1542029, -168.0684463>,
    <0.1653905, -168.0684463>,
    <0.1570531, -168.0684463>,
    <0.1426803, -168.0684463>,
    <0.1598760, -168.0684463>,
    <0.1629734, -168.0684463>,
    <0.1472798, -168.0684463>,
    <0.1478133, -168.0684463>,
    <0.1473658, -168.0684463>,
    <0.1542029, -168.0684463>,
    <0.1426803, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1536910, -168.0684463>,
    <0.1478133, -168.0684463>,
    <0.1402725, -168.0684463>,
    <0.1452695, -168.0684463>,
    <0.1538809, -168.0684463>,
    <0.1599878, -168.0684463>,
    <0.1542029, -168.0684463>,
    <0.1536910, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1653905, -168.0684463>,
    <0.1538809, -168.0684463>,
    <0.1614350, -168.0684463>,
    <0.1662508, -168.0684463>,
    <0.1598760, -168.0684463>,
    <0.8372682, -168.0684463>,
    <0.8377092, -168.0684463>,
    <0.8402111, -168.0684463>,
    <0.8368476, -168.0684463>,
    <0.8343049, -168.0684463>,
    <0.8393245, -168.0684463>,
    <0.8386272, -168.0684463>,
    <0.8354679, -168.0684463>,
    <0.8361097, -168.0684463>,
    <0.8349597, -168.0684463>,
    <0.8377092, -168.0684463>,
    <0.8343049, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8344911, -168.0684463>,
    <0.8361097, -168.0684463>,
    <0.8335939, -168.0684463>,
    <0.8337070, -168.0684463>,
    <0.8355514, -168.0684463>,
    <0.8388395, -168.0684463>,
    <0.8377092, -168.0684463>,
    <0.8344911, -168.0684463>,
    <0.8429467, -168.0684463>,
    <0.8402111, -168.0684463>,
    <0.8355514, -168.0684463>,
    <0.8367217, -168.0684463>,
    <0.8416419, -168.0684463>,
    <0.8393245, -168.0684463>,
    <0.8449756, -168.0684463>,
    <0.8457971, -168.0684463>,
    <0.8566677, -168.0684463>,
    <0.8429467, -168.0684463>,
    <0.8344911, -168.0684463>,
    <0.8512789, -168.0684463>,
    <0.8517640, -168.0684463>,
    <0.8367217, -168.0684463>,
    <0.8395315, -168.0684463>,
    <0.8405285, -168.0684463>,
    <0.8457971, -168.0684463>,
    <0.8344911, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8484925, -168.0684463>,
    <0.8395315, -168.0684463>,
    <0.8337070, -168.0684463>,
    <0.8398940, -168.0684463>,
    <0.8479011, -168.0684463>,
    <0.8530171, -168.0684463>,
    <0.8457971, -168.0684463>,
    <0.8484925, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8566677, -168.0684463>,
    <0.8479011, -168.0684463>,
    <0.8560535, -168.0684463>,
    <0.8594445, -168.0684463>,
    <0.8512789, -168.0684463>,
    <0.8341022, -168.0684463>,
    <0.8345048, -168.0684463>,
    <0.8352374, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8349106, -168.0684463>,
    <0.8343066, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8338037, -168.0684463>,
    <0.8338691, -168.0684463>,
    <0.8345048, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8343049, -168.0684463>,
    <0.8338037, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8335939, -168.0684463>,
    <0.8343779, -168.0684463>,
    <0.8352237, -168.0684463>,
    <0.8345048, -168.0684463>,
    <0.8343049, -168.0684463>,
    <0.8368476, -168.0684463>,
    <0.8352374, -168.0684463>,
    <0.8343779, -168.0684463>,
    <0.8354679, -168.0684463>,
    <0.8360882, -168.0684463>,
    <0.8349106, -168.0684463>,
    <0.1719521, -168.0684463>,
    <0.1698711, -168.0684463>,
    <0.1701022, -168.0684463>,
    <0.1762801, -168.0684463>,
    <0.1715549, -168.0684463>,
    <0.1700199, -168.0684463>,
    <0.1730770, -168.0684463>,
    <0.1739469, -168.0684463>,
    <0.1708776, -168.0684463>,
    <0.1686898, -168.0684463>,
    <0.1698711, -168.0684463>,
    <0.1715549, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1708776, -168.0684463>,
    <0.1691213, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1681665, -168.0684463>,
    <0.1683267, -168.0684463>,
    <0.1698711, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1701022, -168.0684463>,
    <0.1681665, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1678021, -168.0684463>,
    <0.1700199, -168.0684463>,
    <0.8278979, -168.0684463>,
    <0.8301289, -168.0684463>,
    <0.8280472, -168.0684463>,
    <0.8237199, -168.0684463>,
    <0.8296956, -168.0684463>,
    <0.8287634, -168.0684463>,
    <0.8257397, -168.0684463>,
    <0.8267394, -168.0684463>,
    <0.8298432, -168.0684463>,
    <0.8316228, -168.0684463>,
    <0.8301289, -168.0684463>,
    <0.8296956, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8298432, -168.0684463>,
    <0.8320465, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8317244, -168.0684463>,
    <0.8312107, -168.0684463>,
    <0.8301289, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8280472, -168.0684463>,
    <0.8317244, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8306191, -168.0684463>,
    <0.8287634, -168.0684463>,
    <0.8217169, -167.0962026>,
    <0.8264142, -167.0922118>,
    <0.8244797, -167.0844095>,
    <0.8135618, -167.1040945>,
    <0.8224118, -167.1040945>,
    <0.8251530, -167.0871249>,
    <0.8203457, -167.0918630>,
    <0.8181185, -167.1040945>,
    <0.8240588, -167.0992049>,
    <0.8285502, -167.0949800>,
    <0.8264142, -167.0922118>,
    <0.8224118, -167.1040945>,
    <0.8323476, -167.1040945>,
    <0.8330271, -167.0795191>,
    <0.8240588, -167.0992049>,
    <0.8268876, -167.1040945>,
    <0.8327039, -167.0912070>,
    <0.8297295, -167.0858485>,
    <0.8293136, -167.0811467>,
    <0.8264142, -167.0922118>,
    <0.8330271, -167.0795191>,
    <0.8333333, -167.0684463>,
    <0.8244797, -167.0844095>,
    <0.8297295, -167.0858485>,
    <0.8331825, -167.0738995>,
    <0.8280763, -167.0779248>,
    <0.8251530, -167.0871249>,
    <0.1793700, -168.0684463>,
    <0.1767336, -168.0684463>,
    <0.1718865, -168.0684463>,
    <0.1872539, -168.0684463>,
    <0.1816062, -168.0684463>,
    <0.1736155, -168.0684463>,
    <0.1774780, -168.0684463>,
    <0.1843413, -168.0684463>,
    <0.1796932, -168.0684463>,
    <0.1761805, -168.0684463>,
    <0.1767336, -168.0684463>,
    <0.1816062, -168.0684463>,
    <0.1762801, -168.0684463>,
    <0.1701022, -168.0684463>,
    <0.1796932, -168.0684463>,
    <0.1789450, -168.0684463>,
    <0.1730770, -168.0684463>,
    <0.1734746, -168.0684463>,
    <0.1713472, -168.0684463>,
    <0.1767336, -168.0684463>,
    <0.1701022, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1718865, -168.0684463>,
    <0.1734746, -168.0684463>,
    <0.1678021, -168.0684463>,
    <0.1686265, -168.0684463>,
    <0.1736155, -168.0684463>,
    <0.1815574, -167.0962959>,
    <0.1755973, -167.0922118>,
    <0.1782292, -167.1040945>,
    <0.1934585, -167.1040945>,
    <0.1789445, -167.0847827>,
    <0.1771161, -167.0990688>,
    <0.1849010, -167.1040945>,
    <0.1844330, -167.0920855>,
    <0.1776212, -167.0877198>,
    <0.1719688, -167.0830188>,
    <0.1755973, -167.0922118>,
    <0.1789445, -167.0847827>,
    <0.1666667, -167.0684463>,
    <0.1666667, -167.0866345>,
    <0.1776212, -167.0877198>,
    <0.1738733, -167.0780351>,
    <0.1666667, -167.0765184>,
    <0.1710243, -167.0893559>,
    <0.1717900, -167.0967588>,
    <0.1755973, -167.0922118>,
    <0.1666667, -167.0866345>,
    <0.1666667, -167.1040945>,
    <0.1782292, -167.1040945>,
    <0.1710243, -167.0893559>,
    <0.1666667, -167.1002964>,
    <0.1722686, -167.1040945>,
    <0.1771161, -167.0990688>,
    <0.1941430, -167.0967744>,
    <0.1941146, -167.0922245>,
    <0.1935737, -167.1041136>,
    <0.1944410, -167.1041136>,
    <0.1944427, -167.0866461>,
    <0.1938128, -167.0988572>,
    <0.1938127, -167.1041136>,
    <0.1944414, -167.1003146>,
    <0.1943218, -167.0887023>,
    <0.1942953, -167.0813354>,
    <0.1941146, -167.0922245>,
    <0.1944427, -167.0866461>,
    <0.1944444, -167.0684463>,
    <0.1941796, -167.0780248>,
    <0.1943218, -167.0887023>,
    <0.1944437, -167.0765203>,
    <0.1943153, -167.0731174>,
    <0.1941566, -167.0830496>,
    <0.1938316, -167.0946191>,
    <0.1941146, -167.0922245>,
    <0.1941796, -167.0780248>,
    <0.1934583, -167.1041136>,
    <0.1935737, -167.1041136>,
    <0.1941566, -167.0830496>,
    <0.1938924, -167.0884136>,
    <0.1934991, -167.1041136>,
    <0.1938128, -167.0988572>,
    <0.1878598, -167.0868065>,
    <0.1848565, -167.0803290>,
    <0.1789445, -167.0847827>,
    <0.1934585, -167.1040945>,
    <0.1941797, -167.0780197>,
    <0.1814661, -167.0828831>,
    <0.1844330, -167.0920855>,
    <0.1938925, -167.0884029>,
    <0.1895068, -167.0791772>,
    <0.1885090, -167.0738103>,
    <0.1848565, -167.0803290>,
    <0.1941797, -167.0780197>,
    <0.1944444, -167.0684463>,
    <0.1805555, -167.0684463>,
    <0.1895068, -167.0791772>,
    <0.1943153, -167.0731149>,
    <0.1875000, -167.0684463>,
    <0.1822397, -167.0730993>,
    <0.1777558, -167.0755011>,
    <0.1848565, -167.0803290>,
    <0.1805555, -167.0684463>,
    <0.1666667, -167.0684463>,
    <0.1789445, -167.0847827>,
    <0.1822397, -167.0730993>,
    <0.1736111, -167.0684463>,
    <0.1738733, -167.0780351>,
    <0.1814661, -167.0828831>,
    <0.8238578, -167.0684463>,
    <0.8181725, -167.0684463>,
    <0.8244810, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.8194445, -167.0684463>,
    <0.8217211, -167.0684463>,
    <0.8289072, -167.0684463>,
    <0.8263889, -167.0684463>,
    <0.8188880, -167.0684463>,
    <0.8134412, -167.0684463>,
    <0.8181725, -167.0684463>,
    <0.8194445, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.8105921, -167.0684463>,
    <0.8188880, -167.0684463>,
    <0.8125000, -167.0684463>,
    <0.8080738, -167.0684463>,
    <0.8139086, -167.0684463>,
    <0.8172186, -167.0684463>,
    <0.8181725, -167.0684463>,
    <0.8105921, -167.0684463>,
    <0.8156287, -167.0684463>,
    <0.8244810, -167.0684463>,
    <0.8139086, -167.0684463>,
    <0.8131104, -167.0684463>,
    <0.8200549, -167.0684463>,
    <0.8217211, -167.0684463>,
    <0.8159908, -167.0875285>,
    <0.8174836, -167.0803290>,
    <0.8084381, -167.0812810>,
    <0.8135618, -167.1040945>,
    <0.8244797, -167.0844095>,
    <0.8128634, -167.0808153>,
    <0.8103404, -167.0897510>,
    <0.8203457, -167.0918630>,
    <0.8212718, -167.0825385>,
    <0.8236853, -167.0754078>,
    <0.8174836, -167.0803290>,
    <0.8244797, -167.0844095>,
    <0.8333333, -167.0684463>,
    <0.8194445, -167.0684463>,
    <0.8212718, -167.0825385>,
    <0.8280763, -167.0779248>,
    <0.8263889, -167.0684463>,
    <0.8186621, -167.0731874>,
    <0.8127304, -167.0746257>,
    <0.8174836, -167.0803290>,
    <0.8194445, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.8084381, -167.0812810>,
    <0.8186621, -167.0731874>,
    <0.8125000, -167.0684463>,
    <0.8071185, -167.0754053>,
    <0.8128634, -167.0808153>,
    <0.8100893, -167.0954204>,
    <0.8082243, -167.0922118>,
    <0.8101330, -167.1040945>,
    <0.8135618, -167.1040945>,
    <0.8084381, -167.0812810>,
    <0.8094008, -167.0995361>,
    <0.8120038, -167.1040945>,
    <0.8103404, -167.0897510>,
    <0.8083679, -167.0848718>,
    <0.8069434, -167.0821173>,
    <0.8082243, -167.0922118>,
    <0.8084381, -167.0812810>,
    <0.8055556, -167.0684463>,
    <0.8055556, -167.0865302>,
    <0.8083679, -167.0848718>,
    <0.8071185, -167.0754053>,
    <0.8055556, -167.0783709>,
    <0.8069468, -167.0894921>,
    <0.8073671, -167.0967327>,
    <0.8082243, -167.0922118>,
    <0.8055556, -167.0865302>,
    <0.8055556, -167.1040945>,
    <0.8101330, -167.1040945>,
    <0.8069468, -167.0894921>,
    <0.8055556, -167.0971597>,
    <0.8079363, -167.1040945>,
    <0.8094008, -167.0995361>,
    <0.8052618, -167.0967479>,
    <0.8052249, -167.0922245>,
    <0.8047205, -167.1041136>,
    <0.8055495, -167.1041136>,
    <0.8055525, -167.0865398>,
    <0.8049395, -167.0989513>,
    <0.8049859, -167.1041136>,
    <0.8055507, -167.0971751>,
    <0.8054091, -167.0890276>,
    <0.8053956, -167.0816838>,
    <0.8052249, -167.0922245>,
    <0.8055525, -167.0865398>,
    <0.8055556, -167.0684463>,
    <0.8052493, -167.0795248>,
    <0.8054091, -167.0890276>,
    <0.8055539, -167.0783763>,
    <0.8054049, -167.0738958>,
    <0.8052413, -167.0836923>,
    <0.8049411, -167.0949941>,
    <0.8052249, -167.0922245>,
    <0.8052493, -167.0795248>,
    <0.8045696, -167.1041136>,
    <0.8047205, -167.1041136>,
    <0.8052413, -167.0836923>,
    <0.8049259, -167.0912253>,
    <0.8046240, -167.1041136>,
    <0.8049395, -167.0989513>,
    <0.1787549, -167.0684463>,
    <0.1795266, -167.0684463>,
    <0.1720677, -167.0684463>,
    <0.1774688, -167.0684463>,
    <0.1859566, -167.0684463>,
    <0.1753310, -167.0684463>,
    <0.1747682, -167.0684463>,
    <0.1817127, -167.0684463>,
    <0.1831435, -167.0684463>,
    <0.1851208, -167.0684463>,
    <0.1795266, -167.0684463>,
    <0.1859566, -167.0684463>,
    <0.1944444, -167.0684463>,
    <0.1805555, -167.0684463>,
    <0.1831435, -167.0684463>,
    <0.1902005, -167.0684463>,
    <0.1875000, -167.0684463>,
    <0.1801054, -167.0684463>,
    <0.1747041, -167.0684463>,
    <0.1795266, -167.0684463>,
    <0.1805555, -167.0684463>,
    <0.1666667, -167.0684463>,
    <0.1720677, -167.0684463>,
    <0.1801054, -167.0684463>,
    <0.1736111, -167.0684463>,
    <0.1693672, -167.0684463>,
    <0.1753310, -167.0684463>,
    <0.8220890, -168.0684463>,
    <0.8208696, -168.0684463>,
    <0.8296956, -168.0684463>,
    <0.8237199, -168.0684463>,
    <0.8140711, -168.0684463>,
    <0.8252050, -168.0684463>,
    <0.8267394, -168.0684463>,
    <0.8186506, -168.0684463>,
    <0.8167264, -168.0684463>,
    <0.8160476, -168.0684463>,
    <0.8208696, -168.0684463>,
    <0.8140711, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8236942, -168.0684463>,
    <0.8167264, -168.0684463>,
    <0.8097499, -168.0684463>,
    <0.8159327, -168.0684463>,
    <0.8225676, -168.0684463>,
    <0.8268982, -168.0684463>,
    <0.8208696, -168.0684463>,
    <0.8236942, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8296956, -168.0684463>,
    <0.8225676, -168.0684463>,
    <0.8294174, -168.0684463>,
    <0.8320465, -168.0684463>,
    <0.8252050, -168.0684463>,
    <0.1908931, -168.0684463>,
    <0.1920476, -168.0684463>,
    <0.1906297, -168.0684463>,
    <0.1872539, -168.0684463>,
    <0.1936413, -168.0684463>,
    <0.1911049, -168.0684463>,
    <0.1888700, -168.0684463>,
    <0.1918438, -168.0684463>,
    <0.1930581, -168.0684463>,
    <0.1936444, -168.0684463>,
    <0.1920476, -168.0684463>,
    <0.1936413, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1930581, -168.0684463>,
    <0.1941869, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1933273, -168.0684463>,
    <0.1928915, -168.0684463>,
    <0.1920476, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1906297, -168.0684463>,
    <0.1933273, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1925065, -168.0684463>,
    <0.1911049, -168.0684463>,
    <0.1838925, -168.0684463>,
    <0.1827883, -168.0684463>,
    <0.1936414, -168.0684463>,
    <0.1872539, -168.0684463>,
    <0.1718865, -168.0684463>,
    <0.1885650, -168.0684463>,
    <0.1918438, -168.0684463>,
    <0.1774780, -168.0684463>,
    <0.1767328, -168.0684463>,
    <0.1756465, -168.0684463>,
    <0.1827883, -168.0684463>,
    <0.1718865, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1812444, -168.0684463>,
    <0.1767328, -168.0684463>,
    <0.1686265, -168.0684463>,
    <0.1729001, -168.0684463>,
    <0.1818765, -168.0684463>,
    <0.1880296, -168.0684463>,
    <0.1827883, -168.0684463>,
    <0.1812444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1936414, -168.0684463>,
    <0.1818765, -168.0684463>,
    <0.1890479, -168.0684463>,
    <0.1941869, -168.0684463>,
    <0.1885650, -168.0684463>,
    <0.8124050, -168.0684463>,
    <0.8148148, -168.0684463>,
    <0.8236942, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8193937, -168.0684463>,
    <0.8159327, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8095606, -168.0684463>,
    <0.8118151, -168.0684463>,
    <0.8148148, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8213346, -168.0684463>,
    <0.8095606, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8125853, -168.0684463>,
    <0.8169609, -168.0684463>,
    <0.8232943, -168.0684463>,
    <0.8148148, -168.0684463>,
    <0.8213346, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8236942, -168.0684463>,
    <0.8169609, -168.0684463>,
    <0.8286385, -168.0684463>,
    <0.8294174, -168.0684463>,
    <0.8193937, -168.0684463>,
    <0.8000073, -168.0684463>,
    <0.8023511, -168.0684463>,
    <0.8008181, -168.0684463>,
    <0.7959423, -168.0684463>,
    <0.8009175, -168.0684463>,
    <0.8014936, -168.0684463>,
    <0.7984070, -168.0684463>,
    <0.7983886, -168.0684463>,
    <0.8015098, -168.0684463>,
    <0.8035950, -168.0684463>,
    <0.8023511, -168.0684463>,
    <0.8009175, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8015098, -168.0684463>,
    <0.8032685, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8042914, -168.0684463>,
    <0.8035701, -168.0684463>,
    <0.8023511, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8008181, -168.0684463>,
    <0.8042914, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8031953, -168.0684463>,
    <0.8014936, -168.0684463>,
    <0.1997278, -168.0684463>,
    <0.1976489, -168.0684463>,
    <0.1980227, -168.0684463>,
    <0.2040578, -168.0684463>,
    <0.1991820, -168.0684463>,
    <0.1978865, -168.0684463>,
    <0.2009472, -168.0684463>,
    <0.2015931, -168.0684463>,
    <0.1985534, -168.0684463>,
    <0.1964299, -168.0684463>,
    <0.1976489, -168.0684463>,
    <0.1991820, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1985534, -168.0684463>,
    <0.1968048, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1959017, -168.0684463>,
    <0.1961401, -168.0684463>,
    <0.1976489, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1980227, -168.0684463>,
    <0.1959017, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1956578, -168.0684463>,
    <0.1978865, -168.0684463>,
    <0.7939441, -167.0961952>,
    <0.7986370, -167.0922118>,
    <0.7967190, -167.0843800>,
    <0.7857857, -167.1040945>,
    <0.7946346, -167.1040945>,
    <0.7973862, -167.0871043>,
    <0.7925867, -167.0918313>,
    <0.7903418, -167.1040945>,
    <0.7962804, -167.0992083>,
    <0.8007726, -167.0949799>,
    <0.7986370, -167.0922118>,
    <0.7946346, -167.1040945>,
    <0.8045696, -167.1040945>,
    <0.8052493, -167.0795188>,
    <0.7962804, -167.0992083>,
    <0.7991099, -167.1040945>,
    <0.8049259, -167.0912131>,
    <0.8019513, -167.0858496>,
    <0.8015402, -167.0811392>,
    <0.7986370, -167.0922118>,
    <0.8052493, -167.0795188>,
    <0.8055556, -167.0684463>,
    <0.7967190, -167.0843800>,
    <0.8019513, -167.0858496>,
    <0.8054049, -167.0738929>,
    <0.8003109, -167.0779032>,
    <0.7973862, -167.0871043>,
    <0.7962621, -168.0684463>,
    <0.7962964, -168.0684463>,
    <0.8009175, -168.0684463>,
    <0.7959423, -168.0684463>,
    <0.7918921, -168.0684463>,
    <0.7985877, -168.0684463>,
    <0.7983886, -168.0684463>,
    <0.7939585, -168.0684463>,
    <0.7935659, -168.0684463>,
    <0.7940979, -168.0684463>,
    <0.7962964, -168.0684463>,
    <0.7918921, -168.0684463>,
    <0.7873912, -168.0684463>,
    <0.8008119, -168.0684463>,
    <0.7935659, -168.0684463>,
    <0.7897166, -168.0684463>,
    <0.7959197, -168.0684463>,
    <0.7992750, -168.0684463>,
    <0.8008954, -168.0684463>,
    <0.7962964, -168.0684463>,
    <0.8008119, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8009175, -168.0684463>,
    <0.7992750, -168.0684463>,
    <0.8036737, -168.0684463>,
    <0.8032685, -168.0684463>,
    <0.7985877, -168.0684463>,
    <0.2056004, -168.0684463>,
    <0.2037037, -168.0684463>,
    <0.1982430, -168.0684463>,
    <0.2126088, -168.0684463>,
    <0.2078462, -168.0684463>,
    <0.2000760, -168.0684463>,
    <0.2028239, -168.0684463>,
    <0.2100164, -168.0684463>,
    <0.2062267, -168.0684463>,
    <0.2034076, -168.0684463>,
    <0.2037037, -168.0684463>,
    <0.2078462, -168.0684463>,
    <0.2040578, -168.0684463>,
    <0.1980227, -168.0684463>,
    <0.2062267, -168.0684463>,
    <0.2058878, -168.0684463>,
    <0.2009472, -168.0684463>,
    <0.2009088, -168.0684463>,
    <0.1986034, -168.0684463>,
    <0.2037037, -168.0684463>,
    <0.1980227, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1982430, -168.0684463>,
    <0.2009088, -168.0684463>,
    <0.1956578, -168.0684463>,
    <0.1958415, -168.0684463>,
    <0.2000760, -168.0684463>,
    <0.2093342, -167.0962945>,
    <0.2033751, -167.0922118>,
    <0.2060071, -167.1040945>,
    <0.2212365, -167.1040945>,
    <0.2067182, -167.0847772>,
    <0.2048941, -167.0990695>,
    <0.2126788, -167.1040945>,
    <0.2122065, -167.0920796>,
    <0.2053965, -167.0877164>,
    <0.1997455, -167.0830179>,
    <0.2033751, -167.0922118>,
    <0.2067182, -167.0847772>,
    <0.1944444, -167.0684463>,
    <0.1944444, -167.0866364>,
    <0.2053965, -167.0877164>,
    <0.2016479, -167.0780309>,
    <0.1944444, -167.0765160>,
    <0.1988022, -167.0893569>,
    <0.1995678, -167.0967593>,
    <0.2033751, -167.0922118>,
    <0.1944444, -167.0866364>,
    <0.1944444, -167.1040945>,
    <0.2060071, -167.1040945>,
    <0.1988022, -167.0893569>,
    <0.1944444, -167.1002976>,
    <0.2000464, -167.1040945>,
    <0.2048941, -167.0990695>,
    <0.2219213, -167.0967570>,
    <0.2218927, -167.0922118>,
    <0.2213518, -167.1040945>,
    <0.2222196, -167.1040945>,
    <0.2222209, -167.0866273>,
    <0.2215910, -167.0988412>,
    <0.2215909, -167.1040945>,
    <0.2222198, -167.1003883>,
    <0.2221000, -167.0886847>,
    <0.2220750, -167.0812669>,
    <0.2218927, -167.0922118>,
    <0.2222209, -167.0866273>,
    <0.2222222, -167.0684463>,
    <0.2219641, -167.0777821>,
    <0.2221000, -167.0886847>,
    <0.2222216, -167.0764687>,
    <0.2220967, -167.0729859>,
    <0.2219388, -167.0828850>,
    <0.2216113, -167.0945457>,
    <0.2218927, -167.0922118>,
    <0.2219641, -167.0777821>,
    <0.2212365, -167.1040945>,
    <0.2213518, -167.1040945>,
    <0.2219388, -167.0828850>,
    <0.2216748, -167.0882433>,
    <0.2212772, -167.1040945>,
    <0.2215910, -167.0988412>,
    <0.2156383, -167.0867457>,
    <0.2126344, -167.0803290>,
    <0.2067182, -167.0847772>,
    <0.2212365, -167.1040945>,
    <0.2219641, -167.0777821>,
    <0.2092415, -167.0828800>,
    <0.2122065, -167.0920796>,
    <0.2216748, -167.0882433>,
    <0.2172876, -167.0790587>,
    <0.2162885, -167.0737509>,
    <0.2126344, -167.0803290>,
    <0.2219641, -167.0777821>,
    <0.2222222, -167.0684463>,
    <0.2083333, -167.0684463>,
    <0.2172876, -167.0790587>,
    <0.2220967, -167.0729859>,
    <0.2152778, -167.0684463>,
    <0.2100169, -167.0730976>,
    <0.2055326, -167.0754997>,
    <0.2126344, -167.0803290>,
    <0.2083333, -167.0684463>,
    <0.1944444, -167.0684463>,
    <0.2067182, -167.0847772>,
    <0.2100169, -167.0730976>,
    <0.2013889, -167.0684463>,
    <0.2016479, -167.0780309>,
    <0.2092415, -167.0828800>,
    <0.7960801, -167.0684463>,
    <0.7903948, -167.0684463>,
    <0.7967033, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.7916667, -167.0684463>,
    <0.7939433, -167.0684463>,
    <0.8011294, -167.0684463>,
    <0.7986111, -167.0684463>,
    <0.7911102, -167.0684463>,
    <0.7856634, -167.0684463>,
    <0.7903948, -167.0684463>,
    <0.7916667, -167.0684463>,
    <0.7777778, -167.0684463>,
    <0.7828144, -167.0684463>,
    <0.7911102, -167.0684463>,
    <0.7847222, -167.0684463>,
    <0.7802961, -167.0684463>,
    <0.7861308, -167.0684463>,
    <0.7894409, -167.0684463>,
    <0.7903948, -167.0684463>,
    <0.7828144, -167.0684463>,
    <0.7878511, -167.0684463>,
    <0.7967033, -167.0684463>,
    <0.7861308, -167.0684463>,
    <0.7853327, -167.0684463>,
    <0.7922772, -167.0684463>,
    <0.7939433, -167.0684463>,
    <0.7882116, -167.0874926>,
    <0.7897064, -167.0803290>,
    <0.7806353, -167.0811668>,
    <0.7857857, -167.1040945>,
    <0.7967190, -167.0843800>,
    <0.7850742, -167.0807568>,
    <0.7825389, -167.0896407>,
    <0.7925867, -167.0918313>,
    <0.7935030, -167.0825223>,
    <0.7959119, -167.0754004>,
    <0.7897064, -167.0803290>,
    <0.7967190, -167.0843800>,
    <0.8055556, -167.0684463>,
    <0.7916667, -167.0684463>,
    <0.7935030, -167.0825223>,
    <0.8003109, -167.0779032>,
    <0.7986111, -167.0684463>,
    <0.7908871, -167.0731717>,
    <0.7849465, -167.0745971>,
    <0.7897064, -167.0803290>,
    <0.7916667, -167.0684463>,
    <0.7777778, -167.0684463>,
    <0.7806353, -167.0811668>,
    <0.7908871, -167.0731717>,
    <0.7847222, -167.0684463>,
    <0.7793243, -167.0753308>,
    <0.7850742, -167.0807568>,
    <0.7795912, -167.0967556>,
    <0.7804480, -167.0922118>,
    <0.7777792, -167.0866215>,
    <0.7777805, -167.1040945>,
    <0.7823573, -167.1040945>,
    <0.7791699, -167.0895345>,
    <0.7777800, -167.0976060>,
    <0.7801608, -167.1040945>,
    <0.7816425, -167.0996462>,
    <0.7823066, -167.0953919>,
    <0.7804480, -167.0922118>,
    <0.7823573, -167.1040945>,
    <0.7857857, -167.1040945>,
    <0.7806353, -167.0811668>,
    <0.7816425, -167.0996462>,
    <0.7842279, -167.1040945>,
    <0.7825389, -167.0896407>,
    <0.7805740, -167.0847794>,
    <0.7791601, -167.0821116>,
    <0.7804480, -167.0922118>,
    <0.7806353, -167.0811668>,
    <0.7777778, -167.0684463>,
    <0.7777792, -167.0866215>,
    <0.7805740, -167.0847794>,
    <0.7793243, -167.0753308>,
    <0.7777785, -167.0781738>,
    <0.7791699, -167.0895345>,
    <0.2065326, -167.0684463>,
    <0.2073043, -167.0684463>,
    <0.1998454, -167.0684463>,
    <0.2052464, -167.0684463>,
    <0.2137343, -167.0684463>,
    <0.2031087, -167.0684463>,
    <0.2025459, -167.0684463>,
    <0.2094903, -167.0684463>,
    <0.2109212, -167.0684463>,
    <0.2128985, -167.0684463>,
    <0.2073043, -167.0684463>,
    <0.2137343, -167.0684463>,
    <0.2222222, -167.0684463>,
    <0.2083333, -167.0684463>,
    <0.2109212, -167.0684463>,
    <0.2179783, -167.0684463>,
    <0.2152778, -167.0684463>,
    <0.2078831, -167.0684463>,
    <0.2024819, -167.0684463>,
    <0.2073043, -167.0684463>,
    <0.2083333, -167.0684463>,
    <0.1944444, -167.0684463>,
    <0.1998454, -167.0684463>,
    <0.2078831, -167.0684463>,
    <0.2013889, -167.0684463>,
    <0.1971449, -167.0684463>,
    <0.2031087, -167.0684463>,
    <0.7774872, -167.0967556>,
    <0.7774491, -167.0922118>,
    <0.7769439, -167.1040945>,
    <0.7777778, -167.1040945>,
    <0.7777778, -167.0866215>,
    <0.7771621, -167.0989634>,
    <0.7772111, -167.1040945>,
    <0.7777778, -167.0976060>,
    <0.7776347, -167.0890562>,
    <0.7776262, -167.0814419>,
    <0.7774491, -167.0922118>,
    <0.7777778, -167.0866215>,
    <0.7777778, -167.0684463>,
    <0.7775001, -167.0784881>,
    <0.7776347, -167.0890562>,
    <0.7777778, -167.0781738>,
    <0.7776429, -167.0733228>,
    <0.7774835, -167.0829573>,
    <0.7771712, -167.0947222>,
    <0.7774491, -167.0922118>,
    <0.7775001, -167.0784881>,
    <0.7767918, -167.1040945>,
    <0.7769439, -167.1040945>,
    <0.7774835, -167.0829573>,
    <0.7771681, -167.0904911>,
    <0.7768467, -167.1040945>,
    <0.7771621, -167.0989634>,
    <0.2174208, -168.0684463>,
    <0.2198254, -168.0684463>,
    <0.2164998, -168.0684463>,
    <0.2150318, -168.0684463>,
    <0.2183263, -168.0684463>,
    <0.2179770, -168.0684463>,
    <0.2156665, -168.0684463>,
    <0.2166253, -168.0684463>,
    <0.2189557, -168.0684463>,
    <0.2206490, -168.0684463>,
    <0.2198254, -168.0684463>,
    <0.2183263, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2189557, -168.0684463>,
    <0.2201425, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2214000, -168.0684463>,
    <0.2201924, -168.0684463>,
    <0.2198254, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2164998, -168.0684463>,
    <0.2214000, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2219059, -168.0684463>,
    <0.2179770, -168.0684463>,
    <0.2159365, -168.0684463>,
    <0.2166209, -168.0684463>,
    <0.2183263, -168.0684463>,
    <0.2150318, -168.0684463>,
    <0.2137672, -168.0684463>,
    <0.2174451, -168.0684463>,
    <0.2166253, -168.0684463>,
    <0.2144406, -168.0684463>,
    <0.2147754, -168.0684463>,
    <0.2159400, -168.0684463>,
    <0.2166209, -168.0684463>,
    <0.2137672, -168.0684463>,
    <0.2126088, -168.0684463>,
    <0.2207631, -168.0684463>,
    <0.2147754, -168.0684463>,
    <0.2131308, -168.0684463>,
    <0.2182565, -168.0684463>,
    <0.2195642, -168.0684463>,
    <0.2194831, -168.0684463>,
    <0.2166209, -168.0684463>,
    <0.2207631, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2183263, -168.0684463>,
    <0.2195642, -168.0684463>,
    <0.2217177, -168.0684463>,
    <0.2201425, -168.0684463>,
    <0.2174451, -168.0684463>,
    <0.2103434, -168.0684463>,
    <0.2097585, -168.0684463>,
    <0.2207631, -168.0684463>,
    <0.2126088, -168.0684463>,
    <0.1982430, -168.0684463>,
    <0.2153385, -168.0684463>,
    <0.2182565, -168.0684463>,
    <0.2028239, -168.0684463>,
    <0.2032762, -168.0684463>,
    <0.2027859, -168.0684463>,
    <0.2097585, -168.0684463>,
    <0.1982430, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.2086976, -168.0684463>,
    <0.2032762, -168.0684463>,
    <0.1958415, -168.0684463>,
    <0.2005733, -168.0684463>,
    <0.2090948, -168.0684463>,
    <0.2153603, -168.0684463>,
    <0.2097585, -168.0684463>,
    <0.2086976, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2207631, -168.0684463>,
    <0.2090948, -168.0684463>,
    <0.2165209, -168.0684463>,
    <0.2217177, -168.0684463>,
    <0.2153385, -168.0684463>,
    <0.7893506, -168.0684463>,
    <0.7902415, -168.0684463>,
    <0.8008119, -168.0684463>,
    <0.7873912, -168.0684463>,
    <0.7789575, -168.0684463>,
    <0.7955896, -168.0684463>,
    <0.7959197, -168.0684463>,
    <0.7812016, -168.0684463>,
    <0.7839385, -168.0684463>,
    <0.7848812, -168.0684463>,
    <0.7902415, -168.0684463>,
    <0.7789575, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7925480, -168.0684463>,
    <0.7839385, -168.0684463>,
    <0.7781635, -168.0684463>,
    <0.7841888, -168.0684463>,
    <0.7921235, -168.0684463>,
    <0.7972893, -168.0684463>,
    <0.7902415, -168.0684463>,
    <0.7925480, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8008119, -168.0684463>,
    <0.7921235, -168.0684463>,
    <0.8001099, -168.0684463>,
    <0.8036737, -168.0684463>,
    <0.7955896, -168.0684463>,
    <0.7817229, -168.0684463>,
    <0.7821537, -168.0684463>,
    <0.7846555, -168.0684463>,
    <0.7812921, -168.0684463>,
    <0.7787902, -168.0684463>,
    <0.7837749, -168.0684463>,
    <0.7830717, -168.0684463>,
    <0.7799486, -168.0684463>,
    <0.7805734, -168.0684463>,
    <0.7794198, -168.0684463>,
    <0.7821537, -168.0684463>,
    <0.7787902, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7789575, -168.0684463>,
    <0.7805734, -168.0684463>,
    <0.7780553, -168.0684463>,
    <0.7781635, -168.0684463>,
    <0.7800136, -168.0684463>,
    <0.7832895, -168.0684463>,
    <0.7821537, -168.0684463>,
    <0.7789575, -168.0684463>,
    <0.7873913, -168.0684463>,
    <0.7846555, -168.0684463>,
    <0.7800136, -168.0684463>,
    <0.7812016, -168.0684463>,
    <0.7860864, -168.0684463>,
    <0.7837749, -168.0684463>,
    <0.7785466, -168.0684463>,
    <0.7789492, -168.0684463>,
    <0.7796818, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7793576, -168.0684463>,
    <0.7787510, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7782516, -168.0684463>,
    <0.7783237, -168.0684463>,
    <0.7789492, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7787902, -168.0684463>,
    <0.7782516, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7780553, -168.0684463>,
    <0.7788485, -168.0684463>,
    <0.7796783, -168.0684463>,
    <0.7789492, -168.0684463>,
    <0.7787902, -168.0684463>,
    <0.7812921, -168.0684463>,
    <0.7796818, -168.0684463>,
    <0.7788485, -168.0684463>,
    <0.7799486, -168.0684463>,
    <0.7805326, -168.0684463>,
    <0.7793576, -168.0684463>,
    <0.7723747, -168.0684463>,
    <0.7745733, -168.0684463>,
    <0.7730403, -168.0684463>,
    <0.7681644, -168.0684463>,
    <0.7737207, -168.0684463>,
    <0.7736294, -168.0684463>,
    <0.7706292, -168.0684463>,
    <0.7709400, -168.0684463>,
    <0.7740280, -168.0684463>,
    <0.7759624, -168.0684463>,
    <0.7745733, -168.0684463>,
    <0.7737207, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7740280, -168.0684463>,
    <0.7762519, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7762281, -168.0684463>,
    <0.7757923, -168.0684463>,
    <0.7745733, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7730403, -168.0684463>,
    <0.7762281, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7754175, -168.0684463>,
    <0.7736294, -168.0684463>,
    <0.7685732, -168.0684463>,
    <0.7685186, -168.0684463>,
    <0.7737207, -168.0684463>,
    <0.7681644, -168.0684463>,
    <0.7638890, -168.0684463>,
    <0.7710602, -168.0684463>,
    <0.7709400, -168.0684463>,
    <0.7660432, -168.0684463>,
    <0.7656706, -168.0684463>,
    <0.7662524, -168.0684463>,
    <0.7685186, -168.0684463>,
    <0.7638890, -168.0684463>,
    <0.7596135, -168.0684463>,
    <0.7729886, -168.0684463>,
    <0.7656706, -168.0684463>,
    <0.7617348, -168.0684463>,
    <0.7679199, -168.0684463>,
    <0.7714846, -168.0684463>,
    <0.7732514, -168.0684463>,
    <0.7685186, -168.0684463>,
    <0.7729886, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7737207, -168.0684463>,
    <0.7714846, -168.0684463>,
    <0.7759687, -168.0684463>,
    <0.7762519, -168.0684463>,
    <0.7710602, -168.0684463>,
    <0.7661651, -167.0961964>,
    <0.7708589, -167.0922118>,
    <0.7689381, -167.0843847>,
    <0.7580068, -167.1040945>,
    <0.7668566, -167.1040945>,
    <0.7696040, -167.0870981>,
    <0.7648058, -167.0918355>,
    <0.7625634, -167.1040945>,
    <0.7685010, -167.0992124>,
    <0.7730019, -167.0947222>,
    <0.7708589, -167.0922118>,
    <0.7668566, -167.1040945>,
    <0.7767920, -167.1040945>,
    <0.7775001, -167.0784881>,
    <0.7685010, -167.0992124>,
    <0.7713322, -167.1040945>,
    <0.7771682, -167.0904911>,
    <0.7741882, -167.0853319>,
    <0.7737687, -167.0808827>,
    <0.7708589, -167.0922118>,
    <0.7775001, -167.0784881>,
    <0.7777778, -167.0684463>,
    <0.7689381, -167.0843847>,
    <0.7741882, -167.0853319>,
    <0.7776429, -167.0733228>,
    <0.7725312, -167.0779061>,
    <0.7696040, -167.0870981>,
    <0.2371135, -167.0962965>,
    <0.2311529, -167.0922118>,
    <0.2337849, -167.1040945>,
    <0.2490141, -167.1040945>,
    <0.2345019, -167.0847851>,
    <0.2326717, -167.0990689>,
    <0.2404567, -167.1040945>,
    <0.2399903, -167.0920878>,
    <0.2331786, -167.0877197>,
    <0.2275248, -167.0830176>,
    <0.2311529, -167.0922118>,
    <0.2345019, -167.0847851>,
    <0.2222222, -167.0684463>,
    <0.2222222, -167.0866273>,
    <0.2331786, -167.0877197>,
    <0.2294302, -167.0780369>,
    <0.2222222, -167.0764687>,
    <0.2265799, -167.0893522>,
    <0.2273455, -167.0967570>,
    <0.2311529, -167.0922118>,
    <0.2222222, -167.0866273>,
    <0.2222222, -167.1040945>,
    <0.2337849, -167.1040945>,
    <0.2265799, -167.0893522>,
    <0.2222222, -167.1003883>,
    <0.2278242, -167.1040945>,
    <0.2326717, -167.0990689>,
    <0.2497003, -167.0967598>,
    <0.2496714, -167.0922118>,
    <0.2491300, -167.1040945>,
    <0.2500000, -167.1040945>,
    <0.2500000, -167.0866383>,
    <0.2493690, -167.0988475>,
    <0.2493698, -167.1040945>,
    <0.2500000, -167.1002353>,
    <0.2498788, -167.0886940>,
    <0.2498513, -167.0813423>,
    <0.2496714, -167.0922118>,
    <0.2500000, -167.0866383>,
    <0.2500000, -167.0684463>,
    <0.2497338, -167.0780728>,
    <0.2498788, -167.0886940>,
    <0.2500000, -167.0765534>,
    <0.2498699, -167.0731493>,
    <0.2497117, -167.0830783>,
    <0.2493873, -167.0946184>,
    <0.2496714, -167.0922118>,
    <0.2497338, -167.0780728>,
    <0.2490141, -167.1040945>,
    <0.2491300, -167.1040945>,
    <0.2497117, -167.0830783>,
    <0.2494487, -167.0883808>,
    <0.2490551, -167.1040945>,
    <0.2493690, -167.0988475>,
    <0.2434155, -167.0868204>,
    <0.2404121, -167.0803290>,
    <0.2345019, -167.0847851>,
    <0.2490141, -167.1040945>,
    <0.2497338, -167.0780728>,
    <0.2370232, -167.0828841>,
    <0.2399903, -167.0920878>,
    <0.2494487, -167.0883808>,
    <0.2450617, -167.0792037>,
    <0.2440642, -167.0738236>,
    <0.2404121, -167.0803290>,
    <0.2497338, -167.0780728>,
    <0.2500000, -167.0684463>,
    <0.2361111, -167.0684463>,
    <0.2450617, -167.0792037>,
    <0.2498699, -167.0731493>,
    <0.2430555, -167.0684463>,
    <0.2377953, -167.0730993>,
    <0.2333118, -167.0755017>,
    <0.2404121, -167.0803290>,
    <0.2361111, -167.0684463>,
    <0.2222222, -167.0684463>,
    <0.2345019, -167.0847851>,
    <0.2377953, -167.0730993>,
    <0.2291667, -167.0684463>,
    <0.2294302, -167.0780369>,
    <0.2370232, -167.0828841>,
    <0.2334899, -168.0684463>,
    <0.2407407, -168.0684463>,
    <0.2344945, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2365021, -168.0684463>,
    <0.2372801, -168.0684463>,
    <0.2295259, -168.0684463>,
    <0.2307803, -168.0684463>,
    <0.2382714, -168.0684463>,
    <0.2443107, -168.0684463>,
    <0.2407407, -168.0684463>,
    <0.2365021, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2382714, -168.0684463>,
    <0.2419392, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2454109, -168.0684463>,
    <0.2438088, -168.0684463>,
    <0.2407407, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2344945, -168.0684463>,
    <0.2454109, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2397567, -168.0684463>,
    <0.2372801, -168.0684463>,
    <0.2281070, -168.0684463>,
    <0.2314815, -168.0684463>,
    <0.2365021, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2344876, -168.0684463>,
    <0.2307803, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2269009, -168.0684463>,
    <0.2278844, -168.0684463>,
    <0.2314815, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2356116, -168.0684463>,
    <0.2269009, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2283948, -168.0684463>,
    <0.2332347, -168.0684463>,
    <0.2383988, -168.0684463>,
    <0.2314815, -168.0684463>,
    <0.2356116, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2365021, -168.0684463>,
    <0.2332347, -168.0684463>,
    <0.2420336, -168.0684463>,
    <0.2419392, -168.0684463>,
    <0.2344876, -168.0684463>,
    <0.7615537, -168.0684463>,
    <0.7624638, -168.0684463>,
    <0.7729886, -168.0684463>,
    <0.7596135, -168.0684463>,
    <0.7511491, -168.0684463>,
    <0.7677080, -168.0684463>,
    <0.7679199, -168.0684463>,
    <0.7532590, -168.0684463>,
    <0.7560034, -168.0684463>,
    <0.7571235, -168.0684463>,
    <0.7624638, -168.0684463>,
    <0.7511491, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7648812, -168.0684463>,
    <0.7560034, -168.0684463>,
    <0.7503771, -168.0684463>,
    <0.7562072, -168.0684463>,
    <0.7642612, -168.0684463>,
    <0.7695278, -168.0684463>,
    <0.7624638, -168.0684463>,
    <0.7648812, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7729886, -168.0684463>,
    <0.7642612, -168.0684463>,
    <0.7725798, -168.0684463>,
    <0.7759687, -168.0684463>,
    <0.7677080, -168.0684463>,
    <0.7531364, -168.0684463>,
    <0.7532045, -168.0684463>,
    <0.7593409, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7568010, -168.0684463>,
    <0.7534193, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7512680, -168.0684463>,
    <0.7510884, -168.0684463>,
    <0.7532045, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7511491, -168.0684463>,
    <0.7512680, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7503771, -168.0684463>,
    <0.7519424, -168.0684463>,
    <0.7558270, -168.0684463>,
    <0.7532045, -168.0684463>,
    <0.7511491, -168.0684463>,
    <0.7596134, -168.0684463>,
    <0.7593409, -168.0684463>,
    <0.7519424, -168.0684463>,
    <0.7532590, -168.0684463>,
    <0.7594950, -168.0684463>,
    <0.7568010, -168.0684463>,
    <0.7604306, -167.0874852>,
    <0.7619282, -167.0803290>,
    <0.7528494, -167.0811326>,
    <0.7580068, -167.1040945>,
    <0.7689381, -167.0843847>,
    <0.7572921, -167.0807394>,
    <0.7547466, -167.0895791>,
    <0.7648058, -167.0918355>,
    <0.7657225, -167.0825243>,
    <0.7681333, -167.0754016>,
    <0.7619282, -167.0803290>,
    <0.7689381, -167.0843847>,
    <0.7777778, -167.0684463>,
    <0.7638889, -167.0684463>,
    <0.7657225, -167.0825243>,
    <0.7725312, -167.0779061>,
    <0.7708333, -167.0684463>,
    <0.7631101, -167.0731661>,
    <0.7571666, -167.0745885>,
    <0.7619282, -167.0803290>,
    <0.7638889, -167.0684463>,
    <0.7500000, -167.0684463>,
    <0.7528494, -167.0811326>,
    <0.7631101, -167.0731661>,
    <0.7569445, -167.0684463>,
    <0.7515427, -167.0753148>,
    <0.7572921, -167.0807394>,
    <0.7545257, -167.0953833>,
    <0.7526689, -167.0922118>,
    <0.7545778, -167.1040945>,
    <0.7580067, -167.1040945>,
    <0.7528494, -167.0811326>,
    <0.7538576, -167.0996113>,
    <0.7564487, -167.1040945>,
    <0.7547465, -167.0895791>,
    <0.7527903, -167.0847618>,
    <0.7513796, -167.0820916>,
    <0.7526689, -167.0922118>,
    <0.7528494, -167.0811326>,
    <0.7500000, -167.0684463>,
    <0.7500000, -167.0865760>,
    <0.7527903, -167.0847618>,
    <0.7515427, -167.0753148>,
    <0.7500000, -167.0782526>,
    <0.7513914, -167.0895142>,
    <0.7518117, -167.0967442>,
    <0.7526689, -167.0922118>,
    <0.7500000, -167.0865760>,
    <0.7500000, -167.1040945>,
    <0.7545778, -167.1040945>,
    <0.7513914, -167.0895142>,
    <0.7500000, -167.0973757>,
    <0.7523809, -167.1040945>,
    <0.7538576, -167.0996113>,
    <0.7497094, -167.0967442>,
    <0.7496714, -167.0922118>,
    <0.7491661, -167.1040945>,
    <0.7500000, -167.1040945>,
    <0.7500000, -167.0865760>,
    <0.7493850, -167.0989464>,
    <0.7494332, -167.1040945>,
    <0.7500000, -167.0973757>,
    <0.7498566, -167.0890360>,
    <0.7498448, -167.0815633>,
    <0.7496714, -167.0922118>,
    <0.7500000, -167.0865760>,
    <0.7500000, -167.0684463>,
    <0.7497076, -167.0790194>,
    <0.7498566, -167.0890360>,
    <0.7500000, -167.0782526>,
    <0.7498570, -167.0736178>,
    <0.7496958, -167.0833315>,
    <0.7493898, -167.0948550>,
    <0.7496714, -167.0922118>,
    <0.7497076, -167.0790194>,
    <0.7490142, -167.1040945>,
    <0.7491661, -167.1040945>,
    <0.7496958, -167.0833315>,
    <0.7493801, -167.0908622>,
    <0.7490690, -167.1040945>,
    <0.7493850, -167.0989464>,
    <0.2539205, -168.0684463>,
    <0.2520920, -168.0684463>,
    <0.2538694, -168.0684463>,
    <0.2562759, -168.0684463>,
    <0.2534447, -168.0684463>,
    <0.2531395, -168.0684463>,
    <0.2552994, -168.0684463>,
    <0.2549528, -168.0684463>,
    <0.2528781, -168.0684463>,
    <0.2513842, -168.0684463>,
    <0.2520920, -168.0684463>,
    <0.2534447, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2528781, -168.0684463>,
    <0.2517678, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2507327, -168.0684463>,
    <0.2514903, -168.0684463>,
    <0.2520920, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2538694, -168.0684463>,
    <0.2507327, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2507758, -168.0684463>,
    <0.2531395, -168.0684463>,
    <0.2630453, -168.0684463>,
    <0.2581468, -168.0684463>,
    <0.2632832, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2625865, -168.0684463>,
    <0.2613201, -168.0684463>,
    <0.2659334, -168.0684463>,
    <0.2654166, -168.0684463>,
    <0.2607813, -168.0684463>,
    <0.2577197, -168.0684463>,
    <0.2581468, -168.0684463>,
    <0.2625865, -168.0684463>,
    <0.2562759, -168.0684463>,
    <0.2538694, -168.0684463>,
    <0.2607813, -168.0684463>,
    <0.2595892, -168.0684463>,
    <0.2552994, -168.0684463>,
    <0.2559193, -168.0684463>,
    <0.2563249, -168.0684463>,
    <0.2581468, -168.0684463>,
    <0.2538694, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2632832, -168.0684463>,
    <0.2559193, -168.0684463>,
    <0.2507758, -168.0684463>,
    <0.2621038, -168.0684463>,
    <0.2613201, -168.0684463>,
    <0.2643802, -168.0684463>,
    <0.2621097, -168.0684463>,
    <0.2590823, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2603538, -168.0684463>,
    <0.2636234, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2653596, -168.0684463>,
    <0.2642385, -168.0684463>,
    <0.2621097, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2585155, -168.0684463>,
    <0.2653596, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2630951, -168.0684463>,
    <0.2600375, -168.0684463>,
    <0.2574268, -168.0684463>,
    <0.2621097, -168.0684463>,
    <0.2585155, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2590823, -168.0684463>,
    <0.2600375, -168.0684463>,
    <0.2541943, -168.0684463>,
    <0.2545411, -168.0684463>,
    <0.2603538, -168.0684463>,
    <0.7383849, -167.0962010>,
    <0.7430811, -167.0922118>,
    <0.7411501, -167.0844033>,
    <0.7302293, -167.1040945>,
    <0.7390789, -167.1040945>,
    <0.7418209, -167.0871157>,
    <0.7370168, -167.0918561>,
    <0.7347858, -167.1040945>,
    <0.7407247, -167.0992080>,
    <0.7452204, -167.0948550>,
    <0.7430811, -167.0922118>,
    <0.7390789, -167.1040945>,
    <0.7490141, -167.1040945>,
    <0.7497076, -167.0790194>,
    <0.7407247, -167.0992080>,
    <0.7435544, -167.1040945>,
    <0.7493801, -167.0908622>,
    <0.7464033, -167.0855979>,
    <0.7459847, -167.0810202>,
    <0.7430811, -167.0922118>,
    <0.7497076, -167.0790194>,
    <0.7500000, -167.0684463>,
    <0.7411501, -167.0844033>,
    <0.7464033, -167.0855979>,
    <0.7498570, -167.0736178>,
    <0.7447458, -167.0779200>,
    <0.7418209, -167.0871157>,
    <0.2700459, -168.0684463>,
    <0.2713689, -168.0684463>,
    <0.2724858, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2719806, -168.0684463>,
    <0.2704567, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2694630, -168.0684463>,
    <0.2701673, -168.0684463>,
    <0.2713689, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2729711, -168.0684463>,
    <0.2694630, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2705678, -168.0684463>,
    <0.2722286, -168.0684463>,
    <0.2736509, -168.0684463>,
    <0.2713689, -168.0684463>,
    <0.2729711, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2724858, -168.0684463>,
    <0.2722286, -168.0684463>,
    <0.2753745, -168.0684463>,
    <0.2746793, -168.0684463>,
    <0.2719806, -168.0684463>,
    <0.2719288, -168.0684463>,
    <0.2745733, -168.0684463>,
    <0.2724917, -168.0684463>,
    <0.2681645, -168.0684463>,
    <0.2724858, -168.0684463>,
    <0.2734307, -168.0684463>,
    <0.2701842, -168.0684463>,
    <0.2704567, -168.0684463>,
    <0.2734404, -168.0684463>,
    <0.2756537, -168.0684463>,
    <0.2745733, -168.0684463>,
    <0.2724858, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2734404, -168.0684463>,
    <0.2746793, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2764712, -168.0684463>,
    <0.2756551, -168.0684463>,
    <0.2745733, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2724917, -168.0684463>,
    <0.2764712, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2750635, -168.0684463>,
    <0.2734307, -168.0684463>,
    <0.7286525, -168.0684463>,
    <0.7314815, -168.0684463>,
    <0.7386842, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7352156, -168.0684463>,
    <0.7312365, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7258374, -168.0684463>,
    <0.7293232, -168.0684463>,
    <0.7314815, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7413667, -168.0684463>,
    <0.7258374, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7333675, -168.0684463>,
    <0.7383275, -168.0684463>,
    <0.7403831, -168.0684463>,
    <0.7314815, -168.0684463>,
    <0.7413667, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7386842, -168.0684463>,
    <0.7383275, -168.0684463>,
    <0.7465579, -168.0684463>,
    <0.7451620, -168.0684463>,
    <0.7352156, -168.0684463>,
    <0.7344902, -168.0684463>,
    <0.7407408, -168.0684463>,
    <0.7363135, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7386842, -168.0684463>,
    <0.7378454, -168.0684463>,
    <0.7309376, -168.0684463>,
    <0.7312365, -168.0684463>,
    <0.7396341, -168.0684463>,
    <0.7448562, -168.0684463>,
    <0.7407408, -168.0684463>,
    <0.7386842, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7396341, -168.0684463>,
    <0.7451620, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7453228, -168.0684463>,
    <0.7442636, -168.0684463>,
    <0.7407408, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7363135, -168.0684463>,
    <0.7453228, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7418085, -168.0684463>,
    <0.7378454, -168.0684463>,
    <0.2648916, -167.0962970>,
    <0.2589306, -167.0922118>,
    <0.2615626, -167.1040945>,
    <0.2767918, -167.1040945>,
    <0.2622813, -167.0847874>,
    <0.2604493, -167.0990680>,
    <0.2682344, -167.1040945>,
    <0.2677702, -167.0920907>,
    <0.2609561, -167.0877237>,
    <0.2553030, -167.0830209>,
    <0.2589306, -167.0922118>,
    <0.2622813, -167.0847874>,
    <0.2500000, -167.0684463>,
    <0.2500000, -167.0866383>,
    <0.2609561, -167.0877237>,
    <0.2572092, -167.0780386>,
    <0.2500000, -167.0765534>,
    <0.2543575, -167.0893577>,
    <0.2551233, -167.0967598>,
    <0.2589306, -167.0922118>,
    <0.2500000, -167.0866383>,
    <0.2500000, -167.1040945>,
    <0.2615626, -167.1040945>,
    <0.2543575, -167.0893577>,
    <0.2500000, -167.1002353>,
    <0.2556019, -167.1040945>,
    <0.2604493, -167.0990680>,
    <0.2683023, -167.0684463>,
    <0.2626171, -167.0684463>,
    <0.2689256, -167.0684463>,
    <0.2777778, -167.0684463>,
    <0.2638889, -167.0684463>,
    <0.2661656, -167.0684463>,
    <0.2733517, -167.0684463>,
    <0.2708333, -167.0684463>,
    <0.2633325, -167.0684463>,
    <0.2578857, -167.0684463>,
    <0.2626171, -167.0684463>,
    <0.2638889, -167.0684463>,
    <0.2500000, -167.0684463>,
    <0.2550367, -167.0684463>,
    <0.2633325, -167.0684463>,
    <0.2569444, -167.0684463>,
    <0.2525184, -167.0684463>,
    <0.2583531, -167.0684463>,
    <0.2616632, -167.0684463>,
    <0.2626171, -167.0684463>,
    <0.2550367, -167.0684463>,
    <0.2600734, -167.0684463>,
    <0.2689256, -167.0684463>,
    <0.2583531, -167.0684463>,
    <0.2575551, -167.0684463>,
    <0.2644995, -167.0684463>,
    <0.2661656, -167.0684463>,
    <0.2711925, -167.0868630>,
    <0.2681899, -167.0803290>,
    <0.2622813, -167.0847874>,
    <0.2767918, -167.1040945>,
    <0.2775069, -167.0782410>,
    <0.2648012, -167.0828860>,
    <0.2677702, -167.0920907>,
    <0.2772207, -167.0885871>,
    <0.2728373, -167.0792875>,
    <0.2718408, -167.0738657>,
    <0.2681899, -167.0803290>,
    <0.2775069, -167.0782410>,
    <0.2777778, -167.0684463>,
    <0.2638889, -167.0684463>,
    <0.2728373, -167.0792875>,
    <0.2776454, -167.0732327>,
    <0.2708333, -167.0684463>,
    <0.2655738, -167.0731013>,
    <0.2610900, -167.0755022>,
    <0.2681899, -167.0803290>,
    <0.2638889, -167.0684463>,
    <0.2500000, -167.0684463>,
    <0.2622813, -167.0847874>,
    <0.2655738, -167.0731013>,
    <0.2569444, -167.0684463>,
    <0.2572092, -167.0780386>,
    <0.2648012, -167.0828860>,
    <0.2774769, -167.0967606>,
    <0.2774483, -167.0922118>,
    <0.2769075, -167.1040945>,
    <0.2777752, -167.1040945>,
    <0.2777764, -167.0866416>,
    <0.2771468, -167.0988371>,
    <0.2771466, -167.1040945>,
    <0.2777755, -167.1002344>,
    <0.2776555, -167.0886953>,
    <0.2776274, -167.0813852>,
    <0.2774483, -167.0922118>,
    <0.2777764, -167.0866416>,
    <0.2777778, -167.0684463>,
    <0.2775069, -167.0782410>,
    <0.2776555, -167.0886953>,
    <0.2777772, -167.0765547>,
    <0.2776454, -167.0732327>,
    <0.2774862, -167.0831870>,
    <0.2771637, -167.0946604>,
    <0.2774483, -167.0922118>,
    <0.2775069, -167.0782410>,
    <0.2767920, -167.1040945>,
    <0.2769075, -167.1040945>,
    <0.2774862, -167.0831870>,
    <0.2772208, -167.0885871>,
    <0.2768328, -167.1040945>,
    <0.2771468, -167.0988371>,
    <0.7240356, -167.0967305>,
    <0.7248924, -167.0922118>,
    <0.7222235, -167.0865214>,
    <0.7222248, -167.1040945>,
    <0.7268018, -167.1040945>,
    <0.7236150, -167.0894883>,
    <0.7222243, -167.0971569>,
    <0.7246053, -167.1040945>,
    <0.7260710, -167.0995468>,
    <0.7267547, -167.0954085>,
    <0.7248924, -167.0922118>,
    <0.7268018, -167.1040945>,
    <0.7302300, -167.1040945>,
    <0.7250946, -167.0812332>,
    <0.7260710, -167.0995468>,
    <0.7286723, -167.1040945>,
    <0.7269943, -167.0896900>,
    <0.7250282, -167.0848383>,
    <0.7236082, -167.0821032>,
    <0.7248924, -167.0922118>,
    <0.7250946, -167.0812332>,
    <0.7222222, -167.0684463>,
    <0.7222235, -167.0865214>,
    <0.7250282, -167.0848383>,
    <0.7237792, -167.0753776>,
    <0.7222229, -167.0783496>,
    <0.7236150, -167.0894883>,
    <0.7326561, -167.0875150>,
    <0.7341505, -167.0803290>,
    <0.7250943, -167.0812332>,
    <0.7302293, -167.1040945>,
    <0.7411501, -167.0844033>,
    <0.7295253, -167.0807908>,
    <0.7269939, -167.0896900>,
    <0.7370168, -167.0918561>,
    <0.7379400, -167.0825348>,
    <0.7403529, -167.0754062>,
    <0.7341505, -167.0803290>,
    <0.7411501, -167.0844033>,
    <0.7500000, -167.0684463>,
    <0.7361111, -167.0684463>,
    <0.7379400, -167.0825348>,
    <0.7447458, -167.0779200>,
    <0.7430556, -167.0684463>,
    <0.7353300, -167.0731804>,
    <0.7293946, -167.0746137>,
    <0.7341505, -167.0803290>,
    <0.7361111, -167.0684463>,
    <0.7222222, -167.0684463>,
    <0.7250943, -167.0812332>,
    <0.7353300, -167.0731804>,
    <0.7291667, -167.0684463>,
    <0.7237791, -167.0753776>,
    <0.7295253, -167.0807908>,
    <0.7219316, -167.0967305>,
    <0.7218936, -167.0922118>,
    <0.7213884, -167.1040945>,
    <0.7222222, -167.1040945>,
    <0.7222222, -167.0865214>,
    <0.7216078, -167.0989345>,
    <0.7216556, -167.1040945>,
    <0.7222222, -167.0971569>,
    <0.7220784, -167.0890117>,
    <0.7220635, -167.0816746>,
    <0.7218936, -167.0922118>,
    <0.7222222, -167.0865214>,
    <0.7222222, -167.0684463>,
    <0.7219160, -167.0795188>,
    <0.7220784, -167.0890117>,
    <0.7222222, -167.0783496>,
    <0.7220714, -167.0738980>,
    <0.7219086, -167.0836846>,
    <0.7216086, -167.0949799>,
    <0.7218936, -167.0922118>,
    <0.7219160, -167.0795188>,
    <0.7212363, -167.1040945>,
    <0.7213884, -167.1040945>,
    <0.7219086, -167.0836846>,
    <0.7215927, -167.0912081>,
    <0.7212912, -167.1040945>,
    <0.7216078, -167.0989345>,
    <0.7147968, -168.0684463>,
    <0.7190178, -168.0684463>,
    <0.7128820, -168.0684463>,
    <0.7126088, -168.0684463>,
    <0.7146786, -168.0684463>,
    <0.7154387, -168.0684463>,
    <0.7127275, -168.0684463>,
    <0.7134975, -168.0684463>,
    <0.7163515, -168.0684463>,
    <0.7195352, -168.0684463>,
    <0.7190178, -168.0684463>,
    <0.7146786, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7163515, -168.0684463>,
    <0.7202239, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7210173, -168.0684463>,
    <0.7190861, -168.0684463>,
    <0.7190178, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7128820, -168.0684463>,
    <0.7210173, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7188022, -168.0684463>,
    <0.7154387, -168.0684463>,
    <0.2880866, -168.0684463>,
    <0.2838326, -168.0684463>,
    <0.2862933, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2862783, -168.0684463>,
    <0.2852399, -168.0684463>,
    <0.2908729, -168.0684463>,
    <0.2902663, -168.0684463>,
    <0.2852447, -168.0684463>,
    <0.2814166, -168.0684463>,
    <0.2838326, -168.0684463>,
    <0.2862783, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2852447, -168.0684463>,
    <0.2824496, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2805695, -168.0684463>,
    <0.2814204, -168.0684463>,
    <0.2838326, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2862933, -168.0684463>,
    <0.2805695, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2819721, -168.0684463>,
    <0.2852399, -168.0684463>,
    <0.7121459, -168.0684463>,
    <0.7129630, -168.0684463>,
    <0.7146786, -168.0684463>,
    <0.7126088, -168.0684463>,
    <0.7083334, -168.0684463>,
    <0.7138577, -168.0684463>,
    <0.7134975, -168.0684463>,
    <0.7104876, -168.0684463>,
    <0.7102411, -168.0684463>,
    <0.7088477, -168.0684463>,
    <0.7129630, -168.0684463>,
    <0.7083334, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7100367, -168.0684463>,
    <0.7102411, -168.0684463>,
    <0.7061792, -168.0684463>,
    <0.7077359, -168.0684463>,
    <0.7109775, -168.0684463>,
    <0.7149751, -168.0684463>,
    <0.7129630, -168.0684463>,
    <0.7100367, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7146786, -168.0684463>,
    <0.7109775, -168.0684463>,
    <0.7109735, -168.0684463>,
    <0.7202239, -168.0684463>,
    <0.7138577, -168.0684463>,
    <0.7070662, -168.0684463>,
    <0.7101126, -168.0684463>,
    <0.7100367, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7100733, -168.0684463>,
    <0.7077359, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7067264, -168.0684463>,
    <0.7069066, -168.0684463>,
    <0.7101126, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7093980, -168.0684463>,
    <0.7067264, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7066094, -168.0684463>,
    <0.7097182, -168.0684463>,
    <0.7129424, -168.0684463>,
    <0.7101126, -168.0684463>,
    <0.7093980, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7100367, -168.0684463>,
    <0.7097182, -168.0684463>,
    <0.7105981, -168.0684463>,
    <0.7109735, -168.0684463>,
    <0.7100733, -168.0684463>,
    <0.2920126, -168.0684463>,
    <0.2898874, -168.0684463>,
    <0.2862783, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2877878, -168.0684463>,
    <0.2902663, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2931436, -168.0684463>,
    <0.2918821, -168.0684463>,
    <0.2898874, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2857565, -168.0684463>,
    <0.2931436, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2903022, -168.0684463>,
    <0.2874774, -168.0684463>,
    <0.2849250, -168.0684463>,
    <0.2898874, -168.0684463>,
    <0.2857565, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2862783, -168.0684463>,
    <0.2874774, -168.0684463>,
    <0.2816561, -168.0684463>,
    <0.2824496, -168.0684463>,
    <0.2877878, -168.0684463>,
    <0.7106076, -167.0962010>,
    <0.7153036, -167.0922118>,
    <0.7133727, -167.0844033>,
    <0.7024523, -167.1040945>,
    <0.7113016, -167.1040945>,
    <0.7140447, -167.0871207>,
    <0.7092394, -167.0918563>,
    <0.7070087, -167.1040945>,
    <0.7129481, -167.0992056>,
    <0.7174394, -167.0949799>,
    <0.7153036, -167.0922118>,
    <0.7113016, -167.1040945>,
    <0.7212362, -167.1040945>,
    <0.7219160, -167.0795188>,
    <0.7129481, -167.0992056>,
    <0.7157768, -167.1040945>,
    <0.7215927, -167.0912081>,
    <0.7186185, -167.0858486>,
    <0.7182036, -167.0811450>,
    <0.7153036, -167.0922118>,
    <0.7219160, -167.0795188>,
    <0.7222222, -167.0684463>,
    <0.7133727, -167.0844033>,
    <0.7186185, -167.0858486>,
    <0.7220714, -167.0738980>,
    <0.7169681, -167.0779203>,
    <0.7140447, -167.0871207>,
    <0.2992439, -168.0684463>,
    <0.2999543, -168.0684463>,
    <0.3018350, -168.0684463>,
    <0.2983652, -168.0684463>,
    <0.2968211, -168.0684463>,
    <0.3009118, -168.0684463>,
    <0.3000748, -168.0684463>,
    <0.2975853, -168.0684463>,
    <0.2981778, -168.0684463>,
    <0.2982698, -168.0684463>,
    <0.2999543, -168.0684463>,
    <0.2968211, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.3003615, -168.0684463>,
    <0.2981778, -168.0684463>,
    <0.2962984, -168.0684463>,
    <0.2982982, -168.0684463>,
    <0.3001709, -168.0684463>,
    <0.3019266, -168.0684463>,
    <0.2999543, -168.0684463>,
    <0.3003615, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.3018350, -168.0684463>,
    <0.3001709, -168.0684463>,
    <0.3023590, -168.0684463>,
    <0.3033430, -168.0684463>,
    <0.3009118, -168.0684463>,
    <0.2978482, -168.0684463>,
    <0.2991467, -168.0684463>,
    <0.3003615, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2996558, -168.0684463>,
    <0.2982982, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2972351, -168.0684463>,
    <0.2978252, -168.0684463>,
    <0.2991467, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.3002695, -168.0684463>,
    <0.2972351, -168.0684463>,
    <0.2959423, -168.0684463>,
    <0.2979620, -168.0684463>,
    <0.2997275, -168.0684463>,
    <0.3013333, -168.0684463>,
    <0.2991467, -168.0684463>,
    <0.3002695, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.3003615, -168.0684463>,
    <0.2997275, -168.0684463>,
    <0.3028413, -168.0684463>,
    <0.3023590, -168.0684463>,
    <0.2996558, -168.0684463>,
    <0.7021749, -168.0684463>,
    <0.7008534, -168.0684463>,
    <0.6997307, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7002454, -168.0684463>,
    <0.7020382, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7027545, -168.0684463>,
    <0.7020412, -168.0684463>,
    <0.7008534, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.6991957, -168.0684463>,
    <0.7027545, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.7009719, -168.0684463>,
    <0.6999650, -168.0684463>,
    <0.6985561, -168.0684463>,
    <0.7008534, -168.0684463>,
    <0.6991957, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6997307, -168.0684463>,
    <0.6999650, -168.0684463>,
    <0.6974280, -168.0684463>,
    <0.6971588, -168.0684463>,
    <0.7002454, -168.0684463>,
    <0.6964299, -168.0684463>,
    <0.6976489, -168.0684463>,
    <0.6991820, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6984815, -168.0684463>,
    <0.6968048, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6957349, -168.0684463>,
    <0.6964334, -168.0684463>,
    <0.6976489, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6991956, -168.0684463>,
    <0.6957349, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6974280, -168.0684463>,
    <0.6984921, -168.0684463>,
    <0.7000211, -168.0684463>,
    <0.6976489, -168.0684463>,
    <0.6991956, -168.0684463>,
    <0.7040578, -168.0684463>,
    <0.6991820, -168.0684463>,
    <0.6984921, -168.0684463>,
    <0.7009719, -168.0684463>,
    <0.7015931, -168.0684463>,
    <0.6984815, -168.0684463>,
    <0.3014112, -168.0684463>,
    <0.3031588, -168.0684463>,
    <0.3022858, -168.0684463>,
    <0.2983652, -168.0684463>,
    <0.3018350, -168.0684463>,
    <0.3026775, -168.0684463>,
    <0.3004756, -168.0684463>,
    <0.3000747, -168.0684463>,
    <0.3023330, -168.0684463>,
    <0.3040262, -168.0684463>,
    <0.3031588, -168.0684463>,
    <0.3018350, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.3023330, -168.0684463>,
    <0.3033430, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.3045235, -168.0684463>,
    <0.3041389, -168.0684463>,
    <0.3031588, -168.0684463>,
    <0.3055556, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3022858, -168.0684463>,
    <0.3045235, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3039553, -168.0684463>,
    <0.3026775, -168.0684463>,
    <0.2960801, -167.0684463>,
    <0.2903948, -167.0684463>,
    <0.2967033, -167.0684463>,
    <0.3055556, -167.0684463>,
    <0.2916667, -167.0684463>,
    <0.2939433, -167.0684463>,
    <0.3011294, -167.0684463>,
    <0.2986111, -167.0684463>,
    <0.2911102, -167.0684463>,
    <0.2856634, -167.0684463>,
    <0.2903948, -167.0684463>,
    <0.2916667, -167.0684463>,
    <0.2777778, -167.0684463>,
    <0.2828144, -167.0684463>,
    <0.2911102, -167.0684463>,
    <0.2847222, -167.0684463>,
    <0.2802961, -167.0684463>,
    <0.2861308, -167.0684463>,
    <0.2894409, -167.0684463>,
    <0.2903948, -167.0684463>,
    <0.2828144, -167.0684463>,
    <0.2878510, -167.0684463>,
    <0.2967033, -167.0684463>,
    <0.2861308, -167.0684463>,
    <0.2853327, -167.0684463>,
    <0.2922772, -167.0684463>,
    <0.2939433, -167.0684463>,
    <0.2926641, -167.0962961>,
    <0.2867056, -167.0922118>,
    <0.2893370, -167.1040945>,
    <0.3045614, -167.1040945>,
    <0.2900524, -167.0847835>,
    <0.2882240, -167.0990685>,
    <0.2960067, -167.1040945>,
    <0.2955395, -167.0920866>,
    <0.2887287, -167.0877214>,
    <0.2830784, -167.0830208>,
    <0.2867056, -167.0922118>,
    <0.2900524, -167.0847835>,
    <0.2777778, -167.0684463>,
    <0.2777778, -167.0866416>,
    <0.2887287, -167.0877214>,
    <0.2849825, -167.0780356>,
    <0.2777778, -167.0765547>,
    <0.2821340, -167.0893595>,
    <0.2828995, -167.0967606>,
    <0.2867056, -167.0922118>,
    <0.2777778, -167.0866416>,
    <0.2777778, -167.1040945>,
    <0.2893370, -167.1040945>,
    <0.2821340, -167.0893595>,
    <0.2777778, -167.1002344>,
    <0.2833781, -167.1040945>,
    <0.2882240, -167.0990685>,
    <0.2989706, -167.0868334>,
    <0.2959676, -167.0803354>,
    <0.2900561, -167.0847922>,
    <0.3045696, -167.1041136>,
    <0.3052889, -167.0780924>,
    <0.2925773, -167.0828915>,
    <0.2955449, -167.0920992>,
    <0.3050013, -167.0884963>,
    <0.3006171, -167.0792165>,
    <0.2996197, -167.0738301>,
    <0.2959676, -167.0803354>,
    <0.3052889, -167.0780924>,
    <0.3055555, -167.0684463>,
    <0.2916667, -167.0684463>,
    <0.3006171, -167.0792165>,
    <0.3054255, -167.0731512>,
    <0.2986111, -167.0684463>,
    <0.2933511, -167.0731026>,
    <0.2888670, -167.0755050>,
    <0.2959676, -167.0803354>,
    <0.2916667, -167.0684463>,
    <0.2777778, -167.0684463>,
    <0.2900561, -167.0847922>,
    <0.2933511, -167.0731026>,
    <0.2847222, -167.0684463>,
    <0.2849847, -167.0780408>,
    <0.2925773, -167.0828915>,
    <0.3052543, -167.0967745>,
    <0.3052258, -167.0922245>,
    <0.3046851, -167.1041136>,
    <0.3055524, -167.1041136>,
    <0.3055539, -167.0866464>,
    <0.3049243, -167.0988529>,
    <0.3049244, -167.1041136>,
    <0.3055527, -167.1003129>,
    <0.3054330, -167.0887022>,
    <0.3054060, -167.0813524>,
    <0.3052258, -167.0922245>,
    <0.3055539, -167.0866464>,
    <0.3055555, -167.0684463>,
    <0.3052889, -167.0780924>,
    <0.3054330, -167.0887022>,
    <0.3055548, -167.0765242>,
    <0.3054255, -167.0731512>,
    <0.3052665, -167.0830935>,
    <0.3049423, -167.0946360>,
    <0.3052258, -167.0922245>,
    <0.3052889, -167.0780924>,
    <0.3045695, -167.1041136>,
    <0.3046851, -167.1041136>,
    <0.3052665, -167.0830935>,
    <0.3050012, -167.0884963>,
    <0.3046103, -167.1041136>,
    <0.3049243, -167.0988529>,
    <0.6989769, -167.0954146>,
    <0.6971132, -167.0922118>,
    <0.6990220, -167.1040945>,
    <0.7024507, -167.1040945>,
    <0.6973217, -167.0812575>,
    <0.6982931, -167.0995570>,
    <0.7008928, -167.1040945>,
    <0.6992243, -167.0897286>,
    <0.6972533, -167.0848526>,
    <0.6958310, -167.0821150>,
    <0.6971132, -167.0922118>,
    <0.6973217, -167.0812575>,
    <0.6944445, -167.0684463>,
    <0.6944445, -167.0865447>,
    <0.6972533, -167.0848526>,
    <0.6960039, -167.0753899>,
    <0.6944445, -167.0783375>,
    <0.6958356, -167.0894987>,
    <0.6962560, -167.0967364>,
    <0.6971132, -167.0922118>,
    <0.6944445, -167.0865447>,
    <0.6944445, -167.1040945>,
    <0.6990220, -167.1040945>,
    <0.6958356, -167.0894987>,
    <0.6944445, -167.0972383>,
    <0.6968253, -167.1040945>,
    <0.6982931, -167.0995570>,
    <0.7048801, -167.0875211>,
    <0.7063730, -167.0803290>,
    <0.6973223, -167.0812575>,
    <0.7024523, -167.1040945>,
    <0.7133727, -167.0844033>,
    <0.7017504, -167.0808032>,
    <0.6992252, -167.0897286>,
    <0.7092394, -167.0918563>,
    <0.7101631, -167.0825351>,
    <0.7125753, -167.0754062>,
    <0.7063730, -167.0803290>,
    <0.7133727, -167.0844033>,
    <0.7222222, -167.0684463>,
    <0.7083333, -167.0684463>,
    <0.7101631, -167.0825351>,
    <0.7169681, -167.0779203>,
    <0.7152778, -167.0684463>,
    <0.7075517, -167.0731842>,
    <0.7016183, -167.0746198>,
    <0.7063730, -167.0803290>,
    <0.7083333, -167.0684463>,
    <0.6944445, -167.0684463>,
    <0.6973223, -167.0812575>,
    <0.7075517, -167.0731842>,
    <0.7013889, -167.0684463>,
    <0.6960042, -167.0753899>,
    <0.7017504, -167.0808032>,
    <0.6941538, -167.0967515>,
    <0.6941158, -167.0922245>,
    <0.6936104, -167.1041136>,
    <0.6944445, -167.1041136>,
    <0.6944445, -167.0865543>,
    <0.6938297, -167.0989551>,
    <0.6938776, -167.1041136>,
    <0.6944445, -167.0972537>,
    <0.6943008, -167.0890331>,
    <0.6942871, -167.0816387>,
    <0.6941158, -167.0922245>,
    <0.6944445, -167.0865543>,
    <0.6944445, -167.0684463>,
    <0.6941436, -167.0793296>,
    <0.6943008, -167.0890331>,
    <0.6944445, -167.0783428>,
    <0.6942967, -167.0737901>,
    <0.6941345, -167.0835546>,
    <0.6938321, -167.0949453>,
    <0.6941158, -167.0922245>,
    <0.6941436, -167.0793296>,
    <0.6934584, -167.1041136>,
    <0.6936104, -167.1041136>,
    <0.6941345, -167.0835546>,
    <0.6938186, -167.0910865>,
    <0.6935133, -167.1041136>,
    <0.6938297, -167.0989551>,
    <0.3091838, -168.0684463>,
    <0.3076475, -168.0684463>,
    <0.3082560, -168.0684463>,
    <0.3118314, -168.0684463>,
    <0.3090003, -168.0684463>,
    <0.3080486, -168.0684463>,
    <0.3100239, -168.0684463>,
    <0.3105083, -168.0684463>,
    <0.3084356, -168.0684463>,
    <0.3069397, -168.0684463>,
    <0.3076475, -168.0684463>,
    <0.3090003, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3084356, -168.0684463>,
    <0.3073234, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3064978, -168.0684463>,
    <0.3067537, -168.0684463>,
    <0.3076475, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3082560, -168.0684463>,
    <0.3064978, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3070548, -168.0684463>,
    <0.3080486, -168.0684463>,
    <0.3175505, -168.0684463>,
    <0.3137023, -168.0684463>,
    <0.3146377, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3181420, -168.0684463>,
    <0.3142658, -168.0684463>,
    <0.3191788, -168.0684463>,
    <0.3209720, -168.0684463>,
    <0.3162347, -168.0684463>,
    <0.3129829, -168.0684463>,
    <0.3137023, -168.0684463>,
    <0.3181420, -168.0684463>,
    <0.3118314, -168.0684463>,
    <0.3082560, -168.0684463>,
    <0.3162347, -168.0684463>,
    <0.3151447, -168.0684463>,
    <0.3100239, -168.0684463>,
    <0.3109136, -168.0684463>,
    <0.3105379, -168.0684463>,
    <0.3137023, -168.0684463>,
    <0.3082560, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3146377, -168.0684463>,
    <0.3109136, -168.0684463>,
    <0.3070548, -168.0684463>,
    <0.3100966, -168.0684463>,
    <0.3142658, -168.0684463>,
    <0.3199357, -168.0684463>,
    <0.3176651, -168.0684463>,
    <0.3146377, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3158938, -168.0684463>,
    <0.3191788, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3209150, -168.0684463>,
    <0.3196598, -168.0684463>,
    <0.3176651, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3135342, -168.0684463>,
    <0.3209150, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3180799, -168.0684463>,
    <0.3152758, -168.0684463>,
    <0.3128482, -168.0684463>,
    <0.3176651, -168.0684463>,
    <0.3135342, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3146377, -168.0684463>,
    <0.3152758, -168.0684463>,
    <0.3094338, -168.0684463>,
    <0.3100966, -168.0684463>,
    <0.3158938, -168.0684463>,
    <0.6801995, -168.0684463>,
    <0.6823349, -168.0684463>,
    <0.6859031, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6843985, -168.0684463>,
    <0.6824311, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6790796, -168.0684463>,
    <0.6802061, -168.0684463>,
    <0.6823349, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6859291, -168.0684463>,
    <0.6790796, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6813496, -168.0684463>,
    <0.6844273, -168.0684463>,
    <0.6871529, -168.0684463>,
    <0.6823349, -168.0684463>,
    <0.6859291, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6859031, -168.0684463>,
    <0.6844273, -168.0684463>,
    <0.6902503, -168.0684463>,
    <0.6892922, -168.0684463>,
    <0.6843985, -168.0684463>,
    <0.6841255, -168.0684463>,
    <0.6883897, -168.0684463>,
    <0.6859292, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6859031, -168.0684463>,
    <0.6869850, -168.0684463>,
    <0.6813496, -168.0684463>,
    <0.6824311, -168.0684463>,
    <0.6869576, -168.0684463>,
    <0.6907954, -168.0684463>,
    <0.6883897, -168.0684463>,
    <0.6859031, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6869576, -168.0684463>,
    <0.6892922, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6916556, -168.0684463>,
    <0.6908019, -168.0684463>,
    <0.6883897, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6859292, -168.0684463>,
    <0.6916556, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6902503, -168.0684463>,
    <0.6869850, -168.0684463>,
    <0.6828342, -167.0962004>,
    <0.6875283, -167.0922118>,
    <0.6855996, -167.0844007>,
    <0.6746817, -167.1040945>,
    <0.6835273, -167.1040945>,
    <0.6862706, -167.0871182>,
    <0.6814606, -167.0918666>,
    <0.6792361, -167.1040945>,
    <0.6851730, -167.0992069>,
    <0.6896645, -167.0949311>,
    <0.6875283, -167.0922118>,
    <0.6835273, -167.1040945>,
    <0.6934587, -167.1040945>,
    <0.6941437, -167.0793237>,
    <0.6851730, -167.0992069>,
    <0.6880010, -167.1040945>,
    <0.6938188, -167.0910744>,
    <0.6908447, -167.0857508>,
    <0.6904290, -167.0810956>,
    <0.6875283, -167.0922118>,
    <0.6941437, -167.0793237>,
    <0.6944445, -167.0684463>,
    <0.6855996, -167.0844007>,
    <0.6908447, -167.0857508>,
    <0.6942968, -167.0737872>,
    <0.6891939, -167.0779173>,
    <0.6862706, -167.0871182>,
    <0.3270216, -168.0684463>,
    <0.3277320, -168.0684463>,
    <0.3296127, -168.0684463>,
    <0.3261429, -168.0684463>,
    <0.3245988, -168.0684463>,
    <0.3286896, -168.0684463>,
    <0.3278525, -168.0684463>,
    <0.3253630, -168.0684463>,
    <0.3259555, -168.0684463>,
    <0.3260475, -168.0684463>,
    <0.3277320, -168.0684463>,
    <0.3245988, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3281392, -168.0684463>,
    <0.3259555, -168.0684463>,
    <0.3240761, -168.0684463>,
    <0.3260763, -168.0684463>,
    <0.3279479, -168.0684463>,
    <0.3297043, -168.0684463>,
    <0.3277320, -168.0684463>,
    <0.3281392, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3296127, -168.0684463>,
    <0.3279479, -168.0684463>,
    <0.3301367, -168.0684463>,
    <0.3311207, -168.0684463>,
    <0.3286896, -168.0684463>,
    <0.3256259, -168.0684463>,
    <0.3269244, -168.0684463>,
    <0.3281392, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3274466, -168.0684463>,
    <0.3260763, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3250063, -168.0684463>,
    <0.3257227, -168.0684463>,
    <0.3269244, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3285266, -168.0684463>,
    <0.3250063, -168.0684463>,
    <0.3237199, -168.0684463>,
    <0.3261233, -168.0684463>,
    <0.3277626, -168.0684463>,
    <0.3292309, -168.0684463>,
    <0.3269244, -168.0684463>,
    <0.3285266, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3281392, -168.0684463>,
    <0.3277626, -168.0684463>,
    <0.3309300, -168.0684463>,
    <0.3301367, -168.0684463>,
    <0.3274466, -168.0684463>,
    <0.6743972, -168.0684463>,
    <0.6730756, -168.0684463>,
    <0.6719530, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6724766, -168.0684463>,
    <0.6742605, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6749692, -168.0684463>,
    <0.6744263, -168.0684463>,
    <0.6730756, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6720692, -168.0684463>,
    <0.6749692, -168.0684463>,
    <0.6762801, -168.0684463>,
    <0.6738376, -168.0684463>,
    <0.6725393, -168.0684463>,
    <0.6709411, -168.0684463>,
    <0.6730756, -168.0684463>,
    <0.6720692, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6719530, -168.0684463>,
    <0.6725393, -168.0684463>,
    <0.6701694, -168.0684463>,
    <0.6693811, -168.0684463>,
    <0.6724766, -168.0684463>,
    <0.3291889, -168.0684463>,
    <0.3309365, -168.0684463>,
    <0.3300636, -168.0684463>,
    <0.3261429, -168.0684463>,
    <0.3296127, -168.0684463>,
    <0.3304552, -168.0684463>,
    <0.3282533, -168.0684463>,
    <0.3278525, -168.0684463>,
    <0.3301108, -168.0684463>,
    <0.3318040, -168.0684463>,
    <0.3309365, -168.0684463>,
    <0.3296127, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3301108, -168.0684463>,
    <0.3311207, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3323013, -168.0684463>,
    <0.3319167, -168.0684463>,
    <0.3309365, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3300636, -168.0684463>,
    <0.3323013, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3317331, -168.0684463>,
    <0.3304552, -168.0684463>,
    <0.6687894, -168.0684463>,
    <0.6698711, -168.0684463>,
    <0.6719530, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6710450, -168.0684463>,
    <0.6693811, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6680795, -168.0684463>,
    <0.6688184, -168.0684463>,
    <0.6698711, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6720692, -168.0684463>,
    <0.6680795, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6701693, -168.0684463>,
    <0.6711142, -168.0684463>,
    <0.6725433, -168.0684463>,
    <0.6698711, -168.0684463>,
    <0.6720692, -168.0684463>,
    <0.6762800, -168.0684463>,
    <0.6719530, -168.0684463>,
    <0.6711142, -168.0684463>,
    <0.6738376, -168.0684463>,
    <0.6742605, -168.0684463>,
    <0.6710450, -168.0684463>,
    <0.3238578, -167.0684463>,
    <0.3181725, -167.0684463>,
    <0.3244810, -167.0684463>,
    <0.3333333, -167.0684463>,
    <0.3194444, -167.0684463>,
    <0.3217210, -167.0684463>,
    <0.3289072, -167.0684463>,
    <0.3263889, -167.0684463>,
    <0.3188880, -167.0684463>,
    <0.3134412, -167.0684463>,
    <0.3181725, -167.0684463>,
    <0.3194444, -167.0684463>,
    <0.3055555, -167.0684463>,
    <0.3105921, -167.0684463>,
    <0.3188880, -167.0684463>,
    <0.3125000, -167.0684463>,
    <0.3080738, -167.0684463>,
    <0.3139085, -167.0684463>,
    <0.3172186, -167.0684463>,
    <0.3181725, -167.0684463>,
    <0.3105921, -167.0684463>,
    <0.3156287, -167.0684463>,
    <0.3244810, -167.0684463>,
    <0.3139085, -167.0684463>,
    <0.3131104, -167.0684463>,
    <0.3200548, -167.0684463>,
    <0.3217210, -167.0684463>,
    <0.3369616, -168.0684463>,
    <0.3354253, -168.0684463>,
    <0.3360338, -168.0684463>,
    <0.3396092, -168.0684463>,
    <0.3367780, -168.0684463>,
    <0.3358264, -168.0684463>,
    <0.3378017, -168.0684463>,
    <0.3382861, -168.0684463>,
    <0.3362133, -168.0684463>,
    <0.3347175, -168.0684463>,
    <0.3354253, -168.0684463>,
    <0.3367780, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3362133, -168.0684463>,
    <0.3351011, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3342756, -168.0684463>,
    <0.3345314, -168.0684463>,
    <0.3354253, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3360338, -168.0684463>,
    <0.3342756, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3348326, -168.0684463>,
    <0.3358264, -168.0684463>,
    <0.3204463, -167.0962959>,
    <0.3144862, -167.0922118>,
    <0.3171181, -167.1040945>,
    <0.3323474, -167.1040945>,
    <0.3178333, -167.0847827>,
    <0.3160050, -167.0990688>,
    <0.3237899, -167.1040945>,
    <0.3233218, -167.0920854>,
    <0.3165100, -167.0877198>,
    <0.3108577, -167.0830193>,
    <0.3144862, -167.0922118>,
    <0.3178333, -167.0847827>,
    <0.3055555, -167.0684463>,
    <0.3055555, -167.0866366>,
    <0.3165100, -167.0877198>,
    <0.3127621, -167.0780351>,
    <0.3055555, -167.0765198>,
    <0.3099131, -167.0893570>,
    <0.3106788, -167.0967593>,
    <0.3144862, -167.0922118>,
    <0.3055555, -167.0866366>,
    <0.3055555, -167.1040945>,
    <0.3171181, -167.1040945>,
    <0.3099131, -167.0893570>,
    <0.3055555, -167.1002959>,
    <0.3111574, -167.1040945>,
    <0.3160050, -167.0990688>,
    <0.3267487, -167.0868065>,
    <0.3237454, -167.0803290>,
    <0.3178333, -167.0847827>,
    <0.3323474, -167.1040945>,
    <0.3330686, -167.0780197>,
    <0.3203550, -167.0828831>,
    <0.3233218, -167.0920854>,
    <0.3327814, -167.0884028>,
    <0.3283957, -167.0791772>,
    <0.3273979, -167.0738103>,
    <0.3237454, -167.0803290>,
    <0.3330686, -167.0780197>,
    <0.3333333, -167.0684463>,
    <0.3194444, -167.0684463>,
    <0.3283957, -167.0791772>,
    <0.3332042, -167.0731150>,
    <0.3263889, -167.0684463>,
    <0.3211286, -167.0730993>,
    <0.3166447, -167.0755011>,
    <0.3237454, -167.0803290>,
    <0.3194444, -167.0684463>,
    <0.3055555, -167.0684463>,
    <0.3178333, -167.0847827>,
    <0.3211286, -167.0730993>,
    <0.3125000, -167.0684463>,
    <0.3127621, -167.0780351>,
    <0.3203550, -167.0828831>,
    <0.3330325, -167.0967598>,
    <0.3330040, -167.0922118>,
    <0.3324630, -167.1040945>,
    <0.3333309, -167.1040945>,
    <0.3333321, -167.0866386>,
    <0.3327022, -167.0988410>,
    <0.3327021, -167.1040945>,
    <0.3333312, -167.1002963>,
    <0.3332112, -167.0886929>,
    <0.3331845, -167.0813291>,
    <0.3330040, -167.0922118>,
    <0.3333321, -167.0866386>,
    <0.3333333, -167.0684463>,
    <0.3330686, -167.0780197>,
    <0.3332112, -167.0886929>,
    <0.3333328, -167.0765218>,
    <0.3332042, -167.0731150>,
    <0.3330457, -167.0830417>,
    <0.3327208, -167.0946051>,
    <0.3330040, -167.0922118>,
    <0.3330686, -167.0780197>,
    <0.3323476, -167.1040945>,
    <0.3324630, -167.1040945>,
    <0.3330457, -167.0830417>,
    <0.3327815, -167.0884028>,
    <0.3323884, -167.1040945>,
    <0.3327022, -167.0988410>,
    <0.6684798, -167.0966571>,
    <0.6693367, -167.0922118>,
    <0.6666679, -167.0862277>,
    <0.6666691, -167.1040945>,
    <0.6712457, -167.1040945>,
    <0.6680526, -167.0893326>,
    <0.6666686, -167.0971218>,
    <0.6690493, -167.1040945>,
    <0.6705241, -167.0996027>,
    <0.6711775, -167.0953132>,
    <0.6693367, -167.0922118>,
    <0.6712457, -167.1040945>,
    <0.6746744, -167.1040945>,
    <0.6694534, -167.0808520>,
    <0.6705241, -167.0996027>,
    <0.6731164, -167.1040945>,
    <0.6713812, -167.0894342>,
    <0.6694148, -167.0846065>,
    <0.6680312, -167.0819345>,
    <0.6693367, -167.0922118>,
    <0.6694534, -167.0808520>,
    <0.6666667, -167.0684463>,
    <0.6666679, -167.0862277>,
    <0.6694148, -167.0846065>,
    <0.6681108, -167.0748751>,
    <0.6666673, -167.0781463>,
    <0.6680526, -167.0893326>,
    <0.6770788, -167.0874191>,
    <0.6785945, -167.0803290>,
    <0.6694527, -167.0808520>,
    <0.6746724, -167.1040945>,
    <0.6855954, -167.0844007>,
    <0.6739231, -167.0805963>,
    <0.6713800, -167.0894342>,
    <0.6814545, -167.0918666>,
    <0.6823898, -167.0825364>,
    <0.6847975, -167.0754056>,
    <0.6785945, -167.0803290>,
    <0.6855954, -167.0844007>,
    <0.6944445, -167.0684463>,
    <0.6805556, -167.0684463>,
    <0.6823898, -167.0825364>,
    <0.6891914, -167.0779173>,
    <0.6875000, -167.0684463>,
    <0.6797768, -167.0731653>,
    <0.6738174, -167.0745184>,
    <0.6785945, -167.0803290>,
    <0.6805556, -167.0684463>,
    <0.6666667, -167.0684463>,
    <0.6694527, -167.0808520>,
    <0.6797768, -167.0731653>,
    <0.6736111, -167.0684463>,
    <0.6681104, -167.0748751>,
    <0.6739231, -167.0805963>,
    <0.6663670, -167.0966571>,
    <0.6663380, -167.0922118>,
    <0.6657966, -167.1040945>,
    <0.6666667, -167.1040945>,
    <0.6666667, -167.0862277>,
    <0.6660369, -167.0988217>,
    <0.6660366, -167.1040945>,
    <0.6666667, -167.0971218>,
    <0.6665130, -167.0890252>,
    <0.6665190, -167.0812011>,
    <0.6663380, -167.0922118>,
    <0.6666667, -167.0862277>,
    <0.6666667, -167.0684463>,
    <0.6664047, -167.0779186>,
    <0.6665130, -167.0890252>,
    <0.6666667, -167.0781463>,
    <0.6665470, -167.0727742>,
    <0.6663835, -167.0824556>,
    <0.6660550, -167.0945798>,
    <0.6663380, -167.0922118>,
    <0.6664047, -167.0779186>,
    <0.6656807, -167.1040945>,
    <0.6657966, -167.1040945>,
    <0.6663835, -167.0824556>,
    <0.6661173, -167.0883104>,
    <0.6657217, -167.1040945>,
    <0.6660369, -167.0988217>,
    <0.6611173, -168.0684463>,
    <0.6634622, -168.0684463>,
    <0.6619291, -168.0684463>,
    <0.6570532, -168.0684463>,
    <0.6620246, -168.0684463>,
    <0.6625993, -168.0684463>,
    <0.6595180, -168.0684463>,
    <0.6595220, -168.0684463>,
    <0.6625327, -168.0684463>,
    <0.6647050, -168.0684463>,
    <0.6634622, -168.0684463>,
    <0.6620246, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6625327, -168.0684463>,
    <0.6640094, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6652622, -168.0684463>,
    <0.6646812, -168.0684463>,
    <0.6634622, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6619291, -168.0684463>,
    <0.6652622, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6643063, -168.0684463>,
    <0.6625993, -168.0684463>,
    <0.3453283, -168.0684463>,
    <0.3414801, -168.0684463>,
    <0.3424155, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3459198, -168.0684463>,
    <0.3420436, -168.0684463>,
    <0.3469567, -168.0684463>,
    <0.3487498, -168.0684463>,
    <0.3440125, -168.0684463>,
    <0.3407607, -168.0684463>,
    <0.3414801, -168.0684463>,
    <0.3459198, -168.0684463>,
    <0.3396092, -168.0684463>,
    <0.3360338, -168.0684463>,
    <0.3440125, -168.0684463>,
    <0.3429225, -168.0684463>,
    <0.3378017, -168.0684463>,
    <0.3386914, -168.0684463>,
    <0.3383157, -168.0684463>,
    <0.3414801, -168.0684463>,
    <0.3360338, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3424155, -168.0684463>,
    <0.3386914, -168.0684463>,
    <0.3348326, -168.0684463>,
    <0.3378744, -168.0684463>,
    <0.3420436, -168.0684463>,
    <0.6573720, -168.0684463>,
    <0.6574074, -168.0684463>,
    <0.6620246, -168.0684463>,
    <0.6570532, -168.0684463>,
    <0.6530031, -168.0684463>,
    <0.6597791, -168.0684463>,
    <0.6595220, -168.0684463>,
    <0.6550694, -168.0684463>,
    <0.6549011, -168.0684463>,
    <0.6544038, -168.0684463>,
    <0.6574074, -168.0684463>,
    <0.6530031, -168.0684463>,
    <0.6485023, -168.0684463>,
    <0.6587026, -168.0684463>,
    <0.6549011, -168.0684463>,
    <0.6508276, -168.0684463>,
    <0.6551860, -168.0684463>,
    <0.6583835, -168.0684463>,
    <0.6612003, -168.0684463>,
    <0.6574074, -168.0684463>,
    <0.6587026, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6620246, -168.0684463>,
    <0.6583835, -168.0684463>,
    <0.6618305, -168.0684463>,
    <0.6640094, -168.0684463>,
    <0.6597791, -168.0684463>,
    <0.6525661, -168.0684463>,
    <0.6545571, -168.0684463>,
    <0.6587026, -168.0684463>,
    <0.6485023, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6566735, -168.0684463>,
    <0.6551860, -168.0684463>,
    <0.6485023, -168.0684463>,
    <0.6512688, -168.0684463>,
    <0.6524282, -168.0684463>,
    <0.6545571, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6581513, -168.0684463>,
    <0.6512688, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6535717, -168.0684463>,
    <0.6565978, -168.0684463>,
    <0.6595194, -168.0684463>,
    <0.6545571, -168.0684463>,
    <0.6581513, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6587026, -168.0684463>,
    <0.6565978, -168.0684463>,
    <0.6624725, -168.0684463>,
    <0.6618305, -168.0684463>,
    <0.6566735, -168.0684463>,
    <0.3477135, -168.0684463>,
    <0.3454430, -168.0684463>,
    <0.3424155, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3436871, -168.0684463>,
    <0.3469567, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3486929, -168.0684463>,
    <0.3475718, -168.0684463>,
    <0.3454430, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3418488, -168.0684463>,
    <0.3486929, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3464284, -168.0684463>,
    <0.3433709, -168.0684463>,
    <0.3407602, -168.0684463>,
    <0.3454430, -168.0684463>,
    <0.3418488, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3424155, -168.0684463>,
    <0.3433709, -168.0684463>,
    <0.3375276, -168.0684463>,
    <0.3378744, -168.0684463>,
    <0.3436871, -168.0684463>,
    <0.3533792, -168.0684463>,
    <0.3547022, -168.0684463>,
    <0.3558191, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3553139, -168.0684463>,
    <0.3537900, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3527963, -168.0684463>,
    <0.3535005, -168.0684463>,
    <0.3547022, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3563044, -168.0684463>,
    <0.3527963, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3539011, -168.0684463>,
    <0.3555619, -168.0684463>,
    <0.3569842, -168.0684463>,
    <0.3547022, -168.0684463>,
    <0.3563044, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3558191, -168.0684463>,
    <0.3555619, -168.0684463>,
    <0.3587078, -168.0684463>,
    <0.3580126, -168.0684463>,
    <0.3553139, -168.0684463>,
    <0.6429690, -168.0684463>,
    <0.6432648, -168.0684463>,
    <0.6457666, -168.0684463>,
    <0.6424032, -168.0684463>,
    <0.6404416, -168.0684463>,
    <0.6447025, -168.0684463>,
    <0.6441827, -168.0684463>,
    <0.6414021, -168.0684463>,
    <0.6418191, -168.0684463>,
    <0.6415365, -168.0684463>,
    <0.6432648, -168.0684463>,
    <0.6404416, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6435509, -168.0684463>,
    <0.6418191, -168.0684463>,
    <0.6398121, -168.0684463>,
    <0.6417663, -168.0684463>,
    <0.6434545, -168.0684463>,
    <0.6452711, -168.0684463>,
    <0.6432648, -168.0684463>,
    <0.6435509, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6457666, -168.0684463>,
    <0.6434545, -168.0684463>,
    <0.6453690, -168.0684463>,
    <0.6471974, -168.0684463>,
    <0.6447025, -168.0684463>,
    <0.6466194, -168.0684463>,
    <0.6452978, -168.0684463>,
    <0.6441752, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6446991, -168.0684463>,
    <0.6464827, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6472060, -168.0684463>,
    <0.6464633, -168.0684463>,
    <0.6452978, -168.0684463>,
    <0.6485022, -168.0684463>,
    <0.6485023, -168.0684463>,
    <0.6435509, -168.0684463>,
    <0.6472060, -168.0684463>,
    <0.6485023, -168.0684463>,
    <0.6453690, -168.0684463>,
    <0.6444493, -168.0684463>,
    <0.6429782, -168.0684463>,
    <0.6452978, -168.0684463>,
    <0.6435509, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6441752, -168.0684463>,
    <0.6444493, -168.0684463>,
    <0.6417663, -168.0684463>,
    <0.6416033, -168.0684463>,
    <0.6446991, -168.0684463>,
    <0.3552622, -168.0684463>,
    <0.3579067, -168.0684463>,
    <0.3558251, -168.0684463>,
    <0.3514978, -168.0684463>,
    <0.3558191, -168.0684463>,
    <0.3567640, -168.0684463>,
    <0.3535175, -168.0684463>,
    <0.3537900, -168.0684463>,
    <0.3567738, -168.0684463>,
    <0.3589870, -168.0684463>,
    <0.3579067, -168.0684463>,
    <0.3558191, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3567738, -168.0684463>,
    <0.3580127, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3598045, -168.0684463>,
    <0.3589885, -168.0684463>,
    <0.3579067, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3558251, -168.0684463>,
    <0.3598045, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3583968, -168.0684463>,
    <0.3567640, -168.0684463>,
    <0.6396578, -168.0684463>,
    <0.6400603, -168.0684463>,
    <0.6407929, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6404443, -168.0684463>,
    <0.6398621, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6393081, -168.0684463>,
    <0.6395699, -168.0684463>,
    <0.6400603, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6404416, -168.0684463>,
    <0.6393081, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6398121, -168.0684463>,
    <0.6402853, -168.0684463>,
    <0.6409245, -168.0684463>,
    <0.6400603, -168.0684463>,
    <0.6404416, -168.0684463>,
    <0.6424032, -168.0684463>,
    <0.6407929, -168.0684463>,
    <0.6402853, -168.0684463>,
    <0.6414022, -168.0684463>,
    <0.6416437, -168.0684463>,
    <0.6404443, -168.0684463>,
    <0.3516356, -167.0684463>,
    <0.3459503, -167.0684463>,
    <0.3522587, -167.0684463>,
    <0.3611111, -167.0684463>,
    <0.3472222, -167.0684463>,
    <0.3494988, -167.0684463>,
    <0.3566849, -167.0684463>,
    <0.3541667, -167.0684463>,
    <0.3466657, -167.0684463>,
    <0.3412189, -167.0684463>,
    <0.3459503, -167.0684463>,
    <0.3472222, -167.0684463>,
    <0.3333333, -167.0684463>,
    <0.3383698, -167.0684463>,
    <0.3466657, -167.0684463>,
    <0.3402778, -167.0684463>,
    <0.3358516, -167.0684463>,
    <0.3416863, -167.0684463>,
    <0.3449963, -167.0684463>,
    <0.3459503, -167.0684463>,
    <0.3383698, -167.0684463>,
    <0.3434063, -167.0684463>,
    <0.3522587, -167.0684463>,
    <0.3416863, -167.0684463>,
    <0.3408881, -167.0684463>,
    <0.3478325, -167.0684463>,
    <0.3494988, -167.0684463>,
    <0.3482250, -167.0962969>,
    <0.3422640, -167.0922118>,
    <0.3448962, -167.1040945>,
    <0.3601254, -167.1040945>,
    <0.3456143, -167.0847868>,
    <0.3437828, -167.0990684>,
    <0.3515680, -167.1040945>,
    <0.3511030, -167.0920898>,
    <0.3442897, -167.0877223>,
    <0.3386362, -167.0830209>,
    <0.3422640, -167.0922118>,
    <0.3456143, -167.0847868>,
    <0.3333333, -167.0684463>,
    <0.3333333, -167.0866386>,
    <0.3442897, -167.0877223>,
    <0.3405423, -167.0780382>,
    <0.3333333, -167.0765218>,
    <0.3376909, -167.0893579>,
    <0.3384567, -167.0967598>,
    <0.3422640, -167.0922118>,
    <0.3333333, -167.0866386>,
    <0.3333333, -167.1040945>,
    <0.3448962, -167.1040945>,
    <0.3376909, -167.0893579>,
    <0.3333333, -167.1002963>,
    <0.3389354, -167.1040945>,
    <0.3437828, -167.0990684>,
    <0.3545263, -167.0868463>,
    <0.3515233, -167.0803290>,
    <0.3456143, -167.0847868>,
    <0.3601254, -167.1040945>,
    <0.3608421, -167.0781749>,
    <0.3481346, -167.0828854>,
    <0.3511030, -167.0920898>,
    <0.3605564, -167.0885060>,
    <0.3561716, -167.0792545>,
    <0.3551747, -167.0738491>,
    <0.3515233, -167.0803290>,
    <0.3608421, -167.0781749>,
    <0.3611111, -167.0684463>,
    <0.3472222, -167.0684463>,
    <0.3561716, -167.0792545>,
    <0.3609797, -167.0732000>,
    <0.3541667, -167.0684463>,
    <0.3489068, -167.0731005>,
    <0.3444233, -167.0755021>,
    <0.3515233, -167.0803290>,
    <0.3472222, -167.0684463>,
    <0.3333333, -167.0684463>,
    <0.3456143, -167.0847868>,
    <0.3489068, -167.0731005>,
    <0.3402778, -167.0684463>,
    <0.3405423, -167.0780382>,
    <0.3481346, -167.0828854>,
    <0.3608115, -167.0967595>,
    <0.3607825, -167.0922118>,
    <0.3602413, -167.1040945>,
    <0.3611111, -167.1040945>,
    <0.3611111, -167.0866373>,
    <0.3604806, -167.0988412>,
    <0.3604812, -167.1040945>,
    <0.3611111, -167.1002349>,
    <0.3609899, -167.0886930>,
    <0.3609617, -167.0813676>,
    <0.3607825, -167.0922118>,
    <0.3611111, -167.0866373>,
    <0.3611111, -167.0684463>,
    <0.3608421, -167.0781749>,
    <0.3609899, -167.0886930>,
    <0.3611111, -167.0765496>,
    <0.3609797, -167.0732000>,
    <0.3608210, -167.0831444>,
    <0.3604978, -167.0946439>,
    <0.3607825, -167.0922118>,
    <0.3608421, -167.0781749>,
    <0.3601254, -167.1040945>,
    <0.3602413, -167.1040945>,
    <0.3608210, -167.0831444>,
    <0.3605564, -167.0885060>,
    <0.3601663, -167.1040945>,
    <0.3604806, -167.0988412>,
    <0.6538764, -167.0964246>,
    <0.6478195, -167.0922118>,
    <0.6504516, -167.1040945>,
    <0.6656807, -167.1040945>,
    <0.6515536, -167.0852975>,
    <0.6493305, -167.0990334>,
    <0.6571234, -167.1040945>,
    <0.6569127, -167.0924281>,
    <0.6500970, -167.0879946>,
    <0.6442877, -167.0831603>,
    <0.6478195, -167.0922118>,
    <0.6515536, -167.0852975>,
    <0.6388889, -167.0684463>,
    <0.6388889, -167.0866858>,
    <0.6500970, -167.0879946>,
    <0.6466296, -167.0787458>,
    <0.6388889, -167.0767454>,
    <0.6432428, -167.0893799>,
    <0.6440122, -167.0967717>,
    <0.6478195, -167.0922118>,
    <0.6388889, -167.0866858>,
    <0.6388889, -167.1040945>,
    <0.6504516, -167.1040945>,
    <0.6432428, -167.0893799>,
    <0.6388889, -167.1003718>,
    <0.6444909, -167.1040945>,
    <0.6493305, -167.0990334>,
    <0.6601794, -167.0869099>,
    <0.6570788, -167.0803290>,
    <0.6515536, -167.0852975>,
    <0.6656807, -167.1040945>,
    <0.6664047, -167.0779186>,
    <0.6539261, -167.0831641>,
    <0.6569127, -167.0924281>,
    <0.6661173, -167.0883104>,
    <0.6616903, -167.0791371>,
    <0.6607320, -167.0737850>,
    <0.6570788, -167.0803290>,
    <0.6664047, -167.0779186>,
    <0.6666667, -167.0684463>,
    <0.6527778, -167.0684463>,
    <0.6616903, -167.0791371>,
    <0.6665470, -167.0727742>,
    <0.6597222, -167.0684463>,
    <0.6544460, -167.0730552>,
    <0.6500748, -167.0756298>,
    <0.6570788, -167.0803290>,
    <0.6527778, -167.0684463>,
    <0.6388889, -167.0684463>,
    <0.6515536, -167.0852975>,
    <0.6544460, -167.0730552>,
    <0.6458333, -167.0684463>,
    <0.6466296, -167.0787458>,
    <0.6539261, -167.0831641>,
    <0.6385966, -167.0967868>,
    <0.6385591, -167.0922245>,
    <0.6380541, -167.1041136>,
    <0.6388857, -167.1041136>,
    <0.6388873, -167.0866956>,
    <0.6382838, -167.0987071>,
    <0.6383204, -167.1041136>,
    <0.6388861, -167.1003889>,
    <0.6387727, -167.0886266>,
    <0.6387329, -167.0815980>,
    <0.6385591, -167.0922245>,
    <0.6388873, -167.0866956>,
    <0.6388889, -167.0684463>,
    <0.6385964, -167.0790257>,
    <0.6387727, -167.0886266>,
    <0.6388882, -167.0767499>,
    <0.6387342, -167.0740422>,
    <0.6385825, -167.0839525>,
    <0.6382781, -167.0948693>,
    <0.6385591, -167.0922245>,
    <0.6385964, -167.0790257>,
    <0.6379027, -167.1041136>,
    <0.6380541, -167.1041136>,
    <0.6385825, -167.0839525>,
    <0.6382753, -167.0906372>,
    <0.6379573, -167.1041136>,
    <0.6382838, -167.0987071>,
    <0.3714198, -168.0684463>,
    <0.3671659, -168.0684463>,
    <0.3696265, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3696116, -168.0684463>,
    <0.3685731, -168.0684463>,
    <0.3742061, -168.0684463>,
    <0.3735995, -168.0684463>,
    <0.3685780, -168.0684463>,
    <0.3647499, -168.0684463>,
    <0.3671659, -168.0684463>,
    <0.3696116, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3685780, -168.0684463>,
    <0.3657829, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3639027, -168.0684463>,
    <0.3647537, -168.0684463>,
    <0.3671659, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3696265, -168.0684463>,
    <0.3639027, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3653054, -168.0684463>,
    <0.3685731, -168.0684463>,
    <0.3753458, -168.0684463>,
    <0.3732206, -168.0684463>,
    <0.3696116, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3711210, -168.0684463>,
    <0.3735995, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3764768, -168.0684463>,
    <0.3752153, -168.0684463>,
    <0.3732206, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3690898, -168.0684463>,
    <0.3764768, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3736354, -168.0684463>,
    <0.3708107, -168.0684463>,
    <0.3682583, -168.0684463>,
    <0.3732206, -168.0684463>,
    <0.3690898, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3696116, -168.0684463>,
    <0.3708107, -168.0684463>,
    <0.3649894, -168.0684463>,
    <0.3657829, -168.0684463>,
    <0.3711210, -168.0684463>,
    <0.6245825, -168.0684463>,
    <0.6267793, -168.0684463>,
    <0.6301017, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6286848, -168.0684463>,
    <0.6267147, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6235335, -168.0684463>,
    <0.6246505, -168.0684463>,
    <0.6267793, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6303736, -168.0684463>,
    <0.6235335, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6257940, -168.0684463>,
    <0.6288814, -168.0684463>,
    <0.6315359, -168.0684463>,
    <0.6267793, -168.0684463>,
    <0.6303736, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6301017, -168.0684463>,
    <0.6288814, -168.0684463>,
    <0.6346947, -168.0684463>,
    <0.6334133, -168.0684463>,
    <0.6286848, -168.0684463>,
    <0.6285085, -168.0684463>,
    <0.6328341, -168.0684463>,
    <0.6303736, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6301017, -168.0684463>,
    <0.6314135, -168.0684463>,
    <0.6257940, -168.0684463>,
    <0.6267147, -168.0684463>,
    <0.6312197, -168.0684463>,
    <0.6351784, -168.0684463>,
    <0.6328341, -168.0684463>,
    <0.6301017, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6312197, -168.0684463>,
    <0.6334133, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6359673, -168.0684463>,
    <0.6352464, -168.0684463>,
    <0.6328341, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6303736, -168.0684463>,
    <0.6359673, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6346947, -168.0684463>,
    <0.6314135, -168.0684463>,
    <0.3825771, -168.0684463>,
    <0.3832876, -168.0684463>,
    <0.3851683, -168.0684463>,
    <0.3816984, -168.0684463>,
    <0.3801543, -168.0684463>,
    <0.3842451, -168.0684463>,
    <0.3834080, -168.0684463>,
    <0.3809185, -168.0684463>,
    <0.3815110, -168.0684463>,
    <0.3816030, -168.0684463>,
    <0.3832876, -168.0684463>,
    <0.3801543, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3836948, -168.0684463>,
    <0.3815110, -168.0684463>,
    <0.3796316, -168.0684463>,
    <0.3816314, -168.0684463>,
    <0.3835042, -168.0684463>,
    <0.3852599, -168.0684463>,
    <0.3832876, -168.0684463>,
    <0.3836948, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3851683, -168.0684463>,
    <0.3835042, -168.0684463>,
    <0.3856923, -168.0684463>,
    <0.3866763, -168.0684463>,
    <0.3842451, -168.0684463>,
    <0.3811814, -168.0684463>,
    <0.3824799, -168.0684463>,
    <0.3836947, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3829891, -168.0684463>,
    <0.3816314, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3805683, -168.0684463>,
    <0.3811584, -168.0684463>,
    <0.3824799, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3836027, -168.0684463>,
    <0.3805683, -168.0684463>,
    <0.3792754, -168.0684463>,
    <0.3812951, -168.0684463>,
    <0.3830608, -168.0684463>,
    <0.3846666, -168.0684463>,
    <0.3824799, -168.0684463>,
    <0.3836027, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3836947, -168.0684463>,
    <0.3830608, -168.0684463>,
    <0.3861746, -168.0684463>,
    <0.3856923, -168.0684463>,
    <0.3829891, -168.0684463>,
    <0.6188416, -168.0684463>,
    <0.6175200, -168.0684463>,
    <0.6163974, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6169210, -168.0684463>,
    <0.6187049, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6194148, -168.0684463>,
    <0.6188707, -168.0684463>,
    <0.6175200, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6165137, -168.0684463>,
    <0.6194148, -168.0684463>,
    <0.6207245, -168.0684463>,
    <0.6182820, -168.0684463>,
    <0.6169837, -168.0684463>,
    <0.6153856, -168.0684463>,
    <0.6175200, -168.0684463>,
    <0.6165137, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6163974, -168.0684463>,
    <0.6169837, -168.0684463>,
    <0.6146138, -168.0684463>,
    <0.6138255, -168.0684463>,
    <0.6169210, -168.0684463>,
    <0.3847445, -168.0684463>,
    <0.3864920, -168.0684463>,
    <0.3856191, -168.0684463>,
    <0.3816984, -168.0684463>,
    <0.3851683, -168.0684463>,
    <0.3860108, -168.0684463>,
    <0.3838088, -168.0684463>,
    <0.3834080, -168.0684463>,
    <0.3856663, -168.0684463>,
    <0.3873595, -168.0684463>,
    <0.3864920, -168.0684463>,
    <0.3851683, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3856663, -168.0684463>,
    <0.3866763, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3878568, -168.0684463>,
    <0.3874722, -168.0684463>,
    <0.3864920, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3856191, -168.0684463>,
    <0.3878568, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3872886, -168.0684463>,
    <0.3860108, -168.0684463>,
    <0.6132338, -168.0684463>,
    <0.6143156, -168.0684463>,
    <0.6163975, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6154895, -168.0684463>,
    <0.6138256, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6125240, -168.0684463>,
    <0.6132629, -168.0684463>,
    <0.6143156, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6165137, -168.0684463>,
    <0.6125240, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6146138, -168.0684463>,
    <0.6155587, -168.0684463>,
    <0.6169879, -168.0684463>,
    <0.6143156, -168.0684463>,
    <0.6165137, -168.0684463>,
    <0.6207246, -168.0684463>,
    <0.6163975, -168.0684463>,
    <0.6155587, -168.0684463>,
    <0.6182821, -168.0684463>,
    <0.6187050, -168.0684463>,
    <0.6154895, -168.0684463>,
    <0.3925172, -168.0684463>,
    <0.3909808, -168.0684463>,
    <0.3915894, -168.0684463>,
    <0.3951648, -168.0684463>,
    <0.3923336, -168.0684463>,
    <0.3913820, -168.0684463>,
    <0.3933573, -168.0684463>,
    <0.3938417, -168.0684463>,
    <0.3917689, -168.0684463>,
    <0.3902731, -168.0684463>,
    <0.3909808, -168.0684463>,
    <0.3923336, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3917689, -168.0684463>,
    <0.3906567, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3898312, -168.0684463>,
    <0.3900870, -168.0684463>,
    <0.3909808, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3915894, -168.0684463>,
    <0.3898312, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3903881, -168.0684463>,
    <0.3913820, -168.0684463>,
    <0.6272807, -167.0961975>,
    <0.6319730, -167.0922118>,
    <0.6300507, -167.0843893>,
    <0.6191270, -167.1040945>,
    <0.6279721, -167.1040945>,
    <0.6307183, -167.0871059>,
    <0.6259199, -167.0918409>,
    <0.6236811, -167.1040945>,
    <0.6296168, -167.0992097>,
    <0.6341111, -167.0948552>,
    <0.6319730, -167.0922118>,
    <0.6279721, -167.1040945>,
    <0.6379030, -167.1040945>,
    <0.6385965, -167.0790201>,
    <0.6296168, -167.0992097>,
    <0.6324455, -167.1040945>,
    <0.6382755, -167.0906253>,
    <0.6353197, -167.0855463>,
    <0.6348773, -167.0810169>,
    <0.6319730, -167.0922118>,
    <0.6385965, -167.0790201>,
    <0.6388889, -167.0684463>,
    <0.6300507, -167.0843893>,
    <0.6353197, -167.0855463>,
    <0.6387342, -167.0740392>,
    <0.6336427, -167.0779097>,
    <0.6307183, -167.0871059>,
    <0.6055618, -168.0684463>,
    <0.6079067, -168.0684463>,
    <0.6063736, -168.0684463>,
    <0.6014977, -168.0684463>,
    <0.6064691, -168.0684463>,
    <0.6070437, -168.0684463>,
    <0.6039625, -168.0684463>,
    <0.6039666, -168.0684463>,
    <0.6069772, -168.0684463>,
    <0.6091495, -168.0684463>,
    <0.6079067, -168.0684463>,
    <0.6064691, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6069772, -168.0684463>,
    <0.6084539, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6097066, -168.0684463>,
    <0.6091256, -168.0684463>,
    <0.6079067, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6063736, -168.0684463>,
    <0.6097066, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6087508, -168.0684463>,
    <0.6070437, -168.0684463>,
    <0.3759967, -167.0962946>,
    <0.3700392, -167.0922118>,
    <0.3726708, -167.1040945>,
    <0.3878952, -167.1040945>,
    <0.3733815, -167.0847775>,
    <0.3715578, -167.0990692>,
    <0.3793407, -167.1040945>,
    <0.3788686, -167.0920805>,
    <0.3720597, -167.0877176>,
    <0.3664107, -167.0830182>,
    <0.3700392, -167.0922118>,
    <0.3733815, -167.0847775>,
    <0.3611111, -167.0684463>,
    <0.3611111, -167.0866373>,
    <0.3720597, -167.0877176>,
    <0.3683126, -167.0780311>,
    <0.3611111, -167.0765496>,
    <0.3654676, -167.0893574>,
    <0.3662330, -167.0967595>,
    <0.3700392, -167.0922118>,
    <0.3611111, -167.0866373>,
    <0.3611111, -167.1040945>,
    <0.3726708, -167.1040945>,
    <0.3654676, -167.0893574>,
    <0.3611111, -167.1002349>,
    <0.3667116, -167.1040945>,
    <0.3715578, -167.0990692>,
    <0.4008837, -168.0684463>,
    <0.3970356, -168.0684463>,
    <0.3979710, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4014752, -168.0684463>,
    <0.3975991, -168.0684463>,
    <0.4025120, -168.0684463>,
    <0.4043052, -168.0684463>,
    <0.3995679, -168.0684463>,
    <0.3963162, -168.0684463>,
    <0.3970356, -168.0684463>,
    <0.4014752, -168.0684463>,
    <0.3951648, -168.0684463>,
    <0.3915894, -168.0684463>,
    <0.3995679, -168.0684463>,
    <0.3984780, -168.0684463>,
    <0.3933573, -168.0684463>,
    <0.3942469, -168.0684463>,
    <0.3938712, -168.0684463>,
    <0.3970356, -168.0684463>,
    <0.3915894, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3979710, -168.0684463>,
    <0.3942469, -168.0684463>,
    <0.3903881, -168.0684463>,
    <0.3934299, -168.0684463>,
    <0.3975991, -168.0684463>,
    <0.3823043, -167.0867726>,
    <0.3793009, -167.0803354>,
    <0.3733849, -167.0847863>,
    <0.3879027, -167.1041136>,
    <0.3886287, -167.0778552>,
    <0.3759080, -167.0828880>,
    <0.3788735, -167.0920931>,
    <0.3883389, -167.0883375>,
    <0.3839535, -167.0790983>,
    <0.3829546, -167.0737708>,
    <0.3793009, -167.0803354>,
    <0.3886287, -167.0778552>,
    <0.3888889, -167.0684463>,
    <0.3750000, -167.0684463>,
    <0.3839535, -167.0790983>,
    <0.3887624, -167.0730223>,
    <0.3819444, -167.0684463>,
    <0.3766838, -167.0731009>,
    <0.3721992, -167.0755036>,
    <0.3793009, -167.0803354>,
    <0.3750000, -167.0684463>,
    <0.3611111, -167.0684463>,
    <0.3733849, -167.0847863>,
    <0.3766838, -167.0731009>,
    <0.3680555, -167.0684463>,
    <0.3683146, -167.0780362>,
    <0.3759080, -167.0828880>,
    <0.3885892, -167.0967716>,
    <0.3885601, -167.0922245>,
    <0.3880189, -167.1041136>,
    <0.3888889, -167.1041136>,
    <0.3888889, -167.0866347>,
    <0.3882584, -167.0988530>,
    <0.3882592, -167.1041136>,
    <0.3888889, -167.1004045>,
    <0.3887678, -167.0886938>,
    <0.3887417, -167.0812901>,
    <0.3885601, -167.0922245>,
    <0.3888889, -167.0866347>,
    <0.3888889, -167.0684463>,
    <0.3886287, -167.0778552>,
    <0.3887678, -167.0886938>,
    <0.3888889, -167.0764712>,
    <0.3887624, -167.0730223>,
    <0.3886045, -167.0829371>,
    <0.3882776, -167.0945767>,
    <0.3885601, -167.0922245>,
    <0.3886287, -167.0778552>,
    <0.3879027, -167.1041136>,
    <0.3880189, -167.1041136>,
    <0.3886045, -167.0829371>,
    <0.3883389, -167.0883375>,
    <0.3879437, -167.1041136>,
    <0.3882584, -167.0988530>,
    <0.6129247, -167.0967434>,
    <0.6137815, -167.0922118>,
    <0.6111126, -167.0865728>,
    <0.6111141, -167.1040945>,
    <0.6156906, -167.1040945>,
    <0.6125038, -167.0895121>,
    <0.6111135, -167.0973716>,
    <0.6134942, -167.1040945>,
    <0.6149685, -167.0996003>,
    <0.6156407, -167.0953949>,
    <0.6137815, -167.0922118>,
    <0.6156906, -167.1040945>,
    <0.6191193, -167.1040945>,
    <0.6139714, -167.0811790>,
    <0.6149685, -167.0996003>,
    <0.6175613, -167.1040945>,
    <0.6158717, -167.0896379>,
    <0.6139092, -167.0847941>,
    <0.6124942, -167.0821025>,
    <0.6137815, -167.0922118>,
    <0.6139714, -167.0811790>,
    <0.6111111, -167.0684463>,
    <0.6111126, -167.0865728>,
    <0.6139092, -167.0847941>,
    <0.6126602, -167.0753420>,
    <0.6111119, -167.0782669>,
    <0.6125038, -167.0895121>,
    <0.6215443, -167.0874980>,
    <0.6230397, -167.0803290>,
    <0.6139714, -167.0811790>,
    <0.6191190, -167.1040945>,
    <0.6300472, -167.0843893>,
    <0.6184086, -167.0807631>,
    <0.6158715, -167.0896379>,
    <0.6259147, -167.0918409>,
    <0.6268332, -167.0825271>,
    <0.6292439, -167.0754027>,
    <0.6230397, -167.0803290>,
    <0.6300472, -167.0843893>,
    <0.6388889, -167.0684463>,
    <0.6250000, -167.0684463>,
    <0.6268332, -167.0825271>,
    <0.6336406, -167.0779097>,
    <0.6319445, -167.0684463>,
    <0.6242203, -167.0731728>,
    <0.6182805, -167.0746001>,
    <0.6230397, -167.0803290>,
    <0.6250000, -167.0684463>,
    <0.6111111, -167.0684463>,
    <0.6139714, -167.0811790>,
    <0.6242203, -167.0731728>,
    <0.6180556, -167.0684463>,
    <0.6126602, -167.0753420>,
    <0.6184086, -167.0807631>,
    <0.6108206, -167.0967434>,
    <0.6107825, -167.0922118>,
    <0.6102774, -167.1040945>,
    <0.6111111, -167.1040945>,
    <0.6111111, -167.0865728>,
    <0.6104963, -167.0989463>,
    <0.6105446, -167.1040945>,
    <0.6111111, -167.0973716>,
    <0.6109677, -167.0890341>,
    <0.6109559, -167.0815625>,
    <0.6107825, -167.0922118>,
    <0.6111111, -167.0865728>,
    <0.6111111, -167.0684463>,
    <0.6108188, -167.0790191>,
    <0.6109677, -167.0890341>,
    <0.6111111, -167.0782669>,
    <0.6109681, -167.0736177>,
    <0.6108069, -167.0833316>,
    <0.6105010, -167.0948550>,
    <0.6107825, -167.0922118>,
    <0.6108188, -167.0790191>,
    <0.6101254, -167.1040945>,
    <0.6102774, -167.1040945>,
    <0.6108069, -167.0833316>,
    <0.6104913, -167.0908619>,
    <0.6101803, -167.1040945>,
    <0.6104963, -167.0989463>,
    <0.4032689, -168.0684463>,
    <0.4009983, -168.0684463>,
    <0.3979710, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.3992270, -168.0684463>,
    <0.4025120, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4042493, -168.0684463>,
    <0.4029930, -168.0684463>,
    <0.4009983, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.3968675, -168.0684463>,
    <0.4042493, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4014131, -168.0684463>,
    <0.3986091, -168.0684463>,
    <0.3961814, -168.0684463>,
    <0.4009983, -168.0684463>,
    <0.3968675, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3979710, -168.0684463>,
    <0.3986091, -168.0684463>,
    <0.3927671, -168.0684463>,
    <0.3934299, -168.0684463>,
    <0.3992270, -168.0684463>,
    <0.6018166, -168.0684463>,
    <0.6018519, -168.0684463>,
    <0.6064691, -168.0684463>,
    <0.6014977, -168.0684463>,
    <0.5974476, -168.0684463>,
    <0.6042236, -168.0684463>,
    <0.6039666, -168.0684463>,
    <0.5995139, -168.0684463>,
    <0.5993456, -168.0684463>,
    <0.5988484, -168.0684463>,
    <0.6018519, -168.0684463>,
    <0.5974476, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.6031471, -168.0684463>,
    <0.5993456, -168.0684463>,
    <0.5952721, -168.0684463>,
    <0.5996305, -168.0684463>,
    <0.6028280, -168.0684463>,
    <0.6056448, -168.0684463>,
    <0.6018519, -168.0684463>,
    <0.6031471, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6064691, -168.0684463>,
    <0.6028280, -168.0684463>,
    <0.6062750, -168.0684463>,
    <0.6084539, -168.0684463>,
    <0.6042236, -168.0684463>,
    <0.5970106, -168.0684463>,
    <0.5990016, -168.0684463>,
    <0.6031471, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.6011180, -168.0684463>,
    <0.5996305, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5957128, -168.0684463>,
    <0.5968728, -168.0684463>,
    <0.5990016, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.6025958, -168.0684463>,
    <0.5957128, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5980163, -168.0684463>,
    <0.6010423, -168.0684463>,
    <0.6039639, -168.0684463>,
    <0.5990016, -168.0684463>,
    <0.6025958, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6031471, -168.0684463>,
    <0.6010423, -168.0684463>,
    <0.6069169, -168.0684463>,
    <0.6062750, -168.0684463>,
    <0.6011180, -168.0684463>,
    <0.4100995, -168.0684463>,
    <0.4110653, -168.0684463>,
    <0.4119248, -168.0684463>,
    <0.4094761, -168.0684463>,
    <0.4079319, -168.0684463>,
    <0.4115091, -168.0684463>,
    <0.4104848, -168.0684463>,
    <0.4086961, -168.0684463>,
    <0.4092186, -168.0684463>,
    <0.4085721, -168.0684463>,
    <0.4110653, -168.0684463>,
    <0.4079319, -168.0684463>,
    <0.4070530, -168.0684463>,
    <0.4082381, -168.0684463>,
    <0.4092186, -168.0684463>,
    <0.4074092, -168.0684463>,
    <0.4076465, -168.0684463>,
    <0.4092216, -168.0684463>,
    <0.4119737, -168.0684463>,
    <0.4110653, -168.0684463>,
    <0.4082381, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4119248, -168.0684463>,
    <0.4092216, -168.0684463>,
    <0.4120660, -168.0684463>,
    <0.4153915, -168.0684463>,
    <0.4115091, -168.0684463>,
    <0.4081505, -168.0684463>,
    <0.4102576, -168.0684463>,
    <0.4082382, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4094074, -168.0684463>,
    <0.4076465, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4082823, -168.0684463>,
    <0.4079206, -168.0684463>,
    <0.4102576, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4073187, -168.0684463>,
    <0.4082823, -168.0684463>,
    <0.4070531, -168.0684463>,
    <0.4071675, -168.0684463>,
    <0.4088063, -168.0684463>,
    <0.4106203, -168.0684463>,
    <0.4102576, -168.0684463>,
    <0.4073187, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4082382, -168.0684463>,
    <0.4088063, -168.0684463>,
    <0.4131861, -168.0684463>,
    <0.4120660, -168.0684463>,
    <0.4094074, -168.0684463>,
    <0.5874193, -168.0684463>,
    <0.5877092, -168.0684463>,
    <0.5902110, -168.0684463>,
    <0.5868476, -168.0684463>,
    <0.5849092, -168.0684463>,
    <0.5891434, -168.0684463>,
    <0.5886272, -168.0684463>,
    <0.5858696, -168.0684463>,
    <0.5862835, -168.0684463>,
    <0.5860034, -168.0684463>,
    <0.5877092, -168.0684463>,
    <0.5849092, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5880618, -168.0684463>,
    <0.5862835, -168.0684463>,
    <0.5842545, -168.0684463>,
    <0.5863164, -168.0684463>,
    <0.5879443, -168.0684463>,
    <0.5897322, -168.0684463>,
    <0.5877092, -168.0684463>,
    <0.5880618, -168.0684463>,
    <0.5929467, -168.0684463>,
    <0.5902110, -168.0684463>,
    <0.5879443, -168.0684463>,
    <0.5898548, -168.0684463>,
    <0.5916419, -168.0684463>,
    <0.5891434, -168.0684463>,
    <0.5910639, -168.0684463>,
    <0.5897423, -168.0684463>,
    <0.5886197, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5891425, -168.0684463>,
    <0.5909272, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5916482, -168.0684463>,
    <0.5909245, -168.0684463>,
    <0.5897423, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5880618, -168.0684463>,
    <0.5916482, -168.0684463>,
    <0.5929468, -168.0684463>,
    <0.5898548, -168.0684463>,
    <0.5889264, -168.0684463>,
    <0.5874393, -168.0684463>,
    <0.5897423, -168.0684463>,
    <0.5880618, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5886197, -168.0684463>,
    <0.5889264, -168.0684463>,
    <0.5863164, -168.0684463>,
    <0.5860478, -168.0684463>,
    <0.5891425, -168.0684463>,
    <0.4122669, -168.0684463>,
    <0.4142698, -168.0684463>,
    <0.4133968, -168.0684463>,
    <0.4094761, -168.0684463>,
    <0.4119248, -168.0684463>,
    <0.4137481, -168.0684463>,
    <0.4115865, -168.0684463>,
    <0.4104849, -168.0684463>,
    <0.4128809, -168.0684463>,
    <0.4148820, -168.0684463>,
    <0.4142698, -168.0684463>,
    <0.4119248, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4128809, -168.0684463>,
    <0.4153915, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4156958, -168.0684463>,
    <0.4152500, -168.0684463>,
    <0.4142698, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4133968, -168.0684463>,
    <0.4156958, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4150664, -168.0684463>,
    <0.4137481, -168.0684463>,
    <0.5841022, -168.0684463>,
    <0.5845048, -168.0684463>,
    <0.5852374, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5849085, -168.0684463>,
    <0.5843066, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5837970, -168.0684463>,
    <0.5840202, -168.0684463>,
    <0.5845048, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5849093, -168.0684463>,
    <0.5837970, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5842545, -168.0684463>,
    <0.5847579, -168.0684463>,
    <0.5853748, -168.0684463>,
    <0.5845048, -168.0684463>,
    <0.5849093, -168.0684463>,
    <0.5868477, -168.0684463>,
    <0.5852374, -168.0684463>,
    <0.5847579, -168.0684463>,
    <0.5858696, -168.0684463>,
    <0.5860882, -168.0684463>,
    <0.5849085, -168.0684463>,
    <0.4205704, -168.0684463>,
    <0.4190447, -168.0684463>,
    <0.4185305, -168.0684463>,
    <0.4238008, -168.0684463>,
    <0.4209055, -168.0684463>,
    <0.4186887, -168.0684463>,
    <0.4208097, -168.0684463>,
    <0.4225187, -168.0684463>,
    <0.4200721, -168.0684463>,
    <0.4183209, -168.0684463>,
    <0.4190447, -168.0684463>,
    <0.4209055, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4200721, -168.0684463>,
    <0.4189023, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4178033, -168.0684463>,
    <0.4177271, -168.0684463>,
    <0.4190447, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4185305, -168.0684463>,
    <0.4178033, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4176335, -168.0684463>,
    <0.4186887, -168.0684463>,
    <0.5777668, -168.0684463>,
    <0.5801290, -168.0684463>,
    <0.5785959, -168.0684463>,
    <0.5737202, -168.0684463>,
    <0.5786220, -168.0684463>,
    <0.5792447, -168.0684463>,
    <0.5761848, -168.0684463>,
    <0.5761414, -168.0684463>,
    <0.5791233, -168.0684463>,
    <0.5813544, -168.0684463>,
    <0.5801290, -168.0684463>,
    <0.5786220, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5791233, -168.0684463>,
    <0.5806103, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5818160, -168.0684463>,
    <0.5813479, -168.0684463>,
    <0.5801290, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5785959, -168.0684463>,
    <0.5818160, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5809731, -168.0684463>,
    <0.5792447, -168.0684463>,
    <0.5994955, -167.0962011>,
    <0.6041920, -167.0922118>,
    <0.6022607, -167.0844035>,
    <0.5913395, -167.1040945>,
    <0.6001897, -167.1040945>,
    <0.6029316, -167.0871158>,
    <0.5981272, -167.0918562>,
    <0.5958964, -167.1040945>,
    <0.6018356, -167.0992080>,
    <0.6063315, -167.0948550>,
    <0.6041920, -167.0922118>,
    <0.6001897, -167.1040945>,
    <0.6101254, -167.1040945>,
    <0.6108188, -167.0790191>,
    <0.6018356, -167.0992080>,
    <0.6046654, -167.1040945>,
    <0.6104913, -167.0908619>,
    <0.6075143, -167.0855976>,
    <0.6070957, -167.0810202>,
    <0.6041920, -167.0922118>,
    <0.6108188, -167.0790191>,
    <0.6111111, -167.0684463>,
    <0.6022607, -167.0844035>,
    <0.6075143, -167.0855976>,
    <0.6109681, -167.0736177>,
    <0.6058566, -167.0779201>,
    <0.6029316, -167.0871158>,
    <0.5691393, -168.0684463>,
    <0.5712237, -168.0684463>,
    <0.5749956, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5731488, -168.0684463>,
    <0.5714529, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5679396, -168.0684463>,
    <0.5690949, -168.0684463>,
    <0.5712237, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5748180, -168.0684463>,
    <0.5679396, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5702384, -168.0684463>,
    <0.5732614, -168.0684463>,
    <0.5760927, -168.0684463>,
    <0.5712237, -168.0684463>,
    <0.5748180, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5749956, -168.0684463>,
    <0.5732614, -168.0684463>,
    <0.5791391, -168.0684463>,
    <0.5781408, -168.0684463>,
    <0.5731488, -168.0684463>,
    <0.5739652, -168.0684463>,
    <0.5740741, -168.0684463>,
    <0.5786220, -168.0684463>,
    <0.5737202, -168.0684463>,
    <0.5694447, -168.0684463>,
    <0.5764002, -168.0684463>,
    <0.5761414, -168.0684463>,
    <0.5715989, -168.0684463>,
    <0.5714430, -168.0684463>,
    <0.5709208, -168.0684463>,
    <0.5740741, -168.0684463>,
    <0.5694447, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5749956, -168.0684463>,
    <0.5714430, -168.0684463>,
    <0.5672904, -168.0684463>,
    <0.5714529, -168.0684463>,
    <0.5747684, -168.0684463>,
    <0.5777563, -168.0684463>,
    <0.5740741, -168.0684463>,
    <0.5749956, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5786220, -168.0684463>,
    <0.5747684, -168.0684463>,
    <0.5781408, -168.0684463>,
    <0.5806103, -168.0684463>,
    <0.5764002, -168.0684463>,
    <0.4264176, -168.0684463>,
    <0.4283040, -168.0684463>,
    <0.4350353, -168.0684463>,
    <0.4238008, -168.0684463>,
    <0.4185305, -168.0684463>,
    <0.4319731, -168.0684463>,
    <0.4298368, -168.0684463>,
    <0.4208097, -168.0684463>,
    <0.4232016, -168.0684463>,
    <0.4237461, -168.0684463>,
    <0.4283040, -168.0684463>,
    <0.4185305, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4314832, -168.0684463>,
    <0.4232016, -168.0684463>,
    <0.4176335, -168.0684463>,
    <0.4259634, -168.0684463>,
    <0.4309298, -168.0684463>,
    <0.4348167, -168.0684463>,
    <0.4283040, -168.0684463>,
    <0.4314832, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4350353, -168.0684463>,
    <0.4309298, -168.0684463>,
    <0.4366537, -168.0684463>,
    <0.4398374, -168.0684463>,
    <0.4319731, -168.0684463>,
    <0.5632861, -168.0684463>,
    <0.5619645, -168.0684463>,
    <0.5608419, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5613543, -168.0684463>,
    <0.5631494, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5638611, -168.0684463>,
    <0.5631833, -168.0684463>,
    <0.5619645, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5604311, -168.0684463>,
    <0.5638611, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5621671, -168.0684463>,
    <0.5611511, -168.0684463>,
    <0.5596982, -168.0684463>,
    <0.5619645, -168.0684463>,
    <0.5604311, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5608419, -168.0684463>,
    <0.5611511, -168.0684463>,
    <0.5586763, -168.0684463>,
    <0.5582700, -168.0684463>,
    <0.5613543, -168.0684463>,
    <0.4037793, -167.0962955>,
    <0.3978195, -167.0922118>,
    <0.4004515, -167.1040945>,
    <0.4156807, -167.1040945>,
    <0.4011657, -167.0847813>,
    <0.3993384, -167.0990693>,
    <0.4071233, -167.1040945>,
    <0.4066539, -167.0920837>,
    <0.3998435, -167.0877174>,
    <0.3941907, -167.0830161>,
    <0.3978195, -167.0922118>,
    <0.4011657, -167.0847813>,
    <0.3888889, -167.0684463>,
    <0.3888889, -167.0866249>,
    <0.3998435, -167.0877174>,
    <0.3960947, -167.0780341>,
    <0.3888889, -167.0764669>,
    <0.3932465, -167.0893510>,
    <0.3940122, -167.0967564>,
    <0.3978195, -167.0922118>,
    <0.3888889, -167.0866249>,
    <0.3888889, -167.1040945>,
    <0.4004515, -167.1040945>,
    <0.3932465, -167.0893510>,
    <0.3888889, -167.1003874>,
    <0.3944908, -167.1040945>,
    <0.3993384, -167.0990693>,
    <0.4100825, -167.0867807>,
    <0.4070788, -167.0803290>,
    <0.4011657, -167.0847813>,
    <0.4156807, -167.1040945>,
    <0.4164047, -167.0779181>,
    <0.4036882, -167.0828820>,
    <0.4066539, -167.0920837>,
    <0.4161182, -167.0882770>,
    <0.4117303, -167.0791265>,
    <0.4107320, -167.0737849>,
    <0.4070788, -167.0803290>,
    <0.4164047, -167.0779181>,
    <0.4166667, -167.0684463>,
    <0.4027778, -167.0684463>,
    <0.4117303, -167.0791265>,
    <0.4165389, -167.0730647>,
    <0.4097222, -167.0684463>,
    <0.4044615, -167.0730982>,
    <0.3999778, -167.0755007>,
    <0.4070788, -167.0803290>,
    <0.4027778, -167.0684463>,
    <0.3888889, -167.0684463>,
    <0.4011657, -167.0847813>,
    <0.4044615, -167.0730982>,
    <0.3958333, -167.0684463>,
    <0.3960947, -167.0780341>,
    <0.4036882, -167.0828820>,
    <0.4163658, -167.0967588>,
    <0.4163373, -167.0922118>,
    <0.4157964, -167.1040945>,
    <0.4166642, -167.1040945>,
    <0.4166654, -167.0866345>,
    <0.4160352, -167.0988474>,
    <0.4160356, -167.1040945>,
    <0.4166644, -167.1002973>,
    <0.4165444, -167.0886908>,
    <0.4165185, -167.0813027>,
    <0.4163373, -167.0922118>,
    <0.4166654, -167.0866345>,
    <0.4166667, -167.0684463>,
    <0.4164047, -167.0779181>,
    <0.4165444, -167.0886908>,
    <0.4166661, -167.0765174>,
    <0.4165390, -167.0730647>,
    <0.4163809, -167.0829760>,
    <0.4160548, -167.0945797>,
    <0.4163373, -167.0922118>,
    <0.4164047, -167.0779181>,
    <0.4156809, -167.1040945>,
    <0.4157964, -167.1040945>,
    <0.4163809, -167.0829760>,
    <0.4161183, -167.0882770>,
    <0.4157217, -167.1040945>,
    <0.4160352, -167.0988474>,
    <0.5851467, -167.0967307>,
    <0.5860034, -167.0922118>,
    <0.5833346, -167.0865221>,
    <0.5833358, -167.1040945>,
    <0.5879130, -167.1040945>,
    <0.5847261, -167.0894886>,
    <0.5833353, -167.0971569>,
    <0.5857164, -167.1040945>,
    <0.5871822, -167.0995467>,
    <0.5878658, -167.0954084>,
    <0.5860034, -167.0922118>,
    <0.5879130, -167.1040945>,
    <0.5913411, -167.1040945>,
    <0.5862057, -167.0812330>,
    <0.5871822, -167.0995467>,
    <0.5897835, -167.1040945>,
    <0.5881054, -167.0896899>,
    <0.5861393, -167.0848381>,
    <0.5847193, -167.0821033>,
    <0.5860034, -167.0922118>,
    <0.5862057, -167.0812330>,
    <0.5833333, -167.0684463>,
    <0.5833346, -167.0865221>,
    <0.5861393, -167.0848381>,
    <0.5848903, -167.0753774>,
    <0.5833340, -167.0783502>,
    <0.5847261, -167.0894886>,
    <0.5937667, -167.0875150>,
    <0.5952613, -167.0803290>,
    <0.5862051, -167.0812330>,
    <0.5913395, -167.1040945>,
    <0.6022607, -167.0844035>,
    <0.5906360, -167.0807907>,
    <0.5881044, -167.0896899>,
    <0.5981272, -167.0918562>,
    <0.5990507, -167.0825349>,
    <0.6014639, -167.0754063>,
    <0.5952613, -167.0803290>,
    <0.6022607, -167.0844035>,
    <0.6111111, -167.0684463>,
    <0.5972222, -167.0684463>,
    <0.5990507, -167.0825349>,
    <0.6058566, -167.0779201>,
    <0.6041667, -167.0684463>,
    <0.5964410, -167.0731804>,
    <0.5905055, -167.0746136>,
    <0.5952613, -167.0803290>,
    <0.5972222, -167.0684463>,
    <0.5833333, -167.0684463>,
    <0.5862051, -167.0812330>,
    <0.5964410, -167.0731804>,
    <0.5902778, -167.0684463>,
    <0.5848900, -167.0753774>,
    <0.5906360, -167.0807907>,
    <0.5830427, -167.0967307>,
    <0.5830047, -167.0922118>,
    <0.5824995, -167.1040945>,
    <0.5833333, -167.1040945>,
    <0.5833333, -167.0865221>,
    <0.5827189, -167.0989345>,
    <0.5827667, -167.1040945>,
    <0.5833333, -167.0971569>,
    <0.5831895, -167.0890121>,
    <0.5831746, -167.0816748>,
    <0.5830047, -167.0922118>,
    <0.5833333, -167.0865221>,
    <0.5833333, -167.0684463>,
    <0.5830271, -167.0795191>,
    <0.5831895, -167.0890121>,
    <0.5833333, -167.0783502>,
    <0.5831825, -167.0738996>,
    <0.5830197, -167.0836848>,
    <0.5827197, -167.0949800>,
    <0.5830047, -167.0922118>,
    <0.5830271, -167.0795191>,
    <0.5823474, -167.1040945>,
    <0.5824995, -167.1040945>,
    <0.5830197, -167.0836848>,
    <0.5827038, -167.0912070>,
    <0.5824023, -167.1040945>,
    <0.5827189, -167.0989345>,
    <0.4281789, -168.0684463>,
    <0.4351852, -168.0684463>,
    <0.4303082, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4305555, -168.0684463>,
    <0.4323255, -168.0684463>,
    <0.4250931, -168.0684463>,
    <0.4236111, -168.0684463>,
    <0.4325008, -168.0684463>,
    <0.4386574, -168.0684463>,
    <0.4351852, -168.0684463>,
    <0.4305555, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4325008, -168.0684463>,
    <0.4375000, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4399653, -168.0684463>,
    <0.4385956, -168.0684463>,
    <0.4351852, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4303082, -168.0684463>,
    <0.4399653, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4352553, -168.0684463>,
    <0.4323255, -168.0684463>,
    <0.5575411, -168.0684463>,
    <0.5587600, -168.0684463>,
    <0.5602932, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5596164, -168.0684463>,
    <0.5579159, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5569497, -168.0684463>,
    <0.5575755, -168.0684463>,
    <0.5587600, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5604311, -168.0684463>,
    <0.5569497, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5586763, -168.0684463>,
    <0.5597126, -168.0684463>,
    <0.5611633, -168.0684463>,
    <0.5587600, -168.0684463>,
    <0.5604311, -168.0684463>,
    <0.5651689, -168.0684463>,
    <0.5602932, -168.0684463>,
    <0.5597126, -168.0684463>,
    <0.5621671, -168.0684463>,
    <0.5627043, -168.0684463>,
    <0.5596164, -168.0684463>,
    <0.4480179, -168.0684463>,
    <0.4465364, -168.0684463>,
    <0.4469260, -168.0684463>,
    <0.4507202, -168.0684463>,
    <0.4478891, -168.0684463>,
    <0.4467704, -168.0684463>,
    <0.4487437, -168.0684463>,
    <0.4493972, -168.0684463>,
    <0.4472540, -168.0684463>,
    <0.4458286, -168.0684463>,
    <0.4465364, -168.0684463>,
    <0.4478891, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4472540, -168.0684463>,
    <0.4462122, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4452179, -168.0684463>,
    <0.4455878, -168.0684463>,
    <0.4465364, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4469260, -168.0684463>,
    <0.4452179, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4457280, -168.0684463>,
    <0.4467704, -168.0684463>,
    <0.5500062, -168.0684463>,
    <0.5523511, -168.0684463>,
    <0.5508181, -168.0684463>,
    <0.5459422, -168.0684463>,
    <0.5509135, -168.0684463>,
    <0.5514882, -168.0684463>,
    <0.5484070, -168.0684463>,
    <0.5484110, -168.0684463>,
    <0.5514217, -168.0684463>,
    <0.5535939, -168.0684463>,
    <0.5523511, -168.0684463>,
    <0.5509135, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5514217, -168.0684463>,
    <0.5528983, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5541511, -168.0684463>,
    <0.5535701, -168.0684463>,
    <0.5523511, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5508181, -168.0684463>,
    <0.5541511, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5531953, -168.0684463>,
    <0.5514882, -168.0684463>,
    <0.4564394, -168.0684463>,
    <0.4525912, -168.0684463>,
    <0.4535266, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4570308, -168.0684463>,
    <0.4531626, -168.0684463>,
    <0.4580677, -168.0684463>,
    <0.4598609, -168.0684463>,
    <0.4551324, -168.0684463>,
    <0.4518170, -168.0684463>,
    <0.4525912, -168.0684463>,
    <0.4570308, -168.0684463>,
    <0.4507202, -168.0684463>,
    <0.4469260, -168.0684463>,
    <0.4551324, -168.0684463>,
    <0.4540335, -168.0684463>,
    <0.4487437, -168.0684463>,
    <0.4496577, -168.0684463>,
    <0.4493721, -168.0684463>,
    <0.4525912, -168.0684463>,
    <0.4469260, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4535266, -168.0684463>,
    <0.4496577, -168.0684463>,
    <0.4457280, -168.0684463>,
    <0.4489855, -168.0684463>,
    <0.4531626, -168.0684463>,
    <0.5462047, -168.0684463>,
    <0.5462964, -168.0684463>,
    <0.5509135, -168.0684463>,
    <0.5459422, -168.0684463>,
    <0.5416668, -168.0684463>,
    <0.5486611, -168.0684463>,
    <0.5484110, -168.0684463>,
    <0.5438210, -168.0684463>,
    <0.5436586, -168.0684463>,
    <0.5431752, -168.0684463>,
    <0.5462964, -168.0684463>,
    <0.5416668, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5473463, -168.0684463>,
    <0.5436586, -168.0684463>,
    <0.5395126, -168.0684463>,
    <0.5437561, -168.0684463>,
    <0.5470809, -168.0684463>,
    <0.5500279, -168.0684463>,
    <0.5462964, -168.0684463>,
    <0.5473463, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5509135, -168.0684463>,
    <0.5470809, -168.0684463>,
    <0.5505572, -168.0684463>,
    <0.5528983, -168.0684463>,
    <0.5486611, -168.0684463>,
    <0.5413937, -168.0684463>,
    <0.5434460, -168.0684463>,
    <0.5473463, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5454393, -168.0684463>,
    <0.5437561, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5401575, -168.0684463>,
    <0.5413172, -168.0684463>,
    <0.5434460, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5470402, -168.0684463>,
    <0.5401575, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5424607, -168.0684463>,
    <0.5454789, -168.0684463>,
    <0.5483470, -168.0684463>,
    <0.5434460, -168.0684463>,
    <0.5470402, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5473463, -168.0684463>,
    <0.5454789, -168.0684463>,
    <0.5513614, -168.0684463>,
    <0.5505572, -168.0684463>,
    <0.5454393, -168.0684463>,
    <0.4588246, -168.0684463>,
    <0.4565540, -168.0684463>,
    <0.4535266, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4547982, -168.0684463>,
    <0.4580677, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4598077, -168.0684463>,
    <0.4586829, -168.0684463>,
    <0.4565540, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4529599, -168.0684463>,
    <0.4598077, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4575395, -168.0684463>,
    <0.4544819, -168.0684463>,
    <0.4518713, -168.0684463>,
    <0.4565540, -168.0684463>,
    <0.4529599, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4535266, -168.0684463>,
    <0.4544819, -168.0684463>,
    <0.4486387, -168.0684463>,
    <0.4489855, -168.0684463>,
    <0.4547982, -168.0684463>,
    <0.4636888, -168.0684463>,
    <0.4658133, -168.0684463>,
    <0.4637241, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4646458, -168.0684463>,
    <0.4631652, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4638618, -168.0684463>,
    <0.4634763, -168.0684463>,
    <0.4658133, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4628743, -168.0684463>,
    <0.4638618, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4627232, -168.0684463>,
    <0.4643022, -168.0684463>,
    <0.4661585, -168.0684463>,
    <0.4658133, -168.0684463>,
    <0.4628743, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4637241, -168.0684463>,
    <0.4643022, -168.0684463>,
    <0.4687419, -168.0684463>,
    <0.4690033, -168.0684463>,
    <0.4646458, -168.0684463>,
    <0.5355084, -168.0684463>,
    <0.5341868, -168.0684463>,
    <0.5330641, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5335788, -168.0684463>,
    <0.5353716, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5360869, -168.0684463>,
    <0.5353746, -168.0684463>,
    <0.5341868, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5325291, -168.0684463>,
    <0.5360869, -168.0684463>,
    <0.5373913, -168.0684463>,
    <0.5343117, -168.0684463>,
    <0.5333051, -168.0684463>,
    <0.5318894, -168.0684463>,
    <0.5341868, -168.0684463>,
    <0.5325291, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5330641, -168.0684463>,
    <0.5333051, -168.0684463>,
    <0.5307016, -168.0684463>,
    <0.5304922, -168.0684463>,
    <0.5335788, -168.0684463>,
    <0.4645445, -168.0684463>,
    <0.4690177, -168.0684463>,
    <0.4628273, -168.0684463>,
    <0.4626088, -168.0684463>,
    <0.4637241, -168.0684463>,
    <0.4654665, -168.0684463>,
    <0.4626982, -168.0684463>,
    <0.4631651, -168.0684463>,
    <0.4660924, -168.0684463>,
    <0.4692966, -168.0684463>,
    <0.4690177, -168.0684463>,
    <0.4637241, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4660924, -168.0684463>,
    <0.4690033, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4710101, -168.0684463>,
    <0.4690724, -168.0684463>,
    <0.4690177, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4628273, -168.0684463>,
    <0.4710101, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4683076, -168.0684463>,
    <0.4654665, -168.0684463>,
    <0.5297633, -168.0684463>,
    <0.5309823, -168.0684463>,
    <0.5325153, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5318422, -168.0684463>,
    <0.5301381, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5291676, -168.0684463>,
    <0.5297667, -168.0684463>,
    <0.5309823, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5325291, -168.0684463>,
    <0.5291676, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5307016, -168.0684463>,
    <0.5318596, -168.0684463>,
    <0.5333545, -168.0684463>,
    <0.5309823, -168.0684463>,
    <0.5325291, -168.0684463>,
    <0.5373912, -168.0684463>,
    <0.5325153, -168.0684463>,
    <0.5318596, -168.0684463>,
    <0.5343117, -168.0684463>,
    <0.5349265, -168.0684463>,
    <0.5318422, -168.0684463>,
    <0.4786428, -168.0684463>,
    <0.4814815, -168.0684463>,
    <0.4886452, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4852422, -168.0684463>,
    <0.4812113, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4758390, -168.0684463>,
    <0.4794337, -168.0684463>,
    <0.4814815, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4918090, -168.0684463>,
    <0.4758390, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4838095, -168.0684463>,
    <0.4878778, -168.0684463>,
    <0.4904839, -168.0684463>,
    <0.4814815, -168.0684463>,
    <0.4918090, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4886452, -168.0684463>,
    <0.4878778, -168.0684463>,
    <0.4967695, -168.0684463>,
    <0.4951654, -168.0684463>,
    <0.4852422, -168.0684463>,
    <0.5222480, -168.0684463>,
    <0.5245734, -168.0684463>,
    <0.5224917, -168.0684463>,
    <0.5181645, -168.0684463>,
    <0.5237624, -168.0684463>,
    <0.5233372, -168.0684463>,
    <0.5201841, -168.0684463>,
    <0.5210086, -168.0684463>,
    <0.5240358, -168.0684463>,
    <0.5259728, -168.0684463>,
    <0.5245734, -168.0684463>,
    <0.5237624, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5240358, -168.0684463>,
    <0.5256480, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5263101, -168.0684463>,
    <0.5256551, -168.0684463>,
    <0.5245734, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5224917, -168.0684463>,
    <0.5263101, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5250635, -168.0684463>,
    <0.5233372, -168.0684463>,
    <0.5717177, -167.0962025>,
    <0.5764147, -167.0922118>,
    <0.5744804, -167.0844094>,
    <0.5635633, -167.1040945>,
    <0.5724125, -167.1040945>,
    <0.5751536, -167.0871249>,
    <0.5703468, -167.0918630>,
    <0.5681196, -167.1040945>,
    <0.5740594, -167.0992049>,
    <0.5785504, -167.0949800>,
    <0.5764147, -167.0922118>,
    <0.5724125, -167.1040945>,
    <0.5823474, -167.1040945>,
    <0.5830271, -167.0795191>,
    <0.5740594, -167.0992049>,
    <0.5768879, -167.1040945>,
    <0.5827038, -167.0912070>,
    <0.5797297, -167.0858486>,
    <0.5793139, -167.0811467>,
    <0.5764147, -167.0922118>,
    <0.5830271, -167.0795191>,
    <0.5833333, -167.0684463>,
    <0.5744804, -167.0844094>,
    <0.5797297, -167.0858486>,
    <0.5831825, -167.0738996>,
    <0.5780767, -167.0779248>,
    <0.5751536, -167.0871249>,
    <0.5097382, -168.0684463>,
    <0.5116373, -168.0684463>,
    <0.5183686, -168.0684463>,
    <0.5071342, -168.0684463>,
    <0.5018128, -168.0684463>,
    <0.5155983, -168.0684463>,
    <0.5131702, -168.0684463>,
    <0.5041606, -168.0684463>,
    <0.5067147, -168.0684463>,
    <0.5061011, -168.0684463>,
    <0.5116373, -168.0684463>,
    <0.5018128, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5109544, -168.0684463>,
    <0.5067147, -168.0684463>,
    <0.5005475, -168.0684463>,
    <0.5046102, -168.0684463>,
    <0.5113768, -168.0684463>,
    <0.5171845, -168.0684463>,
    <0.5116373, -168.0684463>,
    <0.5109544, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5183686, -168.0684463>,
    <0.5113768, -168.0684463>,
    <0.5179802, -168.0684463>,
    <0.5231707, -168.0684463>,
    <0.5155983, -168.0684463>,
    <0.4287549, -167.0684463>,
    <0.4295266, -167.0684463>,
    <0.4220677, -167.0684463>,
    <0.4274688, -167.0684463>,
    <0.4359566, -167.0684463>,
    <0.4253310, -167.0684463>,
    <0.4247682, -167.0684463>,
    <0.4317127, -167.0684463>,
    <0.4331435, -167.0684463>,
    <0.4351208, -167.0684463>,
    <0.4295266, -167.0684463>,
    <0.4359566, -167.0684463>,
    <0.4444444, -167.0684463>,
    <0.4305555, -167.0684463>,
    <0.4331435, -167.0684463>,
    <0.4402005, -167.0684463>,
    <0.4375000, -167.0684463>,
    <0.4301054, -167.0684463>,
    <0.4247041, -167.0684463>,
    <0.4295266, -167.0684463>,
    <0.4305555, -167.0684463>,
    <0.4166667, -167.0684463>,
    <0.4220677, -167.0684463>,
    <0.4301054, -167.0684463>,
    <0.4236111, -167.0684463>,
    <0.4193672, -167.0684463>,
    <0.4253310, -167.0684463>,
    <0.4839969, -168.0684463>,
    <0.4907407, -168.0684463>,
    <0.4843793, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4886452, -168.0684463>,
    <0.4866436, -168.0684463>,
    <0.4796384, -168.0684463>,
    <0.4812113, -168.0684463>,
    <0.4895901, -168.0684463>,
    <0.4948465, -168.0684463>,
    <0.4907407, -168.0684463>,
    <0.4886452, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4895901, -168.0684463>,
    <0.4951654, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4952580, -168.0684463>,
    <0.4937800, -168.0684463>,
    <0.4907407, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4843793, -168.0684463>,
    <0.4952580, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4896274, -168.0684463>,
    <0.4866436, -168.0684463>,
    <0.5038910, -168.0684463>,
    <0.5023781, -168.0684463>,
    <0.5018128, -168.0684463>,
    <0.5071342, -168.0684463>,
    <0.5042389, -168.0684463>,
    <0.5020218, -168.0684463>,
    <0.5041606, -168.0684463>,
    <0.5058520, -168.0684463>,
    <0.5034052, -168.0684463>,
    <0.5016542, -168.0684463>,
    <0.5023781, -168.0684463>,
    <0.5042389, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5034052, -168.0684463>,
    <0.5022357, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5009257, -168.0684463>,
    <0.5010477, -168.0684463>,
    <0.5023781, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5018128, -168.0684463>,
    <0.5009257, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5005475, -168.0684463>,
    <0.5020218, -168.0684463>,
    <0.5164391, -168.0684463>,
    <0.5153141, -168.0684463>,
    <0.5237624, -168.0684463>,
    <0.5181645, -168.0684463>,
    <0.5085155, -168.0684463>,
    <0.5196353, -168.0684463>,
    <0.5210086, -168.0684463>,
    <0.5130951, -168.0684463>,
    <0.5114312, -168.0684463>,
    <0.5094296, -168.0684463>,
    <0.5153141, -168.0684463>,
    <0.5085155, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5138889, -168.0684463>,
    <0.5114312, -168.0684463>,
    <0.5041943, -168.0684463>,
    <0.5069444, -168.0684463>,
    <0.5144438, -168.0684463>,
    <0.5201858, -168.0684463>,
    <0.5153141, -168.0684463>,
    <0.5138889, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5237624, -168.0684463>,
    <0.5144438, -168.0684463>,
    <0.5208333, -168.0684463>,
    <0.5256480, -168.0684463>,
    <0.5196353, -168.0684463>,
    <0.4315524, -167.0962958>,
    <0.4255943, -167.0922118>,
    <0.4282256, -167.1040945>,
    <0.4434495, -167.1040945>,
    <0.4289402, -167.0847825>,
    <0.4271127, -167.0990689>,
    <0.4348952, -167.1040945>,
    <0.4344269, -167.0920854>,
    <0.4276174, -167.0877196>,
    <0.4219670, -167.0830188>,
    <0.4255943, -167.0922118>,
    <0.4289402, -167.0847825>,
    <0.4166667, -167.0684463>,
    <0.4166667, -167.0866345>,
    <0.4276174, -167.0877196>,
    <0.4238707, -167.0780349>,
    <0.4166667, -167.0765174>,
    <0.4210228, -167.0893559>,
    <0.4217883, -167.0967588>,
    <0.4255943, -167.0922118>,
    <0.4166667, -167.0866345>,
    <0.4166667, -167.1040945>,
    <0.4282256, -167.1040945>,
    <0.4210228, -167.0893559>,
    <0.4166667, -167.1002973>,
    <0.4222668, -167.1040945>,
    <0.4271127, -167.0990689>,
    <0.4378597, -167.0868162>,
    <0.4348565, -167.0803354>,
    <0.4289443, -167.0847912>,
    <0.4434584, -167.1041136>,
    <0.4441797, -167.0780245>,
    <0.4314660, -167.0828907>,
    <0.4344328, -167.0920980>,
    <0.4438925, -167.0884126>,
    <0.4395068, -167.0791827>,
    <0.4385090, -167.0738131>,
    <0.4348565, -167.0803354>,
    <0.4441797, -167.0780245>,
    <0.4444444, -167.0684463>,
    <0.4305555, -167.0684463>,
    <0.4395068, -167.0791827>,
    <0.4443153, -167.0731176>,
    <0.4375000, -167.0684463>,
    <0.4322397, -167.0731018>,
    <0.4277558, -167.0755048>,
    <0.4348565, -167.0803354>,
    <0.4305555, -167.0684463>,
    <0.4166667, -167.0684463>,
    <0.4289443, -167.0847912>,
    <0.4322397, -167.0731018>,
    <0.4236111, -167.0684463>,
    <0.4238731, -167.0780400>,
    <0.4314660, -167.0828907>,
    <0.4441431, -167.0967745>,
    <0.4441146, -167.0922245>,
    <0.4435740, -167.1041136>,
    <0.4444410, -167.1041136>,
    <0.4444427, -167.0866463>,
    <0.4438130, -167.0988573>,
    <0.4438132, -167.1041136>,
    <0.4444414, -167.1003136>,
    <0.4443217, -167.0887025>,
    <0.4442953, -167.0813354>,
    <0.4441146, -167.0922245>,
    <0.4444427, -167.0866463>,
    <0.4444444, -167.0684463>,
    <0.4441796, -167.0780245>,
    <0.4443217, -167.0887025>,
    <0.4444437, -167.0765235>,
    <0.4443153, -167.0731176>,
    <0.4441566, -167.0830495>,
    <0.4438316, -167.0946190>,
    <0.4441146, -167.0922245>,
    <0.4441796, -167.0780245>,
    <0.4434583, -167.1041136>,
    <0.4435740, -167.1041136>,
    <0.4441566, -167.0830495>,
    <0.4438924, -167.0884126>,
    <0.4434992, -167.1041136>,
    <0.4438130, -167.0988573>,
    <0.5600893, -167.0954205>,
    <0.5582243, -167.0922118>,
    <0.5601330, -167.1040945>,
    <0.5635618, -167.1040945>,
    <0.5584381, -167.0812811>,
    <0.5594008, -167.0995361>,
    <0.5620038, -167.1040945>,
    <0.5603404, -167.0897510>,
    <0.5583679, -167.0848718>,
    <0.5569434, -167.0821173>,
    <0.5582243, -167.0922118>,
    <0.5584381, -167.0812811>,
    <0.5555556, -167.0684463>,
    <0.5555556, -167.0865301>,
    <0.5583679, -167.0848718>,
    <0.5571185, -167.0754054>,
    <0.5555556, -167.0783708>,
    <0.5569468, -167.0894920>,
    <0.5573671, -167.0967327>,
    <0.5582243, -167.0922118>,
    <0.5555556, -167.0865301>,
    <0.5555556, -167.1040945>,
    <0.5601330, -167.1040945>,
    <0.5569468, -167.0894920>,
    <0.5555556, -167.0971598>,
    <0.5579363, -167.1040945>,
    <0.5594008, -167.0995361>,
    <0.5738578, -167.0684463>,
    <0.5681725, -167.0684463>,
    <0.5744810, -167.0684463>,
    <0.5833333, -167.0684463>,
    <0.5694444, -167.0684463>,
    <0.5717210, -167.0684463>,
    <0.5789072, -167.0684463>,
    <0.5763889, -167.0684463>,
    <0.5688880, -167.0684463>,
    <0.5634412, -167.0684463>,
    <0.5681725, -167.0684463>,
    <0.5694444, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5605921, -167.0684463>,
    <0.5688880, -167.0684463>,
    <0.5625000, -167.0684463>,
    <0.5580738, -167.0684463>,
    <0.5639086, -167.0684463>,
    <0.5672186, -167.0684463>,
    <0.5681725, -167.0684463>,
    <0.5605921, -167.0684463>,
    <0.5656287, -167.0684463>,
    <0.5744810, -167.0684463>,
    <0.5639086, -167.0684463>,
    <0.5631104, -167.0684463>,
    <0.5700548, -167.0684463>,
    <0.5717210, -167.0684463>,
    <0.5659916, -167.0875285>,
    <0.5674841, -167.0803290>,
    <0.5584387, -167.0812811>,
    <0.5635633, -167.1040945>,
    <0.5744804, -167.0844094>,
    <0.5628640, -167.0808153>,
    <0.5603413, -167.0897510>,
    <0.5703468, -167.0918630>,
    <0.5712724, -167.0825385>,
    <0.5736856, -167.0754078>,
    <0.5674841, -167.0803290>,
    <0.5744804, -167.0844094>,
    <0.5833333, -167.0684463>,
    <0.5694445, -167.0684463>,
    <0.5712724, -167.0825385>,
    <0.5780767, -167.0779248>,
    <0.5763889, -167.0684463>,
    <0.5686623, -167.0731874>,
    <0.5627307, -167.0746257>,
    <0.5674841, -167.0803290>,
    <0.5694445, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5584387, -167.0812811>,
    <0.5686623, -167.0731874>,
    <0.5625000, -167.0684463>,
    <0.5571188, -167.0754054>,
    <0.5628640, -167.0808153>,
    <0.5552618, -167.0967479>,
    <0.5552249, -167.0922245>,
    <0.5547205, -167.1041136>,
    <0.5555495, -167.1041136>,
    <0.5555525, -167.0865398>,
    <0.5549395, -167.0989513>,
    <0.5549859, -167.1041136>,
    <0.5555507, -167.0971752>,
    <0.5554091, -167.0890276>,
    <0.5553956, -167.0816839>,
    <0.5552249, -167.0922245>,
    <0.5555525, -167.0865398>,
    <0.5555556, -167.0684463>,
    <0.5552493, -167.0795251>,
    <0.5554091, -167.0890276>,
    <0.5555539, -167.0783761>,
    <0.5554048, -167.0738992>,
    <0.5552413, -167.0836926>,
    <0.5549411, -167.0949942>,
    <0.5552249, -167.0922245>,
    <0.5552493, -167.0795251>,
    <0.5545696, -167.1041136>,
    <0.5547205, -167.1041136>,
    <0.5552413, -167.0836926>,
    <0.5549259, -167.0912224>,
    <0.5546240, -167.1041136>,
    <0.5549395, -167.0989513>,
    <0.4565319, -167.0684463>,
    <0.4573035, -167.0684463>,
    <0.4498452, -167.0684463>,
    <0.4552461, -167.0684463>,
    <0.4637330, -167.0684463>,
    <0.4531082, -167.0684463>,
    <0.4525457, -167.0684463>,
    <0.4594895, -167.0684463>,
    <0.4609201, -167.0684463>,
    <0.4628972, -167.0684463>,
    <0.4573035, -167.0684463>,
    <0.4637330, -167.0684463>,
    <0.4722200, -167.0684463>,
    <0.4583322, -167.0684463>,
    <0.4609201, -167.0684463>,
    <0.4679765, -167.0684463>,
    <0.4652761, -167.0684463>,
    <0.4578821, -167.0684463>,
    <0.4524813, -167.0684463>,
    <0.4573035, -167.0684463>,
    <0.4583322, -167.0684463>,
    <0.4444444, -167.0684463>,
    <0.4498452, -167.0684463>,
    <0.4578821, -167.0684463>,
    <0.4513883, -167.0684463>,
    <0.4471448, -167.0684463>,
    <0.4531082, -167.0684463>,
    <0.5439459, -167.0961987>,
    <0.5486392, -167.0922118>,
    <0.5467141, -167.0843941>,
    <0.5357922, -167.1040945>,
    <0.5446381, -167.1040945>,
    <0.5473843, -167.0871156>,
    <0.5425752, -167.0918597>,
    <0.5403467, -167.1040945>,
    <0.5462839, -167.0992067>,
    <0.5507741, -167.0949800>,
    <0.5486392, -167.0922118>,
    <0.5446381, -167.1040945>,
    <0.5545698, -167.1040945>,
    <0.5552494, -167.0795192>,
    <0.5462839, -167.0992067>,
    <0.5491119, -167.1040945>,
    <0.5549261, -167.0912102>,
    <0.5519527, -167.0858493>,
    <0.5515396, -167.0811428>,
    <0.5486392, -167.0922118>,
    <0.5552494, -167.0795192>,
    <0.5555556, -167.0684463>,
    <0.5467141, -167.0843941>,
    <0.5519527, -167.0858493>,
    <0.5554049, -167.0738963>,
    <0.5503075, -167.0779126>,
    <0.5473843, -167.0871156>,
    <0.4593352, -167.0962959>,
    <0.4533750, -167.0922118>,
    <0.4560070, -167.1040945>,
    <0.4712363, -167.1040945>,
    <0.4567224, -167.0847829>,
    <0.4548938, -167.0990688>,
    <0.4626787, -167.1040945>,
    <0.4622109, -167.0920857>,
    <0.4553990, -167.0877200>,
    <0.4497466, -167.0830194>,
    <0.4533750, -167.0922118>,
    <0.4567224, -167.0847829>,
    <0.4444444, -167.0684463>,
    <0.4444444, -167.0866365>,
    <0.4553990, -167.0877200>,
    <0.4516512, -167.0780353>,
    <0.4444444, -167.0765192>,
    <0.4488020, -167.0893569>,
    <0.4495677, -167.0967593>,
    <0.4533750, -167.0922118>,
    <0.4444444, -167.0866365>,
    <0.4444444, -167.1040945>,
    <0.4560070, -167.1040945>,
    <0.4488020, -167.0893569>,
    <0.4444444, -167.1002966>,
    <0.4500463, -167.1040945>,
    <0.4548938, -167.0990688>,
    <0.4656376, -167.0868066>,
    <0.4626343, -167.0803290>,
    <0.4567224, -167.0847829>,
    <0.4712363, -167.1040945>,
    <0.4719574, -167.0780199>,
    <0.4592439, -167.0828833>,
    <0.4622109, -167.0920857>,
    <0.4716702, -167.0884034>,
    <0.4672846, -167.0791773>,
    <0.4662868, -167.0738104>,
    <0.4626343, -167.0803290>,
    <0.4719574, -167.0780199>,
    <0.4722222, -167.0684463>,
    <0.4583333, -167.0684463>,
    <0.4672846, -167.0791773>,
    <0.4720931, -167.0731150>,
    <0.4652778, -167.0684463>,
    <0.4600175, -167.0730993>,
    <0.4555336, -167.0755011>,
    <0.4626343, -167.0803290>,
    <0.4583333, -167.0684463>,
    <0.4444444, -167.0684463>,
    <0.4567224, -167.0847829>,
    <0.4600175, -167.0730993>,
    <0.4513889, -167.0684463>,
    <0.4516512, -167.0780353>,
    <0.4592439, -167.0828833>,
    <0.4719213, -167.0967589>,
    <0.4718928, -167.0922118>,
    <0.4713519, -167.1040945>,
    <0.4722196, -167.1040945>,
    <0.4722209, -167.0866350>,
    <0.4715910, -167.0988408>,
    <0.4715909, -167.1040945>,
    <0.4722199, -167.1002961>,
    <0.4720999, -167.0886906>,
    <0.4720733, -167.0813282>,
    <0.4718928, -167.0922118>,
    <0.4722209, -167.0866350>,
    <0.4722222, -167.0684463>,
    <0.4719575, -167.0780199>,
    <0.4720999, -167.0886906>,
    <0.4722216, -167.0765205>,
    <0.4720931, -167.0731150>,
    <0.4719346, -167.0830420>,
    <0.4716096, -167.0946052>,
    <0.4718928, -167.0922118>,
    <0.4719575, -167.0780199>,
    <0.4712365, -167.1040945>,
    <0.4713519, -167.1040945>,
    <0.4719346, -167.0830420>,
    <0.4716704, -167.0884034>,
    <0.4712772, -167.1040945>,
    <0.4715910, -167.0988408>,
    <0.5295912, -167.0966672>,
    <0.5304480, -167.0922118>,
    <0.5277791, -167.0862680>,
    <0.5277805, -167.1040945>,
    <0.5323571, -167.1040945>,
    <0.5291637, -167.0893515>,
    <0.5277800, -167.0972552>,
    <0.5301607, -167.1040945>,
    <0.5316401, -167.0996315>,
    <0.5322880, -167.0953092>,
    <0.5304480, -167.0922118>,
    <0.5323571, -167.1040945>,
    <0.5357857, -167.1040945>,
    <0.5305610, -167.0808361>,
    <0.5316401, -167.0996315>,
    <0.5342278, -167.1040945>,
    <0.5324904, -167.0894250>,
    <0.5305237, -167.0845917>,
    <0.5291415, -167.0819406>,
    <0.5304480, -167.0922118>,
    <0.5305610, -167.0808361>,
    <0.5277778, -167.0684463>,
    <0.5277791, -167.0862680>,
    <0.5305237, -167.0845917>,
    <0.5292194, -167.0748638>,
    <0.5277785, -167.0781532>,
    <0.5291637, -167.0893515>,
    <0.5460801, -167.0684463>,
    <0.5403948, -167.0684463>,
    <0.5467033, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5416667, -167.0684463>,
    <0.5439433, -167.0684463>,
    <0.5511294, -167.0684463>,
    <0.5486111, -167.0684463>,
    <0.5411102, -167.0684463>,
    <0.5356634, -167.0684463>,
    <0.5403948, -167.0684463>,
    <0.5416667, -167.0684463>,
    <0.5277778, -167.0684463>,
    <0.5328144, -167.0684463>,
    <0.5411102, -167.0684463>,
    <0.5347222, -167.0684463>,
    <0.5302961, -167.0684463>,
    <0.5361308, -167.0684463>,
    <0.5394409, -167.0684463>,
    <0.5403948, -167.0684463>,
    <0.5328144, -167.0684463>,
    <0.5378510, -167.0684463>,
    <0.5467033, -167.0684463>,
    <0.5361308, -167.0684463>,
    <0.5353327, -167.0684463>,
    <0.5422771, -167.0684463>,
    <0.5439433, -167.0684463>,
    <0.5381900, -167.0874134>,
    <0.5397057, -167.0803290>,
    <0.5305603, -167.0808361>,
    <0.5357836, -167.1040945>,
    <0.5467103, -167.0843941>,
    <0.5350326, -167.0805882>,
    <0.5324892, -167.0894250>,
    <0.5425696, -167.0918597>,
    <0.5435031, -167.0825328>,
    <0.5459095, -167.0754039>,
    <0.5397057, -167.0803290>,
    <0.5467103, -167.0843941>,
    <0.5555556, -167.0684463>,
    <0.5416667, -167.0684463>,
    <0.5435031, -167.0825328>,
    <0.5503052, -167.0779126>,
    <0.5486111, -167.0684463>,
    <0.5408883, -167.0731629>,
    <0.5349276, -167.0745144>,
    <0.5397057, -167.0803290>,
    <0.5416667, -167.0684463>,
    <0.5277778, -167.0684463>,
    <0.5305603, -167.0808361>,
    <0.5408883, -167.0731629>,
    <0.5347222, -167.0684463>,
    <0.5292190, -167.0748638>,
    <0.5350326, -167.0805882>,
    <0.5274781, -167.0966672>,
    <0.5274491, -167.0922118>,
    <0.5269078, -167.1040945>,
    <0.5277778, -167.1040945>,
    <0.5277778, -167.0862680>,
    <0.5271488, -167.0988043>,
    <0.5271478, -167.1040945>,
    <0.5277778, -167.0972552>,
    <0.5276243, -167.0890434>,
    <0.5276306, -167.0811941>,
    <0.5274491, -167.0922118>,
    <0.5277778, -167.0862680>,
    <0.5277778, -167.0684463>,
    <0.5275177, -167.0778504>,
    <0.5276243, -167.0890434>,
    <0.5277778, -167.0781532>,
    <0.5276595, -167.0727218>,
    <0.5274959, -167.0824124>,
    <0.5271666, -167.0945628>,
    <0.5274491, -167.0922118>,
    <0.5275177, -167.0778504>,
    <0.5267918, -167.1040945>,
    <0.5269078, -167.1040945>,
    <0.5274959, -167.0824124>,
    <0.5272228, -167.0885111>,
    <0.5268328, -167.1040945>,
    <0.5271488, -167.0988043>,
    <0.4871138, -167.0962969>,
    <0.4811529, -167.0922118>,
    <0.4837849, -167.1040945>,
    <0.4990142, -167.1040945>,
    <0.4845031, -167.0847867>,
    <0.4826716, -167.0990684>,
    <0.4904567, -167.1040945>,
    <0.4899918, -167.0920897>,
    <0.4831786, -167.0877222>,
    <0.4775251, -167.0830199>,
    <0.4811529, -167.0922118>,
    <0.4845031, -167.0847867>,
    <0.4722222, -167.0684463>,
    <0.4722222, -167.0866350>,
    <0.4831786, -167.0877222>,
    <0.4794311, -167.0780381>,
    <0.4722222, -167.0765205>,
    <0.4765798, -167.0893561>,
    <0.4773456, -167.0967589>,
    <0.4811529, -167.0922118>,
    <0.4722222, -167.0866350>,
    <0.4722222, -167.1040945>,
    <0.4837849, -167.1040945>,
    <0.4765798, -167.0893561>,
    <0.4722222, -167.1002961>,
    <0.4778242, -167.1040945>,
    <0.4826716, -167.0990684>,
    <0.4934151, -167.0868461>,
    <0.4904121, -167.0803290>,
    <0.4845031, -167.0847867>,
    <0.4990142, -167.1040945>,
    <0.4997310, -167.0781741>,
    <0.4870234, -167.0828854>,
    <0.4899918, -167.0920897>,
    <0.4994453, -167.0885054>,
    <0.4950604, -167.0792542>,
    <0.4940636, -167.0738489>,
    <0.4904121, -167.0803290>,
    <0.4997310, -167.0781741>,
    <0.5000000, -167.0684463>,
    <0.4861111, -167.0684463>,
    <0.4950604, -167.0792542>,
    <0.4998685, -167.0731996>,
    <0.4930556, -167.0684463>,
    <0.4877957, -167.0731005>,
    <0.4833121, -167.0755021>,
    <0.4904121, -167.0803290>,
    <0.4861111, -167.0684463>,
    <0.4722222, -167.0684463>,
    <0.4845031, -167.0847867>,
    <0.4877957, -167.0731005>,
    <0.4791667, -167.0684463>,
    <0.4794311, -167.0780381>,
    <0.4870234, -167.0828854>,
    <0.4997003, -167.0967598>,
    <0.4996714, -167.0922118>,
    <0.4991300, -167.1040945>,
    <0.5000000, -167.1040945>,
    <0.5000000, -167.0866383>,
    <0.4993693, -167.0988411>,
    <0.4993698, -167.1040945>,
    <0.5000000, -167.1002356>,
    <0.4998788, -167.0886935>,
    <0.4998506, -167.0813676>,
    <0.4996714, -167.0922118>,
    <0.5000000, -167.0866383>,
    <0.5000000, -167.0684463>,
    <0.4997310, -167.0781741>,
    <0.4998788, -167.0886935>,
    <0.5000000, -167.0765496>,
    <0.4998685, -167.0731996>,
    <0.4997099, -167.0831439>,
    <0.4993866, -167.0946437>,
    <0.4996714, -167.0922118>,
    <0.4997310, -167.0781741>,
    <0.4990142, -167.1040945>,
    <0.4991300, -167.1040945>,
    <0.4997099, -167.0831439>,
    <0.4994453, -167.0885054>,
    <0.4990551, -167.1040945>,
    <0.4993693, -167.0988411>,
    <0.5148899, -167.0962947>,
    <0.5089306, -167.0922118>,
    <0.5115628, -167.1040945>,
    <0.5267918, -167.1040945>,
    <0.5122743, -167.0847781>,
    <0.5104496, -167.0990691>,
    <0.5182345, -167.1040945>,
    <0.5177629, -167.0920809>,
    <0.5109519, -167.0877180>,
    <0.5053012, -167.0830186>,
    <0.5089306, -167.0922118>,
    <0.5122743, -167.0847781>,
    <0.5000000, -167.0684463>,
    <0.5000000, -167.0866383>,
    <0.5109519, -167.0877180>,
    <0.5072039, -167.0780315>,
    <0.5000000, -167.0765496>,
    <0.5043577, -167.0893579>,
    <0.5051233, -167.0967598>,
    <0.5089306, -167.0922118>,
    <0.5000000, -167.0866383>,
    <0.5000000, -167.1040945>,
    <0.5115628, -167.1040945>,
    <0.5043577, -167.0893579>,
    <0.5000000, -167.1002356>,
    <0.5056020, -167.1040945>,
    <0.5104496, -167.0990691>,
    <0.5183023, -167.0684463>,
    <0.5126171, -167.0684463>,
    <0.5189256, -167.0684463>,
    <0.5277778, -167.0684463>,
    <0.5138889, -167.0684463>,
    <0.5161656, -167.0684463>,
    <0.5233517, -167.0684463>,
    <0.5208333, -167.0684463>,
    <0.5133325, -167.0684463>,
    <0.5078857, -167.0684463>,
    <0.5126171, -167.0684463>,
    <0.5138889, -167.0684463>,
    <0.5000000, -167.0684463>,
    <0.5050367, -167.0684463>,
    <0.5133325, -167.0684463>,
    <0.5069444, -167.0684463>,
    <0.5025184, -167.0684463>,
    <0.5083531, -167.0684463>,
    <0.5116632, -167.0684463>,
    <0.5126171, -167.0684463>,
    <0.5050367, -167.0684463>,
    <0.5100734, -167.0684463>,
    <0.5189256, -167.0684463>,
    <0.5083531, -167.0684463>,
    <0.5075551, -167.0684463>,
    <0.5144995, -167.0684463>,
    <0.5161656, -167.0684463>,
    <0.5211934, -167.0867630>,
    <0.5181899, -167.0803290>,
    <0.5122743, -167.0847781>,
    <0.5267918, -167.1040945>,
    <0.5275177, -167.0778504>,
    <0.5147971, -167.0828807>,
    <0.5177629, -167.0920809>,
    <0.5272228, -167.0885111>,
    <0.5228163, -167.0790997>,
    <0.5218436, -167.0737680>,
    <0.5181899, -167.0803290>,
    <0.5275177, -167.0778504>,
    <0.5277778, -167.0684463>,
    <0.5138889, -167.0684463>,
    <0.5228163, -167.0790997>,
    <0.5276595, -167.0727218>,
    <0.5208333, -167.0684463>,
    <0.5155728, -167.0730985>,
    <0.5110883, -167.0754999>,
    <0.5181899, -167.0803290>,
    <0.5138889, -167.0684463>,
    <0.5000000, -167.0684463>,
    <0.5122743, -167.0847781>,
    <0.5155728, -167.0730985>,
    <0.5069444, -167.0684463>,
    <0.5072039, -167.0780315>,
    <0.5147971, -167.0828807>,
    <0.0064387, -167.1108664>,
    <0.0041600, -167.1123151>,
    <0.0029324, -167.1229615>,
    <0.0124799, -167.1040945>,
    <0.0061825, -167.1040945>,
    <0.0034246, -167.1186929>,
    <0.0064037, -167.1161019>,
    <0.0093092, -167.1040945>,
    <0.0054291, -167.1071566>,
    <0.0025856, -167.1100456>,
    <0.0041600, -167.1123151>,
    <0.0061825, -167.1040945>,
    <0.0000000, -167.1040945>,
    <0.0000000, -167.1196784>,
    <0.0054291, -167.1071566>,
    <0.0030842, -167.1040945>,
    <0.0000000, -167.1103620>,
    <0.0018668, -167.1163741>,
    <0.0017731, -167.1209279>,
    <0.0041600, -167.1123151>,
    <0.0000000, -167.1196784>,
    <0.0000000, -167.1287564>,
    <0.0029324, -167.1229615>,
    <0.0018668, -167.1163741>,
    <0.0000000, -167.1261981>,
    <0.0011118, -167.1265593>,
    <0.0034246, -167.1186929>,
    <0.5011838, -167.1109163>,
    <0.3282341, -167.1123151>,
    <0.4683918, -167.1040945>,
    <0.9847022, -167.1040945>,
    <0.2234069, -167.1231612>,
    <0.4141003, -167.1072788>,
    <0.7165148, -167.1040945>,
    <0.4877798, -167.1165400>,
    <0.2663912, -167.1187138>,
    <0.1379102, -167.1209778>,
    <0.3282341, -167.1123151>,
    <0.2234069, -167.1231612>,
    <0.0000000, -167.1287564>,
    <0.0000000, -167.1196784>,
    <0.2663912, -167.1187138>,
    <0.0823950, -167.1266928>,
    <0.0000000, -167.1261981>,
    <0.1524904, -167.1162576>,
    <0.1991565, -167.1100456>,
    <0.3282341, -167.1123151>,
    <0.0000000, -167.1196784>,
    <0.0000000, -167.1040945>,
    <0.4683918, -167.1040945>,
    <0.1524904, -167.1162576>,
    <0.0000000, -167.1103620>,
    <0.2314471, -167.1040945>,
    <0.4141003, -167.1072788>,
    <0.0257301, -167.1106496>,
    <0.0265412, -167.1123151>,
    <0.0255357, -167.1040945>,
    <0.0240680, -167.1040945>,
    <0.0267756, -167.1220942>,
    <0.0259660, -167.1076129>,
    <0.0247107, -167.1040945>,
    <0.0255276, -167.1137978>,
    <0.0266923, -167.1186210>,
    <0.0272181, -167.1197228>,
    <0.0265412, -167.1123151>,
    <0.0267756, -167.1220942>,
    <0.0277778, -167.1287564>,
    <0.0277778, -167.1157255>,
    <0.0266923, -167.1186210>,
    <0.0274931, -167.1268637>,
    <0.0277778, -167.1243284>,
    <0.0272828, -167.1143604>,
    <0.0269081, -167.1090574>,
    <0.0265412, -167.1123151>,
    <0.0277778, -167.1157255>,
    <0.0277778, -167.1040945>,
    <0.0255357, -167.1040945>,
    <0.0272828, -167.1143604>,
    <0.0277778, -167.1077203>,
    <0.0265874, -167.1040945>,
    <0.0259660, -167.1076129>,
    <0.0224916, -167.1106496>,
    <0.0214419, -167.1123151>,
    <0.0267756, -167.1220942>,
    <0.0240680, -167.1040945>,
    <0.0176810, -167.1040945>,
    <0.0240010, -167.1170071>,
    <0.0255276, -167.1137978>,
    <0.0206145, -167.1040945>,
    <0.0190690, -167.1071285>,
    <0.0189202, -167.1108241>,
    <0.0214419, -167.1123151>,
    <0.0176810, -167.1040945>,
    <0.0124798, -167.1040945>,
    <0.0240782, -167.1227923>,
    <0.0190690, -167.1071285>,
    <0.0150062, -167.1040945>,
    <0.0197635, -167.1158365>,
    <0.0231084, -167.1189381>,
    <0.0250184, -167.1214895>,
    <0.0214419, -167.1123151>,
    <0.0240782, -167.1227923>,
    <0.0277778, -167.1287564>,
    <0.0267756, -167.1220942>,
    <0.0231084, -167.1189381>,
    <0.0264284, -167.1265810>,
    <0.0274931, -167.1268637>,
    <0.0240010, -167.1170071>,
    <0.0132274, -167.1175960>,
    <0.0134192, -167.1205358>,
    <0.0240782, -167.1227923>,
    <0.0124799, -167.1040945>,
    <0.0029324, -167.1229615>,
    <0.0194114, -167.1218043>,
    <0.0197635, -167.1158365>,
    <0.0064037, -167.1161019>,
    <0.0077440, -167.1218485>,
    <0.0073549, -167.1252525>,
    <0.0134192, -167.1205358>,
    <0.0029324, -167.1229615>,
    <0.0000000, -167.1287564>,
    <0.0130678, -167.1287564>,
    <0.0077440, -167.1218485>,
    <0.0011118, -167.1265593>,
    <0.0053934, -167.1287564>,
    <0.0131934, -167.1258172>,
    <0.0195857, -167.1252102>,
    <0.0134192, -167.1205358>,
    <0.0130678, -167.1287564>,
    <0.0277778, -167.1287564>,
    <0.0240782, -167.1227923>,
    <0.0131934, -167.1258172>,
    <0.0213955, -167.1287564>,
    <0.0264284, -167.1265810>,
    <0.0194114, -167.1218043>,
    <0.7089525, -167.1175791>,
    <0.6523081, -167.1205421>,
    <0.2234069, -167.1231655>,
    <0.9847021, -167.1041136>,
    <0.9753930, -167.1224953>,
    <0.4034415, -167.1220643>,
    <0.4877797, -167.1165494>,
    <0.9790787, -167.1152176>,
    <0.8212682, -167.1215636>,
    <0.7778713, -167.1251376>,
    <0.6523081, -167.1205421>,
    <0.9753930, -167.1224953>,
    <0.9722222, -167.1287564>,
    <0.5115619, -167.1287564>,
    <0.8212682, -167.1215636>,
    <0.9733789, -167.1264725>,
    <0.7827657, -167.1287564>,
    <0.5583739, -167.1260244>,
    <0.3468192, -167.1253051>,
    <0.6523081, -167.1205421>,
    <0.5115619, -167.1287564>,
    <0.0000000, -167.1287564>,
    <0.2234069, -167.1231655>,
    <0.5583739, -167.1260244>,
    <0.2202198, -167.1287564>,
    <0.0823950, -167.1266944>,
    <0.4034415, -167.1220643>,
    <0.9795271, -167.1107626>,
    <0.9773344, -167.1123279>,
    <0.9753930, -167.1224953>,
    <0.9847021, -167.1041136>,
    <0.9806788, -167.1041136>,
    <0.9760860, -167.1188661>,
    <0.9790787, -167.1152176>,
    <0.9828264, -167.1041136>,
    <0.9795289, -167.1069379>,
    <0.9765830, -167.1101334>,
    <0.9773344, -167.1123279>,
    <0.9806788, -167.1041136>,
    <0.9750789, -167.1041136>,
    <0.9732398, -167.1199785>,
    <0.9795289, -167.1069379>,
    <0.9781662, -167.1041136>,
    <0.9741520, -167.1121092>,
    <0.9753946, -167.1159522>,
    <0.9745474, -167.1208895>,
    <0.9773344, -167.1123279>,
    <0.9732398, -167.1199785>,
    <0.9722222, -167.1287564>,
    <0.9753930, -167.1224953>,
    <0.9753946, -167.1159522>,
    <0.9725657, -167.1257934>,
    <0.9733789, -167.1264725>,
    <0.9760860, -167.1188661>,
    <0.9738671, -167.1101299>,
    <0.9731744, -167.1123215>,
    <0.9732398, -167.1199785>,
    <0.9750789, -167.1041136>,
    <0.9739755, -167.1041062>,
    <0.9732151, -167.1170888>,
    <0.9741520, -167.1121092>,
    <0.9746004, -167.1041104>,
    <0.9736305, -167.1076438>,
    <0.9728986, -167.1098044>,
    <0.9731744, -167.1123215>,
    <0.9739755, -167.1041062>,
    <0.9722222, -167.1040945>,
    <0.9722222, -167.1186953>,
    <0.9736305, -167.1076438>,
    <0.9731589, -167.1041008>,
    <0.9722222, -167.1075966>,
    <0.9725713, -167.1163585>,
    <0.9727147, -167.1199379>,
    <0.9731744, -167.1123215>,
    <0.9722222, -167.1186953>,
    <0.9722222, -167.1287564>,
    <0.9732398, -167.1199785>,
    <0.9725713, -167.1163585>,
    <0.9722222, -167.1268389>,
    <0.9725657, -167.1257934>,
    <0.9732151, -167.1170888>,
    <0.5705847, -167.1443229>,
    <0.3240741, -167.1533103>,
    <0.5115619, -167.1287564>,
    <0.9722222, -167.1287564>,
    <0.4744807, -167.1664684>,
    <0.4188978, -167.1408919>,
    <0.7827657, -167.1287564>,
    <0.7496973, -167.1456163>,
    <0.4066005, -167.1605300>,
    <0.1996387, -167.1706942>,
    <0.3240741, -167.1533103>,
    <0.4744807, -167.1664684>,
    <0.0000000, -167.2024179>,
    <0.0000000, -167.1605800>,
    <0.4066005, -167.1605300>,
    <0.2061675, -167.1867974>,
    <0.0000000, -167.1838663>,
    <0.1395461, -167.1574497>,
    <0.2089090, -167.1428508>,
    <0.3240741, -167.1533103>,
    <0.0000000, -167.1605800>,
    <0.0000000, -167.1287564>,
    <0.5115619, -167.1287564>,
    <0.1395461, -167.1574497>,
    <0.0000000, -167.1409327>,
    <0.2202198, -167.1287564>,
    <0.4188978, -167.1408919>,
    <0.5453555, -167.0794526>,
    <0.3278814, -167.0842391>,
    <0.3974936, -167.0966789>,
    <0.9836443, -167.0684463>,
    <0.4724026, -167.0684463>,
    <0.3697880, -167.0917279>,
    <0.6833616, -167.0829098>,
    <0.7200819, -167.0684463>,
    <0.4095181, -167.0753181>,
    <0.2000710, -167.0788822>,
    <0.3278814, -167.0842391>,
    <0.4724026, -167.0684463>,
    <0.0000000, -167.0684463>,
    <0.0000000, -167.0943971>,
    <0.4095181, -167.0753181>,
    <0.2339335, -167.0684463>,
    <0.0000000, -167.0816247>,
    <0.1384867, -167.0901067>,
    <0.1813437, -167.0977849>,
    <0.3278814, -167.0842391>,
    <0.0000000, -167.0943971>,
    <0.0000000, -167.1158246>,
    <0.3974936, -167.0966789>,
    <0.1384867, -167.0901067>,
    <0.0000000, -167.1096873>,
    <0.1544557, -167.1083851>,
    <0.3697880, -167.0917279>,
    <0.7260135, -167.0805640>,
    <0.6519545, -167.0842391>,
    <0.3016562, -167.1011243>,
    <0.9722222, -167.0684463>,
    <0.9782212, -167.0684463>,
    <0.4254013, -167.0951595>,
    <0.5676360, -167.0881626>,
    <0.9752611, -167.0684463>,
    <0.8472128, -167.0747877>,
    <0.7528273, -167.0794526>,
    <0.6519545, -167.0842391>,
    <0.9782212, -167.0684463>,
    <0.9836412, -167.0684463>,
    <0.3974923, -167.0966789>,
    <0.8472128, -167.0747877>,
    <0.9810286, -167.0684463>,
    <0.6833594, -167.0829098>,
    <0.5242778, -167.0904808>,
    <0.3377757, -167.0994667>,
    <0.6519545, -167.0842391>,
    <0.3974923, -167.0966789>,
    <0.0000000, -167.1158246>,
    <0.3016562, -167.1011243>,
    <0.5242778, -167.0904808>,
    <0.1544552, -167.1083851>,
    <0.1211621, -167.1099202>,
    <0.4254013, -167.0951595>,
    <0.0341980, -167.1109029>,
    <0.0319377, -167.1123151>,
    <0.0306365, -167.1231073>,
    <0.0402577, -167.1040945>,
    <0.0339602, -167.1040945>,
    <0.0311373, -167.1189533>,
    <0.0341298, -167.1162039>,
    <0.0370869, -167.1040945>,
    <0.0332872, -167.1068303>,
    <0.0303634, -167.1090574>,
    <0.0319377, -167.1123151>,
    <0.0339602, -167.1040945>,
    <0.0277778, -167.1040945>,
    <0.0277778, -167.1157255>,
    <0.0332872, -167.1068303>,
    <0.0308619, -167.1040945>,
    <0.0277778, -167.1077203>,
    <0.0298779, -167.1140038>,
    <0.0295324, -167.1199761>,
    <0.0319377, -167.1123151>,
    <0.0277778, -167.1157255>,
    <0.0277778, -167.1287564>,
    <0.0306365, -167.1231073>,
    <0.0298779, -167.1140038>,
    <0.0277778, -167.1243284>,
    <0.0288158, -167.1267051>,
    <0.0311373, -167.1189533>,
    <0.0114711, -167.1443740>,
    <0.0185185, -167.1533103>,
    <0.0130678, -167.1287564>,
    <0.0000000, -167.1287564>,
    <0.0142983, -167.1666728>,
    <0.0157525, -167.1408501>,
    <0.0053934, -167.1287564>,
    <0.0064263, -167.1457977>,
    <0.0161985, -167.1606560>,
    <0.0220931, -167.1707791>,
    <0.0185185, -167.1533103>,
    <0.0142983, -167.1666728>,
    <0.0277778, -167.2024179>,
    <0.0277778, -167.1607154>,
    <0.0161985, -167.1606560>,
    <0.0219285, -167.1869068>,
    <0.0277778, -167.1838308>,
    <0.0237951, -167.1575302>,
    <0.0217855, -167.1428846>,
    <0.0185185, -167.1533103>,
    <0.0277778, -167.1607154>,
    <0.0277778, -167.1287564>,
    <0.0130678, -167.1287564>,
    <0.0237951, -167.1575302>,
    <0.0277778, -167.1413913>,
    <0.0213955, -167.1287564>,
    <0.0157525, -167.1408501>,
    <0.0058894, -167.1584683>,
    <0.0092593, -167.1778641>,
    <0.0142983, -167.1666728>,
    <0.0000000, -167.1287564>,
    <0.0000000, -167.1605800>,
    <0.0121008, -167.1715532>,
    <0.0064263, -167.1457977>,
    <0.0000000, -167.1409327>,
    <0.0040548, -167.1681491>,
    <0.0057900, -167.1858200>,
    <0.0092593, -167.1778641>,
    <0.0000000, -167.1605800>,
    <0.0000000, -167.2024179>,
    <0.0139007, -167.2024179>,
    <0.0040548, -167.1681491>,
    <0.0000000, -167.1838663>,
    <0.0060835, -167.2024179>,
    <0.0118847, -167.1917530>,
    <0.0163090, -167.1873432>,
    <0.0092593, -167.1778641>,
    <0.0139007, -167.2024179>,
    <0.0277778, -167.2024179>,
    <0.0142983, -167.1666728>,
    <0.0118847, -167.1917530>,
    <0.0217066, -167.2024179>,
    <0.0219285, -167.1869068>,
    <0.0121008, -167.1715532>,
    <0.5674179, -167.2232074>,
    <0.3240741, -167.2357456>,
    <0.4856978, -167.2024179>,
    <0.9722222, -167.2024179>,
    <0.4876776, -167.2522483>,
    <0.4150766, -167.2169804>,
    <0.7593015, -167.2024179>,
    <0.7605448, -167.2241867>,
    <0.4162044, -167.2450388>,
    <0.2029379, -167.2602946>,
    <0.3240741, -167.2357456>,
    <0.4876776, -167.2522483>,
    <0.0000000, -167.3024008>,
    <0.0000000, -167.2507837>,
    <0.4162044, -167.2450388>,
    <0.2137247, -167.2804214>,
    <0.0000000, -167.2798504>,
    <0.1419491, -167.2441968>,
    <0.2024430, -167.2228413>,
    <0.3240741, -167.2357456>,
    <0.0000000, -167.2507837>,
    <0.0000000, -167.2024179>,
    <0.4856978, -167.2024179>,
    <0.1419491, -167.2441968>,
    <0.0000000, -167.2235884>,
    <0.2124913, -167.2024179>,
    <0.4150766, -167.2169804>,
    <0.7667683, -167.1582978>,
    <0.6481481, -167.1778641>,
    <0.4744807, -167.1664684>,
    <0.9722222, -167.1287564>,
    <0.9722222, -167.1601023>,
    <0.5501909, -167.1714363>,
    <0.7496973, -167.1456163>,
    <0.9722222, -167.1407348>,
    <0.8302730, -167.1678822>,
    <0.7695726, -167.1857006>,
    <0.6481481, -167.1778641>,
    <0.9722222, -167.1601023>,
    <0.9722222, -167.2024179>,
    <0.4856978, -167.2024179>,
    <0.8302730, -167.1678822>,
    <0.9722222, -167.1835237>,
    <0.7593015, -167.2024179>,
    <0.5563420, -167.1917403>,
    <0.4020817, -167.1872921>,
    <0.6481481, -167.1778641>,
    <0.4856978, -167.2024179>,
    <0.0000000, -167.2024179>,
    <0.4744807, -167.1664684>,
    <0.5563420, -167.1917403>,
    <0.2124913, -167.2024179>,
    <0.2061675, -167.1867974>,
    <0.5501909, -167.1714363>,
    <0.9644289, -167.1109046>,
    <0.9671230, -167.1123151>,
    <0.9649456, -167.1040945>,
    <0.9569245, -167.1040945>,
    <0.9687225, -167.1231144>,
    <0.9657259, -167.1070407>,
    <0.9610909, -167.1040945>,
    <0.9645968, -167.1164632>,
    <0.9680856, -167.1188144>,
    <0.9700725, -167.1207203>,
    <0.9671230, -167.1123151>,
    <0.9687225, -167.1231144>,
    <0.9722222, -167.1287564>,
    <0.9722222, -167.1186953>,
    <0.9680856, -167.1188144>,
    <0.9709466, -167.1267000>,
    <0.9722222, -167.1268389>,
    <0.9696306, -167.1154527>,
    <0.9691283, -167.1097999>,
    <0.9671230, -167.1123151>,
    <0.9722222, -167.1186953>,
    <0.9722222, -167.1040945>,
    <0.9649456, -167.1040945>,
    <0.9696306, -167.1154527>,
    <0.9722222, -167.1075966>,
    <0.9686266, -167.1040945>,
    <0.9657259, -167.1070407>,
    <0.0184916, -167.0790594>,
    <0.0223248, -167.0842391>,
    <0.0206241, -167.0951061>,
    <0.0114190, -167.0684463>,
    <0.0195984, -167.0684463>,
    <0.0213059, -167.0907495>,
    <0.0158092, -167.0811612>,
    <0.0155087, -167.0684463>,
    <0.0207809, -167.0752956>,
    <0.0243697, -167.0792115>,
    <0.0223248, -167.0842391>,
    <0.0195984, -167.0684463>,
    <0.0277778, -167.0684463>,
    <0.0277778, -167.0957145>,
    <0.0207809, -167.0752956>,
    <0.0236881, -167.0684463>,
    <0.0277778, -167.0828793>,
    <0.0254589, -167.0908346>,
    <0.0246261, -167.0977211>,
    <0.0223248, -167.0842391>,
    <0.0277778, -167.0957145>,
    <0.0277778, -167.1158246>,
    <0.0206241, -167.0951061>,
    <0.0254589, -167.0908346>,
    <0.0277778, -167.1099991>,
    <0.0249390, -167.1076030>,
    <0.0213059, -167.0907495>,
    <0.0095056, -167.0806017>,
    <0.0130656, -167.0842391>,
    <0.0192474, -167.1012751>,
    <0.0000000, -167.0684463>,
    <0.0057095, -167.0684463>,
    <0.0171075, -167.0953779>,
    <0.0116678, -167.0883472>,
    <0.0028548, -167.0684463>,
    <0.0086663, -167.0747943>,
    <0.0127045, -167.0790594>,
    <0.0130656, -167.0842391>,
    <0.0057095, -167.0684463>,
    <0.0114190, -167.0684463>,
    <0.0206241, -167.0951061>,
    <0.0086663, -167.0747943>,
    <0.0085643, -167.0684463>,
    <0.0158092, -167.0811612>,
    <0.0168661, -167.0897032>,
    <0.0201787, -167.0991112>,
    <0.0130656, -167.0842391>,
    <0.0206241, -167.0951061>,
    <0.0277778, -167.1158246>,
    <0.0192474, -167.1012751>,
    <0.0168661, -167.0897032>,
    <0.0249390, -167.1076030>,
    <0.0243567, -167.1099897>,
    <0.0171075, -167.0953779>,
    <0.0071267, -167.0910376>,
    <0.0092593, -167.1000319>,
    <0.0000000, -167.0943971>,
    <0.0000000, -167.0684463>,
    <0.0192474, -167.1012751>,
    <0.0039957, -167.0968287>,
    <0.0000000, -167.0816247>,
    <0.0116678, -167.0883472>,
    <0.0141952, -167.1006462>,
    <0.0173991, -167.1082391>,
    <0.0092593, -167.1000319>,
    <0.0192474, -167.1012751>,
    <0.0277778, -167.1158246>,
    <0.0133120, -167.1158246>,
    <0.0141952, -167.1006462>,
    <0.0243567, -167.1099897>,
    <0.0215251, -167.1158246>,
    <0.0114205, -167.1084535>,
    <0.0056428, -167.1065196>,
    <0.0092593, -167.1000319>,
    <0.0133120, -167.1158246>,
    <0.0000000, -167.1158246>,
    <0.0000000, -167.0943971>,
    <0.0114205, -167.1084535>,
    <0.0054899, -167.1158246>,
    <0.0000000, -167.1096873>,
    <0.0039957, -167.0968287>,
    <0.7235622, -167.0910603>,
    <0.6481482, -167.1000319>,
    <0.9722222, -167.0946389>,
    <0.9722222, -167.0684463>,
    <0.3016562, -167.1011243>,
    <0.8322202, -167.0969687>,
    <0.9722222, -167.0816043>,
    <0.5676360, -167.0881626>,
    <0.4773829, -167.1005703>,
    <0.3639295, -167.1082014>,
    <0.6481482, -167.1000319>,
    <0.3016562, -167.1011243>,
    <0.0000000, -167.1158246>,
    <0.5059138, -167.1158246>,
    <0.4773829, -167.1005703>,
    <0.1211621, -167.1099202>,
    <0.2186007, -167.1158246>,
    <0.5721896, -167.1084658>,
    <0.7746266, -167.1065800>,
    <0.6481482, -167.1000319>,
    <0.5059138, -167.1158246>,
    <0.9722222, -167.1158246>,
    <0.9722222, -167.0946389>,
    <0.5721896, -167.1084658>,
    <0.7798608, -167.1158246>,
    <0.9722222, -167.1099625>,
    <0.8322202, -167.0969687>,
    <0.5749701, -167.1384097>,
    <0.3240741, -167.1524837>,
    <0.4976701, -167.1695057>,
    <0.9722222, -167.1158246>,
    <0.5059138, -167.1158246>,
    <0.4220398, -167.1620898>,
    <0.7716887, -167.1385089>,
    <0.7798608, -167.1158246>,
    <0.4271086, -167.1317119>,
    <0.2074970, -167.1378791>,
    <0.3240741, -167.1524837>,
    <0.5059138, -167.1158246>,
    <0.0000000, -167.1158246>,
    <0.0000000, -167.1673835>,
    <0.4271086, -167.1317119>,
    <0.2186007, -167.1158246>,
    <0.0000000, -167.1360519>,
    <0.1421410, -167.1608484>,
    <0.2054361, -167.1787937>,
    <0.3240741, -167.1524837>,
    <0.0000000, -167.1673835>,
    <0.0000000, -167.2258020>,
    <0.4976701, -167.1695057>,
    <0.1421410, -167.1608484>,
    <0.0000000, -167.2002138>,
    <0.2192108, -167.2010049>,
    <0.4220398, -167.1620898>,
    <0.0115658, -167.2232074>,
    <0.0185185, -167.2357456>,
    <0.0139007, -167.2024179>,
    <0.0000000, -167.2024179>,
    <0.0138441, -167.2522483>,
    <0.0159184, -167.2169804>,
    <0.0060835, -167.2024179>,
    <0.0060479, -167.2241867>,
    <0.0158862, -167.2450388>,
    <0.0219796, -167.2602946>,
    <0.0185185, -167.2357456>,
    <0.0138441, -167.2522483>,
    <0.0277778, -167.3024008>,
    <0.0277778, -167.2507837>,
    <0.0158862, -167.2450388>,
    <0.0216714, -167.2804214>,
    <0.0277778, -167.2798504>,
    <0.0237221, -167.2441968>,
    <0.0219937, -167.2228413>,
    <0.0185185, -167.2357456>,
    <0.0277778, -167.2507837>,
    <0.0277778, -167.2024179>,
    <0.0139007, -167.2024179>,
    <0.0237221, -167.2441968>,
    <0.0277778, -167.2235884>,
    <0.0217066, -167.2024179>,
    <0.0159184, -167.2169804>,
    <0.0057758, -167.2436308>,
    <0.0092593, -167.2690732>,
    <0.0138441, -167.2522483>,
    <0.0000000, -167.2024179>,
    <0.0000000, -167.2507837>,
    <0.0118396, -167.2596042>,
    <0.0060479, -167.2241867>,
    <0.0000000, -167.2235884>,
    <0.0040494, -167.2587824>,
    <0.0057897, -167.2811646>,
    <0.0092593, -167.2690732>,
    <0.0000000, -167.2507837>,
    <0.0000000, -167.3024008>,
    <0.0138995, -167.3024008>,
    <0.0040494, -167.2587824>,
    <0.0000000, -167.2798504>,
    <0.0060828, -167.3024008>,
    <0.0118711, -167.2878319>,
    <0.0161952, -167.2815307>,
    <0.0092593, -167.2690732>,
    <0.0138995, -167.3024008>,
    <0.0277778, -167.3024008>,
    <0.0138441, -167.2522483>,
    <0.0118711, -167.2878319>,
    <0.0217060, -167.3024008>,
    <0.0216714, -167.2804214>,
    <0.0118396, -167.2596042>,
    <0.5673710, -167.3280360>,
    <0.3240741, -167.3434849>,
    <0.4857402, -167.3024008>,
    <0.9722222, -167.3024008>,
    <0.4874476, -167.3638575>,
    <0.4150873, -167.3203558>,
    <0.7593249, -167.3024008>,
    <0.7603956, -167.3292549>,
    <0.4160744, -167.3549573>,
    <0.2028804, -167.3739447>,
    <0.3240741, -167.3434849>,
    <0.4874476, -167.3638575>,
    <0.0000000, -167.4256532>,
    <0.0000000, -167.3627833>,
    <0.4160744, -167.3549573>,
    <0.2135708, -167.3985780>,
    <0.0000000, -167.3982231>,
    <0.1419361, -167.3543311>,
    <0.2024536, -167.3277674>,
    <0.3240741, -167.3434849>,
    <0.0000000, -167.3627833>,
    <0.0000000, -167.3024008>,
    <0.4857402, -167.3024008>,
    <0.1419361, -167.3543311>,
    <0.0000000, -167.3288803>,
    <0.2125119, -167.3024008>,
    <0.4150873, -167.3203558>,
    <0.7700676, -167.2436308>,
    <0.6481481, -167.2690732>,
    <0.4876776, -167.2522483>,
    <0.9722222, -167.2024179>,
    <0.9722222, -167.2507837>,
    <0.5578365, -167.2596042>,
    <0.7605448, -167.2241867>,
    <0.9722222, -167.2235884>,
    <0.8304927, -167.2587824>,
    <0.7695832, -167.2811646>,
    <0.6481481, -167.2690732>,
    <0.9722222, -167.2507837>,
    <0.9722222, -167.3024008>,
    <0.4857402, -167.3024008>,
    <0.8304927, -167.2587824>,
    <0.9722222, -167.2798504>,
    <0.7593249, -167.3024008>,
    <0.5567352, -167.2878319>,
    <0.4053915, -167.2815307>,
    <0.6481481, -167.2690732>,
    <0.4857402, -167.3024008>,
    <0.0000000, -167.3024008>,
    <0.4876776, -167.2522483>,
    <0.5567352, -167.2878319>,
    <0.2125119, -167.3024008>,
    <0.2137247, -167.2804214>,
    <0.5578365, -167.2596042>,
    <0.0113473, -167.1384097>,
    <0.0185185, -167.1524837>,
    <0.0135586, -167.1695056>,
    <0.0000000, -167.1158246>,
    <0.0133120, -167.1158246>,
    <0.0157191, -167.1620911>,
    <0.0057298, -167.1385099>,
    <0.0054899, -167.1158246>,
    <0.0155668, -167.1317006>,
    <0.0218465, -167.1376976>,
    <0.0185185, -167.1524837>,
    <0.0133120, -167.1158246>,
    <0.0277778, -167.1158246>,
    <0.0277778, -167.1666572>,
    <0.0155668, -167.1317006>,
    <0.0215251, -167.1158246>,
    <0.0277778, -167.1354565>,
    <0.0237166, -167.1604406>,
    <0.0219082, -167.1786121>,
    <0.0185185, -167.1524837>,
    <0.0277778, -167.1666572>,
    <0.0277778, -167.2258020>,
    <0.0135586, -167.1695056>,
    <0.0237166, -167.1604406>,
    <0.0277778, -167.1998167>,
    <0.0215145, -167.2010046>,
    <0.0157191, -167.1620911>,
    <0.0057045, -167.1604642>,
    <0.0092593, -167.1891429>,
    <0.0000000, -167.1673835>,
    <0.0000000, -167.1158246>,
    <0.0135586, -167.1695056>,
    <0.0040527, -167.1769074>,
    <0.0000000, -167.1360519>,
    <0.0057298, -167.1385099>,
    <0.0116818, -167.1780778>,
    <0.0161241, -167.2025631>,
    <0.0092593, -167.1891429>,
    <0.0135586, -167.1695056>,
    <0.0277778, -167.2258020>,
    <0.0139006, -167.2258020>,
    <0.0116818, -167.1780778>,
    <0.0215145, -167.2010046>,
    <0.0217066, -167.2258020>,
    <0.0118632, -167.2097098>,
    <0.0057900, -167.2020326>,
    <0.0092593, -167.1891429>,
    <0.0139006, -167.2258020>,
    <0.0000000, -167.2258020>,
    <0.0000000, -167.1673835>,
    <0.0118632, -167.2097098>,
    <0.0060834, -167.2258020>,
    <0.0000000, -167.2002138>,
    <0.0040527, -167.1769074>,
    <0.5673912, -167.2539957>,
    <0.3240741, -167.2709932>,
    <0.4875682, -167.2933857>,
    <0.9722222, -167.2258020>,
    <0.4857005, -167.2258020>,
    <0.4161465, -167.2836036>,
    <0.7604746, -167.2553296>,
    <0.7593049, -167.2258020>,
    <0.4150593, -167.2455535>,
    <0.2024436, -167.2537633>,
    <0.3240741, -167.2709932>,
    <0.4857005, -167.2258020>,
    <0.0000000, -167.2258020>,
    <0.0000000, -167.2924560>,
    <0.4150593, -167.2455535>,
    <0.2124906, -167.2258020>,
    <0.0000000, -167.2550533>,
    <0.1419466, -167.2830552>,
    <0.2029106, -167.3045527>,
    <0.3240741, -167.2709932>,
    <0.0000000, -167.2924560>,
    <0.0000000, -167.3613758>,
    <0.4875682, -167.2933857>,
    <0.1419466, -167.2830552>,
    <0.0000000, -167.3313235>,
    <0.2136475, -167.3315832>,
    <0.4161465, -167.2836036>,
    <0.7725657, -167.1604767>,
    <0.6481481, -167.1891429>,
    <0.9722222, -167.1674336>,
    <0.9722222, -167.1158246>,
    <0.4976701, -167.1695057>,
    <0.8303781, -167.1769355>,
    <0.9722222, -167.1361016>,
    <0.7716887, -167.1385089>,
    <0.5633575, -167.1780778>,
    <0.4078797, -167.2025631>,
    <0.6481481, -167.1891429>,
    <0.4976701, -167.1695057>,
    <0.0000000, -167.2258020>,
    <0.4857005, -167.2258020>,
    <0.5633575, -167.1780778>,
    <0.2192108, -167.2010049>,
    <0.2124906, -167.2258020>,
    <0.5570093, -167.2097099>,
    <0.7695733, -167.2020451>,
    <0.6481481, -167.1891429>,
    <0.4857005, -167.2258020>,
    <0.9722222, -167.2258020>,
    <0.9722222, -167.1674336>,
    <0.5570093, -167.2097099>,
    <0.7593049, -167.2258020>,
    <0.9722222, -167.2002392>,
    <0.8303781, -167.1769355>,
    <0.9631519, -167.0794526>,
    <0.9667693, -167.0842391>,
    <0.9656116, -167.0966788>,
    <0.9558634, -167.0684463>,
    <0.9643632, -167.0684463>,
    <0.9660719, -167.0917323>,
    <0.9608573, -167.0829096>,
    <0.9602443, -167.0684463>,
    <0.9654101, -167.0753177>,
    <0.9688942, -167.0789426>,
    <0.9667693, -167.0842391>,
    <0.9643632, -167.0684463>,
    <0.9722222, -167.0684463>,
    <0.9722222, -167.0946389>,
    <0.9654101, -167.0753177>,
    <0.9683302, -167.0684463>,
    <0.9722222, -167.0816043>,
    <0.9699196, -167.0902473>,
    <0.9692063, -167.0978454>,
    <0.9667693, -167.0842391>,
    <0.9722222, -167.0946389>,
    <0.9722222, -167.1158246>,
    <0.9656116, -167.0966788>,
    <0.9699196, -167.0902473>,
    <0.9722222, -167.1099625>,
    <0.9696534, -167.1083847>,
    <0.9660719, -167.0917323>,
    <0.0115672, -167.3280360>,
    <0.0185185, -167.3434849>,
    <0.0138995, -167.3024008>,
    <0.0000000, -167.3024008>,
    <0.0138507, -167.3638575>,
    <0.0159181, -167.3203558>,
    <0.0060828, -167.3024008>,
    <0.0060522, -167.3292549>,
    <0.0158899, -167.3549573>,
    <0.0219812, -167.3739447>,
    <0.0185185, -167.3434849>,
    <0.0138507, -167.3638575>,
    <0.0277778, -167.4256532>,
    <0.0277778, -167.3627833>,
    <0.0158899, -167.3549573>,
    <0.0216758, -167.3985780>,
    <0.0277778, -167.3982231>,
    <0.0237225, -167.3543311>,
    <0.0219934, -167.3277674>,
    <0.0185185, -167.3434849>,
    <0.0277778, -167.3627833>,
    <0.0277778, -167.3024008>,
    <0.0138995, -167.3024008>,
    <0.0237225, -167.3543311>,
    <0.0277778, -167.3288803>,
    <0.0217060, -167.3024008>,
    <0.0159181, -167.3203558>,
    <0.0057775, -167.3534027>,
    <0.0092593, -167.3845690>,
    <0.0138507, -167.3638575>,
    <0.0000000, -167.3024008>,
    <0.0000000, -167.3627833>,
    <0.0118434, -167.3729124>,
    <0.0060522, -167.3292549>,
    <0.0000000, -167.3288803>,
    <0.0040499, -167.3723121>,
    <0.0057893, -167.3996647>,
    <0.0092593, -167.3845690>,
    <0.0000000, -167.3627833>,
    <0.0000000, -167.4256532>,
    <0.0138979, -167.4256532>,
    <0.0040499, -167.3723121>,
    <0.0000000, -167.3982231>,
    <0.0060819, -167.4256532>,
    <0.0118704, -167.4076960>,
    <0.0161964, -167.3999332>,
    <0.0092593, -167.3845690>,
    <0.0138979, -167.4256532>,
    <0.0277778, -167.4256532>,
    <0.0138507, -167.3638575>,
    <0.0118704, -167.4076960>,
    <0.0217052, -167.4256532>,
    <0.0216758, -167.3985780>,
    <0.0118434, -167.3729124>,
    <0.5673189, -167.4553644>,
    <0.3240741, -167.4732541>,
    <0.4857960, -167.4256532>,
    <0.9722222, -167.4256532>,
    <0.4871834, -167.4968970>,
    <0.4151091, -167.4464590>,
    <0.7593552, -167.4256532>,
    <0.7602240, -167.4567920>,
    <0.4159234, -167.4865678>,
    <0.2028144, -167.5086990>,
    <0.3240741, -167.4732541>,
    <0.4871834, -167.4968970>,
    <0.0000000, -167.5684558>,
    <0.0000000, -167.4961890>,
    <0.4159234, -167.4865678>,
    <0.2133957, -167.5371117>,
    <0.0000000, -167.5369298>,
    <0.1419197, -167.4861453>,
    <0.2024675, -167.4551874>,
    <0.3240741, -167.4732541>,
    <0.0000000, -167.4961890>,
    <0.0000000, -167.4256532>,
    <0.4857960, -167.4256532>,
    <0.1419197, -167.4861453>,
    <0.0000000, -167.4566011>,
    <0.2125396, -167.4256532>,
    <0.4151091, -167.4464590>,
    <0.7700101, -167.3534027>,
    <0.6481481, -167.3845690>,
    <0.4874476, -167.3638575>,
    <0.9722222, -167.3024008>,
    <0.9722222, -167.3627833>,
    <0.5577041, -167.3729124>,
    <0.7603956, -167.3292549>,
    <0.9722222, -167.3288803>,
    <0.8304763, -167.3723121>,
    <0.7695971, -167.3996647>,
    <0.6481481, -167.3845690>,
    <0.9722222, -167.3627833>,
    <0.9722222, -167.4256532>,
    <0.4857960, -167.4256532>,
    <0.8304763, -167.3723121>,
    <0.9722222, -167.3982231>,
    <0.7593552, -167.4256532>,
    <0.5567573, -167.4076960>,
    <0.4053479, -167.3999332>,
    <0.6481481, -167.3845690>,
    <0.4857960, -167.4256532>,
    <0.0000000, -167.4256532>,
    <0.4874476, -167.3638575>,
    <0.5567573, -167.4076960>,
    <0.2125396, -167.4256532>,
    <0.2135708, -167.3985780>,
    <0.5577041, -167.3729124>,
    <0.0535079, -167.1106496>,
    <0.0543190, -167.1123151>,
    <0.0533135, -167.1040945>,
    <0.0518458, -167.1040945>,
    <0.0545534, -167.1220942>,
    <0.0537438, -167.1076129>,
    <0.0524885, -167.1040945>,
    <0.0533054, -167.1137978>,
    <0.0544701, -167.1186210>,
    <0.0549959, -167.1197229>,
    <0.0543190, -167.1123151>,
    <0.0545534, -167.1220942>,
    <0.0555556, -167.1287564>,
    <0.0555556, -167.1157257>,
    <0.0544701, -167.1186210>,
    <0.0552708, -167.1268637>,
    <0.0555556, -167.1243286>,
    <0.0550606, -167.1143605>,
    <0.0546859, -167.1090575>,
    <0.0543190, -167.1123151>,
    <0.0555556, -167.1157257>,
    <0.0555556, -167.1040945>,
    <0.0533135, -167.1040945>,
    <0.0550606, -167.1143605>,
    <0.0555556, -167.1077203>,
    <0.0543652, -167.1040945>,
    <0.0537438, -167.1076129>,
    <0.0502694, -167.1106496>,
    <0.0492196, -167.1123151>,
    <0.0545534, -167.1220942>,
    <0.0518457, -167.1040945>,
    <0.0454588, -167.1040945>,
    <0.0517787, -167.1170071>,
    <0.0533054, -167.1137978>,
    <0.0483923, -167.1040945>,
    <0.0468468, -167.1071285>,
    <0.0466980, -167.1108241>,
    <0.0492196, -167.1123151>,
    <0.0454588, -167.1040945>,
    <0.0402576, -167.1040945>,
    <0.0518559, -167.1227921>,
    <0.0468468, -167.1071285>,
    <0.0427839, -167.1040945>,
    <0.0475411, -167.1158363>,
    <0.0508861, -167.1189380>,
    <0.0527961, -167.1214895>,
    <0.0492196, -167.1123151>,
    <0.0518559, -167.1227921>,
    <0.0555556, -167.1287564>,
    <0.0545534, -167.1220942>,
    <0.0508861, -167.1189380>,
    <0.0542061, -167.1265810>,
    <0.0552708, -167.1268637>,
    <0.0517787, -167.1170071>,
    <0.0409867, -167.1176324>,
    <0.0411970, -167.1205358>,
    <0.0518559, -167.1227921>,
    <0.0402577, -167.1040945>,
    <0.0306365, -167.1231073>,
    <0.0471751, -167.1218013>,
    <0.0475411, -167.1158363>,
    <0.0341298, -167.1162039>,
    <0.0355078, -167.1219211>,
    <0.0350771, -167.1252890>,
    <0.0411970, -167.1205358>,
    <0.0306365, -167.1231073>,
    <0.0277778, -167.1287564>,
    <0.0406971, -167.1287564>,
    <0.0355078, -167.1219211>,
    <0.0288158, -167.1267051>,
    <0.0330482, -167.1287564>,
    <0.0408749, -167.1258320>,
    <0.0473264, -167.1252102>,
    <0.0411970, -167.1205358>,
    <0.0406971, -167.1287564>,
    <0.0555556, -167.1287564>,
    <0.0518559, -167.1227921>,
    <0.0408749, -167.1258320>,
    <0.0490898, -167.1287564>,
    <0.0542061, -167.1265810>,
    <0.0471751, -167.1218013>,
    <0.9577814, -167.1175674>,
    <0.9578637, -167.1205421>,
    <0.9687224, -167.1231187>,
    <0.9569243, -167.1041136>,
    <0.9476153, -167.1224951>,
    <0.9641454, -167.1220327>,
    <0.9645967, -167.1164727>,
    <0.9513010, -167.1152174>,
    <0.9525001, -167.1215643>,
    <0.9518670, -167.1251375>,
    <0.9578637, -167.1205421>,
    <0.9476153, -167.1224951>,
    <0.9444444, -167.1287564>,
    <0.9575446, -167.1287564>,
    <0.9525001, -167.1215643>,
    <0.9456011, -167.1264725>,
    <0.9498264, -167.1287564>,
    <0.9576503, -167.1260345>,
    <0.9640882, -167.1252934>,
    <0.9578637, -167.1205421>,
    <0.9575446, -167.1287564>,
    <0.9722222, -167.1287564>,
    <0.9687224, -167.1231187>,
    <0.9576503, -167.1260345>,
    <0.9658797, -167.1287564>,
    <0.9709466, -167.1267016>,
    <0.9641454, -167.1220327>,
    <0.9517493, -167.1107625>,
    <0.9495566, -167.1123279>,
    <0.9476153, -167.1224951>,
    <0.9569243, -167.1041136>,
    <0.9529010, -167.1041136>,
    <0.9483083, -167.1188659>,
    <0.9513010, -167.1152174>,
    <0.9550486, -167.1041136>,
    <0.9517511, -167.1069379>,
    <0.9488052, -167.1101333>,
    <0.9495566, -167.1123279>,
    <0.9529010, -167.1041136>,
    <0.9473011, -167.1041136>,
    <0.9454620, -167.1199782>,
    <0.9517511, -167.1069379>,
    <0.9503884, -167.1041136>,
    <0.9463743, -167.1121090>,
    <0.9476168, -167.1159522>,
    <0.9467696, -167.1208894>,
    <0.9495566, -167.1123279>,
    <0.9454620, -167.1199782>,
    <0.9444444, -167.1287564>,
    <0.9476153, -167.1224951>,
    <0.9476168, -167.1159522>,
    <0.9447879, -167.1257933>,
    <0.9456011, -167.1264725>,
    <0.9483083, -167.1188659>,
    <0.9559044, -167.1443229>,
    <0.9629630, -167.1533103>,
    <0.9575446, -167.1287564>,
    <0.9444444, -167.1287564>,
    <0.9586656, -167.1664683>,
    <0.9602230, -167.1408941>,
    <0.9498264, -167.1287564>,
    <0.9508023, -167.1456162>,
    <0.9606036, -167.1605343>,
    <0.9665183, -167.1705747>,
    <0.9629630, -167.1533103>,
    <0.9586656, -167.1664683>,
    <0.9722222, -167.2024179>,
    <0.9722222, -167.1601023>,
    <0.9606036, -167.1605343>,
    <0.9663317, -167.1867974>,
    <0.9722222, -167.1835237>,
    <0.9682360, -167.1571782>,
    <0.9662380, -167.1427314>,
    <0.9629630, -167.1533103>,
    <0.9722222, -167.1601023>,
    <0.9722222, -167.1287564>,
    <0.9575446, -167.1287564>,
    <0.9682360, -167.1571782>,
    <0.9722222, -167.1407348>,
    <0.9658797, -167.1287564>,
    <0.9602230, -167.1408941>,
    <0.9460893, -167.1101299>,
    <0.9453967, -167.1123215>,
    <0.9454620, -167.1199782>,
    <0.9473011, -167.1041136>,
    <0.9461975, -167.1041062>,
    <0.9454374, -167.1170884>,
    <0.9463743, -167.1121090>,
    <0.9468226, -167.1041104>,
    <0.9458527, -167.1076438>,
    <0.9451208, -167.1098052>,
    <0.9453967, -167.1123215>,
    <0.9461975, -167.1041062>,
    <0.9444444, -167.1040945>,
    <0.9444444, -167.1186988>,
    <0.9458527, -167.1076438>,
    <0.9453811, -167.1041008>,
    <0.9444444, -167.1075975>,
    <0.9447936, -167.1163606>,
    <0.9449369, -167.1199387>,
    <0.9453967, -167.1123215>,
    <0.9444444, -167.1186988>,
    <0.9444444, -167.1287564>,
    <0.9454620, -167.1199782>,
    <0.9447936, -167.1163606>,
    <0.9444444, -167.1268392>,
    <0.9447879, -167.1257933>,
    <0.9454374, -167.1170884>,
    <0.0115666, -167.2539957>,
    <0.0185185, -167.2709932>,
    <0.0138473, -167.2933857>,
    <0.0000000, -167.2258020>,
    <0.0139006, -167.2258020>,
    <0.0158879, -167.2836036>,
    <0.0060499, -167.2553296>,
    <0.0060834, -167.2258020>,
    <0.0159189, -167.2455535>,
    <0.0219937, -167.2537633>,
    <0.0185185, -167.2709932>,
    <0.0139006, -167.2258020>,
    <0.0277778, -167.2258020>,
    <0.0277778, -167.2924560>,
    <0.0159189, -167.2455535>,
    <0.0217066, -167.2258020>,
    <0.0277778, -167.2550533>,
    <0.0237222, -167.2830552>,
    <0.0219803, -167.3045527>,
    <0.0185185, -167.2709932>,
    <0.0277778, -167.2924560>,
    <0.0277778, -167.3613758>,
    <0.0138473, -167.2933857>,
    <0.0237222, -167.2830552>,
    <0.0277778, -167.3313235>,
    <0.0216736, -167.3315832>,
    <0.0158879, -167.2836036>,
    <0.0057766, -167.2819570>,
    <0.0092593, -167.3161845>,
    <0.0000000, -167.2924560>,
    <0.0000000, -167.2258020>,
    <0.0138473, -167.2933857>,
    <0.0040496, -167.3028339>,
    <0.0000000, -167.2550533>,
    <0.0060499, -167.2553296>,
    <0.0118413, -167.3033535>,
    <0.0161958, -167.3330804>,
    <0.0092593, -167.3161845>,
    <0.0138473, -167.2933857>,
    <0.0277778, -167.3613758>,
    <0.0138989, -167.3613758>,
    <0.0118413, -167.3033535>,
    <0.0216736, -167.3315832>,
    <0.0217057, -167.3613758>,
    <0.0118711, -167.3416247>,
    <0.0057895, -167.3328480>,
    <0.0092593, -167.3161845>,
    <0.0138989, -167.3613758>,
    <0.0000000, -167.3613758>,
    <0.0000000, -167.2924560>,
    <0.0118711, -167.3416247>,
    <0.0060824, -167.3613758>,
    <0.0000000, -167.3313235>,
    <0.0040496, -167.3028339>,
    <0.5673339, -167.3940515>,
    <0.3240741, -167.4137323>,
    <0.4872775, -167.4397221>,
    <0.9722222, -167.3613758>,
    <0.4857617, -167.3613758>,
    <0.4159803, -167.4283682>,
    <0.7602859, -167.3956156>,
    <0.7593382, -167.3613758>,
    <0.4150832, -167.3842624>,
    <0.2024590, -167.3939086>,
    <0.3240741, -167.4137323>,
    <0.4857617, -167.3613758>,
    <0.0000000, -167.3613758>,
    <0.0000000, -167.4391507>,
    <0.4150832, -167.3842624>,
    <0.2125210, -167.3613758>,
    <0.0000000, -167.3955180>,
    <0.1419285, -167.4280187>,
    <0.2028379, -167.4527626>,
    <0.3240741, -167.4137323>,
    <0.0000000, -167.4391507>,
    <0.0000000, -167.5184453>,
    <0.4872775, -167.4397221>,
    <0.1419285, -167.4280187>,
    <0.0000000, -167.4838674>,
    <0.2134550, -167.4839601>,
    <0.4159803, -167.4283682>,
    <0.7700402, -167.2819570>,
    <0.6481481, -167.3161845>,
    <0.9722222, -167.2924560>,
    <0.9722222, -167.2258020>,
    <0.4875682, -167.2933857>,
    <0.8304850, -167.3028339>,
    <0.9722222, -167.2550533>,
    <0.7604746, -167.2553296>,
    <0.5577752, -167.3033535>,
    <0.4053695, -167.3330804>,
    <0.6481481, -167.3161845>,
    <0.4875682, -167.2933857>,
    <0.0000000, -167.3613758>,
    <0.4857617, -167.3613758>,
    <0.5577752, -167.3033535>,
    <0.2136475, -167.3315832>,
    <0.2125210, -167.3613758>,
    <0.5567336, -167.3416247>,
    <0.7695886, -167.3328480>,
    <0.6481481, -167.3161845>,
    <0.4857617, -167.3613758>,
    <0.9722222, -167.3613758>,
    <0.9722222, -167.2924560>,
    <0.5567336, -167.3416247>,
    <0.7593382, -167.3613758>,
    <0.9722222, -167.3313235>,
    <0.8304850, -167.3028339>,
    <0.0115687, -167.4553644>,
    <0.0185185, -167.4732541>,
    <0.0138979, -167.4256532>,
    <0.0000000, -167.4256532>,
    <0.0138583, -167.4968970>,
    <0.0159175, -167.4464590>,
    <0.0060819, -167.4256532>,
    <0.0060571, -167.4567920>,
    <0.0158943, -167.4865678>,
    <0.0219831, -167.5086990>,
    <0.0185185, -167.4732541>,
    <0.0138583, -167.4968970>,
    <0.0277778, -167.5684558>,
    <0.0277778, -167.4961890>,
    <0.0158943, -167.4865678>,
    <0.0216808, -167.5371117>,
    <0.0277778, -167.5369297>,
    <0.0237229, -167.4861453>,
    <0.0219930, -167.4551874>,
    <0.0185185, -167.4732541>,
    <0.0277778, -167.4961890>,
    <0.0277778, -167.4256532>,
    <0.0138979, -167.4256532>,
    <0.0237229, -167.4861453>,
    <0.0277778, -167.4566011>,
    <0.0217052, -167.4256532>,
    <0.0159175, -167.4464590>,
    <0.0057794, -167.4848985>,
    <0.0092593, -167.5208549>,
    <0.0138583, -167.4968970>,
    <0.0000000, -167.4256532>,
    <0.0000000, -167.4961890>,
    <0.0118478, -167.5073705>,
    <0.0060571, -167.4567920>,
    <0.0000000, -167.4566011>,
    <0.0040504, -167.5069791>,
    <0.0057888, -167.5384889>,
    <0.0092593, -167.5208549>,
    <0.0000000, -167.4961890>,
    <0.0000000, -167.5684558>,
    <0.0138960, -167.5684558>,
    <0.0040504, -167.5069791>,
    <0.0000000, -167.5369298>,
    <0.0060809, -167.5684558>,
    <0.0118695, -167.5476517>,
    <0.0161978, -167.5386659>,
    <0.0092593, -167.5208549>,
    <0.0138960, -167.5684558>,
    <0.0277778, -167.5684558>,
    <0.0138583, -167.4968970>,
    <0.0118695, -167.5476517>,
    <0.0217042, -167.5684558>,
    <0.0216808, -167.5371117>,
    <0.0118478, -167.5073705>,
    <0.5672634, -167.6013336>,
    <0.3240741, -167.6211112>,
    <0.4858635, -167.5684558>,
    <0.9722222, -167.5684558>,
    <0.4868937, -167.6473117>,
    <0.4151421, -167.5914725>,
    <0.7593913, -167.5684558>,
    <0.7600362, -167.6029317>,
    <0.4157561, -167.6358644>,
    <0.2027420, -167.6604338>,
    <0.3240741, -167.6211112>,
    <0.4868937, -167.6473117>,
    <0.0000000, -167.7264218>,
    <0.0000000, -167.6468904>,
    <0.4157561, -167.6358644>,
    <0.2132050, -167.6917804>,
    <0.0000000, -167.6917086>,
    <0.1419006, -167.6356026>,
    <0.2024844, -167.6012283>,
    <0.3240741, -167.6211112>,
    <0.0000000, -167.6468904>,
    <0.0000000, -167.5684558>,
    <0.4858635, -167.5684558>,
    <0.1419006, -167.6356026>,
    <0.0000000, -167.6028579>,
    <0.2125736, -167.5684558>,
    <0.4151421, -167.5914725>,
    <0.7699440, -167.4848985>,
    <0.6481481, -167.5208549>,
    <0.4871834, -167.4968970>,
    <0.9722222, -167.4256532>,
    <0.9722222, -167.4961890>,
    <0.5575507, -167.5073705>,
    <0.7602240, -167.4567920>,
    <0.9722222, -167.4566011>,
    <0.8304571, -167.5069791>,
    <0.7696140, -167.5384889>,
    <0.6481481, -167.5208549>,
    <0.9722222, -167.4961890>,
    <0.9722222, -167.5684558>,
    <0.4858635, -167.5684558>,
    <0.8304571, -167.5069791>,
    <0.9722222, -167.5369298>,
    <0.7593913, -167.5684558>,
    <0.5567905, -167.5476517>,
    <0.4052987, -167.5386659>,
    <0.6481481, -167.5208549>,
    <0.4858635, -167.5684558>,
    <0.0000000, -167.5684558>,
    <0.4871834, -167.4968970>,
    <0.5567905, -167.5476517>,
    <0.2125736, -167.5684558>,
    <0.2133957, -167.5371117>,
    <0.5575507, -167.5073705>,
    <0.9539981, -167.0805622>,
    <0.9575090, -167.0842391>,
    <0.9635993, -167.1011172>,
    <0.9444444, -167.0684463>,
    <0.9504396, -167.0684463>,
    <0.9614499, -167.0951604>,
    <0.9559988, -167.0881537>,
    <0.9474811, -167.0684463>,
    <0.9532783, -167.0747878>,
    <0.9573548, -167.0794526>,
    <0.9575090, -167.0842391>,
    <0.9504396, -167.0684463>,
    <0.9558604, -167.0684463>,
    <0.9656103, -167.0966788>,
    <0.9532783, -167.0747878>,
    <0.9532466, -167.0684463>,
    <0.9608552, -167.0829096>,
    <0.9615731, -167.0904796>,
    <0.9647352, -167.0994649>,
    <0.9575090, -167.0842391>,
    <0.9656103, -167.0966788>,
    <0.9722222, -167.1158246>,
    <0.9635993, -167.1011172>,
    <0.9615731, -167.0904796>,
    <0.9696529, -167.1083847>,
    <0.9687585, -167.1099168>,
    <0.9614499, -167.0951604>,
    <0.0115703, -167.6013336>,
    <0.0185185, -167.6211112>,
    <0.0138960, -167.5684558>,
    <0.0000000, -167.5684558>,
    <0.0138665, -167.6473117>,
    <0.0159166, -167.5914725>,
    <0.0060809, -167.5684558>,
    <0.0060625, -167.6029317>,
    <0.0158990, -167.6358644>,
    <0.0219851, -167.6604338>,
    <0.0185185, -167.6211112>,
    <0.0138665, -167.6473117>,
    <0.0277778, -167.7264218>,
    <0.0277778, -167.6468904>,
    <0.0158990, -167.6358644>,
    <0.0216862, -167.6917804>,
    <0.0277778, -167.6917086>,
    <0.0237235, -167.6356026>,
    <0.0219925, -167.6012283>,
    <0.0185185, -167.6211112>,
    <0.0277778, -167.6468904>,
    <0.0277778, -167.5684558>,
    <0.0138960, -167.5684558>,
    <0.0237235, -167.6356026>,
    <0.0277778, -167.6028580>,
    <0.0217042, -167.5684558>,
    <0.0159166, -167.5914725>,
    <0.0057814, -167.6341061>,
    <0.0092593, -167.6737665>,
    <0.0138665, -167.6473117>,
    <0.0000000, -167.5684558>,
    <0.0000000, -167.6468904>,
    <0.0118526, -167.6588757>,
    <0.0060625, -167.6029317>,
    <0.0000000, -167.6028579>,
    <0.0040510, -167.6586490>,
    <0.0057883, -167.6933751>,
    <0.0092593, -167.6737665>,
    <0.0000000, -167.6468904>,
    <0.0000000, -167.7264218>,
    <0.0138938, -167.7264218>,
    <0.0040510, -167.6586490>,
    <0.0000000, -167.6917086>,
    <0.0060797, -167.7264218>,
    <0.0118683, -167.7034090>,
    <0.0161993, -167.6934805>,
    <0.0092593, -167.6737665>,
    <0.0138938, -167.7264218>,
    <0.0277778, -167.7264218>,
    <0.0138665, -167.6473117>,
    <0.0118683, -167.7034090>,
    <0.0217031, -167.7264218>,
    <0.0216862, -167.6917804>,
    <0.0118526, -167.6588757>,
    <0.5677101, -167.7613931>,
    <0.3240741, -167.7825485>,
    <0.4859404, -167.7264218>,
    <0.9722222, -167.7264218>,
    <0.4886038, -167.8101802>,
    <0.4152688, -167.7509270>,
    <0.7594321, -167.7264218>,
    <0.7610388, -167.7629969>,
    <0.4167148, -167.7981069>,
    <0.2031695, -167.8235012>,
    <0.3240741, -167.7825485>,
    <0.4886038, -167.8101802>,
    <0.0000000, -167.8948019>,
    <0.0000000, -167.8064740>,
    <0.4167148, -167.7981069>,
    <0.2122953, -167.8580343>,
    <0.0000000, -167.8565977>,
    <0.1418901, -167.7959987>,
    <0.2025036, -167.7604666>,
    <0.3240741, -167.7825485>,
    <0.0000000, -167.8064740>,
    <0.0000000, -167.7264218>,
    <0.4859404, -167.7264218>,
    <0.1418901, -167.7959987>,
    <0.0000000, -167.7610288>,
    <0.2126128, -167.7264218>,
    <0.4152688, -167.7509270>,
    <0.7698716, -167.6341061>,
    <0.6481481, -167.6737665>,
    <0.4868937, -167.6473117>,
    <0.9722222, -167.5684558>,
    <0.9722222, -167.6468904>,
    <0.5573818, -167.6588757>,
    <0.7600362, -167.6029317>,
    <0.9722222, -167.6028579>,
    <0.8304357, -167.6586490>,
    <0.7696333, -167.6933751>,
    <0.6481481, -167.6737665>,
    <0.9722222, -167.6468904>,
    <0.9722222, -167.7264218>,
    <0.4859404, -167.7264218>,
    <0.8304357, -167.6586490>,
    <0.9722222, -167.6917086>,
    <0.7594321, -167.7264218>,
    <0.5568329, -167.7034090>,
    <0.4052456, -167.6934805>,
    <0.6481481, -167.6737665>,
    <0.4859404, -167.7264218>,
    <0.0000000, -167.7264218>,
    <0.4868937, -167.6473117>,
    <0.5568329, -167.7034090>,
    <0.2126128, -167.7264218>,
    <0.2132050, -167.6917804>,
    <0.5573818, -167.6588757>,
    <0.0115682, -167.3940515>,
    <0.0185185, -167.4137323>,
    <0.0138556, -167.4397221>,
    <0.0000000, -167.3613758>,
    <0.0138989, -167.3613758>,
    <0.0158926, -167.4283682>,
    <0.0060553, -167.3956156>,
    <0.0060824, -167.3613758>,
    <0.0159183, -167.3842624>,
    <0.0219932, -167.3939086>,
    <0.0185185, -167.4137323>,
    <0.0138989, -167.3613758>,
    <0.0277778, -167.3613758>,
    <0.0277778, -167.4391507>,
    <0.0159183, -167.3842624>,
    <0.0217057, -167.3613758>,
    <0.0277778, -167.3955180>,
    <0.0237227, -167.4280187>,
    <0.0219824, -167.4527626>,
    <0.0185185, -167.4137323>,
    <0.0277778, -167.4391507>,
    <0.0277778, -167.5184453>,
    <0.0138556, -167.4397221>,
    <0.0237227, -167.4280187>,
    <0.0277778, -167.4838674>,
    <0.0216791, -167.4839601>,
    <0.0158926, -167.4283682>,
    <0.0057787, -167.4265843>,
    <0.0092593, -167.4660888>,
    <0.0000000, -167.4391507>,
    <0.0000000, -167.3613758>,
    <0.0138556, -167.4397221>,
    <0.0040502, -167.4509341>,
    <0.0000000, -167.3955180>,
    <0.0060553, -167.3956156>,
    <0.0118462, -167.4512490>,
    <0.0161973, -167.4856754>,
    <0.0092593, -167.4660888>,
    <0.0138556, -167.4397221>,
    <0.0277778, -167.5184453>,
    <0.0138967, -167.5184453>,
    <0.0118462, -167.4512490>,
    <0.0216791, -167.4839601>,
    <0.0217047, -167.5184453>,
    <0.0118700, -167.4955641>,
    <0.0057890, -167.4855325>,
    <0.0092593, -167.4660888>,
    <0.0138967, -167.5184453>,
    <0.0000000, -167.5184453>,
    <0.0000000, -167.4391507>,
    <0.0118700, -167.4955641>,
    <0.0060813, -167.5184453>,
    <0.0000000, -167.4838674>,
    <0.0040502, -167.4509341>,
    <0.5672734, -167.5546111>,
    <0.3240741, -167.5763713>,
    <0.4869609, -167.6051824>,
    <0.9722222, -167.5184453>,
    <0.4858362, -167.5184453>,
    <0.4157973, -167.5925951>,
    <0.7600805, -167.5563642>,
    <0.7593781, -167.5184453>,
    <0.4151202, -167.5437683>,
    <0.2024776, -167.5545331>,
    <0.3240741, -167.5763713>,
    <0.4858362, -167.5184453>,
    <0.0000000, -167.5184453>,
    <0.0000000, -167.6048705>,
    <0.4151202, -167.5437683>,
    <0.2125585, -167.5184453>,
    <0.0000000, -167.5563664>,
    <0.1419074, -167.5923911>,
    <0.2027587, -167.6196618>,
    <0.3240741, -167.5763713>,
    <0.0000000, -167.6048705>,
    <0.0000000, -167.6922232>,
    <0.4869609, -167.6051824>,
    <0.1419074, -167.5923911>,
    <0.0000000, -167.6541051>,
    <0.2132468, -167.6541068>,
    <0.4157973, -167.5925951>,
    <0.7699675, -167.4265843>,
    <0.6481481, -167.4660888>,
    <0.9722222, -167.4391507>,
    <0.9722222, -167.3613758>,
    <0.4872775, -167.4397221>,
    <0.8304639, -167.4509341>,
    <0.9722222, -167.3955180>,
    <0.7602859, -167.3956156>,
    <0.5576065, -167.4512490>,
    <0.4053155, -167.4856754>,
    <0.6481481, -167.4660888>,
    <0.4872775, -167.4397221>,
    <0.0000000, -167.5184453>,
    <0.4858362, -167.5184453>,
    <0.5576065, -167.4512490>,
    <0.2134550, -167.4839601>,
    <0.2125585, -167.5184453>,
    <0.5567709, -167.4955641>,
    <0.7696072, -167.4855325>,
    <0.6481481, -167.4660888>,
    <0.4858362, -167.5184453>,
    <0.9722222, -167.5184453>,
    <0.9722222, -167.4391507>,
    <0.5567709, -167.4955641>,
    <0.7593781, -167.5184453>,
    <0.9722222, -167.4838674>,
    <0.8304639, -167.4509341>,
    <0.0391692, -167.1442610>,
    <0.0462963, -167.1533103>,
    <0.0406971, -167.1287564>,
    <0.0277778, -167.1287564>,
    <0.0419056, -167.1662209>,
    <0.0434561, -167.1408553>,
    <0.0330482, -167.1287564>,
    <0.0340349, -167.1453492>,
    <0.0438841, -167.1604034>,
    <0.0498283, -167.1706661>,
    <0.0462963, -167.1533103>,
    <0.0419056, -167.1662209>,
    <0.0555556, -167.2024179>,
    <0.0555556, -167.1607154>,
    <0.0438841, -167.1604034>,
    <0.0496152, -167.1866652>,
    <0.0555556, -167.1838308>,
    <0.0515676, -167.1575260>,
    <0.0495261, -167.1428846>,
    <0.0462963, -167.1533103>,
    <0.0555556, -167.1607154>,
    <0.0555556, -167.1287564>,
    <0.0406971, -167.1287564>,
    <0.0515676, -167.1575260>,
    <0.0555556, -167.1413914>,
    <0.0490898, -167.1287564>,
    <0.0434561, -167.1408553>,
    <0.0336246, -167.1583892>,
    <0.0370370, -167.1778641>,
    <0.0419056, -167.1662209>,
    <0.0277778, -167.1287564>,
    <0.0277778, -167.1607154>,
    <0.0397843, -167.1712941>,
    <0.0340349, -167.1453492>,
    <0.0277778, -167.1413913>,
    <0.0318345, -167.1682287>,
    <0.0335678, -167.1858538>,
    <0.0370370, -167.1778641>,
    <0.0277778, -167.1607154>,
    <0.0277778, -167.2024179>,
    <0.0416785, -167.2024179>,
    <0.0318345, -167.1682287>,
    <0.0277778, -167.1838308>,
    <0.0338612, -167.2024179>,
    <0.0396574, -167.1917260>,
    <0.0440442, -167.1872302>,
    <0.0370370, -167.1778641>,
    <0.0416785, -167.2024179>,
    <0.0555556, -167.2024179>,
    <0.0419056, -167.1662209>,
    <0.0396574, -167.1917260>,
    <0.0494844, -167.2024179>,
    <0.0496152, -167.1866652>,
    <0.0397843, -167.1712941>,
    <0.9560103, -167.2232074>,
    <0.9629630, -167.2357456>,
    <0.9583451, -167.2024179>,
    <0.9444444, -167.2024179>,
    <0.9582886, -167.2522483>,
    <0.9603629, -167.2169804>,
    <0.9505279, -167.2024179>,
    <0.9504924, -167.2241867>,
    <0.9603307, -167.2450388>,
    <0.9664240, -167.2602946>,
    <0.9629630, -167.2357456>,
    <0.9582886, -167.2522483>,
    <0.9722222, -167.3024008>,
    <0.9722222, -167.2507837>,
    <0.9603307, -167.2450388>,
    <0.9661158, -167.2804214>,
    <0.9722222, -167.2798504>,
    <0.9681665, -167.2441968>,
    <0.9664381, -167.2228413>,
    <0.9629630, -167.2357456>,
    <0.9722222, -167.2507837>,
    <0.9722222, -167.2024179>,
    <0.9583451, -167.2024179>,
    <0.9681665, -167.2441968>,
    <0.9722222, -167.2235884>,
    <0.9661510, -167.2024179>,
    <0.9603629, -167.2169804>,
    <0.9503146, -167.1582978>,
    <0.9537037, -167.1778641>,
    <0.9586656, -167.1664683>,
    <0.9444444, -167.1287564>,
    <0.9444444, -167.1601024>,
    <0.9565025, -167.1714363>,
    <0.9508023, -167.1456162>,
    <0.9444444, -167.1407349>,
    <0.9485001, -167.1678823>,
    <0.9502344, -167.1857006>,
    <0.9537037, -167.1778641>,
    <0.9444444, -167.1601024>,
    <0.9444444, -167.2024179>,
    <0.9583451, -167.2024179>,
    <0.9485001, -167.1678823>,
    <0.9444444, -167.1835238>,
    <0.9505279, -167.2024179>,
    <0.9563267, -167.1917403>,
    <0.9607342, -167.1872921>,
    <0.9537037, -167.1778641>,
    <0.9583451, -167.2024179>,
    <0.9722222, -167.2024179>,
    <0.9586656, -167.1664683>,
    <0.9563267, -167.1917403>,
    <0.9661510, -167.2024179>,
    <0.9663317, -167.1867974>,
    <0.9565025, -167.1714363>,
    <0.0115578, -167.7613948>,
    <0.0185185, -167.7825485>,
    <0.0138938, -167.7264218>,
    <0.0000000, -167.7264218>,
    <0.0138188, -167.8101870>,
    <0.0159130, -167.7509274>,
    <0.0060797, -167.7264218>,
    <0.0060344, -167.7630007>,
    <0.0158723, -167.7981107>,
    <0.0219732, -167.8235050>,
    <0.0185185, -167.7825485>,
    <0.0138188, -167.8101870>,
    <0.0277778, -167.8948019>,
    <0.0277778, -167.8064827>,
    <0.0158723, -167.7981107>,
    <0.0217132, -167.8580407>,
    <0.0277778, -167.8566142>,
    <0.0237238, -167.7960035>,
    <0.0219920, -167.7604687>,
    <0.0185185, -167.7825485>,
    <0.0277778, -167.8064827>,
    <0.0277778, -167.7264218>,
    <0.0138938, -167.7264218>,
    <0.0237238, -167.7960035>,
    <0.0277778, -167.7610332>,
    <0.0217031, -167.7264218>,
    <0.0159130, -167.7509274>,
    <0.0057695, -167.7954395>,
    <0.0092593, -167.8386752>,
    <0.0138188, -167.8101870>,
    <0.0000000, -167.7264218>,
    <0.0000000, -167.8064740>,
    <0.0118243, -167.8226489>,
    <0.0060344, -167.7630007>,
    <0.0000000, -167.7610288>,
    <0.0040455, -167.8205431>,
    <0.0057919, -167.8586883>,
    <0.0092593, -167.8386752>,
    <0.0000000, -167.8064740>,
    <0.0000000, -167.8948019>,
    <0.0139083, -167.8948019>,
    <0.0040455, -167.8205431>,
    <0.0000000, -167.8565977>,
    <0.0059686, -167.8948019>,
    <0.0118958, -167.8705056>,
    <0.0161910, -167.8596165>,
    <0.0092593, -167.8386752>,
    <0.0139083, -167.8948019>,
    <0.0277778, -167.8948019>,
    <0.0138188, -167.8101870>,
    <0.0118958, -167.8705056>,
    <0.0217991, -167.8948019>,
    <0.0217132, -167.8580407>,
    <0.0118243, -167.8226489>,
    <0.5978379, -167.9254618>,
    <0.3240741, -167.9526834>,
    <0.4854087, -167.8948019>,
    <0.9722222, -167.8948019>,
    <0.6096466, -167.9595600>,
    <0.4101830, -167.9217904>,
    <0.7633108, -167.8948019>,
    <0.8169176, -167.9225402>,
    <0.4957042, -167.9568162>,
    <0.2334302, -167.9832615>,
    <0.3240741, -167.9526834>,
    <0.6096466, -167.9595600>,
    <0.0000000, -168.0684463>,
    <0.0000000, -167.9523564>,
    <0.4957042, -167.9568162>,
    <0.3449100, -168.0068434>,
    <0.0000000, -167.9963160>,
    <0.1360344, -167.9524937>,
    <0.2023707, -167.9236609>,
    <0.3240741, -167.9526834>,
    <0.0000000, -167.9523564>,
    <0.0000000, -167.8948019>,
    <0.4854087, -167.8948019>,
    <0.1360344, -167.9524937>,
    <0.0000000, -167.9196256>,
    <0.2092414, -167.8948019>,
    <0.4101830, -167.9217904>,
    <0.7702991, -167.7954350>,
    <0.6481481, -167.8386752>,
    <0.4886038, -167.8101802>,
    <0.9722222, -167.7264218>,
    <0.9722222, -167.8064627>,
    <0.5583989, -167.8226458>,
    <0.7610388, -167.7629969>,
    <0.9722222, -167.7610230>,
    <0.8306346, -167.8205363>,
    <0.7695003, -167.8586855>,
    <0.6481481, -167.8386752>,
    <0.9722222, -167.8064627>,
    <0.9722222, -167.8948019>,
    <0.4854087, -167.8948019>,
    <0.8306346, -167.8205363>,
    <0.9722222, -167.8565780>,
    <0.7633108, -167.8948019>,
    <0.5558701, -167.8705007>,
    <0.4055402, -167.8596148>,
    <0.6481481, -167.8386752>,
    <0.4854087, -167.8948019>,
    <0.0000000, -167.8948019>,
    <0.4886038, -167.8101802>,
    <0.5558701, -167.8705007>,
    <0.2092414, -167.8948019>,
    <0.2122953, -167.8580343>,
    <0.5583989, -167.8226458>,
    <0.0106968, -167.9254636>,
    <0.0185185, -167.9526834>,
    <0.0139083, -167.8948019>,
    <0.0000000, -167.8948019>,
    <0.0103605, -167.9595672>,
    <0.0160584, -167.9217957>,
    <0.0059686, -167.8948019>,
    <0.0044381, -167.9225451>,
    <0.0136154, -167.9568207>,
    <0.0211086, -167.9832751>,
    <0.0185185, -167.9526834>,
    <0.0103605, -167.9595672>,
    <0.0277778, -168.0684463>,
    <0.0277778, -167.9524033>,
    <0.0136154, -167.9568207>,
    <0.0179239, -168.0068475>,
    <0.0277778, -167.9963224>,
    <0.0238912, -167.9525209>,
    <0.0219956, -167.9236726>,
    <0.0185185, -167.9526834>,
    <0.0277778, -167.9524033>,
    <0.0277778, -167.8948019>,
    <0.0139083, -167.8948019>,
    <0.0238912, -167.9525209>,
    <0.0277778, -167.9196450>,
    <0.0217991, -167.8948019>,
    <0.0160584, -167.9217957>,
    <0.0049049, -167.9543226>,
    <0.0092593, -168.0105648>,
    <0.0103605, -167.9595672>,
    <0.0000000, -167.8948019>,
    <0.0000000, -167.9523564>,
    <0.0098583, -167.9828241>,
    <0.0044381, -167.9225451>,
    <0.0000000, -167.9196256>,
    <0.0041964, -167.9787372>,
    <0.0057870, -168.0249535>,
    <0.0092593, -168.0105648>,
    <0.0000000, -167.9523564>,
    <0.0000000, -168.0684463>,
    <0.0138889, -168.0684463>,
    <0.0041964, -167.9787372>,
    <0.0000000, -167.9963160>,
    <0.0069444, -168.0684463>,
    <0.0120046, -168.0448886>,
    <0.0153216, -168.0267562>,
    <0.0092593, -168.0105648>,
    <0.0138889, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0103605, -167.9595672>,
    <0.0120046, -168.0448886>,
    <0.0208333, -168.0684463>,
    <0.0179239, -168.0068475>,
    <0.0098583, -167.9828241>,
    <0.8005598, -167.9543074>,
    <0.6481482, -168.0105648>,
    <0.6096466, -167.9595600>,
    <0.9722222, -167.8948019>,
    <0.9722222, -167.9523027>,
    <0.6272046, -167.9828199>,
    <0.8169176, -167.9225402>,
    <0.9722222, -167.9196016>,
    <0.8253479, -167.9787078>,
    <0.7696759, -168.0249400>,
    <0.6481482, -168.0105648>,
    <0.9722222, -167.9523027>,
    <0.9722222, -168.0684463>,
    <0.4861111, -168.0684463>,
    <0.8253479, -167.9787078>,
    <0.9722222, -167.9962961>,
    <0.7291667, -168.0684463>,
    <0.5520612, -168.0448882>,
    <0.4359765, -168.0267543>,
    <0.6481482, -168.0105648>,
    <0.4861111, -168.0684463>,
    <0.0000000, -168.0684463>,
    <0.6096466, -167.9595600>,
    <0.5520612, -168.0448882>,
    <0.2430556, -168.0684463>,
    <0.3449100, -168.0068434>,
    <0.6272046, -167.9828199>,
    <0.0462830, -167.0791039>,
    <0.0501016, -167.0842391>,
    <0.0484619, -167.0952839>,
    <0.0391937, -167.0684463>,
    <0.0473746, -167.0684463>,
    <0.0491181, -167.0908638>,
    <0.0436387, -167.0813173>,
    <0.0432842, -167.0684463>,
    <0.0485571, -167.0752945>,
    <0.0521468, -167.0791200>,
    <0.0501016, -167.0842391>,
    <0.0473746, -167.0684463>,
    <0.0555556, -167.0684463>,
    <0.0555556, -167.0953483>,
    <0.0485571, -167.0752945>,
    <0.0514651, -167.0684463>,
    <0.0555556, -167.0824562>,
    <0.0532389, -167.0906294>,
    <0.0524187, -167.0976740>,
    <0.0501016, -167.0842391>,
    <0.0555556, -167.0953483>,
    <0.0555556, -167.1158246>,
    <0.0484619, -167.0952839>,
    <0.0532389, -167.0906294>,
    <0.0555556, -167.1100291>,
    <0.0527515, -167.1077050>,
    <0.0491181, -167.0908638>,
    <0.0372754, -167.0805880>,
    <0.0408434, -167.0842391>,
    <0.0469930, -167.1012202>,
    <0.0277778, -167.0684463>,
    <0.0334873, -167.0684463>,
    <0.0448779, -167.0953798>,
    <0.0394214, -167.0883059>,
    <0.0306325, -167.0684463>,
    <0.0364421, -167.0747899>,
    <0.0404977, -167.0791039>,
    <0.0408434, -167.0842391>,
    <0.0334873, -167.0684463>,
    <0.0391968, -167.0684463>,
    <0.0484632, -167.0952839>,
    <0.0364421, -167.0747899>,
    <0.0363420, -167.0684463>,
    <0.0436409, -167.0813173>,
    <0.0446721, -167.0897887>,
    <0.0479638, -167.0991419>,
    <0.0408434, -167.0842391>,
    <0.0484632, -167.0952839>,
    <0.0555556, -167.1158246>,
    <0.0469930, -167.1012202>,
    <0.0446721, -167.0897887>,
    <0.0527520, -167.1077050>,
    <0.0521190, -167.1099631>,
    <0.0448779, -167.0953798>,
    <0.0348964, -167.0913532>,
    <0.0370370, -167.1000319>,
    <0.0277778, -167.0957145>,
    <0.0277778, -167.0684463>,
    <0.0469930, -167.1012202>,
    <0.0317579, -167.0975703>,
    <0.0277778, -167.0828793>,
    <0.0394214, -167.0883059>,
    <0.0419243, -167.1006152>,
    <0.0451656, -167.1082253>,
    <0.0370370, -167.1000319>,
    <0.0469930, -167.1012202>,
    <0.0555556, -167.1158246>,
    <0.0410767, -167.1158246>,
    <0.0419243, -167.1006152>,
    <0.0521190, -167.1099631>,
    <0.0492946, -167.1158246>,
    <0.0391885, -167.1084428>,
    <0.0334173, -167.1068489>,
    <0.0370370, -167.1000319>,
    <0.0410767, -167.1158246>,
    <0.0277778, -167.1158246>,
    <0.0277778, -167.0957145>,
    <0.0391885, -167.1084428>,
    <0.0332608, -167.1158246>,
    <0.0277778, -167.1099991>,
    <0.0317579, -167.0975703>,
    <0.9557946, -167.1384095>,
    <0.9629630, -167.1524837>,
    <0.9580028, -167.1695048>,
    <0.9444444, -167.1158246>,
    <0.9577681, -167.1158246>,
    <0.9601638, -167.1620894>,
    <0.9501739, -167.1385084>,
    <0.9499407, -167.1158246>,
    <0.9600190, -167.1317090>,
    <0.9662939, -167.1378917>,
    <0.9629630, -167.1524837>,
    <0.9577681, -167.1158246>,
    <0.9722222, -167.1158246>,
    <0.9722222, -167.1674336>,
    <0.9600190, -167.1317090>,
    <0.9659769, -167.1158246>,
    <0.9722222, -167.1361016>,
    <0.9681610, -167.1608763>,
    <0.9663526, -167.1788060>,
    <0.9629630, -167.1524837>,
    <0.9722222, -167.1674336>,
    <0.9722222, -167.2258020>,
    <0.9580028, -167.1695048>,
    <0.9681610, -167.1608763>,
    <0.9722222, -167.2002392>,
    <0.9659589, -167.2010043>,
    <0.9601638, -167.1620894>,
    <0.9515480, -167.0910330>,
    <0.9537037, -167.1000319>,
    <0.9444444, -167.0945365>,
    <0.9444444, -167.0684463>,
    <0.9635993, -167.1011172>,
    <0.9484448, -167.0969108>,
    <0.9444444, -167.0815501>,
    <0.9559988, -167.0881537>,
    <0.9585787, -167.1005665>,
    <0.9618233, -167.1081996>,
    <0.9537037, -167.1000319>,
    <0.9635993, -167.1011172>,
    <0.9722222, -167.1158246>,
    <0.9577681, -167.1158246>,
    <0.9585787, -167.1005665>,
    <0.9687585, -167.1099168>,
    <0.9659769, -167.1158246>,
    <0.9558741, -167.1084654>,
    <0.9500902, -167.1065544>,
    <0.9537037, -167.1000319>,
    <0.9577681, -167.1158246>,
    <0.9444444, -167.1158246>,
    <0.9444444, -167.0945365>,
    <0.9558741, -167.1084654>,
    <0.9499407, -167.1158246>,
    <0.9444444, -167.1098579>,
    <0.9484448, -167.0969108>,
    <0.0115700, -167.5546111>,
    <0.0185185, -167.5763713>,
    <0.0138646, -167.6051824>,
    <0.0000000, -167.5184453>,
    <0.0138967, -167.5184453>,
    <0.0158979, -167.5925951>,
    <0.0060612, -167.5563642>,
    <0.0060813, -167.5184453>,
    <0.0159172, -167.5437683>,
    <0.0219927, -167.5545331>,
    <0.0185185, -167.5763713>,
    <0.0138967, -167.5184453>,
    <0.0277778, -167.5184453>,
    <0.0277778, -167.6048705>,
    <0.0159172, -167.5437683>,
    <0.0217047, -167.5184453>,
    <0.0277778, -167.5563664>,
    <0.0237233, -167.5923911>,
    <0.0219847, -167.6196618>,
    <0.0185185, -167.5763713>,
    <0.0277778, -167.6048705>,
    <0.0277778, -167.6922232>,
    <0.0138646, -167.6051824>,
    <0.0237233, -167.5923911>,
    <0.0277778, -167.6541051>,
    <0.0216850, -167.6541068>,
    <0.0158979, -167.5925951>,
    <0.0057810, -167.5906989>,
    <0.0092593, -167.6342972>,
    <0.0000000, -167.6048705>,
    <0.0000000, -167.5184453>,
    <0.0138646, -167.6051824>,
    <0.0040509, -167.6177446>,
    <0.0000000, -167.5563664>,
    <0.0060612, -167.5563642>,
    <0.0118514, -167.6179095>,
    <0.0161990, -167.6559815>,
    <0.0092593, -167.6342972>,
    <0.0138646, -167.6051824>,
    <0.0277778, -167.6922232>,
    <0.0138943, -167.6922232>,
    <0.0118514, -167.6179095>,
    <0.0216850, -167.6541068>,
    <0.0217034, -167.6922232>,
    <0.0118687, -167.6669079>,
    <0.0057884, -167.6559035>,
    <0.0092593, -167.6342972>,
    <0.0138943, -167.6922232>,
    <0.0000000, -167.6922232>,
    <0.0000000, -167.6048705>,
    <0.0118687, -167.6669079>,
    <0.0060800, -167.6922232>,
    <0.0000000, -167.6541051>,
    <0.0040509, -167.6177446>,
    <0.5677360, -167.7306826>,
    <0.3240741, -167.7539575>,
    <0.4887264, -167.7843264>,
    <0.9722222, -167.6922232>,
    <0.4859215, -167.6922232>,
    <0.4167856, -167.7710575>,
    <0.7611109, -167.7324387>,
    <0.7594233, -167.6922232>,
    <0.4152557, -167.7191776>,
    <0.2024989, -167.7297559>,
    <0.3240741, -167.7539575>,
    <0.4859215, -167.6922232>,
    <0.0000000, -167.6922232>,
    <0.0000000, -167.7806198>,
    <0.4152557, -167.7191776>,
    <0.2126019, -167.6922232>,
    <0.0000000, -167.7304864>,
    <0.1418952, -167.7689458>,
    <0.2032001, -167.7990824>,
    <0.3240741, -167.7539575>,
    <0.0000000, -167.7806198>,
    <0.0000000, -167.8774261>,
    <0.4887264, -167.7843264>,
    <0.1418952, -167.7689458>,
    <0.0000000, -167.8363555>,
    <0.2105719, -167.8373133>,
    <0.4167856, -167.7710575>,
    <0.7698884, -167.5906989>,
    <0.6481481, -167.6342972>,
    <0.9722222, -167.6048705>,
    <0.9722222, -167.5184453>,
    <0.4869609, -167.6051824>,
    <0.8304404, -167.6177446>,
    <0.9722222, -167.5563664>,
    <0.7600805, -167.5563642>,
    <0.5574215, -167.6179095>,
    <0.4052576, -167.6559815>,
    <0.6481481, -167.6342972>,
    <0.4869609, -167.6051824>,
    <0.0000000, -167.6922232>,
    <0.4859215, -167.6922232>,
    <0.5574215, -167.6179095>,
    <0.2132468, -167.6541068>,
    <0.2126019, -167.6922232>,
    <0.5568193, -167.6669079>,
    <0.7696285, -167.6559035>,
    <0.6481481, -167.6342972>,
    <0.4859215, -167.6922232>,
    <0.9722222, -167.6922232>,
    <0.9722222, -167.6048705>,
    <0.5568193, -167.6669079>,
    <0.7594233, -167.6922232>,
    <0.9722222, -167.6541051>,
    <0.8304404, -167.6177446>,
    <0.0619758, -167.1109029>,
    <0.0597155, -167.1123151>,
    <0.0584142, -167.1231073>,
    <0.0680354, -167.1040945>,
    <0.0617380, -167.1040945>,
    <0.0589151, -167.1189534>,
    <0.0619076, -167.1162039>,
    <0.0648647, -167.1040945>,
    <0.0610649, -167.1068303>,
    <0.0581412, -167.1090575>,
    <0.0597155, -167.1123151>,
    <0.0617380, -167.1040945>,
    <0.0555556, -167.1040945>,
    <0.0555556, -167.1157257>,
    <0.0610649, -167.1068303>,
    <0.0586397, -167.1040945>,
    <0.0555556, -167.1077203>,
    <0.0576557, -167.1140039>,
    <0.0573102, -167.1199761>,
    <0.0597155, -167.1123151>,
    <0.0555556, -167.1157257>,
    <0.0555556, -167.1287564>,
    <0.0584142, -167.1231073>,
    <0.0576557, -167.1140039>,
    <0.0555556, -167.1243286>,
    <0.0565936, -167.1267051>,
    <0.0589151, -167.1189534>,
    <0.0115570, -167.7306845>,
    <0.0185185, -167.7539575>,
    <0.0138153, -167.7843340>,
    <0.0000000, -167.6922232>,
    <0.0138943, -167.6922232>,
    <0.0158703, -167.7710617>,
    <0.0060324, -167.7324429>,
    <0.0060800, -167.6922232>,
    <0.0159134, -167.7191781>,
    <0.0219921, -167.7297580>,
    <0.0185185, -167.7539575>,
    <0.0138943, -167.6922232>,
    <0.0277778, -167.6922232>,
    <0.0277778, -167.7806279>,
    <0.0159134, -167.7191781>,
    <0.0217034, -167.6922232>,
    <0.0277778, -167.7304906>,
    <0.0237236, -167.7689503>,
    <0.0219723, -167.7990864>,
    <0.0185185, -167.7539575>,
    <0.0277778, -167.7806279>,
    <0.0277778, -167.8774261>,
    <0.0138153, -167.7843340>,
    <0.0237236, -167.7689503>,
    <0.0277778, -167.8351483>,
    <0.0216509, -167.8365760>,
    <0.0158703, -167.7710617>,
    <0.0057686, -167.7682172>,
    <0.0092593, -167.8156918>,
    <0.0000000, -167.7806198>,
    <0.0000000, -167.6922232>,
    <0.0138153, -167.7843340>,
    <0.0040453, -167.7959424>,
    <0.0000000, -167.7304864>,
    <0.0060324, -167.7324429>,
    <0.0118226, -167.7980492>,
    <0.0161902, -167.8387195>,
    <0.0092593, -167.8156918>,
    <0.0138153, -167.7843340>,
    <0.0277778, -167.8774261>,
    <0.0139086, -167.8774261>,
    <0.0118226, -167.7980492>,
    <0.0216509, -167.8365760>,
    <0.0217674, -167.8774261>,
    <0.0119137, -167.8509367>,
    <0.0057920, -167.8377909>,
    <0.0092593, -167.8156918>,
    <0.0139086, -167.8774261>,
    <0.0000000, -167.8774261>,
    <0.0000000, -167.7806198>,
    <0.0119137, -167.8509367>,
    <0.0058641, -167.8774261>,
    <0.0000000, -167.8363555>,
    <0.0040453, -167.7959424>,
    <0.5953668, -167.9116389>,
    <0.3240741, -167.9410995>,
    <0.5997728, -167.9506042>,
    <0.9722222, -167.8774261>,
    <0.4853982, -167.8774261>,
    <0.5039900, -167.9473020>,
    <0.8084585, -167.9096020>,
    <0.7667863, -167.8774261>,
    <0.4055954, -167.9089236>,
    <0.2023681, -167.9193361>,
    <0.3240741, -167.9410995>,
    <0.4853982, -167.8774261>,
    <0.0000000, -167.8774261>,
    <0.0000000, -167.9813927>,
    <0.4055954, -167.9089236>,
    <0.2065964, -167.8774261>,
    <0.0000000, -167.9213932>,
    <0.1324127, -167.9649294>,
    <0.2309617, -167.9853857>,
    <0.3240741, -167.9410995>,
    <0.0000000, -167.9813927>,
    <0.0000000, -168.0684463>,
    <0.5997728, -167.9506042>,
    <0.1324127, -167.9649294>,
    <0.0000000, -168.0240116>,
    <0.3465225, -168.0003623>,
    <0.5039900, -167.9473020>,
    <0.7703297, -167.7682127>,
    <0.6481481, -167.8156918>,
    <0.9722222, -167.7806092>,
    <0.9722222, -167.6922232>,
    <0.4887264, -167.7843264>,
    <0.8306423, -167.7959359>,
    <0.9722222, -167.7304809>,
    <0.7611109, -167.7324387>,
    <0.5584580, -167.7980457>,
    <0.4055682, -167.8387176>,
    <0.6481481, -167.8156918>,
    <0.4887264, -167.7843264>,
    <0.0000000, -167.8774261>,
    <0.4853982, -167.8774261>,
    <0.5584580, -167.7980457>,
    <0.2105719, -167.8373133>,
    <0.2065964, -167.8774261>,
    <0.5552830, -167.8509174>,
    <0.7694977, -167.8377883>,
    <0.6481481, -167.8156918>,
    <0.4853982, -167.8774261>,
    <0.9722222, -167.8774261>,
    <0.9722222, -167.7806092>,
    <0.5552830, -167.8509174>,
    <0.7667863, -167.8774261>,
    <0.9722222, -167.8355367>,
    <0.8306423, -167.7959359>,
    <0.0393436, -167.2232074>,
    <0.0462963, -167.2357456>,
    <0.0416785, -167.2024179>,
    <0.0277778, -167.2024179>,
    <0.0416219, -167.2522483>,
    <0.0436962, -167.2169804>,
    <0.0338612, -167.2024179>,
    <0.0338257, -167.2241867>,
    <0.0436640, -167.2450388>,
    <0.0497573, -167.2602946>,
    <0.0462963, -167.2357456>,
    <0.0416219, -167.2522483>,
    <0.0555556, -167.3024008>,
    <0.0555556, -167.2507837>,
    <0.0436640, -167.2450388>,
    <0.0494491, -167.2804214>,
    <0.0555556, -167.2798504>,
    <0.0514999, -167.2441968>,
    <0.0497715, -167.2228413>,
    <0.0462963, -167.2357456>,
    <0.0555556, -167.2507837>,
    <0.0555556, -167.2024179>,
    <0.0416785, -167.2024179>,
    <0.0514999, -167.2441968>,
    <0.0555556, -167.2235884>,
    <0.0494844, -167.2024179>,
    <0.0436962, -167.2169804>,
    <0.0335536, -167.2436308>,
    <0.0370370, -167.2690732>,
    <0.0416219, -167.2522483>,
    <0.0277778, -167.2024179>,
    <0.0277778, -167.2507837>,
    <0.0396174, -167.2596042>,
    <0.0338257, -167.2241867>,
    <0.0277778, -167.2235884>,
    <0.0318272, -167.2587824>,
    <0.0335675, -167.2811646>,
    <0.0370370, -167.2690732>,
    <0.0277778, -167.2507837>,
    <0.0277778, -167.3024008>,
    <0.0416773, -167.3024008>,
    <0.0318272, -167.2587824>,
    <0.0277778, -167.2798504>,
    <0.0338606, -167.3024008>,
    <0.0396488, -167.2878319>,
    <0.0439729, -167.2815307>,
    <0.0370370, -167.2690732>,
    <0.0416773, -167.3024008>,
    <0.0555556, -167.3024008>,
    <0.0416219, -167.2522483>,
    <0.0396488, -167.2878319>,
    <0.0494838, -167.3024008>,
    <0.0494491, -167.2804214>,
    <0.0396174, -167.2596042>,
    <0.9560116, -167.3280360>,
    <0.9629630, -167.3434849>,
    <0.9583439, -167.3024008>,
    <0.9444444, -167.3024008>,
    <0.9582951, -167.3638575>,
    <0.9603626, -167.3203558>,
    <0.9505272, -167.3024008>,
    <0.9504966, -167.3292549>,
    <0.9603344, -167.3549573>,
    <0.9664256, -167.3739447>,
    <0.9629630, -167.3434849>,
    <0.9582951, -167.3638575>,
    <0.9722222, -167.4256532>,
    <0.9722222, -167.3627833>,
    <0.9603344, -167.3549573>,
    <0.9661202, -167.3985780>,
    <0.9722222, -167.3982231>,
    <0.9681669, -167.3543311>,
    <0.9664378, -167.3277674>,
    <0.9629630, -167.3434849>,
    <0.9722222, -167.3627833>,
    <0.9722222, -167.3024008>,
    <0.9583439, -167.3024008>,
    <0.9681669, -167.3543311>,
    <0.9722222, -167.3288803>,
    <0.9661505, -167.3024008>,
    <0.9603626, -167.3203558>,
    <0.9502203, -167.2436308>,
    <0.9537037, -167.2690732>,
    <0.9582886, -167.2522483>,
    <0.9444444, -167.2024179>,
    <0.9444444, -167.2507837>,
    <0.9562840, -167.2596042>,
    <0.9504924, -167.2241867>,
    <0.9444444, -167.2235884>,
    <0.9484939, -167.2587824>,
    <0.9502341, -167.2811646>,
    <0.9537037, -167.2690732>,
    <0.9444444, -167.2507837>,
    <0.9444444, -167.3024008>,
    <0.9583439, -167.3024008>,
    <0.9484939, -167.2587824>,
    <0.9444444, -167.2798504>,
    <0.9505272, -167.3024008>,
    <0.9563155, -167.2878319>,
    <0.9606396, -167.2815307>,
    <0.9537037, -167.2690732>,
    <0.9583439, -167.3024008>,
    <0.9722222, -167.3024008>,
    <0.9582886, -167.2522483>,
    <0.9563155, -167.2878319>,
    <0.9661505, -167.3024008>,
    <0.9661158, -167.2804214>,
    <0.9562840, -167.2596042>,
    <0.0089447, -167.8991064>,
    <0.0185185, -167.9410995>,
    <0.0033516, -167.9004739>,
    <0.0000000, -167.8774261>,
    <0.0139086, -167.8774261>,
    <0.0088958, -167.9153244>,
    <0.0013609, -167.8867848>,
    <0.0058641, -167.8774261>,
    <0.0160878, -167.9075252>,
    <0.0219957, -167.9187072>,
    <0.0185185, -167.9410995>,
    <0.0139086, -167.8774261>,
    <0.0277778, -167.8774261>,
    <0.0277778, -167.9788771>,
    <0.0160878, -167.9075252>,
    <0.0217674, -167.8774261>,
    <0.0277778, -167.9227974>,
    <0.0239896, -167.9634214>,
    <0.0193564, -167.9722242>,
    <0.0185185, -167.9410995>,
    <0.0277778, -167.9788771>,
    <0.0277778, -168.0684463>,
    <0.0033516, -167.9004739>,
    <0.0239896, -167.9634214>,
    <0.0277778, -168.0257366>,
    <0.0073484, -167.9279592>,
    <0.0088958, -167.9153244>,
    <0.0031527, -167.9410164>,
    <0.0092593, -168.0047729>,
    <0.0000000, -167.9813927>,
    <0.0000000, -167.8774261>,
    <0.0033516, -167.9004739>,
    <0.0042161, -167.9920386>,
    <0.0000000, -167.9213932>,
    <0.0013609, -167.8867848>,
    <0.0060279, -167.9477236>,
    <0.0135694, -168.0105348>,
    <0.0092593, -168.0047729>,
    <0.0033516, -167.9004739>,
    <0.0277778, -168.0684463>,
    <0.0138888, -168.0684463>,
    <0.0060279, -167.9477236>,
    <0.0073484, -167.9279592>,
    <0.0196078, -168.0684463>,
    <0.0121443, -168.0444527>,
    <0.0057870, -168.0307645>,
    <0.0092593, -168.0047729>,
    <0.0138888, -168.0684463>,
    <0.0000000, -168.0684463>,
    <0.0000000, -167.9813927>,
    <0.0121443, -168.0444527>,
    <0.0081699, -168.0684463>,
    <0.0000000, -168.0240116>,
    <0.0042161, -167.9920386>,
    <0.7980914, -167.9504363>,
    <0.6481481, -168.0047729>,
    <0.9722222, -167.9689421>,
    <0.9722222, -167.8774261>,
    <0.5997728, -167.9506042>,
    <0.8172648, -167.9860747>,
    <0.9722222, -167.9167707>,
    <0.8084585, -167.9096020>,
    <0.6219041, -167.9753858>,
    <0.4424814, -168.0230674>,
    <0.6481481, -168.0047729>,
    <0.5997728, -167.9506042>,
    <0.0000000, -168.0684463>,
    <0.5220048, -168.0684463>,
    <0.6219041, -167.9753858>,
    <0.3465225, -168.0003623>,
    <0.2933379, -168.0684463>,
    <0.5877913, -168.0352392>,
    <0.7786493, -168.0276519>,
    <0.6481481, -168.0047729>,
    <0.5220048, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9722222, -167.9689421>,
    <0.5877913, -168.0352392>,
    <0.7697119, -168.0684463>,
    <0.9722222, -168.0303083>,
    <0.8172648, -167.9860747>,
    <0.9366510, -167.1109046>,
    <0.9393451, -167.1123151>,
    <0.9371677, -167.1040945>,
    <0.9291465, -167.1040945>,
    <0.9409447, -167.1231144>,
    <0.9379481, -167.1070407>,
    <0.9333130, -167.1040945>,
    <0.9368189, -167.1164632>,
    <0.9403078, -167.1188145>,
    <0.9422947, -167.1207212>,
    <0.9393451, -167.1123151>,
    <0.9409447, -167.1231144>,
    <0.9444444, -167.1287564>,
    <0.9444444, -167.1186988>,
    <0.9403078, -167.1188145>,
    <0.9431689, -167.1267000>,
    <0.9444444, -167.1268392>,
    <0.9418528, -167.1154544>,
    <0.9413504, -167.1098007>,
    <0.9393451, -167.1123151>,
    <0.9444444, -167.1186988>,
    <0.9444444, -167.1040945>,
    <0.9371677, -167.1040945>,
    <0.9418528, -167.1154544>,
    <0.9444444, -167.1075975>,
    <0.9408488, -167.1040945>,
    <0.9379481, -167.1070407>,
    <0.0391169, -167.1383902>,
    <0.0462963, -167.1524837>,
    <0.0413167, -167.1694277>,
    <0.0277778, -167.1158246>,
    <0.0410767, -167.1158246>,
    <0.0434861, -167.1620460>,
    <0.0334898, -167.1384395>,
    <0.0332608, -167.1158246>,
    <0.0433366, -167.1316966>,
    <0.0496210, -167.1377692>,
    <0.0462963, -167.1524837>,
    <0.0410767, -167.1158246>,
    <0.0555556, -167.1158246>,
    <0.0555556, -167.1669437>,
    <0.0433366, -167.1316966>,
    <0.0492946, -167.1158246>,
    <0.0555556, -167.1356938>,
    <0.0514936, -167.1606003>,
    <0.0496810, -167.1786643>,
    <0.0462963, -167.1524837>,
    <0.0555556, -167.1669437>,
    <0.0555556, -167.2258020>,
    <0.0413167, -167.1694277>,
    <0.0514936, -167.1606003>,
    <0.0555556, -167.1999722>,
    <0.0492813, -167.2009609>,
    <0.0434861, -167.1620460>,
    <0.0334773, -167.1602631>,
    <0.0370370, -167.1891429>,
    <0.0277778, -167.1666572>,
    <0.0277778, -167.1158246>,
    <0.0413167, -167.1694277>,
    <0.0318307, -167.1764995>,
    <0.0277778, -167.1354565>,
    <0.0334898, -167.1384395>,
    <0.0394486, -167.1780332>,
    <0.0438969, -167.2025436>,
    <0.0370370, -167.1891429>,
    <0.0413167, -167.1694277>,
    <0.0555556, -167.2258020>,
    <0.0416784, -167.2258020>,
    <0.0394486, -167.1780332>,
    <0.0492813, -167.2009609>,
    <0.0494844, -167.2258020>,
    <0.0396403, -167.2097043>,
    <0.0335677, -167.2018510>,
    <0.0370370, -167.1891429>,
    <0.0416784, -167.2258020>,
    <0.0277778, -167.2258020>,
    <0.0277778, -167.1666572>,
    <0.0396403, -167.2097043>,
    <0.0338611, -167.2258020>,
    <0.0277778, -167.1998167>,
    <0.0318307, -167.1764995>,
    <0.9560110, -167.2539957>,
    <0.9629630, -167.2709932>,
    <0.9582917, -167.2933857>,
    <0.9444444, -167.2258020>,
    <0.9583451, -167.2258020>,
    <0.9603323, -167.2836036>,
    <0.9504944, -167.2553296>,
    <0.9505278, -167.2258020>,
    <0.9603634, -167.2455535>,
    <0.9664381, -167.2537633>,
    <0.9629630, -167.2709932>,
    <0.9583451, -167.2258020>,
    <0.9722222, -167.2258020>,
    <0.9722222, -167.2924560>,
    <0.9603634, -167.2455535>,
    <0.9661511, -167.2258020>,
    <0.9722222, -167.2550533>,
    <0.9681666, -167.2830552>,
    <0.9664248, -167.3045527>,
    <0.9629630, -167.2709932>,
    <0.9722222, -167.2924560>,
    <0.9722222, -167.3613758>,
    <0.9582917, -167.2933857>,
    <0.9681666, -167.2830552>,
    <0.9722222, -167.3313235>,
    <0.9661180, -167.3315832>,
    <0.9603323, -167.2836036>,
    <0.9501489, -167.1604678>,
    <0.9537037, -167.1891429>,
    <0.9444444, -167.1673989>,
    <0.9444444, -167.1158246>,
    <0.9580028, -167.1695048>,
    <0.9484971, -167.1769160>,
    <0.9444444, -167.1360737>,
    <0.9501739, -167.1385084>,
    <0.9561262, -167.1780773>,
    <0.9605685, -167.2025629>,
    <0.9537037, -167.1891429>,
    <0.9580028, -167.1695048>,
    <0.9722222, -167.2258020>,
    <0.9583451, -167.2258020>,
    <0.9561262, -167.1780773>,
    <0.9659589, -167.2010043>,
    <0.9661511, -167.2258020>,
    <0.9563077, -167.2097098>,
    <0.9502344, -167.2020364>,
    <0.9537037, -167.1891429>,
    <0.9583451, -167.2258020>,
    <0.9444444, -167.2258020>,
    <0.9444444, -167.1673989>,
    <0.9563077, -167.2097098>,
    <0.9505278, -167.2258020>,
    <0.9444444, -167.2002202>,
    <0.9484971, -167.1769160>,
    <0.0393450, -167.3280360>,
    <0.0462963, -167.3434849>,
    <0.0416773, -167.3024008>,
    <0.0277778, -167.3024008>,
    <0.0416285, -167.3638575>,
    <0.0436959, -167.3203558>,
    <0.0338606, -167.3024008>,
    <0.0338300, -167.3292549>,
    <0.0436677, -167.3549573>,
    <0.0497590, -167.3739447>,
    <0.0462963, -167.3434849>,
    <0.0416285, -167.3638575>,
    <0.0555555, -167.4256532>,
    <0.0555556, -167.3627833>,
    <0.0436677, -167.3549573>,
    <0.0494535, -167.3985780>,
    <0.0555556, -167.3982231>,
    <0.0515002, -167.3543311>,
    <0.0497712, -167.3277674>,
    <0.0462963, -167.3434849>,
    <0.0555556, -167.3627833>,
    <0.0555556, -167.3024008>,
    <0.0416773, -167.3024008>,
    <0.0515002, -167.3543311>,
    <0.0555556, -167.3288803>,
    <0.0494838, -167.3024008>,
    <0.0436959, -167.3203558>,
    <0.0335553, -167.3534027>,
    <0.0370370, -167.3845690>,
    <0.0416285, -167.3638575>,
    <0.0277778, -167.3024008>,
    <0.0277778, -167.3627833>,
    <0.0396212, -167.3729124>,
    <0.0338300, -167.3292549>,
    <0.0277778, -167.3288803>,
    <0.0318277, -167.3723121>,
    <0.0335671, -167.3996647>,
    <0.0370370, -167.3845690>,
    <0.0277778, -167.3627833>,
    <0.0277778, -167.4256532>,
    <0.0416757, -167.4256532>,
    <0.0318277, -167.3723121>,
    <0.0277778, -167.3982231>,
    <0.0338597, -167.4256532>,
    <0.0396482, -167.4076960>,
    <0.0439742, -167.3999332>,
    <0.0370370, -167.3845690>,
    <0.0416757, -167.4256532>,
    <0.0555555, -167.4256532>,
    <0.0416285, -167.3638575>,
    <0.0396482, -167.4076960>,
    <0.0494830, -167.4256532>,
    <0.0494535, -167.3985780>,
    <0.0396212, -167.3729124>,
    <0.9560131, -167.4553644>,
    <0.9629630, -167.4732541>,
    <0.9583423, -167.4256532>,
    <0.9444445, -167.4256532>,
    <0.9583027, -167.4968970>,
    <0.9603620, -167.4464590>,
    <0.9505264, -167.4256532>,
    <0.9505015, -167.4567920>,
    <0.9603387, -167.4865678>,
    <0.9664275, -167.5086990>,
    <0.9629630, -167.4732541>,
    <0.9583027, -167.4968970>,
    <0.9722222, -167.5684558>,
    <0.9722222, -167.4961890>,
    <0.9603387, -167.4865678>,
    <0.9661252, -167.5371117>,
    <0.9722222, -167.5369298>,
    <0.9681674, -167.4861453>,
    <0.9664374, -167.4551874>,
    <0.9629630, -167.4732541>,
    <0.9722222, -167.4961890>,
    <0.9722222, -167.4256532>,
    <0.9583423, -167.4256532>,
    <0.9681674, -167.4861453>,
    <0.9722222, -167.4566011>,
    <0.9661497, -167.4256532>,
    <0.9603620, -167.4464590>,
    <0.9502219, -167.3534027>,
    <0.9537037, -167.3845690>,
    <0.9582951, -167.3638575>,
    <0.9444444, -167.3024008>,
    <0.9444444, -167.3627833>,
    <0.9562878, -167.3729124>,
    <0.9504966, -167.3292549>,
    <0.9444444, -167.3288803>,
    <0.9484943, -167.3723121>,
    <0.9502337, -167.3996647>,
    <0.9537037, -167.3845690>,
    <0.9444444, -167.3627833>,
    <0.9444445, -167.4256532>,
    <0.9583423, -167.4256532>,
    <0.9484943, -167.3723121>,
    <0.9444444, -167.3982231>,
    <0.9505264, -167.4256532>,
    <0.9563149, -167.4076960>,
    <0.9606409, -167.3999332>,
    <0.9537037, -167.3845690>,
    <0.9583423, -167.4256532>,
    <0.9722222, -167.4256532>,
    <0.9582951, -167.3638575>,
    <0.9563149, -167.4076960>,
    <0.9661497, -167.4256532>,
    <0.9661202, -167.3985780>,
    <0.9562878, -167.3729124>,
    <0.0393444, -167.2539957>,
    <0.0462963, -167.2709932>,
    <0.0416250, -167.2933857>,
    <0.0277778, -167.2258020>,
    <0.0416784, -167.2258020>,
    <0.0436657, -167.2836036>,
    <0.0338277, -167.2553296>,
    <0.0338611, -167.2258020>,
    <0.0436967, -167.2455535>,
    <0.0497714, -167.2537633>,
    <0.0462963, -167.2709932>,
    <0.0416784, -167.2258020>,
    <0.0555556, -167.2258020>,
    <0.0555556, -167.2924560>,
    <0.0436967, -167.2455535>,
    <0.0494844, -167.2258020>,
    <0.0555556, -167.2550533>,
    <0.0514999, -167.2830552>,
    <0.0497581, -167.3045527>,
    <0.0462963, -167.2709932>,
    <0.0555556, -167.2924560>,
    <0.0555556, -167.3613758>,
    <0.0416250, -167.2933857>,
    <0.0514999, -167.2830552>,
    <0.0555556, -167.3313235>,
    <0.0494513, -167.3315832>,
    <0.0436657, -167.2836036>,
    <0.0335544, -167.2819570>,
    <0.0370370, -167.3161845>,
    <0.0277778, -167.2924560>,
    <0.0277778, -167.2258020>,
    <0.0416250, -167.2933857>,
    <0.0318274, -167.3028339>,
    <0.0277778, -167.2550533>,
    <0.0338277, -167.2553296>,
    <0.0396191, -167.3033535>,
    <0.0439736, -167.3330804>,
    <0.0370370, -167.3161845>,
    <0.0416250, -167.2933857>,
    <0.0555556, -167.3613758>,
    <0.0416766, -167.3613758>,
    <0.0396191, -167.3033535>,
    <0.0494513, -167.3315832>,
    <0.0494835, -167.3613758>,
    <0.0396489, -167.3416247>,
    <0.0335673, -167.3328480>,
    <0.0370370, -167.3161845>,
    <0.0416766, -167.3613758>,
    <0.0277778, -167.3613758>,
    <0.0277778, -167.2924560>,
    <0.0396489, -167.3416247>,
    <0.0338602, -167.3613758>,
    <0.0277778, -167.3313235>,
    <0.0318274, -167.3028339>,
    <0.9560127, -167.3940515>,
    <0.9629630, -167.4137323>,
    <0.9583000, -167.4397221>,
    <0.9444444, -167.3613758>,
    <0.9583433, -167.3613758>,
    <0.9603371, -167.4283682>,
    <0.9504998, -167.3956156>,
    <0.9505268, -167.3613758>,
    <0.9603627, -167.3842624>,
    <0.9664377, -167.3939086>,
    <0.9629630, -167.4137323>,
    <0.9583433, -167.3613758>,
    <0.9722222, -167.3613758>,
    <0.9722222, -167.4391507>,
    <0.9603627, -167.3842624>,
    <0.9661502, -167.3613758>,
    <0.9722222, -167.3955180>,
    <0.9681671, -167.4280187>,
    <0.9664269, -167.4527626>,
    <0.9629630, -167.4137323>,
    <0.9722222, -167.4391507>,
    <0.9722222, -167.5184453>,
    <0.9583000, -167.4397221>,
    <0.9681671, -167.4280187>,
    <0.9722222, -167.4838674>,
    <0.9661235, -167.4839601>,
    <0.9603371, -167.4283682>,
    <0.9502211, -167.2819570>,
    <0.9537037, -167.3161845>,
    <0.9444444, -167.2924560>,
    <0.9444444, -167.2258020>,
    <0.9582917, -167.2933857>,
    <0.9484941, -167.3028339>,
    <0.9444444, -167.2550533>,
    <0.9504944, -167.2553296>,
    <0.9562858, -167.3033535>,
    <0.9606402, -167.3330804>,
    <0.9537037, -167.3161845>,
    <0.9582917, -167.2933857>,
    <0.9722222, -167.3613758>,
    <0.9583433, -167.3613758>,
    <0.9562858, -167.3033535>,
    <0.9661180, -167.3315832>,
    <0.9661502, -167.3613758>,
    <0.9563156, -167.3416247>,
    <0.9502340, -167.3328480>,
    <0.9537037, -167.3161845>,
    <0.9583433, -167.3613758>,
    <0.9444444, -167.3613758>,
    <0.9444444, -167.2924560>,
    <0.9563156, -167.3416247>,
    <0.9505268, -167.3613758>,
    <0.9444444, -167.3313235>,
    <0.9484941, -167.3028339>,
    <0.0393464, -167.4553644>,
    <0.0462963, -167.4732541>,
    <0.0416757, -167.4256532>,
    <0.0277778, -167.4256532>,
    <0.0416360, -167.4968970>,
    <0.0436953, -167.4464590>,
    <0.0338597, -167.4256532>,
    <0.0338349, -167.4567920>,
    <0.0436720, -167.4865678>,
    <0.0497609, -167.5086990>,
    <0.0462963, -167.4732541>,
    <0.0416360, -167.4968970>,
    <0.0555556, -167.5684558>,
    <0.0555556, -167.4961890>,
    <0.0436720, -167.4865678>,
    <0.0494585, -167.5371117>,
    <0.0555556, -167.5369298>,
    <0.0515007, -167.4861453>,
    <0.0497708, -167.4551874>,
    <0.0462963, -167.4732541>,
    <0.0555556, -167.4961890>,
    <0.0555555, -167.4256532>,
    <0.0416757, -167.4256532>,
    <0.0515007, -167.4861453>,
    <0.0555556, -167.4566011>,
    <0.0494830, -167.4256532>,
    <0.0436953, -167.4464590>,
    <0.0335572, -167.4848985>,
    <0.0370370, -167.5208549>,
    <0.0416360, -167.4968970>,
    <0.0277778, -167.4256532>,
    <0.0277778, -167.4961890>,
    <0.0396255, -167.5073705>,
    <0.0338349, -167.4567920>,
    <0.0277778, -167.4566011>,
    <0.0318282, -167.5069791>,
    <0.0335666, -167.5384889>,
    <0.0370370, -167.5208549>,
    <0.0277778, -167.4961890>,
    <0.0277778, -167.5684558>,
    <0.0416737, -167.5684558>,
    <0.0318282, -167.5069791>,
    <0.0277778, -167.5369297>,
    <0.0338587, -167.5684558>,
    <0.0396473, -167.5476517>,
    <0.0439756, -167.5386659>,
    <0.0370370, -167.5208549>,
    <0.0416737, -167.5684558>,
    <0.0555556, -167.5684558>,
    <0.0416360, -167.4968970>,
    <0.0396473, -167.5476517>,
    <0.0494820, -167.5684558>,
    <0.0494585, -167.5371117>,
    <0.0396255, -167.5073705>,
    <0.9560147, -167.6013336>,
    <0.9629630, -167.6211112>,
    <0.9583404, -167.5684558>,
    <0.9444444, -167.5684558>,
    <0.9583110, -167.6473117>,
    <0.9603610, -167.5914725>,
    <0.9505253, -167.5684558>,
    <0.9505069, -167.6029317>,
    <0.9603435, -167.6358644>,
    <0.9664296, -167.6604338>,
    <0.9629630, -167.6211112>,
    <0.9583110, -167.6473117>,
    <0.9722222, -167.7264218>,
    <0.9722222, -167.6468904>,
    <0.9603435, -167.6358644>,
    <0.9661307, -167.6917804>,
    <0.9722222, -167.6917086>,
    <0.9681679, -167.6356026>,
    <0.9664370, -167.6012283>,
    <0.9629630, -167.6211112>,
    <0.9722222, -167.6468904>,
    <0.9722222, -167.5684558>,
    <0.9583404, -167.5684558>,
    <0.9681679, -167.6356026>,
    <0.9722222, -167.6028579>,
    <0.9661487, -167.5684558>,
    <0.9603610, -167.5914725>,
    <0.9502238, -167.4848985>,
    <0.9537037, -167.5208549>,
    <0.9583027, -167.4968970>,
    <0.9444445, -167.4256532>,
    <0.9444444, -167.4961890>,
    <0.9562922, -167.5073705>,
    <0.9505015, -167.4567920>,
    <0.9444444, -167.4566011>,
    <0.9484949, -167.5069791>,
    <0.9502333, -167.5384889>,
    <0.9537037, -167.5208549>,
    <0.9444444, -167.4961890>,
    <0.9444444, -167.5684558>,
    <0.9583404, -167.5684558>,
    <0.9484949, -167.5069791>,
    <0.9444444, -167.5369297>,
    <0.9505253, -167.5684558>,
    <0.9563139, -167.5476517>,
    <0.9606423, -167.5386659>,
    <0.9537037, -167.5208549>,
    <0.9583404, -167.5684558>,
    <0.9722222, -167.5684558>,
    <0.9583027, -167.4968970>,
    <0.9563139, -167.5476517>,
    <0.9661487, -167.5684558>,
    <0.9661252, -167.5371117>,
    <0.9562922, -167.5073705>,
    <0.9353744, -167.0794530>,
    <0.9389915, -167.0842391>,
    <0.9378342, -167.0966801>,
    <0.9280857, -167.0684463>,
    <0.9365862, -167.0684463>,
    <0.9382946, -167.0917316>,
    <0.9330798, -167.0829104>,
    <0.9324672, -167.0684463>,
    <0.9376327, -167.0753174>,
    <0.9411167, -167.0789170>,
    <0.9389915, -167.0842391>,
    <0.9365862, -167.0684463>,
    <0.9444444, -167.0684463>,
    <0.9444444, -167.0945365>,
    <0.9376327, -167.0753174>,
    <0.9405528, -167.0684463>,
    <0.9444444, -167.0815501>,
    <0.9421417, -167.0901880>,
    <0.9414287, -167.0978201>,
    <0.9389915, -167.0842391>,
    <0.9444444, -167.0945365>,
    <0.9444444, -167.1158246>,
    <0.9378342, -167.0966801>,
    <0.9421417, -167.0901880>,
    <0.9444444, -167.1098579>,
    <0.9418759, -167.1083857>,
    <0.9382946, -167.0917316>,
    <0.0393480, -167.6013336>,
    <0.0462963, -167.6211112>,
    <0.0416737, -167.5684558>,
    <0.0277778, -167.5684558>,
    <0.0416443, -167.6473117>,
    <0.0436943, -167.5914725>,
    <0.0338587, -167.5684558>,
    <0.0338402, -167.6029317>,
    <0.0436768, -167.6358644>,
    <0.0497629, -167.6604338>,
    <0.0462963, -167.6211112>,
    <0.0416443, -167.6473117>,
    <0.0555556, -167.7264218>,
    <0.0555556, -167.6468904>,
    <0.0436768, -167.6358644>,
    <0.0494640, -167.6917804>,
    <0.0555556, -167.6917086>,
    <0.0515013, -167.6356026>,
    <0.0497703, -167.6012283>,
    <0.0462963, -167.6211112>,
    <0.0555556, -167.6468904>,
    <0.0555556, -167.5684558>,
    <0.0416737, -167.5684558>,
    <0.0515013, -167.6356026>,
    <0.0555556, -167.6028579>,
    <0.0494820, -167.5684558>,
    <0.0436943, -167.5914725>,
    <0.0335592, -167.6341061>,
    <0.0370370, -167.6737665>,
    <0.0416443, -167.6473117>,
    <0.0277778, -167.5684558>,
    <0.0277778, -167.6468904>,
    <0.0396304, -167.6588757>,
    <0.0338402, -167.6029317>,
    <0.0277778, -167.6028580>,
    <0.0318288, -167.6586490>,
    <0.0335660, -167.6933751>,
    <0.0370370, -167.6737665>,
    <0.0277778, -167.6468904>,
    <0.0277778, -167.7264218>,
    <0.0416715, -167.7264218>,
    <0.0318288, -167.6586490>,
    <0.0277778, -167.6917086>,
    <0.0338575, -167.7264218>,
    <0.0396460, -167.7034090>,
    <0.0439771, -167.6934805>,
    <0.0370370, -167.6737665>,
    <0.0416715, -167.7264218>,
    <0.0555556, -167.7264218>,
    <0.0416443, -167.6473117>,
    <0.0396460, -167.7034090>,
    <0.0494809, -167.7264218>,
    <0.0494640, -167.6917804>,
    <0.0396304, -167.6588757>,
    <0.9560017, -167.7613916>,
    <0.9629630, -167.7825485>,
    <0.9583382, -167.7264218>,
    <0.9444444, -167.7264218>,
    <0.9582611, -167.8101743>,
    <0.9603574, -167.7509267>,
    <0.9505242, -167.7264218>,
    <0.9504777, -167.7629937>,
    <0.9603155, -167.7981036>,
    <0.9664171, -167.8234969>,
    <0.9629630, -167.7825485>,
    <0.9582611, -167.8101743>,
    <0.9722222, -167.8948019>,
    <0.9722222, -167.8064627>,
    <0.9603155, -167.7981036>,
    <0.9661557, -167.8580287>,
    <0.9722222, -167.8565780>,
    <0.9681682, -167.7959923>,
    <0.9664364, -167.7604637>,
    <0.9629630, -167.7825485>,
    <0.9722222, -167.8064627>,
    <0.9722222, -167.7264218>,
    <0.9583382, -167.7264218>,
    <0.9681682, -167.7959923>,
    <0.9722222, -167.7610230>,
    <0.9661476, -167.7264218>,
    <0.9603574, -167.7509267>,
    <0.9502259, -167.6341061>,
    <0.9537037, -167.6737665>,
    <0.9583110, -167.6473117>,
    <0.9444444, -167.5684558>,
    <0.9444444, -167.6468904>,
    <0.9562970, -167.6588757>,
    <0.9505069, -167.6029317>,
    <0.9444444, -167.6028580>,
    <0.9484955, -167.6586490>,
    <0.9502327, -167.6933751>,
    <0.9537037, -167.6737665>,
    <0.9444444, -167.6468904>,
    <0.9444444, -167.7264218>,
    <0.9583382, -167.7264218>,
    <0.9484955, -167.6586490>,
    <0.9444444, -167.6917086>,
    <0.9505242, -167.7264218>,
    <0.9563127, -167.7034090>,
    <0.9606438, -167.6934805>,
    <0.9537037, -167.6737665>,
    <0.9583382, -167.7264218>,
    <0.9722222, -167.7264218>,
    <0.9583110, -167.6473117>,
    <0.9563127, -167.7034090>,
    <0.9661476, -167.7264218>,
    <0.9661307, -167.6917804>,
    <0.9562970, -167.6588757>,
    <0.0393460, -167.3940515>,
    <0.0462963, -167.4137323>,
    <0.0416333, -167.4397221>,
    <0.0277778, -167.3613758>,
    <0.0416766, -167.3613758>,
    <0.0436704, -167.4283682>,
    <0.0338331, -167.3956156>,
    <0.0338602, -167.3613758>,
    <0.0436960, -167.3842624>,
    <0.0497710, -167.3939086>,
    <0.0462963, -167.4137323>,
    <0.0416766, -167.3613758>,
    <0.0555556, -167.3613758>,
    <0.0555556, -167.4391507>,
    <0.0436960, -167.3842624>,
    <0.0494835, -167.3613758>,
    <0.0555556, -167.3955180>,
    <0.0515005, -167.4280187>,
    <0.0497602, -167.4527626>,
    <0.0462963, -167.4137323>,
    <0.0555556, -167.4391507>,
    <0.0555556, -167.5184453>,
    <0.0416333, -167.4397221>,
    <0.0515005, -167.4280187>,
    <0.0555556, -167.4838674>,
    <0.0494568, -167.4839601>,
    <0.0436704, -167.4283682>,
    <0.0335565, -167.4265843>,
    <0.0370370, -167.4660888>,
    <0.0277778, -167.4391507>,
    <0.0277778, -167.3613758>,
    <0.0416333, -167.4397221>,
    <0.0318280, -167.4509341>,
    <0.0277778, -167.3955180>,
    <0.0338331, -167.3956156>,
    <0.0396239, -167.4512490>,
    <0.0439751, -167.4856754>,
    <0.0370370, -167.4660888>,
    <0.0416333, -167.4397221>,
    <0.0555556, -167.5184453>,
    <0.0416745, -167.5184453>,
    <0.0396239, -167.4512490>,
    <0.0494568, -167.4839601>,
    <0.0494825, -167.5184453>,
    <0.0396478, -167.4955641>,
    <0.0335668, -167.4855325>,
    <0.0370370, -167.4660888>,
    <0.0416745, -167.5184453>,
    <0.0277778, -167.5184453>,
    <0.0277778, -167.4391507>,
    <0.0396478, -167.4955641>,
    <0.0338590, -167.5184453>,
    <0.0277778, -167.4838674>,
    <0.0318280, -167.4509341>,
    <0.9560144, -167.5546111>,
    <0.9629630, -167.5763713>,
    <0.9583091, -167.6051824>,
    <0.9444444, -167.5184453>,
    <0.9583412, -167.5184453>,
    <0.9603423, -167.5925951>,
    <0.9505056, -167.5563642>,
    <0.9505257, -167.5184453>,
    <0.9603616, -167.5437683>,
    <0.9664371, -167.5545331>,
    <0.9629630, -167.5763713>,
    <0.9583412, -167.5184453>,
    <0.9722222, -167.5184453>,
    <0.9722222, -167.6048705>,
    <0.9603616, -167.5437683>,
    <0.9661491, -167.5184453>,
    <0.9722222, -167.5563664>,
    <0.9681677, -167.5923911>,
    <0.9664291, -167.6196618>,
    <0.9629630, -167.5763713>,
    <0.9722222, -167.6048705>,
    <0.9722222, -167.6922232>,
    <0.9583091, -167.6051824>,
    <0.9681677, -167.5923911>,
    <0.9722222, -167.6541051>,
    <0.9661295, -167.6541068>,
    <0.9603423, -167.5925951>,
    <0.9502232, -167.4265843>,
    <0.9537037, -167.4660888>,
    <0.9444444, -167.4391507>,
    <0.9444444, -167.3613758>,
    <0.9583000, -167.4397221>,
    <0.9484947, -167.4509341>,
    <0.9444444, -167.3955180>,
    <0.9504998, -167.3956156>,
    <0.9562906, -167.4512490>,
    <0.9606418, -167.4856754>,
    <0.9537037, -167.4660888>,
    <0.9583000, -167.4397221>,
    <0.9722222, -167.5184453>,
    <0.9583412, -167.5184453>,
    <0.9562906, -167.4512490>,
    <0.9661235, -167.4839601>,
    <0.9661491, -167.5184453>,
    <0.9563145, -167.4955641>,
    <0.9502334, -167.4855325>,
    <0.9537037, -167.4660888>,
    <0.9583412, -167.5184453>,
    <0.9444444, -167.5184453>,
    <0.9444444, -167.4391507>,
    <0.9563145, -167.4955641>,
    <0.9505257, -167.5184453>,
    <0.9444444, -167.4838674>,
    <0.9484947, -167.4509341>,
    <0.0393359, -167.7613967>,
    <0.0462963, -167.7825485>,
    <0.0416715, -167.7264218>,
    <0.0277778, -167.7264218>,
    <0.0415978, -167.8101944>,
    <0.0436908, -167.7509278>,
    <0.0338575, -167.7264218>,
    <0.0338129, -167.7630048>,
    <0.0436507, -167.7981149>,
    <0.0497513, -167.8235083>,
    <0.0462963, -167.7825485>,
    <0.0415978, -167.8101944>,
    <0.0555556, -167.8948019>,
    <0.0555556, -167.8064884>,
    <0.0436507, -167.7981149>,
    <0.0494922, -167.8580476>,
    <0.0555556, -167.8566270>,
    <0.0515016, -167.7960068>,
    <0.0497697, -167.7604701>,
    <0.0462963, -167.7825485>,
    <0.0555556, -167.8064884>,
    <0.0555556, -167.7264218>,
    <0.0416715, -167.7264218>,
    <0.0515016, -167.7960068>,
    <0.0555556, -167.7610362>,
    <0.0494809, -167.7264218>,
    <0.0436908, -167.7509278>,
    <0.0335476, -167.7954435>,
    <0.0370370, -167.8386752>,
    <0.0415978, -167.8101944>,
    <0.0277778, -167.7264218>,
    <0.0277778, -167.8064827>,
    <0.0396029, -167.8226523>,
    <0.0338129, -167.7630048>,
    <0.0277778, -167.7610332>,
    <0.0318234, -167.8205485>,
    <0.0335695, -167.8586904>,
    <0.0370370, -167.8386752>,
    <0.0277778, -167.8064827>,
    <0.0277778, -167.8948019>,
    <0.0416854, -167.8948019>,
    <0.0318234, -167.8205485>,
    <0.0277778, -167.8566142>,
    <0.0337460, -167.8948019>,
    <0.0396736, -167.8705106>,
    <0.0439690, -167.8596184>,
    <0.0370370, -167.8386752>,
    <0.0416854, -167.8948019>,
    <0.0555556, -167.8948019>,
    <0.0415978, -167.8101944>,
    <0.0396736, -167.8705106>,
    <0.0495765, -167.8948019>,
    <0.0494922, -167.8580476>,
    <0.0396029, -167.8226523>,
    <0.9551410, -167.9254604>,
    <0.9629630, -167.9526834>,
    <0.9583539, -167.8948019>,
    <0.9444444, -167.8948019>,
    <0.9548028, -167.9595543>,
    <0.9605025, -167.9217852>,
    <0.9504136, -167.8948019>,
    <0.9488811, -167.9225363>,
    <0.9580587, -167.9568128>,
    <0.9655526, -167.9832467>,
    <0.9629630, -167.9526834>,
    <0.9548028, -167.9595543>,
    <0.9722222, -168.0684463>,
    <0.9722222, -167.9523027>,
    <0.9580587, -167.9568128>,
    <0.9623672, -168.0068407>,
    <0.9722222, -167.9962961>,
    <0.9683354, -167.9524625>,
    <0.9664403, -167.9236475>,
    <0.9629630, -167.9526834>,
    <0.9722222, -167.9523027>,
    <0.9722222, -167.8948019>,
    <0.9583539, -167.8948019>,
    <0.9683354, -167.9524625>,
    <0.9722222, -167.9196016>,
    <0.9662442, -167.8948019>,
    <0.9605025, -167.9217852>,
    <0.9502134, -167.7954301>,
    <0.9537037, -167.8386752>,
    <0.9582611, -167.8101743>,
    <0.9444444, -167.7264218>,
    <0.9444444, -167.8064491>,
    <0.9562673, -167.8226430>,
    <0.9504777, -167.7629937>,
    <0.9444444, -167.7610160>,
    <0.9484897, -167.8205283>,
    <0.9502366, -167.8586820>,
    <0.9537037, -167.8386752>,
    <0.9444444, -167.8064491>,
    <0.9444444, -167.8948019>,
    <0.9583539, -167.8948019>,
    <0.9484897, -167.8205283>,
    <0.9444444, -167.8565554>,
    <0.9504136, -167.8948019>,
    <0.9563401, -167.8704963>,
    <0.9606352, -167.8596133>,
    <0.9537037, -167.8386752>,
    <0.9583539, -167.8948019>,
    <0.9722222, -167.8948019>,
    <0.9582611, -167.8101743>,
    <0.9563401, -167.8704963>,
    <0.9662442, -167.8948019>,
    <0.9661557, -167.8580287>,
    <0.9562673, -167.8226430>,
    <0.0384747, -167.9254654>,
    <0.0462963, -167.9526834>,
    <0.0416854, -167.8948019>,
    <0.0277778, -167.8948019>,
    <0.0381394, -167.9595742>,
    <0.0438362, -167.9218009>,
    <0.0337460, -167.8948019>,
    <0.0322166, -167.9225498>,
    <0.0413938, -167.9568249>,
    <0.0488867, -167.9832864>,
    <0.0462963, -167.9526834>,
    <0.0381394, -167.9595742>,
    <0.0555556, -168.0684463>,
    <0.0555556, -167.9524416>,
    <0.0413938, -167.9568249>,
    <0.0457023, -168.0068514>,
    <0.0555556, -167.9963158>,
    <0.0516691, -167.9525431>,
    <0.0497732, -167.9236822>,
    <0.0462963, -167.9526834>,
    <0.0555556, -167.9524416>,
    <0.0555556, -167.8948019>,
    <0.0416854, -167.8948019>,
    <0.0516691, -167.9525431>,
    <0.0555556, -167.9196590>,
    <0.0495765, -167.8948019>,
    <0.0438362, -167.9218009>,
    <0.0326830, -167.9543361>,
    <0.0370370, -168.0105648>,
    <0.0381394, -167.9595742>,
    <0.0277778, -167.8948019>,
    <0.0277778, -167.9524033>,
    <0.0376366, -167.9828281>,
    <0.0322166, -167.9225498>,
    <0.0277778, -167.9196450>,
    <0.0319742, -167.9787629>,
    <0.0335648, -168.0249652>,
    <0.0370370, -168.0105648>,
    <0.0277778, -167.9524033>,
    <0.0277778, -168.0684463>,
    <0.0416667, -168.0684463>,
    <0.0319742, -167.9787629>,
    <0.0277778, -167.9963224>,
    <0.0347222, -168.0684463>,
    <0.0397824, -168.0448888>,
    <0.0430996, -168.0267579>,
    <0.0370370, -168.0105648>,
    <0.0416667, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0381394, -167.9595742>,
    <0.0397824, -168.0448888>,
    <0.0486111, -168.0684463>,
    <0.0457023, -168.0068514>,
    <0.0376366, -167.9828281>,
    <0.9493489, -167.9542906>,
    <0.9537037, -168.0105648>,
    <0.9548028, -167.9595543>,
    <0.9444444, -167.8948019>,
    <0.9444444, -167.9522414>,
    <0.9543016, -167.9828168>,
    <0.9488811, -167.9225363>,
    <0.9444444, -167.9195727>,
    <0.9486409, -167.9786743>,
    <0.9502315, -168.0249247>,
    <0.9537037, -168.0105648>,
    <0.9444444, -167.9522414>,
    <0.9444444, -168.0684463>,
    <0.9583333, -168.0684463>,
    <0.9486409, -167.9786743>,
    <0.9444444, -167.9962654>,
    <0.9513889, -168.0684463>,
    <0.9564490, -168.0448877>,
    <0.9597655, -168.0267529>,
    <0.9537037, -168.0105648>,
    <0.9583333, -168.0684463>,
    <0.9722222, -168.0684463>,
    <0.9548028, -167.9595543>,
    <0.9564490, -168.0448877>,
    <0.9652778, -168.0684463>,
    <0.9623672, -168.0068407>,
    <0.9543016, -167.9828168>,
    <0.0393477, -167.5546111>,
    <0.0462963, -167.5763713>,
    <0.0416424, -167.6051824>,
    <0.0277778, -167.5184453>,
    <0.0416745, -167.5184453>,
    <0.0436756, -167.5925951>,
    <0.0338390, -167.5563642>,
    <0.0338590, -167.5184453>,
    <0.0436950, -167.5437683>,
    <0.0497705, -167.5545331>,
    <0.0462963, -167.5763713>,
    <0.0416745, -167.5184453>,
    <0.0555556, -167.5184453>,
    <0.0555556, -167.6048705>,
    <0.0436950, -167.5437683>,
    <0.0494825, -167.5184453>,
    <0.0555556, -167.5563664>,
    <0.0515011, -167.5923911>,
    <0.0497624, -167.6196618>,
    <0.0462963, -167.5763713>,
    <0.0555556, -167.6048705>,
    <0.0555556, -167.6922232>,
    <0.0416424, -167.6051824>,
    <0.0515011, -167.5923911>,
    <0.0555556, -167.6541051>,
    <0.0494628, -167.6541068>,
    <0.0436756, -167.5925951>,
    <0.0335587, -167.5906989>,
    <0.0370370, -167.6342972>,
    <0.0277778, -167.6048705>,
    <0.0277778, -167.5184453>,
    <0.0416424, -167.6051824>,
    <0.0318287, -167.6177446>,
    <0.0277778, -167.5563664>,
    <0.0338390, -167.5563642>,
    <0.0396292, -167.6179095>,
    <0.0439768, -167.6559815>,
    <0.0370370, -167.6342972>,
    <0.0416424, -167.6051824>,
    <0.0555556, -167.6922232>,
    <0.0416721, -167.6922232>,
    <0.0396292, -167.6179095>,
    <0.0494628, -167.6541068>,
    <0.0494812, -167.6922232>,
    <0.0396464, -167.6669079>,
    <0.0335662, -167.6559035>,
    <0.0370370, -167.6342972>,
    <0.0416721, -167.6922232>,
    <0.0277778, -167.6922232>,
    <0.0277778, -167.6048705>,
    <0.0396464, -167.6669079>,
    <0.0338577, -167.6922232>,
    <0.0277778, -167.6541051>,
    <0.0318287, -167.6177446>,
    <0.9560009, -167.7306809>,
    <0.9629630, -167.7539575>,
    <0.9582576, -167.7843199>,
    <0.9444444, -167.6922232>,
    <0.9583388, -167.6922232>,
    <0.9603135, -167.7710538>,
    <0.9504757, -167.7324351>,
    <0.9505244, -167.6922232>,
    <0.9603577, -167.7191773>,
    <0.9664365, -167.7297533>,
    <0.9629630, -167.7539575>,
    <0.9583388, -167.6922232>,
    <0.9722222, -167.6922232>,
    <0.9722222, -167.7806092>,
    <0.9603577, -167.7191773>,
    <0.9661479, -167.6922232>,
    <0.9722222, -167.7304809>,
    <0.9681681, -167.7689398>,
    <0.9664163, -167.7990782>,
    <0.9629630, -167.7539575>,
    <0.9722222, -167.7806092>,
    <0.9722222, -167.8774261>,
    <0.9582576, -167.7843199>,
    <0.9681681, -167.7689398>,
    <0.9722222, -167.8355367>,
    <0.9661999, -167.8372733>,
    <0.9603135, -167.7710538>,
    <0.9502254, -167.5906989>,
    <0.9537037, -167.6342972>,
    <0.9444444, -167.6048705>,
    <0.9444444, -167.5184453>,
    <0.9583091, -167.6051824>,
    <0.9484954, -167.6177446>,
    <0.9444444, -167.5563664>,
    <0.9505056, -167.5563642>,
    <0.9562959, -167.6179095>,
    <0.9606434, -167.6559815>,
    <0.9537037, -167.6342972>,
    <0.9583091, -167.6051824>,
    <0.9722222, -167.6922232>,
    <0.9583388, -167.6922232>,
    <0.9562959, -167.6179095>,
    <0.9661295, -167.6541068>,
    <0.9661479, -167.6922232>,
    <0.9563131, -167.6669079>,
    <0.9502328, -167.6559035>,
    <0.9537037, -167.6342972>,
    <0.9583388, -167.6922232>,
    <0.9444444, -167.6922232>,
    <0.9444444, -167.6048705>,
    <0.9563131, -167.6669079>,
    <0.9505244, -167.6922232>,
    <0.9444444, -167.6541051>,
    <0.9484954, -167.6177446>,
    <0.0393351, -167.7306865>,
    <0.0462963, -167.7539575>,
    <0.0415943, -167.7843422>,
    <0.0277778, -167.6922232>,
    <0.0416721, -167.6922232>,
    <0.0436487, -167.7710663>,
    <0.0338108, -167.7324475>,
    <0.0338577, -167.6922232>,
    <0.0436912, -167.7191785>,
    <0.0497699, -167.7297593>,
    <0.0462963, -167.7539575>,
    <0.0416721, -167.6922232>,
    <0.0555556, -167.6922232>,
    <0.0555556, -167.7806332>,
    <0.0436912, -167.7191785>,
    <0.0494812, -167.6922232>,
    <0.0555556, -167.7304934>,
    <0.0515014, -167.7689534>,
    <0.0497504, -167.7990897>,
    <0.0462963, -167.7539575>,
    <0.0555556, -167.7806332>,
    <0.0555556, -167.8774261>,
    <0.0415943, -167.7843422>,
    <0.0515014, -167.7689534>,
    <0.0555556, -167.8343496>,
    <0.0494273, -167.8365669>,
    <0.0436487, -167.7710663>,
    <0.0335467, -167.7682213>,
    <0.0370370, -167.8156918>,
    <0.0277778, -167.7806279>,
    <0.0277778, -167.6922232>,
    <0.0415943, -167.7843422>,
    <0.0318232, -167.7959475>,
    <0.0277778, -167.7304906>,
    <0.0338108, -167.7324475>,
    <0.0396012, -167.7980529>,
    <0.0439681, -167.8387215>,
    <0.0370370, -167.8156918>,
    <0.0415943, -167.7843422>,
    <0.0555556, -167.8774261>,
    <0.0416857, -167.8774261>,
    <0.0396012, -167.7980529>,
    <0.0494273, -167.8365669>,
    <0.0494850, -167.8774261>,
    <0.0396488, -167.8503766>,
    <0.0335696, -167.8377929>,
    <0.0370370, -167.8156918>,
    <0.0416857, -167.8774261>,
    <0.0277778, -167.8774261>,
    <0.0277778, -167.7806279>,
    <0.0396488, -167.8503766>,
    <0.0338687, -167.8774261>,
    <0.0277778, -167.8351483>,
    <0.0318232, -167.7959475>,
    <0.9558254, -167.9158580>,
    <0.9629630, -167.9410995>,
    <0.9575400, -167.9674805>,
    <0.9444444, -167.8774261>,
    <0.9583542, -167.8774261>,
    <0.9598988, -167.9560056>,
    <0.9500814, -167.9161900>,
    <0.9505357, -167.8774261>,
    <0.9603600, -167.9051379>,
    <0.9664404, -167.9162234>,
    <0.9629630, -167.9410995>,
    <0.9583542, -167.8774261>,
    <0.9722222, -167.8774261>,
    <0.9722222, -167.9689421>,
    <0.9603600, -167.9051379>,
    <0.9662590, -167.8774261>,
    <0.9722222, -167.9167707>,
    <0.9682389, -167.9569642>,
    <0.9662368, -167.9864921>,
    <0.9629630, -167.9410995>,
    <0.9722222, -167.9689421>,
    <0.9722222, -168.0684463>,
    <0.9575400, -167.9674805>,
    <0.9682389, -167.9569642>,
    <0.9722222, -168.0303083>,
    <0.9654745, -168.0220440>,
    <0.9598988, -167.9560056>,
    <0.9502126, -167.7682078>,
    <0.9537037, -167.8156918>,
    <0.9444444, -167.7805965>,
    <0.9444444, -167.6922232>,
    <0.9582576, -167.7843199>,
    <0.9484895, -167.7959283>,
    <0.9444444, -167.7304743>,
    <0.9504757, -167.7324351>,
    <0.9562656, -167.7980427>,
    <0.9606344, -167.8387159>,
    <0.9537037, -167.8156918>,
    <0.9582576, -167.7843199>,
    <0.9722222, -167.8774261>,
    <0.9583542, -167.8774261>,
    <0.9562656, -167.7980427>,
    <0.9661999, -167.8372733>,
    <0.9662590, -167.8774261>,
    <0.9563154, -167.8503618>,
    <0.9502367, -167.8377851>,
    <0.9537037, -167.8156918>,
    <0.9583542, -167.8774261>,
    <0.9444444, -167.8774261>,
    <0.9444444, -167.7805965>,
    <0.9563154, -167.8503618>,
    <0.9505357, -167.8774261>,
    <0.9444444, -167.8343036>,
    <0.9484895, -167.7959283>,
    <0.0392512, -167.9164969>,
    <0.0462963, -167.9410995>,
    <0.0412449, -167.9700362>,
    <0.0277778, -167.8774261>,
    <0.0416857, -167.8774261>,
    <0.0434009, -167.9576856>,
    <0.0335548, -167.9171532>,
    <0.0338687, -167.8774261>,
    <0.0437032, -167.9052886>,
    <0.0497733, -167.9151143>,
    <0.0462963, -167.9410995>,
    <0.0416857, -167.8774261>,
    <0.0555556, -167.8774261>,
    <0.0555556, -167.9645057>,
    <0.0437032, -167.9052886>,
    <0.0494850, -167.8774261>,
    <0.0555556, -167.9158750>,
    <0.0514970, -167.9542461>,
    <0.0496631, -167.9860219>,
    <0.0462963, -167.9410995>,
    <0.0555556, -167.9645057>,
    <0.0555556, -168.0684463>,
    <0.0412449, -167.9700362>,
    <0.0514970, -167.9542461>,
    <0.0555556, -168.0211455>,
    <0.0494192, -168.0262482>,
    <0.0434009, -167.9576856>,
    <0.0334594, -167.9577781>,
    <0.0370370, -168.0047729>,
    <0.0277778, -167.9788771>,
    <0.0277778, -167.8774261>,
    <0.0412449, -167.9700362>,
    <0.0315700, -167.9894830>,
    <0.0277778, -167.9227974>,
    <0.0335548, -167.9171532>,
    <0.0391559, -167.9872813>,
    <0.0448793, -168.0279254>,
    <0.0370370, -168.0047729>,
    <0.0412449, -167.9700362>,
    <0.0555556, -168.0684463>,
    <0.0456798, -168.0684463>,
    <0.0391559, -167.9872813>,
    <0.0494192, -168.0262482>,
    <0.0514609, -168.0684463>,
    <0.0419766, -168.0411644>,
    <0.0345681, -168.0301356>,
    <0.0370370, -168.0047729>,
    <0.0456798, -168.0684463>,
    <0.0277778, -168.0684463>,
    <0.0277778, -167.9788771>,
    <0.0419766, -168.0411644>,
    <0.0380114, -168.0684463>,
    <0.0277778, -168.0257366>,
    <0.0315700, -167.9894830>,
    <0.9500331, -167.9539567>,
    <0.9537037, -168.0047729>,
    <0.9444444, -167.9661475>,
    <0.9444444, -167.8774261>,
    <0.9575400, -167.9674805>,
    <0.9483847, -167.9825846>,
    <0.9444444, -167.9166800>,
    <0.9500814, -167.9161900>,
    <0.9558026, -167.9843697>,
    <0.9607380, -168.0272865>,
    <0.9537037, -168.0047729>,
    <0.9575400, -167.9674805>,
    <0.9722222, -168.0684463>,
    <0.9594863, -168.0684463>,
    <0.9558026, -167.9843697>,
    <0.9654745, -168.0220440>,
    <0.9670675, -168.0684463>,
    <0.9563874, -168.0343232>,
    <0.9505197, -168.0269532>,
    <0.9537037, -168.0047729>,
    <0.9594863, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9444444, -167.9661475>,
    <0.9563874, -168.0343232>,
    <0.9510083, -168.0684463>,
    <0.9444444, -168.0222152>,
    <0.9483847, -167.9825846>,
    <0.0812857, -167.1106496>,
    <0.0820967, -167.1123151>,
    <0.0810912, -167.1040945>,
    <0.0796235, -167.1040945>,
    <0.0823311, -167.1220942>,
    <0.0815216, -167.1076129>,
    <0.0802663, -167.1040945>,
    <0.0810831, -167.1137978>,
    <0.0822479, -167.1186210>,
    <0.0827736, -167.1197229>,
    <0.0820967, -167.1123151>,
    <0.0823311, -167.1220942>,
    <0.0833333, -167.1287564>,
    <0.0833333, -167.1157258>,
    <0.0822479, -167.1186210>,
    <0.0830486, -167.1268637>,
    <0.0833333, -167.1243286>,
    <0.0828383, -167.1143605>,
    <0.0824637, -167.1090575>,
    <0.0820967, -167.1123151>,
    <0.0833333, -167.1157258>,
    <0.0833333, -167.1040945>,
    <0.0810912, -167.1040945>,
    <0.0828383, -167.1143605>,
    <0.0833333, -167.1077204>,
    <0.0821429, -167.1040945>,
    <0.0815216, -167.1076129>,
    <0.0780472, -167.1106496>,
    <0.0769974, -167.1123151>,
    <0.0823312, -167.1220942>,
    <0.0796235, -167.1040945>,
    <0.0732365, -167.1040945>,
    <0.0795565, -167.1170071>,
    <0.0810832, -167.1137978>,
    <0.0761701, -167.1040945>,
    <0.0746246, -167.1071285>,
    <0.0744757, -167.1108241>,
    <0.0769974, -167.1123151>,
    <0.0732365, -167.1040945>,
    <0.0680354, -167.1040945>,
    <0.0796336, -167.1227921>,
    <0.0746246, -167.1071285>,
    <0.0705617, -167.1040945>,
    <0.0753189, -167.1158363>,
    <0.0786638, -167.1189380>,
    <0.0805739, -167.1214895>,
    <0.0769974, -167.1123151>,
    <0.0796336, -167.1227921>,
    <0.0833333, -167.1287564>,
    <0.0823312, -167.1220942>,
    <0.0786638, -167.1189380>,
    <0.0819839, -167.1265810>,
    <0.0830486, -167.1268637>,
    <0.0795565, -167.1170071>,
    <0.0687645, -167.1176324>,
    <0.0689748, -167.1205358>,
    <0.0796337, -167.1227921>,
    <0.0680354, -167.1040945>,
    <0.0584142, -167.1231073>,
    <0.0749529, -167.1218013>,
    <0.0753189, -167.1158363>,
    <0.0619076, -167.1162039>,
    <0.0632855, -167.1219211>,
    <0.0628548, -167.1252890>,
    <0.0689748, -167.1205358>,
    <0.0584142, -167.1231073>,
    <0.0555556, -167.1287564>,
    <0.0684748, -167.1287564>,
    <0.0632855, -167.1219211>,
    <0.0565936, -167.1267051>,
    <0.0608260, -167.1287564>,
    <0.0686527, -167.1258320>,
    <0.0751041, -167.1252102>,
    <0.0689748, -167.1205358>,
    <0.0684748, -167.1287564>,
    <0.0833333, -167.1287564>,
    <0.0796337, -167.1227921>,
    <0.0686527, -167.1258320>,
    <0.0768676, -167.1287564>,
    <0.0819839, -167.1265810>,
    <0.0749529, -167.1218013>,
    <0.9300037, -167.1175675>,
    <0.9300859, -167.1205421>,
    <0.9409447, -167.1231187>,
    <0.9291466, -167.1041136>,
    <0.9198375, -167.1224954>,
    <0.9363676, -167.1220327>,
    <0.9368189, -167.1164727>,
    <0.9235231, -167.1152176>,
    <0.9247222, -167.1215644>,
    <0.9240892, -167.1251376>,
    <0.9300859, -167.1205421>,
    <0.9198375, -167.1224954>,
    <0.9166667, -167.1287564>,
    <0.9297668, -167.1287564>,
    <0.9247222, -167.1215644>,
    <0.9178233, -167.1264726>,
    <0.9220486, -167.1287564>,
    <0.9298725, -167.1260344>,
    <0.9363105, -167.1252934>,
    <0.9300859, -167.1205421>,
    <0.9297668, -167.1287564>,
    <0.9444444, -167.1287564>,
    <0.9409447, -167.1231187>,
    <0.9298725, -167.1260344>,
    <0.9381019, -167.1287564>,
    <0.9431689, -167.1267016>,
    <0.9363676, -167.1220327>,
    <0.9239715, -167.1107626>,
    <0.9217789, -167.1123279>,
    <0.9198375, -167.1224954>,
    <0.9291466, -167.1041136>,
    <0.9251232, -167.1041136>,
    <0.9205304, -167.1188661>,
    <0.9235231, -167.1152176>,
    <0.9272708, -167.1041136>,
    <0.9239734, -167.1069379>,
    <0.9210274, -167.1101333>,
    <0.9217789, -167.1123279>,
    <0.9251232, -167.1041136>,
    <0.9195233, -167.1041136>,
    <0.9176842, -167.1199784>,
    <0.9239734, -167.1069379>,
    <0.9226106, -167.1041136>,
    <0.9185965, -167.1121091>,
    <0.9198391, -167.1159522>,
    <0.9189918, -167.1208895>,
    <0.9217789, -167.1123279>,
    <0.9176842, -167.1199784>,
    <0.9166667, -167.1287564>,
    <0.9198375, -167.1224954>,
    <0.9198391, -167.1159522>,
    <0.9170102, -167.1257934>,
    <0.9178233, -167.1264726>,
    <0.9205304, -167.1188661>,
    <0.9281266, -167.1443229>,
    <0.9351852, -167.1533103>,
    <0.9297668, -167.1287564>,
    <0.9166667, -167.1287564>,
    <0.9308878, -167.1664683>,
    <0.9324453, -167.1408941>,
    <0.9220486, -167.1287564>,
    <0.9230245, -167.1456162>,
    <0.9328259, -167.1605343>,
    <0.9387405, -167.1705747>,
    <0.9351852, -167.1533103>,
    <0.9308878, -167.1664683>,
    <0.9444444, -167.2024179>,
    <0.9444444, -167.1601024>,
    <0.9328259, -167.1605343>,
    <0.9385539, -167.1867974>,
    <0.9444444, -167.1835238>,
    <0.9404582, -167.1571783>,
    <0.9384602, -167.1427314>,
    <0.9351852, -167.1533103>,
    <0.9444444, -167.1601024>,
    <0.9444444, -167.1287564>,
    <0.9297668, -167.1287564>,
    <0.9404582, -167.1571783>,
    <0.9444444, -167.1407349>,
    <0.9381019, -167.1287564>,
    <0.9324453, -167.1408941>,
    <0.9183116, -167.1101299>,
    <0.9176189, -167.1123215>,
    <0.9176842, -167.1199784>,
    <0.9195233, -167.1041136>,
    <0.9184198, -167.1041062>,
    <0.9176596, -167.1170886>,
    <0.9185965, -167.1121091>,
    <0.9190449, -167.1041104>,
    <0.9180749, -167.1076438>,
    <0.9173430, -167.1098047>,
    <0.9176189, -167.1123215>,
    <0.9184198, -167.1041062>,
    <0.9166667, -167.1040945>,
    <0.9166667, -167.1186966>,
    <0.9180749, -167.1076438>,
    <0.9176033, -167.1041008>,
    <0.9166667, -167.1075969>,
    <0.9170158, -167.1163593>,
    <0.9171591, -167.1199382>,
    <0.9176189, -167.1123215>,
    <0.9166667, -167.1186966>,
    <0.9166667, -167.1287564>,
    <0.9176842, -167.1199784>,
    <0.9170158, -167.1163593>,
    <0.9166667, -167.1268390>,
    <0.9170102, -167.1257934>,
    <0.9176596, -167.1170886>,
    <0.9262210, -167.0805621>,
    <0.9297323, -167.0842391>,
    <0.9358213, -167.1011169>,
    <0.9166667, -167.0684463>,
    <0.9226635, -167.0684463>,
    <0.9336717, -167.0951584>,
    <0.9282208, -167.0881533>,
    <0.9197042, -167.0684463>,
    <0.9255019, -167.0747878>,
    <0.9295789, -167.0794530>,
    <0.9297323, -167.0842391>,
    <0.9226635, -167.0684463>,
    <0.9280857, -167.0684463>,
    <0.9378342, -167.0966801>,
    <0.9255019, -167.0747878>,
    <0.9254714, -167.0684463>,
    <0.9330798, -167.0829104>,
    <0.9337969, -167.0904805>,
    <0.9369581, -167.0994652>,
    <0.9297323, -167.0842391>,
    <0.9378342, -167.0966801>,
    <0.9444444, -167.1158246>,
    <0.9358213, -167.1011169>,
    <0.9337969, -167.0904805>,
    <0.9418759, -167.1083857>,
    <0.9409806, -167.1099166>,
    <0.9336717, -167.0951584>,
    <0.0669470, -167.1442610>,
    <0.0740741, -167.1533103>,
    <0.0684748, -167.1287564>,
    <0.0555556, -167.1287564>,
    <0.0696834, -167.1662209>,
    <0.0712339, -167.1408553>,
    <0.0608260, -167.1287564>,
    <0.0618127, -167.1453493>,
    <0.0716618, -167.1604034>,
    <0.0776060, -167.1706661>,
    <0.0740741, -167.1533103>,
    <0.0696834, -167.1662209>,
    <0.0833333, -167.2024179>,
    <0.0833333, -167.1607154>,
    <0.0716618, -167.1604034>,
    <0.0773929, -167.1866652>,
    <0.0833333, -167.1838308>,
    <0.0793453, -167.1575260>,
    <0.0773039, -167.1428846>,
    <0.0740741, -167.1533103>,
    <0.0833333, -167.1607154>,
    <0.0833333, -167.1287564>,
    <0.0684748, -167.1287564>,
    <0.0793453, -167.1575260>,
    <0.0833333, -167.1413913>,
    <0.0768676, -167.1287564>,
    <0.0712339, -167.1408553>,
    <0.0614023, -167.1583892>,
    <0.0648148, -167.1778641>,
    <0.0696834, -167.1662209>,
    <0.0555556, -167.1287564>,
    <0.0555556, -167.1607154>,
    <0.0675621, -167.1712941>,
    <0.0618127, -167.1453493>,
    <0.0555556, -167.1413914>,
    <0.0596123, -167.1682288>,
    <0.0613455, -167.1858539>,
    <0.0648148, -167.1778641>,
    <0.0555556, -167.1607154>,
    <0.0555556, -167.2024179>,
    <0.0694563, -167.2024179>,
    <0.0596123, -167.1682288>,
    <0.0555556, -167.1838308>,
    <0.0616390, -167.2024179>,
    <0.0674351, -167.1917260>,
    <0.0718220, -167.1872302>,
    <0.0648148, -167.1778641>,
    <0.0694563, -167.2024179>,
    <0.0833333, -167.2024179>,
    <0.0696834, -167.1662209>,
    <0.0674351, -167.1917260>,
    <0.0772622, -167.2024179>,
    <0.0773929, -167.1866652>,
    <0.0675621, -167.1712941>,
    <0.9282325, -167.2232074>,
    <0.9351852, -167.2357456>,
    <0.9305674, -167.2024179>,
    <0.9166667, -167.2024179>,
    <0.9305108, -167.2522483>,
    <0.9325851, -167.2169804>,
    <0.9227501, -167.2024179>,
    <0.9227146, -167.2241867>,
    <0.9325529, -167.2450388>,
    <0.9386462, -167.2602946>,
    <0.9351852, -167.2357456>,
    <0.9305108, -167.2522483>,
    <0.9444444, -167.3024008>,
    <0.9444444, -167.2507837>,
    <0.9325529, -167.2450388>,
    <0.9383380, -167.2804214>,
    <0.9444444, -167.2798504>,
    <0.9403888, -167.2441968>,
    <0.9386604, -167.2228413>,
    <0.9351852, -167.2357456>,
    <0.9444444, -167.2507837>,
    <0.9444444, -167.2024179>,
    <0.9305674, -167.2024179>,
    <0.9403888, -167.2441968>,
    <0.9444444, -167.2235884>,
    <0.9383733, -167.2024179>,
    <0.9325851, -167.2169804>,
    <0.9225368, -167.1582978>,
    <0.9259259, -167.1778641>,
    <0.9308878, -167.1664683>,
    <0.9166667, -167.1287564>,
    <0.9166667, -167.1601023>,
    <0.9287247, -167.1714363>,
    <0.9230245, -167.1456162>,
    <0.9166667, -167.1407348>,
    <0.9207224, -167.1678823>,
    <0.9224567, -167.1857006>,
    <0.9259259, -167.1778641>,
    <0.9166667, -167.1601023>,
    <0.9166667, -167.2024179>,
    <0.9305674, -167.2024179>,
    <0.9207224, -167.1678823>,
    <0.9166667, -167.1835237>,
    <0.9227501, -167.2024179>,
    <0.9285490, -167.1917403>,
    <0.9329564, -167.1872921>,
    <0.9259259, -167.1778641>,
    <0.9305674, -167.2024179>,
    <0.9444444, -167.2024179>,
    <0.9308878, -167.1664683>,
    <0.9285490, -167.1917403>,
    <0.9383733, -167.2024179>,
    <0.9385539, -167.1867974>,
    <0.9287247, -167.1714363>,
    <0.0740612, -167.0791001>,
    <0.0778804, -167.0842391>,
    <0.0762358, -167.0952687>,
    <0.0669746, -167.0684463>,
    <0.0751539, -167.0684463>,
    <0.0768939, -167.0908553>,
    <0.0714141, -167.0813042>,
    <0.0710642, -167.0684463>,
    <0.0763365, -167.0752962>,
    <0.0799252, -167.0791482>,
    <0.0778804, -167.0842391>,
    <0.0751539, -167.0684463>,
    <0.0833333, -167.0684463>,
    <0.0833333, -167.0954613>,
    <0.0763365, -167.0752962>,
    <0.0792436, -167.0684463>,
    <0.0833333, -167.0824248>,
    <0.0810175, -167.0906952>,
    <0.0801957, -167.0976984>,
    <0.0778804, -167.0842391>,
    <0.0833333, -167.0954613>,
    <0.0833333, -167.1158246>,
    <0.0762358, -167.0952687>,
    <0.0810175, -167.0906952>,
    <0.0833333, -167.1101338>,
    <0.0805268, -167.1076964>,
    <0.0768939, -167.0908553>,
    <0.0650546, -167.0805905>,
    <0.0686211, -167.0842391>,
    <0.0747768, -167.1012305>,
    <0.0555556, -167.0684463>,
    <0.0612651, -167.0684463>,
    <0.0726566, -167.0953781>,
    <0.0672013, -167.0883095>,
    <0.0584103, -167.0684463>,
    <0.0642198, -167.0747898>,
    <0.0682741, -167.0791001>,
    <0.0686211, -167.0842391>,
    <0.0612651, -167.0684463>,
    <0.0669745, -167.0684463>,
    <0.0762358, -167.0952687>,
    <0.0642198, -167.0747898>,
    <0.0641198, -167.0684463>,
    <0.0714141, -167.0813042>,
    <0.0724473, -167.0897812>,
    <0.0757418, -167.0991407>,
    <0.0686211, -167.0842391>,
    <0.0762358, -167.0952687>,
    <0.0833333, -167.1158246>,
    <0.0747768, -167.1012305>,
    <0.0724473, -167.0897812>,
    <0.0805268, -167.1076964>,
    <0.0798999, -167.1099685>,
    <0.0726566, -167.0953781>,
    <0.0626757, -167.0912642>,
    <0.0648148, -167.1000319>,
    <0.0555556, -167.0953483>,
    <0.0555556, -167.0684463>,
    <0.0747768, -167.1012305>,
    <0.0595410, -167.0973642>,
    <0.0555556, -167.0824562>,
    <0.0672013, -167.0883095>,
    <0.0697088, -167.1006207>,
    <0.0729459, -167.1082279>,
    <0.0648148, -167.1000319>,
    <0.0747768, -167.1012305>,
    <0.0833333, -167.1158246>,
    <0.0688585, -167.1158246>,
    <0.0697088, -167.1006207>,
    <0.0798999, -167.1099685>,
    <0.0770748, -167.1158246>,
    <0.0669698, -167.1084485>,
    <0.0611961, -167.1067574>,
    <0.0648148, -167.1000319>,
    <0.0688585, -167.1158246>,
    <0.0555556, -167.1158246>,
    <0.0555556, -167.0953483>,
    <0.0669698, -167.1084485>,
    <0.0610406, -167.1158246>,
    <0.0555556, -167.1100291>,
    <0.0595410, -167.0973642>,
    <0.9280165, -167.1384086>,
    <0.9351852, -167.1524837>,
    <0.9302242, -167.1695015>,
    <0.9166667, -167.1158246>,
    <0.9299898, -167.1158246>,
    <0.9323855, -167.1620875>,
    <0.9223953, -167.1385053>,
    <0.9221625, -167.1158246>,
    <0.9322410, -167.1317092>,
    <0.9385160, -167.1378830>,
    <0.9351852, -167.1524837>,
    <0.9299898, -167.1158246>,
    <0.9444444, -167.1158246>,
    <0.9444444, -167.1673989>,
    <0.9322410, -167.1317092>,
    <0.9381989, -167.1158246>,
    <0.9444444, -167.1360737>,
    <0.9403832, -167.1608569>,
    <0.9385746, -167.1787965>,
    <0.9351852, -167.1524837>,
    <0.9444444, -167.1673989>,
    <0.9444444, -167.2258020>,
    <0.9302242, -167.1695015>,
    <0.9403832, -167.1608569>,
    <0.9444444, -167.2002202>,
    <0.9381806, -167.2010024>,
    <0.9323855, -167.1620875>,
    <0.9237701, -167.0910306>,
    <0.9259259, -167.1000319>,
    <0.9166667, -167.0945275>,
    <0.9166667, -167.0684463>,
    <0.9358213, -167.1011169>,
    <0.9206671, -167.0969056>,
    <0.9166667, -167.0815405>,
    <0.9282208, -167.0881533>,
    <0.9308014, -167.1005664>,
    <0.9340454, -167.1081995>,
    <0.9259259, -167.1000319>,
    <0.9358213, -167.1011169>,
    <0.9444444, -167.1158246>,
    <0.9299898, -167.1158246>,
    <0.9308014, -167.1005664>,
    <0.9409806, -167.1099166>,
    <0.9381989, -167.1158246>,
    <0.9280961, -167.1084655>,
    <0.9223123, -167.1065522>,
    <0.9259259, -167.1000319>,
    <0.9299898, -167.1158246>,
    <0.9166667, -167.1158246>,
    <0.9166667, -167.0945275>,
    <0.9280961, -167.1084655>,
    <0.9221625, -167.1158246>,
    <0.9166667, -167.1098632>,
    <0.9206671, -167.0969056>,
    <0.0671214, -167.2232074>,
    <0.0740741, -167.2357456>,
    <0.0694563, -167.2024179>,
    <0.0555556, -167.2024179>,
    <0.0693997, -167.2522483>,
    <0.0714740, -167.2169804>,
    <0.0616390, -167.2024179>,
    <0.0616035, -167.2241867>,
    <0.0714418, -167.2450388>,
    <0.0775351, -167.2602946>,
    <0.0740741, -167.2357456>,
    <0.0693997, -167.2522483>,
    <0.0833333, -167.3024008>,
    <0.0833333, -167.2507837>,
    <0.0714418, -167.2450388>,
    <0.0772269, -167.2804214>,
    <0.0833333, -167.2798504>,
    <0.0792776, -167.2441968>,
    <0.0775492, -167.2228413>,
    <0.0740741, -167.2357456>,
    <0.0833333, -167.2507837>,
    <0.0833333, -167.2024179>,
    <0.0694563, -167.2024179>,
    <0.0792776, -167.2441968>,
    <0.0833333, -167.2235884>,
    <0.0772622, -167.2024179>,
    <0.0714740, -167.2169804>,
    <0.0613314, -167.2436308>,
    <0.0648148, -167.2690732>,
    <0.0693997, -167.2522483>,
    <0.0555556, -167.2024179>,
    <0.0555556, -167.2507837>,
    <0.0673951, -167.2596042>,
    <0.0616035, -167.2241867>,
    <0.0555556, -167.2235884>,
    <0.0596050, -167.2587824>,
    <0.0613452, -167.2811646>,
    <0.0648148, -167.2690732>,
    <0.0555556, -167.2507837>,
    <0.0555556, -167.3024008>,
    <0.0694550, -167.3024008>,
    <0.0596050, -167.2587824>,
    <0.0555556, -167.2798504>,
    <0.0616383, -167.3024008>,
    <0.0674266, -167.2878319>,
    <0.0717507, -167.2815307>,
    <0.0648148, -167.2690732>,
    <0.0694550, -167.3024008>,
    <0.0833333, -167.3024008>,
    <0.0693997, -167.2522483>,
    <0.0674266, -167.2878319>,
    <0.0772616, -167.3024008>,
    <0.0772269, -167.2804214>,
    <0.0673951, -167.2596042>,
    <0.9282338, -167.3280360>,
    <0.9351852, -167.3434849>,
    <0.9305662, -167.3024008>,
    <0.9166667, -167.3024008>,
    <0.9305174, -167.3638575>,
    <0.9325848, -167.3203558>,
    <0.9227495, -167.3024008>,
    <0.9227189, -167.3292549>,
    <0.9325566, -167.3549573>,
    <0.9386479, -167.3739447>,
    <0.9351852, -167.3434849>,
    <0.9305174, -167.3638575>,
    <0.9444445, -167.4256532>,
    <0.9444444, -167.3627833>,
    <0.9325566, -167.3549573>,
    <0.9383424, -167.3985780>,
    <0.9444444, -167.3982231>,
    <0.9403891, -167.3543311>,
    <0.9386601, -167.3277674>,
    <0.9351852, -167.3434849>,
    <0.9444444, -167.3627833>,
    <0.9444444, -167.3024008>,
    <0.9305662, -167.3024008>,
    <0.9403891, -167.3543311>,
    <0.9444444, -167.3288803>,
    <0.9383727, -167.3024008>,
    <0.9325848, -167.3203558>,
    <0.9224425, -167.2436308>,
    <0.9259259, -167.2690732>,
    <0.9305108, -167.2522483>,
    <0.9166667, -167.2024179>,
    <0.9166667, -167.2507837>,
    <0.9285063, -167.2596042>,
    <0.9227146, -167.2241867>,
    <0.9166667, -167.2235884>,
    <0.9207161, -167.2587824>,
    <0.9224564, -167.2811646>,
    <0.9259259, -167.2690732>,
    <0.9166667, -167.2507837>,
    <0.9166667, -167.3024008>,
    <0.9305662, -167.3024008>,
    <0.9207161, -167.2587824>,
    <0.9166667, -167.2798504>,
    <0.9227495, -167.3024008>,
    <0.9285377, -167.2878319>,
    <0.9328618, -167.2815307>,
    <0.9259259, -167.2690732>,
    <0.9305662, -167.3024008>,
    <0.9444444, -167.3024008>,
    <0.9305108, -167.2522483>,
    <0.9285377, -167.2878319>,
    <0.9383727, -167.3024008>,
    <0.9383380, -167.2804214>,
    <0.9285063, -167.2596042>,
    <0.0668973, -167.1383967>,
    <0.0740741, -167.1524837>,
    <0.0691010, -167.1694536>,
    <0.0555556, -167.1158246>,
    <0.0688585, -167.1158246>,
    <0.0712675, -167.1620608>,
    <0.0612733, -167.1384622>,
    <0.0610406, -167.1158246>,
    <0.0711175, -167.1317026>,
    <0.0773998, -167.1377915>,
    <0.0740741, -167.1524837>,
    <0.0688585, -167.1158246>,
    <0.0833333, -167.1158246>,
    <0.0833333, -167.1670330>,
    <0.0711175, -167.1317026>,
    <0.0770748, -167.1158246>,
    <0.0833333, -167.1357508>,
    <0.0792717, -167.1606510>,
    <0.0774604, -167.1786931>,
    <0.0740741, -167.1524837>,
    <0.0833333, -167.1670330>,
    <0.0833333, -167.2258020>,
    <0.0691010, -167.1694536>,
    <0.0792717, -167.1606510>,
    <0.0833333, -167.2000246>,
    <0.0770628, -167.2009756>,
    <0.0712675, -167.1620608>,
    <0.0612567, -167.1603412>,
    <0.0648148, -167.1891429>,
    <0.0555556, -167.1669437>,
    <0.0555556, -167.1158246>,
    <0.0691010, -167.1694536>,
    <0.0596084, -167.1766604>,
    <0.0555556, -167.1356938>,
    <0.0612733, -167.1384622>,
    <0.0672301, -167.1780480>,
    <0.0716763, -167.2025501>,
    <0.0648148, -167.1891429>,
    <0.0691010, -167.1694536>,
    <0.0833333, -167.2258020>,
    <0.0694562, -167.2258020>,
    <0.0672301, -167.1780480>,
    <0.0770628, -167.2009756>,
    <0.0772622, -167.2258020>,
    <0.0674183, -167.2097062>,
    <0.0613455, -167.2019226>,
    <0.0648148, -167.1891429>,
    <0.0694562, -167.2258020>,
    <0.0555556, -167.2258020>,
    <0.0555556, -167.1669437>,
    <0.0674183, -167.2097062>,
    <0.0616389, -167.2258020>,
    <0.0555556, -167.1999722>,
    <0.0596084, -167.1766604>,
    <0.9282333, -167.2539957>,
    <0.9351852, -167.2709932>,
    <0.9305139, -167.2933857>,
    <0.9166667, -167.2258020>,
    <0.9305673, -167.2258020>,
    <0.9325545, -167.2836036>,
    <0.9227166, -167.2553296>,
    <0.9227500, -167.2258020>,
    <0.9325856, -167.2455535>,
    <0.9386603, -167.2537633>,
    <0.9351852, -167.2709932>,
    <0.9305673, -167.2258020>,
    <0.9444444, -167.2258020>,
    <0.9444444, -167.2924560>,
    <0.9325856, -167.2455535>,
    <0.9383733, -167.2258020>,
    <0.9444444, -167.2550533>,
    <0.9403888, -167.2830552>,
    <0.9386470, -167.3045527>,
    <0.9351852, -167.2709932>,
    <0.9444444, -167.2924560>,
    <0.9444444, -167.3613758>,
    <0.9305139, -167.2933857>,
    <0.9403888, -167.2830552>,
    <0.9444444, -167.3313235>,
    <0.9383402, -167.3315832>,
    <0.9325545, -167.2836036>,
    <0.9223709, -167.1604533>,
    <0.9259259, -167.1891429>,
    <0.9166667, -167.1673444>,
    <0.9166667, -167.1158246>,
    <0.9302242, -167.1695015>,
    <0.9207193, -167.1768853>,
    <0.9166667, -167.1360443>,
    <0.9223953, -167.1385053>,
    <0.9283479, -167.1780754>,
    <0.9327905, -167.2025621>,
    <0.9259259, -167.1891429>,
    <0.9302242, -167.1695015>,
    <0.9444444, -167.2258020>,
    <0.9305673, -167.2258020>,
    <0.9283479, -167.1780754>,
    <0.9381806, -167.2010024>,
    <0.9383733, -167.2258020>,
    <0.9285299, -167.2097095>,
    <0.9224566, -167.2020228>,
    <0.9259259, -167.1891429>,
    <0.9305673, -167.2258020>,
    <0.9166667, -167.2258020>,
    <0.9166667, -167.1673444>,
    <0.9285299, -167.2097095>,
    <0.9227500, -167.2258020>,
    <0.9166667, -167.2001871>,
    <0.9207193, -167.1768853>,
    <0.0671227, -167.3280360>,
    <0.0740741, -167.3434849>,
    <0.0694550, -167.3024008>,
    <0.0555556, -167.3024008>,
    <0.0694063, -167.3638575>,
    <0.0714737, -167.3203558>,
    <0.0616383, -167.3024008>,
    <0.0616077, -167.3292549>,
    <0.0714455, -167.3549573>,
    <0.0775367, -167.3739447>,
    <0.0740741, -167.3434849>,
    <0.0694063, -167.3638575>,
    <0.0833333, -167.4256532>,
    <0.0833333, -167.3627833>,
    <0.0714455, -167.3549573>,
    <0.0772313, -167.3985780>,
    <0.0833333, -167.3982231>,
    <0.0792780, -167.3543311>,
    <0.0775489, -167.3277674>,
    <0.0740741, -167.3434849>,
    <0.0833333, -167.3627833>,
    <0.0833333, -167.3024008>,
    <0.0694550, -167.3024008>,
    <0.0792780, -167.3543311>,
    <0.0833333, -167.3288803>,
    <0.0772616, -167.3024008>,
    <0.0714737, -167.3203558>,
    <0.0613330, -167.3534027>,
    <0.0648148, -167.3845690>,
    <0.0694063, -167.3638575>,
    <0.0555556, -167.3024008>,
    <0.0555556, -167.3627833>,
    <0.0673989, -167.3729124>,
    <0.0616077, -167.3292549>,
    <0.0555556, -167.3288803>,
    <0.0596054, -167.3723121>,
    <0.0613448, -167.3996647>,
    <0.0648148, -167.3845690>,
    <0.0555556, -167.3627833>,
    <0.0555555, -167.4256532>,
    <0.0694534, -167.4256532>,
    <0.0596054, -167.3723121>,
    <0.0555556, -167.3982231>,
    <0.0616375, -167.4256532>,
    <0.0674260, -167.4076960>,
    <0.0717520, -167.3999332>,
    <0.0648148, -167.3845690>,
    <0.0694534, -167.4256532>,
    <0.0833333, -167.4256532>,
    <0.0694063, -167.3638575>,
    <0.0674260, -167.4076960>,
    <0.0772608, -167.4256532>,
    <0.0772313, -167.3985780>,
    <0.0673989, -167.3729124>,
    <0.9282353, -167.4553644>,
    <0.9351852, -167.4732541>,
    <0.9305646, -167.4256532>,
    <0.9166667, -167.4256532>,
    <0.9305249, -167.4968970>,
    <0.9325842, -167.4464590>,
    <0.9227486, -167.4256532>,
    <0.9227238, -167.4567920>,
    <0.9325609, -167.4865678>,
    <0.9386498, -167.5086990>,
    <0.9351852, -167.4732541>,
    <0.9305249, -167.4968970>,
    <0.9444444, -167.5684558>,
    <0.9444444, -167.4961890>,
    <0.9325609, -167.4865678>,
    <0.9383474, -167.5371117>,
    <0.9444444, -167.5369297>,
    <0.9403896, -167.4861453>,
    <0.9386597, -167.4551874>,
    <0.9351852, -167.4732541>,
    <0.9444444, -167.4961890>,
    <0.9444445, -167.4256532>,
    <0.9305646, -167.4256532>,
    <0.9403896, -167.4861453>,
    <0.9444444, -167.4566011>,
    <0.9383719, -167.4256532>,
    <0.9325842, -167.4464590>,
    <0.9224442, -167.3534027>,
    <0.9259259, -167.3845690>,
    <0.9305174, -167.3638575>,
    <0.9166667, -167.3024008>,
    <0.9166667, -167.3627833>,
    <0.9285100, -167.3729124>,
    <0.9227189, -167.3292549>,
    <0.9166667, -167.3288803>,
    <0.9207166, -167.3723121>,
    <0.9224560, -167.3996647>,
    <0.9259259, -167.3845690>,
    <0.9166667, -167.3627833>,
    <0.9166667, -167.4256532>,
    <0.9305646, -167.4256532>,
    <0.9207166, -167.3723121>,
    <0.9166667, -167.3982231>,
    <0.9227486, -167.4256532>,
    <0.9285371, -167.4076960>,
    <0.9328631, -167.3999332>,
    <0.9259259, -167.3845690>,
    <0.9305646, -167.4256532>,
    <0.9444445, -167.4256532>,
    <0.9305174, -167.3638575>,
    <0.9285371, -167.4076960>,
    <0.9383719, -167.4256532>,
    <0.9383424, -167.3985780>,
    <0.9285100, -167.3729124>,
    <0.0897536, -167.1109029>,
    <0.0874933, -167.1123151>,
    <0.0861920, -167.1231073>,
    <0.0958132, -167.1040945>,
    <0.0895158, -167.1040945>,
    <0.0866929, -167.1189534>,
    <0.0896854, -167.1162039>,
    <0.0926425, -167.1040945>,
    <0.0888427, -167.1068303>,
    <0.0859189, -167.1090575>,
    <0.0874933, -167.1123151>,
    <0.0895158, -167.1040945>,
    <0.0833333, -167.1040945>,
    <0.0833333, -167.1157258>,
    <0.0888427, -167.1068303>,
    <0.0864175, -167.1040945>,
    <0.0833333, -167.1077204>,
    <0.0854335, -167.1140039>,
    <0.0850880, -167.1199762>,
    <0.0874933, -167.1123151>,
    <0.0833333, -167.1157258>,
    <0.0833333, -167.1287564>,
    <0.0861920, -167.1231073>,
    <0.0854335, -167.1140039>,
    <0.0833333, -167.1243286>,
    <0.0843714, -167.1267051>,
    <0.0866929, -167.1189534>,
    <0.0671222, -167.2539957>,
    <0.0740741, -167.2709932>,
    <0.0694028, -167.2933857>,
    <0.0555556, -167.2258020>,
    <0.0694562, -167.2258020>,
    <0.0714434, -167.2836036>,
    <0.0616055, -167.2553296>,
    <0.0616389, -167.2258020>,
    <0.0714745, -167.2455535>,
    <0.0775492, -167.2537633>,
    <0.0740741, -167.2709932>,
    <0.0694562, -167.2258020>,
    <0.0833333, -167.2258020>,
    <0.0833333, -167.2924560>,
    <0.0714745, -167.2455535>,
    <0.0772622, -167.2258020>,
    <0.0833333, -167.2550533>,
    <0.0792777, -167.2830552>,
    <0.0775359, -167.3045527>,
    <0.0740741, -167.2709932>,
    <0.0833333, -167.2924560>,
    <0.0833333, -167.3613758>,
    <0.0694028, -167.2933857>,
    <0.0792777, -167.2830552>,
    <0.0833333, -167.3313235>,
    <0.0772291, -167.3315832>,
    <0.0714434, -167.2836036>,
    <0.0613322, -167.2819570>,
    <0.0648148, -167.3161845>,
    <0.0555556, -167.2924560>,
    <0.0555556, -167.2258020>,
    <0.0694028, -167.2933857>,
    <0.0596052, -167.3028339>,
    <0.0555556, -167.2550533>,
    <0.0616055, -167.2553296>,
    <0.0673969, -167.3033535>,
    <0.0717513, -167.3330804>,
    <0.0648148, -167.3161845>,
    <0.0694028, -167.2933857>,
    <0.0833333, -167.3613758>,
    <0.0694544, -167.3613758>,
    <0.0673969, -167.3033535>,
    <0.0772291, -167.3315832>,
    <0.0772613, -167.3613758>,
    <0.0674267, -167.3416247>,
    <0.0613451, -167.3328480>,
    <0.0648148, -167.3161845>,
    <0.0694544, -167.3613758>,
    <0.0555556, -167.3613758>,
    <0.0555556, -167.2924560>,
    <0.0674267, -167.3416247>,
    <0.0616380, -167.3613758>,
    <0.0555556, -167.3313235>,
    <0.0596052, -167.3028339>,
    <0.9282349, -167.3940515>,
    <0.9351852, -167.4137323>,
    <0.9305222, -167.4397221>,
    <0.9166667, -167.3613758>,
    <0.9305655, -167.3613758>,
    <0.9325593, -167.4283682>,
    <0.9227220, -167.3956156>,
    <0.9227491, -167.3613758>,
    <0.9325849, -167.3842624>,
    <0.9386599, -167.3939086>,
    <0.9351852, -167.4137323>,
    <0.9305655, -167.3613758>,
    <0.9444444, -167.3613758>,
    <0.9444444, -167.4391507>,
    <0.9325849, -167.3842624>,
    <0.9383724, -167.3613758>,
    <0.9444444, -167.3955180>,
    <0.9403893, -167.4280187>,
    <0.9386491, -167.4527626>,
    <0.9351852, -167.4137323>,
    <0.9444444, -167.4391507>,
    <0.9444444, -167.5184453>,
    <0.9305222, -167.4397221>,
    <0.9403893, -167.4280187>,
    <0.9444444, -167.4838674>,
    <0.9383457, -167.4839601>,
    <0.9325593, -167.4283682>,
    <0.9224433, -167.2819570>,
    <0.9259259, -167.3161845>,
    <0.9166667, -167.2924560>,
    <0.9166667, -167.2258020>,
    <0.9305139, -167.2933857>,
    <0.9207163, -167.3028339>,
    <0.9166667, -167.2550533>,
    <0.9227166, -167.2553296>,
    <0.9285080, -167.3033535>,
    <0.9328625, -167.3330804>,
    <0.9259259, -167.3161845>,
    <0.9305139, -167.2933857>,
    <0.9444444, -167.3613758>,
    <0.9305655, -167.3613758>,
    <0.9285080, -167.3033535>,
    <0.9383402, -167.3315832>,
    <0.9383724, -167.3613758>,
    <0.9285378, -167.3416247>,
    <0.9224562, -167.3328480>,
    <0.9259259, -167.3161845>,
    <0.9305655, -167.3613758>,
    <0.9166667, -167.3613758>,
    <0.9166667, -167.2924560>,
    <0.9285378, -167.3416247>,
    <0.9227491, -167.3613758>,
    <0.9166667, -167.3313235>,
    <0.9207163, -167.3028339>,
    <0.0671242, -167.4553644>,
    <0.0740741, -167.4732541>,
    <0.0694534, -167.4256532>,
    <0.0555555, -167.4256532>,
    <0.0694138, -167.4968970>,
    <0.0714731, -167.4464590>,
    <0.0616375, -167.4256532>,
    <0.0616126, -167.4567920>,
    <0.0714498, -167.4865678>,
    <0.0775386, -167.5086990>,
    <0.0740741, -167.4732541>,
    <0.0694138, -167.4968970>,
    <0.0833333, -167.5684558>,
    <0.0833333, -167.4961891>,
    <0.0714498, -167.4865678>,
    <0.0772363, -167.5371117>,
    <0.0833333, -167.5369298>,
    <0.0792785, -167.4861453>,
    <0.0775485, -167.4551874>,
    <0.0740741, -167.4732541>,
    <0.0833333, -167.4961891>,
    <0.0833333, -167.4256532>,
    <0.0694534, -167.4256532>,
    <0.0792785, -167.4861453>,
    <0.0833333, -167.4566011>,
    <0.0772608, -167.4256532>,
    <0.0714731, -167.4464590>,
    <0.0613349, -167.4848985>,
    <0.0648148, -167.5208549>,
    <0.0694138, -167.4968970>,
    <0.0555555, -167.4256532>,
    <0.0555556, -167.4961890>,
    <0.0674033, -167.5073705>,
    <0.0616126, -167.4567920>,
    <0.0555556, -167.4566011>,
    <0.0596060, -167.5069791>,
    <0.0613444, -167.5384889>,
    <0.0648148, -167.5208549>,
    <0.0555556, -167.4961890>,
    <0.0555556, -167.5684558>,
    <0.0694515, -167.5684558>,
    <0.0596060, -167.5069791>,
    <0.0555556, -167.5369298>,
    <0.0616364, -167.5684558>,
    <0.0674250, -167.5476517>,
    <0.0717534, -167.5386659>,
    <0.0648148, -167.5208549>,
    <0.0694515, -167.5684558>,
    <0.0833333, -167.5684558>,
    <0.0694138, -167.4968970>,
    <0.0674250, -167.5476517>,
    <0.0772598, -167.5684558>,
    <0.0772363, -167.5371117>,
    <0.0674033, -167.5073705>,
    <0.9282369, -167.6013336>,
    <0.9351852, -167.6211112>,
    <0.9305626, -167.5684558>,
    <0.9166667, -167.5684558>,
    <0.9305332, -167.6473117>,
    <0.9325832, -167.5914725>,
    <0.9227476, -167.5684558>,
    <0.9227291, -167.6029317>,
    <0.9325657, -167.6358644>,
    <0.9386518, -167.6604338>,
    <0.9351852, -167.6211112>,
    <0.9305332, -167.6473117>,
    <0.9444444, -167.7264218>,
    <0.9444444, -167.6468904>,
    <0.9325657, -167.6358644>,
    <0.9383529, -167.6917804>,
    <0.9444444, -167.6917086>,
    <0.9403901, -167.6356026>,
    <0.9386592, -167.6012283>,
    <0.9351852, -167.6211112>,
    <0.9444444, -167.6468904>,
    <0.9444444, -167.5684558>,
    <0.9305626, -167.5684558>,
    <0.9403901, -167.6356026>,
    <0.9444444, -167.6028580>,
    <0.9383709, -167.5684558>,
    <0.9325832, -167.5914725>,
    <0.9224461, -167.4848985>,
    <0.9259259, -167.5208549>,
    <0.9305249, -167.4968970>,
    <0.9166667, -167.4256532>,
    <0.9166667, -167.4961890>,
    <0.9285144, -167.5073705>,
    <0.9227238, -167.4567920>,
    <0.9166667, -167.4566011>,
    <0.9207171, -167.5069791>,
    <0.9224555, -167.5384889>,
    <0.9259259, -167.5208549>,
    <0.9166667, -167.4961890>,
    <0.9166667, -167.5684558>,
    <0.9305626, -167.5684558>,
    <0.9207171, -167.5069791>,
    <0.9166667, -167.5369298>,
    <0.9227476, -167.5684558>,
    <0.9285361, -167.5476517>,
    <0.9328645, -167.5386659>,
    <0.9259259, -167.5208549>,
    <0.9305626, -167.5684558>,
    <0.9444444, -167.5684558>,
    <0.9305249, -167.4968970>,
    <0.9285361, -167.5476517>,
    <0.9383709, -167.5684558>,
    <0.9383474, -167.5371117>,
    <0.9285144, -167.5073705>,
    <0.9087584, -167.1107971>,
    <0.9115673, -167.1123151>,
    <0.9091975, -167.1040945>,
    <0.9013686, -167.1040945>,
    <0.9129000, -167.1226843>,
    <0.9100465, -167.1070396>,
    <0.9053542, -167.1040945>,
    <0.9086256, -167.1157935>,
    <0.9123691, -167.1185536>,
    <0.9144502, -167.1206131>,
    <0.9115673, -167.1123151>,
    <0.9129000, -167.1226843>,
    <0.9166667, -167.1287564>,
    <0.9166667, -167.1186966>,
    <0.9123691, -167.1185536>,
    <0.9152853, -167.1265296>,
    <0.9166667, -167.1268390>,
    <0.9140694, -167.1154464>,
    <0.9135245, -167.1098002>,
    <0.9115673, -167.1123151>,
    <0.9166667, -167.1186966>,
    <0.9166667, -167.1040945>,
    <0.9091975, -167.1040945>,
    <0.9140694, -167.1154464>,
    <0.9166667, -167.1075969>,
    <0.9129537, -167.1040945>,
    <0.9100465, -167.1070396>,
    <0.0671258, -167.6013336>,
    <0.0740741, -167.6211112>,
    <0.0694515, -167.5684558>,
    <0.0555556, -167.5684558>,
    <0.0694221, -167.6473117>,
    <0.0714721, -167.5914725>,
    <0.0616364, -167.5684558>,
    <0.0616180, -167.6029317>,
    <0.0714546, -167.6358644>,
    <0.0775407, -167.6604338>,
    <0.0740741, -167.6211112>,
    <0.0694221, -167.6473117>,
    <0.0833333, -167.7264218>,
    <0.0833333, -167.6468904>,
    <0.0714546, -167.6358644>,
    <0.0772418, -167.6917804>,
    <0.0833333, -167.6917086>,
    <0.0792790, -167.6356026>,
    <0.0775481, -167.6012283>,
    <0.0740741, -167.6211112>,
    <0.0833333, -167.6468904>,
    <0.0833333, -167.5684558>,
    <0.0694515, -167.5684558>,
    <0.0792790, -167.6356026>,
    <0.0833333, -167.6028579>,
    <0.0772598, -167.5684558>,
    <0.0714721, -167.5914725>,
    <0.0613370, -167.6341061>,
    <0.0648148, -167.6737665>,
    <0.0694221, -167.6473117>,
    <0.0555556, -167.5684558>,
    <0.0555556, -167.6468904>,
    <0.0674081, -167.6588757>,
    <0.0616180, -167.6029317>,
    <0.0555556, -167.6028579>,
    <0.0596066, -167.6586490>,
    <0.0613438, -167.6933751>,
    <0.0648148, -167.6737665>,
    <0.0555556, -167.6468904>,
    <0.0555556, -167.7264218>,
    <0.0694493, -167.7264218>,
    <0.0596066, -167.6586490>,
    <0.0555556, -167.6917086>,
    <0.0616353, -167.7264218>,
    <0.0674238, -167.7034090>,
    <0.0717549, -167.6934805>,
    <0.0648148, -167.6737665>,
    <0.0694493, -167.7264218>,
    <0.0833333, -167.7264218>,
    <0.0694221, -167.6473117>,
    <0.0674238, -167.7034090>,
    <0.0772587, -167.7264218>,
    <0.0772418, -167.6917804>,
    <0.0674081, -167.6588757>,
    <0.9282237, -167.7613904>,
    <0.9351852, -167.7825485>,
    <0.9305604, -167.7264218>,
    <0.9166667, -167.7264218>,
    <0.9304825, -167.8101693>,
    <0.9325796, -167.7509264>,
    <0.9227464, -167.7264218>,
    <0.9226995, -167.7629909>,
    <0.9325373, -167.7981008>,
    <0.9386392, -167.8234922>,
    <0.9351852, -167.7825485>,
    <0.9304825, -167.8101693>,
    <0.9444444, -167.8948019>,
    <0.9444444, -167.8064491>,
    <0.9325373, -167.7981008>,
    <0.9383771, -167.8580239>,
    <0.9444444, -167.8565554>,
    <0.9403904, -167.7959846>,
    <0.9386586, -167.7604603>,
    <0.9351852, -167.7825485>,
    <0.9444444, -167.8064491>,
    <0.9444444, -167.7264218>,
    <0.9305604, -167.7264218>,
    <0.9403904, -167.7959846>,
    <0.9444444, -167.7610160>,
    <0.9383698, -167.7264218>,
    <0.9325796, -167.7509264>,
    <0.9224481, -167.6341061>,
    <0.9259259, -167.6737665>,
    <0.9305332, -167.6473117>,
    <0.9166667, -167.5684558>,
    <0.9166667, -167.6468904>,
    <0.9285193, -167.6588757>,
    <0.9227291, -167.6029317>,
    <0.9166667, -167.6028580>,
    <0.9207177, -167.6586490>,
    <0.9224549, -167.6933751>,
    <0.9259259, -167.6737665>,
    <0.9166667, -167.6468904>,
    <0.9166667, -167.7264218>,
    <0.9305604, -167.7264218>,
    <0.9207177, -167.6586490>,
    <0.9166667, -167.6917086>,
    <0.9227464, -167.7264218>,
    <0.9285349, -167.7034090>,
    <0.9328660, -167.6934805>,
    <0.9259259, -167.6737665>,
    <0.9305604, -167.7264218>,
    <0.9444444, -167.7264218>,
    <0.9305332, -167.6473117>,
    <0.9285349, -167.7034090>,
    <0.9383698, -167.7264218>,
    <0.9383529, -167.6917804>,
    <0.9285193, -167.6588757>,
    <0.0671238, -167.3940515>,
    <0.0740741, -167.4137323>,
    <0.0694111, -167.4397221>,
    <0.0555556, -167.3613758>,
    <0.0694544, -167.3613758>,
    <0.0714482, -167.4283682>,
    <0.0616109, -167.3956156>,
    <0.0616380, -167.3613758>,
    <0.0714738, -167.3842624>,
    <0.0775488, -167.3939086>,
    <0.0740741, -167.4137323>,
    <0.0694544, -167.3613758>,
    <0.0833333, -167.3613758>,
    <0.0833333, -167.4391507>,
    <0.0714738, -167.3842624>,
    <0.0772613, -167.3613758>,
    <0.0833333, -167.3955180>,
    <0.0792782, -167.4280187>,
    <0.0775380, -167.4527626>,
    <0.0740741, -167.4137323>,
    <0.0833333, -167.4391507>,
    <0.0833333, -167.5184453>,
    <0.0694111, -167.4397221>,
    <0.0792782, -167.4280187>,
    <0.0833333, -167.4838674>,
    <0.0772346, -167.4839601>,
    <0.0714482, -167.4283682>,
    <0.0613343, -167.4265843>,
    <0.0648148, -167.4660888>,
    <0.0555556, -167.4391507>,
    <0.0555556, -167.3613758>,
    <0.0694111, -167.4397221>,
    <0.0596058, -167.4509341>,
    <0.0555556, -167.3955180>,
    <0.0616109, -167.3956156>,
    <0.0674017, -167.4512490>,
    <0.0717529, -167.4856754>,
    <0.0648148, -167.4660888>,
    <0.0694111, -167.4397221>,
    <0.0833333, -167.5184453>,
    <0.0694523, -167.5184453>,
    <0.0674017, -167.4512490>,
    <0.0772346, -167.4839601>,
    <0.0772602, -167.5184453>,
    <0.0674256, -167.4955641>,
    <0.0613446, -167.4855325>,
    <0.0648148, -167.4660888>,
    <0.0694523, -167.5184453>,
    <0.0555556, -167.5184453>,
    <0.0555556, -167.4391507>,
    <0.0674256, -167.4955641>,
    <0.0616368, -167.5184453>,
    <0.0555556, -167.4838674>,
    <0.0596058, -167.4509341>,
    <0.9282366, -167.5546111>,
    <0.9351852, -167.5763713>,
    <0.9305313, -167.6051824>,
    <0.9166667, -167.5184453>,
    <0.9305634, -167.5184453>,
    <0.9325645, -167.5925951>,
    <0.9227279, -167.5563642>,
    <0.9227479, -167.5184453>,
    <0.9325839, -167.5437683>,
    <0.9386594, -167.5545331>,
    <0.9351852, -167.5763713>,
    <0.9305634, -167.5184453>,
    <0.9444444, -167.5184453>,
    <0.9444444, -167.6048705>,
    <0.9325839, -167.5437683>,
    <0.9383713, -167.5184453>,
    <0.9444444, -167.5563664>,
    <0.9403899, -167.5923911>,
    <0.9386513, -167.6196618>,
    <0.9351852, -167.5763713>,
    <0.9444444, -167.6048705>,
    <0.9444444, -167.6922232>,
    <0.9305313, -167.6051824>,
    <0.9403899, -167.5923911>,
    <0.9444444, -167.6541051>,
    <0.9383517, -167.6541068>,
    <0.9325645, -167.5925951>,
    <0.9224454, -167.4265843>,
    <0.9259259, -167.4660888>,
    <0.9166667, -167.4391507>,
    <0.9166667, -167.3613758>,
    <0.9305222, -167.4397221>,
    <0.9207169, -167.4509341>,
    <0.9166667, -167.3955180>,
    <0.9227220, -167.3956156>,
    <0.9285128, -167.4512490>,
    <0.9328640, -167.4856754>,
    <0.9259259, -167.4660888>,
    <0.9305222, -167.4397221>,
    <0.9444444, -167.5184453>,
    <0.9305634, -167.5184453>,
    <0.9285128, -167.4512490>,
    <0.9383457, -167.4839601>,
    <0.9383713, -167.5184453>,
    <0.9285367, -167.4955641>,
    <0.9224557, -167.4855325>,
    <0.9259259, -167.4660888>,
    <0.9305634, -167.5184453>,
    <0.9166667, -167.5184453>,
    <0.9166667, -167.4391507>,
    <0.9285367, -167.4955641>,
    <0.9227479, -167.5184453>,
    <0.9166667, -167.4838674>,
    <0.9207169, -167.4509341>,
    <0.0671139, -167.7613986>,
    <0.0740741, -167.7825485>,
    <0.0694493, -167.7264218>,
    <0.0555556, -167.7264218>,
    <0.0693768, -167.8102021>,
    <0.0714686, -167.7509283>,
    <0.0616353, -167.7264218>,
    <0.0615914, -167.7630092>,
    <0.0714293, -167.7981192>,
    <0.0775294, -167.8235109>,
    <0.0740741, -167.7825485>,
    <0.0693768, -167.8102021>,
    <0.0833333, -167.8948019>,
    <0.0833333, -167.8064909>,
    <0.0714293, -167.7981192>,
    <0.0772711, -167.8580547>,
    <0.0833333, -167.8566354>,
    <0.0792793, -167.7960082>,
    <0.0775475, -167.7604708>,
    <0.0740741, -167.7825485>,
    <0.0833333, -167.8064909>,
    <0.0833333, -167.7264218>,
    <0.0694493, -167.7264218>,
    <0.0792793, -167.7960082>,
    <0.0833333, -167.7610375>,
    <0.0772587, -167.7264218>,
    <0.0714686, -167.7509283>,
    <0.0613257, -167.7954469>,
    <0.0648148, -167.8386752>,
    <0.0693768, -167.8102021>,
    <0.0555556, -167.7264218>,
    <0.0555556, -167.8064884>,
    <0.0673815, -167.8226558>,
    <0.0615914, -167.7630092>,
    <0.0555556, -167.7610362>,
    <0.0596013, -167.8205522>,
    <0.0613471, -167.8586919>,
    <0.0648148, -167.8386752>,
    <0.0555556, -167.8064884>,
    <0.0555556, -167.8948019>,
    <0.0694624, -167.8948019>,
    <0.0596013, -167.8205522>,
    <0.0555556, -167.8566270>,
    <0.0615233, -167.8948019>,
    <0.0674514, -167.8705157>,
    <0.0717469, -167.8596203>,
    <0.0648148, -167.8386752>,
    <0.0694624, -167.8948019>,
    <0.0833333, -167.8948019>,
    <0.0693768, -167.8102021>,
    <0.0674514, -167.8705157>,
    <0.0773539, -167.8948019>,
    <0.0772711, -167.8580547>,
    <0.0673815, -167.8226558>,
    <0.9273631, -167.9254586>,
    <0.9351852, -167.9526834>,
    <0.9305766, -167.8948019>,
    <0.9166667, -167.8948019>,
    <0.9270239, -167.9595473>,
    <0.9327246, -167.9217801>,
    <0.9226361, -167.8948019>,
    <0.9211026, -167.9225316>,
    <0.9302804, -167.9568084>,
    <0.9377745, -167.9832296>,
    <0.9351852, -167.9526834>,
    <0.9270239, -167.9595473>,
    <0.9444444, -168.0684463>,
    <0.9444444, -167.9522414>,
    <0.9302804, -167.9568084>,
    <0.9345888, -168.0068366>,
    <0.9444444, -167.9962654>,
    <0.9405575, -167.9524269>,
    <0.9386627, -167.9236322>,
    <0.9351852, -167.9526834>,
    <0.9444444, -167.9522414>,
    <0.9444444, -167.8948019>,
    <0.9305766, -167.8948019>,
    <0.9405575, -167.9524269>,
    <0.9444444, -167.9195727>,
    <0.9384667, -167.8948019>,
    <0.9327246, -167.9217801>,
    <0.9224355, -167.7954249>,
    <0.9259259, -167.8386752>,
    <0.9304825, -167.8101693>,
    <0.9166667, -167.7264218>,
    <0.9166667, -167.8064334>,
    <0.9284890, -167.8226407>,
    <0.9226995, -167.7629909>,
    <0.9166667, -167.7610080>,
    <0.9207118, -167.8205191>,
    <0.9224590, -167.8586781>,
    <0.9259259, -167.8386752>,
    <0.9166667, -167.8064334>,
    <0.9166667, -167.8948019>,
    <0.9305766, -167.8948019>,
    <0.9207118, -167.8205191>,
    <0.9166667, -167.8565307>,
    <0.9226361, -167.8948019>,
    <0.9285623, -167.8704922>,
    <0.9328574, -167.8596121>,
    <0.9259259, -167.8386752>,
    <0.9305766, -167.8948019>,
    <0.9444444, -167.8948019>,
    <0.9304825, -167.8101693>,
    <0.9285623, -167.8704922>,
    <0.9384667, -167.8948019>,
    <0.9383771, -167.8580239>,
    <0.9284890, -167.8226407>,
    <0.0662526, -167.9254671>,
    <0.0740741, -167.9526834>,
    <0.0694624, -167.8948019>,
    <0.0555556, -167.8948019>,
    <0.0659183, -167.9595813>,
    <0.0716139, -167.9218058>,
    <0.0615233, -167.8948019>,
    <0.0599951, -167.9225546>,
    <0.0691722, -167.9568293>,
    <0.0766647, -167.9832958>,
    <0.0740741, -167.9526834>,
    <0.0659183, -167.9595813>,
    <0.0833333, -168.0684463>,
    <0.0833333, -167.9524723>,
    <0.0691722, -167.9568293>,
    <0.0734807, -168.0068555>,
    <0.0833333, -167.9962970>,
    <0.0794470, -167.9525609>,
    <0.0775508, -167.9236899>,
    <0.0740741, -167.9526834>,
    <0.0833333, -167.9524723>,
    <0.0833333, -167.8948019>,
    <0.0694624, -167.8948019>,
    <0.0794470, -167.9525609>,
    <0.0833333, -167.9196681>,
    <0.0773539, -167.8948019>,
    <0.0716139, -167.9218058>,
    <0.0604610, -167.9543474>,
    <0.0648148, -168.0105648>,
    <0.0659183, -167.9595813>,
    <0.0555556, -167.8948019>,
    <0.0555556, -167.9524416>,
    <0.0654150, -167.9828323>,
    <0.0599951, -167.9225546>,
    <0.0555556, -167.9196590>,
    <0.0597520, -167.9787838>,
    <0.0613426, -168.0249748>,
    <0.0648148, -168.0105648>,
    <0.0555556, -167.9524416>,
    <0.0555556, -168.0684463>,
    <0.0694444, -168.0684463>,
    <0.0597520, -167.9787838>,
    <0.0555556, -167.9963158>,
    <0.0625000, -168.0684463>,
    <0.0675602, -168.0448889>,
    <0.0708777, -168.0267597>,
    <0.0648148, -168.0105648>,
    <0.0694444, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0659183, -167.9595813>,
    <0.0675602, -168.0448889>,
    <0.0763889, -168.0684463>,
    <0.0734807, -168.0068555>,
    <0.0654150, -167.9828323>,
    <0.9215708, -167.9542730>,
    <0.9259259, -168.0105648>,
    <0.9270239, -167.9595473>,
    <0.9166667, -167.8948019>,
    <0.9166667, -167.9521780>,
    <0.9265232, -167.9828127>,
    <0.9211026, -167.9225316>,
    <0.9166667, -167.9195413>,
    <0.9208631, -167.9786395>,
    <0.9224537, -168.0249088>,
    <0.9259259, -168.0105648>,
    <0.9166667, -167.9521780>,
    <0.9166667, -168.0684463>,
    <0.9305556, -168.0684463>,
    <0.9208631, -167.9786395>,
    <0.9166667, -167.9962220>,
    <0.9236111, -168.0684463>,
    <0.9286712, -168.0448871>,
    <0.9319875, -168.0267512>,
    <0.9259259, -168.0105648>,
    <0.9305556, -168.0684463>,
    <0.9444444, -168.0684463>,
    <0.9270239, -167.9595473>,
    <0.9286712, -168.0448871>,
    <0.9375000, -168.0684463>,
    <0.9345888, -168.0068366>,
    <0.9265232, -167.9828127>,
    <0.0671255, -167.5546111>,
    <0.0740741, -167.5763713>,
    <0.0694202, -167.6051824>,
    <0.0555556, -167.5184453>,
    <0.0694523, -167.5184453>,
    <0.0714534, -167.5925951>,
    <0.0616167, -167.5563642>,
    <0.0616368, -167.5184453>,
    <0.0714728, -167.5437683>,
    <0.0775483, -167.5545331>,
    <0.0740741, -167.5763713>,
    <0.0694523, -167.5184453>,
    <0.0833333, -167.5184453>,
    <0.0833333, -167.6048705>,
    <0.0714728, -167.5437683>,
    <0.0772602, -167.5184453>,
    <0.0833333, -167.5563664>,
    <0.0792788, -167.5923911>,
    <0.0775402, -167.6196618>,
    <0.0740741, -167.5763713>,
    <0.0833333, -167.6048705>,
    <0.0833333, -167.6922232>,
    <0.0694202, -167.6051824>,
    <0.0792788, -167.5923911>,
    <0.0833333, -167.6541051>,
    <0.0772406, -167.6541068>,
    <0.0714534, -167.5925951>,
    <0.0613365, -167.5906989>,
    <0.0648148, -167.6342972>,
    <0.0555556, -167.6048705>,
    <0.0555556, -167.5184453>,
    <0.0694202, -167.6051824>,
    <0.0596065, -167.6177446>,
    <0.0555556, -167.5563664>,
    <0.0616167, -167.5563642>,
    <0.0674070, -167.6179095>,
    <0.0717545, -167.6559815>,
    <0.0648148, -167.6342972>,
    <0.0694202, -167.6051824>,
    <0.0833333, -167.6922232>,
    <0.0694499, -167.6922232>,
    <0.0674070, -167.6179095>,
    <0.0772406, -167.6541068>,
    <0.0772590, -167.6922232>,
    <0.0674242, -167.6669079>,
    <0.0613439, -167.6559035>,
    <0.0648148, -167.6342972>,
    <0.0694499, -167.6922232>,
    <0.0555556, -167.6922232>,
    <0.0555556, -167.6048705>,
    <0.0674242, -167.6669079>,
    <0.0616355, -167.6922232>,
    <0.0555556, -167.6541051>,
    <0.0596065, -167.6177446>,
    <0.9282230, -167.7306795>,
    <0.9351852, -167.7539575>,
    <0.9304790, -167.7843143>,
    <0.9166667, -167.6922232>,
    <0.9305610, -167.6922232>,
    <0.9325353, -167.7710507>,
    <0.9226974, -167.7324320>,
    <0.9227466, -167.6922232>,
    <0.9325799, -167.7191769>,
    <0.9386588, -167.7297501>,
    <0.9351852, -167.7539575>,
    <0.9305610, -167.6922232>,
    <0.9444444, -167.6922232>,
    <0.9444444, -167.7805965>,
    <0.9325799, -167.7191769>,
    <0.9383701, -167.6922232>,
    <0.9444444, -167.7304743>,
    <0.9403903, -167.7689326>,
    <0.9386383, -167.7990736>,
    <0.9351852, -167.7539575>,
    <0.9444444, -167.7805965>,
    <0.9444444, -167.8774261>,
    <0.9304790, -167.7843143>,
    <0.9403903, -167.7689326>,
    <0.9444444, -167.8343036>,
    <0.9383125, -167.8365428>,
    <0.9325353, -167.7710507>,
    <0.9224476, -167.5906989>,
    <0.9259259, -167.6342972>,
    <0.9166667, -167.6048705>,
    <0.9166667, -167.5184453>,
    <0.9305313, -167.6051824>,
    <0.9207176, -167.6177446>,
    <0.9166667, -167.5563664>,
    <0.9227279, -167.5563642>,
    <0.9285181, -167.6179095>,
    <0.9328657, -167.6559815>,
    <0.9259259, -167.6342972>,
    <0.9305313, -167.6051824>,
    <0.9444444, -167.6922232>,
    <0.9305610, -167.6922232>,
    <0.9285181, -167.6179095>,
    <0.9383517, -167.6541068>,
    <0.9383701, -167.6922232>,
    <0.9285353, -167.6669079>,
    <0.9224551, -167.6559035>,
    <0.9259259, -167.6342972>,
    <0.9305610, -167.6922232>,
    <0.9166667, -167.6922232>,
    <0.9166667, -167.6048705>,
    <0.9285353, -167.6669079>,
    <0.9227466, -167.6922232>,
    <0.9166667, -167.6541051>,
    <0.9207176, -167.6177446>,
    <0.0671132, -167.7306886>,
    <0.0740741, -167.7539575>,
    <0.0693734, -167.7843507>,
    <0.0555556, -167.6922232>,
    <0.0694499, -167.6922232>,
    <0.0714272, -167.7710710>,
    <0.0615893, -167.7324523>,
    <0.0616355, -167.6922232>,
    <0.0714690, -167.7191790>,
    <0.0775476, -167.7297599>,
    <0.0740741, -167.7539575>,
    <0.0694499, -167.6922232>,
    <0.0833333, -167.6922232>,
    <0.0833333, -167.7806356>,
    <0.0714690, -167.7191790>,
    <0.0772590, -167.6922232>,
    <0.0833333, -167.7304946>,
    <0.0792792, -167.7689547>,
    <0.0775285, -167.7990925>,
    <0.0740741, -167.7539575>,
    <0.0833333, -167.7806356>,
    <0.0833333, -167.8774261>,
    <0.0693734, -167.7843507>,
    <0.0792792, -167.7689547>,
    <0.0833333, -167.8343526>,
    <0.0772061, -167.8365740>,
    <0.0714272, -167.7710710>,
    <0.0613248, -167.7682247>,
    <0.0648148, -167.8156918>,
    <0.0555556, -167.7806332>,
    <0.0555556, -167.6922232>,
    <0.0693734, -167.7843507>,
    <0.0596011, -167.7959510>,
    <0.0555556, -167.7304934>,
    <0.0615893, -167.7324523>,
    <0.0673798, -167.7980568>,
    <0.0717461, -167.8387236>,
    <0.0648148, -167.8156918>,
    <0.0693734, -167.7843507>,
    <0.0833333, -167.8774261>,
    <0.0694628, -167.8774261>,
    <0.0673798, -167.7980568>,
    <0.0772061, -167.8365740>,
    <0.0772624, -167.8774261>,
    <0.0674266, -167.8503818>,
    <0.0613472, -167.8377943>,
    <0.0648148, -167.8156918>,
    <0.0694628, -167.8774261>,
    <0.0555556, -167.8774261>,
    <0.0555556, -167.7806332>,
    <0.0674266, -167.8503818>,
    <0.0616455, -167.8774261>,
    <0.0555556, -167.8343496>,
    <0.0596011, -167.7959510>,
    <0.9281151, -167.9163213>,
    <0.9351852, -167.9410995>,
    <0.9300317, -167.9693337>,
    <0.9166667, -167.8774261>,
    <0.9305769, -167.8774261>,
    <0.9322702, -167.9570699>,
    <0.9224449, -167.9171614>,
    <0.9227582, -167.8774261>,
    <0.9325894, -167.9052324>,
    <0.9386628, -167.9155248>,
    <0.9351852, -167.9410995>,
    <0.9305769, -167.8774261>,
    <0.9444444, -167.8774261>,
    <0.9444444, -167.9661475>,
    <0.9325894, -167.9052324>,
    <0.9383751, -167.8774261>,
    <0.9444444, -167.9166800>,
    <0.9403791, -167.9551500>,
    <0.9385264, -167.9862567>,
    <0.9351852, -167.9410995>,
    <0.9444444, -167.9661475>,
    <0.9444444, -168.0684463>,
    <0.9300317, -167.9693337>,
    <0.9403791, -167.9551500>,
    <0.9444444, -168.0222152>,
    <0.9379302, -168.0236496>,
    <0.9322702, -167.9570699>,
    <0.9224346, -167.7682028>,
    <0.9259259, -167.8156918>,
    <0.9166667, -167.7805818>,
    <0.9166667, -167.6922232>,
    <0.9304790, -167.7843143>,
    <0.9207116, -167.7959197>,
    <0.9166667, -167.7304668>,
    <0.9226974, -167.7324320>,
    <0.9284873, -167.7980400>,
    <0.9328566, -167.8387145>,
    <0.9259259, -167.8156918>,
    <0.9304790, -167.7843143>,
    <0.9444444, -167.8774261>,
    <0.9305769, -167.8774261>,
    <0.9284873, -167.7980400>,
    <0.9383125, -167.8365428>,
    <0.9383751, -167.8774261>,
    <0.9285376, -167.8503575>,
    <0.9224590, -167.8377814>,
    <0.9259259, -167.8156918>,
    <0.9305769, -167.8774261>,
    <0.9166667, -167.8774261>,
    <0.9166667, -167.7805818>,
    <0.9285376, -167.8503575>,
    <0.9227582, -167.8774261>,
    <0.9166667, -167.8342852>,
    <0.9207116, -167.7959197>,
    <0.0670751, -167.9168156>,
    <0.0740741, -167.9410995>,
    <0.0692081, -167.9713108>,
    <0.0555556, -167.8774261>,
    <0.0694628, -167.8774261>,
    <0.0713257, -167.9581633>,
    <0.0614975, -167.9182874>,
    <0.0616455, -167.8774261>,
    <0.0714861, -167.9053645>,
    <0.0775509, -167.9150209>,
    <0.0740741, -167.9410995>,
    <0.0694628, -167.8774261>,
    <0.0833333, -167.8774261>,
    <0.0833333, -167.9641320>,
    <0.0714861, -167.9053645>,
    <0.0772624, -167.8774261>,
    <0.0833333, -167.9157383>,
    <0.0792728, -167.9540314>,
    <0.0774872, -167.9862471>,
    <0.0740741, -167.9410995>,
    <0.0833333, -167.9641320>,
    <0.0833333, -168.0684463>,
    <0.0692081, -167.9713108>,
    <0.0792728, -167.9540314>,
    <0.0833333, -168.0181756>,
    <0.0770946, -168.0255442>,
    <0.0713257, -167.9581633>,
    <0.0612835, -167.9545039>,
    <0.0648148, -168.0047729>,
    <0.0555556, -167.9645057>,
    <0.0555556, -167.8774261>,
    <0.0692081, -167.9713108>,
    <0.0595541, -167.9818948>,
    <0.0555556, -167.9158750>,
    <0.0614975, -167.9182874>,
    <0.0672498, -167.9862261>,
    <0.0718728, -168.0282441>,
    <0.0648148, -168.0047729>,
    <0.0692081, -167.9713108>,
    <0.0833333, -168.0684463>,
    <0.0701352, -168.0684463>,
    <0.0672498, -167.9862261>,
    <0.0770946, -168.0255442>,
    <0.0779680, -168.0684463>,
    <0.0675606, -168.0376337>,
    <0.0615153, -168.0265428>,
    <0.0648148, -168.0047729>,
    <0.0701352, -168.0684463>,
    <0.0555556, -168.0684463>,
    <0.0555556, -167.9645057>,
    <0.0675606, -168.0376337>,
    <0.0617326, -168.0684463>,
    <0.0555556, -168.0211455>,
    <0.0595541, -167.9818948>,
    <0.9223227, -167.9544177>,
    <0.9259259, -168.0047729>,
    <0.9166667, -167.9661382>,
    <0.9166667, -167.8774261>,
    <0.9300317, -167.9693337>,
    <0.9206153, -167.9826140>,
    <0.9166667, -167.9166665>,
    <0.9224449, -167.9171614>,
    <0.9281704, -167.9853999>,
    <0.9330858, -168.0277498>,
    <0.9259259, -168.0047729>,
    <0.9300317, -167.9693337>,
    <0.9444444, -168.0684463>,
    <0.9319411, -168.0684463>,
    <0.9281704, -167.9853999>,
    <0.9379302, -168.0236496>,
    <0.9394431, -168.0684463>,
    <0.9287175, -168.0343229>,
    <0.9228001, -168.0269509>,
    <0.9259259, -168.0047729>,
    <0.9319411, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.9166667, -167.9661382>,
    <0.9287175, -168.0343229>,
    <0.9233633, -168.0684463>,
    <0.9166667, -168.0222310>,
    <0.9206153, -167.9826140>,
    <0.9075985, -167.0794542>,
    <0.9112148, -167.0842391>,
    <0.9100594, -167.0966849>,
    <0.9003109, -167.0684463>,
    <0.9088090, -167.0684463>,
    <0.9105189, -167.0917353>,
    <0.9053051, -167.0829132>,
    <0.9046907, -167.0684463>,
    <0.9098554, -167.0753157>,
    <0.9133393, -167.0789148>,
    <0.9112148, -167.0842391>,
    <0.9088090, -167.0684463>,
    <0.9166667, -167.0684463>,
    <0.9166667, -167.0945275>,
    <0.9098554, -167.0753157>,
    <0.9127753, -167.0684463>,
    <0.9166667, -167.0815405>,
    <0.9143643, -167.0901826>,
    <0.9136519, -167.0978191>,
    <0.9112148, -167.0842391>,
    <0.9166667, -167.0945275>,
    <0.9166667, -167.1158246>,
    <0.9100594, -167.0966849>,
    <0.9143643, -167.0901826>,
    <0.9166667, -167.1098632>,
    <0.9140997, -167.1083889>,
    <0.9105189, -167.0917353>,
    <0.1090635, -167.1106495>,
    <0.1098745, -167.1123151>,
    <0.1088694, -167.1040945>,
    <0.1074012, -167.1040945>,
    <0.1101089, -167.1220938>,
    <0.1092996, -167.1076129>,
    <0.1080442, -167.1040945>,
    <0.1088609, -167.1137975>,
    <0.1100256, -167.1186204>,
    <0.1105514, -167.1197253>,
    <0.1098745, -167.1123151>,
    <0.1101089, -167.1220938>,
    <0.1111111, -167.1287564>,
    <0.1111111, -167.1157357>,
    <0.1100256, -167.1186204>,
    <0.1108264, -167.1268636>,
    <0.1111111, -167.1243338>,
    <0.1106161, -167.1143664>,
    <0.1102415, -167.1090600>,
    <0.1098745, -167.1123151>,
    <0.1111111, -167.1157357>,
    <0.1111111, -167.1040945>,
    <0.1088694, -167.1040945>,
    <0.1106161, -167.1143664>,
    <0.1111111, -167.1077238>,
    <0.1099210, -167.1040945>,
    <0.1092996, -167.1076129>,
    <0.1058250, -167.1106495>,
    <0.1047752, -167.1123151>,
    <0.1101089, -167.1220938>,
    <0.1074013, -167.1040945>,
    <0.1010145, -167.1040945>,
    <0.1073343, -167.1170071>,
    <0.1088609, -167.1137975>,
    <0.1039481, -167.1040945>,
    <0.1024025, -167.1071285>,
    <0.1022536, -167.1108241>,
    <0.1047752, -167.1123151>,
    <0.1010145, -167.1040945>,
    <0.0958131, -167.1040945>,
    <0.1074114, -167.1227922>,
    <0.1024025, -167.1071285>,
    <0.0983396, -167.1040945>,
    <0.1030967, -167.1158363>,
    <0.1064416, -167.1189379>,
    <0.1083516, -167.1214894>,
    <0.1047752, -167.1123151>,
    <0.1074114, -167.1227922>,
    <0.1111111, -167.1287564>,
    <0.1101089, -167.1220938>,
    <0.1064416, -167.1189379>,
    <0.1097617, -167.1265810>,
    <0.1108264, -167.1268636>,
    <0.1073343, -167.1170071>,
    <0.0965423, -167.1176324>,
    <0.0967526, -167.1205358>,
    <0.1074115, -167.1227922>,
    <0.0958132, -167.1040945>,
    <0.0861920, -167.1231073>,
    <0.1027307, -167.1218013>,
    <0.1030967, -167.1158363>,
    <0.0896854, -167.1162039>,
    <0.0910633, -167.1219211>,
    <0.0906326, -167.1252890>,
    <0.0967526, -167.1205358>,
    <0.0861920, -167.1231073>,
    <0.0833333, -167.1287564>,
    <0.0962527, -167.1287564>,
    <0.0910633, -167.1219211>,
    <0.0843714, -167.1267051>,
    <0.0886038, -167.1287564>,
    <0.0964305, -167.1258320>,
    <0.1028819, -167.1252102>,
    <0.0967526, -167.1205358>,
    <0.0962527, -167.1287564>,
    <0.1111111, -167.1287564>,
    <0.1074115, -167.1227922>,
    <0.0964305, -167.1258320>,
    <0.1046454, -167.1287564>,
    <0.1097617, -167.1265810>,
    <0.1027307, -167.1218013>,
    <0.9021904, -167.1173893>,
    <0.9023080, -167.1205358>,
    <0.9129000, -167.1226843>,
    <0.9013685, -167.1040945>,
    <0.8921851, -167.1222425>,
    <0.9084091, -167.1217733>,
    <0.9086256, -167.1157935>,
    <0.8958113, -167.1150766>,
    <0.8968657, -167.1214534>,
    <0.8963588, -167.1250728>,
    <0.9023080, -167.1205358>,
    <0.8921851, -167.1222425>,
    <0.8888889, -167.1287564>,
    <0.9020531, -167.1287564>,
    <0.8968657, -167.1214534>,
    <0.8901519, -167.1262605>,
    <0.8943353, -167.1287564>,
    <0.9021408, -167.1259277>,
    <0.9084819, -167.1251832>,
    <0.9023080, -167.1205358>,
    <0.9020531, -167.1287564>,
    <0.9166667, -167.1287564>,
    <0.9129000, -167.1226843>,
    <0.9021408, -167.1259277>,
    <0.9103563, -167.1287564>,
    <0.9152853, -167.1265296>,
    <0.9084091, -167.1217733>,
    <0.9003841, -167.1443740>,
    <0.9074074, -167.1533103>,
    <0.9020531, -167.1287564>,
    <0.8888889, -167.1287564>,
    <0.9031871, -167.1666727>,
    <0.9046951, -167.1408722>,
    <0.8943353, -167.1287564>,
    <0.8953152, -167.1457977>,
    <0.9050898, -167.1606485>,
    <0.9109820, -167.1706258>,
    <0.9074074, -167.1533103>,
    <0.9031871, -167.1666727>,
    <0.9166667, -167.2024179>,
    <0.9166667, -167.1601023>,
    <0.9050898, -167.1606485>,
    <0.9108174, -167.1869068>,
    <0.9166667, -167.1835237>,
    <0.9126828, -167.1571800>,
    <0.9106985, -167.1427314>,
    <0.9074074, -167.1533103>,
    <0.9166667, -167.1601023>,
    <0.9166667, -167.1287564>,
    <0.9020531, -167.1287564>,
    <0.9126828, -167.1571800>,
    <0.9166667, -167.1407348>,
    <0.9103563, -167.1287564>,
    <0.9046951, -167.1408722>,
    <0.8954755, -167.1106867>,
    <0.8930488, -167.1123151>,
    <0.8921851, -167.1222425>,
    <0.9013685, -167.1040945>,
    <0.8952996, -167.1040945>,
    <0.8925316, -167.1182600>,
    <0.8958113, -167.1150766>,
    <0.8983943, -167.1040945>,
    <0.8944626, -167.1071515>,
    <0.8915315, -167.1100457>,
    <0.8930488, -167.1123151>,
    <0.8952996, -167.1040945>,
    <0.8888889, -167.1040945>,
    <0.8888889, -167.1196785>,
    <0.8944626, -167.1071515>,
    <0.8921167, -167.1040945>,
    <0.8888889, -167.1103619>,
    <0.8907616, -167.1163636>,
    <0.8907529, -167.1207482>,
    <0.8930488, -167.1123151>,
    <0.8888889, -167.1196785>,
    <0.8888889, -167.1287564>,
    <0.8921851, -167.1222425>,
    <0.8907616, -167.1163636>,
    <0.8888889, -167.1261982>,
    <0.8901519, -167.1262605>,
    <0.8925316, -167.1182600>,
    <0.8984407, -167.0805591>,
    <0.9019545, -167.0842391>,
    <0.9080364, -167.1011047>,
    <0.8888889, -167.0684463>,
    <0.8948829, -167.0684463>,
    <0.9058896, -167.0951514>,
    <0.9004342, -167.0881382>,
    <0.8919245, -167.0684463>,
    <0.8977225, -167.0747878>,
    <0.9018008, -167.0794542>,
    <0.9019545, -167.0842391>,
    <0.8948829, -167.0684463>,
    <0.9003079, -167.0684463>,
    <0.9100581, -167.0966849>,
    <0.8977225, -167.0747878>,
    <0.8976914, -167.0684463>,
    <0.9053030, -167.0829132>,
    <0.9060196, -167.0904825>,
    <0.9091789, -167.0994633>,
    <0.9019545, -167.0842391>,
    <0.9100581, -167.0966849>,
    <0.9166667, -167.1158246>,
    <0.9080364, -167.1011047>,
    <0.9060196, -167.0904825>,
    <0.9140993, -167.1083889>,
    <0.9131994, -167.1099109>,
    <0.9058896, -167.0951514>,
    <0.0947248, -167.1442610>,
    <0.1018518, -167.1533103>,
    <0.0962527, -167.1287564>,
    <0.0833333, -167.1287564>,
    <0.0974612, -167.1662209>,
    <0.0990117, -167.1408553>,
    <0.0886038, -167.1287564>,
    <0.0895905, -167.1453492>,
    <0.0994396, -167.1604034>,
    <0.1053838, -167.1706661>,
    <0.1018518, -167.1533103>,
    <0.0974612, -167.1662209>,
    <0.1111111, -167.2024179>,
    <0.1111111, -167.1607152>,
    <0.0994396, -167.1604034>,
    <0.1051707, -167.1866652>,
    <0.1111111, -167.1838307>,
    <0.1071231, -167.1575259>,
    <0.1050817, -167.1428846>,
    <0.1018518, -167.1533103>,
    <0.1111111, -167.1607152>,
    <0.1111111, -167.1287564>,
    <0.0962527, -167.1287564>,
    <0.1071231, -167.1575259>,
    <0.1111111, -167.1413911>,
    <0.1046454, -167.1287564>,
    <0.0990117, -167.1408553>,
    <0.0891801, -167.1583892>,
    <0.0925926, -167.1778641>,
    <0.0974612, -167.1662209>,
    <0.0833333, -167.1287564>,
    <0.0833333, -167.1607154>,
    <0.0953399, -167.1712941>,
    <0.0895905, -167.1453492>,
    <0.0833333, -167.1413913>,
    <0.0873901, -167.1682287>,
    <0.0891233, -167.1858538>,
    <0.0925926, -167.1778641>,
    <0.0833333, -167.1607154>,
    <0.0833333, -167.2024179>,
    <0.0972340, -167.2024179>,
    <0.0873901, -167.1682287>,
    <0.0833333, -167.1838308>,
    <0.0894168, -167.2024179>,
    <0.0952129, -167.1917260>,
    <0.0995997, -167.1872302>,
    <0.0925926, -167.1778641>,
    <0.0972340, -167.2024179>,
    <0.1111111, -167.2024179>,
    <0.0974612, -167.1662209>,
    <0.0952129, -167.1917260>,
    <0.1050399, -167.2024179>,
    <0.1051707, -167.1866652>,
    <0.0953399, -167.1712941>,
    <0.9004547, -167.2232074>,
    <0.9074074, -167.2357456>,
    <0.9027896, -167.2024179>,
    <0.8888889, -167.2024179>,
    <0.9027330, -167.2522483>,
    <0.9048073, -167.2169804>,
    <0.8949723, -167.2024179>,
    <0.8949368, -167.2241867>,
    <0.9047751, -167.2450388>,
    <0.9108684, -167.2602946>,
    <0.9074074, -167.2357456>,
    <0.9027330, -167.2522483>,
    <0.9166667, -167.3024008>,
    <0.9166667, -167.2507837>,
    <0.9047751, -167.2450388>,
    <0.9105603, -167.2804214>,
    <0.9166667, -167.2798504>,
    <0.9126110, -167.2441968>,
    <0.9108826, -167.2228413>,
    <0.9074074, -167.2357456>,
    <0.9166667, -167.2507837>,
    <0.9166667, -167.2024179>,
    <0.9027896, -167.2024179>,
    <0.9126110, -167.2441968>,
    <0.9166667, -167.2235884>,
    <0.9105955, -167.2024179>,
    <0.9048073, -167.2169804>,
    <0.8947783, -167.1584683>,
    <0.8981482, -167.1778641>,
    <0.9031871, -167.1666727>,
    <0.8888889, -167.1287564>,
    <0.8888889, -167.1605801>,
    <0.9009897, -167.1715532>,
    <0.8953152, -167.1457977>,
    <0.8888889, -167.1409328>,
    <0.8929437, -167.1681491>,
    <0.8946789, -167.1858200>,
    <0.8981482, -167.1778641>,
    <0.8888889, -167.1605801>,
    <0.8888889, -167.2024179>,
    <0.9027896, -167.2024179>,
    <0.8929437, -167.1681491>,
    <0.8888889, -167.1838663>,
    <0.8949723, -167.2024179>,
    <0.9007736, -167.1917530>,
    <0.9051979, -167.1873432>,
    <0.8981482, -167.1778641>,
    <0.9027896, -167.2024179>,
    <0.9166667, -167.2024179>,
    <0.9031871, -167.1666727>,
    <0.9007736, -167.1917530>,
    <0.9105955, -167.2024179>,
    <0.9108174, -167.1869068>,
    <0.9009897, -167.1715532>,
    <0.1020414, -167.0794525>,
    <0.1056582, -167.0842391>,
    <0.1045003, -167.0966785>,
    <0.0947523, -167.0684463>,
    <0.1032549, -167.0684463>,
    <0.1049612, -167.0917276>,
    <0.0997462, -167.0829095>,
    <0.0991358, -167.0684463>,
    <0.1043006, -167.0753181>,
    <0.1077838, -167.0788822>,
    <0.1056582, -167.0842391>,
    <0.1032549, -167.0684463>,
    <0.1111111, -167.0684463>,
    <0.1111111, -167.0943971>,
    <0.1043006, -167.0753181>,
    <0.1072207, -167.0684463>,
    <0.1111111, -167.0814793>,
    <0.1088083, -167.0901074>,
    <0.1080952, -167.0977848>,
    <0.1056582, -167.0842391>,
    <0.1111111, -167.0943971>,
    <0.1111111, -167.1158246>,
    <0.1045003, -167.0966785>,
    <0.1088083, -167.0901074>,
    <0.1111111, -167.1096992>,
    <0.1085423, -167.1083848>,
    <0.1049612, -167.0917276>,
    <0.0928893, -167.0805641>,
    <0.0963989, -167.0842391>,
    <0.1024926, -167.1011247>,
    <0.0833333, -167.0684463>,
    <0.0893325, -167.0684463>,
    <0.1003413, -167.0951634>,
    <0.0949032, -167.0881801>,
    <0.0863723, -167.0684463>,
    <0.0921700, -167.0747877>,
    <0.0962460, -167.0794525>,
    <0.0963989, -167.0842391>,
    <0.0893325, -167.0684463>,
    <0.0947523, -167.0684463>,
    <0.1045003, -167.0966785>,
    <0.0921700, -167.0747877>,
    <0.0921399, -167.0684463>,
    <0.0997462, -167.0829095>,
    <0.1004638, -167.0904806>,
    <0.1036257, -167.0994667>,
    <0.0963989, -167.0842391>,
    <0.1045003, -167.0966785>,
    <0.1111111, -167.1158246>,
    <0.1024926, -167.1011247>,
    <0.1004638, -167.0904806>,
    <0.1085423, -167.1083848>,
    <0.1076490, -167.1099196>,
    <0.1003413, -167.0951634>,
    <0.0904380, -167.0912660>,
    <0.0925926, -167.1000319>,
    <0.0833333, -167.0954613>,
    <0.0833333, -167.0684463>,
    <0.1024926, -167.1011247>,
    <0.0873220, -167.0974302>,
    <0.0833333, -167.0824248>,
    <0.0949032, -167.0881801>,
    <0.0974621, -167.1005694>,
    <0.1007105, -167.1082015>,
    <0.0925926, -167.1000319>,
    <0.1024926, -167.1011247>,
    <0.1111111, -167.1158246>,
    <0.0966456, -167.1158246>,
    <0.0974621, -167.1005694>,
    <0.1076490, -167.1099196>,
    <0.1048585, -167.1158246>,
    <0.0947546, -167.1084564>,
    <0.0889762, -167.1067856>,
    <0.0925926, -167.1000319>,
    <0.0966456, -167.1158246>,
    <0.0833333, -167.1158246>,
    <0.0833333, -167.0954613>,
    <0.0947546, -167.1084564>,
    <0.0888239, -167.1158246>,
    <0.0833333, -167.1101338>,
    <0.0873220, -167.0974302>,
    <0.9002395, -167.1384097>,
    <0.9074074, -167.1524837>,
    <0.9024475, -167.1695056>,
    <0.8888889, -167.1158246>,
    <0.9022144, -167.1158246>,
    <0.9046083, -167.1620900>,
    <0.8946187, -167.1385099>,
    <0.8943862, -167.1158246>,
    <0.9044639, -167.1317049>,
    <0.9107388, -167.1378694>,
    <0.9074074, -167.1524837>,
    <0.9022144, -167.1158246>,
    <0.9166667, -167.1158246>,
    <0.9166667, -167.1673444>,
    <0.9044639, -167.1317049>,
    <0.9104227, -167.1158246>,
    <0.9166667, -167.1360443>,
    <0.9126053, -167.1608261>,
    <0.9107971, -167.1787839>,
    <0.9074074, -167.1524837>,
    <0.9166667, -167.1673444>,
    <0.9166667, -167.2258020>,
    <0.9024475, -167.1695056>,
    <0.9126053, -167.1608261>,
    <0.9166667, -167.2001871>,
    <0.9104034, -167.2010046>,
    <0.9046083, -167.1620900>,
    <0.8959906, -167.0909949>,
    <0.8981482, -167.1000319>,
    <0.8888889, -167.0943969>,
    <0.8888889, -167.0684463>,
    <0.9080364, -167.1011047>,
    <0.8928899, -167.0968318>,
    <0.8888889, -167.0814789>,
    <0.9004342, -167.0881382>,
    <0.9030186, -167.1005603>,
    <0.9062664, -167.1081965>,
    <0.8981482, -167.1000319>,
    <0.9080364, -167.1011047>,
    <0.9166667, -167.1158246>,
    <0.9022144, -167.1158246>,
    <0.9030186, -167.1005603>,
    <0.9131994, -167.1099109>,
    <0.9104227, -167.1158246>,
    <0.9003194, -167.1084649>,
    <0.8945351, -167.1065195>,
    <0.8981482, -167.1000319>,
    <0.9022144, -167.1158246>,
    <0.8888889, -167.1158246>,
    <0.8888889, -167.0943969>,
    <0.9003194, -167.1084649>,
    <0.8943862, -167.1158246>,
    <0.8888889, -167.1096993>,
    <0.8928899, -167.0968318>,
    <0.0948992, -167.2232074>,
    <0.1018518, -167.2357456>,
    <0.0972340, -167.2024179>,
    <0.0833333, -167.2024179>,
    <0.0971775, -167.2522483>,
    <0.0992518, -167.2169804>,
    <0.0894168, -167.2024179>,
    <0.0893813, -167.2241867>,
    <0.0992196, -167.2450388>,
    <0.1053129, -167.2602946>,
    <0.1018518, -167.2357456>,
    <0.0971775, -167.2522483>,
    <0.1111111, -167.3024008>,
    <0.1111111, -167.2507837>,
    <0.0992196, -167.2450388>,
    <0.1050047, -167.2804214>,
    <0.1111111, -167.2798504>,
    <0.1070554, -167.2441968>,
    <0.1053270, -167.2228413>,
    <0.1018518, -167.2357456>,
    <0.1111111, -167.2507837>,
    <0.1111111, -167.2024179>,
    <0.0972340, -167.2024179>,
    <0.1070554, -167.2441968>,
    <0.1111111, -167.2235884>,
    <0.1050399, -167.2024179>,
    <0.0992518, -167.2169804>,
    <0.0891092, -167.2436308>,
    <0.0925926, -167.2690732>,
    <0.0971775, -167.2522483>,
    <0.0833333, -167.2024179>,
    <0.0833333, -167.2507837>,
    <0.0951729, -167.2596042>,
    <0.0893813, -167.2241867>,
    <0.0833333, -167.2235884>,
    <0.0873827, -167.2587824>,
    <0.0891230, -167.2811646>,
    <0.0925926, -167.2690732>,
    <0.0833333, -167.2507837>,
    <0.0833333, -167.3024008>,
    <0.0972328, -167.3024008>,
    <0.0873827, -167.2587824>,
    <0.0833333, -167.2798504>,
    <0.0894161, -167.3024008>,
    <0.0952044, -167.2878319>,
    <0.0995285, -167.2815307>,
    <0.0925926, -167.2690732>,
    <0.0972328, -167.3024008>,
    <0.1111111, -167.3024008>,
    <0.0971775, -167.2522483>,
    <0.0952044, -167.2878319>,
    <0.1050393, -167.3024008>,
    <0.1050047, -167.2804214>,
    <0.0951729, -167.2596042>,
    <0.9004561, -167.3280360>,
    <0.9074074, -167.3434849>,
    <0.9027884, -167.3024008>,
    <0.8888889, -167.3024008>,
    <0.9027396, -167.3638575>,
    <0.9048070, -167.3203558>,
    <0.8949717, -167.3024008>,
    <0.8949411, -167.3292549>,
    <0.9047788, -167.3549573>,
    <0.9108701, -167.3739447>,
    <0.9074074, -167.3434849>,
    <0.9027396, -167.3638575>,
    <0.9166667, -167.4256532>,
    <0.9166667, -167.3627833>,
    <0.9047788, -167.3549573>,
    <0.9105646, -167.3985780>,
    <0.9166667, -167.3982231>,
    <0.9126114, -167.3543311>,
    <0.9108823, -167.3277674>,
    <0.9074074, -167.3434849>,
    <0.9166667, -167.3627833>,
    <0.9166667, -167.3024008>,
    <0.9027884, -167.3024008>,
    <0.9126114, -167.3543311>,
    <0.9166667, -167.3288803>,
    <0.9105949, -167.3024008>,
    <0.9048070, -167.3203558>,
    <0.8946647, -167.2436308>,
    <0.8981482, -167.2690732>,
    <0.9027330, -167.2522483>,
    <0.8888889, -167.2024179>,
    <0.8888889, -167.2507837>,
    <0.9007285, -167.2596042>,
    <0.8949368, -167.2241867>,
    <0.8888889, -167.2235884>,
    <0.8929383, -167.2587824>,
    <0.8946786, -167.2811646>,
    <0.8981482, -167.2690732>,
    <0.8888889, -167.2507837>,
    <0.8888889, -167.3024008>,
    <0.9027884, -167.3024008>,
    <0.8929383, -167.2587824>,
    <0.8888889, -167.2798504>,
    <0.8949717, -167.3024008>,
    <0.9007600, -167.2878319>,
    <0.9050841, -167.2815307>,
    <0.8981482, -167.2690732>,
    <0.9027884, -167.3024008>,
    <0.9166667, -167.3024008>,
    <0.9027330, -167.2522483>,
    <0.9007600, -167.2878319>,
    <0.9105949, -167.3024008>,
    <0.9105603, -167.2804214>,
    <0.9007285, -167.2596042>,
    <0.0946777, -167.1383978>,
    <0.1018518, -167.1524837>,
    <0.0968799, -167.1694582>,
    <0.0833333, -167.1158246>,
    <0.0966456, -167.1158246>,
    <0.0990462, -167.1620624>,
    <0.0890520, -167.1384660>,
    <0.0888239, -167.1158246>,
    <0.0989014, -167.1317083>,
    <0.1051799, -167.1378791>,
    <0.1018518, -167.1524837>,
    <0.0966456, -167.1158246>,
    <0.1111111, -167.1158246>,
    <0.1111111, -167.1673834>,
    <0.0989014, -167.1317083>,
    <0.1048585, -167.1158246>,
    <0.1111111, -167.1360516>,
    <0.1070495, -167.1608476>,
    <0.1052385, -167.1787818>,
    <0.1018518, -167.1524837>,
    <0.1111111, -167.1673834>,
    <0.1111111, -167.2258020>,
    <0.0968799, -167.1694582>,
    <0.1070495, -167.1608476>,
    <0.1111111, -167.2002137>,
    <0.1048412, -167.2009783>,
    <0.0990462, -167.1620624>,
    <0.0890348, -167.1603647>,
    <0.0925926, -167.1891429>,
    <0.0833333, -167.1670330>,
    <0.0833333, -167.1158246>,
    <0.0968799, -167.1694582>,
    <0.0873862, -167.1767107>,
    <0.0833333, -167.1357508>,
    <0.0890520, -167.1384660>,
    <0.0950085, -167.1780506>,
    <0.0994544, -167.2025512>,
    <0.0925926, -167.1891429>,
    <0.0968799, -167.1694582>,
    <0.1111111, -167.2258020>,
    <0.0972339, -167.2258020>,
    <0.0950085, -167.1780506>,
    <0.1048412, -167.2009783>,
    <0.1050399, -167.2258020>,
    <0.0951961, -167.2097066>,
    <0.0891233, -167.2019449>,
    <0.0925926, -167.1891429>,
    <0.0972339, -167.2258020>,
    <0.0833333, -167.2258020>,
    <0.0833333, -167.1670330>,
    <0.0951961, -167.2097066>,
    <0.0894167, -167.2258020>,
    <0.0833333, -167.2000246>,
    <0.0873862, -167.1767107>,
    <0.9004555, -167.2539957>,
    <0.9074074, -167.2709932>,
    <0.9027362, -167.2933857>,
    <0.8888889, -167.2258020>,
    <0.9027895, -167.2258020>,
    <0.9047768, -167.2836036>,
    <0.8949388, -167.2553296>,
    <0.8949722, -167.2258020>,
    <0.9048078, -167.2455535>,
    <0.9108826, -167.2537633>,
    <0.9074074, -167.2709932>,
    <0.9027895, -167.2258020>,
    <0.9166667, -167.2258020>,
    <0.9166667, -167.2924560>,
    <0.9048078, -167.2455535>,
    <0.9105955, -167.2258020>,
    <0.9166667, -167.2550533>,
    <0.9126111, -167.2830552>,
    <0.9108692, -167.3045527>,
    <0.9074074, -167.2709932>,
    <0.9166667, -167.2924560>,
    <0.9166667, -167.3613758>,
    <0.9027362, -167.2933857>,
    <0.9126111, -167.2830552>,
    <0.9166667, -167.3313235>,
    <0.9105625, -167.3315832>,
    <0.9047768, -167.2836036>,
    <0.8945934, -167.1604642>,
    <0.8981482, -167.1891429>,
    <0.8888889, -167.1673836>,
    <0.8888889, -167.1158246>,
    <0.9024475, -167.1695056>,
    <0.8929416, -167.1769075>,
    <0.8888889, -167.1360520>,
    <0.8946187, -167.1385099>,
    <0.9005707, -167.1780778>,
    <0.9050130, -167.2025631>,
    <0.8981482, -167.1891429>,
    <0.9024475, -167.1695056>,
    <0.9166667, -167.2258020>,
    <0.9027895, -167.2258020>,
    <0.9005707, -167.1780778>,
    <0.9104034, -167.2010046>,
    <0.9105955, -167.2258020>,
    <0.9007521, -167.2097098>,
    <0.8946789, -167.2020326>,
    <0.8981482, -167.1891429>,
    <0.9027895, -167.2258020>,
    <0.8888889, -167.2258020>,
    <0.8888889, -167.1673836>,
    <0.9007521, -167.2097098>,
    <0.8949722, -167.2258020>,
    <0.8888889, -167.2002138>,
    <0.8929416, -167.1769075>,
    <0.0949005, -167.3280360>,
    <0.1018518, -167.3434849>,
    <0.0972328, -167.3024008>,
    <0.0833333, -167.3024008>,
    <0.0971840, -167.3638575>,
    <0.0992515, -167.3203558>,
    <0.0894161, -167.3024008>,
    <0.0893855, -167.3292549>,
    <0.0992233, -167.3549573>,
    <0.1053145, -167.3739447>,
    <0.1018518, -167.3434849>,
    <0.0971840, -167.3638575>,
    <0.1111111, -167.4256532>,
    <0.1111111, -167.3627833>,
    <0.0992233, -167.3549573>,
    <0.1050091, -167.3985780>,
    <0.1111111, -167.3982231>,
    <0.1070558, -167.3543311>,
    <0.1053267, -167.3277674>,
    <0.1018518, -167.3434849>,
    <0.1111111, -167.3627833>,
    <0.1111111, -167.3024008>,
    <0.0972328, -167.3024008>,
    <0.1070558, -167.3543311>,
    <0.1111111, -167.3288803>,
    <0.1050393, -167.3024008>,
    <0.0992515, -167.3203558>,
    <0.0891108, -167.3534027>,
    <0.0925926, -167.3845690>,
    <0.0971840, -167.3638575>,
    <0.0833333, -167.3024008>,
    <0.0833333, -167.3627833>,
    <0.0951767, -167.3729124>,
    <0.0893855, -167.3292549>,
    <0.0833333, -167.3288803>,
    <0.0873832, -167.3723121>,
    <0.0891226, -167.3996647>,
    <0.0925926, -167.3845690>,
    <0.0833333, -167.3627833>,
    <0.0833333, -167.4256532>,
    <0.0972312, -167.4256532>,
    <0.0873832, -167.3723121>,
    <0.0833333, -167.3982231>,
    <0.0894152, -167.4256532>,
    <0.0952038, -167.4076960>,
    <0.0995297, -167.3999332>,
    <0.0925926, -167.3845690>,
    <0.0972312, -167.4256532>,
    <0.1111111, -167.4256532>,
    <0.0971840, -167.3638575>,
    <0.0952038, -167.4076960>,
    <0.1050385, -167.4256532>,
    <0.1050091, -167.3985780>,
    <0.0951767, -167.3729124>,
    <0.9004576, -167.4553644>,
    <0.9074074, -167.4732541>,
    <0.9027868, -167.4256532>,
    <0.8888889, -167.4256532>,
    <0.9027471, -167.4968970>,
    <0.9048064, -167.4464590>,
    <0.8949708, -167.4256532>,
    <0.8949460, -167.4567920>,
    <0.9047831, -167.4865678>,
    <0.9108720, -167.5086990>,
    <0.9074074, -167.4732541>,
    <0.9027471, -167.4968970>,
    <0.9166667, -167.5684558>,
    <0.9166667, -167.4961890>,
    <0.9047831, -167.4865678>,
    <0.9105697, -167.5371117>,
    <0.9166667, -167.5369298>,
    <0.9126118, -167.4861453>,
    <0.9108819, -167.4551874>,
    <0.9074074, -167.4732541>,
    <0.9166667, -167.4961890>,
    <0.9166667, -167.4256532>,
    <0.9027868, -167.4256532>,
    <0.9126118, -167.4861453>,
    <0.9166667, -167.4566011>,
    <0.9105941, -167.4256532>,
    <0.9048064, -167.4464590>,
    <0.8946664, -167.3534027>,
    <0.8981482, -167.3845690>,
    <0.9027396, -167.3638575>,
    <0.8888889, -167.3024008>,
    <0.8888889, -167.3627833>,
    <0.9007323, -167.3729124>,
    <0.8949411, -167.3292549>,
    <0.8888889, -167.3288803>,
    <0.8929388, -167.3723121>,
    <0.8946782, -167.3996647>,
    <0.8981482, -167.3845690>,
    <0.8888889, -167.3627833>,
    <0.8888889, -167.4256532>,
    <0.9027868, -167.4256532>,
    <0.8929388, -167.3723121>,
    <0.8888889, -167.3982231>,
    <0.8949708, -167.4256532>,
    <0.9007593, -167.4076960>,
    <0.9050853, -167.3999332>,
    <0.8981482, -167.3845690>,
    <0.9027868, -167.4256532>,
    <0.9166667, -167.4256532>,
    <0.9027396, -167.3638575>,
    <0.9007593, -167.4076960>,
    <0.9105941, -167.4256532>,
    <0.9105646, -167.3985780>,
    <0.9007323, -167.3729124>,
    <0.0948999, -167.2539957>,
    <0.1018518, -167.2709932>,
    <0.0971806, -167.2933857>,
    <0.0833333, -167.2258020>,
    <0.0972339, -167.2258020>,
    <0.0992212, -167.2836036>,
    <0.0893833, -167.2553296>,
    <0.0894167, -167.2258020>,
    <0.0992523, -167.2455535>,
    <0.1053270, -167.2537633>,
    <0.1018518, -167.2709932>,
    <0.0972339, -167.2258020>,
    <0.1111111, -167.2258020>,
    <0.1111111, -167.2924560>,
    <0.0992523, -167.2455535>,
    <0.1050399, -167.2258020>,
    <0.1111111, -167.2550533>,
    <0.1070555, -167.2830552>,
    <0.1053137, -167.3045527>,
    <0.1018518, -167.2709932>,
    <0.1111111, -167.2924560>,
    <0.1111111, -167.3613758>,
    <0.0971806, -167.2933857>,
    <0.1070555, -167.2830552>,
    <0.1111111, -167.3313235>,
    <0.1050069, -167.3315832>,
    <0.0992212, -167.2836036>,
    <0.0891100, -167.2819570>,
    <0.0925926, -167.3161845>,
    <0.0833333, -167.2924560>,
    <0.0833333, -167.2258020>,
    <0.0971806, -167.2933857>,
    <0.0873830, -167.3028339>,
    <0.0833333, -167.2550533>,
    <0.0893833, -167.2553296>,
    <0.0951747, -167.3033535>,
    <0.0995291, -167.3330804>,
    <0.0925926, -167.3161845>,
    <0.0971806, -167.2933857>,
    <0.1111111, -167.3613758>,
    <0.0972322, -167.3613758>,
    <0.0951747, -167.3033535>,
    <0.1050069, -167.3315832>,
    <0.1050391, -167.3613758>,
    <0.0952044, -167.3416247>,
    <0.0891229, -167.3328480>,
    <0.0925926, -167.3161845>,
    <0.0972322, -167.3613758>,
    <0.0833333, -167.3613758>,
    <0.0833333, -167.2924560>,
    <0.0952044, -167.3416247>,
    <0.0894157, -167.3613758>,
    <0.0833333, -167.3313235>,
    <0.0873830, -167.3028339>,
    <0.9004571, -167.3940515>,
    <0.9074074, -167.4137323>,
    <0.9027445, -167.4397221>,
    <0.8888889, -167.3613758>,
    <0.9027878, -167.3613758>,
    <0.9047815, -167.4283682>,
    <0.8949442, -167.3956156>,
    <0.8949713, -167.3613758>,
    <0.9048072, -167.3842624>,
    <0.9108821, -167.3939086>,
    <0.9074074, -167.4137323>,
    <0.9027878, -167.3613758>,
    <0.9166667, -167.3613758>,
    <0.9166667, -167.4391507>,
    <0.9048072, -167.3842624>,
    <0.9105946, -167.3613758>,
    <0.9166667, -167.3955180>,
    <0.9126116, -167.4280187>,
    <0.9108713, -167.4527626>,
    <0.9074074, -167.4137323>,
    <0.9166667, -167.4391507>,
    <0.9166667, -167.5184453>,
    <0.9027445, -167.4397221>,
    <0.9126116, -167.4280187>,
    <0.9166667, -167.4838674>,
    <0.9105680, -167.4839601>,
    <0.9047815, -167.4283682>,
    <0.8946655, -167.2819570>,
    <0.8981482, -167.3161845>,
    <0.8888889, -167.2924560>,
    <0.8888889, -167.2258020>,
    <0.9027362, -167.2933857>,
    <0.8929385, -167.3028339>,
    <0.8888889, -167.2550533>,
    <0.8949388, -167.2553296>,
    <0.9007302, -167.3033535>,
    <0.9050847, -167.3330804>,
    <0.8981482, -167.3161845>,
    <0.9027362, -167.2933857>,
    <0.9166667, -167.3613758>,
    <0.9027878, -167.3613758>,
    <0.9007302, -167.3033535>,
    <0.9105625, -167.3315832>,
    <0.9105946, -167.3613758>,
    <0.9007600, -167.3416247>,
    <0.8946784, -167.3328480>,
    <0.8981482, -167.3161845>,
    <0.9027878, -167.3613758>,
    <0.8888889, -167.3613758>,
    <0.8888889, -167.2924560>,
    <0.9007600, -167.3416247>,
    <0.8949713, -167.3613758>,
    <0.8888889, -167.3313235>,
    <0.8929385, -167.3028339>,
    <0.0949020, -167.4553644>,
    <0.1018518, -167.4732541>,
    <0.0972312, -167.4256532>,
    <0.0833333, -167.4256532>,
    <0.0971916, -167.4968970>,
    <0.0992508, -167.4464590>,
    <0.0894152, -167.4256532>,
    <0.0893904, -167.4567920>,
    <0.0992276, -167.4865678>,
    <0.1053164, -167.5086990>,
    <0.1018518, -167.4732541>,
    <0.0971916, -167.4968970>,
    <0.1111111, -167.5684558>,
    <0.1111111, -167.4961890>,
    <0.0992276, -167.4865678>,
    <0.1050141, -167.5371117>,
    <0.1111111, -167.5369298>,
    <0.1070563, -167.4861453>,
    <0.1053263, -167.4551874>,
    <0.1018518, -167.4732541>,
    <0.1111111, -167.4961890>,
    <0.1111111, -167.4256532>,
    <0.0972312, -167.4256532>,
    <0.1070563, -167.4861453>,
    <0.1111111, -167.4566011>,
    <0.1050385, -167.4256532>,
    <0.0992508, -167.4464590>,
    <0.0891127, -167.4848985>,
    <0.0925926, -167.5208549>,
    <0.0971916, -167.4968970>,
    <0.0833333, -167.4256532>,
    <0.0833333, -167.4961891>,
    <0.0951811, -167.5073705>,
    <0.0893904, -167.4567920>,
    <0.0833333, -167.4566011>,
    <0.0873838, -167.5069791>,
    <0.0891221, -167.5384889>,
    <0.0925926, -167.5208549>,
    <0.0833333, -167.4961891>,
    <0.0833333, -167.5684558>,
    <0.0972293, -167.5684558>,
    <0.0873838, -167.5069791>,
    <0.0833333, -167.5369298>,
    <0.0894142, -167.5684558>,
    <0.0952028, -167.5476517>,
    <0.0995311, -167.5386659>,
    <0.0925926, -167.5208549>,
    <0.0972293, -167.5684558>,
    <0.1111111, -167.5684558>,
    <0.0971916, -167.4968970>,
    <0.0952028, -167.5476517>,
    <0.1050376, -167.5684558>,
    <0.1050141, -167.5371117>,
    <0.0951811, -167.5073705>,
    <0.9004591, -167.6013336>,
    <0.9074074, -167.6211112>,
    <0.9027849, -167.5684558>,
    <0.8888889, -167.5684558>,
    <0.9027554, -167.6473117>,
    <0.9048055, -167.5914725>,
    <0.8949698, -167.5684558>,
    <0.8949514, -167.6029317>,
    <0.9047879, -167.6358644>,
    <0.9108740, -167.6604338>,
    <0.9074074, -167.6211112>,
    <0.9027554, -167.6473117>,
    <0.9166667, -167.7264218>,
    <0.9166667, -167.6468904>,
    <0.9047879, -167.6358644>,
    <0.9105751, -167.6917804>,
    <0.9166667, -167.6917086>,
    <0.9126124, -167.6356026>,
    <0.9108814, -167.6012283>,
    <0.9074074, -167.6211112>,
    <0.9166667, -167.6468904>,
    <0.9166667, -167.5684558>,
    <0.9027849, -167.5684558>,
    <0.9126124, -167.6356026>,
    <0.9166667, -167.6028580>,
    <0.9105931, -167.5684558>,
    <0.9048055, -167.5914725>,
    <0.8946683, -167.4848985>,
    <0.8981482, -167.5208549>,
    <0.9027471, -167.4968970>,
    <0.8888889, -167.4256532>,
    <0.8888889, -167.4961890>,
    <0.9007367, -167.5073705>,
    <0.8949460, -167.4567920>,
    <0.8888889, -167.4566011>,
    <0.8929393, -167.5069791>,
    <0.8946777, -167.5384889>,
    <0.8981482, -167.5208549>,
    <0.8888889, -167.4961890>,
    <0.8888889, -167.5684558>,
    <0.9027849, -167.5684558>,
    <0.8929393, -167.5069791>,
    <0.8888889, -167.5369298>,
    <0.8949698, -167.5684558>,
    <0.9007584, -167.5476517>,
    <0.9050867, -167.5386659>,
    <0.8981482, -167.5208549>,
    <0.9027849, -167.5684558>,
    <0.9166667, -167.5684558>,
    <0.9027471, -167.4968970>,
    <0.9007584, -167.5476517>,
    <0.9105931, -167.5684558>,
    <0.9105697, -167.5371117>,
    <0.9007367, -167.5073705>,
    <0.0949036, -167.6013336>,
    <0.1018518, -167.6211112>,
    <0.0972293, -167.5684558>,
    <0.0833333, -167.5684558>,
    <0.0971999, -167.6473117>,
    <0.0992499, -167.5914725>,
    <0.0894142, -167.5684558>,
    <0.0893958, -167.6029317>,
    <0.0992324, -167.6358644>,
    <0.1053185, -167.6604338>,
    <0.1018518, -167.6211112>,
    <0.0971999, -167.6473117>,
    <0.1111111, -167.7264218>,
    <0.1111111, -167.6468904>,
    <0.0992324, -167.6358644>,
    <0.1050195, -167.6917804>,
    <0.1111111, -167.6917086>,
    <0.1070568, -167.6356026>,
    <0.1053258, -167.6012283>,
    <0.1018518, -167.6211112>,
    <0.1111111, -167.6468904>,
    <0.1111111, -167.5684558>,
    <0.0972293, -167.5684558>,
    <0.1070568, -167.6356026>,
    <0.1111111, -167.6028579>,
    <0.1050376, -167.5684558>,
    <0.0992499, -167.5914725>,
    <0.0891148, -167.6341061>,
    <0.0925926, -167.6737665>,
    <0.0971999, -167.6473117>,
    <0.0833333, -167.5684558>,
    <0.0833333, -167.6468904>,
    <0.0951859, -167.6588757>,
    <0.0893958, -167.6029317>,
    <0.0833333, -167.6028579>,
    <0.0873844, -167.6586490>,
    <0.0891216, -167.6933751>,
    <0.0925926, -167.6737665>,
    <0.0833333, -167.6468904>,
    <0.0833333, -167.7264218>,
    <0.0972271, -167.7264218>,
    <0.0873844, -167.6586490>,
    <0.0833333, -167.6917086>,
    <0.0894130, -167.7264218>,
    <0.0952016, -167.7034090>,
    <0.0995327, -167.6934805>,
    <0.0925926, -167.6737665>,
    <0.0972271, -167.7264218>,
    <0.1111111, -167.7264218>,
    <0.0971999, -167.6473117>,
    <0.0952016, -167.7034090>,
    <0.1050365, -167.7264218>,
    <0.1050195, -167.6917804>,
    <0.0951859, -167.6588757>,
    <0.9004458, -167.7613894>,
    <0.9074074, -167.7825485>,
    <0.9027827, -167.7264218>,
    <0.8888889, -167.7264218>,
    <0.9027041, -167.8101654>,
    <0.9048018, -167.7509262>,
    <0.8949686, -167.7264218>,
    <0.8949214, -167.7629888>,
    <0.9047592, -167.7980986>,
    <0.9108612, -167.8234873>,
    <0.9074074, -167.7825485>,
    <0.9027041, -167.8101654>,
    <0.9166667, -167.8948019>,
    <0.9166667, -167.8064334>,
    <0.9047592, -167.7980986>,
    <0.9105987, -167.8580199>,
    <0.9166667, -167.8565307>,
    <0.9126126, -167.7959758>,
    <0.9108809, -167.7604564>,
    <0.9074074, -167.7825485>,
    <0.9166667, -167.8064334>,
    <0.9166667, -167.7264218>,
    <0.9027827, -167.7264218>,
    <0.9126126, -167.7959758>,
    <0.9166667, -167.7610080>,
    <0.9105920, -167.7264218>,
    <0.9048018, -167.7509262>,
    <0.8946703, -167.6341061>,
    <0.8981482, -167.6737665>,
    <0.9027554, -167.6473117>,
    <0.8888889, -167.5684558>,
    <0.8888889, -167.6468904>,
    <0.9007415, -167.6588757>,
    <0.8949514, -167.6029317>,
    <0.8888889, -167.6028579>,
    <0.8929399, -167.6586490>,
    <0.8946772, -167.6933751>,
    <0.8981482, -167.6737665>,
    <0.8888889, -167.6468904>,
    <0.8888889, -167.7264218>,
    <0.9027827, -167.7264218>,
    <0.8929399, -167.6586490>,
    <0.8888889, -167.6917086>,
    <0.8949686, -167.7264218>,
    <0.9007572, -167.7034090>,
    <0.9050882, -167.6934805>,
    <0.8981482, -167.6737665>,
    <0.9027827, -167.7264218>,
    <0.9166667, -167.7264218>,
    <0.9027554, -167.6473117>,
    <0.9007572, -167.7034090>,
    <0.9105920, -167.7264218>,
    <0.9105751, -167.6917804>,
    <0.9007415, -167.6588757>,
    <0.0949016, -167.3940515>,
    <0.1018518, -167.4137323>,
    <0.0971889, -167.4397221>,
    <0.0833333, -167.3613758>,
    <0.0972322, -167.3613758>,
    <0.0992260, -167.4283682>,
    <0.0893887, -167.3956156>,
    <0.0894157, -167.3613758>,
    <0.0992516, -167.3842624>,
    <0.1053266, -167.3939086>,
    <0.1018518, -167.4137323>,
    <0.0972322, -167.3613758>,
    <0.1111111, -167.3613758>,
    <0.1111111, -167.4391506>,
    <0.0992516, -167.3842624>,
    <0.1050391, -167.3613758>,
    <0.1111111, -167.3955180>,
    <0.1070560, -167.4280187>,
    <0.1053157, -167.4527626>,
    <0.1018518, -167.4137323>,
    <0.1111111, -167.4391506>,
    <0.1111111, -167.5184453>,
    <0.0971889, -167.4397221>,
    <0.1070560, -167.4280187>,
    <0.1111111, -167.4838674>,
    <0.1050124, -167.4839601>,
    <0.0992260, -167.4283682>,
    <0.0891120, -167.4265843>,
    <0.0925926, -167.4660888>,
    <0.0833333, -167.4391507>,
    <0.0833333, -167.3613758>,
    <0.0971889, -167.4397221>,
    <0.0873836, -167.4509341>,
    <0.0833333, -167.3955180>,
    <0.0893887, -167.3956156>,
    <0.0951795, -167.4512490>,
    <0.0995307, -167.4856754>,
    <0.0925926, -167.4660888>,
    <0.0971889, -167.4397221>,
    <0.1111111, -167.5184453>,
    <0.0972301, -167.5184453>,
    <0.0951795, -167.4512490>,
    <0.1050124, -167.4839601>,
    <0.1050380, -167.5184453>,
    <0.0952034, -167.4955641>,
    <0.0891223, -167.4855325>,
    <0.0925926, -167.4660888>,
    <0.0972301, -167.5184453>,
    <0.0833333, -167.5184453>,
    <0.0833333, -167.4391507>,
    <0.0952034, -167.4955641>,
    <0.0894146, -167.5184453>,
    <0.0833333, -167.4838674>,
    <0.0873836, -167.4509341>,
    <0.9004589, -167.5546111>,
    <0.9074074, -167.5763713>,
    <0.9027535, -167.6051824>,
    <0.8888889, -167.5184453>,
    <0.9027856, -167.5184453>,
    <0.9047867, -167.5925951>,
    <0.8949501, -167.5563642>,
    <0.8949702, -167.5184453>,
    <0.9048061, -167.5437683>,
    <0.9108816, -167.5545331>,
    <0.9074074, -167.5763713>,
    <0.9027856, -167.5184453>,
    <0.9166667, -167.5184453>,
    <0.9166667, -167.6048705>,
    <0.9048061, -167.5437683>,
    <0.9105936, -167.5184453>,
    <0.9166667, -167.5563664>,
    <0.9126122, -167.5923911>,
    <0.9108736, -167.6196618>,
    <0.9074074, -167.5763713>,
    <0.9166667, -167.6048705>,
    <0.9166667, -167.6922232>,
    <0.9027535, -167.6051824>,
    <0.9126122, -167.5923911>,
    <0.9166667, -167.6541051>,
    <0.9105739, -167.6541068>,
    <0.9047867, -167.5925951>,
    <0.8946676, -167.4265843>,
    <0.8981482, -167.4660888>,
    <0.8888889, -167.4391507>,
    <0.8888889, -167.3613758>,
    <0.9027445, -167.4397221>,
    <0.8929391, -167.4509341>,
    <0.8888889, -167.3955180>,
    <0.8949442, -167.3956156>,
    <0.9007351, -167.4512490>,
    <0.9050862, -167.4856754>,
    <0.8981482, -167.4660888>,
    <0.9027445, -167.4397221>,
    <0.9166667, -167.5184453>,
    <0.9027856, -167.5184453>,
    <0.9007351, -167.4512490>,
    <0.9105680, -167.4839601>,
    <0.9105936, -167.5184453>,
    <0.9007589, -167.4955641>,
    <0.8946779, -167.4855325>,
    <0.8981482, -167.4660888>,
    <0.9027856, -167.5184453>,
    <0.8888889, -167.5184453>,
    <0.8888889, -167.4391507>,
    <0.9007589, -167.4955641>,
    <0.8949702, -167.5184453>,
    <0.8888889, -167.4838674>,
    <0.8929391, -167.4509341>,
    <0.0948920, -167.7614005>,
    <0.1018518, -167.7825485>,
    <0.0972271, -167.7264218>,
    <0.0833333, -167.7264218>,
    <0.0971559, -167.8102099>,
    <0.0992464, -167.7509287>,
    <0.0894130, -167.7264218>,
    <0.0893699, -167.7630136>,
    <0.0992078, -167.7981235>,
    <0.1053075, -167.8235126>,
    <0.1018518, -167.7825485>,
    <0.0971559, -167.8102099>,
    <0.1111111, -167.8948019>,
    <0.1111111, -167.8064902>,
    <0.0992078, -167.7981235>,
    <0.1050501, -167.8580618>,
    <0.1111111, -167.8566393>,
    <0.1070571, -167.7960078>,
    <0.1053253, -167.7604706>,
    <0.1018518, -167.7825485>,
    <0.1111111, -167.8064902>,
    <0.1111111, -167.7264218>,
    <0.0972271, -167.7264218>,
    <0.1070571, -167.7960078>,
    <0.1111111, -167.7610372>,
    <0.1050365, -167.7264218>,
    <0.0992464, -167.7509287>,
    <0.0891038, -167.7954495>,
    <0.0925926, -167.8386752>,
    <0.0971559, -167.8102099>,
    <0.0833333, -167.7264218>,
    <0.0833333, -167.8064909>,
    <0.0951601, -167.8226593>,
    <0.0893699, -167.7630136>,
    <0.0833333, -167.7610375>,
    <0.0873793, -167.8205541>,
    <0.0891247, -167.8586925>,
    <0.0925926, -167.8386752>,
    <0.0833333, -167.8064909>,
    <0.0833333, -167.8948019>,
    <0.0972395, -167.8948019>,
    <0.0873793, -167.8205541>,
    <0.0833333, -167.8566354>,
    <0.0893007, -167.8948019>,
    <0.0952292, -167.8705206>,
    <0.0995248, -167.8596223>,
    <0.0925926, -167.8386752>,
    <0.0972395, -167.8948019>,
    <0.1111111, -167.8948019>,
    <0.0971559, -167.8102099>,
    <0.0952292, -167.8705206>,
    <0.1051313, -167.8948019>,
    <0.1050501, -167.8580618>,
    <0.0951601, -167.8226593>,
    <0.8995852, -167.9254574>,
    <0.9074074, -167.9526834>,
    <0.9027991, -167.8948019>,
    <0.8888889, -167.8948019>,
    <0.8992453, -167.9595422>,
    <0.9049466, -167.9217754>,
    <0.8948584, -167.8948019>,
    <0.8933242, -167.9225282>,
    <0.9025022, -167.9568053>,
    <0.9099965, -167.9832125>,
    <0.9074074, -167.9526834>,
    <0.8992453, -167.9595422>,
    <0.9166667, -168.0684463>,
    <0.9166667, -167.9521780>,
    <0.9025022, -167.9568053>,
    <0.9068106, -168.0068341>,
    <0.9166667, -167.9962220>,
    <0.9127796, -167.9523901>,
    <0.9108850, -167.9236163>,
    <0.9074074, -167.9526834>,
    <0.9166667, -167.9521780>,
    <0.9166667, -167.8948019>,
    <0.9027991, -167.8948019>,
    <0.9127796, -167.9523901>,
    <0.9166667, -167.9195413>,
    <0.9106890, -167.8948019>,
    <0.9049466, -167.9217754>,
    <0.8946575, -167.7954197>,
    <0.8981482, -167.8386752>,
    <0.9027041, -167.8101654>,
    <0.8888889, -167.7264218>,
    <0.8888889, -167.8064163>,
    <0.9007108, -167.8226388>,
    <0.8949214, -167.7629888>,
    <0.8888889, -167.7609993>,
    <0.8929340, -167.8205093>,
    <0.8946813, -167.8586739>,
    <0.8981482, -167.8386752>,
    <0.8888889, -167.8064163>,
    <0.8888889, -167.8948019>,
    <0.9027991, -167.8948019>,
    <0.8929340, -167.8205093>,
    <0.8888889, -167.8565047>,
    <0.8948584, -167.8948019>,
    <0.9007844, -167.8704888>,
    <0.9050795, -167.8596111>,
    <0.8981482, -167.8386752>,
    <0.9027991, -167.8948019>,
    <0.9166667, -167.8948019>,
    <0.9027041, -167.8101654>,
    <0.9007844, -167.8704888>,
    <0.9106890, -167.8948019>,
    <0.9105987, -167.8580199>,
    <0.9007108, -167.8226388>,
    <0.1176778, -167.1107263>,
    <0.1152711, -167.1123151>,
    <0.1143272, -167.1224010>,
    <0.1235909, -167.1040945>,
    <0.1175219, -167.1040945>,
    <0.1146908, -167.1185152>,
    <0.1179805, -167.1151816>,
    <0.1206167, -167.1040945>,
    <0.1167720, -167.1068332>,
    <0.1137538, -167.1090600>,
    <0.1152711, -167.1123151>,
    <0.1175219, -167.1040945>,
    <0.1111111, -167.1040945>,
    <0.1111111, -167.1157357>,
    <0.1167720, -167.1068332>,
    <0.1143389, -167.1040945>,
    <0.1111111, -167.1077238>,
    <0.1132182, -167.1140031>,
    <0.1129551, -167.1198021>,
    <0.1152711, -167.1123151>,
    <0.1111111, -167.1157357>,
    <0.1111111, -167.1287564>,
    <0.1143272, -167.1224010>,
    <0.1132182, -167.1140031>,
    <0.1111111, -167.1243338>,
    <0.1122915, -167.1264237>,
    <0.1146908, -167.1185152>,
    <0.0940304, -167.9254685>,
    <0.1018518, -167.9526834>,
    <0.0972395, -167.8948019>,
    <0.0833333, -167.8948019>,
    <0.0936969, -167.9595867>,
    <0.0993917, -167.9218102>,
    <0.0893007, -167.8948019>,
    <0.0877735, -167.9225584>,
    <0.0969505, -167.9568325>,
    <0.1044427, -167.9833018>,
    <0.1018518, -167.9526834>,
    <0.0936969, -167.9595867>,
    <0.1111111, -168.0684463>,
    <0.1111111, -167.9524907>,
    <0.0969505, -167.9568325>,
    <0.1012589, -168.0068582>,
    <0.1111111, -167.9962671>,
    <0.1072249, -167.9525716>,
    <0.1053284, -167.9236945>,
    <0.1018518, -167.9526834>,
    <0.1111111, -167.9524907>,
    <0.1111111, -167.8948019>,
    <0.0972395, -167.8948019>,
    <0.1072249, -167.9525716>,
    <0.1111111, -167.9196706>,
    <0.1051313, -167.8948019>,
    <0.0993917, -167.9218102>,
    <0.0882390, -167.9543564>,
    <0.0925926, -168.0105648>,
    <0.0936969, -167.9595867>,
    <0.0833333, -167.8948019>,
    <0.0833333, -167.9524723>,
    <0.0931933, -167.9828353>,
    <0.0877735, -167.9225584>,
    <0.0833333, -167.9196681>,
    <0.0875297, -167.9788005>,
    <0.0891204, -168.0249824>,
    <0.0925926, -168.0105648>,
    <0.0833333, -167.9524723>,
    <0.0833333, -168.0684463>,
    <0.0972222, -168.0684463>,
    <0.0875297, -167.9788005>,
    <0.0833333, -167.9962970>,
    <0.0902778, -168.0684463>,
    <0.0953380, -168.0448889>,
    <0.0986557, -168.0267610>,
    <0.0925926, -168.0105648>,
    <0.0972222, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.0936969, -167.9595867>,
    <0.0953380, -168.0448889>,
    <0.1041667, -168.0684463>,
    <0.1012589, -168.0068582>,
    <0.0931933, -167.9828353>,
    <0.8937928, -167.9542548>,
    <0.8981482, -168.0105648>,
    <0.8992453, -167.9595422>,
    <0.8888889, -167.8948019>,
    <0.8888889, -167.9521104>,
    <0.8987450, -167.9828098>,
    <0.8933242, -167.9225282>,
    <0.8888889, -167.9195066>,
    <0.8930853, -167.9786025>,
    <0.8946759, -168.0248920>,
    <0.8981482, -168.0105648>,
    <0.8888889, -167.9521104>,
    <0.8888889, -168.0684463>,
    <0.9027778, -168.0684463>,
    <0.8930853, -167.9786025>,
    <0.8888889, -167.9961684>,
    <0.8958333, -168.0684463>,
    <0.9008933, -168.0448864>,
    <0.9042095, -168.0267499>,
    <0.8981482, -168.0105648>,
    <0.9027778, -168.0684463>,
    <0.9166667, -168.0684463>,
    <0.8992453, -167.9595422>,
    <0.9008933, -168.0448864>,
    <0.9097222, -168.0684463>,
    <0.9068106, -168.0068341>,
    <0.8987450, -167.9828098>,
    <0.0949033, -167.5546111>,
    <0.1018518, -167.5763713>,
    <0.0971979, -167.6051824>,
    <0.0833333, -167.5184453>,
    <0.0972301, -167.5184453>,
    <0.0992312, -167.5925951>,
    <0.0893945, -167.5563642>,
    <0.0894146, -167.5184453>,
    <0.0992505, -167.5437683>,
    <0.1053260, -167.5545331>,
    <0.1018518, -167.5763713>,
    <0.0972301, -167.5184453>,
    <0.1111111, -167.5184453>,
    <0.1111111, -167.6048705>,
    <0.0992505, -167.5437683>,
    <0.1050380, -167.5184453>,
    <0.1111111, -167.5563664>,
    <0.1070566, -167.5923911>,
    <0.1053180, -167.6196618>,
    <0.1018518, -167.5763713>,
    <0.1111111, -167.6048705>,
    <0.1111111, -167.6922232>,
    <0.0971979, -167.6051824>,
    <0.1070566, -167.5923911>,
    <0.1111111, -167.6541051>,
    <0.1050183, -167.6541068>,
    <0.0992312, -167.5925951>,
    <0.0891143, -167.5906989>,
    <0.0925926, -167.6342972>,
    <0.0833333, -167.6048705>,
    <0.0833333, -167.5184453>,
    <0.0971979, -167.6051824>,
    <0.0873842, -167.6177446>,
    <0.0833333, -167.5563664>,
    <0.0893945, -167.5563642>,
    <0.0951848, -167.6179095>,
    <0.0995323, -167.6559815>,
    <0.0925926, -167.6342972>,
    <0.0971979, -167.6051824>,
    <0.1111111, -167.6922232>,
    <0.0972276, -167.6922232>,
    <0.0951848, -167.6179095>,
    <0.1050183, -167.6541068>,
    <0.1050368, -167.6922232>,
    <0.0952020, -167.6669079>,
    <0.0891217, -167.6559035>,
    <0.0925926, -167.6342972>,
    <0.0972276, -167.6922232>,
    <0.0833333, -167.6922232>,
    <0.0833333, -167.6048705>,
    <0.0952020, -167.6669079>,
    <0.0894133, -167.6922232>,
    <0.0833333, -167.6541051>,
    <0.0873842, -167.6177446>,
    <0.9004450, -167.7306785>,
    <0.9074074, -167.7539575>,
    <0.9027006, -167.7843100>,
    <0.8888889, -167.6922232>,
    <0.9027832, -167.6922232>,
    <0.9047571, -167.7710483>,
    <0.8949193, -167.7324297>,
    <0.8949689, -167.6922232>,
    <0.9048022, -167.7191767>,
    <0.9108810, -167.7297464>,
    <0.9074074, -167.7539575>,
    <0.9027832, -167.6922232>,
    <0.9166667, -167.6922232>,
    <0.9166667, -167.7805818>,
    <0.9048022, -167.7191767>,
    <0.9105923, -167.6922232>,
    <0.9166667, -167.7304668>,
    <0.9126125, -167.7689244>,
    <0.9108603, -167.7990688>,
    <0.9074074, -167.7539575>,
    <0.9166667, -167.7805818>,
    <0.9166667, -167.8774261>,
    <0.9027006, -167.7843100>,
    <0.9126125, -167.7689244>,
    <0.9166667, -167.8342852>,
    <0.9105342, -167.8365388>,
    <0.9047571, -167.7710483>,
    <0.8946699, -167.5906989>,
    <0.8981482, -167.6342972>,
    <0.8888889, -167.6048705>,
    <0.8888889, -167.5184453>,
    <0.9027535, -167.6051824>,
    <0.8929398, -167.6177446>,
    <0.8888889, -167.5563664>,
    <0.8949501, -167.5563642>,
    <0.9007403, -167.6179095>,
    <0.9050879, -167.6559815>,
    <0.8981482, -167.6342972>,
    <0.9027535, -167.6051824>,
    <0.9166667, -167.6922232>,
    <0.9027832, -167.6922232>,
    <0.9007403, -167.6179095>,
    <0.9105739, -167.6541068>,
    <0.9105923, -167.6922232>,
    <0.9007575, -167.6669079>,
    <0.8946773, -167.6559035>,
    <0.8981482, -167.6342972>,
    <0.9027832, -167.6922232>,
    <0.8888889, -167.6922232>,
    <0.8888889, -167.6048705>,
    <0.9007575, -167.6669079>,
    <0.8949689, -167.6922232>,
    <0.8888889, -167.6541051>,
    <0.8929398, -167.6177446>,
    <0.0948913, -167.7306908>,
    <0.1018518, -167.7539575>,
    <0.0971524, -167.7843593>,
    <0.0833333, -167.6922232>,
    <0.0972276, -167.6922232>,
    <0.0992057, -167.7710758>,
    <0.0893678, -167.7324571>,
    <0.0894133, -167.6922232>,
    <0.0992468, -167.7191795>,
    <0.1053254, -167.7297597>,
    <0.1018518, -167.7539575>,
    <0.0972276, -167.6922232>,
    <0.1111111, -167.6922232>,
    <0.1111111, -167.7806351>,
    <0.0992468, -167.7191795>,
    <0.1050368, -167.6922232>,
    <0.1111111, -167.7304944>,
    <0.1070570, -167.7689544>,
    <0.1053066, -167.7990945>,
    <0.1018518, -167.7539575>,
    <0.1111111, -167.7806351>,
    <0.1111111, -167.8774261>,
    <0.0971524, -167.7843593>,
    <0.1070570, -167.7689544>,
    <0.1111111, -167.8343518>,
    <0.1049850, -167.8365812>,
    <0.0992057, -167.7710758>,
    <0.0891029, -167.7682275>,
    <0.0925926, -167.8156918>,
    <0.0833333, -167.7806356>,
    <0.0833333, -167.6922232>,
    <0.0971524, -167.7843593>,
    <0.0873790, -167.7959530>,
    <0.0833333, -167.7304946>,
    <0.0893678, -167.7324571>,
    <0.0951585, -167.7980606>,
    <0.0995240, -167.8387258>,
    <0.0925926, -167.8156918>,
    <0.0971524, -167.7843593>,
    <0.1111111, -167.8774261>,
    <0.0972398, -167.8774261>,
    <0.0951585, -167.7980606>,
    <0.1049850, -167.8365812>,
    <0.1050398, -167.8774261>,
    <0.0952043, -167.8503868>,
    <0.0891248, -167.8377949>,
    <0.0925926, -167.8156918>,
    <0.0972398, -167.8774261>,
    <0.0833333, -167.8774261>,
    <0.0833333, -167.7806356>,
    <0.0952043, -167.8503868>,
    <0.0894229, -167.8774261>,
    <0.0833333, -167.8343526>,
    <0.0873790, -167.7959530>,
    <0.9003372, -167.9163196>,
    <0.9074074, -167.9410995>,
    <0.9022529, -167.9693270>,
    <0.8888889, -167.8774261>,
    <0.9027994, -167.8774261>,
    <0.9044918, -167.9570661>,
    <0.8946664, -167.9171561>,
    <0.8949805, -167.8774261>,
    <0.9048114, -167.9052275>,
    <0.9108850, -167.9155224>,
    <0.9074074, -167.9410995>,
    <0.9027994, -167.8774261>,
    <0.9166667, -167.8774261>,
    <0.9166667, -167.9661382>,
    <0.9048114, -167.9052275>,
    <0.9105975, -167.8774261>,
    <0.9166667, -167.9166665>,
    <0.9126012, -167.9551444>,
    <0.9107484, -167.9862527>,
    <0.9074074, -167.9410995>,
    <0.9166667, -167.9661382>,
    <0.9166667, -168.0684463>,
    <0.9022529, -167.9693270>,
    <0.9126012, -167.9551444>,
    <0.9166667, -168.0222310>,
    <0.9101518, -168.0236456>,
    <0.9044918, -167.9570661>,
    <0.8946566, -167.7681977>,
    <0.8981482, -167.8156918>,
    <0.8888889, -167.7805659>,
    <0.8888889, -167.6922232>,
    <0.9027006, -167.7843100>,
    <0.8929338, -167.7959106>,
    <0.8888889, -167.7304587>,
    <0.8949193, -167.7324297>,
    <0.9007091, -167.7980379>,
    <0.9050787, -167.8387135>,
    <0.8981482, -167.8156918>,
    <0.9027006, -167.7843100>,
    <0.9166667, -167.8774261>,
    <0.9027994, -167.8774261>,
    <0.9007091, -167.7980379>,
    <0.9105342, -167.8365388>,
    <0.9105975, -167.8774261>,
    <0.9007597, -167.8503541>,
    <0.8946813, -167.8377775>,
    <0.8981482, -167.8156918>,
    <0.9027994, -167.8774261>,
    <0.8888889, -167.8774261>,
    <0.8888889, -167.7805659>,
    <0.9007597, -167.8503541>,
    <0.8949805, -167.8774261>,
    <0.8888889, -167.8342651>,
    <0.8929338, -167.7959106>,
    <0.0948068, -167.9165002>,
    <0.1018518, -167.9410995>,
    <0.0968024, -167.9700492>,
    <0.0833333, -167.8774261>,
    <0.0972398, -167.8774261>,
    <0.0990021, -167.9574375>,
    <0.0891776, -167.9176159>,
    <0.0894229, -167.8774261>,
    <0.0992586, -167.9052982>,
    <0.1053285, -167.9150932>,
    <0.1018518, -167.9410995>,
    <0.0972398, -167.8774261>,
    <0.1111111, -167.8774261>,
    <0.1111111, -167.9644214>,
    <0.0992586, -167.9052982>,
    <0.1050398, -167.8774261>,
    <0.1111111, -167.9158322>,
    <0.1070528, -167.9541995>,
    <0.1052191, -167.9860041>,
    <0.1018518, -167.9410995>,
    <0.1111111, -167.9644214>,
    <0.1111111, -168.0684463>,
    <0.0968024, -167.9700492>,
    <0.1070528, -167.9541995>,
    <0.1111111, -168.0195758>,
    <0.1046806, -168.0242256>,
    <0.0990021, -167.9574375>,
    <0.0890154, -167.9540950>,
    <0.0925926, -168.0047729>,
    <0.0833333, -167.9641320>,
    <0.0833333, -167.8774261>,
    <0.0968024, -167.9700492>,
    <0.0873237, -167.9816467>,
    <0.0833333, -167.9157383>,
    <0.0891776, -167.9176159>,
    <0.0949321, -167.9854759>,
    <0.0996101, -168.0279287>,
    <0.0925926, -168.0047729>,
    <0.0968024, -167.9700492>,
    <0.1111111, -168.0684463>,
    <0.0979342, -168.0684463>,
    <0.0949321, -167.9854759>,
    <0.1046806, -168.0242256>,
    <0.1057030, -168.0684463>,
    <0.0953610, -168.0377733>,
    <0.0892984, -168.0264494>,
    <0.0925926, -168.0047729>,
    <0.0979342, -168.0684463>,
    <0.0833333, -168.0684463>,
    <0.0833333, -167.9641320>,
    <0.0953610, -168.0377733>,
    <0.0896019, -168.0684463>,
    <0.0833333, -168.0181756>,
    <0.0873237, -167.9816467>,
    <0.8945447, -167.9542098>,
    <0.8981482, -168.0047729>,
    <0.8888889, -167.9653134>,
    <0.8888889, -167.8774261>,
    <0.9022529, -167.9693270>,
    <0.8928375, -167.9821408>,
    <0.8888889, -167.9162189>,
    <0.8946664, -167.9171561>,
    <0.9003923, -167.9853939>,
    <0.9053098, -168.0277481>,
    <0.8981482, -168.0047729>,
    <0.9022529, -167.9693270>,
    <0.9166667, -168.0684463>,
    <0.9041714, -168.0684463>,
    <0.9003923, -167.9853939>,
    <0.9101518, -168.0236456>,
    <0.9116690, -168.0684463>,
    <0.9009430, -168.0343177>,
    <0.8950244, -168.0267447>,
    <0.8981482, -168.0047729>,
    <0.9041714, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8888889, -167.9653134>,
    <0.9009430, -168.0343177>,
    <0.8956044, -168.0684463>,
    <0.8888889, -168.0212495>,
    <0.8928375, -167.9821408>,
    <0.8809882, -167.1108094>,
    <0.8837895, -167.1123151>,
    <0.8814198, -167.1040945>,
    <0.8735908, -167.1040945>,
    <0.8851529, -167.1227337>,
    <0.8823363, -167.1072739>,
    <0.8775764, -167.1040945>,
    <0.8808944, -167.1158686>,
    <0.8845937, -167.1184605>,
    <0.8866800, -167.1208709>,
    <0.8837895, -167.1123151>,
    <0.8851529, -167.1227337>,
    <0.8888889, -167.1287564>,
    <0.8888889, -167.1196785>,
    <0.8845937, -167.1184605>,
    <0.8875028, -167.1265219>,
    <0.8888889, -167.1261982>,
    <0.8865148, -167.1162504>,
    <0.8857468, -167.1100457>,
    <0.8837895, -167.1123151>,
    <0.8888889, -167.1196785>,
    <0.8888889, -167.1040945>,
    <0.8814198, -167.1040945>,
    <0.8865148, -167.1162504>,
    <0.8888889, -167.1103619>,
    <0.8851759, -167.1040945>,
    <0.8823363, -167.1072739>,
    <0.8798192, -167.0794526>,
    <0.8834360, -167.0842391>,
    <0.8822783, -167.0966789>,
    <0.8725301, -167.0684463>,
    <0.8810325, -167.0684463>,
    <0.8827390, -167.0917279>,
    <0.8775241, -167.0829097>,
    <0.8769134, -167.0684463>,
    <0.8820783, -167.0753181>,
    <0.8855616, -167.0788821>,
    <0.8834360, -167.0842391>,
    <0.8810325, -167.0684463>,
    <0.8888889, -167.0684463>,
    <0.8888889, -167.0943969>,
    <0.8820783, -167.0753181>,
    <0.8849984, -167.0684463>,
    <0.8888889, -167.0814789>,
    <0.8865862, -167.0901073>,
    <0.8858730, -167.0977849>,
    <0.8834360, -167.0842391>,
    <0.8888889, -167.0943969>,
    <0.8888889, -167.1158246>,
    <0.8822783, -167.0966789>,
    <0.8865862, -167.0901073>,
    <0.8888889, -167.1096993>,
    <0.8863202, -167.1083851>,
    <0.8827390, -167.0917279>,
    <0.1309884, -167.1108095>,
    <0.1337896, -167.1123151>,
    <0.1314198, -167.1040945>,
    <0.1235910, -167.1040945>,
    <0.1351531, -167.1227339>,
    <0.1323364, -167.1072740>,
    <0.1275765, -167.1040945>,
    <0.1308947, -167.1158689>,
    <0.1345938, -167.1184607>,
    <0.1366801, -167.1208724>,
    <0.1337896, -167.1123151>,
    <0.1351531, -167.1227339>,
    <0.1388889, -167.1287564>,
    <0.1388889, -167.1196840>,
    <0.1345938, -167.1184607>,
    <0.1375028, -167.1265220>,
    <0.1388889, -167.1261994>,
    <0.1365149, -167.1162534>,
    <0.1357468, -167.1100470>,
    <0.1337896, -167.1123151>,
    <0.1388889, -167.1196840>,
    <0.1388889, -167.1040945>,
    <0.1314198, -167.1040945>,
    <0.1365149, -167.1162534>,
    <0.1388889, -167.1103669>,
    <0.1351759, -167.1040945>,
    <0.1323364, -167.1072740>,
    <0.1244004, -167.1174413>,
    <0.1245303, -167.1205358>,
    <0.1351531, -167.1227339>,
    <0.1235909, -167.1040945>,
    <0.1143272, -167.1224010>,
    <0.1306548, -167.1218031>,
    <0.1308947, -167.1158689>,
    <0.1179805, -167.1151816>,
    <0.1190738, -167.1215333>,
    <0.1185392, -167.1251124>,
    <0.1245303, -167.1205358>,
    <0.1143272, -167.1224010>,
    <0.1111111, -167.1287564>,
    <0.1241882, -167.1287564>,
    <0.1190738, -167.1215333>,
    <0.1122915, -167.1264237>,
    <0.1164644, -167.1287564>,
    <0.1243056, -167.1259349>,
    <0.1306901, -167.1251956>,
    <0.1245303, -167.1205358>,
    <0.1241882, -167.1287564>,
    <0.1388889, -167.1287564>,
    <0.1351531, -167.1227339>,
    <0.1243056, -167.1259349>,
    <0.1325464, -167.1287564>,
    <0.1375028, -167.1265220>,
    <0.1306548, -167.1218031>,
    <0.8744203, -167.1174017>,
    <0.8745303, -167.1205358>,
    <0.8851529, -167.1227337>,
    <0.8735908, -167.1040945>,
    <0.8644072, -167.1222427>,
    <0.8806675, -167.1218056>,
    <0.8808944, -167.1158686>,
    <0.8680334, -167.1150768>,
    <0.8690919, -167.1214528>,
    <0.8685964, -167.1250728>,
    <0.8745303, -167.1205358>,
    <0.8644072, -167.1222427>,
    <0.8611111, -167.1287564>,
    <0.8743369, -167.1287564>,
    <0.8690919, -167.1214528>,
    <0.8623741, -167.1262606>,
    <0.8665888, -167.1287564>,
    <0.8744037, -167.1259187>,
    <0.8807272, -167.1251956>,
    <0.8745303, -167.1205358>,
    <0.8743369, -167.1287564>,
    <0.8888889, -167.1287564>,
    <0.8851529, -167.1227337>,
    <0.8744037, -167.1259187>,
    <0.8826289, -167.1287564>,
    <0.8875028, -167.1265219>,
    <0.8806675, -167.1218056>,
    <0.8726218, -167.1443740>,
    <0.8796296, -167.1533103>,
    <0.8743369, -167.1287564>,
    <0.8611111, -167.1287564>,
    <0.8754094, -167.1666728>,
    <0.8769481, -167.1408700>,
    <0.8665888, -167.1287564>,
    <0.8675374, -167.1457977>,
    <0.8773134, -167.1606440>,
    <0.8832042, -167.1707453>,
    <0.8796296, -167.1533103>,
    <0.8754094, -167.1666728>,
    <0.8888889, -167.2024179>,
    <0.8888889, -167.1605801>,
    <0.8773134, -167.1606440>,
    <0.8830396, -167.1869068>,
    <0.8888889, -167.1838663>,
    <0.8849042, -167.1574516>,
    <0.8829361, -167.1428508>,
    <0.8796296, -167.1533103>,
    <0.8888889, -167.1605801>,
    <0.8888889, -167.1287564>,
    <0.8743369, -167.1287564>,
    <0.8849042, -167.1574516>,
    <0.8888889, -167.1409328>,
    <0.8826289, -167.1287564>,
    <0.8769481, -167.1408700>,
    <0.8676977, -167.1106867>,
    <0.8652710, -167.1123151>,
    <0.8644072, -167.1222427>,
    <0.8735908, -167.1040945>,
    <0.8675219, -167.1040945>,
    <0.8647537, -167.1182602>,
    <0.8680334, -167.1150768>,
    <0.8706166, -167.1040945>,
    <0.8666848, -167.1071516>,
    <0.8637538, -167.1100451>,
    <0.8652710, -167.1123151>,
    <0.8675219, -167.1040945>,
    <0.8611111, -167.1040945>,
    <0.8611111, -167.1196763>,
    <0.8666848, -167.1071516>,
    <0.8643389, -167.1040945>,
    <0.8611111, -167.1103597>,
    <0.8629838, -167.1163624>,
    <0.8629751, -167.1207476>,
    <0.8652710, -167.1123151>,
    <0.8611111, -167.1196763>,
    <0.8611111, -167.1287564>,
    <0.8644072, -167.1222427>,
    <0.8629838, -167.1163624>,
    <0.8611111, -167.1261977>,
    <0.8623741, -167.1262606>,
    <0.8647537, -167.1182602>,
    <0.8706704, -167.0805640>,
    <0.8741794, -167.0842391>,
    <0.8802718, -167.1011244>,
    <0.8611162, -167.0684463>,
    <0.8671141, -167.0684463>,
    <0.8781208, -167.0951629>,
    <0.8726837, -167.0881797>,
    <0.8641546, -167.0684463>,
    <0.8699511, -167.0747877>,
    <0.8740266, -167.0794526>,
    <0.8741794, -167.0842391>,
    <0.8671141, -167.0684463>,
    <0.8725332, -167.0684463>,
    <0.8822795, -167.0966789>,
    <0.8699511, -167.0747877>,
    <0.8699210, -167.0684463>,
    <0.8775262, -167.0829097>,
    <0.8782436, -167.0904808>,
    <0.8814049, -167.0994668>,
    <0.8741794, -167.0842391>,
    <0.8822795, -167.0966789>,
    <0.8888889, -167.1158246>,
    <0.8802718, -167.1011244>,
    <0.8782436, -167.0904808>,
    <0.8863206, -167.1083851>,
    <0.8854274, -167.1099195>,
    <0.8781208, -167.0951629>,
    <0.1225420, -167.1442610>,
    <0.1296296, -167.1533103>,
    <0.1241882, -167.1287564>,
    <0.1111111, -167.1287564>,
    <0.1252390, -167.1662210>,
    <0.1268738, -167.1408752>,
    <0.1164644, -167.1287564>,
    <0.1173683, -167.1453494>,
    <0.1272213, -167.1603919>,
    <0.1331616, -167.1706324>,
    <0.1296296, -167.1533103>,
    <0.1252390, -167.1662210>,
    <0.1388889, -167.2024179>,
    <0.1388889, -167.1605805>,
    <0.1272213, -167.1603919>,
    <0.1329485, -167.1866652>,
    <0.1388889, -167.1838665>,
    <0.1348989, -167.1574476>,
    <0.1328989, -167.1428509>,
    <0.1296296, -167.1533103>,
    <0.1388889, -167.1605805>,
    <0.1388889, -167.1287564>,
    <0.1241882, -167.1287564>,
    <0.1348989, -167.1574476>,
    <0.1388889, -167.1409331>,
    <0.1325464, -167.1287564>,
    <0.1268738, -167.1408752>,
    <0.1169579, -167.1583892>,
    <0.1203704, -167.1778641>,
    <0.1252390, -167.1662210>,
    <0.1111111, -167.1287564>,
    <0.1111111, -167.1607152>,
    <0.1231177, -167.1712941>,
    <0.1173683, -167.1453494>,
    <0.1111111, -167.1413911>,
    <0.1151679, -167.1682286>,
    <0.1169011, -167.1858538>,
    <0.1203704, -167.1778641>,
    <0.1111111, -167.1607152>,
    <0.1111111, -167.2024179>,
    <0.1250118, -167.2024179>,
    <0.1151679, -167.1682286>,
    <0.1111111, -167.1838307>,
    <0.1171946, -167.2024179>,
    <0.1229907, -167.1917260>,
    <0.1273775, -167.1872303>,
    <0.1203704, -167.1778641>,
    <0.1250118, -167.2024179>,
    <0.1388889, -167.2024179>,
    <0.1252390, -167.1662210>,
    <0.1229907, -167.1917260>,
    <0.1328177, -167.2024179>,
    <0.1329485, -167.1866652>,
    <0.1231177, -167.1712941>,
    <0.8726770, -167.2232074>,
    <0.8796296, -167.2357456>,
    <0.8750118, -167.2024179>,
    <0.8611111, -167.2024179>,
    <0.8749553, -167.2522483>,
    <0.8770296, -167.2169804>,
    <0.8671946, -167.2024179>,
    <0.8671590, -167.2241867>,
    <0.8769973, -167.2450388>,
    <0.8830907, -167.2602946>,
    <0.8796296, -167.2357456>,
    <0.8749553, -167.2522483>,
    <0.8888889, -167.3024008>,
    <0.8888889, -167.2507837>,
    <0.8769973, -167.2450388>,
    <0.8827825, -167.2804214>,
    <0.8888889, -167.2798504>,
    <0.8848332, -167.2441968>,
    <0.8831048, -167.2228413>,
    <0.8796296, -167.2357456>,
    <0.8888889, -167.2507837>,
    <0.8888889, -167.2024179>,
    <0.8750118, -167.2024179>,
    <0.8848332, -167.2441968>,
    <0.8888889, -167.2235884>,
    <0.8828177, -167.2024179>,
    <0.8770296, -167.2169804>,
    <0.8670005, -167.1584683>,
    <0.8703704, -167.1778641>,
    <0.8754094, -167.1666728>,
    <0.8611111, -167.1287564>,
    <0.8611111, -167.1605800>,
    <0.8732119, -167.1715532>,
    <0.8675374, -167.1457977>,
    <0.8611111, -167.1409326>,
    <0.8651659, -167.1681490>,
    <0.8669011, -167.1858200>,
    <0.8703704, -167.1778641>,
    <0.8611111, -167.1605800>,
    <0.8611111, -167.2024179>,
    <0.8750118, -167.2024179>,
    <0.8651659, -167.1681490>,
    <0.8611111, -167.1838663>,
    <0.8671946, -167.2024179>,
    <0.8729958, -167.1917530>,
    <0.8774201, -167.1873432>,
    <0.8703704, -167.1778641>,
    <0.8750118, -167.2024179>,
    <0.8888889, -167.2024179>,
    <0.8754094, -167.1666728>,
    <0.8729958, -167.1917530>,
    <0.8828177, -167.2024179>,
    <0.8830396, -167.1869068>,
    <0.8732119, -167.1715532>,
    <0.1298207, -167.0794541>,
    <0.1334370, -167.0842391>,
    <0.1322816, -167.0966849>,
    <0.1225331, -167.0684463>,
    <0.1310312, -167.0684463>,
    <0.1327411, -167.0917353>,
    <0.1275273, -167.0829132>,
    <0.1269129, -167.0684463>,
    <0.1320776, -167.0753157>,
    <0.1355615, -167.0789148>,
    <0.1334370, -167.0842391>,
    <0.1310312, -167.0684463>,
    <0.1388889, -167.0684463>,
    <0.1388889, -167.0945275>,
    <0.1320776, -167.0753157>,
    <0.1349975, -167.0684463>,
    <0.1388889, -167.0815943>,
    <0.1365863, -167.0901824>,
    <0.1358741, -167.0978191>,
    <0.1334370, -167.0842391>,
    <0.1388889, -167.0945275>,
    <0.1388889, -167.1158246>,
    <0.1322816, -167.0966849>,
    <0.1365863, -167.0901824>,
    <0.1388889, -167.1098585>,
    <0.1363219, -167.1083889>,
    <0.1327411, -167.0917353>,
    <0.1206629, -167.0805591>,
    <0.1241767, -167.0842391>,
    <0.1302586, -167.1011047>,
    <0.1111111, -167.0684463>,
    <0.1171051, -167.0684463>,
    <0.1281118, -167.0951515>,
    <0.1226564, -167.0881382>,
    <0.1141467, -167.0684463>,
    <0.1199447, -167.0747878>,
    <0.1240231, -167.0794541>,
    <0.1241767, -167.0842391>,
    <0.1171051, -167.0684463>,
    <0.1225301, -167.0684463>,
    <0.1322803, -167.0966849>,
    <0.1199447, -167.0747878>,
    <0.1199136, -167.0684463>,
    <0.1275252, -167.0829132>,
    <0.1282418, -167.0904825>,
    <0.1314011, -167.0994633>,
    <0.1241767, -167.0842391>,
    <0.1322803, -167.0966849>,
    <0.1388889, -167.1158246>,
    <0.1302586, -167.1011047>,
    <0.1282418, -167.0904825>,
    <0.1363215, -167.1083889>,
    <0.1354217, -167.1099109>,
    <0.1281118, -167.0951515>,
    <0.1182128, -167.0909950>,
    <0.1203704, -167.1000319>,
    <0.1111111, -167.0943971>,
    <0.1111111, -167.0684463>,
    <0.1302586, -167.1011047>,
    <0.1151120, -167.0968319>,
    <0.1111111, -167.0814793>,
    <0.1226564, -167.0881382>,
    <0.1252408, -167.1005603>,
    <0.1284886, -167.1081965>,
    <0.1203704, -167.1000319>,
    <0.1302586, -167.1011047>,
    <0.1388889, -167.1158246>,
    <0.1244365, -167.1158246>,
    <0.1252408, -167.1005603>,
    <0.1354217, -167.1099109>,
    <0.1326448, -167.1158246>,
    <0.1225416, -167.1084649>,
    <0.1167573, -167.1065196>,
    <0.1203704, -167.1000319>,
    <0.1244365, -167.1158246>,
    <0.1111111, -167.1158246>,
    <0.1111111, -167.0943971>,
    <0.1225416, -167.1084649>,
    <0.1166084, -167.1158246>,
    <0.1111111, -167.1096992>,
    <0.1151120, -167.0968319>,
    <0.8724557, -167.1383984>,
    <0.8796296, -167.1524837>,
    <0.8746583, -167.1694605>,
    <0.8611111, -167.1158246>,
    <0.8744239, -167.1158246>,
    <0.8768243, -167.1620638>,
    <0.8668304, -167.1384683>,
    <0.8666021, -167.1158246>,
    <0.8766794, -167.1317082>,
    <0.8829578, -167.1378792>,
    <0.8796296, -167.1524837>,
    <0.8744239, -167.1158246>,
    <0.8888889, -167.1158246>,
    <0.8888889, -167.1673836>,
    <0.8766794, -167.1317082>,
    <0.8826366, -167.1158246>,
    <0.8888889, -167.1360520>,
    <0.8848273, -167.1608478>,
    <0.8830164, -167.1787825>,
    <0.8796296, -167.1524837>,
    <0.8888889, -167.1673836>,
    <0.8888889, -167.2258020>,
    <0.8746583, -167.1694605>,
    <0.8848273, -167.1608478>,
    <0.8888889, -167.2002138>,
    <0.8826193, -167.2009797>,
    <0.8768243, -167.1620638>,
    <0.8682157, -167.0912675>,
    <0.8703704, -167.1000319>,
    <0.8611111, -167.0954672>,
    <0.8611111, -167.0684463>,
    <0.8802702, -167.1011244>,
    <0.8650999, -167.0974336>,
    <0.8611111, -167.0824309>,
    <0.8726807, -167.0881797>,
    <0.8752400, -167.1005693>,
    <0.8784883, -167.1082014>,
    <0.8703704, -167.1000319>,
    <0.8802702, -167.1011244>,
    <0.8888889, -167.1158246>,
    <0.8744239, -167.1158246>,
    <0.8752400, -167.1005693>,
    <0.8854267, -167.1099195>,
    <0.8826366, -167.1158246>,
    <0.8725327, -167.1084564>,
    <0.8667541, -167.1067871>,
    <0.8703704, -167.1000319>,
    <0.8744239, -167.1158246>,
    <0.8611111, -167.1158246>,
    <0.8611111, -167.0954672>,
    <0.8725327, -167.1084564>,
    <0.8666021, -167.1158246>,
    <0.8611111, -167.1101308>,
    <0.8650999, -167.0974336>,
    <0.1226769, -167.2232074>,
    <0.1296296, -167.2357456>,
    <0.1250118, -167.2024179>,
    <0.1111111, -167.2024179>,
    <0.1249552, -167.2522483>,
    <0.1270295, -167.2169804>,
    <0.1171946, -167.2024179>,
    <0.1171590, -167.2241867>,
    <0.1269973, -167.2450388>,
    <0.1330907, -167.2602946>,
    <0.1296296, -167.2357456>,
    <0.1249552, -167.2522483>,
    <0.1388889, -167.3024008>,
    <0.1388889, -167.2507837>,
    <0.1269973, -167.2450388>,
    <0.1327825, -167.2804214>,
    <0.1388889, -167.2798504>,
    <0.1348332, -167.2441968>,
    <0.1331048, -167.2228413>,
    <0.1296296, -167.2357456>,
    <0.1388889, -167.2507837>,
    <0.1388889, -167.2024179>,
    <0.1250118, -167.2024179>,
    <0.1348332, -167.2441968>,
    <0.1388889, -167.2235884>,
    <0.1328177, -167.2024179>,
    <0.1270295, -167.2169804>,
    <0.1168870, -167.2436308>,
    <0.1203704, -167.2690732>,
    <0.1249552, -167.2522483>,
    <0.1111111, -167.2024179>,
    <0.1111111, -167.2507837>,
    <0.1229507, -167.2596042>,
    <0.1171590, -167.2241867>,
    <0.1111111, -167.2235884>,
    <0.1151605, -167.2587824>,
    <0.1169008, -167.2811646>,
    <0.1203704, -167.2690732>,
    <0.1111111, -167.2507837>,
    <0.1111111, -167.3024008>,
    <0.1250106, -167.3024008>,
    <0.1151605, -167.2587824>,
    <0.1111111, -167.2798504>,
    <0.1171939, -167.3024008>,
    <0.1229822, -167.2878319>,
    <0.1273063, -167.2815307>,
    <0.1203704, -167.2690732>,
    <0.1250106, -167.3024008>,
    <0.1388889, -167.3024008>,
    <0.1249552, -167.2522483>,
    <0.1229822, -167.2878319>,
    <0.1328171, -167.3024008>,
    <0.1327825, -167.2804214>,
    <0.1229507, -167.2596042>,
    <0.8726783, -167.3280360>,
    <0.8796296, -167.3434849>,
    <0.8750106, -167.3024008>,
    <0.8611111, -167.3024008>,
    <0.8749618, -167.3638575>,
    <0.8770293, -167.3203558>,
    <0.8671939, -167.3024008>,
    <0.8671633, -167.3292549>,
    <0.8770011, -167.3549573>,
    <0.8830923, -167.3739447>,
    <0.8796296, -167.3434849>,
    <0.8749618, -167.3638575>,
    <0.8888889, -167.4256532>,
    <0.8888889, -167.3627833>,
    <0.8770011, -167.3549573>,
    <0.8827869, -167.3985780>,
    <0.8888889, -167.3982231>,
    <0.8848336, -167.3543311>,
    <0.8831045, -167.3277674>,
    <0.8796296, -167.3434849>,
    <0.8888889, -167.3627833>,
    <0.8888889, -167.3024008>,
    <0.8750106, -167.3024008>,
    <0.8848336, -167.3543311>,
    <0.8888889, -167.3288803>,
    <0.8828171, -167.3024008>,
    <0.8770293, -167.3203558>,
    <0.8668870, -167.2436308>,
    <0.8703704, -167.2690732>,
    <0.8749553, -167.2522483>,
    <0.8611111, -167.2024179>,
    <0.8611111, -167.2507837>,
    <0.8729507, -167.2596042>,
    <0.8671590, -167.2241867>,
    <0.8611111, -167.2235884>,
    <0.8651605, -167.2587824>,
    <0.8669008, -167.2811646>,
    <0.8703704, -167.2690732>,
    <0.8611111, -167.2507837>,
    <0.8611111, -167.3024008>,
    <0.8750106, -167.3024008>,
    <0.8651605, -167.2587824>,
    <0.8611111, -167.2798504>,
    <0.8671939, -167.3024008>,
    <0.8729822, -167.2878319>,
    <0.8773063, -167.2815307>,
    <0.8703704, -167.2690732>,
    <0.8750106, -167.3024008>,
    <0.8888889, -167.3024008>,
    <0.8749553, -167.2522483>,
    <0.8729822, -167.2878319>,
    <0.8828171, -167.3024008>,
    <0.8827825, -167.2804214>,
    <0.8729507, -167.2596042>,
    <0.1224617, -167.1384096>,
    <0.1296296, -167.1524837>,
    <0.1246697, -167.1695055>,
    <0.1111111, -167.1158246>,
    <0.1244365, -167.1158246>,
    <0.1268305, -167.1620899>,
    <0.1168409, -167.1385098>,
    <0.1166084, -167.1158246>,
    <0.1266861, -167.1317049>,
    <0.1329610, -167.1378694>,
    <0.1296296, -167.1524837>,
    <0.1244365, -167.1158246>,
    <0.1388889, -167.1158246>,
    <0.1388889, -167.1673444>,
    <0.1266861, -167.1317049>,
    <0.1326448, -167.1158246>,
    <0.1388889, -167.1360443>,
    <0.1348275, -167.1608261>,
    <0.1330193, -167.1787839>,
    <0.1296296, -167.1524837>,
    <0.1388889, -167.1673444>,
    <0.1388889, -167.2258020>,
    <0.1246697, -167.1695055>,
    <0.1348275, -167.1608261>,
    <0.1388889, -167.2001871>,
    <0.1326256, -167.2010045>,
    <0.1268305, -167.1620899>,
    <0.1168156, -167.1604641>,
    <0.1203704, -167.1891429>,
    <0.1111111, -167.1673834>,
    <0.1111111, -167.1158246>,
    <0.1246697, -167.1695055>,
    <0.1151638, -167.1769073>,
    <0.1111111, -167.1360516>,
    <0.1168409, -167.1385098>,
    <0.1227929, -167.1780777>,
    <0.1272352, -167.2025631>,
    <0.1203704, -167.1891429>,
    <0.1246697, -167.1695055>,
    <0.1388889, -167.2258020>,
    <0.1250117, -167.2258020>,
    <0.1227929, -167.1780777>,
    <0.1326256, -167.2010045>,
    <0.1328177, -167.2258020>,
    <0.1229743, -167.2097098>,
    <0.1169011, -167.2020325>,
    <0.1203704, -167.1891429>,
    <0.1250117, -167.2258020>,
    <0.1111111, -167.2258020>,
    <0.1111111, -167.1673834>,
    <0.1229743, -167.2097098>,
    <0.1171945, -167.2258020>,
    <0.1111111, -167.2002137>,
    <0.1151638, -167.1769073>,
    <0.8726777, -167.2539957>,
    <0.8796296, -167.2709932>,
    <0.8749584, -167.2933857>,
    <0.8611111, -167.2258020>,
    <0.8750117, -167.2258020>,
    <0.8769990, -167.2836036>,
    <0.8671610, -167.2553296>,
    <0.8671945, -167.2258020>,
    <0.8770301, -167.2455535>,
    <0.8831048, -167.2537633>,
    <0.8796296, -167.2709932>,
    <0.8750117, -167.2258020>,
    <0.8888889, -167.2258020>,
    <0.8888889, -167.2924560>,
    <0.8770301, -167.2455535>,
    <0.8828177, -167.2258020>,
    <0.8888889, -167.2550533>,
    <0.8848333, -167.2830552>,
    <0.8830915, -167.3045527>,
    <0.8796296, -167.2709932>,
    <0.8888889, -167.2924560>,
    <0.8888889, -167.3613758>,
    <0.8749584, -167.2933857>,
    <0.8848333, -167.2830552>,
    <0.8888889, -167.3313235>,
    <0.8827847, -167.3315832>,
    <0.8769990, -167.2836036>,
    <0.8668127, -167.1603744>,
    <0.8703704, -167.1891429>,
    <0.8611111, -167.1670696>,
    <0.8611111, -167.1158246>,
    <0.8746583, -167.1694605>,
    <0.8651640, -167.1767313>,
    <0.8611111, -167.1357705>,
    <0.8668304, -167.1384683>,
    <0.8727866, -167.1780519>,
    <0.8772323, -167.2025518>,
    <0.8703704, -167.1891429>,
    <0.8746583, -167.1694605>,
    <0.8888889, -167.2258020>,
    <0.8750117, -167.2258020>,
    <0.8727866, -167.1780519>,
    <0.8826193, -167.2009797>,
    <0.8828177, -167.2258020>,
    <0.8729740, -167.2097068>,
    <0.8669011, -167.2019541>,
    <0.8703704, -167.1891429>,
    <0.8750117, -167.2258020>,
    <0.8611111, -167.2258020>,
    <0.8611111, -167.1670696>,
    <0.8729740, -167.2097068>,
    <0.8671945, -167.2258020>,
    <0.8611111, -167.2000469>,
    <0.8651640, -167.1767313>,
    <0.1226783, -167.3280360>,
    <0.1296296, -167.3434849>,
    <0.1250106, -167.3024008>,
    <0.1111111, -167.3024008>,
    <0.1249618, -167.3638575>,
    <0.1270292, -167.3203558>,
    <0.1171939, -167.3024008>,
    <0.1171633, -167.3292549>,
    <0.1270010, -167.3549573>,
    <0.1330923, -167.3739447>,
    <0.1296296, -167.3434849>,
    <0.1249618, -167.3638575>,
    <0.1388889, -167.4256532>,
    <0.1388889, -167.3627833>,
    <0.1270010, -167.3549573>,
    <0.1327869, -167.3985780>,
    <0.1388889, -167.3982231>,
    <0.1348336, -167.3543311>,
    <0.1331045, -167.3277674>,
    <0.1296296, -167.3434849>,
    <0.1388889, -167.3627833>,
    <0.1388889, -167.3024008>,
    <0.1250106, -167.3024008>,
    <0.1348336, -167.3543311>,
    <0.1388889, -167.3288803>,
    <0.1328171, -167.3024008>,
    <0.1270292, -167.3203558>,
    <0.1168886, -167.3534027>,
    <0.1203704, -167.3845690>,
    <0.1249618, -167.3638575>,
    <0.1111111, -167.3024008>,
    <0.1111111, -167.3627833>,
    <0.1229545, -167.3729124>,
    <0.1171633, -167.3292549>,
    <0.1111111, -167.3288803>,
    <0.1151610, -167.3723121>,
    <0.1169004, -167.3996647>,
    <0.1203704, -167.3845690>,
    <0.1111111, -167.3627833>,
    <0.1111111, -167.4256532>,
    <0.1250090, -167.4256532>,
    <0.1151610, -167.3723121>,
    <0.1111111, -167.3982231>,
    <0.1171930, -167.4256532>,
    <0.1229815, -167.4076960>,
    <0.1273075, -167.3999332>,
    <0.1203704, -167.3845690>,
    <0.1250090, -167.4256532>,
    <0.1388889, -167.4256532>,
    <0.1249618, -167.3638575>,
    <0.1229815, -167.4076960>,
    <0.1328163, -167.4256532>,
    <0.1327869, -167.3985780>,
    <0.1229545, -167.3729124>,
    <0.8726798, -167.4553644>,
    <0.8796296, -167.4732541>,
    <0.8750090, -167.4256532>,
    <0.8611111, -167.4256532>,
    <0.8749694, -167.4968970>,
    <0.8770286, -167.4464590>,
    <0.8671930, -167.4256532>,
    <0.8671682, -167.4567920>,
    <0.8770054, -167.4865678>,
    <0.8830942, -167.5086990>,
    <0.8796296, -167.4732541>,
    <0.8749694, -167.4968970>,
    <0.8888889, -167.5684558>,
    <0.8888889, -167.4961890>,
    <0.8770054, -167.4865678>,
    <0.8827919, -167.5371117>,
    <0.8888889, -167.5369298>,
    <0.8848340, -167.4861453>,
    <0.8831041, -167.4551874>,
    <0.8796296, -167.4732541>,
    <0.8888889, -167.4961890>,
    <0.8888889, -167.4256532>,
    <0.8750090, -167.4256532>,
    <0.8848340, -167.4861453>,
    <0.8888889, -167.4566011>,
    <0.8828163, -167.4256532>,
    <0.8770286, -167.4464590>,
    <0.8668886, -167.3534027>,
    <0.8703704, -167.3845690>,
    <0.8749618, -167.3638575>,
    <0.8611111, -167.3024008>,
    <0.8611111, -167.3627833>,
    <0.8729545, -167.3729124>,
    <0.8671633, -167.3292549>,
    <0.8611111, -167.3288803>,
    <0.8651610, -167.3723121>,
    <0.8669004, -167.3996647>,
    <0.8703704, -167.3845690>,
    <0.8611111, -167.3627833>,
    <0.8611111, -167.4256532>,
    <0.8750090, -167.4256532>,
    <0.8651610, -167.3723121>,
    <0.8611111, -167.3982231>,
    <0.8671930, -167.4256532>,
    <0.8729815, -167.4076960>,
    <0.8773075, -167.3999332>,
    <0.8703704, -167.3845690>,
    <0.8750090, -167.4256532>,
    <0.8888889, -167.4256532>,
    <0.8749618, -167.3638575>,
    <0.8729815, -167.4076960>,
    <0.8828163, -167.4256532>,
    <0.8827869, -167.3985780>,
    <0.8729545, -167.3729124>,
    <0.1226777, -167.2539957>,
    <0.1296296, -167.2709932>,
    <0.1249584, -167.2933857>,
    <0.1111111, -167.2258020>,
    <0.1250117, -167.2258020>,
    <0.1269990, -167.2836036>,
    <0.1171610, -167.2553296>,
    <0.1171945, -167.2258020>,
    <0.1270300, -167.2455535>,
    <0.1331048, -167.2537633>,
    <0.1296296, -167.2709932>,
    <0.1250117, -167.2258020>,
    <0.1388889, -167.2258020>,
    <0.1388889, -167.2924560>,
    <0.1270300, -167.2455535>,
    <0.1328177, -167.2258020>,
    <0.1388889, -167.2550533>,
    <0.1348333, -167.2830552>,
    <0.1330914, -167.3045527>,
    <0.1296296, -167.2709932>,
    <0.1388889, -167.2924560>,
    <0.1388889, -167.3613758>,
    <0.1249584, -167.2933857>,
    <0.1348333, -167.2830552>,
    <0.1388889, -167.3313235>,
    <0.1327847, -167.3315832>,
    <0.1269990, -167.2836036>,
    <0.1168877, -167.2819570>,
    <0.1203704, -167.3161845>,
    <0.1111111, -167.2924560>,
    <0.1111111, -167.2258020>,
    <0.1249584, -167.2933857>,
    <0.1151607, -167.3028339>,
    <0.1111111, -167.2550533>,
    <0.1171610, -167.2553296>,
    <0.1229524, -167.3033535>,
    <0.1273069, -167.3330804>,
    <0.1203704, -167.3161845>,
    <0.1249584, -167.2933857>,
    <0.1388889, -167.3613758>,
    <0.1250100, -167.3613758>,
    <0.1229524, -167.3033535>,
    <0.1327847, -167.3315832>,
    <0.1328169, -167.3613758>,
    <0.1229822, -167.3416247>,
    <0.1169006, -167.3328480>,
    <0.1203704, -167.3161845>,
    <0.1250100, -167.3613758>,
    <0.1111111, -167.3613758>,
    <0.1111111, -167.2924560>,
    <0.1229822, -167.3416247>,
    <0.1171935, -167.3613758>,
    <0.1111111, -167.3313235>,
    <0.1151607, -167.3028339>,
    <0.8726794, -167.3940515>,
    <0.8796296, -167.4137323>,
    <0.8749667, -167.4397221>,
    <0.8611111, -167.3613758>,
    <0.8750100, -167.3613758>,
    <0.8770037, -167.4283682>,
    <0.8671664, -167.3956156>,
    <0.8671935, -167.3613758>,
    <0.8770294, -167.3842624>,
    <0.8831044, -167.3939086>,
    <0.8796296, -167.4137323>,
    <0.8750100, -167.3613758>,
    <0.8888889, -167.3613758>,
    <0.8888889, -167.4391507>,
    <0.8770294, -167.3842624>,
    <0.8828169, -167.3613758>,
    <0.8888889, -167.3955180>,
    <0.8848338, -167.4280187>,
    <0.8830935, -167.4527626>,
    <0.8796296, -167.4137323>,
    <0.8888889, -167.4391507>,
    <0.8888889, -167.5184453>,
    <0.8749667, -167.4397221>,
    <0.8848338, -167.4280187>,
    <0.8888889, -167.4838674>,
    <0.8827902, -167.4839601>,
    <0.8770037, -167.4283682>,
    <0.8668877, -167.2819570>,
    <0.8703704, -167.3161845>,
    <0.8611111, -167.2924560>,
    <0.8611111, -167.2258020>,
    <0.8749584, -167.2933857>,
    <0.8651608, -167.3028339>,
    <0.8611111, -167.2550533>,
    <0.8671610, -167.2553296>,
    <0.8729525, -167.3033535>,
    <0.8773069, -167.3330804>,
    <0.8703704, -167.3161845>,
    <0.8749584, -167.2933857>,
    <0.8888889, -167.3613758>,
    <0.8750100, -167.3613758>,
    <0.8729525, -167.3033535>,
    <0.8827847, -167.3315832>,
    <0.8828169, -167.3613758>,
    <0.8729822, -167.3416247>,
    <0.8669007, -167.3328480>,
    <0.8703704, -167.3161845>,
    <0.8750100, -167.3613758>,
    <0.8611111, -167.3613758>,
    <0.8611111, -167.2924560>,
    <0.8729822, -167.3416247>,
    <0.8671935, -167.3613758>,
    <0.8611111, -167.3313235>,
    <0.8651608, -167.3028339>,
    <0.1226798, -167.4553644>,
    <0.1296296, -167.4732541>,
    <0.1250090, -167.4256532>,
    <0.1111111, -167.4256532>,
    <0.1249694, -167.4968970>,
    <0.1270286, -167.4464590>,
    <0.1171930, -167.4256532>,
    <0.1171682, -167.4567920>,
    <0.1270054, -167.4865678>,
    <0.1330942, -167.5086990>,
    <0.1296296, -167.4732541>,
    <0.1249694, -167.4968970>,
    <0.1388889, -167.5684558>,
    <0.1388889, -167.4961890>,
    <0.1270054, -167.4865678>,
    <0.1327919, -167.5371117>,
    <0.1388889, -167.5369298>,
    <0.1348340, -167.4861453>,
    <0.1331041, -167.4551874>,
    <0.1296296, -167.4732541>,
    <0.1388889, -167.4961890>,
    <0.1388889, -167.4256532>,
    <0.1250090, -167.4256532>,
    <0.1348340, -167.4861453>,
    <0.1388889, -167.4566011>,
    <0.1328163, -167.4256532>,
    <0.1270286, -167.4464590>,
    <0.1168905, -167.4848985>,
    <0.1203704, -167.5208549>,
    <0.1249694, -167.4968970>,
    <0.1111111, -167.4256532>,
    <0.1111111, -167.4961890>,
    <0.1229589, -167.5073705>,
    <0.1171682, -167.4567920>,
    <0.1111111, -167.4566011>,
    <0.1151615, -167.5069791>,
    <0.1168999, -167.5384889>,
    <0.1203704, -167.5208549>,
    <0.1111111, -167.4961890>,
    <0.1111111, -167.5684558>,
    <0.1250071, -167.5684558>,
    <0.1151615, -167.5069791>,
    <0.1111111, -167.5369298>,
    <0.1171920, -167.5684558>,
    <0.1229806, -167.5476517>,
    <0.1273089, -167.5386659>,
    <0.1203704, -167.5208549>,
    <0.1250071, -167.5684558>,
    <0.1388889, -167.5684558>,
    <0.1249694, -167.4968970>,
    <0.1229806, -167.5476517>,
    <0.1328154, -167.5684558>,
    <0.1327919, -167.5371117>,
    <0.1229589, -167.5073705>,
    <0.8726814, -167.6013336>,
    <0.8796296, -167.6211112>,
    <0.8750071, -167.5684558>,
    <0.8611111, -167.5684558>,
    <0.8749776, -167.6473117>,
    <0.8770277, -167.5914725>,
    <0.8671920, -167.5684558>,
    <0.8671736, -167.6029317>,
    <0.8770101, -167.6358644>,
    <0.8830963, -167.6604338>,
    <0.8796296, -167.6211112>,
    <0.8749776, -167.6473117>,
    <0.8888889, -167.7264218>,
    <0.8888889, -167.6468904>,
    <0.8770101, -167.6358644>,
    <0.8827973, -167.6917804>,
    <0.8888889, -167.6917086>,
    <0.8848346, -167.6356026>,
    <0.8831036, -167.6012283>,
    <0.8796296, -167.6211112>,
    <0.8888889, -167.6468904>,
    <0.8888889, -167.5684558>,
    <0.8750071, -167.5684558>,
    <0.8848346, -167.6356026>,
    <0.8888889, -167.6028579>,
    <0.8828154, -167.5684558>,
    <0.8770277, -167.5914725>,
    <0.8668905, -167.4848985>,
    <0.8703704, -167.5208549>,
    <0.8749694, -167.4968970>,
    <0.8611111, -167.4256532>,
    <0.8611111, -167.4961890>,
    <0.8729589, -167.5073705>,
    <0.8671682, -167.4567920>,
    <0.8611111, -167.4566011>,
    <0.8651616, -167.5069791>,
    <0.8668999, -167.5384889>,
    <0.8703704, -167.5208549>,
    <0.8611111, -167.4961890>,
    <0.8611111, -167.5684558>,
    <0.8750071, -167.5684558>,
    <0.8651616, -167.5069791>,
    <0.8611111, -167.5369298>,
    <0.8671920, -167.5684558>,
    <0.8729806, -167.5476517>,
    <0.8773089, -167.5386659>,
    <0.8703704, -167.5208549>,
    <0.8750071, -167.5684558>,
    <0.8888889, -167.5684558>,
    <0.8749694, -167.4968970>,
    <0.8729806, -167.5476517>,
    <0.8828154, -167.5684558>,
    <0.8827919, -167.5371117>,
    <0.8729589, -167.5073705>,
    <0.1226814, -167.6013336>,
    <0.1296296, -167.6211112>,
    <0.1250071, -167.5684558>,
    <0.1111111, -167.5684558>,
    <0.1249776, -167.6473117>,
    <0.1270277, -167.5914725>,
    <0.1171920, -167.5684558>,
    <0.1171736, -167.6029317>,
    <0.1270101, -167.6358644>,
    <0.1330963, -167.6604338>,
    <0.1296296, -167.6211112>,
    <0.1249776, -167.6473117>,
    <0.1388889, -167.7264218>,
    <0.1388889, -167.6468904>,
    <0.1270101, -167.6358644>,
    <0.1327973, -167.6917804>,
    <0.1388889, -167.6917086>,
    <0.1348346, -167.6356026>,
    <0.1331036, -167.6012283>,
    <0.1296296, -167.6211112>,
    <0.1388889, -167.6468904>,
    <0.1388889, -167.5684558>,
    <0.1250071, -167.5684558>,
    <0.1348346, -167.6356026>,
    <0.1388889, -167.6028579>,
    <0.1328154, -167.5684558>,
    <0.1270277, -167.5914725>,
    <0.1168926, -167.6341061>,
    <0.1203704, -167.6737665>,
    <0.1249776, -167.6473117>,
    <0.1111111, -167.5684558>,
    <0.1111111, -167.6468904>,
    <0.1229637, -167.6588757>,
    <0.1171736, -167.6029317>,
    <0.1111111, -167.6028579>,
    <0.1151621, -167.6586490>,
    <0.1168994, -167.6933751>,
    <0.1203704, -167.6737665>,
    <0.1111111, -167.6468904>,
    <0.1111111, -167.7264218>,
    <0.1250049, -167.7264218>,
    <0.1151621, -167.6586490>,
    <0.1111111, -167.6917086>,
    <0.1171908, -167.7264218>,
    <0.1229794, -167.7034090>,
    <0.1273104, -167.6934805>,
    <0.1203704, -167.6737665>,
    <0.1250049, -167.7264218>,
    <0.1388889, -167.7264218>,
    <0.1249776, -167.6473117>,
    <0.1229794, -167.7034090>,
    <0.1328142, -167.7264218>,
    <0.1327973, -167.6917804>,
    <0.1229637, -167.6588757>,
    <0.8726679, -167.7613888>,
    <0.8796296, -167.7825485>,
    <0.8750049, -167.7264218>,
    <0.8611111, -167.7264218>,
    <0.8749259, -167.8101628>,
    <0.8770240, -167.7509260>,
    <0.8671908, -167.7264218>,
    <0.8671434, -167.7629874>,
    <0.8769811, -167.7980972>,
    <0.8830833, -167.8234824>,
    <0.8796296, -167.7825485>,
    <0.8749259, -167.8101628>,
    <0.8888889, -167.8948019>,
    <0.8888889, -167.8064163>,
    <0.8769811, -167.7980972>,
    <0.8828205, -167.8580172>,
    <0.8888889, -167.8565047>,
    <0.8848349, -167.7959662>,
    <0.8831031, -167.7604521>,
    <0.8796296, -167.7825485>,
    <0.8888889, -167.8064163>,
    <0.8888889, -167.7264218>,
    <0.8750049, -167.7264218>,
    <0.8848349, -167.7959662>,
    <0.8888889, -167.7609993>,
    <0.8828142, -167.7264218>,
    <0.8770240, -167.7509260>,
    <0.8668926, -167.6341061>,
    <0.8703704, -167.6737665>,
    <0.8749776, -167.6473117>,
    <0.8611111, -167.5684558>,
    <0.8611111, -167.6468904>,
    <0.8729637, -167.6588757>,
    <0.8671736, -167.6029317>,
    <0.8611111, -167.6028579>,
    <0.8651622, -167.6586490>,
    <0.8668994, -167.6933751>,
    <0.8703704, -167.6737665>,
    <0.8611111, -167.6468904>,
    <0.8611111, -167.7264218>,
    <0.8750049, -167.7264218>,
    <0.8651622, -167.6586490>,
    <0.8611111, -167.6917086>,
    <0.8671908, -167.7264218>,
    <0.8729794, -167.7034090>,
    <0.8773105, -167.6934805>,
    <0.8703704, -167.6737665>,
    <0.8750049, -167.7264218>,
    <0.8888889, -167.7264218>,
    <0.8749776, -167.6473117>,
    <0.8729794, -167.7034090>,
    <0.8828142, -167.7264218>,
    <0.8827973, -167.6917804>,
    <0.8729637, -167.6588757>,
    <0.1226793, -167.3940515>,
    <0.1296296, -167.4137323>,
    <0.1249667, -167.4397221>,
    <0.1111111, -167.3613758>,
    <0.1250100, -167.3613758>,
    <0.1270037, -167.4283682>,
    <0.1171664, -167.3956156>,
    <0.1171935, -167.3613758>,
    <0.1270294, -167.3842624>,
    <0.1331043, -167.3939086>,
    <0.1296296, -167.4137323>,
    <0.1250100, -167.3613758>,
    <0.1388889, -167.3613758>,
    <0.1388889, -167.4391507>,
    <0.1270294, -167.3842624>,
    <0.1328169, -167.3613758>,
    <0.1388889, -167.3955180>,
    <0.1348338, -167.4280187>,
    <0.1330935, -167.4527626>,
    <0.1296296, -167.4137323>,
    <0.1388889, -167.4391507>,
    <0.1388889, -167.5184453>,
    <0.1249667, -167.4397221>,
    <0.1348338, -167.4280187>,
    <0.1388889, -167.4838674>,
    <0.1327902, -167.4839601>,
    <0.1270037, -167.4283682>,
    <0.1168898, -167.4265843>,
    <0.1203704, -167.4660888>,
    <0.1111111, -167.4391506>,
    <0.1111111, -167.3613758>,
    <0.1249667, -167.4397221>,
    <0.1151613, -167.4509341>,
    <0.1111111, -167.3955180>,
    <0.1171664, -167.3956156>,
    <0.1229573, -167.4512490>,
    <0.1273084, -167.4856754>,
    <0.1203704, -167.4660888>,
    <0.1249667, -167.4397221>,
    <0.1388889, -167.5184453>,
    <0.1250078, -167.5184453>,
    <0.1229573, -167.4512490>,
    <0.1327902, -167.4839601>,
    <0.1328158, -167.5184453>,
    <0.1229811, -167.4955641>,
    <0.1169001, -167.4855325>,
    <0.1203704, -167.4660888>,
    <0.1250078, -167.5184453>,
    <0.1111111, -167.5184453>,
    <0.1111111, -167.4391506>,
    <0.1229811, -167.4955641>,
    <0.1171924, -167.5184453>,
    <0.1111111, -167.4838674>,
    <0.1151613, -167.4509341>,
    <0.8726811, -167.5546111>,
    <0.8796296, -167.5763713>,
    <0.8749757, -167.6051824>,
    <0.8611111, -167.5184453>,
    <0.8750079, -167.5184453>,
    <0.8770090, -167.5925951>,
    <0.8671723, -167.5563642>,
    <0.8671924, -167.5184453>,
    <0.8770283, -167.5437683>,
    <0.8831038, -167.5545331>,
    <0.8796296, -167.5763713>,
    <0.8750079, -167.5184453>,
    <0.8888889, -167.5184453>,
    <0.8888889, -167.6048705>,
    <0.8770283, -167.5437683>,
    <0.8828158, -167.5184453>,
    <0.8888889, -167.5563664>,
    <0.8848344, -167.5923911>,
    <0.8830958, -167.6196618>,
    <0.8796296, -167.5763713>,
    <0.8888889, -167.6048705>,
    <0.8888889, -167.6922232>,
    <0.8749757, -167.6051824>,
    <0.8848344, -167.5923911>,
    <0.8888889, -167.6541051>,
    <0.8827961, -167.6541068>,
    <0.8770090, -167.5925951>,
    <0.8668898, -167.4265843>,
    <0.8703704, -167.4660888>,
    <0.8611111, -167.4391506>,
    <0.8611111, -167.3613758>,
    <0.8749667, -167.4397221>,
    <0.8651614, -167.4509341>,
    <0.8611111, -167.3955180>,
    <0.8671664, -167.3956156>,
    <0.8729573, -167.4512490>,
    <0.8773085, -167.4856754>,
    <0.8703704, -167.4660888>,
    <0.8749667, -167.4397221>,
    <0.8888889, -167.5184453>,
    <0.8750079, -167.5184453>,
    <0.8729573, -167.4512490>,
    <0.8827902, -167.4839601>,
    <0.8828158, -167.5184453>,
    <0.8729812, -167.4955641>,
    <0.8669001, -167.4855325>,
    <0.8703704, -167.4660888>,
    <0.8750079, -167.5184453>,
    <0.8611111, -167.5184453>,
    <0.8611111, -167.4391506>,
    <0.8729812, -167.4955641>,
    <0.8671924, -167.5184453>,
    <0.8611111, -167.4838674>,
    <0.8651614, -167.4509341>,
    <0.1226701, -167.7614025>,
    <0.1296296, -167.7825485>,
    <0.1250049, -167.7264218>,
    <0.1111111, -167.7264218>,
    <0.1249350, -167.8102176>,
    <0.1270242, -167.7509292>,
    <0.1171908, -167.7264218>,
    <0.1171484, -167.7630179>,
    <0.1269863, -167.7981278>,
    <0.1330856, -167.8235136>,
    <0.1296296, -167.7825485>,
    <0.1249350, -167.8102176>,
    <0.1388889, -167.8948019>,
    <0.1388889, -167.8064863>,
    <0.1269863, -167.7981278>,
    <0.1328290, -167.8580687>,
    <0.1388889, -167.8566387>,
    <0.1348349, -167.7960057>,
    <0.1331031, -167.7604696>,
    <0.1296296, -167.7825485>,
    <0.1388889, -167.8064863>,
    <0.1388889, -167.7264218>,
    <0.1250049, -167.7264218>,
    <0.1348349, -167.7960057>,
    <0.1388889, -167.7610353>,
    <0.1328142, -167.7264218>,
    <0.1270242, -167.7509292>,
    <0.1168819, -167.7954512>,
    <0.1203704, -167.8386752>,
    <0.1249350, -167.8102176>,
    <0.1111111, -167.7264218>,
    <0.1111111, -167.8064902>,
    <0.1229388, -167.8226627>,
    <0.1171484, -167.7630179>,
    <0.1111111, -167.7610372>,
    <0.1151572, -167.8205543>,
    <0.1169023, -167.8586923>,
    <0.1203704, -167.8386752>,
    <0.1111111, -167.8064902>,
    <0.1111111, -167.8948019>,
    <0.1250165, -167.8948019>,
    <0.1151572, -167.8205543>,
    <0.1111111, -167.8566393>,
    <0.1170780, -167.8948019>,
    <0.1230069, -167.8705252>,
    <0.1273027, -167.8596242>,
    <0.1203704, -167.8386752>,
    <0.1250165, -167.8948019>,
    <0.1388889, -167.8948019>,
    <0.1249350, -167.8102176>,
    <0.1230069, -167.8705252>,
    <0.1329086, -167.8948019>,
    <0.1328290, -167.8580687>,
    <0.1229388, -167.8226627>,
    <0.8718073, -167.9254561>,
    <0.8796296, -167.9526834>,
    <0.8750215, -167.8948019>,
    <0.8611111, -167.8948019>,
    <0.8714668, -167.9595373>,
    <0.8771686, -167.9217712>,
    <0.8670808, -167.8948019>,
    <0.8655459, -167.9225249>,
    <0.8747241, -167.9568023>,
    <0.8822186, -167.9831943>,
    <0.8796296, -167.9526834>,
    <0.8714668, -167.9595373>,
    <0.8888889, -168.0684463>,
    <0.8888889, -167.9521104>,
    <0.8747241, -167.9568023>,
    <0.8790324, -168.0068314>,
    <0.8888889, -167.9961684>,
    <0.8850018, -167.9523510>,
    <0.8831072, -167.9235994>,
    <0.8796296, -167.9526834>,
    <0.8888889, -167.9521104>,
    <0.8888889, -167.8948019>,
    <0.8750215, -167.8948019>,
    <0.8850018, -167.9523510>,
    <0.8888889, -167.9195066>,
    <0.8829114, -167.8948019>,
    <0.8771686, -167.9217712>,
    <0.8668796, -167.7954145>,
    <0.8703704, -167.8386752>,
    <0.8749259, -167.8101628>,
    <0.8611111, -167.7264218>,
    <0.8611111, -167.8063982>,
    <0.8729328, -167.8226375>,
    <0.8671434, -167.7629874>,
    <0.8611111, -167.7609901>,
    <0.8651562, -167.8204990>,
    <0.8669035, -167.8586693>,
    <0.8703704, -167.8386752>,
    <0.8611111, -167.8063982>,
    <0.8611111, -167.8948019>,
    <0.8750215, -167.8948019>,
    <0.8651562, -167.8204990>,
    <0.8611111, -167.8564780>,
    <0.8670808, -167.8948019>,
    <0.8730065, -167.8704860>,
    <0.8773017, -167.8596105>,
    <0.8703704, -167.8386752>,
    <0.8750215, -167.8948019>,
    <0.8888889, -167.8948019>,
    <0.8749259, -167.8101628>,
    <0.8730065, -167.8704860>,
    <0.8829114, -167.8948019>,
    <0.8828205, -167.8580172>,
    <0.8729328, -167.8226375>,
    <0.1218082, -167.9254701>,
    <0.1296296, -167.9526834>,
    <0.1250165, -167.8948019>,
    <0.1111111, -167.8948019>,
    <0.1214757, -167.9595930>,
    <0.1271694, -167.9218141>,
    <0.1170780, -167.8948019>,
    <0.1155520, -167.9225627>,
    <0.1247288, -167.9568364>,
    <0.1322208, -167.9833058>,
    <0.1296296, -167.9526834>,
    <0.1214757, -167.9595930>,
    <0.1388889, -168.0684463>,
    <0.1388889, -167.9525007>,
    <0.1247288, -167.9568364>,
    <0.1290373, -168.0068620>,
    <0.1388889, -167.9962258>,
    <0.1350027, -167.9525774>,
    <0.1331060, -167.9236970>,
    <0.1296296, -167.9526834>,
    <0.1388889, -167.9525007>,
    <0.1388889, -167.8948019>,
    <0.1250165, -167.8948019>,
    <0.1350027, -167.9525774>,
    <0.1388889, -167.9196682>,
    <0.1329086, -167.8948019>,
    <0.1271694, -167.9218141>,
    <0.1160171, -167.9543626>,
    <0.1203704, -168.0105648>,
    <0.1214757, -167.9595930>,
    <0.1111111, -167.8948019>,
    <0.1111111, -167.9524907>,
    <0.1209716, -167.9828390>,
    <0.1155520, -167.9225627>,
    <0.1111111, -167.9196706>,
    <0.1153075, -167.9788105>,
    <0.1168981, -168.0249870>,
    <0.1203704, -168.0105648>,
    <0.1111111, -167.9524907>,
    <0.1111111, -168.0684463>,
    <0.1250000, -168.0684463>,
    <0.1153075, -167.9788105>,
    <0.1111111, -167.9962671>,
    <0.1180555, -168.0684463>,
    <0.1231157, -168.0448887>,
    <0.1264337, -168.0267626>,
    <0.1203704, -168.0105648>,
    <0.1250000, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1214757, -167.9595930>,
    <0.1231157, -168.0448887>,
    <0.1319444, -168.0684463>,
    <0.1290373, -168.0068620>,
    <0.1209716, -167.9828390>,
    <0.8660149, -167.9542367>,
    <0.8703704, -168.0105648>,
    <0.8714668, -167.9595373>,
    <0.8611111, -167.8948019>,
    <0.8611111, -167.9520428>,
    <0.8709668, -167.9828071>,
    <0.8655459, -167.9225249>,
    <0.8611111, -167.9194706>,
    <0.8653075, -167.9785653>,
    <0.8668982, -168.0248750>,
    <0.8703704, -168.0105648>,
    <0.8611111, -167.9520428>,
    <0.8611111, -168.0684463>,
    <0.8750000, -168.0684463>,
    <0.8653075, -167.9785653>,
    <0.8611111, -167.9961054>,
    <0.8680556, -168.0684463>,
    <0.8731155, -168.0448856>,
    <0.8764315, -168.0267487>,
    <0.8703704, -168.0105648>,
    <0.8750000, -168.0684463>,
    <0.8888889, -168.0684463>,
    <0.8714668, -167.9595373>,
    <0.8731155, -168.0448856>,
    <0.8819445, -168.0684463>,
    <0.8790324, -168.0068314>,
    <0.8709668, -167.9828071>,
    <0.1226811, -167.5546111>,
    <0.1296296, -167.5763713>,
    <0.1249757, -167.6051824>,
    <0.1111111, -167.5184453>,
    <0.1250078, -167.5184453>,
    <0.1270090, -167.5925951>,
    <0.1171723, -167.5563642>,
    <0.1171924, -167.5184453>,
    <0.1270283, -167.5437683>,
    <0.1331038, -167.5545331>,
    <0.1296296, -167.5763713>,
    <0.1250078, -167.5184453>,
    <0.1388889, -167.5184453>,
    <0.1388889, -167.6048705>,
    <0.1270283, -167.5437683>,
    <0.1328158, -167.5184453>,
    <0.1388889, -167.5563664>,
    <0.1348344, -167.5923911>,
    <0.1330958, -167.6196618>,
    <0.1296296, -167.5763713>,
    <0.1388889, -167.6048705>,
    <0.1388889, -167.6922232>,
    <0.1249757, -167.6051824>,
    <0.1348344, -167.5923911>,
    <0.1388889, -167.6541051>,
    <0.1327961, -167.6541068>,
    <0.1270090, -167.5925951>,
    <0.1168921, -167.5906989>,
    <0.1203704, -167.6342972>,
    <0.1111111, -167.6048705>,
    <0.1111111, -167.5184453>,
    <0.1249757, -167.6051824>,
    <0.1151620, -167.6177446>,
    <0.1111111, -167.5563664>,
    <0.1171723, -167.5563642>,
    <0.1229626, -167.6179095>,
    <0.1273101, -167.6559815>,
    <0.1203704, -167.6342972>,
    <0.1249757, -167.6051824>,
    <0.1388889, -167.6922232>,
    <0.1250054, -167.6922232>,
    <0.1229626, -167.6179095>,
    <0.1327961, -167.6541068>,
    <0.1328145, -167.6922232>,
    <0.1229798, -167.6669079>,
    <0.1168995, -167.6559035>,
    <0.1203704, -167.6342972>,
    <0.1250054, -167.6922232>,
    <0.1111111, -167.6922232>,
    <0.1111111, -167.6048705>,
    <0.1229798, -167.6669079>,
    <0.1171911, -167.6922232>,
    <0.1111111, -167.6541051>,
    <0.1151620, -167.6177446>,
    <0.8726671, -167.7306778>,
    <0.8796296, -167.7539575>,
    <0.8749224, -167.7843072>,
    <0.8611111, -167.6922232>,
    <0.8750054, -167.6922232>,
    <0.8769791, -167.7710467>,
    <0.8671413, -167.7324281>,
    <0.8671911, -167.6922232>,
    <0.8770244, -167.7191765>,
    <0.8831032, -167.7297425>,
    <0.8796296, -167.7539575>,
    <0.8750054, -167.6922232>,
    <0.8888889, -167.6922232>,
    <0.8888889, -167.7805659>,
    <0.8770244, -167.7191765>,
    <0.8828146, -167.6922232>,
    <0.8888889, -167.7304587>,
    <0.8848347, -167.7689154>,
    <0.8830825, -167.7990642>,
    <0.8796296, -167.7539575>,
    <0.8888889, -167.7805659>,
    <0.8888889, -167.8774261>,
    <0.8749224, -167.7843072>,
    <0.8848347, -167.7689154>,
    <0.8888889, -167.8342651>,
    <0.8827560, -167.8365361>,
    <0.8769791, -167.7710467>,
    <0.8668921, -167.5906989>,
    <0.8703704, -167.6342972>,
    <0.8611111, -167.6048705>,
    <0.8611111, -167.5184453>,
    <0.8749757, -167.6051824>,
    <0.8651620, -167.6177446>,
    <0.8611111, -167.5563664>,
    <0.8671723, -167.5563642>,
    <0.8729626, -167.6179095>,
    <0.8773101, -167.6559815>,
    <0.8703704, -167.6342972>,
    <0.8749757, -167.6051824>,
    <0.8888889, -167.6922232>,
    <0.8750054, -167.6922232>,
    <0.8729626, -167.6179095>,
    <0.8827961, -167.6541068>,
    <0.8828146, -167.6922232>,
    <0.8729798, -167.6669079>,
    <0.8668995, -167.6559035>,
    <0.8703704, -167.6342972>,
    <0.8750054, -167.6922232>,
    <0.8611111, -167.6922232>,
    <0.8611111, -167.6048705>,
    <0.8729798, -167.6669079>,
    <0.8671911, -167.6922232>,
    <0.8611111, -167.6541051>,
    <0.8651620, -167.6177446>,
    <0.1226694, -167.7306929>,
    <0.1296296, -167.7539575>,
    <0.1249315, -167.7843678>,
    <0.1111111, -167.6922232>,
    <0.1250054, -167.6922232>,
    <0.1269842, -167.7710806>,
    <0.1171463, -167.7324619>,
    <0.1171911, -167.6922232>,
    <0.1270246, -167.7191800>,
    <0.1331032, -167.7297589>,
    <0.1296296, -167.7539575>,
    <0.1250054, -167.6922232>,
    <0.1388889, -167.6922232>,
    <0.1388889, -167.7806315>,
    <0.1270246, -167.7191800>,
    <0.1328145, -167.6922232>,
    <0.1388889, -167.7304926>,
    <0.1348348, -167.7689525>,
    <0.1330847, -167.7990957>,
    <0.1296296, -167.7539575>,
    <0.1388889, -167.7806315>,
    <0.1388889, -167.8774261>,
    <0.1249315, -167.7843678>,
    <0.1348348, -167.7689525>,
    <0.1388889, -167.8343473>,
    <0.1327638, -167.8365883>,
    <0.1269842, -167.7710806>,
    <0.1168810, -167.7682295>,
    <0.1203704, -167.8156918>,
    <0.1111111, -167.7806351>,
    <0.1111111, -167.6922232>,
    <0.1249315, -167.7843678>,
    <0.1151570, -167.7959532>,
    <0.1111111, -167.7304944>,
    <0.1171463, -167.7324619>,
    <0.1229371, -167.7980644>,
    <0.1273019, -167.8387279>,
    <0.1203704, -167.8156918>,
    <0.1249315, -167.7843678>,
    <0.1388889, -167.8774261>,
    <0.1250168, -167.8774261>,
    <0.1229371, -167.7980644>,
    <0.1327638, -167.8365883>,
    <0.1328172, -167.8774261>,
    <0.1229820, -167.8503915>,
    <0.1169023, -167.8377947>,
    <0.1203704, -167.8156918>,
    <0.1250168, -167.8774261>,
    <0.1111111, -167.8774261>,
    <0.1111111, -167.7806351>,
    <0.1229820, -167.8503915>,
    <0.1172003, -167.8774261>,
    <0.1111111, -167.8343518>,
    <0.1151570, -167.7959532>,
    <0.8725606, -167.9163276>,
    <0.8796296, -167.9410995>,
    <0.8744798, -167.9693587>,
    <0.8611111, -167.8774261>,
    <0.8750218, -167.8774261>,
    <0.8767166, -167.9570846>,
    <0.8668909, -167.9171719>,
    <0.8672029, -167.8774261>,
    <0.8770334, -167.9052236>,
    <0.8831073, -167.9153162>,
    <0.8796296, -167.9410995>,
    <0.8750218, -167.8774261>,
    <0.8888889, -167.8774261>,
    <0.8888889, -167.9653134>,
    <0.8770334, -167.9052236>,
    <0.8828198, -167.8774261>,
    <0.8888889, -167.9162189>,
    <0.8848232, -167.9546813>,
    <0.8829718, -167.9860545>,
    <0.8796296, -167.9410995>,
    <0.8888889, -167.9653134>,
    <0.8888889, -168.0684463>,
    <0.8744798, -167.9693587>,
    <0.8848232, -167.9546813>,
    <0.8888889, -168.0212495>,
    <0.8823887, -168.0237465>,
    <0.8767166, -167.9570846>,
    <0.8668788, -167.7681928>,
    <0.8703704, -167.8156918>,
    <0.8611111, -167.7805491>,
    <0.8611111, -167.6922232>,
    <0.8749224, -167.7843072>,
    <0.8651560, -167.7959009>,
    <0.8611111, -167.7304500>,
    <0.8671413, -167.7324281>,
    <0.8729311, -167.7980365>,
    <0.8773009, -167.8387128>,
    <0.8703704, -167.8156918>,
    <0.8749224, -167.7843072>,
    <0.8888889, -167.8774261>,
    <0.8750218, -167.8774261>,
    <0.8729311, -167.7980365>,
    <0.8827560, -167.8365361>,
    <0.8828198, -167.8774261>,
    <0.8729818, -167.8503512>,
    <0.8669036, -167.8377732>,
    <0.8703704, -167.8156918>,
    <0.8750218, -167.8774261>,
    <0.8611111, -167.8774261>,
    <0.8611111, -167.7805491>,
    <0.8729818, -167.8503512>,
    <0.8672029, -167.8774261>,
    <0.8611111, -167.8342438>,
    <0.8651560, -167.7959009>,
    <0.1226307, -167.9168186>,
    <0.1296296, -167.9410995>,
    <0.1247654, -167.9713228>,
    <0.1111111, -167.8774261>,
    <0.1250168, -167.8774261>,
    <0.1268825, -167.9581686>,
    <0.1170547, -167.9182984>,
    <0.1172003, -167.8774261>,
    <0.1270414, -167.9053731>,
    <0.1331060, -167.9150103>,
    <0.1296296, -167.9410995>,
    <0.1250168, -167.8774261>,
    <0.1388889, -167.8774261>,
    <0.1388889, -167.9640898>,
    <0.1270414, -167.9053731>,
    <0.1328172, -167.8774261>,
    <0.1388889, -167.9157136>,
    <0.1348286, -167.9540084>,
    <0.1330432, -167.9862396>,
    <0.1296296, -167.9410995>,
    <0.1388889, -167.9640898>,
    <0.1388889, -168.0684463>,
    <0.1247654, -167.9713228>,
    <0.1348286, -167.9540084>,
    <0.1388889, -168.0181340>,
    <0.1326510, -168.0255501>,
    <0.1268825, -167.9581686>,
    <0.1168395, -167.9544858>,
    <0.1203704, -168.0047729>,
    <0.1111111, -167.9644214>,
    <0.1111111, -167.8774261>,
    <0.1247654, -167.9713228>,
    <0.1151094, -167.9818459>,
    <0.1111111, -167.9158322>,
    <0.1170547, -167.9182984>,
    <0.1228061, -167.9862350>,
    <0.1274299, -168.0282471>,
    <0.1203704, -168.0047729>,
    <0.1247654, -167.9713228>,
    <0.1388889, -168.0684463>,
    <0.1256949, -168.0684463>,
    <0.1228061, -167.9862350>,
    <0.1326510, -168.0255501>,
    <0.1335260, -168.0684463>,
    <0.1231181, -168.0376314>,
    <0.1170719, -168.0265217>,
    <0.1203704, -168.0047729>,
    <0.1256949, -168.0684463>,
    <0.1111111, -168.0684463>,
    <0.1111111, -167.9644214>,
    <0.1231181, -168.0376314>,
    <0.1173585, -168.0684463>,
    <0.1111111, -168.0195758>,
    <0.1151094, -167.9818459>,
    <0.8667681, -167.9544102>,
    <0.8703704, -168.0047729>,
    <0.8611111, -167.9660833>,
    <0.8611111, -167.8774261>,
    <0.8744798, -167.9693587>,
    <0.8650601, -167.9825838>,
    <0.8611111, -167.9166169>,
    <0.8668909, -167.9171719>,
    <0.8726167, -167.9854143>,
    <0.8775328, -168.0277560>,
    <0.8703704, -168.0047729>,
    <0.8744798, -167.9693587>,
    <0.8888889, -168.0684463>,
    <0.8763923, -168.0684463>,
    <0.8726167, -167.9854143>,
    <0.8823887, -168.0237465>,
    <0.8838453, -168.0684463>,
    <0.8731820, -168.0345013>,
    <0.8672462, -168.0269372>,
    <0.8703704, -168.0047729>,
    <0.8763923, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8611111, -167.9660833>,
    <0.8731820, -168.0345013>,
    <0.8678243, -168.0684463>,
    <0.8611111, -168.0222355>,
    <0.8650601, -167.9825838>,
    <0.1453274, -167.1108664>,
    <0.1430488, -167.1123151>,
    <0.1418213, -167.1229615>,
    <0.1513685, -167.1040945>,
    <0.1450712, -167.1040945>,
    <0.1423135, -167.1186928>,
    <0.1452924, -167.1161019>,
    <0.1481978, -167.1040945>,
    <0.1443179, -167.1071565>,
    <0.1414744, -167.1100470>,
    <0.1430488, -167.1123151>,
    <0.1450712, -167.1040945>,
    <0.1388889, -167.1040945>,
    <0.1388889, -167.1196840>,
    <0.1443179, -167.1071565>,
    <0.1419729, -167.1040945>,
    <0.1388889, -167.1103669>,
    <0.1407556, -167.1163772>,
    <0.1406620, -167.1209293>,
    <0.1430488, -167.1123151>,
    <0.1388889, -167.1196840>,
    <0.1388889, -167.1287564>,
    <0.1418213, -167.1229615>,
    <0.1407556, -167.1163772>,
    <0.1388889, -167.1261994>,
    <0.1400007, -167.1265592>,
    <0.1423135, -167.1186928>,
    <0.8533249, -167.1109163>,
    <0.8560118, -167.1123151>,
    <0.8538344, -167.1040945>,
    <0.8458132, -167.1040945>,
    <0.8576403, -167.1231611>,
    <0.8546778, -167.1072788>,
    <0.8499797, -167.1040945>,
    <0.8535331, -167.1165399>,
    <0.8569725, -167.1187137>,
    <0.8589686, -167.1209772>,
    <0.8560118, -167.1123151>,
    <0.8576403, -167.1231611>,
    <0.8611111, -167.1287564>,
    <0.8611111, -167.1196763>,
    <0.8569725, -167.1187137>,
    <0.8598310, -167.1266928>,
    <0.8611111, -167.1261977>,
    <0.8587421, -167.1162565>,
    <0.8580171, -167.1100451>,
    <0.8560118, -167.1123151>,
    <0.8611111, -167.1196763>,
    <0.8611111, -167.1040945>,
    <0.8538344, -167.1040945>,
    <0.8587421, -167.1162565>,
    <0.8611111, -167.1103597>,
    <0.8575155, -167.1040945>,
    <0.8546778, -167.1072788>,
    <0.8518383, -167.0790980>,
    <0.8556582, -167.0842391>,
    <0.8540108, -167.0952605>,
    <0.8447523, -167.0684463>,
    <0.8529317, -167.0684463>,
    <0.8546700, -167.0908500>,
    <0.8491894, -167.0812969>,
    <0.8488420, -167.0684463>,
    <0.8541145, -167.0752973>,
    <0.8577030, -167.0791497>,
    <0.8556582, -167.0842391>,
    <0.8529317, -167.0684463>,
    <0.8611111, -167.0684463>,
    <0.8611111, -167.0954672>,
    <0.8541145, -167.0752973>,
    <0.8570214, -167.0684463>,
    <0.8611111, -167.0824309>,
    <0.8587954, -167.0906989>,
    <0.8579728, -167.0976979>,
    <0.8556582, -167.0842391>,
    <0.8611111, -167.0954672>,
    <0.8611111, -167.1158246>,
    <0.8540108, -167.0952605>,
    <0.8587954, -167.0906989>,
    <0.8611111, -167.1101308>,
    <0.8583030, -167.1076919>,
    <0.8546700, -167.0908500>,
    <0.1646190, -167.1106496>,
    <0.1654300, -167.1123151>,
    <0.1644246, -167.1040945>,
    <0.1629568, -167.1040945>,
    <0.1656645, -167.1220941>,
    <0.1648549, -167.1076129>,
    <0.1635996, -167.1040945>,
    <0.1644164, -167.1137977>,
    <0.1655812, -167.1186208>,
    <0.1661070, -167.1197235>,
    <0.1654300, -167.1123151>,
    <0.1656645, -167.1220941>,
    <0.1666667, -167.1287564>,
    <0.1666667, -167.1157282>,
    <0.1655812, -167.1186208>,
    <0.1663819, -167.1268636>,
    <0.1666667, -167.1243298>,
    <0.1661716, -167.1143619>,
    <0.1657970, -167.1090581>,
    <0.1654300, -167.1123151>,
    <0.1666667, -167.1157282>,
    <0.1666667, -167.1040945>,
    <0.1644246, -167.1040945>,
    <0.1661716, -167.1143619>,
    <0.1666667, -167.1077212>,
    <0.1654763, -167.1040945>,
    <0.1648549, -167.1076129>,
    <0.1613804, -167.1106496>,
    <0.1603307, -167.1123151>,
    <0.1656645, -167.1220941>,
    <0.1629568, -167.1040945>,
    <0.1565698, -167.1040945>,
    <0.1628898, -167.1170071>,
    <0.1644164, -167.1137977>,
    <0.1595033, -167.1040945>,
    <0.1579578, -167.1071285>,
    <0.1578090, -167.1108240>,
    <0.1603307, -167.1123151>,
    <0.1565698, -167.1040945>,
    <0.1513685, -167.1040945>,
    <0.1629668, -167.1227920>,
    <0.1579578, -167.1071285>,
    <0.1538949, -167.1040945>,
    <0.1586520, -167.1158361>,
    <0.1619971, -167.1189378>,
    <0.1639072, -167.1214894>,
    <0.1603307, -167.1123151>,
    <0.1629668, -167.1227920>,
    <0.1666667, -167.1287564>,
    <0.1656645, -167.1220941>,
    <0.1619971, -167.1189378>,
    <0.1653172, -167.1265809>,
    <0.1663819, -167.1268636>,
    <0.1628898, -167.1170071>,
    <0.1521162, -167.1175959>,
    <0.1523080, -167.1205358>,
    <0.1629668, -167.1227920>,
    <0.1513685, -167.1040945>,
    <0.1418213, -167.1229615>,
    <0.1583000, -167.1218041>,
    <0.1586520, -167.1158361>,
    <0.1452924, -167.1161019>,
    <0.1466327, -167.1218485>,
    <0.1462437, -167.1252525>,
    <0.1523080, -167.1205358>,
    <0.1418213, -167.1229615>,
    <0.1388889, -167.1287564>,
    <0.1519567, -167.1287564>,
    <0.1466327, -167.1218485>,
    <0.1400007, -167.1265592>,
    <0.1442823, -167.1287564>,
    <0.1520823, -167.1258171>,
    <0.1584745, -167.1252102>,
    <0.1523080, -167.1205358>,
    <0.1519567, -167.1287564>,
    <0.1666667, -167.1287564>,
    <0.1629668, -167.1227920>,
    <0.1520823, -167.1258171>,
    <0.1602844, -167.1287564>,
    <0.1653171, -167.1265809>,
    <0.1583000, -167.1218041>,
    <0.8466775, -167.1175791>,
    <0.8467525, -167.1205421>,
    <0.8576403, -167.1231655>,
    <0.8458131, -167.1041136>,
    <0.8365042, -167.1224952>,
    <0.8530701, -167.1220643>,
    <0.8535331, -167.1165494>,
    <0.8401898, -167.1152174>,
    <0.8413931, -167.1215635>,
    <0.8407713, -167.1251375>,
    <0.8467525, -167.1205421>,
    <0.8365042, -167.1224952>,
    <0.8333333, -167.1287564>,
    <0.8464951, -167.1287564>,
    <0.8413931, -167.1215635>,
    <0.8344900, -167.1264725>,
    <0.8387464, -167.1287564>,
    <0.8465807, -167.1260244>,
    <0.8529998, -167.1253051>,
    <0.8467525, -167.1205421>,
    <0.8464951, -167.1287564>,
    <0.8611111, -167.1287564>,
    <0.8576403, -167.1231655>,
    <0.8465807, -167.1260244>,
    <0.8548191, -167.1287564>,
    <0.8598310, -167.1266944>,
    <0.8530701, -167.1220643>,
    <0.8406382, -167.1107626>,
    <0.8384455, -167.1123279>,
    <0.8365042, -167.1224952>,
    <0.8458131, -167.1041136>,
    <0.8417899, -167.1041136>,
    <0.8371971, -167.1188660>,
    <0.8401898, -167.1152174>,
    <0.8439374, -167.1041136>,
    <0.8406400, -167.1069379>,
    <0.8376941, -167.1101334>,
    <0.8384455, -167.1123279>,
    <0.8417899, -167.1041136>,
    <0.8361900, -167.1041136>,
    <0.8343509, -167.1199784>,
    <0.8406400, -167.1069379>,
    <0.8392773, -167.1041136>,
    <0.8352632, -167.1121091>,
    <0.8365057, -167.1159522>,
    <0.8356585, -167.1208895>,
    <0.8384455, -167.1123279>,
    <0.8343509, -167.1199784>,
    <0.8333333, -167.1287564>,
    <0.8365042, -167.1224952>,
    <0.8365057, -167.1159522>,
    <0.8336768, -167.1257934>,
    <0.8344900, -167.1264725>,
    <0.8371971, -167.1188660>,
    <0.8448087, -167.1443229>,
    <0.8518519, -167.1533103>,
    <0.8464951, -167.1287564>,
    <0.8333333, -167.1287564>,
    <0.8475545, -167.1664684>,
    <0.8491426, -167.1408919>,
    <0.8387464, -167.1287564>,
    <0.8396912, -167.1456163>,
    <0.8494940, -167.1605300>,
    <0.8554072, -167.1706941>,
    <0.8518519, -167.1533103>,
    <0.8475545, -167.1664684>,
    <0.8611111, -167.2024179>,
    <0.8611111, -167.1605800>,
    <0.8494940, -167.1605300>,
    <0.8552206, -167.1867974>,
    <0.8611111, -167.1838663>,
    <0.8571241, -167.1574496>,
    <0.8551423, -167.1428508>,
    <0.8518519, -167.1533103>,
    <0.8611111, -167.1605800>,
    <0.8611111, -167.1287564>,
    <0.8464951, -167.1287564>,
    <0.8571241, -167.1574496>,
    <0.8611111, -167.1409326>,
    <0.8548191, -167.1287564>,
    <0.8491426, -167.1408919>,
    <0.8349783, -167.1101299>,
    <0.8342856, -167.1123215>,
    <0.8343509, -167.1199784>,
    <0.8361901, -167.1041136>,
    <0.8350866, -167.1041062>,
    <0.8343263, -167.1170887>,
    <0.8352632, -167.1121091>,
    <0.8357116, -167.1041104>,
    <0.8347417, -167.1076438>,
    <0.8340097, -167.1098044>,
    <0.8342856, -167.1123215>,
    <0.8350866, -167.1041062>,
    <0.8333333, -167.1040945>,
    <0.8333333, -167.1186954>,
    <0.8347417, -167.1076438>,
    <0.8342701, -167.1041008>,
    <0.8333333, -167.1075966>,
    <0.8336825, -167.1163585>,
    <0.8338258, -167.1199379>,
    <0.8342856, -167.1123215>,
    <0.8333333, -167.1186954>,
    <0.8333333, -167.1287564>,
    <0.8343509, -167.1199784>,
    <0.8336825, -167.1163585>,
    <0.8333333, -167.1268389>,
    <0.8336768, -167.1257934>,
    <0.8343263, -167.1170887>,
    <0.8428368, -167.0805922>,
    <0.8464017, -167.0842391>,
    <0.8525601, -167.1012372>,
    <0.8333385, -167.0684463>,
    <0.8390469, -167.0684463>,
    <0.8504366, -167.0953760>,
    <0.8449867, -167.0883174>,
    <0.8361927, -167.0684463>,
    <0.8420011, -167.0747897>,
    <0.8460540, -167.0790980>,
    <0.8464017, -167.0842391>,
    <0.8390469, -167.0684463>,
    <0.8447554, -167.0684463>,
    <0.8540121, -167.0952605>,
    <0.8420011, -167.0747897>,
    <0.8419012, -167.0684463>,
    <0.8491916, -167.0812969>,
    <0.8502259, -167.0897773>,
    <0.8535212, -167.0991404>,
    <0.8464017, -167.0842391>,
    <0.8540121, -167.0952605>,
    <0.8611111, -167.1158246>,
    <0.8525601, -167.1012372>,
    <0.8502259, -167.0897773>,
    <0.8583036, -167.1076919>,
    <0.8576802, -167.1099717>,
    <0.8504366, -167.0953760>,
    <0.1503600, -167.1443739>,
    <0.1574074, -167.1533103>,
    <0.1519567, -167.1287564>,
    <0.1388889, -167.1287564>,
    <0.1531871, -167.1666726>,
    <0.1546413, -167.1408500>,
    <0.1442823, -167.1287564>,
    <0.1453151, -167.1457976>,
    <0.1550874, -167.1606560>,
    <0.1609820, -167.1707791>,
    <0.1574074, -167.1533103>,
    <0.1531871, -167.1666726>,
    <0.1666667, -167.2024179>,
    <0.1666667, -167.1607154>,
    <0.1550874, -167.1606560>,
    <0.1608174, -167.1869067>,
    <0.1666667, -167.1838308>,
    <0.1626839, -167.1575302>,
    <0.1606743, -167.1428846>,
    <0.1574074, -167.1533103>,
    <0.1666667, -167.1607154>,
    <0.1666667, -167.1287564>,
    <0.1519567, -167.1287564>,
    <0.1626839, -167.1575302>,
    <0.1666667, -167.1413913>,
    <0.1602844, -167.1287564>,
    <0.1546413, -167.1408500>,
    <0.1447782, -167.1584684>,
    <0.1481481, -167.1778641>,
    <0.1531871, -167.1666726>,
    <0.1388889, -167.1287564>,
    <0.1388889, -167.1605805>,
    <0.1509896, -167.1715532>,
    <0.1453151, -167.1457976>,
    <0.1388889, -167.1409331>,
    <0.1429437, -167.1681493>,
    <0.1446789, -167.1858201>,
    <0.1481481, -167.1778641>,
    <0.1388889, -167.1605805>,
    <0.1388889, -167.2024179>,
    <0.1527896, -167.2024179>,
    <0.1429437, -167.1681493>,
    <0.1388889, -167.1838665>,
    <0.1449723, -167.2024179>,
    <0.1507736, -167.1917530>,
    <0.1551979, -167.1873432>,
    <0.1481481, -167.1778641>,
    <0.1527896, -167.2024179>,
    <0.1666667, -167.2024179>,
    <0.1531871, -167.1666726>,
    <0.1507736, -167.1917530>,
    <0.1605955, -167.2024179>,
    <0.1608174, -167.1869067>,
    <0.1509896, -167.1715532>,
    <0.8448992, -167.2232074>,
    <0.8518519, -167.2357456>,
    <0.8472340, -167.2024179>,
    <0.8333333, -167.2024179>,
    <0.8471775, -167.2522483>,
    <0.8492518, -167.2169804>,
    <0.8394168, -167.2024179>,
    <0.8393813, -167.2241867>,
    <0.8492196, -167.2450388>,
    <0.8553129, -167.2602946>,
    <0.8518519, -167.2357456>,
    <0.8471775, -167.2522483>,
    <0.8611111, -167.3024008>,
    <0.8611111, -167.2507837>,
    <0.8492196, -167.2450388>,
    <0.8550047, -167.2804214>,
    <0.8611111, -167.2798504>,
    <0.8570554, -167.2441968>,
    <0.8553270, -167.2228413>,
    <0.8518519, -167.2357456>,
    <0.8611111, -167.2507837>,
    <0.8611111, -167.2024179>,
    <0.8472340, -167.2024179>,
    <0.8570554, -167.2441968>,
    <0.8611111, -167.2235884>,
    <0.8550399, -167.2024179>,
    <0.8492518, -167.2169804>,
    <0.8392035, -167.1582978>,
    <0.8425926, -167.1778641>,
    <0.8475545, -167.1664684>,
    <0.8333333, -167.1287564>,
    <0.8333333, -167.1601023>,
    <0.8453914, -167.1714363>,
    <0.8396912, -167.1456163>,
    <0.8333333, -167.1407348>,
    <0.8373890, -167.1678822>,
    <0.8391233, -167.1857006>,
    <0.8425926, -167.1778641>,
    <0.8333333, -167.1601023>,
    <0.8333333, -167.2024179>,
    <0.8472340, -167.2024179>,
    <0.8373890, -167.1678822>,
    <0.8333333, -167.1835237>,
    <0.8394168, -167.2024179>,
    <0.8452156, -167.1917403>,
    <0.8496231, -167.1872921>,
    <0.8425926, -167.1778641>,
    <0.8472340, -167.2024179>,
    <0.8611111, -167.2024179>,
    <0.8475545, -167.1664684>,
    <0.8452156, -167.1917403>,
    <0.8550399, -167.2024179>,
    <0.8552206, -167.1867974>,
    <0.8453914, -167.1714363>,
    <0.1574122, -167.0791462>,
    <0.1612147, -167.0842391>,
    <0.1596341, -167.0954532>,
    <0.1503109, -167.0684463>,
    <0.1584888, -167.0684463>,
    <0.1602657, -167.0909727>,
    <0.1548056, -167.0814662>,
    <0.1543999, -167.0684463>,
    <0.1596709, -167.0752949>,
    <0.1632592, -167.0790376>,
    <0.1612147, -167.0842391>,
    <0.1584888, -167.0684463>,
    <0.1666667, -167.0684463>,
    <0.1666667, -167.0950187>,
    <0.1596709, -167.0752949>,
    <0.1625777, -167.0684463>,
    <0.1666667, -167.0820954>,
    <0.1643540, -167.0904460>,
    <0.1635455, -167.0976339>,
    <0.1612147, -167.0842391>,
    <0.1666667, -167.0950187>,
    <0.1666667, -167.1158246>,
    <0.1596341, -167.0954532>,
    <0.1643540, -167.0904460>,
    <0.1666667, -167.1099562>,
    <0.1638970, -167.1078017>,
    <0.1602657, -167.0909727>,
    <0.1483794, -167.0805759>,
    <0.1519545, -167.0842391>,
    <0.1580759, -167.1011721>,
    <0.1388889, -167.0684463>,
    <0.1445984, -167.0684463>,
    <0.1559566, -167.0953097>,
    <0.1504829, -167.0882213>,
    <0.1417436, -167.0684463>,
    <0.1475510, -167.0747853>,
    <0.1516234, -167.0791462>,
    <0.1519545, -167.0842391>,
    <0.1445984, -167.0684463>,
    <0.1503079, -167.0684463>,
    <0.1596328, -167.0954532>,
    <0.1475510, -167.0747853>,
    <0.1474531, -167.0684463>,
    <0.1548034, -167.0814662>,
    <0.1558103, -167.0898704>,
    <0.1590825, -167.0991723>,
    <0.1519545, -167.0842391>,
    <0.1596328, -167.0954532>,
    <0.1666667, -167.1158246>,
    <0.1580759, -167.1011721>,
    <0.1558103, -167.0898704>,
    <0.1638965, -167.1078017>,
    <0.1632178, -167.1099422>,
    <0.1559566, -167.0953097>,
    <0.1460005, -167.0910444>,
    <0.1481481, -167.1000319>,
    <0.1388889, -167.0945275>,
    <0.1388889, -167.0684463>,
    <0.1580759, -167.1011721>,
    <0.1428876, -167.0969046>,
    <0.1388889, -167.0815943>,
    <0.1504829, -167.0882213>,
    <0.1530431, -167.1005941>,
    <0.1562746, -167.1082133>,
    <0.1481481, -167.1000319>,
    <0.1580759, -167.1011721>,
    <0.1666667, -167.1158246>,
    <0.1522077, -167.1158246>,
    <0.1530431, -167.1005941>,
    <0.1632178, -167.1099422>,
    <0.1604182, -167.1158246>,
    <0.1503151, -167.1084618>,
    <0.1445334, -167.1065522>,
    <0.1481481, -167.1000319>,
    <0.1522077, -167.1158246>,
    <0.1388889, -167.1158246>,
    <0.1388889, -167.0945275>,
    <0.1503151, -167.1084618>,
    <0.1443823, -167.1158246>,
    <0.1388889, -167.1098585>,
    <0.1428876, -167.0969046>,
    <0.8446756, -167.1383984>,
    <0.8518519, -167.1524837>,
    <0.8468805, -167.1694605>,
    <0.8333333, -167.1158246>,
    <0.8466365, -167.1158246>,
    <0.8490463, -167.1620647>,
    <0.8390526, -167.1384682>,
    <0.8388190, -167.1158246>,
    <0.8488958, -167.1317052>,
    <0.8551776, -167.1378007>,
    <0.8518519, -167.1524837>,
    <0.8466365, -167.1158246>,
    <0.8611111, -167.1158246>,
    <0.8611111, -167.1670696>,
    <0.8488958, -167.1317052>,
    <0.8548525, -167.1158246>,
    <0.8611111, -167.1357705>,
    <0.8570497, -167.1606717>,
    <0.8552387, -167.1787040>,
    <0.8518519, -167.1524837>,
    <0.8611111, -167.1670696>,
    <0.8611111, -167.2258020>,
    <0.8468805, -167.1694605>,
    <0.8570497, -167.1606717>,
    <0.8611111, -167.2000469>,
    <0.8548416, -167.2009796>,
    <0.8490463, -167.1620647>,
    <0.8404545, -167.0912957>,
    <0.8425926, -167.1000319>,
    <0.8333333, -167.0954675>,
    <0.8333333, -167.0684463>,
    <0.8525585, -167.1012372>,
    <0.8373185, -167.0974320>,
    <0.8333333, -167.0825383>,
    <0.8449837, -167.0883174>,
    <0.8474885, -167.1006240>,
    <0.8507247, -167.1082296>,
    <0.8425926, -167.1000319>,
    <0.8525585, -167.1012372>,
    <0.8611111, -167.1158246>,
    <0.8466365, -167.1158246>,
    <0.8474885, -167.1006240>,
    <0.8576796, -167.1099717>,
    <0.8548525, -167.1158246>,
    <0.8447479, -167.1084489>,
    <0.8389739, -167.1067872>,
    <0.8425926, -167.1000319>,
    <0.8466365, -167.1158246>,
    <0.8333333, -167.1158246>,
    <0.8333333, -167.0954675>,
    <0.8447479, -167.1084489>,
    <0.8388190, -167.1158246>,
    <0.8333333, -167.1101239>,
    <0.8373185, -167.0974320>,
    <0.1504547, -167.2232074>,
    <0.1574074, -167.2357456>,
    <0.1527896, -167.2024179>,
    <0.1388889, -167.2024179>,
    <0.1527330, -167.2522483>,
    <0.1548073, -167.2169804>,
    <0.1449723, -167.2024179>,
    <0.1449368, -167.2241867>,
    <0.1547751, -167.2450388>,
    <0.1608684, -167.2602946>,
    <0.1574074, -167.2357456>,
    <0.1527330, -167.2522483>,
    <0.1666667, -167.3024008>,
    <0.1666667, -167.2507837>,
    <0.1547751, -167.2450388>,
    <0.1605602, -167.2804214>,
    <0.1666667, -167.2798504>,
    <0.1626110, -167.2441968>,
    <0.1608826, -167.2228413>,
    <0.1574074, -167.2357456>,
    <0.1666667, -167.2507837>,
    <0.1666667, -167.2024179>,
    <0.1527896, -167.2024179>,
    <0.1626110, -167.2441968>,
    <0.1666667, -167.2235884>,
    <0.1605955, -167.2024179>,
    <0.1548073, -167.2169804>,
    <0.1446647, -167.2436308>,
    <0.1481481, -167.2690732>,
    <0.1527330, -167.2522483>,
    <0.1388889, -167.2024179>,
    <0.1388889, -167.2507837>,
    <0.1507285, -167.2596042>,
    <0.1449368, -167.2241867>,
    <0.1388889, -167.2235884>,
    <0.1429383, -167.2587824>,
    <0.1446786, -167.2811646>,
    <0.1481481, -167.2690732>,
    <0.1388889, -167.2507837>,
    <0.1388889, -167.3024008>,
    <0.1527884, -167.3024008>,
    <0.1429383, -167.2587824>,
    <0.1388889, -167.2798504>,
    <0.1449717, -167.3024008>,
    <0.1507599, -167.2878319>,
    <0.1550840, -167.2815307>,
    <0.1481481, -167.2690732>,
    <0.1527884, -167.3024008>,
    <0.1666667, -167.3024008>,
    <0.1527330, -167.2522483>,
    <0.1507599, -167.2878319>,
    <0.1605949, -167.3024008>,
    <0.1605602, -167.2804214>,
    <0.1507285, -167.2596042>,
    <0.8449005, -167.3280360>,
    <0.8518519, -167.3434849>,
    <0.8472328, -167.3024008>,
    <0.8333333, -167.3024008>,
    <0.8471840, -167.3638575>,
    <0.8492515, -167.3203558>,
    <0.8394161, -167.3024008>,
    <0.8393855, -167.3292549>,
    <0.8492233, -167.3549573>,
    <0.8553145, -167.3739447>,
    <0.8518519, -167.3434849>,
    <0.8471840, -167.3638575>,
    <0.8611111, -167.4256532>,
    <0.8611111, -167.3627833>,
    <0.8492233, -167.3549573>,
    <0.8550091, -167.3985780>,
    <0.8611111, -167.3982231>,
    <0.8570558, -167.3543311>,
    <0.8553267, -167.3277674>,
    <0.8518519, -167.3434849>,
    <0.8611111, -167.3627833>,
    <0.8611111, -167.3024008>,
    <0.8472328, -167.3024008>,
    <0.8570558, -167.3543311>,
    <0.8611111, -167.3288803>,
    <0.8550394, -167.3024008>,
    <0.8492515, -167.3203558>,
    <0.8391092, -167.2436308>,
    <0.8425926, -167.2690732>,
    <0.8471775, -167.2522483>,
    <0.8333333, -167.2024179>,
    <0.8333333, -167.2507837>,
    <0.8451729, -167.2596042>,
    <0.8393813, -167.2241867>,
    <0.8333333, -167.2235884>,
    <0.8373828, -167.2587824>,
    <0.8391230, -167.2811646>,
    <0.8425926, -167.2690732>,
    <0.8333333, -167.2507837>,
    <0.8333333, -167.3024008>,
    <0.8472328, -167.3024008>,
    <0.8373828, -167.2587824>,
    <0.8333333, -167.2798504>,
    <0.8394161, -167.3024008>,
    <0.8452044, -167.2878319>,
    <0.8495285, -167.2815307>,
    <0.8425926, -167.2690732>,
    <0.8472328, -167.3024008>,
    <0.8611111, -167.3024008>,
    <0.8471775, -167.2522483>,
    <0.8452044, -167.2878319>,
    <0.8550394, -167.3024008>,
    <0.8550047, -167.2804214>,
    <0.8451729, -167.2596042>,
    <0.1502376, -167.1384086>,
    <0.1574074, -167.1524837>,
    <0.1524464, -167.1695015>,
    <0.1388889, -167.1158246>,
    <0.1522077, -167.1158246>,
    <0.1546076, -167.1620879>,
    <0.1446175, -167.1385053>,
    <0.1443823, -167.1158246>,
    <0.1544606, -167.1317078>,
    <0.1607371, -167.1378239>,
    <0.1574074, -167.1524837>,
    <0.1522077, -167.1158246>,
    <0.1666667, -167.1158246>,
    <0.1666667, -167.1671626>,
    <0.1544606, -167.1317078>,
    <0.1604182, -167.1158246>,
    <0.1666667, -167.1358722>,
    <0.1626054, -167.1607243>,
    <0.1607968, -167.1787375>,
    <0.1574074, -167.1524837>,
    <0.1666667, -167.1671626>,
    <0.1666667, -167.2258020>,
    <0.1524464, -167.1695015>,
    <0.1626054, -167.1607243>,
    <0.1666667, -167.2000930>,
    <0.1604029, -167.2010024>,
    <0.1546076, -167.1620879>,
    <0.1445931, -167.1604533>,
    <0.1481481, -167.1891429>,
    <0.1388889, -167.1673444>,
    <0.1388889, -167.1158246>,
    <0.1524464, -167.1695015>,
    <0.1429416, -167.1768853>,
    <0.1388889, -167.1360443>,
    <0.1446175, -167.1385053>,
    <0.1505701, -167.1780754>,
    <0.1550127, -167.2025621>,
    <0.1481481, -167.1891429>,
    <0.1524464, -167.1695015>,
    <0.1666667, -167.2258020>,
    <0.1527895, -167.2258020>,
    <0.1505701, -167.1780754>,
    <0.1604029, -167.2010024>,
    <0.1605955, -167.2258020>,
    <0.1507521, -167.2097095>,
    <0.1446789, -167.2020228>,
    <0.1481481, -167.1891429>,
    <0.1527895, -167.2258020>,
    <0.1388889, -167.2258020>,
    <0.1388889, -167.1673444>,
    <0.1507521, -167.2097095>,
    <0.1449722, -167.2258020>,
    <0.1388889, -167.2001871>,
    <0.1429416, -167.1768853>,
    <0.8448999, -167.2539957>,
    <0.8518519, -167.2709932>,
    <0.8471806, -167.2933857>,
    <0.8333333, -167.2258020>,
    <0.8472340, -167.2258020>,
    <0.8492212, -167.2836036>,
    <0.8393833, -167.2553296>,
    <0.8394167, -167.2258020>,
    <0.8492523, -167.2455535>,
    <0.8553270, -167.2537633>,
    <0.8518519, -167.2709932>,
    <0.8472340, -167.2258020>,
    <0.8611111, -167.2258020>,
    <0.8611111, -167.2924560>,
    <0.8492523, -167.2455535>,
    <0.8550400, -167.2258020>,
    <0.8611111, -167.2550533>,
    <0.8570555, -167.2830552>,
    <0.8553137, -167.3045527>,
    <0.8518519, -167.2709932>,
    <0.8611111, -167.2924560>,
    <0.8611111, -167.3613758>,
    <0.8471806, -167.2933857>,
    <0.8570555, -167.2830552>,
    <0.8611111, -167.3313235>,
    <0.8550069, -167.3315832>,
    <0.8492212, -167.2836036>,
    <0.8390350, -167.1603744>,
    <0.8425926, -167.1891429>,
    <0.8333333, -167.1670695>,
    <0.8333333, -167.1158246>,
    <0.8468805, -167.1694605>,
    <0.8373862, -167.1767312>,
    <0.8333333, -167.1357703>,
    <0.8390526, -167.1384682>,
    <0.8450088, -167.1780519>,
    <0.8494546, -167.2025518>,
    <0.8425926, -167.1891429>,
    <0.8468805, -167.1694605>,
    <0.8611111, -167.2258020>,
    <0.8472340, -167.2258020>,
    <0.8450088, -167.1780519>,
    <0.8548416, -167.2009796>,
    <0.8550400, -167.2258020>,
    <0.8451962, -167.2097068>,
    <0.8391233, -167.2019541>,
    <0.8425926, -167.1891429>,
    <0.8472340, -167.2258020>,
    <0.8333333, -167.2258020>,
    <0.8333333, -167.1670695>,
    <0.8451962, -167.2097068>,
    <0.8394167, -167.2258020>,
    <0.8333333, -167.2000468>,
    <0.8373862, -167.1767312>,
    <0.1504561, -167.3280360>,
    <0.1574074, -167.3434849>,
    <0.1527884, -167.3024008>,
    <0.1388889, -167.3024008>,
    <0.1527396, -167.3638575>,
    <0.1548070, -167.3203558>,
    <0.1449717, -167.3024008>,
    <0.1449411, -167.3292549>,
    <0.1547788, -167.3549573>,
    <0.1608701, -167.3739447>,
    <0.1574074, -167.3434849>,
    <0.1527396, -167.3638575>,
    <0.1666667, -167.4256532>,
    <0.1666667, -167.3627833>,
    <0.1547788, -167.3549573>,
    <0.1605646, -167.3985780>,
    <0.1666667, -167.3982231>,
    <0.1626113, -167.3543311>,
    <0.1608823, -167.3277674>,
    <0.1574074, -167.3434849>,
    <0.1666667, -167.3627833>,
    <0.1666667, -167.3024008>,
    <0.1527884, -167.3024008>,
    <0.1626113, -167.3543311>,
    <0.1666667, -167.3288803>,
    <0.1605949, -167.3024008>,
    <0.1548070, -167.3203558>,
    <0.1446664, -167.3534027>,
    <0.1481481, -167.3845690>,
    <0.1527396, -167.3638575>,
    <0.1388889, -167.3024008>,
    <0.1388889, -167.3627833>,
    <0.1507323, -167.3729124>,
    <0.1449411, -167.3292549>,
    <0.1388889, -167.3288803>,
    <0.1429388, -167.3723121>,
    <0.1446782, -167.3996647>,
    <0.1481481, -167.3845690>,
    <0.1388889, -167.3627833>,
    <0.1388889, -167.4256532>,
    <0.1527868, -167.4256532>,
    <0.1429388, -167.3723121>,
    <0.1388889, -167.3982231>,
    <0.1449708, -167.4256532>,
    <0.1507593, -167.4076960>,
    <0.1550853, -167.3999332>,
    <0.1481481, -167.3845690>,
    <0.1527868, -167.4256532>,
    <0.1666667, -167.4256532>,
    <0.1527396, -167.3638575>,
    <0.1507593, -167.4076960>,
    <0.1605941, -167.4256532>,
    <0.1605646, -167.3985780>,
    <0.1507323, -167.3729124>,
    <0.8449020, -167.4553644>,
    <0.8518519, -167.4732541>,
    <0.8472312, -167.4256532>,
    <0.8333333, -167.4256532>,
    <0.8471916, -167.4968970>,
    <0.8492509, -167.4464590>,
    <0.8394153, -167.4256532>,
    <0.8393904, -167.4567920>,
    <0.8492276, -167.4865678>,
    <0.8553164, -167.5086990>,
    <0.8518519, -167.4732541>,
    <0.8471916, -167.4968970>,
    <0.8611111, -167.5684558>,
    <0.8611111, -167.4961890>,
    <0.8492276, -167.4865678>,
    <0.8550141, -167.5371117>,
    <0.8611111, -167.5369298>,
    <0.8570563, -167.4861453>,
    <0.8553263, -167.4551874>,
    <0.8518519, -167.4732541>,
    <0.8611111, -167.4961890>,
    <0.8611111, -167.4256532>,
    <0.8472312, -167.4256532>,
    <0.8570563, -167.4861453>,
    <0.8611111, -167.4566011>,
    <0.8550386, -167.4256532>,
    <0.8492509, -167.4464590>,
    <0.8391108, -167.3534027>,
    <0.8425926, -167.3845690>,
    <0.8471840, -167.3638575>,
    <0.8333333, -167.3024008>,
    <0.8333333, -167.3627833>,
    <0.8451767, -167.3729124>,
    <0.8393855, -167.3292549>,
    <0.8333333, -167.3288803>,
    <0.8373832, -167.3723121>,
    <0.8391226, -167.3996647>,
    <0.8425926, -167.3845690>,
    <0.8333333, -167.3627833>,
    <0.8333333, -167.4256532>,
    <0.8472312, -167.4256532>,
    <0.8373832, -167.3723121>,
    <0.8333333, -167.3982231>,
    <0.8394153, -167.4256532>,
    <0.8452038, -167.4076960>,
    <0.8495297, -167.3999332>,
    <0.8425926, -167.3845690>,
    <0.8472312, -167.4256532>,
    <0.8611111, -167.4256532>,
    <0.8471840, -167.3638575>,
    <0.8452038, -167.4076960>,
    <0.8550386, -167.4256532>,
    <0.8550091, -167.3985780>,
    <0.8451767, -167.3729124>,
    <0.1504555, -167.2539957>,
    <0.1574074, -167.2709932>,
    <0.1527361, -167.2933857>,
    <0.1388889, -167.2258020>,
    <0.1527895, -167.2258020>,
    <0.1547768, -167.2836036>,
    <0.1449388, -167.2553296>,
    <0.1449722, -167.2258020>,
    <0.1548078, -167.2455535>,
    <0.1608826, -167.2537633>,
    <0.1574074, -167.2709932>,
    <0.1527895, -167.2258020>,
    <0.1666667, -167.2258020>,
    <0.1666667, -167.2924560>,
    <0.1548078, -167.2455535>,
    <0.1605955, -167.2258020>,
    <0.1666667, -167.2550533>,
    <0.1626110, -167.2830552>,
    <0.1608692, -167.3045527>,
    <0.1574074, -167.2709932>,
    <0.1666667, -167.2924560>,
    <0.1666667, -167.3613758>,
    <0.1527361, -167.2933857>,
    <0.1626110, -167.2830552>,
    <0.1666667, -167.3313235>,
    <0.1605624, -167.3315832>,
    <0.1547768, -167.2836036>,
    <0.1446655, -167.2819570>,
    <0.1481481, -167.3161845>,
    <0.1388889, -167.2924560>,
    <0.1388889, -167.2258020>,
    <0.1527361, -167.2933857>,
    <0.1429385, -167.3028339>,
    <0.1388889, -167.2550533>,
    <0.1449388, -167.2553296>,
    <0.1507302, -167.3033535>,
    <0.1550847, -167.3330804>,
    <0.1481481, -167.3161845>,
    <0.1527361, -167.2933857>,
    <0.1666667, -167.3613758>,
    <0.1527878, -167.3613758>,
    <0.1507302, -167.3033535>,
    <0.1605624, -167.3315832>,
    <0.1605946, -167.3613758>,
    <0.1507600, -167.3416247>,
    <0.1446784, -167.3328480>,
    <0.1481481, -167.3161845>,
    <0.1527878, -167.3613758>,
    <0.1388889, -167.3613758>,
    <0.1388889, -167.2924560>,
    <0.1507600, -167.3416247>,
    <0.1449713, -167.3613758>,
    <0.1388889, -167.3313235>,
    <0.1429385, -167.3028339>,
    <0.8449016, -167.3940515>,
    <0.8518519, -167.4137323>,
    <0.8471889, -167.4397221>,
    <0.8333333, -167.3613758>,
    <0.8472322, -167.3613758>,
    <0.8492260, -167.4283682>,
    <0.8393887, -167.3956156>,
    <0.8394157, -167.3613758>,
    <0.8492516, -167.3842624>,
    <0.8553266, -167.3939086>,
    <0.8518519, -167.4137323>,
    <0.8472322, -167.3613758>,
    <0.8611111, -167.3613758>,
    <0.8611111, -167.4391506>,
    <0.8492516, -167.3842624>,
    <0.8550391, -167.3613758>,
    <0.8611111, -167.3955180>,
    <0.8570560, -167.4280187>,
    <0.8553158, -167.4527626>,
    <0.8518519, -167.4137323>,
    <0.8611111, -167.4391506>,
    <0.8611111, -167.5184453>,
    <0.8471889, -167.4397221>,
    <0.8570560, -167.4280187>,
    <0.8611111, -167.4838674>,
    <0.8550124, -167.4839601>,
    <0.8492260, -167.4283682>,
    <0.8391100, -167.2819570>,
    <0.8425926, -167.3161845>,
    <0.8333333, -167.2924560>,
    <0.8333333, -167.2258020>,
    <0.8471806, -167.2933857>,
    <0.8373830, -167.3028339>,
    <0.8333333, -167.2550533>,
    <0.8393833, -167.2553296>,
    <0.8451747, -167.3033535>,
    <0.8495291, -167.3330804>,
    <0.8425926, -167.3161845>,
    <0.8471806, -167.2933857>,
    <0.8611111, -167.3613758>,
    <0.8472322, -167.3613758>,
    <0.8451747, -167.3033535>,
    <0.8550069, -167.3315832>,
    <0.8550391, -167.3613758>,
    <0.8452044, -167.3416247>,
    <0.8391229, -167.3328480>,
    <0.8425926, -167.3161845>,
    <0.8472322, -167.3613758>,
    <0.8333333, -167.3613758>,
    <0.8333333, -167.2924560>,
    <0.8452044, -167.3416247>,
    <0.8394157, -167.3613758>,
    <0.8333333, -167.3313235>,
    <0.8373830, -167.3028339>,
    <0.1504575, -167.4553644>,
    <0.1574074, -167.4732541>,
    <0.1527868, -167.4256532>,
    <0.1388889, -167.4256532>,
    <0.1527471, -167.4968970>,
    <0.1548064, -167.4464590>,
    <0.1449708, -167.4256532>,
    <0.1449460, -167.4567920>,
    <0.1547831, -167.4865678>,
    <0.1608720, -167.5086990>,
    <0.1574074, -167.4732541>,
    <0.1527471, -167.4968970>,
    <0.1666667, -167.5684558>,
    <0.1666667, -167.4961890>,
    <0.1547831, -167.4865678>,
    <0.1605696, -167.5371117>,
    <0.1666667, -167.5369298>,
    <0.1626118, -167.4861453>,
    <0.1608819, -167.4551874>,
    <0.1574074, -167.4732541>,
    <0.1666667, -167.4961890>,
    <0.1666667, -167.4256532>,
    <0.1527868, -167.4256532>,
    <0.1626118, -167.4861453>,
    <0.1666667, -167.4566011>,
    <0.1605941, -167.4256532>,
    <0.1548064, -167.4464590>,
    <0.1446683, -167.4848985>,
    <0.1481481, -167.5208549>,
    <0.1527471, -167.4968970>,
    <0.1388889, -167.4256532>,
    <0.1388889, -167.4961890>,
    <0.1507366, -167.5073705>,
    <0.1449460, -167.4567920>,
    <0.1388889, -167.4566011>,
    <0.1429393, -167.5069791>,
    <0.1446777, -167.5384889>,
    <0.1481481, -167.5208549>,
    <0.1388889, -167.4961890>,
    <0.1388889, -167.5684558>,
    <0.1527848, -167.5684558>,
    <0.1429393, -167.5069791>,
    <0.1388889, -167.5369298>,
    <0.1449698, -167.5684558>,
    <0.1507584, -167.5476517>,
    <0.1550867, -167.5386659>,
    <0.1481481, -167.5208549>,
    <0.1527848, -167.5684558>,
    <0.1666667, -167.5684558>,
    <0.1527471, -167.4968970>,
    <0.1507584, -167.5476517>,
    <0.1605931, -167.5684558>,
    <0.1605696, -167.5371117>,
    <0.1507366, -167.5073705>,
    <0.8449036, -167.6013336>,
    <0.8518519, -167.6211112>,
    <0.8472293, -167.5684558>,
    <0.8333333, -167.5684558>,
    <0.8471999, -167.6473117>,
    <0.8492499, -167.5914725>,
    <0.8394142, -167.5684558>,
    <0.8393958, -167.6029317>,
    <0.8492324, -167.6358644>,
    <0.8553185, -167.6604338>,
    <0.8518519, -167.6211112>,
    <0.8471999, -167.6473117>,
    <0.8611111, -167.7264218>,
    <0.8611111, -167.6468904>,
    <0.8492324, -167.6358644>,
    <0.8550195, -167.6917804>,
    <0.8611111, -167.6917086>,
    <0.8570568, -167.6356026>,
    <0.8553259, -167.6012283>,
    <0.8518519, -167.6211112>,
    <0.8611111, -167.6468904>,
    <0.8611111, -167.5684558>,
    <0.8472293, -167.5684558>,
    <0.8570568, -167.6356026>,
    <0.8611111, -167.6028579>,
    <0.8550376, -167.5684558>,
    <0.8492499, -167.5914725>,
    <0.8391127, -167.4848985>,
    <0.8425926, -167.5208549>,
    <0.8471916, -167.4968970>,
    <0.8333333, -167.4256532>,
    <0.8333333, -167.4961891>,
    <0.8451811, -167.5073705>,
    <0.8393904, -167.4567920>,
    <0.8333333, -167.4566011>,
    <0.8373838, -167.5069791>,
    <0.8391221, -167.5384889>,
    <0.8425926, -167.5208549>,
    <0.8333333, -167.4961891>,
    <0.8333333, -167.5684558>,
    <0.8472293, -167.5684558>,
    <0.8373838, -167.5069791>,
    <0.8333333, -167.5369298>,
    <0.8394142, -167.5684558>,
    <0.8452028, -167.5476517>,
    <0.8495312, -167.5386659>,
    <0.8425926, -167.5208549>,
    <0.8472293, -167.5684558>,
    <0.8611111, -167.5684558>,
    <0.8471916, -167.4968970>,
    <0.8452028, -167.5476517>,
    <0.8550376, -167.5684558>,
    <0.8550141, -167.5371117>,
    <0.8451811, -167.5073705>,
    <0.1504591, -167.6013336>,
    <0.1574074, -167.6211112>,
    <0.1527848, -167.5684558>,
    <0.1388889, -167.5684558>,
    <0.1527554, -167.6473117>,
    <0.1548055, -167.5914725>,
    <0.1449698, -167.5684558>,
    <0.1449513, -167.6029317>,
    <0.1547879, -167.6358644>,
    <0.1608740, -167.6604338>,
    <0.1574074, -167.6211112>,
    <0.1527554, -167.6473117>,
    <0.1666667, -167.7264218>,
    <0.1666667, -167.6468904>,
    <0.1547879, -167.6358644>,
    <0.1605751, -167.6917804>,
    <0.1666667, -167.6917086>,
    <0.1626124, -167.6356026>,
    <0.1608814, -167.6012283>,
    <0.1574074, -167.6211112>,
    <0.1666667, -167.6468904>,
    <0.1666667, -167.5684558>,
    <0.1527848, -167.5684558>,
    <0.1626124, -167.6356026>,
    <0.1666667, -167.6028580>,
    <0.1605931, -167.5684558>,
    <0.1548055, -167.5914725>,
    <0.1446703, -167.6341061>,
    <0.1481481, -167.6737665>,
    <0.1527554, -167.6473117>,
    <0.1388889, -167.5684558>,
    <0.1388889, -167.6468904>,
    <0.1507415, -167.6588757>,
    <0.1449513, -167.6029317>,
    <0.1388889, -167.6028579>,
    <0.1429399, -167.6586490>,
    <0.1446771, -167.6933751>,
    <0.1481481, -167.6737665>,
    <0.1388889, -167.6468904>,
    <0.1388889, -167.7264218>,
    <0.1527826, -167.7264218>,
    <0.1429399, -167.6586490>,
    <0.1388889, -167.6917086>,
    <0.1449686, -167.7264218>,
    <0.1507571, -167.7034090>,
    <0.1550882, -167.6934805>,
    <0.1481481, -167.6737665>,
    <0.1527826, -167.7264218>,
    <0.1666667, -167.7264218>,
    <0.1527554, -167.6473117>,
    <0.1507571, -167.7034090>,
    <0.1605920, -167.7264218>,
    <0.1605751, -167.6917804>,
    <0.1507415, -167.6588757>,
    <0.8448901, -167.7613884>,
    <0.8518519, -167.7825485>,
    <0.8472271, -167.7264218>,
    <0.8333333, -167.7264218>,
    <0.8471479, -167.8101615>,
    <0.8492462, -167.7509260>,
    <0.8394131, -167.7264218>,
    <0.8393655, -167.7629867>,
    <0.8492032, -167.7980964>,
    <0.8553055, -167.8234775>,
    <0.8518519, -167.7825485>,
    <0.8471479, -167.8101615>,
    <0.8611111, -167.8948019>,
    <0.8611111, -167.8063982>,
    <0.8492032, -167.7980964>,
    <0.8550424, -167.8580156>,
    <0.8611111, -167.8564780>,
    <0.8570571, -167.7959560>,
    <0.8553253, -167.7604476>,
    <0.8518519, -167.7825485>,
    <0.8611111, -167.8063982>,
    <0.8611111, -167.7264218>,
    <0.8472271, -167.7264218>,
    <0.8570571, -167.7959560>,
    <0.8611111, -167.7609901>,
    <0.8550365, -167.7264218>,
    <0.8492462, -167.7509260>,
    <0.8391148, -167.6341061>,
    <0.8425926, -167.6737665>,
    <0.8471999, -167.6473117>,
    <0.8333333, -167.5684558>,
    <0.8333333, -167.6468904>,
    <0.8451859, -167.6588757>,
    <0.8393958, -167.6029317>,
    <0.8333333, -167.6028579>,
    <0.8373844, -167.6586490>,
    <0.8391216, -167.6933751>,
    <0.8425926, -167.6737665>,
    <0.8333333, -167.6468904>,
    <0.8333333, -167.7264218>,
    <0.8472271, -167.7264218>,
    <0.8373844, -167.6586490>,
    <0.8333333, -167.6917086>,
    <0.8394131, -167.7264218>,
    <0.8452016, -167.7034090>,
    <0.8495327, -167.6934805>,
    <0.8425926, -167.6737665>,
    <0.8472271, -167.7264218>,
    <0.8611111, -167.7264218>,
    <0.8471999, -167.6473117>,
    <0.8452016, -167.7034090>,
    <0.8550365, -167.7264218>,
    <0.8550195, -167.6917804>,
    <0.8451859, -167.6588757>,
    <0.1504571, -167.3940515>,
    <0.1574074, -167.4137323>,
    <0.1527444, -167.4397221>,
    <0.1388889, -167.3613758>,
    <0.1527878, -167.3613758>,
    <0.1547815, -167.4283682>,
    <0.1449442, -167.3956156>,
    <0.1449713, -167.3613758>,
    <0.1548071, -167.3842624>,
    <0.1608821, -167.3939086>,
    <0.1574074, -167.4137323>,
    <0.1527878, -167.3613758>,
    <0.1666667, -167.3613758>,
    <0.1666667, -167.4391507>,
    <0.1548071, -167.3842624>,
    <0.1605946, -167.3613758>,
    <0.1666667, -167.3955180>,
    <0.1626116, -167.4280187>,
    <0.1608713, -167.4527626>,
    <0.1574074, -167.4137323>,
    <0.1666667, -167.4391507>,
    <0.1666667, -167.5184453>,
    <0.1527444, -167.4397221>,
    <0.1626116, -167.4280187>,
    <0.1666667, -167.4838674>,
    <0.1605679, -167.4839601>,
    <0.1547815, -167.4283682>,
    <0.1446676, -167.4265843>,
    <0.1481481, -167.4660888>,
    <0.1388889, -167.4391507>,
    <0.1388889, -167.3613758>,
    <0.1527444, -167.4397221>,
    <0.1429391, -167.4509341>,
    <0.1388889, -167.3955180>,
    <0.1449442, -167.3956156>,
    <0.1507350, -167.4512490>,
    <0.1550862, -167.4856754>,
    <0.1481481, -167.4660888>,
    <0.1527444, -167.4397221>,
    <0.1666667, -167.5184453>,
    <0.1527856, -167.5184453>,
    <0.1507350, -167.4512490>,
    <0.1605679, -167.4839601>,
    <0.1605936, -167.5184453>,
    <0.1507589, -167.4955641>,
    <0.1446779, -167.4855325>,
    <0.1481481, -167.4660888>,
    <0.1527856, -167.5184453>,
    <0.1388889, -167.5184453>,
    <0.1388889, -167.4391507>,
    <0.1507589, -167.4955641>,
    <0.1449701, -167.5184453>,
    <0.1388889, -167.4838674>,
    <0.1429391, -167.4509341>,
    <0.8449033, -167.5546111>,
    <0.8518519, -167.5763713>,
    <0.8471979, -167.6051824>,
    <0.8333333, -167.5184453>,
    <0.8472301, -167.5184453>,
    <0.8492312, -167.5925951>,
    <0.8393945, -167.5563642>,
    <0.8394146, -167.5184453>,
    <0.8492505, -167.5437683>,
    <0.8553260, -167.5545331>,
    <0.8518519, -167.5763713>,
    <0.8472301, -167.5184453>,
    <0.8611111, -167.5184453>,
    <0.8611111, -167.6048705>,
    <0.8492505, -167.5437683>,
    <0.8550380, -167.5184453>,
    <0.8611111, -167.5563664>,
    <0.8570566, -167.5923911>,
    <0.8553180, -167.6196618>,
    <0.8518519, -167.5763713>,
    <0.8611111, -167.6048705>,
    <0.8611111, -167.6922232>,
    <0.8471979, -167.6051824>,
    <0.8570566, -167.5923911>,
    <0.8611111, -167.6541051>,
    <0.8550184, -167.6541068>,
    <0.8492312, -167.5925951>,
    <0.8391120, -167.4265843>,
    <0.8425926, -167.4660888>,
    <0.8333333, -167.4391507>,
    <0.8333333, -167.3613758>,
    <0.8471889, -167.4397221>,
    <0.8373836, -167.4509341>,
    <0.8333333, -167.3955180>,
    <0.8393887, -167.3956156>,
    <0.8451795, -167.4512490>,
    <0.8495307, -167.4856754>,
    <0.8425926, -167.4660888>,
    <0.8471889, -167.4397221>,
    <0.8611111, -167.5184453>,
    <0.8472301, -167.5184453>,
    <0.8451795, -167.4512490>,
    <0.8550124, -167.4839601>,
    <0.8550380, -167.5184453>,
    <0.8452034, -167.4955641>,
    <0.8391223, -167.4855325>,
    <0.8425926, -167.4660888>,
    <0.8472301, -167.5184453>,
    <0.8333333, -167.5184453>,
    <0.8333333, -167.4391507>,
    <0.8452034, -167.4955641>,
    <0.8394146, -167.5184453>,
    <0.8333333, -167.4838674>,
    <0.8373836, -167.4509341>,
    <0.1504482, -167.7614043>,
    <0.1574074, -167.7825485>,
    <0.1527826, -167.7264218>,
    <0.1388889, -167.7264218>,
    <0.1527139, -167.8102249>,
    <0.1548020, -167.7509296>,
    <0.1449686, -167.7264218>,
    <0.1449268, -167.7630220>,
    <0.1547647, -167.7981319>,
    <0.1608637, -167.8235137>,
    <0.1574074, -167.7825485>,
    <0.1527139, -167.8102249>,
    <0.1666667, -167.8948019>,
    <0.1666667, -167.8064793>,
    <0.1547647, -167.7981319>,
    <0.1606078, -167.8580752>,
    <0.1666667, -167.8566335>,
    <0.1626127, -167.7960018>,
    <0.1608808, -167.7604679>,
    <0.1574074, -167.7825485>,
    <0.1666667, -167.8064793>,
    <0.1666667, -167.7264218>,
    <0.1527826, -167.7264218>,
    <0.1626127, -167.7960018>,
    <0.1666667, -167.7610318>,
    <0.1605920, -167.7264218>,
    <0.1548020, -167.7509296>,
    <0.1446600, -167.7954521>,
    <0.1481481, -167.8386752>,
    <0.1527139, -167.8102249>,
    <0.1388889, -167.7264218>,
    <0.1388889, -167.8064863>,
    <0.1507174, -167.8226658>,
    <0.1449268, -167.7630220>,
    <0.1388889, -167.7610353>,
    <0.1429351, -167.8205526>,
    <0.1446799, -167.8586913>,
    <0.1481481, -167.8386752>,
    <0.1388889, -167.8064863>,
    <0.1388889, -167.8948019>,
    <0.1527936, -167.8948019>,
    <0.1429351, -167.8205526>,
    <0.1388889, -167.8566387>,
    <0.1448554, -167.8948019>,
    <0.1507846, -167.8705293>,
    <0.1550806, -167.8596260>,
    <0.1481481, -167.8386752>,
    <0.1527936, -167.8948019>,
    <0.1666667, -167.8948019>,
    <0.1527139, -167.8102249>,
    <0.1507846, -167.8705293>,
    <0.1606860, -167.8948019>,
    <0.1606078, -167.8580752>,
    <0.1507174, -167.8226658>,
    <0.8440293, -167.9254551>,
    <0.8518519, -167.9526834>,
    <0.8472438, -167.8948019>,
    <0.8333333, -167.8948019>,
    <0.8436884, -167.9595332>,
    <0.8493906, -167.9217677>,
    <0.8393030, -167.8948019>,
    <0.8377677, -167.9225222>,
    <0.8469460, -167.9567998>,
    <0.8544406, -167.9831764>,
    <0.8518519, -167.9526834>,
    <0.8436884, -167.9595332>,
    <0.8611111, -168.0684463>,
    <0.8611111, -167.9520428>,
    <0.8469460, -167.9567998>,
    <0.8512543, -168.0068292>,
    <0.8611111, -167.9961054>,
    <0.8572239, -167.9523117>,
    <0.8553295, -167.9235825>,
    <0.8518519, -167.9526834>,
    <0.8611111, -167.9520428>,
    <0.8611111, -167.8948019>,
    <0.8472438, -167.8948019>,
    <0.8572239, -167.9523117>,
    <0.8611111, -167.9194706>,
    <0.8551336, -167.8948019>,
    <0.8493906, -167.9217677>,
    <0.8391018, -167.7954096>,
    <0.8425926, -167.8386752>,
    <0.8471479, -167.8101615>,
    <0.8333333, -167.7264218>,
    <0.8333333, -167.8063797>,
    <0.8451549, -167.8226367>,
    <0.8393655, -167.7629867>,
    <0.8333333, -167.7609807>,
    <0.8373784, -167.8204885>,
    <0.8391258, -167.8586647>,
    <0.8425926, -167.8386752>,
    <0.8333333, -167.8063797>,
    <0.8333333, -167.8948019>,
    <0.8472438, -167.8948019>,
    <0.8373784, -167.8204885>,
    <0.8333333, -167.8564516>,
    <0.8393030, -167.8948019>,
    <0.8452286, -167.8704840>,
    <0.8495239, -167.8596101>,
    <0.8425926, -167.8386752>,
    <0.8472438, -167.8948019>,
    <0.8611111, -167.8948019>,
    <0.8471479, -167.8101615>,
    <0.8452286, -167.8704840>,
    <0.8551336, -167.8948019>,
    <0.8550424, -167.8580156>,
    <0.8451549, -167.8226367>,
    <0.1495860, -167.9254711>,
    <0.1574074, -167.9526834>,
    <0.1527936, -167.8948019>,
    <0.1388889, -167.8948019>,
    <0.1492541, -167.9595971>,
    <0.1549470, -167.9218173>,
    <0.1448554, -167.8948019>,
    <0.1433302, -167.9225657>,
    <0.1525070, -167.9568388>,
    <0.1599987, -167.9833062>,
    <0.1574074, -167.9526834>,
    <0.1492541, -167.9595971>,
    <0.1666667, -168.0684463>,
    <0.1666667, -167.9524981>,
    <0.1525070, -167.9568388>,
    <0.1568154, -168.0068640>,
    <0.1666667, -167.9961751>,
    <0.1627806, -167.9525759>,
    <0.1608836, -167.9236963>,
    <0.1574074, -167.9526834>,
    <0.1666667, -167.9524981>,
    <0.1666667, -167.8948019>,
    <0.1527936, -167.8948019>,
    <0.1627806, -167.9525759>,
    <0.1666667, -167.9196593>,
    <0.1606860, -167.8948019>,
    <0.1549470, -167.9218173>,
    <0.1437950, -167.9543661>,
    <0.1481481, -168.0105648>,
    <0.1492541, -167.9595971>,
    <0.1388889, -167.8948019>,
    <0.1388889, -167.9525007>,
    <0.1487497, -167.9828414>,
    <0.1433302, -167.9225657>,
    <0.1388889, -167.9196682>,
    <0.1430852, -167.9788158>,
    <0.1446759, -168.0249895>,
    <0.1481481, -168.0105648>,
    <0.1388889, -167.9525007>,
    <0.1388889, -168.0684463>,
    <0.1527778, -168.0684463>,
    <0.1430852, -167.9788158>,
    <0.1388889, -167.9962258>,
    <0.1458333, -168.0684463>,
    <0.1508935, -168.0448884>,
    <0.1542117, -168.0267636>,
    <0.1481481, -168.0105648>,
    <0.1527778, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1492541, -167.9595971>,
    <0.1508935, -168.0448884>,
    <0.1597222, -168.0684463>,
    <0.1568154, -168.0068640>,
    <0.1487497, -167.9828414>,
    <0.8382369, -167.9542192>,
    <0.8425926, -168.0105648>,
    <0.8436884, -167.9595332>,
    <0.8333333, -167.8948019>,
    <0.8333333, -167.9519769>,
    <0.8431887, -167.9828047>,
    <0.8377677, -167.9225222>,
    <0.8333333, -167.9194340>,
    <0.8375297, -167.9785291>,
    <0.8391204, -168.0248586>,
    <0.8425926, -168.0105648>,
    <0.8333333, -167.9519769>,
    <0.8333333, -168.0684463>,
    <0.8472222, -168.0684463>,
    <0.8375297, -167.9785291>,
    <0.8333333, -167.9960340>,
    <0.8402778, -168.0684463>,
    <0.8453377, -168.0448848>,
    <0.8486536, -168.0267476>,
    <0.8425926, -168.0105648>,
    <0.8472222, -168.0684463>,
    <0.8611111, -168.0684463>,
    <0.8436884, -167.9595332>,
    <0.8453377, -168.0448848>,
    <0.8541667, -168.0684463>,
    <0.8512543, -168.0068292>,
    <0.8431887, -167.9828047>,
    <0.1504588, -167.5546111>,
    <0.1574074, -167.5763713>,
    <0.1527535, -167.6051824>,
    <0.1388889, -167.5184453>,
    <0.1527856, -167.5184453>,
    <0.1547867, -167.5925951>,
    <0.1449501, -167.5563642>,
    <0.1449701, -167.5184453>,
    <0.1548061, -167.5437683>,
    <0.1608816, -167.5545331>,
    <0.1574074, -167.5763713>,
    <0.1527856, -167.5184453>,
    <0.1666667, -167.5184453>,
    <0.1666667, -167.6048705>,
    <0.1548061, -167.5437683>,
    <0.1605936, -167.5184453>,
    <0.1666667, -167.5563664>,
    <0.1626122, -167.5923911>,
    <0.1608735, -167.6196618>,
    <0.1574074, -167.5763713>,
    <0.1666667, -167.6048705>,
    <0.1666667, -167.6922232>,
    <0.1527535, -167.6051824>,
    <0.1626122, -167.5923911>,
    <0.1666667, -167.6541051>,
    <0.1605739, -167.6541068>,
    <0.1547867, -167.5925951>,
    <0.1446698, -167.5906989>,
    <0.1481481, -167.6342972>,
    <0.1388889, -167.6048705>,
    <0.1388889, -167.5184453>,
    <0.1527535, -167.6051824>,
    <0.1429398, -167.6177446>,
    <0.1388889, -167.5563664>,
    <0.1449501, -167.5563642>,
    <0.1507403, -167.6179095>,
    <0.1550879, -167.6559815>,
    <0.1481481, -167.6342972>,
    <0.1527535, -167.6051824>,
    <0.1666667, -167.6922232>,
    <0.1527832, -167.6922232>,
    <0.1507403, -167.6179095>,
    <0.1605739, -167.6541068>,
    <0.1605923, -167.6922232>,
    <0.1507575, -167.6669079>,
    <0.1446773, -167.6559035>,
    <0.1481481, -167.6342972>,
    <0.1527832, -167.6922232>,
    <0.1388889, -167.6922232>,
    <0.1388889, -167.6048705>,
    <0.1507575, -167.6669079>,
    <0.1449688, -167.6922232>,
    <0.1388889, -167.6541051>,
    <0.1429398, -167.6177446>,
    <0.8448893, -167.7306774>,
    <0.8518519, -167.7539575>,
    <0.8471444, -167.7843057>,
    <0.8333333, -167.6922232>,
    <0.8472277, -167.6922232>,
    <0.8492012, -167.7710458>,
    <0.8393634, -167.7324274>,
    <0.8394133, -167.6922232>,
    <0.8492466, -167.7191765>,
    <0.8553254, -167.7297382>,
    <0.8518519, -167.7539575>,
    <0.8472277, -167.6922232>,
    <0.8611111, -167.6922232>,
    <0.8611111, -167.7805491>,
    <0.8492466, -167.7191765>,
    <0.8550368, -167.6922232>,
    <0.8611111, -167.7304500>,
    <0.8570569, -167.7689059>,
    <0.8553046, -167.7990596>,
    <0.8518519, -167.7539575>,
    <0.8611111, -167.7805491>,
    <0.8611111, -167.8774261>,
    <0.8471444, -167.7843057>,
    <0.8570569, -167.7689059>,
    <0.8611111, -167.8342438>,
    <0.8549780, -167.8365345>,
    <0.8492012, -167.7710458>,
    <0.8391143, -167.5906989>,
    <0.8425926, -167.6342972>,
    <0.8333333, -167.6048705>,
    <0.8333333, -167.5184453>,
    <0.8471979, -167.6051824>,
    <0.8373843, -167.6177446>,
    <0.8333333, -167.5563664>,
    <0.8393945, -167.5563642>,
    <0.8451848, -167.6179095>,
    <0.8495323, -167.6559815>,
    <0.8425926, -167.6342972>,
    <0.8471979, -167.6051824>,
    <0.8611111, -167.6922232>,
    <0.8472277, -167.6922232>,
    <0.8451848, -167.6179095>,
    <0.8550184, -167.6541068>,
    <0.8550368, -167.6922232>,
    <0.8452020, -167.6669079>,
    <0.8391217, -167.6559035>,
    <0.8425926, -167.6342972>,
    <0.8472277, -167.6922232>,
    <0.8333333, -167.6922232>,
    <0.8333333, -167.6048705>,
    <0.8452020, -167.6669079>,
    <0.8394133, -167.6922232>,
    <0.8333333, -167.6541051>,
    <0.8373843, -167.6177446>,
    <0.1504475, -167.7306949>,
    <0.1574074, -167.7539575>,
    <0.1527105, -167.7843759>,
    <0.1388889, -167.6922232>,
    <0.1527832, -167.6922232>,
    <0.1547627, -167.7710851>,
    <0.1449248, -167.7324665>,
    <0.1449688, -167.6922232>,
    <0.1548024, -167.7191804>,
    <0.1608810, -167.7297573>,
    <0.1574074, -167.7539575>,
    <0.1527832, -167.6922232>,
    <0.1666667, -167.6922232>,
    <0.1666667, -167.7806251>,
    <0.1548024, -167.7191804>,
    <0.1605923, -167.6922232>,
    <0.1666667, -167.7304894>,
    <0.1626126, -167.7689489>,
    <0.1608628, -167.7990961>,
    <0.1574074, -167.7539575>,
    <0.1666667, -167.7806251>,
    <0.1666667, -167.8774261>,
    <0.1527105, -167.7843759>,
    <0.1626126, -167.7689489>,
    <0.1666667, -167.8343391>,
    <0.1605426, -167.8365949>,
    <0.1547627, -167.7710851>,
    <0.1446591, -167.7682306>,
    <0.1481481, -167.8156918>,
    <0.1388889, -167.7806315>,
    <0.1388889, -167.6922232>,
    <0.1527105, -167.7843759>,
    <0.1429349, -167.7959518>,
    <0.1388889, -167.7304926>,
    <0.1449248, -167.7324665>,
    <0.1507157, -167.7980679>,
    <0.1550798, -167.8387299>,
    <0.1481481, -167.8156918>,
    <0.1527105, -167.7843759>,
    <0.1666667, -167.8774261>,
    <0.1527938, -167.8774261>,
    <0.1507157, -167.7980679>,
    <0.1605426, -167.8365949>,
    <0.1605946, -167.8774261>,
    <0.1507597, -167.8503959>,
    <0.1446799, -167.8377939>,
    <0.1481481, -167.8156918>,
    <0.1527938, -167.8774261>,
    <0.1388889, -167.8774261>,
    <0.1388889, -167.7806315>,
    <0.1507597, -167.8503959>,
    <0.1449776, -167.8774261>,
    <0.1388889, -167.8343473>,
    <0.1429349, -167.7959518>,
    <0.8447813, -167.9163169>,
    <0.8518519, -167.9410995>,
    <0.8466958, -167.9693160>,
    <0.8333333, -167.8774261>,
    <0.8472441, -167.8774261>,
    <0.8489355, -167.9570593>,
    <0.8391096, -167.9171478>,
    <0.8394251, -167.8774261>,
    <0.8492554, -167.9052195>,
    <0.8553295, -167.9155087>,
    <0.8518519, -167.9410995>,
    <0.8472441, -167.8774261>,
    <0.8611111, -167.8774261>,
    <0.8611111, -167.9660833>,
    <0.8492554, -167.9052195>,
    <0.8550421, -167.8774261>,
    <0.8611111, -167.9166169>,
    <0.8570455, -167.9551132>,
    <0.8551925, -167.9862363>,
    <0.8518519, -167.9410995>,
    <0.8611111, -167.9660833>,
    <0.8611111, -168.0684463>,
    <0.8466958, -167.9693160>,
    <0.8570455, -167.9551132>,
    <0.8611111, -168.0222355>,
    <0.8545954, -168.0236393>,
    <0.8489355, -167.9570593>,
    <0.8391009, -167.7681881>,
    <0.8425926, -167.8156918>,
    <0.8333333, -167.7805319>,
    <0.8333333, -167.6922232>,
    <0.8471444, -167.7843057>,
    <0.8373782, -167.7958912>,
    <0.8333333, -167.7304412>,
    <0.8393634, -167.7324274>,
    <0.8451532, -167.7980356>,
    <0.8495230, -167.8387124>,
    <0.8425926, -167.8156918>,
    <0.8471444, -167.7843057>,
    <0.8611111, -167.8774261>,
    <0.8472441, -167.8774261>,
    <0.8451532, -167.7980356>,
    <0.8549780, -167.8365345>,
    <0.8550421, -167.8774261>,
    <0.8452039, -167.8503492>,
    <0.8391258, -167.8377689>,
    <0.8425926, -167.8156918>,
    <0.8472441, -167.8774261>,
    <0.8333333, -167.8774261>,
    <0.8333333, -167.7805319>,
    <0.8452039, -167.8503492>,
    <0.8394251, -167.8774261>,
    <0.8333333, -167.8342221>,
    <0.8373782, -167.7958912>,
    <0.1504150, -167.9168645>,
    <0.1574074, -167.9410995>,
    <0.1525699, -167.9715064>,
    <0.1388889, -167.8774261>,
    <0.1527938, -167.8774261>,
    <0.1546751, -167.9582734>,
    <0.1448471, -167.9183990>,
    <0.1449776, -167.8774261>,
    <0.1548197, -167.9053864>,
    <0.1608836, -167.9150045>,
    <0.1574074, -167.9410995>,
    <0.1527938, -167.8774261>,
    <0.1666667, -167.8774261>,
    <0.1666667, -167.9640663>,
    <0.1548197, -167.9053864>,
    <0.1605946, -167.8774261>,
    <0.1666667, -167.9157041>,
    <0.1626083, -167.9539998>,
    <0.1608276, -167.9862796>,
    <0.1574074, -167.9410995>,
    <0.1666667, -167.9640663>,
    <0.1666667, -168.0684463>,
    <0.1525699, -167.9715064>,
    <0.1626083, -167.9539998>,
    <0.1666667, -168.0180680>,
    <0.1604597, -168.0257624>,
    <0.1546751, -167.9582734>,
    <0.1446239, -167.9544488>,
    <0.1481481, -168.0047729>,
    <0.1388889, -167.9640898>,
    <0.1388889, -167.8774261>,
    <0.1525699, -167.9715064>,
    <0.1428856, -167.9816506>,
    <0.1388889, -167.9157136>,
    <0.1448471, -167.9183990>,
    <0.1506032, -167.9863025>,
    <0.1552689, -168.0282930>,
    <0.1481481, -168.0047729>,
    <0.1525699, -167.9715064>,
    <0.1666667, -168.0684463>,
    <0.1536910, -168.0684463>,
    <0.1506032, -167.9863025>,
    <0.1604597, -168.0257624>,
    <0.1614351, -168.0684463>,
    <0.1510191, -168.0377525>,
    <0.1449042, -168.0264388>,
    <0.1481481, -168.0047729>,
    <0.1536910, -168.0684463>,
    <0.1388889, -168.0684463>,
    <0.1388889, -167.9640898>,
    <0.1510191, -168.0377525>,
    <0.1452695, -168.0684463>,
    <0.1388889, -168.0181340>,
    <0.1428856, -167.9816506>,
    <0.8389888, -167.9547891>,
    <0.8425926, -168.0047729>,
    <0.8333333, -167.9676413>,
    <0.8333333, -167.8774261>,
    <0.8466958, -167.9693160>,
    <0.8372834, -167.9834817>,
    <0.8333333, -167.9173643>,
    <0.8391096, -167.9171478>,
    <0.8448330, -167.9854126>,
    <0.8497230, -168.0277454>,
    <0.8425926, -168.0047729>,
    <0.8466958, -167.9693160>,
    <0.8611111, -168.0684463>,
    <0.8484925, -168.0684463>,
    <0.8448330, -167.9854126>,
    <0.8545954, -168.0236393>,
    <0.8560535, -168.0684463>,
    <0.8453295, -168.0343104>,
    <0.8394380, -168.0273267>,
    <0.8425926, -168.0047729>,
    <0.8484925, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8333333, -167.9676413>,
    <0.8453295, -168.0343104>,
    <0.8398940, -168.0684463>,
    <0.8333333, -168.0250477>,
    <0.8372834, -167.9834817>,
    <0.1730869, -167.1109029>,
    <0.1708266, -167.1123151>,
    <0.1695253, -167.1231073>,
    <0.1791465, -167.1040945>,
    <0.1728491, -167.1040945>,
    <0.1700262, -167.1189534>,
    <0.1730187, -167.1162039>,
    <0.1759758, -167.1040945>,
    <0.1721760, -167.1068303>,
    <0.1692523, -167.1090581>,
    <0.1708266, -167.1123151>,
    <0.1728491, -167.1040945>,
    <0.1666667, -167.1040945>,
    <0.1666667, -167.1157282>,
    <0.1721760, -167.1068303>,
    <0.1697508, -167.1040945>,
    <0.1666667, -167.1077212>,
    <0.1687668, -167.1140051>,
    <0.1684213, -167.1199768>,
    <0.1708266, -167.1123151>,
    <0.1666667, -167.1157282>,
    <0.1666667, -167.1287564>,
    <0.1695253, -167.1231073>,
    <0.1687668, -167.1140051>,
    <0.1666667, -167.1243298>,
    <0.1677047, -167.1267052>,
    <0.1700262, -167.1189534>,
    <0.8255399, -167.1109046>,
    <0.8282340, -167.1123151>,
    <0.8260566, -167.1040945>,
    <0.8180354, -167.1040945>,
    <0.8298335, -167.1231143>,
    <0.8268370, -167.1070407>,
    <0.8222019, -167.1040945>,
    <0.8257078, -167.1164632>,
    <0.8291966, -167.1188144>,
    <0.8311836, -167.1207203>,
    <0.8282340, -167.1123151>,
    <0.8298335, -167.1231143>,
    <0.8333333, -167.1287564>,
    <0.8333333, -167.1186954>,
    <0.8291966, -167.1188144>,
    <0.8320577, -167.1267000>,
    <0.8333333, -167.1268389>,
    <0.8307417, -167.1154528>,
    <0.8302393, -167.1097999>,
    <0.8282340, -167.1123151>,
    <0.8333333, -167.1186954>,
    <0.8333333, -167.1040945>,
    <0.8260566, -167.1040945>,
    <0.8307417, -167.1154528>,
    <0.8333333, -167.1075966>,
    <0.8297377, -167.1040945>,
    <0.8268370, -167.1070407>,
    <0.8240604, -167.0790979>,
    <0.8278804, -167.0842391>,
    <0.8262328, -167.0952600>,
    <0.8169746, -167.0684463>,
    <0.8251540, -167.0684463>,
    <0.8268921, -167.0908497>,
    <0.8214115, -167.0812964>,
    <0.8210643, -167.0684463>,
    <0.8263367, -167.0752973>,
    <0.8299253, -167.0791498>,
    <0.8278804, -167.0842391>,
    <0.8251540, -167.0684463>,
    <0.8333333, -167.0684463>,
    <0.8333333, -167.0954675>,
    <0.8263367, -167.0752973>,
    <0.8292436, -167.0684463>,
    <0.8333333, -167.0825383>,
    <0.8310173, -167.0906984>,
    <0.8301950, -167.0976978>,
    <0.8278804, -167.0842391>,
    <0.8333333, -167.0954675>,
    <0.8333333, -167.1158246>,
    <0.8262328, -167.0952600>,
    <0.8310173, -167.0906984>,
    <0.8333333, -167.1101239>,
    <0.8305252, -167.1076916>,
    <0.8268921, -167.0908497>,
    <0.1923968, -167.1106496>,
    <0.1932078, -167.1123151>,
    <0.1922023, -167.1040945>,
    <0.1907346, -167.1040945>,
    <0.1934423, -167.1220942>,
    <0.1926327, -167.1076129>,
    <0.1913774, -167.1040945>,
    <0.1921942, -167.1137978>,
    <0.1933590, -167.1186210>,
    <0.1938847, -167.1197228>,
    <0.1932078, -167.1123151>,
    <0.1934423, -167.1220942>,
    <0.1944444, -167.1287564>,
    <0.1944444, -167.1157255>,
    <0.1933590, -167.1186210>,
    <0.1941597, -167.1268637>,
    <0.1944444, -167.1243285>,
    <0.1939494, -167.1143604>,
    <0.1935748, -167.1090574>,
    <0.1932078, -167.1123151>,
    <0.1944444, -167.1157255>,
    <0.1944444, -167.1040945>,
    <0.1922023, -167.1040945>,
    <0.1939494, -167.1143604>,
    <0.1944444, -167.1077202>,
    <0.1932540, -167.1040945>,
    <0.1926327, -167.1076129>,
    <0.1891583, -167.1106496>,
    <0.1881085, -167.1123151>,
    <0.1934423, -167.1220942>,
    <0.1907346, -167.1040945>,
    <0.1843477, -167.1040945>,
    <0.1906676, -167.1170071>,
    <0.1921943, -167.1137978>,
    <0.1872812, -167.1040945>,
    <0.1857357, -167.1071285>,
    <0.1855869, -167.1108241>,
    <0.1881085, -167.1123151>,
    <0.1843477, -167.1040945>,
    <0.1791465, -167.1040945>,
    <0.1907448, -167.1227922>,
    <0.1857357, -167.1071285>,
    <0.1816728, -167.1040945>,
    <0.1864301, -167.1158365>,
    <0.1897750, -167.1189380>,
    <0.1916850, -167.1214895>,
    <0.1881085, -167.1123151>,
    <0.1907448, -167.1227922>,
    <0.1944444, -167.1287564>,
    <0.1934423, -167.1220942>,
    <0.1897750, -167.1189380>,
    <0.1930950, -167.1265810>,
    <0.1941597, -167.1268637>,
    <0.1906676, -167.1170071>,
    <0.1798756, -167.1176325>,
    <0.1800859, -167.1205358>,
    <0.1907448, -167.1227922>,
    <0.1791465, -167.1040945>,
    <0.1695253, -167.1231073>,
    <0.1860641, -167.1218013>,
    <0.1864301, -167.1158365>,
    <0.1730187, -167.1162039>,
    <0.1743967, -167.1219211>,
    <0.1739659, -167.1252890>,
    <0.1800859, -167.1205358>,
    <0.1695253, -167.1231073>,
    <0.1666667, -167.1287564>,
    <0.1795859, -167.1287564>,
    <0.1743967, -167.1219211>,
    <0.1677047, -167.1267052>,
    <0.1719371, -167.1287564>,
    <0.1797638, -167.1258321>,
    <0.1862153, -167.1252102>,
    <0.1800859, -167.1205358>,
    <0.1795859, -167.1287564>,
    <0.1944444, -167.1287564>,
    <0.1907448, -167.1227922>,
    <0.1797638, -167.1258321>,
    <0.1879787, -167.1287564>,
    <0.1930950, -167.1265810>,
    <0.1860641, -167.1218013>,
    <0.8188926, -167.1175674>,
    <0.8189748, -167.1205421>,
    <0.8298335, -167.1231187>,
    <0.8180355, -167.1041136>,
    <0.8087264, -167.1224952>,
    <0.8252566, -167.1220327>,
    <0.8257078, -167.1164727>,
    <0.8124121, -167.1152174>,
    <0.8136112, -167.1215643>,
    <0.8129781, -167.1251375>,
    <0.8189748, -167.1205421>,
    <0.8087264, -167.1224952>,
    <0.8055556, -167.1287564>,
    <0.8186557, -167.1287564>,
    <0.8136112, -167.1215643>,
    <0.8067122, -167.1264725>,
    <0.8109375, -167.1287564>,
    <0.8187614, -167.1260345>,
    <0.8251993, -167.1252934>,
    <0.8189748, -167.1205421>,
    <0.8186557, -167.1287564>,
    <0.8333333, -167.1287564>,
    <0.8298335, -167.1231187>,
    <0.8187614, -167.1260345>,
    <0.8269908, -167.1287564>,
    <0.8320577, -167.1267016>,
    <0.8252566, -167.1220327>,
    <0.8170155, -167.1443228>,
    <0.8240741, -167.1533103>,
    <0.8186557, -167.1287564>,
    <0.8055556, -167.1287564>,
    <0.8197767, -167.1664683>,
    <0.8213341, -167.1408941>,
    <0.8109375, -167.1287564>,
    <0.8119134, -167.1456162>,
    <0.8217147, -167.1605343>,
    <0.8276294, -167.1705747>,
    <0.8240741, -167.1533103>,
    <0.8197767, -167.1664683>,
    <0.8333333, -167.2024179>,
    <0.8333333, -167.1601023>,
    <0.8217147, -167.1605343>,
    <0.8274428, -167.1867974>,
    <0.8333333, -167.1835237>,
    <0.8293471, -167.1571782>,
    <0.8273491, -167.1427314>,
    <0.8240741, -167.1533103>,
    <0.8333333, -167.1601023>,
    <0.8333333, -167.1287564>,
    <0.8186557, -167.1287564>,
    <0.8293471, -167.1571782>,
    <0.8333333, -167.1407348>,
    <0.8269908, -167.1287564>,
    <0.8213341, -167.1408941>,
    <0.8128604, -167.1107625>,
    <0.8106678, -167.1123279>,
    <0.8087264, -167.1224952>,
    <0.8180355, -167.1041136>,
    <0.8140120, -167.1041136>,
    <0.8094194, -167.1188659>,
    <0.8124121, -167.1152174>,
    <0.8161597, -167.1041136>,
    <0.8128622, -167.1069379>,
    <0.8099163, -167.1101332>,
    <0.8106678, -167.1123279>,
    <0.8140120, -167.1041136>,
    <0.8084122, -167.1041136>,
    <0.8065732, -167.1199778>,
    <0.8128622, -167.1069379>,
    <0.8114994, -167.1041136>,
    <0.8074854, -167.1121087>,
    <0.8087279, -167.1159521>,
    <0.8078807, -167.1208893>,
    <0.8106678, -167.1123279>,
    <0.8065732, -167.1199778>,
    <0.8055556, -167.1287564>,
    <0.8087264, -167.1224952>,
    <0.8087279, -167.1159521>,
    <0.8058991, -167.1257931>,
    <0.8067122, -167.1264725>,
    <0.8094194, -167.1188659>,
    <0.8072004, -167.1101298>,
    <0.8065078, -167.1123215>,
    <0.8065732, -167.1199778>,
    <0.8084122, -167.1041136>,
    <0.8073085, -167.1041062>,
    <0.8065485, -167.1170881>,
    <0.8074854, -167.1121087>,
    <0.8079336, -167.1041104>,
    <0.8069637, -167.1076438>,
    <0.8062318, -167.1098063>,
    <0.8065078, -167.1123215>,
    <0.8073085, -167.1041062>,
    <0.8055556, -167.1040945>,
    <0.8055556, -167.1187029>,
    <0.8069637, -167.1076438>,
    <0.8064920, -167.1041008>,
    <0.8055556, -167.1075984>,
    <0.8059047, -167.1163632>,
    <0.8060480, -167.1199397>,
    <0.8065078, -167.1123215>,
    <0.8055556, -167.1187029>,
    <0.8055556, -167.1287564>,
    <0.8065732, -167.1199778>,
    <0.8059047, -167.1163632>,
    <0.8055556, -167.1268397>,
    <0.8058991, -167.1257931>,
    <0.8065485, -167.1170881>,
    <0.8150584, -167.0805923>,
    <0.8186229, -167.0842391>,
    <0.8247824, -167.1012374>,
    <0.8055607, -167.0684463>,
    <0.8112676, -167.0684463>,
    <0.8226586, -167.0953764>,
    <0.8172091, -167.0883177>,
    <0.8084142, -167.0684463>,
    <0.8142220, -167.0747897>,
    <0.8182745, -167.0790979>,
    <0.8186229, -167.0842391>,
    <0.8112676, -167.0684463>,
    <0.8169746, -167.0684463>,
    <0.8262328, -167.0952600>,
    <0.8142220, -167.0747897>,
    <0.8141211, -167.0684463>,
    <0.8214115, -167.0812964>,
    <0.8224468, -167.0897770>,
    <0.8257429, -167.0991403>,
    <0.8186229, -167.0842391>,
    <0.8262328, -167.0952600>,
    <0.8333333, -167.1158246>,
    <0.8247824, -167.1012374>,
    <0.8224468, -167.0897770>,
    <0.8305252, -167.1076916>,
    <0.8299025, -167.1099718>,
    <0.8226586, -167.0953764>,
    <0.1780581, -167.1442610>,
    <0.1851852, -167.1533103>,
    <0.1795859, -167.1287564>,
    <0.1666667, -167.1287564>,
    <0.1807945, -167.1662209>,
    <0.1823450, -167.1408553>,
    <0.1719371, -167.1287564>,
    <0.1729238, -167.1453493>,
    <0.1827729, -167.1604034>,
    <0.1887171, -167.1706661>,
    <0.1851852, -167.1533103>,
    <0.1807945, -167.1662209>,
    <0.1944444, -167.2024179>,
    <0.1944444, -167.1607154>,
    <0.1827729, -167.1604034>,
    <0.1885041, -167.1866652>,
    <0.1944444, -167.1838308>,
    <0.1904564, -167.1575260>,
    <0.1884150, -167.1428846>,
    <0.1851852, -167.1533103>,
    <0.1944444, -167.1607154>,
    <0.1944444, -167.1287564>,
    <0.1795859, -167.1287564>,
    <0.1904564, -167.1575260>,
    <0.1944444, -167.1413914>,
    <0.1879787, -167.1287564>,
    <0.1823450, -167.1408553>,
    <0.1725134, -167.1583892>,
    <0.1759259, -167.1778641>,
    <0.1807945, -167.1662209>,
    <0.1666667, -167.1287564>,
    <0.1666667, -167.1607154>,
    <0.1786732, -167.1712941>,
    <0.1729238, -167.1453493>,
    <0.1666667, -167.1413913>,
    <0.1707234, -167.1682287>,
    <0.1724566, -167.1858538>,
    <0.1759259, -167.1778641>,
    <0.1666667, -167.1607154>,
    <0.1666667, -167.2024179>,
    <0.1805674, -167.2024179>,
    <0.1707234, -167.1682287>,
    <0.1666667, -167.1838308>,
    <0.1727501, -167.2024179>,
    <0.1785462, -167.1917260>,
    <0.1829331, -167.1872302>,
    <0.1759259, -167.1778641>,
    <0.1805674, -167.2024179>,
    <0.1944444, -167.2024179>,
    <0.1807945, -167.1662209>,
    <0.1785462, -167.1917260>,
    <0.1883733, -167.2024179>,
    <0.1885041, -167.1866652>,
    <0.1786732, -167.1712941>,
    <0.8171214, -167.2232074>,
    <0.8240741, -167.2357456>,
    <0.8194563, -167.2024179>,
    <0.8055556, -167.2024179>,
    <0.8193997, -167.2522483>,
    <0.8214740, -167.2169804>,
    <0.8116390, -167.2024179>,
    <0.8116035, -167.2241867>,
    <0.8214418, -167.2450388>,
    <0.8275351, -167.2602946>,
    <0.8240741, -167.2357456>,
    <0.8193997, -167.2522483>,
    <0.8333333, -167.3024008>,
    <0.8333333, -167.2507837>,
    <0.8214418, -167.2450388>,
    <0.8272269, -167.2804214>,
    <0.8333333, -167.2798504>,
    <0.8292777, -167.2441968>,
    <0.8275493, -167.2228413>,
    <0.8240741, -167.2357456>,
    <0.8333333, -167.2507837>,
    <0.8333333, -167.2024179>,
    <0.8194563, -167.2024179>,
    <0.8292777, -167.2441968>,
    <0.8333333, -167.2235884>,
    <0.8272622, -167.2024179>,
    <0.8214740, -167.2169804>,
    <0.8114257, -167.1582979>,
    <0.8148148, -167.1778641>,
    <0.8197767, -167.1664683>,
    <0.8055556, -167.1287564>,
    <0.8055556, -167.1601026>,
    <0.8176136, -167.1714363>,
    <0.8119134, -167.1456162>,
    <0.8055556, -167.1407351>,
    <0.8096113, -167.1678824>,
    <0.8113456, -167.1857007>,
    <0.8148148, -167.1778641>,
    <0.8055556, -167.1601026>,
    <0.8055556, -167.2024179>,
    <0.8194563, -167.2024179>,
    <0.8096113, -167.1678824>,
    <0.8055556, -167.1835239>,
    <0.8116390, -167.2024179>,
    <0.8174379, -167.1917403>,
    <0.8218453, -167.1872921>,
    <0.8148148, -167.1778641>,
    <0.8194563, -167.2024179>,
    <0.8333333, -167.2024179>,
    <0.8197767, -167.1664683>,
    <0.8174379, -167.1917403>,
    <0.8272622, -167.2024179>,
    <0.8274428, -167.1867974>,
    <0.8176136, -167.1714363>,
    <0.1851807, -167.0791246>,
    <0.1889915, -167.0842391>,
    <0.1873807, -167.0953667>,
    <0.1780857, -167.0684463>,
    <0.1862650, -167.0684463>,
    <0.1880247, -167.0909177>,
    <0.1825550, -167.0813903>,
    <0.1821754, -167.0684463>,
    <0.1874475, -167.0752958>,
    <0.1910364, -167.0790995>,
    <0.1889915, -167.0842391>,
    <0.1862650, -167.0684463>,
    <0.1944444, -167.0684463>,
    <0.1944444, -167.0952665>,
    <0.1874475, -167.0752958>,
    <0.1903547, -167.0684463>,
    <0.1944444, -167.0823113>,
    <0.1921301, -167.0905863>,
    <0.1913153, -167.0976742>,
    <0.1889915, -167.0842391>,
    <0.1944444, -167.0952665>,
    <0.1944444, -167.1158246>,
    <0.1873807, -167.0953667>,
    <0.1921301, -167.0905863>,
    <0.1944444, -167.1100137>,
    <0.1916571, -167.1077519>,
    <0.1880247, -167.0909177>,
    <0.1761612, -167.0805829>,
    <0.1797323, -167.0842391>,
    <0.1858699, -167.1011998>,
    <0.1666667, -167.0684463>,
    <0.1723762, -167.0684463>,
    <0.1837449, -167.0953274>,
    <0.1782857, -167.0882639>,
    <0.1695214, -167.0684463>,
    <0.1753298, -167.0747876>,
    <0.1793937, -167.0791246>,
    <0.1797323, -167.0842391>,
    <0.1723762, -167.0684463>,
    <0.1780857, -167.0684463>,
    <0.1873807, -167.0953667>,
    <0.1753298, -167.0747876>,
    <0.1752309, -167.0684463>,
    <0.1825550, -167.0813903>,
    <0.1835742, -167.0898287>,
    <0.1868568, -167.0991575>,
    <0.1797323, -167.0842391>,
    <0.1873807, -167.0953667>,
    <0.1944444, -167.1158246>,
    <0.1858699, -167.1011998>,
    <0.1835742, -167.0898287>,
    <0.1916571, -167.1077519>,
    <0.1910029, -167.1099546>,
    <0.1837449, -167.0953274>,
    <0.1737823, -167.0911742>,
    <0.1759259, -167.1000319>,
    <0.1666667, -167.0950187>,
    <0.1666667, -167.0684463>,
    <0.1858699, -167.1011998>,
    <0.1706589, -167.0971802>,
    <0.1666667, -167.0820954>,
    <0.1782857, -167.0882639>,
    <0.1808298, -167.1006078>,
    <0.1840547, -167.1082202>,
    <0.1759259, -167.1000319>,
    <0.1858699, -167.1011998>,
    <0.1944444, -167.1158246>,
    <0.1799786, -167.1158246>,
    <0.1808298, -167.1006078>,
    <0.1910029, -167.1099546>,
    <0.1881915, -167.1158246>,
    <0.1780874, -167.1084550>,
    <0.1723095, -167.1066750>,
    <0.1759259, -167.1000319>,
    <0.1799786, -167.1158246>,
    <0.1666667, -167.1158246>,
    <0.1666667, -167.0950187>,
    <0.1780874, -167.1084550>,
    <0.1721568, -167.1158246>,
    <0.1666667, -167.1099562>,
    <0.1706589, -167.0971802>,
    <0.8168965, -167.1383955>,
    <0.8240741, -167.1524837>,
    <0.8190999, -167.1694491>,
    <0.8055556, -167.1158246>,
    <0.8188565, -167.1158246>,
    <0.8212669, -167.1620581>,
    <0.8112721, -167.1384574>,
    <0.8110393, -167.1158246>,
    <0.8211168, -167.1317057>,
    <0.8273993, -167.1378006>,
    <0.8240741, -167.1524837>,
    <0.8188565, -167.1158246>,
    <0.8333333, -167.1158246>,
    <0.8333333, -167.1670695>,
    <0.8211168, -167.1317057>,
    <0.8270735, -167.1158246>,
    <0.8333333, -167.1357703>,
    <0.8292718, -167.1606715>,
    <0.8274602, -167.1787011>,
    <0.8240741, -167.1524837>,
    <0.8333333, -167.1670695>,
    <0.8333333, -167.2258020>,
    <0.8190999, -167.1694491>,
    <0.8292718, -167.1606715>,
    <0.8333333, -167.2000468>,
    <0.8270621, -167.2009731>,
    <0.8212669, -167.1620581>,
    <0.8126767, -167.0912879>,
    <0.8148148, -167.1000319>,
    <0.8055556, -167.0954362>,
    <0.8055556, -167.0684463>,
    <0.8247809, -167.1012374>,
    <0.8095406, -167.0974141>,
    <0.8055556, -167.0825055>,
    <0.8172061, -167.0883177>,
    <0.8197107, -167.1006241>,
    <0.8229464, -167.1082296>,
    <0.8148148, -167.1000319>,
    <0.8247809, -167.1012374>,
    <0.8333333, -167.1158246>,
    <0.8188565, -167.1158246>,
    <0.8197107, -167.1006241>,
    <0.8299018, -167.1099718>,
    <0.8270735, -167.1158246>,
    <0.8169689, -167.1084490>,
    <0.8111956, -167.1067793>,
    <0.8148148, -167.1000319>,
    <0.8188565, -167.1158246>,
    <0.8055556, -167.1158246>,
    <0.8055556, -167.0954362>,
    <0.8169689, -167.1084490>,
    <0.8110393, -167.1158246>,
    <0.8055556, -167.1101386>,
    <0.8095406, -167.0974141>,
    <0.1782325, -167.2232074>,
    <0.1851852, -167.2357456>,
    <0.1805674, -167.2024179>,
    <0.1666667, -167.2024179>,
    <0.1805108, -167.2522483>,
    <0.1825851, -167.2169804>,
    <0.1727501, -167.2024179>,
    <0.1727146, -167.2241867>,
    <0.1825529, -167.2450388>,
    <0.1886462, -167.2602946>,
    <0.1851852, -167.2357456>,
    <0.1805108, -167.2522483>,
    <0.1944444, -167.3024008>,
    <0.1944444, -167.2507837>,
    <0.1825529, -167.2450388>,
    <0.1883380, -167.2804214>,
    <0.1944444, -167.2798504>,
    <0.1903887, -167.2441968>,
    <0.1886603, -167.2228413>,
    <0.1851852, -167.2357456>,
    <0.1944444, -167.2507837>,
    <0.1944444, -167.2024179>,
    <0.1805674, -167.2024179>,
    <0.1903887, -167.2441968>,
    <0.1944444, -167.2235884>,
    <0.1883733, -167.2024179>,
    <0.1825851, -167.2169804>,
    <0.1724425, -167.2436308>,
    <0.1759259, -167.2690732>,
    <0.1805108, -167.2522483>,
    <0.1666667, -167.2024179>,
    <0.1666667, -167.2507837>,
    <0.1785063, -167.2596042>,
    <0.1727146, -167.2241867>,
    <0.1666667, -167.2235884>,
    <0.1707161, -167.2587824>,
    <0.1724563, -167.2811646>,
    <0.1759259, -167.2690732>,
    <0.1666667, -167.2507837>,
    <0.1666667, -167.3024008>,
    <0.1805661, -167.3024008>,
    <0.1707161, -167.2587824>,
    <0.1666667, -167.2798504>,
    <0.1727494, -167.3024008>,
    <0.1785377, -167.2878319>,
    <0.1828618, -167.2815307>,
    <0.1759259, -167.2690732>,
    <0.1805661, -167.3024008>,
    <0.1944444, -167.3024008>,
    <0.1805108, -167.2522483>,
    <0.1785377, -167.2878319>,
    <0.1883727, -167.3024008>,
    <0.1883380, -167.2804214>,
    <0.1785063, -167.2596042>,
    <0.8171227, -167.3280360>,
    <0.8240741, -167.3434849>,
    <0.8194550, -167.3024008>,
    <0.8055556, -167.3024008>,
    <0.8194063, -167.3638575>,
    <0.8214737, -167.3203558>,
    <0.8116383, -167.3024008>,
    <0.8116078, -167.3292549>,
    <0.8214455, -167.3549573>,
    <0.8275368, -167.3739447>,
    <0.8240741, -167.3434849>,
    <0.8194063, -167.3638575>,
    <0.8333333, -167.4256532>,
    <0.8333333, -167.3627833>,
    <0.8214455, -167.3549573>,
    <0.8272313, -167.3985780>,
    <0.8333333, -167.3982231>,
    <0.8292780, -167.3543311>,
    <0.8275490, -167.3277674>,
    <0.8240741, -167.3434849>,
    <0.8333333, -167.3627833>,
    <0.8333333, -167.3024008>,
    <0.8194550, -167.3024008>,
    <0.8292780, -167.3543311>,
    <0.8333333, -167.3288803>,
    <0.8272616, -167.3024008>,
    <0.8214737, -167.3203558>,
    <0.8113314, -167.2436308>,
    <0.8148148, -167.2690732>,
    <0.8193997, -167.2522483>,
    <0.8055556, -167.2024179>,
    <0.8055556, -167.2507837>,
    <0.8173952, -167.2596042>,
    <0.8116035, -167.2241867>,
    <0.8055556, -167.2235884>,
    <0.8096050, -167.2587824>,
    <0.8113453, -167.2811646>,
    <0.8148148, -167.2690732>,
    <0.8055556, -167.2507837>,
    <0.8055556, -167.3024008>,
    <0.8194550, -167.3024008>,
    <0.8096050, -167.2587824>,
    <0.8055556, -167.2798504>,
    <0.8116383, -167.3024008>,
    <0.8174266, -167.2878319>,
    <0.8217507, -167.2815307>,
    <0.8148148, -167.2690732>,
    <0.8194550, -167.3024008>,
    <0.8333333, -167.3024008>,
    <0.8193997, -167.2522483>,
    <0.8174266, -167.2878319>,
    <0.8272616, -167.3024008>,
    <0.8272269, -167.2804214>,
    <0.8173952, -167.2596042>,
    <0.1780123, -167.1384034>,
    <0.1851852, -167.1524837>,
    <0.1802189, -167.1694805>,
    <0.1666667, -167.1158246>,
    <0.1799786, -167.1158246>,
    <0.1823824, -167.1620760>,
    <0.1723906, -167.1384867>,
    <0.1721568, -167.1158246>,
    <0.1822340, -167.1317050>,
    <0.1885132, -167.1377944>,
    <0.1851852, -167.1524837>,
    <0.1799786, -167.1158246>,
    <0.1944444, -167.1158246>,
    <0.1944444, -167.1670444>,
    <0.1822340, -167.1317050>,
    <0.1881915, -167.1158246>,
    <0.1944444, -167.1357720>,
    <0.1903830, -167.1606577>,
    <0.1885732, -167.1787027>,
    <0.1851852, -167.1524837>,
    <0.1944444, -167.1670444>,
    <0.1944444, -167.2258020>,
    <0.1802189, -167.1694805>,
    <0.1903830, -167.1606577>,
    <0.1944444, -167.2000293>,
    <0.1881777, -167.2009906>,
    <0.1823824, -167.1620760>,
    <0.1723695, -167.1604027>,
    <0.1759259, -167.1891429>,
    <0.1666667, -167.1671626>,
    <0.1666667, -167.1158246>,
    <0.1802189, -167.1694805>,
    <0.1707194, -167.1767834>,
    <0.1666667, -167.1358722>,
    <0.1723906, -167.1384867>,
    <0.1783450, -167.1780634>,
    <0.1827891, -167.2025568>,
    <0.1759259, -167.1891429>,
    <0.1802189, -167.1694805>,
    <0.1944444, -167.2258020>,
    <0.1805673, -167.2258020>,
    <0.1783450, -167.1780634>,
    <0.1881777, -167.2009906>,
    <0.1883733, -167.2258020>,
    <0.1785297, -167.2097081>,
    <0.1724566, -167.2019773>,
    <0.1759259, -167.1891429>,
    <0.1805673, -167.2258020>,
    <0.1666667, -167.2258020>,
    <0.1666667, -167.1671626>,
    <0.1785297, -167.2097081>,
    <0.1727500, -167.2258020>,
    <0.1666667, -167.2000930>,
    <0.1707194, -167.1767834>,
    <0.8171222, -167.2539957>,
    <0.8240741, -167.2709932>,
    <0.8194028, -167.2933857>,
    <0.8055556, -167.2258020>,
    <0.8194562, -167.2258020>,
    <0.8214434, -167.2836036>,
    <0.8116055, -167.2553296>,
    <0.8116389, -167.2258020>,
    <0.8214745, -167.2455535>,
    <0.8275492, -167.2537633>,
    <0.8240741, -167.2709932>,
    <0.8194562, -167.2258020>,
    <0.8333333, -167.2258020>,
    <0.8333333, -167.2924560>,
    <0.8214745, -167.2455535>,
    <0.8272622, -167.2258020>,
    <0.8333333, -167.2550533>,
    <0.8292777, -167.2830552>,
    <0.8275359, -167.3045527>,
    <0.8240741, -167.2709932>,
    <0.8333333, -167.2924560>,
    <0.8333333, -167.3613758>,
    <0.8194028, -167.2933857>,
    <0.8292777, -167.2830552>,
    <0.8333333, -167.3313235>,
    <0.8272291, -167.3315832>,
    <0.8214434, -167.2836036>,
    <0.8112565, -167.1603261>,
    <0.8148148, -167.1891429>,
    <0.8055556, -167.1668877>,
    <0.8055556, -167.1158246>,
    <0.8190999, -167.1694491>,
    <0.8096084, -167.1766288>,
    <0.8055556, -167.1356731>,
    <0.8112721, -167.1384574>,
    <0.8172294, -167.1780454>,
    <0.8216761, -167.2025490>,
    <0.8148148, -167.1891429>,
    <0.8190999, -167.1694491>,
    <0.8333333, -167.2258020>,
    <0.8194562, -167.2258020>,
    <0.8172294, -167.1780454>,
    <0.8270621, -167.2009731>,
    <0.8272622, -167.2258020>,
    <0.8174183, -167.2097059>,
    <0.8113455, -167.2019086>,
    <0.8148148, -167.1891429>,
    <0.8194562, -167.2258020>,
    <0.8055556, -167.2258020>,
    <0.8055556, -167.1668877>,
    <0.8174183, -167.2097059>,
    <0.8116389, -167.2258020>,
    <0.8055556, -167.1999361>,
    <0.8096084, -167.1766288>,
    <0.1782338, -167.3280360>,
    <0.1851852, -167.3434849>,
    <0.1805661, -167.3024008>,
    <0.1666667, -167.3024008>,
    <0.1805174, -167.3638575>,
    <0.1825848, -167.3203558>,
    <0.1727494, -167.3024008>,
    <0.1727188, -167.3292549>,
    <0.1825566, -167.3549573>,
    <0.1886479, -167.3739447>,
    <0.1851852, -167.3434849>,
    <0.1805174, -167.3638575>,
    <0.1944444, -167.4256532>,
    <0.1944444, -167.3627833>,
    <0.1825566, -167.3549573>,
    <0.1883424, -167.3985780>,
    <0.1944444, -167.3982231>,
    <0.1903891, -167.3543311>,
    <0.1886600, -167.3277674>,
    <0.1851852, -167.3434849>,
    <0.1944444, -167.3627833>,
    <0.1944444, -167.3024008>,
    <0.1805661, -167.3024008>,
    <0.1903891, -167.3543311>,
    <0.1944444, -167.3288803>,
    <0.1883727, -167.3024008>,
    <0.1825848, -167.3203558>,
    <0.1724441, -167.3534027>,
    <0.1759259, -167.3845690>,
    <0.1805174, -167.3638575>,
    <0.1666667, -167.3024008>,
    <0.1666667, -167.3627833>,
    <0.1785100, -167.3729124>,
    <0.1727188, -167.3292549>,
    <0.1666667, -167.3288803>,
    <0.1707165, -167.3723121>,
    <0.1724559, -167.3996647>,
    <0.1759259, -167.3845690>,
    <0.1666667, -167.3627833>,
    <0.1666667, -167.4256532>,
    <0.1805646, -167.4256532>,
    <0.1707165, -167.3723121>,
    <0.1666667, -167.3982231>,
    <0.1727486, -167.4256532>,
    <0.1785371, -167.4076960>,
    <0.1828631, -167.3999332>,
    <0.1759259, -167.3845690>,
    <0.1805646, -167.4256532>,
    <0.1944444, -167.4256532>,
    <0.1805174, -167.3638575>,
    <0.1785371, -167.4076960>,
    <0.1883719, -167.4256532>,
    <0.1883424, -167.3985780>,
    <0.1785100, -167.3729124>,
    <0.8171242, -167.4553644>,
    <0.8240741, -167.4732541>,
    <0.8194535, -167.4256532>,
    <0.8055556, -167.4256532>,
    <0.8194138, -167.4968970>,
    <0.8214731, -167.4464590>,
    <0.8116375, -167.4256532>,
    <0.8116127, -167.4567920>,
    <0.8214498, -167.4865678>,
    <0.8275386, -167.5086990>,
    <0.8240741, -167.4732541>,
    <0.8194138, -167.4968970>,
    <0.8333333, -167.5684558>,
    <0.8333333, -167.4961891>,
    <0.8214498, -167.4865678>,
    <0.8272363, -167.5371117>,
    <0.8333333, -167.5369298>,
    <0.8292785, -167.4861453>,
    <0.8275486, -167.4551874>,
    <0.8240741, -167.4732541>,
    <0.8333333, -167.4961891>,
    <0.8333333, -167.4256532>,
    <0.8194535, -167.4256532>,
    <0.8292785, -167.4861453>,
    <0.8333333, -167.4566011>,
    <0.8272608, -167.4256532>,
    <0.8214731, -167.4464590>,
    <0.8113331, -167.3534027>,
    <0.8148148, -167.3845690>,
    <0.8194063, -167.3638575>,
    <0.8055556, -167.3024008>,
    <0.8055556, -167.3627833>,
    <0.8173989, -167.3729124>,
    <0.8116078, -167.3292549>,
    <0.8055556, -167.3288803>,
    <0.8096054, -167.3723121>,
    <0.8113449, -167.3996647>,
    <0.8148148, -167.3845690>,
    <0.8055556, -167.3627833>,
    <0.8055556, -167.4256532>,
    <0.8194535, -167.4256532>,
    <0.8096054, -167.3723121>,
    <0.8055556, -167.3982231>,
    <0.8116375, -167.4256532>,
    <0.8174260, -167.4076960>,
    <0.8217520, -167.3999332>,
    <0.8148148, -167.3845690>,
    <0.8194535, -167.4256532>,
    <0.8333333, -167.4256532>,
    <0.8194063, -167.3638575>,
    <0.8174260, -167.4076960>,
    <0.8272608, -167.4256532>,
    <0.8272313, -167.3985780>,
    <0.8173989, -167.3729124>,
    <0.1782333, -167.2539957>,
    <0.1851852, -167.2709932>,
    <0.1805139, -167.2933857>,
    <0.1666667, -167.2258020>,
    <0.1805673, -167.2258020>,
    <0.1825545, -167.2836036>,
    <0.1727166, -167.2553296>,
    <0.1727500, -167.2258020>,
    <0.1825856, -167.2455535>,
    <0.1886603, -167.2537633>,
    <0.1851852, -167.2709932>,
    <0.1805673, -167.2258020>,
    <0.1944444, -167.2258020>,
    <0.1944444, -167.2924560>,
    <0.1825856, -167.2455535>,
    <0.1883733, -167.2258020>,
    <0.1944444, -167.2550533>,
    <0.1903888, -167.2830552>,
    <0.1886470, -167.3045527>,
    <0.1851852, -167.2709932>,
    <0.1944444, -167.2924560>,
    <0.1944444, -167.3613758>,
    <0.1805139, -167.2933857>,
    <0.1903888, -167.2830552>,
    <0.1944444, -167.3313235>,
    <0.1883402, -167.3315832>,
    <0.1825545, -167.2836036>,
    <0.1724433, -167.2819570>,
    <0.1759259, -167.3161845>,
    <0.1666667, -167.2924560>,
    <0.1666667, -167.2258020>,
    <0.1805139, -167.2933857>,
    <0.1707163, -167.3028339>,
    <0.1666667, -167.2550533>,
    <0.1727166, -167.2553296>,
    <0.1785080, -167.3033535>,
    <0.1828624, -167.3330804>,
    <0.1759259, -167.3161845>,
    <0.1805139, -167.2933857>,
    <0.1944444, -167.3613758>,
    <0.1805655, -167.3613758>,
    <0.1785080, -167.3033535>,
    <0.1883402, -167.3315832>,
    <0.1883724, -167.3613758>,
    <0.1785378, -167.3416247>,
    <0.1724562, -167.3328480>,
    <0.1759259, -167.3161845>,
    <0.1805655, -167.3613758>,
    <0.1666667, -167.3613758>,
    <0.1666667, -167.2924560>,
    <0.1785378, -167.3416247>,
    <0.1727491, -167.3613758>,
    <0.1666667, -167.3313235>,
    <0.1707163, -167.3028339>,
    <0.8171238, -167.3940515>,
    <0.8240741, -167.4137323>,
    <0.8194111, -167.4397221>,
    <0.8055556, -167.3613758>,
    <0.8194544, -167.3613758>,
    <0.8214482, -167.4283682>,
    <0.8116109, -167.3956156>,
    <0.8116380, -167.3613758>,
    <0.8214738, -167.3842624>,
    <0.8275488, -167.3939086>,
    <0.8240741, -167.4137323>,
    <0.8194544, -167.3613758>,
    <0.8333333, -167.3613758>,
    <0.8333333, -167.4391507>,
    <0.8214738, -167.3842624>,
    <0.8272613, -167.3613758>,
    <0.8333333, -167.3955180>,
    <0.8292782, -167.4280187>,
    <0.8275380, -167.4527626>,
    <0.8240741, -167.4137323>,
    <0.8333333, -167.4391507>,
    <0.8333333, -167.5184453>,
    <0.8194111, -167.4397221>,
    <0.8292782, -167.4280187>,
    <0.8333333, -167.4838674>,
    <0.8272346, -167.4839601>,
    <0.8214482, -167.4283682>,
    <0.8113322, -167.2819570>,
    <0.8148148, -167.3161845>,
    <0.8055556, -167.2924560>,
    <0.8055556, -167.2258020>,
    <0.8194028, -167.2933857>,
    <0.8096052, -167.3028339>,
    <0.8055556, -167.2550533>,
    <0.8116055, -167.2553296>,
    <0.8173969, -167.3033535>,
    <0.8217514, -167.3330804>,
    <0.8148148, -167.3161845>,
    <0.8194028, -167.2933857>,
    <0.8333333, -167.3613758>,
    <0.8194544, -167.3613758>,
    <0.8173969, -167.3033535>,
    <0.8272291, -167.3315832>,
    <0.8272613, -167.3613758>,
    <0.8174267, -167.3416247>,
    <0.8113451, -167.3328480>,
    <0.8148148, -167.3161845>,
    <0.8194544, -167.3613758>,
    <0.8055556, -167.3613758>,
    <0.8055556, -167.2924560>,
    <0.8174267, -167.3416247>,
    <0.8116380, -167.3613758>,
    <0.8055556, -167.3313235>,
    <0.8096052, -167.3028339>,
    <0.1782353, -167.4553644>,
    <0.1851852, -167.4732541>,
    <0.1805646, -167.4256532>,
    <0.1666667, -167.4256532>,
    <0.1805249, -167.4968970>,
    <0.1825842, -167.4464590>,
    <0.1727486, -167.4256532>,
    <0.1727237, -167.4567920>,
    <0.1825609, -167.4865678>,
    <0.1886497, -167.5086990>,
    <0.1851852, -167.4732541>,
    <0.1805249, -167.4968970>,
    <0.1944444, -167.5684558>,
    <0.1944444, -167.4961890>,
    <0.1825609, -167.4865678>,
    <0.1883474, -167.5371117>,
    <0.1944444, -167.5369297>,
    <0.1903896, -167.4861453>,
    <0.1886597, -167.4551874>,
    <0.1851852, -167.4732541>,
    <0.1944444, -167.4961890>,
    <0.1944444, -167.4256532>,
    <0.1805646, -167.4256532>,
    <0.1903896, -167.4861453>,
    <0.1944444, -167.4566011>,
    <0.1883719, -167.4256532>,
    <0.1825842, -167.4464590>,
    <0.1724460, -167.4848985>,
    <0.1759259, -167.5208549>,
    <0.1805249, -167.4968970>,
    <0.1666667, -167.4256532>,
    <0.1666667, -167.4961890>,
    <0.1785144, -167.5073705>,
    <0.1727237, -167.4567920>,
    <0.1666667, -167.4566011>,
    <0.1707171, -167.5069791>,
    <0.1724555, -167.5384889>,
    <0.1759259, -167.5208549>,
    <0.1666667, -167.4961890>,
    <0.1666667, -167.5684558>,
    <0.1805626, -167.5684558>,
    <0.1707171, -167.5069791>,
    <0.1666667, -167.5369298>,
    <0.1727475, -167.5684558>,
    <0.1785361, -167.5476517>,
    <0.1828645, -167.5386659>,
    <0.1759259, -167.5208549>,
    <0.1805626, -167.5684558>,
    <0.1944444, -167.5684558>,
    <0.1805249, -167.4968970>,
    <0.1785361, -167.5476517>,
    <0.1883709, -167.5684558>,
    <0.1883474, -167.5371117>,
    <0.1785144, -167.5073705>,
    <0.8171258, -167.6013336>,
    <0.8240741, -167.6211112>,
    <0.8194515, -167.5684558>,
    <0.8055556, -167.5684558>,
    <0.8194221, -167.6473117>,
    <0.8214721, -167.5914725>,
    <0.8116364, -167.5684558>,
    <0.8116180, -167.6029317>,
    <0.8214546, -167.6358644>,
    <0.8275407, -167.6604338>,
    <0.8240741, -167.6211112>,
    <0.8194221, -167.6473117>,
    <0.8333333, -167.7264218>,
    <0.8333333, -167.6468904>,
    <0.8214546, -167.6358644>,
    <0.8272418, -167.6917804>,
    <0.8333333, -167.6917086>,
    <0.8292790, -167.6356026>,
    <0.8275481, -167.6012283>,
    <0.8240741, -167.6211112>,
    <0.8333333, -167.6468904>,
    <0.8333333, -167.5684558>,
    <0.8194515, -167.5684558>,
    <0.8292790, -167.6356026>,
    <0.8333333, -167.6028579>,
    <0.8272598, -167.5684558>,
    <0.8214721, -167.5914725>,
    <0.8113349, -167.4848985>,
    <0.8148148, -167.5208549>,
    <0.8194138, -167.4968970>,
    <0.8055556, -167.4256532>,
    <0.8055556, -167.4961890>,
    <0.8174033, -167.5073705>,
    <0.8116127, -167.4567920>,
    <0.8055556, -167.4566011>,
    <0.8096060, -167.5069791>,
    <0.8113444, -167.5384889>,
    <0.8148148, -167.5208549>,
    <0.8055556, -167.4961890>,
    <0.8055556, -167.5684558>,
    <0.8194515, -167.5684558>,
    <0.8096060, -167.5069791>,
    <0.8055556, -167.5369298>,
    <0.8116364, -167.5684558>,
    <0.8174250, -167.5476517>,
    <0.8217534, -167.5386659>,
    <0.8148148, -167.5208549>,
    <0.8194515, -167.5684558>,
    <0.8333333, -167.5684558>,
    <0.8194138, -167.4968970>,
    <0.8174250, -167.5476517>,
    <0.8272598, -167.5684558>,
    <0.8272363, -167.5371117>,
    <0.8174033, -167.5073705>,
    <0.1782369, -167.6013336>,
    <0.1851852, -167.6211112>,
    <0.1805626, -167.5684558>,
    <0.1666667, -167.5684558>,
    <0.1805332, -167.6473117>,
    <0.1825832, -167.5914725>,
    <0.1727475, -167.5684558>,
    <0.1727291, -167.6029317>,
    <0.1825657, -167.6358644>,
    <0.1886518, -167.6604338>,
    <0.1851852, -167.6211112>,
    <0.1805332, -167.6473117>,
    <0.1944444, -167.7264218>,
    <0.1944444, -167.6468904>,
    <0.1825657, -167.6358644>,
    <0.1883529, -167.6917804>,
    <0.1944444, -167.6917086>,
    <0.1903901, -167.6356026>,
    <0.1886592, -167.6012283>,
    <0.1851852, -167.6211112>,
    <0.1944444, -167.6468904>,
    <0.1944444, -167.5684558>,
    <0.1805626, -167.5684558>,
    <0.1903901, -167.6356026>,
    <0.1944444, -167.6028580>,
    <0.1883709, -167.5684558>,
    <0.1825832, -167.5914725>,
    <0.1724481, -167.6341061>,
    <0.1759259, -167.6737665>,
    <0.1805332, -167.6473117>,
    <0.1666667, -167.5684558>,
    <0.1666667, -167.6468904>,
    <0.1785192, -167.6588757>,
    <0.1727291, -167.6029317>,
    <0.1666667, -167.6028580>,
    <0.1707177, -167.6586490>,
    <0.1724549, -167.6933751>,
    <0.1759259, -167.6737665>,
    <0.1666667, -167.6468904>,
    <0.1666667, -167.7264218>,
    <0.1805604, -167.7264218>,
    <0.1707177, -167.6586490>,
    <0.1666667, -167.6917086>,
    <0.1727464, -167.7264218>,
    <0.1785349, -167.7034090>,
    <0.1828660, -167.6934805>,
    <0.1759259, -167.6737665>,
    <0.1805604, -167.7264218>,
    <0.1944444, -167.7264218>,
    <0.1805332, -167.6473117>,
    <0.1785349, -167.7034090>,
    <0.1883698, -167.7264218>,
    <0.1883529, -167.6917804>,
    <0.1785192, -167.6588757>,
    <0.8171123, -167.7613884>,
    <0.8240741, -167.7825485>,
    <0.8194493, -167.7264218>,
    <0.8055556, -167.7264218>,
    <0.8193702, -167.8101615>,
    <0.8214684, -167.7509260>,
    <0.8116353, -167.7264218>,
    <0.8115877, -167.7629868>,
    <0.8214255, -167.7980964>,
    <0.8275277, -167.8234729>,
    <0.8240741, -167.7825485>,
    <0.8193702, -167.8101615>,
    <0.8333333, -167.8948019>,
    <0.8333333, -167.8063797>,
    <0.8214255, -167.7980964>,
    <0.8272646, -167.8580152>,
    <0.8333333, -167.8564516>,
    <0.8292793, -167.7959456>,
    <0.8275475, -167.7604430>,
    <0.8240741, -167.7825485>,
    <0.8333333, -167.8063797>,
    <0.8333333, -167.7264218>,
    <0.8194493, -167.7264218>,
    <0.8292793, -167.7959456>,
    <0.8333333, -167.7609807>,
    <0.8272587, -167.7264218>,
    <0.8214684, -167.7509260>,
    <0.8113370, -167.6341061>,
    <0.8148148, -167.6737665>,
    <0.8194221, -167.6473117>,
    <0.8055556, -167.5684558>,
    <0.8055556, -167.6468904>,
    <0.8174081, -167.6588757>,
    <0.8116180, -167.6029317>,
    <0.8055556, -167.6028579>,
    <0.8096066, -167.6586490>,
    <0.8113438, -167.6933751>,
    <0.8148148, -167.6737665>,
    <0.8055556, -167.6468904>,
    <0.8055556, -167.7264218>,
    <0.8194493, -167.7264218>,
    <0.8096066, -167.6586490>,
    <0.8055556, -167.6917086>,
    <0.8116353, -167.7264218>,
    <0.8174238, -167.7034090>,
    <0.8217549, -167.6934805>,
    <0.8148148, -167.6737665>,
    <0.8194493, -167.7264218>,
    <0.8333333, -167.7264218>,
    <0.8194221, -167.6473117>,
    <0.8174238, -167.7034090>,
    <0.8272587, -167.7264218>,
    <0.8272418, -167.6917804>,
    <0.8174081, -167.6588757>,
    <0.1782349, -167.3940515>,
    <0.1851852, -167.4137323>,
    <0.1805222, -167.4397221>,
    <0.1666667, -167.3613758>,
    <0.1805655, -167.3613758>,
    <0.1825593, -167.4283682>,
    <0.1727220, -167.3956156>,
    <0.1727491, -167.3613758>,
    <0.1825849, -167.3842624>,
    <0.1886599, -167.3939086>,
    <0.1851852, -167.4137323>,
    <0.1805655, -167.3613758>,
    <0.1944444, -167.3613758>,
    <0.1944444, -167.4391507>,
    <0.1825849, -167.3842624>,
    <0.1883724, -167.3613758>,
    <0.1944444, -167.3955180>,
    <0.1903893, -167.4280187>,
    <0.1886491, -167.4527626>,
    <0.1851852, -167.4137323>,
    <0.1944444, -167.4391507>,
    <0.1944444, -167.5184453>,
    <0.1805222, -167.4397221>,
    <0.1903893, -167.4280187>,
    <0.1944444, -167.4838674>,
    <0.1883457, -167.4839601>,
    <0.1825593, -167.4283682>,
    <0.1724454, -167.4265843>,
    <0.1759259, -167.4660888>,
    <0.1666667, -167.4391507>,
    <0.1666667, -167.3613758>,
    <0.1805222, -167.4397221>,
    <0.1707169, -167.4509341>,
    <0.1666667, -167.3955180>,
    <0.1727220, -167.3956156>,
    <0.1785128, -167.4512490>,
    <0.1828640, -167.4856754>,
    <0.1759259, -167.4660888>,
    <0.1805222, -167.4397221>,
    <0.1944444, -167.5184453>,
    <0.1805634, -167.5184453>,
    <0.1785128, -167.4512490>,
    <0.1883457, -167.4839601>,
    <0.1883713, -167.5184453>,
    <0.1785367, -167.4955641>,
    <0.1724557, -167.4855325>,
    <0.1759259, -167.4660888>,
    <0.1805634, -167.5184453>,
    <0.1666667, -167.5184453>,
    <0.1666667, -167.4391507>,
    <0.1785367, -167.4955641>,
    <0.1727479, -167.5184453>,
    <0.1666667, -167.4838674>,
    <0.1707169, -167.4509341>,
    <0.8171255, -167.5546111>,
    <0.8240741, -167.5763713>,
    <0.8194202, -167.6051824>,
    <0.8055556, -167.5184453>,
    <0.8194523, -167.5184453>,
    <0.8214534, -167.5925951>,
    <0.8116168, -167.5563642>,
    <0.8116368, -167.5184453>,
    <0.8214728, -167.5437683>,
    <0.8275483, -167.5545331>,
    <0.8240741, -167.5763713>,
    <0.8194523, -167.5184453>,
    <0.8333333, -167.5184453>,
    <0.8333333, -167.6048705>,
    <0.8214728, -167.5437683>,
    <0.8272602, -167.5184453>,
    <0.8333333, -167.5563664>,
    <0.8292788, -167.5923911>,
    <0.8275402, -167.6196618>,
    <0.8240741, -167.5763713>,
    <0.8333333, -167.6048705>,
    <0.8333333, -167.6922232>,
    <0.8194202, -167.6051824>,
    <0.8292788, -167.5923911>,
    <0.8333333, -167.6541051>,
    <0.8272406, -167.6541068>,
    <0.8214534, -167.5925951>,
    <0.8113343, -167.4265843>,
    <0.8148148, -167.4660888>,
    <0.8055556, -167.4391507>,
    <0.8055556, -167.3613758>,
    <0.8194111, -167.4397221>,
    <0.8096058, -167.4509341>,
    <0.8055556, -167.3955180>,
    <0.8116109, -167.3956156>,
    <0.8174017, -167.4512490>,
    <0.8217529, -167.4856754>,
    <0.8148148, -167.4660888>,
    <0.8194111, -167.4397221>,
    <0.8333333, -167.5184453>,
    <0.8194523, -167.5184453>,
    <0.8174017, -167.4512490>,
    <0.8272346, -167.4839601>,
    <0.8272602, -167.5184453>,
    <0.8174256, -167.4955641>,
    <0.8113446, -167.4855325>,
    <0.8148148, -167.4660888>,
    <0.8194523, -167.5184453>,
    <0.8055556, -167.5184453>,
    <0.8055556, -167.4391507>,
    <0.8174256, -167.4955641>,
    <0.8116368, -167.5184453>,
    <0.8055556, -167.4838674>,
    <0.8096058, -167.4509341>,
    <0.1782263, -167.7614060>,
    <0.1851852, -167.7825485>,
    <0.1805604, -167.7264218>,
    <0.1666667, -167.7264218>,
    <0.1804928, -167.8102318>,
    <0.1825799, -167.7509300>,
    <0.1727464, -167.7264218>,
    <0.1727053, -167.7630259>,
    <0.1825431, -167.7981357>,
    <0.1886417, -167.8235130>,
    <0.1851852, -167.7825485>,
    <0.1804928, -167.8102318>,
    <0.1944444, -167.8948019>,
    <0.1944444, -167.8064696>,
    <0.1825431, -167.7981357>,
    <0.1884307, -167.8583485>,
    <0.1944444, -167.8572258>,
    <0.1903905, -167.7959963>,
    <0.1886586, -167.7604654>,
    <0.1851852, -167.7825485>,
    <0.1944444, -167.8064696>,
    <0.1944444, -167.7264218>,
    <0.1805604, -167.7264218>,
    <0.1903905, -167.7959963>,
    <0.1944444, -167.7610269>,
    <0.1883698, -167.7264218>,
    <0.1825799, -167.7509300>,
    <0.1724380, -167.7954521>,
    <0.1759259, -167.8386752>,
    <0.1804928, -167.8102318>,
    <0.1666667, -167.7264218>,
    <0.1666667, -167.8064793>,
    <0.1784959, -167.8226688>,
    <0.1727053, -167.7630259>,
    <0.1666667, -167.7610318>,
    <0.1707130, -167.8205492>,
    <0.1724575, -167.8586896>,
    <0.1759259, -167.8386752>,
    <0.1666667, -167.8064793>,
    <0.1666667, -167.8948019>,
    <0.1805707, -167.8948019>,
    <0.1707130, -167.8205492>,
    <0.1666667, -167.8566335>,
    <0.1726328, -167.8948019>,
    <0.1785623, -167.8705330>,
    <0.1828585, -167.8596277>,
    <0.1759259, -167.8386752>,
    <0.1805707, -167.8948019>,
    <0.1944444, -167.8948019>,
    <0.1804928, -167.8102318>,
    <0.1785623, -167.8705330>,
    <0.1885065, -167.8948019>,
    <0.1884307, -167.8583485>,
    <0.1784959, -167.8226688>,
    <0.8162514, -167.9254544>,
    <0.8240741, -167.9526834>,
    <0.8194659, -167.8948019>,
    <0.8055556, -167.8948019>,
    <0.8159102, -167.9595305>,
    <0.8216125, -167.9217649>,
    <0.8115252, -167.8948019>,
    <0.8099897, -167.9225205>,
    <0.8191681, -167.9567981>,
    <0.8266627, -167.9831593>,
    <0.8240741, -167.9526834>,
    <0.8159102, -167.9595305>,
    <0.8333333, -168.0684463>,
    <0.8333333, -167.9519769>,
    <0.8191681, -167.9567981>,
    <0.8234763, -168.0068279>,
    <0.8333333, -167.9960340>,
    <0.8294461, -167.9522735>,
    <0.8275517, -167.9235660>,
    <0.8240741, -167.9526834>,
    <0.8333333, -167.9519769>,
    <0.8333333, -167.8948019>,
    <0.8194659, -167.8948019>,
    <0.8294461, -167.9522735>,
    <0.8333333, -167.9194340>,
    <0.8273558, -167.8948019>,
    <0.8216125, -167.9217649>,
    <0.8113240, -167.7954050>,
    <0.8148148, -167.8386752>,
    <0.8193702, -167.8101615>,
    <0.8055556, -167.7264218>,
    <0.8055556, -167.8063614>,
    <0.8173772, -167.8226365>,
    <0.8115877, -167.7629868>,
    <0.8055556, -167.7609714>,
    <0.8096006, -167.8204783>,
    <0.8113480, -167.8586601>,
    <0.8148148, -167.8386752>,
    <0.8055556, -167.8063614>,
    <0.8055556, -167.8948019>,
    <0.8194659, -167.8948019>,
    <0.8096006, -167.8204783>,
    <0.8055556, -167.8564263>,
    <0.8115252, -167.8948019>,
    <0.8174506, -167.8704829>,
    <0.8217461, -167.8596102>,
    <0.8148148, -167.8386752>,
    <0.8194659, -167.8948019>,
    <0.8333333, -167.8948019>,
    <0.8193702, -167.8101615>,
    <0.8174506, -167.8704829>,
    <0.8273558, -167.8948019>,
    <0.8272646, -167.8580152>,
    <0.8173772, -167.8226365>,
    <0.1773638, -167.9254722>,
    <0.1851852, -167.9526834>,
    <0.1805707, -167.8948019>,
    <0.1666667, -167.8948019>,
    <0.1770326, -167.9596014>,
    <0.1827246, -167.9218198>,
    <0.1726328, -167.8948019>,
    <0.1711085, -167.9225686>,
    <0.1802852, -167.9568414>,
    <0.1877767, -167.9833040>,
    <0.1851852, -167.9526834>,
    <0.1770326, -167.9596014>,
    <0.1944444, -168.0684463>,
    <0.1944444, -167.9524848>,
    <0.1802852, -167.9568414>,
    <0.1845936, -168.0068665>,
    <0.1944444, -167.9964636>,
    <0.1905759, -167.9525677>,
    <0.1886612, -167.9236930>,
    <0.1851852, -167.9526834>,
    <0.1944444, -167.9524848>,
    <0.1944444, -167.8948019>,
    <0.1805707, -167.8948019>,
    <0.1905759, -167.9525677>,
    <0.1944444, -167.9192443>,
    <0.1885065, -167.8948019>,
    <0.1827246, -167.9218198>,
    <0.1715730, -167.9543666>,
    <0.1759259, -168.0105648>,
    <0.1770326, -167.9596014>,
    <0.1666667, -167.8948019>,
    <0.1666667, -167.9524981>,
    <0.1765279, -167.9828439>,
    <0.1711085, -167.9225686>,
    <0.1666667, -167.9196593>,
    <0.1708630, -167.9788143>,
    <0.1724537, -168.0249889>,
    <0.1759259, -168.0105648>,
    <0.1666667, -167.9524981>,
    <0.1666667, -168.0684463>,
    <0.1805555, -168.0684463>,
    <0.1708630, -167.9788143>,
    <0.1666667, -167.9961751>,
    <0.1736111, -168.0684463>,
    <0.1786712, -168.0448879>,
    <0.1819896, -168.0267647>,
    <0.1759259, -168.0105648>,
    <0.1805555, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1770326, -167.9596014>,
    <0.1786712, -168.0448879>,
    <0.1875000, -168.0684463>,
    <0.1845936, -168.0068665>,
    <0.1765279, -167.9828439>,
    <0.8104590, -167.9542028>,
    <0.8148148, -168.0105648>,
    <0.8159102, -167.9595305>,
    <0.8055556, -167.8948019>,
    <0.8055556, -167.9519140>,
    <0.8154107, -167.9828032>,
    <0.8099897, -167.9225205>,
    <0.8055556, -167.9193977>,
    <0.8097519, -167.9784946>,
    <0.8113426, -168.0248429>,
    <0.8148148, -168.0105648>,
    <0.8055556, -167.9519140>,
    <0.8055556, -168.0684463>,
    <0.8194445, -168.0684463>,
    <0.8097519, -167.9784946>,
    <0.8055556, -167.9959565>,
    <0.8125000, -168.0684463>,
    <0.8175598, -168.0448839>,
    <0.8208757, -168.0267470>,
    <0.8148148, -168.0105648>,
    <0.8194445, -168.0684463>,
    <0.8333333, -168.0684463>,
    <0.8159102, -167.9595305>,
    <0.8175598, -168.0448839>,
    <0.8263889, -168.0684463>,
    <0.8234763, -168.0068279>,
    <0.8154107, -167.9828032>,
    <0.1782366, -167.5546111>,
    <0.1851852, -167.5763713>,
    <0.1805313, -167.6051824>,
    <0.1666667, -167.5184453>,
    <0.1805634, -167.5184453>,
    <0.1825645, -167.5925951>,
    <0.1727279, -167.5563642>,
    <0.1727479, -167.5184453>,
    <0.1825839, -167.5437683>,
    <0.1886594, -167.5545331>,
    <0.1851852, -167.5763713>,
    <0.1805634, -167.5184453>,
    <0.1944444, -167.5184453>,
    <0.1944444, -167.6048705>,
    <0.1825839, -167.5437683>,
    <0.1883713, -167.5184453>,
    <0.1944444, -167.5563664>,
    <0.1903899, -167.5923911>,
    <0.1886513, -167.6196618>,
    <0.1851852, -167.5763713>,
    <0.1944444, -167.6048705>,
    <0.1944444, -167.6922232>,
    <0.1805313, -167.6051824>,
    <0.1903899, -167.5923911>,
    <0.1944444, -167.6541051>,
    <0.1883517, -167.6541068>,
    <0.1825645, -167.5925951>,
    <0.1724476, -167.5906989>,
    <0.1759259, -167.6342972>,
    <0.1666667, -167.6048705>,
    <0.1666667, -167.5184453>,
    <0.1805313, -167.6051824>,
    <0.1707176, -167.6177446>,
    <0.1666667, -167.5563664>,
    <0.1727279, -167.5563642>,
    <0.1785181, -167.6179095>,
    <0.1828656, -167.6559815>,
    <0.1759259, -167.6342972>,
    <0.1805313, -167.6051824>,
    <0.1944444, -167.6922232>,
    <0.1805610, -167.6922232>,
    <0.1785181, -167.6179095>,
    <0.1883517, -167.6541068>,
    <0.1883701, -167.6922232>,
    <0.1785353, -167.6669079>,
    <0.1724550, -167.6559035>,
    <0.1759259, -167.6342972>,
    <0.1805610, -167.6922232>,
    <0.1666667, -167.6922232>,
    <0.1666667, -167.6048705>,
    <0.1785353, -167.6669079>,
    <0.1727466, -167.6922232>,
    <0.1666667, -167.6541051>,
    <0.1707176, -167.6177446>,
    <0.8171115, -167.7306774>,
    <0.8240741, -167.7539575>,
    <0.8193666, -167.7843057>,
    <0.8055556, -167.6922232>,
    <0.8194499, -167.6922232>,
    <0.8214234, -167.7710458>,
    <0.8115856, -167.7324275>,
    <0.8116355, -167.6922232>,
    <0.8214688, -167.7191765>,
    <0.8275477, -167.7297339>,
    <0.8240741, -167.7539575>,
    <0.8194499, -167.6922232>,
    <0.8333333, -167.6922232>,
    <0.8333333, -167.7805319>,
    <0.8214688, -167.7191765>,
    <0.8272590, -167.6922232>,
    <0.8333333, -167.7304412>,
    <0.8292792, -167.7688963>,
    <0.8275268, -167.7990553>,
    <0.8240741, -167.7539575>,
    <0.8333333, -167.7805319>,
    <0.8333333, -167.8774261>,
    <0.8193666, -167.7843057>,
    <0.8292792, -167.7688963>,
    <0.8333333, -167.8342221>,
    <0.8272002, -167.8365342>,
    <0.8214234, -167.7710458>,
    <0.8113365, -167.5906989>,
    <0.8148148, -167.6342972>,
    <0.8055556, -167.6048705>,
    <0.8055556, -167.5184453>,
    <0.8194202, -167.6051824>,
    <0.8096065, -167.6177446>,
    <0.8055556, -167.5563664>,
    <0.8116168, -167.5563642>,
    <0.8174070, -167.6179095>,
    <0.8217546, -167.6559815>,
    <0.8148148, -167.6342972>,
    <0.8194202, -167.6051824>,
    <0.8333333, -167.6922232>,
    <0.8194499, -167.6922232>,
    <0.8174070, -167.6179095>,
    <0.8272406, -167.6541068>,
    <0.8272590, -167.6922232>,
    <0.8174242, -167.6669079>,
    <0.8113440, -167.6559035>,
    <0.8148148, -167.6342972>,
    <0.8194499, -167.6922232>,
    <0.8055556, -167.6922232>,
    <0.8055556, -167.6048705>,
    <0.8174242, -167.6669079>,
    <0.8116355, -167.6922232>,
    <0.8055556, -167.6541051>,
    <0.8096065, -167.6177446>,
    <0.1782255, -167.7306968>,
    <0.1851852, -167.7539575>,
    <0.1804894, -167.7843835>,
    <0.1666667, -167.6922232>,
    <0.1805610, -167.6922232>,
    <0.1825411, -167.7710893>,
    <0.1727032, -167.7324708>,
    <0.1727466, -167.6922232>,
    <0.1825802, -167.7191808>,
    <0.1886588, -167.7297550>,
    <0.1851852, -167.7539575>,
    <0.1805610, -167.6922232>,
    <0.1944444, -167.6922232>,
    <0.1944444, -167.7806161>,
    <0.1825802, -167.7191808>,
    <0.1883701, -167.6922232>,
    <0.1944444, -167.7304848>,
    <0.1903903, -167.7689438>,
    <0.1886409, -167.7990958>,
    <0.1851852, -167.7539575>,
    <0.1944444, -167.7806161>,
    <0.1944444, -167.8774261>,
    <0.1804894, -167.7843835>,
    <0.1903903, -167.7689438>,
    <0.1944444, -167.8343277>,
    <0.1883213, -167.8366011>,
    <0.1825411, -167.7710893>,
    <0.1724372, -167.7682309>,
    <0.1759259, -167.8156918>,
    <0.1666667, -167.7806251>,
    <0.1666667, -167.6922232>,
    <0.1804894, -167.7843835>,
    <0.1707128, -167.7959487>,
    <0.1666667, -167.7304894>,
    <0.1727032, -167.7324708>,
    <0.1784943, -167.7980712>,
    <0.1828577, -167.8387318>,
    <0.1759259, -167.8156918>,
    <0.1804894, -167.7843835>,
    <0.1944444, -167.8774261>,
    <0.1805710, -167.8774261>,
    <0.1784943, -167.7980712>,
    <0.1883213, -167.8366011>,
    <0.1883720, -167.8774261>,
    <0.1785374, -167.8503996>,
    <0.1724575, -167.8377922>,
    <0.1759259, -167.8156918>,
    <0.1805710, -167.8774261>,
    <0.1666667, -167.8774261>,
    <0.1666667, -167.7806251>,
    <0.1785374, -167.8503996>,
    <0.1727551, -167.8774261>,
    <0.1666667, -167.8343391>,
    <0.1707128, -167.7959487>,
    <0.8169766, -167.9161324>,
    <0.8240741, -167.9410995>,
    <0.8188107, -167.9685779>,
    <0.8055556, -167.8774261>,
    <0.8194662, -167.8774261>,
    <0.8210899, -167.9566787>,
    <0.8112652, -167.9166894>,
    <0.8116473, -167.8774261>,
    <0.8214746, -167.9051781>,
    <0.8275518, -167.9158982>,
    <0.8240741, -167.9410995>,
    <0.8194662, -167.8774261>,
    <0.8333333, -167.8774261>,
    <0.8333333, -167.9676413>,
    <0.8214746, -167.9051781>,
    <0.8272643, -167.8774261>,
    <0.8333333, -167.9173643>,
    <0.8292689, -167.9559904>,
    <0.8273879, -167.9864412>,
    <0.8240741, -167.9410995>,
    <0.8333333, -167.9676413>,
    <0.8333333, -168.0684463>,
    <0.8188107, -167.9685779>,
    <0.8292689, -167.9559904>,
    <0.8333333, -168.0250477>,
    <0.8267547, -168.0232068>,
    <0.8210899, -167.9566787>,
    <0.8113231, -167.7681839>,
    <0.8148148, -167.8156918>,
    <0.8055556, -167.7805148>,
    <0.8055556, -167.6922232>,
    <0.8193666, -167.7843057>,
    <0.8096004, -167.7958816>,
    <0.8055556, -167.7304324>,
    <0.8115856, -167.7324275>,
    <0.8173755, -167.7980354>,
    <0.8217453, -167.8387124>,
    <0.8148148, -167.8156918>,
    <0.8193666, -167.7843057>,
    <0.8333333, -167.8774261>,
    <0.8194662, -167.8774261>,
    <0.8173755, -167.7980354>,
    <0.8272002, -167.8365342>,
    <0.8272643, -167.8774261>,
    <0.8174260, -167.8503480>,
    <0.8113480, -167.8377647>,
    <0.8148148, -167.8156918>,
    <0.8194662, -167.8774261>,
    <0.8055556, -167.8774261>,
    <0.8055556, -167.7805148>,
    <0.8174260, -167.8503480>,
    <0.8116473, -167.8774261>,
    <0.8055556, -167.8342005>,
    <0.8096004, -167.7958816>,
    <0.1782045, -167.9169466>,
    <0.1851852, -167.9410995>,
    <0.1803954, -167.9718349>,
    <0.1666667, -167.8774261>,
    <0.1805710, -167.8774261>,
    <0.1824814, -167.9584493>,
    <0.1726534, -167.9185953>,
    <0.1727551, -167.8774261>,
    <0.1825985, -167.9054054>,
    <0.1886613, -167.9147704>,
    <0.1851852, -167.9410995>,
    <0.1805710, -167.8774261>,
    <0.1944444, -167.8774261>,
    <0.1944444, -167.9631301>,
    <0.1825985, -167.9054054>,
    <0.1883720, -167.8774261>,
    <0.1944444, -167.9152029>,
    <0.1903835, -167.9534679>,
    <0.1886174, -167.9861277>,
    <0.1851852, -167.9410995>,
    <0.1944444, -167.9631301>,
    <0.1944444, -168.0684463>,
    <0.1803954, -167.9718349>,
    <0.1903835, -167.9534679>,
    <0.1944444, -168.0169040>,
    <0.1882780, -168.0260412>,
    <0.1824814, -167.9584493>,
    <0.1724137, -167.9545250>,
    <0.1759259, -168.0047729>,
    <0.1666667, -167.9640663>,
    <0.1666667, -167.8774261>,
    <0.1803954, -167.9718349>,
    <0.1706764, -167.9816944>,
    <0.1666667, -167.9157041>,
    <0.1726534, -167.9185953>,
    <0.1784177, -167.9864097>,
    <0.1830025, -168.0283751>,
    <0.1759259, -168.0047729>,
    <0.1803954, -167.9718349>,
    <0.1944444, -168.0684463>,
    <0.1812444, -168.0684463>,
    <0.1784177, -167.9864097>,
    <0.1882780, -168.0260412>,
    <0.1890479, -168.0684463>,
    <0.1787480, -168.0385597>,
    <0.1726259, -168.0264329>,
    <0.1759259, -168.0047729>,
    <0.1812444, -168.0684463>,
    <0.1666667, -168.0684463>,
    <0.1666667, -167.9640663>,
    <0.1787480, -168.0385597>,
    <0.1729001, -168.0684463>,
    <0.1666667, -168.0180680>,
    <0.1706764, -167.9816944>,
    <0.8111842, -167.9560985>,
    <0.8148148, -168.0047729>,
    <0.8055556, -167.9736171>,
    <0.8055556, -167.8774261>,
    <0.8188107, -167.9685779>,
    <0.8094584, -167.9867495>,
    <0.8055556, -167.9201376>,
    <0.8112652, -167.9166894>,
    <0.8169552, -167.9853849>,
    <0.8220734, -168.0275608>,
    <0.8148148, -168.0047729>,
    <0.8188107, -167.9685779>,
    <0.8333333, -168.0684463>,
    <0.8213346, -168.0684463>,
    <0.8169552, -167.9853849>,
    <0.8267547, -168.0232068>,
    <0.8286385, -168.0684463>,
    <0.8172475, -168.0285303>,
    <0.8118151, -168.0288206>,
    <0.8148148, -168.0047729>,
    <0.8213346, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.8055556, -167.9736171>,
    <0.8172475, -168.0285303>,
    <0.8125853, -168.0684463>,
    <0.8055556, -168.0320981>,
    <0.8094584, -167.9867495>,
    <0.2008647, -167.1109029>,
    <0.1986044, -167.1123151>,
    <0.1973031, -167.1231073>,
    <0.2069243, -167.1040945>,
    <0.2006269, -167.1040945>,
    <0.1978040, -167.1189534>,
    <0.2007965, -167.1162039>,
    <0.2037536, -167.1040945>,
    <0.1999538, -167.1068303>,
    <0.1970300, -167.1090574>,
    <0.1986044, -167.1123151>,
    <0.2006269, -167.1040945>,
    <0.1944444, -167.1040945>,
    <0.1944444, -167.1157255>,
    <0.1999538, -167.1068303>,
    <0.1975286, -167.1040945>,
    <0.1944444, -167.1077202>,
    <0.1965446, -167.1140038>,
    <0.1961991, -167.1199761>,
    <0.1986044, -167.1123151>,
    <0.1944444, -167.1157255>,
    <0.1944444, -167.1287564>,
    <0.1973031, -167.1231073>,
    <0.1965446, -167.1140038>,
    <0.1944444, -167.1243285>,
    <0.1954825, -167.1267051>,
    <0.1978040, -167.1189534>,
    <0.7977621, -167.1109046>,
    <0.8004562, -167.1123151>,
    <0.7982787, -167.1040945>,
    <0.7902576, -167.1040945>,
    <0.8020558, -167.1231144>,
    <0.7990592, -167.1070408>,
    <0.7944240, -167.1040945>,
    <0.7979300, -167.1164633>,
    <0.8014189, -167.1188146>,
    <0.8034058, -167.1207222>,
    <0.8004562, -167.1123151>,
    <0.8020558, -167.1231144>,
    <0.8055556, -167.1287564>,
    <0.8055556, -167.1187029>,
    <0.8014189, -167.1188146>,
    <0.8042800, -167.1267001>,
    <0.8055556, -167.1268397>,
    <0.8029639, -167.1154565>,
    <0.8024615, -167.1098018>,
    <0.8004562, -167.1123151>,
    <0.8055556, -167.1187029>,
    <0.8055556, -167.1040945>,
    <0.7982787, -167.1040945>,
    <0.8029639, -167.1154565>,
    <0.8055556, -167.1075984>,
    <0.8019599, -167.1040945>,
    <0.7990592, -167.1070408>,
    <0.7962845, -167.0791084>,
    <0.8001016, -167.0842391>,
    <0.7984682, -167.0953019>,
    <0.7891937, -167.0684463>,
    <0.7973747, -167.0684463>,
    <0.7991215, -167.0908768>,
    <0.7936442, -167.0813333>,
    <0.7932842, -167.0684463>,
    <0.7985568, -167.0752923>,
    <0.8021469, -167.0791420>,
    <0.8001016, -167.0842391>,
    <0.7973747, -167.0684463>,
    <0.8055556, -167.0684463>,
    <0.8055556, -167.0954362>,
    <0.7985568, -167.0752923>,
    <0.8014651, -167.0684463>,
    <0.8055556, -167.0825055>,
    <0.8032387, -167.0906795>,
    <0.8024202, -167.0977004>,
    <0.8001016, -167.0842391>,
    <0.8055556, -167.0954362>,
    <0.8055556, -167.1158246>,
    <0.7984682, -167.0953019>,
    <0.8032387, -167.0906795>,
    <0.8055556, -167.1101386>,
    <0.8027549, -167.1077149>,
    <0.7991215, -167.0908768>,
    <0.2201745, -167.1106496>,
    <0.2209856, -167.1123151>,
    <0.2199801, -167.1040945>,
    <0.2185123, -167.1040945>,
    <0.2212200, -167.1220942>,
    <0.2204104, -167.1076129>,
    <0.2191551, -167.1040945>,
    <0.2199720, -167.1137978>,
    <0.2211368, -167.1186210>,
    <0.2216625, -167.1197228>,
    <0.2209856, -167.1123151>,
    <0.2212200, -167.1220942>,
    <0.2222222, -167.1287564>,
    <0.2222222, -167.1157254>,
    <0.2211368, -167.1186210>,
    <0.2219375, -167.1268636>,
    <0.2222222, -167.1243284>,
    <0.2217272, -167.1143603>,
    <0.2213525, -167.1090574>,
    <0.2209856, -167.1123151>,
    <0.2222222, -167.1157254>,
    <0.2222222, -167.1040945>,
    <0.2199801, -167.1040945>,
    <0.2217272, -167.1143603>,
    <0.2222222, -167.1077203>,
    <0.2210318, -167.1040945>,
    <0.2204104, -167.1076129>,
    <0.2169360, -167.1106496>,
    <0.2158863, -167.1123151>,
    <0.2212200, -167.1220942>,
    <0.2185123, -167.1040945>,
    <0.2121254, -167.1040945>,
    <0.2184454, -167.1170071>,
    <0.2199720, -167.1137978>,
    <0.2150589, -167.1040945>,
    <0.2135134, -167.1071285>,
    <0.2133646, -167.1108241>,
    <0.2158863, -167.1123151>,
    <0.2121254, -167.1040945>,
    <0.2069242, -167.1040945>,
    <0.2185225, -167.1227921>,
    <0.2135134, -167.1071285>,
    <0.2094505, -167.1040945>,
    <0.2142078, -167.1158363>,
    <0.2175527, -167.1189380>,
    <0.2194628, -167.1214895>,
    <0.2158863, -167.1123151>,
    <0.2185225, -167.1227921>,
    <0.2222222, -167.1287564>,
    <0.2212200, -167.1220942>,
    <0.2175527, -167.1189380>,
    <0.2208728, -167.1265810>,
    <0.2219375, -167.1268636>,
    <0.2184454, -167.1170071>,
    <0.2076534, -167.1176324>,
    <0.2078637, -167.1205358>,
    <0.2185225, -167.1227921>,
    <0.2069243, -167.1040945>,
    <0.1973031, -167.1231073>,
    <0.2138418, -167.1218013>,
    <0.2142078, -167.1158363>,
    <0.2007965, -167.1162039>,
    <0.2021744, -167.1219211>,
    <0.2017437, -167.1252890>,
    <0.2078637, -167.1205358>,
    <0.1973031, -167.1231073>,
    <0.1944444, -167.1287564>,
    <0.2073637, -167.1287564>,
    <0.2021744, -167.1219211>,
    <0.1954825, -167.1267051>,
    <0.1997149, -167.1287564>,
    <0.2075416, -167.1258320>,
    <0.2139930, -167.1252102>,
    <0.2078637, -167.1205358>,
    <0.2073637, -167.1287564>,
    <0.2222222, -167.1287564>,
    <0.2185225, -167.1227921>,
    <0.2075416, -167.1258320>,
    <0.2157564, -167.1287564>,
    <0.2208728, -167.1265810>,
    <0.2138418, -167.1218013>,
    <0.7911148, -167.1175675>,
    <0.7911970, -167.1205421>,
    <0.8020558, -167.1231188>,
    <0.7902577, -167.1041136>,
    <0.7809484, -167.1224956>,
    <0.7974787, -167.1220327>,
    <0.7979301, -167.1164728>,
    <0.7846341, -167.1152180>,
    <0.7858333, -167.1215645>,
    <0.7852003, -167.1251377>,
    <0.7911970, -167.1205421>,
    <0.7809484, -167.1224956>,
    <0.7777778, -167.1287564>,
    <0.7908779, -167.1287564>,
    <0.7858333, -167.1215645>,
    <0.7789344, -167.1264727>,
    <0.7831597, -167.1287564>,
    <0.7909836, -167.1260344>,
    <0.7974216, -167.1252934>,
    <0.7911970, -167.1205421>,
    <0.7908779, -167.1287564>,
    <0.8055556, -167.1287564>,
    <0.8020558, -167.1231188>,
    <0.7909836, -167.1260344>,
    <0.7992131, -167.1287564>,
    <0.8042800, -167.1267016>,
    <0.7974787, -167.1220327>,
    <0.7892377, -167.1443229>,
    <0.7962963, -167.1533103>,
    <0.7908779, -167.1287564>,
    <0.7777778, -167.1287564>,
    <0.7919990, -167.1664684>,
    <0.7935564, -167.1408940>,
    <0.7831597, -167.1287564>,
    <0.7841356, -167.1456163>,
    <0.7939370, -167.1605343>,
    <0.7998516, -167.1705748>,
    <0.7962963, -167.1533103>,
    <0.7919990, -167.1664684>,
    <0.8055556, -167.2024179>,
    <0.8055556, -167.1601026>,
    <0.7939370, -167.1605343>,
    <0.7996651, -167.1867974>,
    <0.8055556, -167.1835239>,
    <0.8015693, -167.1571784>,
    <0.7995713, -167.1427314>,
    <0.7962963, -167.1533103>,
    <0.8055556, -167.1601026>,
    <0.8055556, -167.1287564>,
    <0.7908779, -167.1287564>,
    <0.8015693, -167.1571784>,
    <0.8055556, -167.1407351>,
    <0.7992131, -167.1287564>,
    <0.7935564, -167.1408940>,
    <0.7850826, -167.1107627>,
    <0.7828900, -167.1123279>,
    <0.7809484, -167.1224956>,
    <0.7902577, -167.1041136>,
    <0.7862343, -167.1041136>,
    <0.7816415, -167.1188663>,
    <0.7846341, -167.1152180>,
    <0.7883819, -167.1041136>,
    <0.7850845, -167.1069379>,
    <0.7821385, -167.1101333>,
    <0.7828900, -167.1123279>,
    <0.7862343, -167.1041136>,
    <0.7806345, -167.1041136>,
    <0.7787954, -167.1199784>,
    <0.7850845, -167.1069379>,
    <0.7837217, -167.1041136>,
    <0.7797076, -167.1121091>,
    <0.7809502, -167.1159522>,
    <0.7801029, -167.1208896>,
    <0.7828900, -167.1123279>,
    <0.7787954, -167.1199784>,
    <0.7777778, -167.1287564>,
    <0.7809484, -167.1224956>,
    <0.7809502, -167.1159522>,
    <0.7781213, -167.1257934>,
    <0.7789344, -167.1264727>,
    <0.7816415, -167.1188663>,
    <0.7794227, -167.1101299>,
    <0.7787300, -167.1123215>,
    <0.7787954, -167.1199784>,
    <0.7806345, -167.1041136>,
    <0.7795310, -167.1041062>,
    <0.7787707, -167.1170886>,
    <0.7797076, -167.1121091>,
    <0.7801560, -167.1041104>,
    <0.7791861, -167.1076438>,
    <0.7784541, -167.1098047>,
    <0.7787300, -167.1123215>,
    <0.7795310, -167.1041062>,
    <0.7777778, -167.1040945>,
    <0.7777778, -167.1186964>,
    <0.7791861, -167.1076438>,
    <0.7787145, -167.1041008>,
    <0.7777778, -167.1075969>,
    <0.7781269, -167.1163591>,
    <0.7782702, -167.1199382>,
    <0.7787300, -167.1123215>,
    <0.7777778, -167.1186964>,
    <0.7777778, -167.1287564>,
    <0.7787954, -167.1199784>,
    <0.7781269, -167.1163591>,
    <0.7777778, -167.1268390>,
    <0.7781213, -167.1257934>,
    <0.7787707, -167.1170886>,
    <0.7872726, -167.0805832>,
    <0.7908434, -167.0842391>,
    <0.7969819, -167.1012012>,
    <0.7777778, -167.0684463>,
    <0.7834873, -167.0684463>,
    <0.7948749, -167.0953790>,
    <0.7893926, -167.0882568>,
    <0.7806325, -167.0684463>,
    <0.7864422, -167.0747903>,
    <0.7904992, -167.0791084>,
    <0.7908434, -167.0842391>,
    <0.7834873, -167.0684463>,
    <0.7891968, -167.0684463>,
    <0.7984695, -167.0953019>,
    <0.7864422, -167.0747903>,
    <0.7863420, -167.0684463>,
    <0.7936464, -167.0813333>,
    <0.7946747, -167.0897970>,
    <0.7979626, -167.0991417>,
    <0.7908434, -167.0842391>,
    <0.7984695, -167.0953019>,
    <0.8055556, -167.1158246>,
    <0.7969819, -167.1012012>,
    <0.7946747, -167.0897970>,
    <0.8027554, -167.1077149>,
    <0.8021143, -167.1099552>,
    <0.7948749, -167.0953790>,
    <0.2058358, -167.1442610>,
    <0.2129630, -167.1533103>,
    <0.2073637, -167.1287564>,
    <0.1944444, -167.1287564>,
    <0.2085723, -167.1662209>,
    <0.2101227, -167.1408553>,
    <0.1997149, -167.1287564>,
    <0.2007016, -167.1453492>,
    <0.2105507, -167.1604034>,
    <0.2164949, -167.1706661>,
    <0.2129630, -167.1533103>,
    <0.2085723, -167.1662209>,
    <0.2222222, -167.2024179>,
    <0.2222222, -167.1607154>,
    <0.2105507, -167.1604034>,
    <0.2162818, -167.1866652>,
    <0.2222222, -167.1838308>,
    <0.2182342, -167.1575260>,
    <0.2161928, -167.1428846>,
    <0.2129630, -167.1533103>,
    <0.2222222, -167.1607154>,
    <0.2222222, -167.1287564>,
    <0.2073637, -167.1287564>,
    <0.2182342, -167.1575260>,
    <0.2222222, -167.1413913>,
    <0.2157564, -167.1287564>,
    <0.2101227, -167.1408553>,
    <0.2002912, -167.1583892>,
    <0.2037037, -167.1778641>,
    <0.2085723, -167.1662209>,
    <0.1944444, -167.1287564>,
    <0.1944444, -167.1607154>,
    <0.2064510, -167.1712941>,
    <0.2007016, -167.1453492>,
    <0.1944444, -167.1413914>,
    <0.1985012, -167.1682288>,
    <0.2002344, -167.1858539>,
    <0.2037037, -167.1778641>,
    <0.1944444, -167.1607154>,
    <0.1944444, -167.2024179>,
    <0.2083451, -167.2024179>,
    <0.1985012, -167.1682288>,
    <0.1944444, -167.1838308>,
    <0.2005279, -167.2024179>,
    <0.2063240, -167.1917260>,
    <0.2107108, -167.1872302>,
    <0.2037037, -167.1778641>,
    <0.2083451, -167.2024179>,
    <0.2222222, -167.2024179>,
    <0.2085723, -167.1662209>,
    <0.2063240, -167.1917260>,
    <0.2161510, -167.2024179>,
    <0.2162818, -167.1866652>,
    <0.2064510, -167.1712941>,
    <0.7893436, -167.2232074>,
    <0.7962963, -167.2357456>,
    <0.7916785, -167.2024179>,
    <0.7777778, -167.2024179>,
    <0.7916219, -167.2522483>,
    <0.7936962, -167.2169804>,
    <0.7838612, -167.2024179>,
    <0.7838257, -167.2241867>,
    <0.7936640, -167.2450388>,
    <0.7997573, -167.2602946>,
    <0.7962963, -167.2357456>,
    <0.7916219, -167.2522483>,
    <0.8055556, -167.3024008>,
    <0.8055556, -167.2507837>,
    <0.7936640, -167.2450388>,
    <0.7994491, -167.2804214>,
    <0.8055556, -167.2798504>,
    <0.8014999, -167.2441968>,
    <0.7997715, -167.2228413>,
    <0.7962963, -167.2357456>,
    <0.8055556, -167.2507837>,
    <0.8055556, -167.2024179>,
    <0.7916785, -167.2024179>,
    <0.8014999, -167.2441968>,
    <0.8055556, -167.2235884>,
    <0.7994844, -167.2024179>,
    <0.7936962, -167.2169804>,
    <0.7836479, -167.1582978>,
    <0.7870370, -167.1778641>,
    <0.7919990, -167.1664684>,
    <0.7777778, -167.1287564>,
    <0.7777778, -167.1601023>,
    <0.7898358, -167.1714363>,
    <0.7841356, -167.1456163>,
    <0.7777778, -167.1407348>,
    <0.7818335, -167.1678822>,
    <0.7835678, -167.1857006>,
    <0.7870370, -167.1778641>,
    <0.7777778, -167.1601023>,
    <0.7777778, -167.2024179>,
    <0.7916785, -167.2024179>,
    <0.7818335, -167.1678822>,
    <0.7777778, -167.1835237>,
    <0.7838612, -167.2024179>,
    <0.7896601, -167.1917403>,
    <0.7940675, -167.1872921>,
    <0.7870370, -167.1778641>,
    <0.7916785, -167.2024179>,
    <0.8055556, -167.2024179>,
    <0.7919990, -167.1664684>,
    <0.7896601, -167.1917403>,
    <0.7994844, -167.2024179>,
    <0.7996651, -167.1867974>,
    <0.7898358, -167.1714363>,
    <0.2129661, -167.0791466>,
    <0.2167693, -167.0842391>,
    <0.2151889, -167.0954548>,
    <0.2058634, -167.0684463>,
    <0.2140428, -167.0684463>,
    <0.2158206, -167.0909715>,
    <0.2103591, -167.0814668>,
    <0.2099531, -167.0684463>,
    <0.2152251, -167.0752946>,
    <0.2188141, -167.0790013>,
    <0.2167693, -167.0842391>,
    <0.2140428, -167.0684463>,
    <0.2222222, -167.0684463>,
    <0.2222222, -167.0948736>,
    <0.2152251, -167.0752946>,
    <0.2181325, -167.0684463>,
    <0.2222222, -167.0819272>,
    <0.2199092, -167.0903626>,
    <0.2191007, -167.0975980>,
    <0.2167693, -167.0842391>,
    <0.2222222, -167.0948736>,
    <0.2222222, -167.1158246>,
    <0.2151889, -167.0954548>,
    <0.2199092, -167.0903626>,
    <0.2222222, -167.1098105>,
    <0.2194525, -167.1078030>,
    <0.2158206, -167.0909715>,
    <0.2039344, -167.0805760>,
    <0.2075090, -167.0842391>,
    <0.2136317, -167.1011725>,
    <0.1944444, -167.0684463>,
    <0.2001524, -167.0684463>,
    <0.2115119, -167.0953099>,
    <0.2060465, -167.0882350>,
    <0.1972984, -167.0684463>,
    <0.2031053, -167.0747853>,
    <0.2071774, -167.0791466>,
    <0.2075090, -167.0842391>,
    <0.2001524, -167.0684463>,
    <0.2058604, -167.0684463>,
    <0.2151876, -167.0954548>,
    <0.2031053, -167.0747853>,
    <0.2030064, -167.0684463>,
    <0.2103569, -167.0814668>,
    <0.2113653, -167.0898717>,
    <0.2146376, -167.0991727>,
    <0.2075090, -167.0842391>,
    <0.2151876, -167.0954548>,
    <0.2222222, -167.1158246>,
    <0.2136317, -167.1011725>,
    <0.2113653, -167.0898717>,
    <0.2194520, -167.1078030>,
    <0.2187731, -167.1099418>,
    <0.2115119, -167.0953099>,
    <0.2015561, -167.0912293>,
    <0.2037037, -167.1000319>,
    <0.1944444, -167.0952665>,
    <0.1944444, -167.0684463>,
    <0.2136317, -167.1011725>,
    <0.1984347, -167.0973201>,
    <0.1944444, -167.0823113>,
    <0.2060465, -167.0882350>,
    <0.2085931, -167.1005936>,
    <0.2118284, -167.1082134>,
    <0.2037037, -167.1000319>,
    <0.2136317, -167.1011725>,
    <0.2222222, -167.1158246>,
    <0.2077560, -167.1158246>,
    <0.2085931, -167.1005936>,
    <0.2187731, -167.1099418>,
    <0.2159692, -167.1158246>,
    <0.2058648, -167.1084543>,
    <0.2000871, -167.1067369>,
    <0.2037037, -167.1000319>,
    <0.2077560, -167.1158246>,
    <0.1944444, -167.1158246>,
    <0.1944444, -167.0952665>,
    <0.2058648, -167.1084543>,
    <0.1999345, -167.1158246>,
    <0.1944444, -167.1100137>,
    <0.1984347, -167.0973201>,
    <0.7891258, -167.1384076>,
    <0.7962963, -167.1524837>,
    <0.7913343, -167.1694972>,
    <0.7777778, -167.1158246>,
    <0.7910947, -167.1158246>,
    <0.7934957, -167.1620862>,
    <0.7835059, -167.1385031>,
    <0.7832699, -167.1158246>,
    <0.7933466, -167.1316950>,
    <0.7996255, -167.1377552>,
    <0.7962963, -167.1524837>,
    <0.7910947, -167.1158246>,
    <0.8055556, -167.1158246>,
    <0.8055556, -167.1668877>,
    <0.7933466, -167.1316950>,
    <0.7993063, -167.1158246>,
    <0.8055556, -167.1356731>,
    <0.8014941, -167.1605695>,
    <0.7996854, -167.1786677>,
    <0.7962963, -167.1524837>,
    <0.8055556, -167.1668877>,
    <0.8055556, -167.2258020>,
    <0.7913343, -167.1694972>,
    <0.8014941, -167.1605695>,
    <0.8055556, -167.1999361>,
    <0.7992910, -167.2009995>,
    <0.7934957, -167.1620862>,
    <0.7848936, -167.0909571>,
    <0.7870370, -167.1000319>,
    <0.7777778, -167.0941490>,
    <0.7777778, -167.0684463>,
    <0.7969819, -167.1012012>,
    <0.7817759, -167.0966892>,
    <0.7777778, -167.0814301>,
    <0.7893926, -167.0882568>,
    <0.7919308, -167.1006073>,
    <0.7951673, -167.1082206>,
    <0.7870370, -167.1000319>,
    <0.7969819, -167.1012012>,
    <0.8055556, -167.1158246>,
    <0.7910947, -167.1158246>,
    <0.7919308, -167.1006073>,
    <0.8021143, -167.1099552>,
    <0.7993063, -167.1158246>,
    <0.7892015, -167.1084562>,
    <0.7834218, -167.1064575>,
    <0.7870370, -167.1000319>,
    <0.7910947, -167.1158246>,
    <0.7777778, -167.1158246>,
    <0.7777778, -167.0941490>,
    <0.7892015, -167.1084562>,
    <0.7832699, -167.1158246>,
    <0.7777778, -167.1094425>,
    <0.7817759, -167.0966892>,
    <0.2060103, -167.2232074>,
    <0.2129630, -167.2357456>,
    <0.2083451, -167.2024179>,
    <0.1944444, -167.2024179>,
    <0.2082886, -167.2522483>,
    <0.2103629, -167.2169804>,
    <0.2005279, -167.2024179>,
    <0.2004924, -167.2241867>,
    <0.2103307, -167.2450388>,
    <0.2164240, -167.2602946>,
    <0.2129630, -167.2357456>,
    <0.2082886, -167.2522483>,
    <0.2222222, -167.3024008>,
    <0.2222222, -167.2507837>,
    <0.2103307, -167.2450388>,
    <0.2161158, -167.2804214>,
    <0.2222222, -167.2798504>,
    <0.2181665, -167.2441968>,
    <0.2164381, -167.2228413>,
    <0.2129630, -167.2357456>,
    <0.2222222, -167.2507837>,
    <0.2222222, -167.2024179>,
    <0.2083451, -167.2024179>,
    <0.2181665, -167.2441968>,
    <0.2222222, -167.2235884>,
    <0.2161510, -167.2024179>,
    <0.2103629, -167.2169804>,
    <0.2002203, -167.2436308>,
    <0.2037037, -167.2690732>,
    <0.2082886, -167.2522483>,
    <0.1944444, -167.2024179>,
    <0.1944444, -167.2507837>,
    <0.2062840, -167.2596042>,
    <0.2004924, -167.2241867>,
    <0.1944444, -167.2235884>,
    <0.1984938, -167.2587824>,
    <0.2002341, -167.2811646>,
    <0.2037037, -167.2690732>,
    <0.1944444, -167.2507837>,
    <0.1944444, -167.3024008>,
    <0.2083439, -167.3024008>,
    <0.1984938, -167.2587824>,
    <0.1944444, -167.2798504>,
    <0.2005272, -167.3024008>,
    <0.2063155, -167.2878319>,
    <0.2106396, -167.2815307>,
    <0.2037037, -167.2690732>,
    <0.2083439, -167.3024008>,
    <0.2222222, -167.3024008>,
    <0.2082886, -167.2522483>,
    <0.2063155, -167.2878319>,
    <0.2161504, -167.3024008>,
    <0.2161158, -167.2804214>,
    <0.2062840, -167.2596042>,
    <0.7893450, -167.3280360>,
    <0.7962963, -167.3434849>,
    <0.7916773, -167.3024008>,
    <0.7777778, -167.3024008>,
    <0.7916285, -167.3638575>,
    <0.7936959, -167.3203558>,
    <0.7838606, -167.3024008>,
    <0.7838300, -167.3292549>,
    <0.7936677, -167.3549573>,
    <0.7997590, -167.3739447>,
    <0.7962963, -167.3434849>,
    <0.7916285, -167.3638575>,
    <0.8055556, -167.4256532>,
    <0.8055556, -167.3627833>,
    <0.7936677, -167.3549573>,
    <0.7994535, -167.3985780>,
    <0.8055556, -167.3982231>,
    <0.8015002, -167.3543311>,
    <0.7997712, -167.3277674>,
    <0.7962963, -167.3434849>,
    <0.8055556, -167.3627833>,
    <0.8055556, -167.3024008>,
    <0.7916773, -167.3024008>,
    <0.8015002, -167.3543311>,
    <0.8055556, -167.3288803>,
    <0.7994838, -167.3024008>,
    <0.7936959, -167.3203558>,
    <0.7835536, -167.2436308>,
    <0.7870370, -167.2690732>,
    <0.7916219, -167.2522483>,
    <0.7777778, -167.2024179>,
    <0.7777778, -167.2507837>,
    <0.7896174, -167.2596042>,
    <0.7838257, -167.2241867>,
    <0.7777778, -167.2235884>,
    <0.7818272, -167.2587824>,
    <0.7835675, -167.2811646>,
    <0.7870370, -167.2690732>,
    <0.7777778, -167.2507837>,
    <0.7777778, -167.3024008>,
    <0.7916773, -167.3024008>,
    <0.7818272, -167.2587824>,
    <0.7777778, -167.2798504>,
    <0.7838606, -167.3024008>,
    <0.7896488, -167.2878319>,
    <0.7939730, -167.2815307>,
    <0.7870370, -167.2690732>,
    <0.7916773, -167.3024008>,
    <0.8055556, -167.3024008>,
    <0.7916219, -167.2522483>,
    <0.7896488, -167.2878319>,
    <0.7994838, -167.3024008>,
    <0.7994491, -167.2804214>,
    <0.7896174, -167.2596042>,
    <0.2057892, -167.1384003>,
    <0.2129630, -167.1524837>,
    <0.2079936, -167.1694682>,
    <0.1944444, -167.1158246>,
    <0.2077560, -167.1158246>,
    <0.2101586, -167.1620687>,
    <0.2001656, -167.1384757>,
    <0.1999345, -167.1158246>,
    <0.2100116, -167.1317048>,
    <0.2162908, -167.1378108>,
    <0.2129630, -167.1524837>,
    <0.2077560, -167.1158246>,
    <0.2222222, -167.1158246>,
    <0.2222222, -167.1671102>,
    <0.2100116, -167.1317048>,
    <0.2159692, -167.1158246>,
    <0.2222222, -167.1358300>,
    <0.2181607, -167.1606944>,
    <0.2163502, -167.1787160>,
    <0.2129630, -167.1524837>,
    <0.2222222, -167.1671102>,
    <0.2222222, -167.2258020>,
    <0.2079936, -167.1694682>,
    <0.2181607, -167.1606944>,
    <0.2222222, -167.2000642>,
    <0.2159537, -167.2009838>,
    <0.2101586, -167.1620687>,
    <0.2001465, -167.1603700>,
    <0.2037037, -167.1891429>,
    <0.1944444, -167.1670444>,
    <0.1944444, -167.1158246>,
    <0.2079936, -167.1694682>,
    <0.1984972, -167.1767170>,
    <0.1944444, -167.1357720>,
    <0.2001656, -167.1384757>,
    <0.2061210, -167.1780564>,
    <0.2105661, -167.2025537>,
    <0.2037037, -167.1891429>,
    <0.2079936, -167.1694682>,
    <0.2222222, -167.2258020>,
    <0.2083451, -167.2258020>,
    <0.2061210, -167.1780564>,
    <0.2159537, -167.2009838>,
    <0.2161511, -167.2258020>,
    <0.2063073, -167.2097072>,
    <0.2002344, -167.2019478>,
    <0.2037037, -167.1891429>,
    <0.2083451, -167.2258020>,
    <0.1944444, -167.2258020>,
    <0.1944444, -167.1670444>,
    <0.2063073, -167.2097072>,
    <0.2005278, -167.2258020>,
    <0.1944444, -167.2000293>,
    <0.1984972, -167.1767170>,
    <0.7893444, -167.2539957>,
    <0.7962963, -167.2709932>,
    <0.7916250, -167.2933857>,
    <0.7777778, -167.2258020>,
    <0.7916784, -167.2258020>,
    <0.7936657, -167.2836036>,
    <0.7838277, -167.2553296>,
    <0.7838611, -167.2258020>,
    <0.7936967, -167.2455535>,
    <0.7997715, -167.2537633>,
    <0.7962963, -167.2709932>,
    <0.7916784, -167.2258020>,
    <0.8055556, -167.2258020>,
    <0.8055556, -167.2924560>,
    <0.7936967, -167.2455535>,
    <0.7994844, -167.2258020>,
    <0.8055556, -167.2550533>,
    <0.8014999, -167.2830552>,
    <0.7997581, -167.3045527>,
    <0.7962963, -167.2709932>,
    <0.8055556, -167.2924560>,
    <0.8055556, -167.3613758>,
    <0.7916250, -167.2933857>,
    <0.8014999, -167.2830552>,
    <0.8055556, -167.3313235>,
    <0.7994513, -167.3315832>,
    <0.7936657, -167.2836036>,
    <0.7834817, -167.1604175>,
    <0.7870370, -167.1891429>,
    <0.7777778, -167.1672051>,
    <0.7777778, -167.1158246>,
    <0.7913343, -167.1694972>,
    <0.7818305, -167.1768071>,
    <0.7777778, -167.1359319>,
    <0.7835059, -167.1385031>,
    <0.7894584, -167.1780731>,
    <0.7939013, -167.2025610>,
    <0.7870370, -167.1891429>,
    <0.7913343, -167.1694972>,
    <0.8055556, -167.2258020>,
    <0.7916784, -167.2258020>,
    <0.7894584, -167.1780731>,
    <0.7992910, -167.2009995>,
    <0.7994844, -167.2258020>,
    <0.7896409, -167.2097091>,
    <0.7835678, -167.2019880>,
    <0.7870370, -167.1891429>,
    <0.7916784, -167.2258020>,
    <0.7777778, -167.2258020>,
    <0.7777778, -167.1672051>,
    <0.7896409, -167.2097091>,
    <0.7838611, -167.2258020>,
    <0.7777778, -167.2001106>,
    <0.7818305, -167.1768071>,
    <0.2060116, -167.3280360>,
    <0.2129630, -167.3434849>,
    <0.2083439, -167.3024008>,
    <0.1944444, -167.3024008>,
    <0.2082951, -167.3638575>,
    <0.2103626, -167.3203558>,
    <0.2005272, -167.3024008>,
    <0.2004966, -167.3292549>,
    <0.2103344, -167.3549573>,
    <0.2164256, -167.3739447>,
    <0.2129630, -167.3434849>,
    <0.2082951, -167.3638575>,
    <0.2222222, -167.4256532>,
    <0.2222222, -167.3627833>,
    <0.2103344, -167.3549573>,
    <0.2161202, -167.3985780>,
    <0.2222222, -167.3982231>,
    <0.2181669, -167.3543311>,
    <0.2164378, -167.3277674>,
    <0.2129630, -167.3434849>,
    <0.2222222, -167.3627833>,
    <0.2222222, -167.3024008>,
    <0.2083439, -167.3024008>,
    <0.2181669, -167.3543311>,
    <0.2222222, -167.3288803>,
    <0.2161504, -167.3024008>,
    <0.2103626, -167.3203558>,
    <0.2002219, -167.3534027>,
    <0.2037037, -167.3845690>,
    <0.2082951, -167.3638575>,
    <0.1944444, -167.3024008>,
    <0.1944444, -167.3627833>,
    <0.2062878, -167.3729124>,
    <0.2004966, -167.3292549>,
    <0.1944444, -167.3288803>,
    <0.1984943, -167.3723121>,
    <0.2002337, -167.3996647>,
    <0.2037037, -167.3845690>,
    <0.1944444, -167.3627833>,
    <0.1944444, -167.4256532>,
    <0.2083423, -167.4256532>,
    <0.1984943, -167.3723121>,
    <0.1944444, -167.3982231>,
    <0.2005264, -167.4256532>,
    <0.2063149, -167.4076960>,
    <0.2106408, -167.3999332>,
    <0.2037037, -167.3845690>,
    <0.2083423, -167.4256532>,
    <0.2222222, -167.4256532>,
    <0.2082951, -167.3638575>,
    <0.2063149, -167.4076960>,
    <0.2161497, -167.4256532>,
    <0.2161202, -167.3985780>,
    <0.2062878, -167.3729124>,
    <0.7893465, -167.4553644>,
    <0.7962963, -167.4732541>,
    <0.7916757, -167.4256532>,
    <0.7777778, -167.4256532>,
    <0.7916360, -167.4968970>,
    <0.7936953, -167.4464590>,
    <0.7838597, -167.4256532>,
    <0.7838349, -167.4567920>,
    <0.7936720, -167.4865678>,
    <0.7997609, -167.5086990>,
    <0.7962963, -167.4732541>,
    <0.7916360, -167.4968970>,
    <0.8055556, -167.5684558>,
    <0.8055556, -167.4961890>,
    <0.7936720, -167.4865678>,
    <0.7994585, -167.5371117>,
    <0.8055556, -167.5369298>,
    <0.8015007, -167.4861453>,
    <0.7997708, -167.4551874>,
    <0.7962963, -167.4732541>,
    <0.8055556, -167.4961890>,
    <0.8055556, -167.4256532>,
    <0.7916757, -167.4256532>,
    <0.8015007, -167.4861453>,
    <0.8055556, -167.4566011>,
    <0.7994830, -167.4256532>,
    <0.7936953, -167.4464590>,
    <0.7835553, -167.3534027>,
    <0.7870370, -167.3845690>,
    <0.7916285, -167.3638575>,
    <0.7777778, -167.3024008>,
    <0.7777778, -167.3627833>,
    <0.7896212, -167.3729124>,
    <0.7838300, -167.3292549>,
    <0.7777778, -167.3288803>,
    <0.7818277, -167.3723121>,
    <0.7835671, -167.3996647>,
    <0.7870370, -167.3845690>,
    <0.7777778, -167.3627833>,
    <0.7777778, -167.4256532>,
    <0.7916757, -167.4256532>,
    <0.7818277, -167.3723121>,
    <0.7777778, -167.3982231>,
    <0.7838597, -167.4256532>,
    <0.7896482, -167.4076960>,
    <0.7939742, -167.3999332>,
    <0.7870370, -167.3845690>,
    <0.7916757, -167.4256532>,
    <0.8055556, -167.4256532>,
    <0.7916285, -167.3638575>,
    <0.7896482, -167.4076960>,
    <0.7994830, -167.4256532>,
    <0.7994535, -167.3985780>,
    <0.7896212, -167.3729124>,
    <0.2060110, -167.2539957>,
    <0.2129630, -167.2709932>,
    <0.2082917, -167.2933857>,
    <0.1944444, -167.2258020>,
    <0.2083451, -167.2258020>,
    <0.2103323, -167.2836036>,
    <0.2004944, -167.2553296>,
    <0.2005278, -167.2258020>,
    <0.2103634, -167.2455535>,
    <0.2164381, -167.2537633>,
    <0.2129630, -167.2709932>,
    <0.2083451, -167.2258020>,
    <0.2222222, -167.2258020>,
    <0.2222222, -167.2924560>,
    <0.2103634, -167.2455535>,
    <0.2161511, -167.2258020>,
    <0.2222222, -167.2550533>,
    <0.2181666, -167.2830552>,
    <0.2164248, -167.3045527>,
    <0.2129630, -167.2709932>,
    <0.2222222, -167.2924560>,
    <0.2222222, -167.3613758>,
    <0.2082917, -167.2933857>,
    <0.2181666, -167.2830552>,
    <0.2222222, -167.3313235>,
    <0.2161180, -167.3315832>,
    <0.2103323, -167.2836036>,
    <0.2002211, -167.2819570>,
    <0.2037037, -167.3161845>,
    <0.1944444, -167.2924560>,
    <0.1944444, -167.2258020>,
    <0.2082917, -167.2933857>,
    <0.1984941, -167.3028339>,
    <0.1944444, -167.2550533>,
    <0.2004944, -167.2553296>,
    <0.2062858, -167.3033535>,
    <0.2106402, -167.3330804>,
    <0.2037037, -167.3161845>,
    <0.2082917, -167.2933857>,
    <0.2222222, -167.3613758>,
    <0.2083433, -167.3613758>,
    <0.2062858, -167.3033535>,
    <0.2161180, -167.3315832>,
    <0.2161502, -167.3613758>,
    <0.2063155, -167.3416247>,
    <0.2002340, -167.3328480>,
    <0.2037037, -167.3161845>,
    <0.2083433, -167.3613758>,
    <0.1944444, -167.3613758>,
    <0.1944444, -167.2924560>,
    <0.2063155, -167.3416247>,
    <0.2005268, -167.3613758>,
    <0.1944444, -167.3313235>,
    <0.1984941, -167.3028339>,
    <0.7893460, -167.3940515>,
    <0.7962963, -167.4137323>,
    <0.7916334, -167.4397221>,
    <0.7777778, -167.3613758>,
    <0.7916767, -167.3613758>,
    <0.7936704, -167.4283682>,
    <0.7838331, -167.3956156>,
    <0.7838602, -167.3613758>,
    <0.7936960, -167.3842624>,
    <0.7997710, -167.3939086>,
    <0.7962963, -167.4137323>,
    <0.7916767, -167.3613758>,
    <0.8055556, -167.3613758>,
    <0.8055556, -167.4391507>,
    <0.7936960, -167.3842624>,
    <0.7994835, -167.3613758>,
    <0.8055556, -167.3955180>,
    <0.8015005, -167.4280187>,
    <0.7997602, -167.4527626>,
    <0.7962963, -167.4137323>,
    <0.8055556, -167.4391507>,
    <0.8055556, -167.5184453>,
    <0.7916334, -167.4397221>,
    <0.8015005, -167.4280187>,
    <0.8055556, -167.4838674>,
    <0.7994569, -167.4839601>,
    <0.7936704, -167.4283682>,
    <0.7835544, -167.2819570>,
    <0.7870370, -167.3161845>,
    <0.7777778, -167.2924560>,
    <0.7777778, -167.2258020>,
    <0.7916250, -167.2933857>,
    <0.7818274, -167.3028339>,
    <0.7777778, -167.2550533>,
    <0.7838277, -167.2553296>,
    <0.7896191, -167.3033535>,
    <0.7939736, -167.3330804>,
    <0.7870370, -167.3161845>,
    <0.7916250, -167.2933857>,
    <0.8055556, -167.3613758>,
    <0.7916767, -167.3613758>,
    <0.7896191, -167.3033535>,
    <0.7994513, -167.3315832>,
    <0.7994835, -167.3613758>,
    <0.7896489, -167.3416247>,
    <0.7835673, -167.3328480>,
    <0.7870370, -167.3161845>,
    <0.7916767, -167.3613758>,
    <0.7777778, -167.3613758>,
    <0.7777778, -167.2924560>,
    <0.7896489, -167.3416247>,
    <0.7838602, -167.3613758>,
    <0.7777778, -167.3313235>,
    <0.7818274, -167.3028339>,
    <0.2060131, -167.4553644>,
    <0.2129630, -167.4732541>,
    <0.2083423, -167.4256532>,
    <0.1944444, -167.4256532>,
    <0.2083027, -167.4968970>,
    <0.2103620, -167.4464590>,
    <0.2005264, -167.4256532>,
    <0.2005015, -167.4567920>,
    <0.2103387, -167.4865678>,
    <0.2164275, -167.5086990>,
    <0.2129630, -167.4732541>,
    <0.2083027, -167.4968970>,
    <0.2222222, -167.5684558>,
    <0.2222222, -167.4961890>,
    <0.2103387, -167.4865678>,
    <0.2161252, -167.5371117>,
    <0.2222222, -167.5369298>,
    <0.2181674, -167.4861453>,
    <0.2164374, -167.4551874>,
    <0.2129630, -167.4732541>,
    <0.2222222, -167.4961890>,
    <0.2222222, -167.4256532>,
    <0.2083423, -167.4256532>,
    <0.2181674, -167.4861453>,
    <0.2222222, -167.4566011>,
    <0.2161497, -167.4256532>,
    <0.2103620, -167.4464590>,
    <0.2002238, -167.4848985>,
    <0.2037037, -167.5208549>,
    <0.2083027, -167.4968970>,
    <0.1944444, -167.4256532>,
    <0.1944444, -167.4961890>,
    <0.2062922, -167.5073705>,
    <0.2005015, -167.4567920>,
    <0.1944444, -167.4566011>,
    <0.1984949, -167.5069791>,
    <0.2002332, -167.5384889>,
    <0.2037037, -167.5208549>,
    <0.1944444, -167.4961890>,
    <0.1944444, -167.5684558>,
    <0.2083404, -167.5684558>,
    <0.1984949, -167.5069791>,
    <0.1944444, -167.5369297>,
    <0.2005253, -167.5684558>,
    <0.2063139, -167.5476517>,
    <0.2106422, -167.5386659>,
    <0.2037037, -167.5208549>,
    <0.2083404, -167.5684558>,
    <0.2222222, -167.5684558>,
    <0.2083027, -167.4968970>,
    <0.2063139, -167.5476517>,
    <0.2161487, -167.5684558>,
    <0.2161252, -167.5371117>,
    <0.2062922, -167.5073705>,
    <0.7893480, -167.6013336>,
    <0.7962963, -167.6211112>,
    <0.7916738, -167.5684558>,
    <0.7777778, -167.5684558>,
    <0.7916443, -167.6473117>,
    <0.7936944, -167.5914725>,
    <0.7838587, -167.5684558>,
    <0.7838402, -167.6029317>,
    <0.7936768, -167.6358644>,
    <0.7997629, -167.6604338>,
    <0.7962963, -167.6211112>,
    <0.7916443, -167.6473117>,
    <0.8055556, -167.7264218>,
    <0.8055556, -167.6468904>,
    <0.7936768, -167.6358644>,
    <0.7994640, -167.6917804>,
    <0.8055556, -167.6917086>,
    <0.8015013, -167.6356026>,
    <0.7997703, -167.6012283>,
    <0.7962963, -167.6211112>,
    <0.8055556, -167.6468904>,
    <0.8055556, -167.5684558>,
    <0.7916738, -167.5684558>,
    <0.8015013, -167.6356026>,
    <0.8055556, -167.6028579>,
    <0.7994820, -167.5684558>,
    <0.7936944, -167.5914725>,
    <0.7835572, -167.4848985>,
    <0.7870370, -167.5208549>,
    <0.7916360, -167.4968970>,
    <0.7777778, -167.4256532>,
    <0.7777778, -167.4961890>,
    <0.7896255, -167.5073705>,
    <0.7838349, -167.4567920>,
    <0.7777778, -167.4566011>,
    <0.7818282, -167.5069791>,
    <0.7835666, -167.5384889>,
    <0.7870370, -167.5208549>,
    <0.7777778, -167.4961890>,
    <0.7777778, -167.5684558>,
    <0.7916738, -167.5684558>,
    <0.7818282, -167.5069791>,
    <0.7777778, -167.5369297>,
    <0.7838587, -167.5684558>,
    <0.7896473, -167.5476517>,
    <0.7939756, -167.5386659>,
    <0.7870370, -167.5208549>,
    <0.7916738, -167.5684558>,
    <0.8055556, -167.5684558>,
    <0.7916360, -167.4968970>,
    <0.7896473, -167.5476517>,
    <0.7994820, -167.5684558>,
    <0.7994585, -167.5371117>,
    <0.7896255, -167.5073705>,
    <0.2060147, -167.6013336>,
    <0.2129630, -167.6211112>,
    <0.2083404, -167.5684558>,
    <0.1944444, -167.5684558>,
    <0.2083110, -167.6473117>,
    <0.2103610, -167.5914725>,
    <0.2005253, -167.5684558>,
    <0.2005069, -167.6029317>,
    <0.2103435, -167.6358644>,
    <0.2164296, -167.6604338>,
    <0.2129630, -167.6211112>,
    <0.2083110, -167.6473117>,
    <0.2222222, -167.7264218>,
    <0.2222222, -167.6468904>,
    <0.2103435, -167.6358644>,
    <0.2161306, -167.6917804>,
    <0.2222222, -167.6917086>,
    <0.2181679, -167.6356026>,
    <0.2164369, -167.6012283>,
    <0.2129630, -167.6211112>,
    <0.2222222, -167.6468904>,
    <0.2222222, -167.5684558>,
    <0.2083404, -167.5684558>,
    <0.2181679, -167.6356026>,
    <0.2222222, -167.6028579>,
    <0.2161487, -167.5684558>,
    <0.2103610, -167.5914725>,
    <0.2002259, -167.6341061>,
    <0.2037037, -167.6737665>,
    <0.2083110, -167.6473117>,
    <0.1944444, -167.5684558>,
    <0.1944444, -167.6468904>,
    <0.2062970, -167.6588757>,
    <0.2005069, -167.6029317>,
    <0.1944444, -167.6028580>,
    <0.1984955, -167.6586490>,
    <0.2002327, -167.6933751>,
    <0.2037037, -167.6737665>,
    <0.1944444, -167.6468904>,
    <0.1944444, -167.7264218>,
    <0.2083382, -167.7264218>,
    <0.1984955, -167.6586490>,
    <0.1944444, -167.6917086>,
    <0.2005242, -167.7264218>,
    <0.2063127, -167.7034090>,
    <0.2106438, -167.6934805>,
    <0.2037037, -167.6737665>,
    <0.2083382, -167.7264218>,
    <0.2222222, -167.7264218>,
    <0.2083110, -167.6473117>,
    <0.2063127, -167.7034090>,
    <0.2161476, -167.7264218>,
    <0.2161306, -167.6917804>,
    <0.2062970, -167.6588757>,
    <0.7893346, -167.7613888>,
    <0.7962963, -167.7825485>,
    <0.7916716, -167.7264218>,
    <0.7777778, -167.7264218>,
    <0.7915926, -167.8101630>,
    <0.7936907, -167.7509260>,
    <0.7838575, -167.7264218>,
    <0.7838101, -167.7629877>,
    <0.7936478, -167.7980973>,
    <0.7997500, -167.8234687>,
    <0.7962963, -167.7825485>,
    <0.7915926, -167.8101630>,
    <0.8055556, -167.8948019>,
    <0.8055556, -167.8063614>,
    <0.7936478, -167.7980973>,
    <0.7994870, -167.8580162>,
    <0.8055556, -167.8564263>,
    <0.8015015, -167.7959353>,
    <0.7997697, -167.7604384>,
    <0.7962963, -167.7825485>,
    <0.8055556, -167.8063614>,
    <0.8055556, -167.7264218>,
    <0.7916716, -167.7264218>,
    <0.8015015, -167.7959353>,
    <0.8055556, -167.7609714>,
    <0.7994809, -167.7264218>,
    <0.7936907, -167.7509260>,
    <0.7835592, -167.6341061>,
    <0.7870370, -167.6737665>,
    <0.7916443, -167.6473117>,
    <0.7777778, -167.5684558>,
    <0.7777778, -167.6468904>,
    <0.7896304, -167.6588757>,
    <0.7838402, -167.6029317>,
    <0.7777778, -167.6028580>,
    <0.7818288, -167.6586490>,
    <0.7835660, -167.6933751>,
    <0.7870370, -167.6737665>,
    <0.7777778, -167.6468904>,
    <0.7777778, -167.7264218>,
    <0.7916716, -167.7264218>,
    <0.7818288, -167.6586490>,
    <0.7777778, -167.6917086>,
    <0.7838575, -167.7264218>,
    <0.7896461, -167.7034090>,
    <0.7939771, -167.6934805>,
    <0.7870370, -167.6737665>,
    <0.7916716, -167.7264218>,
    <0.8055556, -167.7264218>,
    <0.7916443, -167.6473117>,
    <0.7896461, -167.7034090>,
    <0.7994809, -167.7264218>,
    <0.7994640, -167.6917804>,
    <0.7896304, -167.6588757>,
    <0.2060127, -167.3940515>,
    <0.2129630, -167.4137323>,
    <0.2083000, -167.4397221>,
    <0.1944444, -167.3613758>,
    <0.2083433, -167.3613758>,
    <0.2103371, -167.4283682>,
    <0.2004998, -167.3956156>,
    <0.2005268, -167.3613758>,
    <0.2103627, -167.3842624>,
    <0.2164377, -167.3939086>,
    <0.2129630, -167.4137323>,
    <0.2083433, -167.3613758>,
    <0.2222222, -167.3613758>,
    <0.2222222, -167.4391507>,
    <0.2103627, -167.3842624>,
    <0.2161502, -167.3613758>,
    <0.2222222, -167.3955180>,
    <0.2181671, -167.4280187>,
    <0.2164268, -167.4527626>,
    <0.2129630, -167.4137323>,
    <0.2222222, -167.4391507>,
    <0.2222222, -167.5184453>,
    <0.2083000, -167.4397221>,
    <0.2181671, -167.4280187>,
    <0.2222222, -167.4838674>,
    <0.2161235, -167.4839601>,
    <0.2103371, -167.4283682>,
    <0.2002231, -167.4265843>,
    <0.2037037, -167.4660888>,
    <0.1944444, -167.4391507>,
    <0.1944444, -167.3613758>,
    <0.2083000, -167.4397221>,
    <0.1984947, -167.4509341>,
    <0.1944444, -167.3955180>,
    <0.2004998, -167.3956156>,
    <0.2062906, -167.4512490>,
    <0.2106418, -167.4856754>,
    <0.2037037, -167.4660888>,
    <0.2083000, -167.4397221>,
    <0.2222222, -167.5184453>,
    <0.2083412, -167.5184453>,
    <0.2062906, -167.4512490>,
    <0.2161235, -167.4839601>,
    <0.2161491, -167.5184453>,
    <0.2063145, -167.4955641>,
    <0.2002334, -167.4855325>,
    <0.2037037, -167.4660888>,
    <0.2083412, -167.5184453>,
    <0.1944444, -167.5184453>,
    <0.1944444, -167.4391507>,
    <0.2063145, -167.4955641>,
    <0.2005257, -167.5184453>,
    <0.1944444, -167.4838674>,
    <0.1984947, -167.4509341>,
    <0.7893478, -167.5546111>,
    <0.7962963, -167.5763713>,
    <0.7916424, -167.6051824>,
    <0.7777778, -167.5184453>,
    <0.7916745, -167.5184453>,
    <0.7936756, -167.5925951>,
    <0.7838390, -167.5563642>,
    <0.7838591, -167.5184453>,
    <0.7936950, -167.5437683>,
    <0.7997705, -167.5545331>,
    <0.7962963, -167.5763713>,
    <0.7916745, -167.5184453>,
    <0.8055556, -167.5184453>,
    <0.8055556, -167.6048705>,
    <0.7936950, -167.5437683>,
    <0.7994825, -167.5184453>,
    <0.8055556, -167.5563664>,
    <0.8015011, -167.5923911>,
    <0.7997625, -167.6196618>,
    <0.7962963, -167.5763713>,
    <0.8055556, -167.6048705>,
    <0.8055556, -167.6922232>,
    <0.7916424, -167.6051824>,
    <0.8015011, -167.5923911>,
    <0.8055556, -167.6541051>,
    <0.7994628, -167.6541068>,
    <0.7936756, -167.5925951>,
    <0.7835565, -167.4265843>,
    <0.7870370, -167.4660888>,
    <0.7777778, -167.4391507>,
    <0.7777778, -167.3613758>,
    <0.7916334, -167.4397221>,
    <0.7818280, -167.4509341>,
    <0.7777778, -167.3955180>,
    <0.7838331, -167.3956156>,
    <0.7896240, -167.4512490>,
    <0.7939751, -167.4856754>,
    <0.7870370, -167.4660888>,
    <0.7916334, -167.4397221>,
    <0.8055556, -167.5184453>,
    <0.7916745, -167.5184453>,
    <0.7896240, -167.4512490>,
    <0.7994569, -167.4839601>,
    <0.7994825, -167.5184453>,
    <0.7896478, -167.4955641>,
    <0.7835668, -167.4855325>,
    <0.7870370, -167.4660888>,
    <0.7916745, -167.5184453>,
    <0.7777778, -167.5184453>,
    <0.7777778, -167.4391507>,
    <0.7896478, -167.4955641>,
    <0.7838591, -167.5184453>,
    <0.7777778, -167.4838674>,
    <0.7818280, -167.4509341>,
    <0.2060043, -167.7614075>,
    <0.2129630, -167.7825485>,
    <0.2083382, -167.7264218>,
    <0.1944444, -167.7264218>,
    <0.2082716, -167.8102378>,
    <0.2103577, -167.7509303>,
    <0.2005242, -167.7264218>,
    <0.2004836, -167.7630294>,
    <0.2103215, -167.7981391>,
    <0.2164197, -167.8235114>,
    <0.2129630, -167.7825485>,
    <0.2082716, -167.8102378>,
    <0.2222222, -167.8948019>,
    <0.2222222, -167.8064572>,
    <0.2103215, -167.7981391>,
    <0.2162036, -167.8583191>,
    <0.2222222, -167.8574111>,
    <0.2181683, -167.7959894>,
    <0.2164364, -167.7604624>,
    <0.2129630, -167.7825485>,
    <0.2222222, -167.8064572>,
    <0.2222222, -167.7264218>,
    <0.2083382, -167.7264218>,
    <0.2181683, -167.7959894>,
    <0.2222222, -167.7610206>,
    <0.2161476, -167.7264218>,
    <0.2103577, -167.7509303>,
    <0.2002160, -167.7954511>,
    <0.2037037, -167.8386752>,
    <0.2082716, -167.8102378>,
    <0.1944444, -167.7264218>,
    <0.1944444, -167.8064696>,
    <0.2062744, -167.8226714>,
    <0.2004836, -167.7630294>,
    <0.1944444, -167.7610269>,
    <0.1984909, -167.8205442>,
    <0.2002351, -167.8586872>,
    <0.2037037, -167.8386752>,
    <0.1944444, -167.8064696>,
    <0.1944444, -167.8948019>,
    <0.2083478, -167.8948019>,
    <0.1984909, -167.8205442>,
    <0.1944444, -167.8572258>,
    <0.2003193, -167.8948019>,
    <0.2063568, -167.8707399>,
    <0.2106363, -167.8596292>,
    <0.2037037, -167.8386752>,
    <0.2083478, -167.8948019>,
    <0.2222222, -167.8948019>,
    <0.2082716, -167.8102378>,
    <0.2063568, -167.8707399>,
    <0.2163004, -167.8948019>,
    <0.2162036, -167.8583191>,
    <0.2062744, -167.8226714>,
    <0.7884735, -167.9254542>,
    <0.7962963, -167.9526834>,
    <0.7916879, -167.8948019>,
    <0.7777778, -167.8948019>,
    <0.7881322, -167.9595294>,
    <0.7938345, -167.9217630>,
    <0.7837473, -167.8948019>,
    <0.7822118, -167.9225198>,
    <0.7913902, -167.9567974>,
    <0.7988849, -167.9831433>,
    <0.7962963, -167.9526834>,
    <0.7881322, -167.9595294>,
    <0.8055556, -168.0684463>,
    <0.8055556, -167.9519140>,
    <0.7913902, -167.9567974>,
    <0.7956985, -168.0068276>,
    <0.8055556, -167.9959565>,
    <0.8016682, -167.9522370>,
    <0.7997738, -167.9235503>,
    <0.7962963, -167.9526834>,
    <0.8055556, -167.9519140>,
    <0.8055556, -167.8948019>,
    <0.7916879, -167.8948019>,
    <0.8016682, -167.9522370>,
    <0.8055556, -167.9193977>,
    <0.7995779, -167.8948019>,
    <0.7938345, -167.9217630>,
    <0.7835463, -167.7954010>,
    <0.7870370, -167.8386752>,
    <0.7915926, -167.8101630>,
    <0.7777778, -167.7264218>,
    <0.7777778, -167.8063438>,
    <0.7895996, -167.8226370>,
    <0.7838101, -167.7629877>,
    <0.7777778, -167.7609625>,
    <0.7818229, -167.8204685>,
    <0.7835701, -167.8586557>,
    <0.7870370, -167.8386752>,
    <0.7777778, -167.8063438>,
    <0.7777778, -167.8948019>,
    <0.7916879, -167.8948019>,
    <0.7818229, -167.8204685>,
    <0.7777778, -167.8564026>,
    <0.7837473, -167.8948019>,
    <0.7896727, -167.8704826>,
    <0.7939683, -167.8596105>,
    <0.7870370, -167.8386752>,
    <0.7916879, -167.8948019>,
    <0.8055556, -167.8948019>,
    <0.7915926, -167.8101630>,
    <0.7896727, -167.8704826>,
    <0.7995779, -167.8948019>,
    <0.7994870, -167.8580162>,
    <0.7895996, -167.8226370>,
    <0.2036732, -167.9162941>,
    <0.2129630, -167.9526834>,
    <0.2083478, -167.8948019>,
    <0.1944444, -167.8948019>,
    <0.1989375, -167.9228891>,
    <0.2105307, -167.9221786>,
    <0.2003193, -167.8948019>,
    <0.1962861, -167.9063146>,
    <0.2041167, -167.9338913>,
    <0.2140862, -167.9815354>,
    <0.2129630, -167.9526834>,
    <0.1989375, -167.9228891>,
    <0.2222222, -168.0684463>,
    <0.2222222, -167.9821228>,
    <0.2041167, -167.9338913>,
    <0.2038162, -167.9533868>,
    <0.2222222, -168.0320027>,
    <0.2185015, -167.9702931>,
    <0.2164388, -167.9311025>,
    <0.2129630, -167.9526834>,
    <0.2222222, -167.9821228>,
    <0.2222222, -167.8948019>,
    <0.2083478, -167.8948019>,
    <0.2185015, -167.9702931>,
    <0.2222222, -167.9330494>,
    <0.2163004, -167.8948019>,
    <0.2105307, -167.9221786>,
    <0.1978825, -167.9451852>,
    <0.2037037, -168.0105648>,
    <0.1989375, -167.9228891>,
    <0.1944444, -167.8948019>,
    <0.1944444, -167.9524848>,
    <0.2011462, -167.9635195>,
    <0.1962861, -167.9063146>,
    <0.1944444, -167.9192443>,
    <0.1986664, -167.9789673>,
    <0.1995828, -168.0249855>,
    <0.2037037, -168.0105648>,
    <0.1944444, -167.9524848>,
    <0.1944444, -168.0684463>,
    <0.2057385, -168.0684463>,
    <0.1986664, -167.9789673>,
    <0.1944444, -167.9964636>,
    <0.1998601, -168.0684463>,
    <0.2049520, -168.0460743>,
    <0.2076505, -168.0175866>,
    <0.2037037, -168.0105648>,
    <0.2057385, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.1989375, -167.9228891>,
    <0.2049520, -168.0460743>,
    <0.2124736, -168.0684463>,
    <0.2038162, -167.9533868>,
    <0.2011462, -167.9635195>,
    <0.7826812, -167.9541880>,
    <0.7870370, -168.0105648>,
    <0.7881322, -167.9595294>,
    <0.7777778, -167.8948019>,
    <0.7777778, -167.9518560>,
    <0.7876328, -167.9828027>,
    <0.7822118, -167.9225198>,
    <0.7777778, -167.9193630>,
    <0.7819741, -167.9784628>,
    <0.7835648, -168.0248284>,
    <0.7870370, -168.0105648>,
    <0.7777778, -167.9518560>,
    <0.7777778, -168.0684463>,
    <0.7916667, -168.0684463>,
    <0.7819741, -167.9784628>,
    <0.7777778, -167.9958768>,
    <0.7847222, -168.0684463>,
    <0.7897820, -168.0448831>,
    <0.7930979, -168.0267467>,
    <0.7870370, -168.0105648>,
    <0.7916667, -168.0684463>,
    <0.8055556, -168.0684463>,
    <0.7881322, -167.9595294>,
    <0.7897820, -168.0448831>,
    <0.7986111, -168.0684463>,
    <0.7956985, -168.0068276>,
    <0.7876328, -167.9828027>,
    <0.2060144, -167.5546111>,
    <0.2129630, -167.5763713>,
    <0.2083090, -167.6051824>,
    <0.1944444, -167.5184453>,
    <0.2083412, -167.5184453>,
    <0.2103423, -167.5925951>,
    <0.2005056, -167.5563642>,
    <0.2005257, -167.5184453>,
    <0.2103616, -167.5437683>,
    <0.2164371, -167.5545331>,
    <0.2129630, -167.5763713>,
    <0.2083412, -167.5184453>,
    <0.2222222, -167.5184453>,
    <0.2222222, -167.6048705>,
    <0.2103616, -167.5437683>,
    <0.2161491, -167.5184453>,
    <0.2222222, -167.5563664>,
    <0.2181677, -167.5923911>,
    <0.2164291, -167.6196618>,
    <0.2129630, -167.5763713>,
    <0.2222222, -167.6048705>,
    <0.2222222, -167.6922232>,
    <0.2083090, -167.6051824>,
    <0.2181677, -167.5923911>,
    <0.2222222, -167.6541051>,
    <0.2161294, -167.6541068>,
    <0.2103423, -167.5925951>,
    <0.2002254, -167.5906989>,
    <0.2037037, -167.6342972>,
    <0.1944444, -167.6048705>,
    <0.1944444, -167.5184453>,
    <0.2083090, -167.6051824>,
    <0.1984953, -167.6177446>,
    <0.1944444, -167.5563664>,
    <0.2005056, -167.5563642>,
    <0.2062959, -167.6179095>,
    <0.2106434, -167.6559815>,
    <0.2037037, -167.6342972>,
    <0.2083090, -167.6051824>,
    <0.2222222, -167.6922232>,
    <0.2083387, -167.6922232>,
    <0.2062959, -167.6179095>,
    <0.2161294, -167.6541068>,
    <0.2161479, -167.6922232>,
    <0.2063131, -167.6669079>,
    <0.2002328, -167.6559035>,
    <0.2037037, -167.6342972>,
    <0.2083387, -167.6922232>,
    <0.1944444, -167.6922232>,
    <0.1944444, -167.6048705>,
    <0.2063131, -167.6669079>,
    <0.2005244, -167.6922232>,
    <0.1944444, -167.6541051>,
    <0.1984953, -167.6177446>,
    <0.7893338, -167.7306778>,
    <0.7962963, -167.7539575>,
    <0.7915891, -167.7843073>,
    <0.7777778, -167.6922232>,
    <0.7916721, -167.6922232>,
    <0.7936458, -167.7710467>,
    <0.7838080, -167.7324285>,
    <0.7838578, -167.6922232>,
    <0.7936910, -167.7191766>,
    <0.7997699, -167.7297297>,
    <0.7962963, -167.7539575>,
    <0.7916721, -167.6922232>,
    <0.8055556, -167.6922232>,
    <0.8055556, -167.7805148>,
    <0.7936910, -167.7191766>,
    <0.7994812, -167.6922232>,
    <0.8055556, -167.7304324>,
    <0.8015014, -167.7688867>,
    <0.7997491, -167.7990514>,
    <0.7962963, -167.7539575>,
    <0.8055556, -167.7805148>,
    <0.8055556, -167.8774261>,
    <0.7915891, -167.7843073>,
    <0.8015014, -167.7688867>,
    <0.8055556, -167.8342005>,
    <0.7994225, -167.8365352>,
    <0.7936458, -167.7710467>,
    <0.7835588, -167.5906989>,
    <0.7870370, -167.6342972>,
    <0.7777778, -167.6048705>,
    <0.7777778, -167.5184453>,
    <0.7916424, -167.6051824>,
    <0.7818287, -167.6177446>,
    <0.7777778, -167.5563664>,
    <0.7838390, -167.5563642>,
    <0.7896292, -167.6179095>,
    <0.7939768, -167.6559815>,
    <0.7870370, -167.6342972>,
    <0.7916424, -167.6051824>,
    <0.8055556, -167.6922232>,
    <0.7916721, -167.6922232>,
    <0.7896292, -167.6179095>,
    <0.7994628, -167.6541068>,
    <0.7994812, -167.6922232>,
    <0.7896464, -167.6669079>,
    <0.7835662, -167.6559035>,
    <0.7870370, -167.6342972>,
    <0.7916721, -167.6922232>,
    <0.7777778, -167.6922232>,
    <0.7777778, -167.6048705>,
    <0.7896464, -167.6669079>,
    <0.7838578, -167.6922232>,
    <0.7777778, -167.6541051>,
    <0.7818287, -167.6177446>,
    <0.2060036, -167.7306985>,
    <0.2129630, -167.7539575>,
    <0.2082682, -167.7843902>,
    <0.1944444, -167.6922232>,
    <0.2083387, -167.6922232>,
    <0.2103195, -167.7710930>,
    <0.2004816, -167.7324746>,
    <0.2005244, -167.6922232>,
    <0.2103580, -167.7191812>,
    <0.2164365, -167.7297521>,
    <0.2129630, -167.7539575>,
    <0.2083387, -167.6922232>,
    <0.2222222, -167.6922232>,
    <0.2222222, -167.7806046>,
    <0.2103580, -167.7191812>,
    <0.2161479, -167.6922232>,
    <0.2222222, -167.7304789>,
    <0.2181681, -167.7689374>,
    <0.2164189, -167.7990946>,
    <0.2129630, -167.7539575>,
    <0.2222222, -167.7806046>,
    <0.2222222, -167.8774261>,
    <0.2082682, -167.7843902>,
    <0.2181681, -167.7689374>,
    <0.2222222, -167.8355933>,
    <0.2162092, -167.8373354>,
    <0.2103195, -167.7710930>,
    <0.2002152, -167.7682303>,
    <0.2037037, -167.8156918>,
    <0.1944444, -167.7806161>,
    <0.1944444, -167.6922232>,
    <0.2082682, -167.7843902>,
    <0.1984907, -167.7959441>,
    <0.1944444, -167.7304848>,
    <0.2004816, -167.7324746>,
    <0.2062727, -167.7980741>,
    <0.2106355, -167.8387335>,
    <0.2037037, -167.8156918>,
    <0.2082682, -167.7843902>,
    <0.2222222, -167.8774261>,
    <0.2083480, -167.8774261>,
    <0.2062727, -167.7980741>,
    <0.2162092, -167.8373354>,
    <0.2162567, -167.8774261>,
    <0.2063150, -167.8504028>,
    <0.2002351, -167.8377900>,
    <0.2037037, -167.8156918>,
    <0.2083480, -167.8774261>,
    <0.1944444, -167.8774261>,
    <0.1944444, -167.7806161>,
    <0.2063150, -167.8504028>,
    <0.2005325, -167.8774261>,
    <0.1944444, -167.8343277>,
    <0.1984907, -167.7959441>,
    <0.7890795, -167.9153122>,
    <0.7962963, -167.9410995>,
    <0.7905558, -167.9652971>,
    <0.7777778, -167.8774261>,
    <0.7916882, -167.8774261>,
    <0.7930569, -167.9547544>,
    <0.7832492, -167.9150512>,
    <0.7838694, -167.8774261>,
    <0.7936840, -167.9050034>,
    <0.7997739, -167.9173922>,
    <0.7962963, -167.9410995>,
    <0.7916882, -167.8774261>,
    <0.8055556, -167.8774261>,
    <0.8055556, -167.9736171>,
    <0.7936840, -167.9050034>,
    <0.7994864, -167.8774261>,
    <0.8055556, -167.9201376>,
    <0.8014878, -167.9593314>,
    <0.7994908, -167.9871150>,
    <0.7962963, -167.9410995>,
    <0.8055556, -167.9736171>,
    <0.8055556, -168.0684463>,
    <0.7905558, -167.9652971>,
    <0.8014878, -167.9593314>,
    <0.8055556, -168.0320981>,
    <0.7983593, -168.0189592>,
    <0.7930569, -167.9547544>,
    <0.7835454, -167.7681802>,
    <0.7870370, -167.8156918>,
    <0.7777778, -167.7804984>,
    <0.7777778, -167.6922232>,
    <0.7915891, -167.7843073>,
    <0.7818227, -167.7958726>,
    <0.7777778, -167.7304241>,
    <0.7838080, -167.7324285>,
    <0.7895979, -167.7980359>,
    <0.7939675, -167.8387128>,
    <0.7870370, -167.8156918>,
    <0.7915891, -167.7843073>,
    <0.8055556, -167.8774261>,
    <0.7916882, -167.8774261>,
    <0.7895979, -167.7980359>,
    <0.7994225, -167.8365352>,
    <0.7994864, -167.8774261>,
    <0.7896481, -167.8503478>,
    <0.7835702, -167.8377606>,
    <0.7870370, -167.8156918>,
    <0.7916882, -167.8774261>,
    <0.7777778, -167.8774261>,
    <0.7777778, -167.7804984>,
    <0.7896481, -167.8503478>,
    <0.7838694, -167.8774261>,
    <0.7777778, -167.8341797>,
    <0.7818227, -167.7958726>,
    <0.2058010, -167.9157012>,
    <0.2129630, -167.9410995>,
    <0.2074488, -167.9668534>,
    <0.1944444, -167.8774261>,
    <0.2083480, -167.8774261>,
    <0.2098574, -167.9556040>,
    <0.2000453, -167.9159417>,
    <0.2005325, -167.8774261>,
    <0.2103565, -167.9051383>,
    <0.2164388, -167.9161249>,
    <0.2129630, -167.9410995>,
    <0.2083480, -167.8774261>,
    <0.2222222, -167.8774261>,
    <0.2222222, -167.9685482>,
    <0.2103565, -167.9051383>,
    <0.2162567, -167.8774261>,
    <0.2222222, -167.9163560>,
    <0.2182383, -167.9567381>,
    <0.2162140, -167.9862368>,
    <0.2129630, -167.9410995>,
    <0.2222222, -167.9685482>,
    <0.2222222, -168.0684463>,
    <0.2074488, -167.9668534>,
    <0.2182383, -167.9567381>,
    <0.2222222, -168.0299212>,
    <0.2153497, -168.0211856>,
    <0.2098574, -167.9556040>,
    <0.2000103, -167.9530456>,
    <0.2037037, -168.0047729>,
    <0.1944444, -167.9631301>,
    <0.1944444, -167.8774261>,
    <0.2074488, -167.9668534>,
    <0.1984194, -167.9810072>,
    <0.1944444, -167.9152029>,
    <0.2000453, -167.9159417>,
    <0.2057899, -167.9836497>,
    <0.2105181, -168.0271297>,
    <0.2037037, -168.0047729>,
    <0.2074488, -167.9668534>,
    <0.2222222, -168.0684463>,
    <0.2086976, -168.0684463>,
    <0.2057899, -167.9836497>,
    <0.2153497, -168.0211856>,
    <0.2165209, -168.0684463>,
    <0.2062942, -168.0378021>,
    <0.2003225, -168.0261989>,
    <0.2037037, -168.0047729>,
    <0.2086976, -168.0684463>,
    <0.1944444, -168.0684463>,
    <0.1944444, -167.9631301>,
    <0.2062942, -168.0378021>,
    <0.2005734, -168.0684463>,
    <0.1944444, -168.0169040>,
    <0.1984194, -167.9810072>,
    <0.7832871, -167.9533523>,
    <0.7870370, -168.0047729>,
    <0.7777778, -167.9659130>,
    <0.7777778, -167.8774261>,
    <0.7905558, -167.9652971>,
    <0.7817088, -167.9824111>,
    <0.7777778, -167.9164933>,
    <0.7832492, -167.9150512>,
    <0.7889640, -167.9831554>,
    <0.7939241, -168.0267406>,
    <0.7870370, -168.0047729>,
    <0.7905558, -167.9652971>,
    <0.8055556, -168.0684463>,
    <0.7925480, -168.0684463>,
    <0.7889640, -167.9831554>,
    <0.7983593, -168.0189592>,
    <0.8001099, -168.0684463>,
    <0.7895923, -168.0342964>,
    <0.7837852, -168.0268946>,
    <0.7870370, -168.0047729>,
    <0.7925480, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7777778, -167.9659130>,
    <0.7895923, -168.0342964>,
    <0.7841888, -168.0684463>,
    <0.7777778, -168.0221643>,
    <0.7817088, -167.9824111>,
    <0.2286425, -167.1109029>,
    <0.2263822, -167.1123151>,
    <0.2250809, -167.1231073>,
    <0.2347021, -167.1040945>,
    <0.2284047, -167.1040945>,
    <0.2255818, -167.1189533>,
    <0.2285743, -167.1162039>,
    <0.2315314, -167.1040945>,
    <0.2277316, -167.1068303>,
    <0.2248078, -167.1090574>,
    <0.2263822, -167.1123151>,
    <0.2284047, -167.1040945>,
    <0.2222222, -167.1040945>,
    <0.2222222, -167.1157254>,
    <0.2277316, -167.1068303>,
    <0.2253064, -167.1040945>,
    <0.2222222, -167.1077203>,
    <0.2243224, -167.1140037>,
    <0.2239769, -167.1199761>,
    <0.2263822, -167.1123151>,
    <0.2222222, -167.1157254>,
    <0.2222222, -167.1287564>,
    <0.2250809, -167.1231073>,
    <0.2243224, -167.1140037>,
    <0.2222222, -167.1243284>,
    <0.2232602, -167.1267051>,
    <0.2255818, -167.1189533>,
    <0.7698697, -167.1107971>,
    <0.7726785, -167.1123151>,
    <0.7703088, -167.1040945>,
    <0.7624800, -167.1040945>,
    <0.7740113, -167.1226843>,
    <0.7711578, -167.1070396>,
    <0.7664656, -167.1040945>,
    <0.7697369, -167.1157935>,
    <0.7734803, -167.1185536>,
    <0.7755613, -167.1206131>,
    <0.7726785, -167.1123151>,
    <0.7740113, -167.1226843>,
    <0.7777778, -167.1287564>,
    <0.7777778, -167.1186964>,
    <0.7734803, -167.1185536>,
    <0.7763965, -167.1265296>,
    <0.7777778, -167.1268390>,
    <0.7751806, -167.1154463>,
    <0.7746357, -167.1098001>,
    <0.7726785, -167.1123151>,
    <0.7777778, -167.1186964>,
    <0.7777778, -167.1040945>,
    <0.7703088, -167.1040945>,
    <0.7751806, -167.1154463>,
    <0.7777778, -167.1075969>,
    <0.7740649, -167.1040945>,
    <0.7711578, -167.1070396>,
    <0.7687094, -167.0794550>,
    <0.7723249, -167.0842391>,
    <0.7711704, -167.0966882>,
    <0.7614190, -167.0684463>,
    <0.7699234, -167.0684463>,
    <0.7716302, -167.0917299>,
    <0.7664148, -167.0829151>,
    <0.7658039, -167.0684463>,
    <0.7709677, -167.0753142>,
    <0.7744510, -167.0788202>,
    <0.7723249, -167.0842391>,
    <0.7699234, -167.0684463>,
    <0.7777778, -167.0684463>,
    <0.7777778, -167.0941490>,
    <0.7709677, -167.0753142>,
    <0.7738886, -167.0684463>,
    <0.7777778, -167.0814301>,
    <0.7754743, -167.0899627>,
    <0.7747627, -167.0977252>,
    <0.7723249, -167.0842391>,
    <0.7777778, -167.0941490>,
    <0.7777778, -167.1158246>,
    <0.7711704, -167.0966882>,
    <0.7754743, -167.0899627>,
    <0.7777778, -167.1094425>,
    <0.7752113, -167.1083916>,
    <0.7716302, -167.0917299>,
    <0.7614952, -167.1443740>,
    <0.7685185, -167.1533103>,
    <0.7631642, -167.1287564>,
    <0.7500000, -167.1287564>,
    <0.7642983, -167.1666728>,
    <0.7658062, -167.1408723>,
    <0.7554464, -167.1287564>,
    <0.7564263, -167.1457977>,
    <0.7662009, -167.1606485>,
    <0.7720931, -167.1706258>,
    <0.7685185, -167.1533103>,
    <0.7642983, -167.1666728>,
    <0.7777778, -167.2024179>,
    <0.7777778, -167.1601023>,
    <0.7662009, -167.1606485>,
    <0.7719285, -167.1869068>,
    <0.7777778, -167.1835237>,
    <0.7737939, -167.1571799>,
    <0.7718096, -167.1427314>,
    <0.7685185, -167.1533103>,
    <0.7777778, -167.1601023>,
    <0.7777778, -167.1287564>,
    <0.7631642, -167.1287564>,
    <0.7737939, -167.1571799>,
    <0.7777778, -167.1407348>,
    <0.7714674, -167.1287564>,
    <0.7658062, -167.1408723>,
    <0.7633017, -167.1173893>,
    <0.7634192, -167.1205358>,
    <0.7740112, -167.1226843>,
    <0.7624799, -167.1040945>,
    <0.7532963, -167.1222425>,
    <0.7695202, -167.1217733>,
    <0.7697368, -167.1157935>,
    <0.7569225, -167.1150765>,
    <0.7579769, -167.1214533>,
    <0.7574699, -167.1250728>,
    <0.7634192, -167.1205358>,
    <0.7532963, -167.1222425>,
    <0.7500000, -167.1287564>,
    <0.7631642, -167.1287564>,
    <0.7579769, -167.1214533>,
    <0.7512630, -167.1262605>,
    <0.7554464, -167.1287564>,
    <0.7632519, -167.1259277>,
    <0.7695931, -167.1251832>,
    <0.7634192, -167.1205358>,
    <0.7631642, -167.1287564>,
    <0.7777778, -167.1287564>,
    <0.7740112, -167.1226843>,
    <0.7632519, -167.1259277>,
    <0.7714674, -167.1287564>,
    <0.7763965, -167.1265296>,
    <0.7695202, -167.1217733>,
    <0.7565867, -167.1106867>,
    <0.7541600, -167.1123151>,
    <0.7532963, -167.1222425>,
    <0.7624799, -167.1040945>,
    <0.7564108, -167.1040945>,
    <0.7536428, -167.1182600>,
    <0.7569225, -167.1150765>,
    <0.7595056, -167.1040945>,
    <0.7555738, -167.1071515>,
    <0.7526427, -167.1100456>,
    <0.7541600, -167.1123151>,
    <0.7564108, -167.1040945>,
    <0.7500000, -167.1040945>,
    <0.7500000, -167.1196784>,
    <0.7555738, -167.1071515>,
    <0.7532278, -167.1040945>,
    <0.7500000, -167.1103620>,
    <0.7518728, -167.1163635>,
    <0.7518641, -167.1207481>,
    <0.7541600, -167.1123151>,
    <0.7500000, -167.1196784>,
    <0.7500000, -167.1287564>,
    <0.7532963, -167.1222425>,
    <0.7518728, -167.1163635>,
    <0.7500000, -167.1261981>,
    <0.7512630, -167.1262605>,
    <0.7536428, -167.1182600>,
    <0.7595522, -167.0805592>,
    <0.7630656, -167.0842391>,
    <0.7691477, -167.1011050>,
    <0.7500000, -167.0684463>,
    <0.7559955, -167.0684463>,
    <0.7669988, -167.0951461>,
    <0.7615455, -167.0881385>,
    <0.7530365, -167.0684463>,
    <0.7588345, -167.0747878>,
    <0.7629126, -167.0794550>,
    <0.7630656, -167.0842391>,
    <0.7559955, -167.0684463>,
    <0.7614190, -167.0684463>,
    <0.7711704, -167.0966882>,
    <0.7588345, -167.0747878>,
    <0.7588041, -167.0684463>,
    <0.7664148, -167.0829151>,
    <0.7671322, -167.0904856>,
    <0.7702904, -167.0994642>,
    <0.7630656, -167.0842391>,
    <0.7711704, -167.0966882>,
    <0.7777778, -167.1158246>,
    <0.7691477, -167.1011050>,
    <0.7671322, -167.0904856>,
    <0.7752113, -167.1083916>,
    <0.7743106, -167.1099110>,
    <0.7669988, -167.0951461>,
    <0.7615658, -167.2232074>,
    <0.7685185, -167.2357456>,
    <0.7639007, -167.2024179>,
    <0.7500000, -167.2024179>,
    <0.7638441, -167.2522483>,
    <0.7659185, -167.2169804>,
    <0.7560835, -167.2024179>,
    <0.7560479, -167.2241867>,
    <0.7658862, -167.2450388>,
    <0.7719796, -167.2602946>,
    <0.7685185, -167.2357456>,
    <0.7638441, -167.2522483>,
    <0.7777778, -167.3024008>,
    <0.7777778, -167.2507837>,
    <0.7658862, -167.2450388>,
    <0.7716714, -167.2804214>,
    <0.7777778, -167.2798504>,
    <0.7737221, -167.2441968>,
    <0.7719937, -167.2228413>,
    <0.7685185, -167.2357456>,
    <0.7777778, -167.2507837>,
    <0.7777778, -167.2024179>,
    <0.7639007, -167.2024179>,
    <0.7737221, -167.2441968>,
    <0.7777778, -167.2235884>,
    <0.7717066, -167.2024179>,
    <0.7659185, -167.2169804>,
    <0.7558894, -167.1584683>,
    <0.7592593, -167.1778641>,
    <0.7642983, -167.1666728>,
    <0.7500000, -167.1287564>,
    <0.7500000, -167.1605800>,
    <0.7621008, -167.1715532>,
    <0.7564263, -167.1457977>,
    <0.7500000, -167.1409327>,
    <0.7540548, -167.1681491>,
    <0.7557900, -167.1858200>,
    <0.7592593, -167.1778641>,
    <0.7500000, -167.1605800>,
    <0.7500000, -167.2024179>,
    <0.7639007, -167.2024179>,
    <0.7540548, -167.1681491>,
    <0.7500000, -167.1838663>,
    <0.7560835, -167.2024179>,
    <0.7618847, -167.1917530>,
    <0.7663090, -167.1873432>,
    <0.7592593, -167.1778641>,
    <0.7639007, -167.2024179>,
    <0.7777778, -167.2024179>,
    <0.7642983, -167.1666728>,
    <0.7618847, -167.1917530>,
    <0.7717066, -167.2024179>,
    <0.7719285, -167.1869068>,
    <0.7621008, -167.1715532>,
    <0.7613508, -167.1384097>,
    <0.7685185, -167.1524837>,
    <0.7635586, -167.1695056>,
    <0.7500000, -167.1158246>,
    <0.7633260, -167.1158246>,
    <0.7657195, -167.1620898>,
    <0.7557298, -167.1385099>,
    <0.7554976, -167.1158246>,
    <0.7655753, -167.1317050>,
    <0.7718500, -167.1378345>,
    <0.7685185, -167.1524837>,
    <0.7633260, -167.1158246>,
    <0.7777778, -167.1158246>,
    <0.7777778, -167.1672051>,
    <0.7655753, -167.1317050>,
    <0.7715342, -167.1158246>,
    <0.7777778, -167.1359319>,
    <0.7737164, -167.1607479>,
    <0.7719082, -167.1787491>,
    <0.7685185, -167.1524837>,
    <0.7777778, -167.1672051>,
    <0.7777778, -167.2258020>,
    <0.7635586, -167.1695056>,
    <0.7737164, -167.1607479>,
    <0.7777778, -167.2001106>,
    <0.7715145, -167.2010046>,
    <0.7657195, -167.1620898>,
    <0.7571017, -167.0909951>,
    <0.7592593, -167.1000319>,
    <0.7500000, -167.0943971>,
    <0.7500000, -167.0684463>,
    <0.7691477, -167.1011050>,
    <0.7540010, -167.0968319>,
    <0.7500000, -167.0814791>,
    <0.7615455, -167.0881385>,
    <0.7641307, -167.1005605>,
    <0.7673777, -167.1081965>,
    <0.7592593, -167.1000319>,
    <0.7691477, -167.1011050>,
    <0.7777778, -167.1158246>,
    <0.7633260, -167.1158246>,
    <0.7641307, -167.1005605>,
    <0.7743106, -167.1099110>,
    <0.7715342, -167.1158246>,
    <0.7614308, -167.1084649>,
    <0.7556463, -167.1065196>,
    <0.7592593, -167.1000319>,
    <0.7633260, -167.1158246>,
    <0.7500000, -167.1158246>,
    <0.7500000, -167.0943971>,
    <0.7614308, -167.1084649>,
    <0.7554976, -167.1158246>,
    <0.7500000, -167.1096995>,
    <0.7540010, -167.0968319>,
    <0.7615672, -167.3280360>,
    <0.7685185, -167.3434849>,
    <0.7638995, -167.3024008>,
    <0.7500000, -167.3024008>,
    <0.7638507, -167.3638575>,
    <0.7659182, -167.3203558>,
    <0.7560828, -167.3024008>,
    <0.7560522, -167.3292549>,
    <0.7658899, -167.3549573>,
    <0.7719812, -167.3739447>,
    <0.7685185, -167.3434849>,
    <0.7638507, -167.3638575>,
    <0.7777778, -167.4256532>,
    <0.7777778, -167.3627833>,
    <0.7658899, -167.3549573>,
    <0.7716758, -167.3985780>,
    <0.7777778, -167.3982231>,
    <0.7737225, -167.3543311>,
    <0.7719934, -167.3277674>,
    <0.7685185, -167.3434849>,
    <0.7777778, -167.3627833>,
    <0.7777778, -167.3024008>,
    <0.7638995, -167.3024008>,
    <0.7737225, -167.3543311>,
    <0.7777778, -167.3288803>,
    <0.7717060, -167.3024008>,
    <0.7659182, -167.3203558>,
    <0.7557759, -167.2436308>,
    <0.7592593, -167.2690732>,
    <0.7638441, -167.2522483>,
    <0.7500000, -167.2024179>,
    <0.7500000, -167.2507837>,
    <0.7618396, -167.2596042>,
    <0.7560479, -167.2241867>,
    <0.7500000, -167.2235884>,
    <0.7540494, -167.2587824>,
    <0.7557897, -167.2811646>,
    <0.7592593, -167.2690732>,
    <0.7500000, -167.2507837>,
    <0.7500000, -167.3024008>,
    <0.7638995, -167.3024008>,
    <0.7540494, -167.2587824>,
    <0.7500000, -167.2798504>,
    <0.7560828, -167.3024008>,
    <0.7618711, -167.2878319>,
    <0.7661952, -167.2815307>,
    <0.7592593, -167.2690732>,
    <0.7638995, -167.3024008>,
    <0.7777778, -167.3024008>,
    <0.7638441, -167.2522483>,
    <0.7618711, -167.2878319>,
    <0.7717060, -167.3024008>,
    <0.7716714, -167.2804214>,
    <0.7618396, -167.2596042>,
    <0.7615666, -167.2539957>,
    <0.7685185, -167.2709932>,
    <0.7638473, -167.2933857>,
    <0.7500000, -167.2258020>,
    <0.7639006, -167.2258020>,
    <0.7658879, -167.2836036>,
    <0.7560499, -167.2553296>,
    <0.7560834, -167.2258020>,
    <0.7659190, -167.2455535>,
    <0.7719937, -167.2537633>,
    <0.7685185, -167.2709932>,
    <0.7639006, -167.2258020>,
    <0.7777778, -167.2258020>,
    <0.7777778, -167.2924560>,
    <0.7659190, -167.2455535>,
    <0.7717066, -167.2258020>,
    <0.7777778, -167.2550533>,
    <0.7737222, -167.2830552>,
    <0.7719803, -167.3045527>,
    <0.7685185, -167.2709932>,
    <0.7777778, -167.2924560>,
    <0.7777778, -167.3613758>,
    <0.7638473, -167.2933857>,
    <0.7737222, -167.2830552>,
    <0.7777778, -167.3313235>,
    <0.7716736, -167.3315832>,
    <0.7658879, -167.2836036>,
    <0.7557045, -167.1604642>,
    <0.7592593, -167.1891429>,
    <0.7500000, -167.1673835>,
    <0.7500000, -167.1158246>,
    <0.7635586, -167.1695056>,
    <0.7540527, -167.1769074>,
    <0.7500000, -167.1360519>,
    <0.7557298, -167.1385099>,
    <0.7616818, -167.1780778>,
    <0.7661241, -167.2025631>,
    <0.7592593, -167.1891429>,
    <0.7635586, -167.1695056>,
    <0.7777778, -167.2258020>,
    <0.7639006, -167.2258020>,
    <0.7616818, -167.1780778>,
    <0.7715145, -167.2010046>,
    <0.7717066, -167.2258020>,
    <0.7618632, -167.2097098>,
    <0.7557900, -167.2020326>,
    <0.7592593, -167.1891429>,
    <0.7639006, -167.2258020>,
    <0.7500000, -167.2258020>,
    <0.7500000, -167.1673835>,
    <0.7618632, -167.2097098>,
    <0.7560834, -167.2258020>,
    <0.7500000, -167.2002138>,
    <0.7540527, -167.1769074>,
    <0.7615687, -167.4553644>,
    <0.7685185, -167.4732541>,
    <0.7638979, -167.4256532>,
    <0.7500000, -167.4256532>,
    <0.7638583, -167.4968970>,
    <0.7659175, -167.4464590>,
    <0.7560819, -167.4256532>,
    <0.7560571, -167.4567920>,
    <0.7658943, -167.4865678>,
    <0.7719831, -167.5086990>,
    <0.7685185, -167.4732541>,
    <0.7638583, -167.4968970>,
    <0.7777778, -167.5684558>,
    <0.7777778, -167.4961890>,
    <0.7658943, -167.4865678>,
    <0.7716808, -167.5371117>,
    <0.7777778, -167.5369297>,
    <0.7737229, -167.4861453>,
    <0.7719930, -167.4551874>,
    <0.7685185, -167.4732541>,
    <0.7777778, -167.4961890>,
    <0.7777778, -167.4256532>,
    <0.7638979, -167.4256532>,
    <0.7737229, -167.4861453>,
    <0.7777778, -167.4566011>,
    <0.7717052, -167.4256532>,
    <0.7659175, -167.4464590>,
    <0.7557775, -167.3534027>,
    <0.7592593, -167.3845690>,
    <0.7638507, -167.3638575>,
    <0.7500000, -167.3024008>,
    <0.7500000, -167.3627833>,
    <0.7618434, -167.3729124>,
    <0.7560522, -167.3292549>,
    <0.7500000, -167.3288803>,
    <0.7540499, -167.3723121>,
    <0.7557893, -167.3996647>,
    <0.7592593, -167.3845690>,
    <0.7500000, -167.3627833>,
    <0.7500000, -167.4256532>,
    <0.7638979, -167.4256532>,
    <0.7540499, -167.3723121>,
    <0.7500000, -167.3982231>,
    <0.7560819, -167.4256532>,
    <0.7618704, -167.4076960>,
    <0.7661964, -167.3999332>,
    <0.7592593, -167.3845690>,
    <0.7638979, -167.4256532>,
    <0.7777778, -167.4256532>,
    <0.7638507, -167.3638575>,
    <0.7618704, -167.4076960>,
    <0.7717052, -167.4256532>,
    <0.7716758, -167.3985780>,
    <0.7618434, -167.3729124>,
    <0.7615682, -167.3940515>,
    <0.7685185, -167.4137323>,
    <0.7638556, -167.4397221>,
    <0.7500000, -167.3613758>,
    <0.7638989, -167.3613758>,
    <0.7658926, -167.4283682>,
    <0.7560553, -167.3956156>,
    <0.7560824, -167.3613758>,
    <0.7659183, -167.3842624>,
    <0.7719932, -167.3939086>,
    <0.7685185, -167.4137323>,
    <0.7638989, -167.3613758>,
    <0.7777778, -167.3613758>,
    <0.7777778, -167.4391507>,
    <0.7659183, -167.3842624>,
    <0.7717058, -167.3613758>,
    <0.7777778, -167.3955180>,
    <0.7737227, -167.4280187>,
    <0.7719824, -167.4527626>,
    <0.7685185, -167.4137323>,
    <0.7777778, -167.4391507>,
    <0.7777778, -167.5184453>,
    <0.7638556, -167.4397221>,
    <0.7737227, -167.4280187>,
    <0.7777778, -167.4838674>,
    <0.7716791, -167.4839601>,
    <0.7658926, -167.4283682>,
    <0.7557766, -167.2819570>,
    <0.7592593, -167.3161845>,
    <0.7500000, -167.2924560>,
    <0.7500000, -167.2258020>,
    <0.7638473, -167.2933857>,
    <0.7540496, -167.3028339>,
    <0.7500000, -167.2550533>,
    <0.7560499, -167.2553296>,
    <0.7618414, -167.3033535>,
    <0.7661958, -167.3330804>,
    <0.7592593, -167.3161845>,
    <0.7638473, -167.2933857>,
    <0.7777778, -167.3613758>,
    <0.7638989, -167.3613758>,
    <0.7618414, -167.3033535>,
    <0.7716736, -167.3315832>,
    <0.7717058, -167.3613758>,
    <0.7618711, -167.3416247>,
    <0.7557895, -167.3328480>,
    <0.7592593, -167.3161845>,
    <0.7638989, -167.3613758>,
    <0.7500000, -167.3613758>,
    <0.7500000, -167.2924560>,
    <0.7618711, -167.3416247>,
    <0.7560824, -167.3613758>,
    <0.7500000, -167.3313235>,
    <0.7540496, -167.3028339>,
    <0.7615703, -167.6013336>,
    <0.7685185, -167.6211112>,
    <0.7638960, -167.5684558>,
    <0.7500000, -167.5684558>,
    <0.7638665, -167.6473117>,
    <0.7659166, -167.5914725>,
    <0.7560809, -167.5684558>,
    <0.7560625, -167.6029317>,
    <0.7658990, -167.6358644>,
    <0.7719852, -167.6604338>,
    <0.7685185, -167.6211112>,
    <0.7638665, -167.6473117>,
    <0.7777778, -167.7264218>,
    <0.7777778, -167.6468904>,
    <0.7658990, -167.6358644>,
    <0.7716862, -167.6917804>,
    <0.7777778, -167.6917086>,
    <0.7737235, -167.6356026>,
    <0.7719925, -167.6012283>,
    <0.7685185, -167.6211112>,
    <0.7777778, -167.6468904>,
    <0.7777778, -167.5684558>,
    <0.7638960, -167.5684558>,
    <0.7737235, -167.6356026>,
    <0.7777778, -167.6028580>,
    <0.7717043, -167.5684558>,
    <0.7659166, -167.5914725>,
    <0.7557794, -167.4848985>,
    <0.7592593, -167.5208549>,
    <0.7638583, -167.4968970>,
    <0.7500000, -167.4256532>,
    <0.7500000, -167.4961890>,
    <0.7618478, -167.5073705>,
    <0.7560571, -167.4567920>,
    <0.7500000, -167.4566011>,
    <0.7540504, -167.5069791>,
    <0.7557888, -167.5384889>,
    <0.7592593, -167.5208549>,
    <0.7500000, -167.4961890>,
    <0.7500000, -167.5684558>,
    <0.7638960, -167.5684558>,
    <0.7540504, -167.5069791>,
    <0.7500000, -167.5369298>,
    <0.7560809, -167.5684558>,
    <0.7618695, -167.5476517>,
    <0.7661978, -167.5386659>,
    <0.7592593, -167.5208549>,
    <0.7638960, -167.5684558>,
    <0.7777778, -167.5684558>,
    <0.7638583, -167.4968970>,
    <0.7618695, -167.5476517>,
    <0.7717043, -167.5684558>,
    <0.7716808, -167.5371117>,
    <0.7618478, -167.5073705>,
    <0.7615569, -167.7613895>,
    <0.7685185, -167.7825485>,
    <0.7638938, -167.7264218>,
    <0.7500000, -167.7264218>,
    <0.7638153, -167.8101657>,
    <0.7659129, -167.7509262>,
    <0.7560797, -167.7264218>,
    <0.7560326, -167.7629893>,
    <0.7658703, -167.7980987>,
    <0.7719723, -167.8234650>,
    <0.7685185, -167.7825485>,
    <0.7638153, -167.8101657>,
    <0.7777778, -167.8948019>,
    <0.7777778, -167.8063438>,
    <0.7658703, -167.7980987>,
    <0.7717096, -167.8580182>,
    <0.7777778, -167.8564026>,
    <0.7737238, -167.7959254>,
    <0.7719920, -167.7604340>,
    <0.7685185, -167.7825485>,
    <0.7777778, -167.8063438>,
    <0.7777778, -167.7264218>,
    <0.7638938, -167.7264218>,
    <0.7737238, -167.7959254>,
    <0.7777778, -167.7609625>,
    <0.7717031, -167.7264218>,
    <0.7659129, -167.7509262>,
    <0.7557815, -167.6341061>,
    <0.7592593, -167.6737665>,
    <0.7638665, -167.6473117>,
    <0.7500000, -167.5684558>,
    <0.7500000, -167.6468904>,
    <0.7618526, -167.6588757>,
    <0.7560625, -167.6029317>,
    <0.7500000, -167.6028579>,
    <0.7540511, -167.6586490>,
    <0.7557883, -167.6933751>,
    <0.7592593, -167.6737665>,
    <0.7500000, -167.6468904>,
    <0.7500000, -167.7264218>,
    <0.7638938, -167.7264218>,
    <0.7540511, -167.6586490>,
    <0.7500000, -167.6917086>,
    <0.7560797, -167.7264218>,
    <0.7618683, -167.7034090>,
    <0.7661993, -167.6934805>,
    <0.7592593, -167.6737665>,
    <0.7638938, -167.7264218>,
    <0.7777778, -167.7264218>,
    <0.7638665, -167.6473117>,
    <0.7618683, -167.7034090>,
    <0.7717031, -167.7264218>,
    <0.7716862, -167.6917804>,
    <0.7618526, -167.6588757>,
    <0.7615700, -167.5546111>,
    <0.7685185, -167.5763713>,
    <0.7638646, -167.6051824>,
    <0.7500000, -167.5184453>,
    <0.7638968, -167.5184453>,
    <0.7658979, -167.5925951>,
    <0.7560612, -167.5563642>,
    <0.7560813, -167.5184453>,
    <0.7659172, -167.5437683>,
    <0.7719927, -167.5545331>,
    <0.7685185, -167.5763713>,
    <0.7638968, -167.5184453>,
    <0.7777778, -167.5184453>,
    <0.7777778, -167.6048705>,
    <0.7659172, -167.5437683>,
    <0.7717047, -167.5184453>,
    <0.7777778, -167.5563664>,
    <0.7737233, -167.5923911>,
    <0.7719847, -167.6196618>,
    <0.7685185, -167.5763713>,
    <0.7777778, -167.6048705>,
    <0.7777778, -167.6922232>,
    <0.7638646, -167.6051824>,
    <0.7737233, -167.5923911>,
    <0.7777778, -167.6541051>,
    <0.7716850, -167.6541068>,
    <0.7658979, -167.5925951>,
    <0.7557787, -167.4265843>,
    <0.7592593, -167.4660888>,
    <0.7500000, -167.4391507>,
    <0.7500000, -167.3613758>,
    <0.7638556, -167.4397221>,
    <0.7540502, -167.4509341>,
    <0.7500000, -167.3955180>,
    <0.7560553, -167.3956156>,
    <0.7618462, -167.4512490>,
    <0.7661973, -167.4856754>,
    <0.7592593, -167.4660888>,
    <0.7638556, -167.4397221>,
    <0.7777778, -167.5184453>,
    <0.7638968, -167.5184453>,
    <0.7618462, -167.4512490>,
    <0.7716791, -167.4839601>,
    <0.7717047, -167.5184453>,
    <0.7618700, -167.4955641>,
    <0.7557890, -167.4855325>,
    <0.7592593, -167.4660888>,
    <0.7638968, -167.5184453>,
    <0.7500000, -167.5184453>,
    <0.7500000, -167.4391507>,
    <0.7618700, -167.4955641>,
    <0.7560813, -167.5184453>,
    <0.7500000, -167.4838674>,
    <0.7540502, -167.4509341>,
    <0.7606957, -167.9254539>,
    <0.7685185, -167.9526834>,
    <0.7639098, -167.8948019>,
    <0.7500000, -167.8948019>,
    <0.7603542, -167.9595283>,
    <0.7660565, -167.9217619>,
    <0.7559695, -167.8948019>,
    <0.7544313, -167.9225029>,
    <0.7636105, -167.9567983>,
    <0.7711071, -167.9831285>,
    <0.7685185, -167.9526834>,
    <0.7603542, -167.9595283>,
    <0.7777778, -168.0684463>,
    <0.7777778, -167.9518560>,
    <0.7636105, -167.9567983>,
    <0.7679219, -168.0068353>,
    <0.7777778, -167.9958768>,
    <0.7738904, -167.9522034>,
    <0.7719960, -167.9235358>,
    <0.7685185, -167.9526834>,
    <0.7777778, -167.9518560>,
    <0.7777778, -167.8948019>,
    <0.7639098, -167.8948019>,
    <0.7738904, -167.9522034>,
    <0.7777778, -167.9193630>,
    <0.7718000, -167.8948019>,
    <0.7660565, -167.9217619>,
    <0.7557686, -167.7953975>,
    <0.7592593, -167.8386752>,
    <0.7638153, -167.8101657>,
    <0.7500000, -167.7264218>,
    <0.7500000, -167.8063273>,
    <0.7618221, -167.8226380>,
    <0.7560326, -167.7629893>,
    <0.7500000, -167.7609541>,
    <0.7540452, -167.8204595>,
    <0.7557923, -167.8586516>,
    <0.7592593, -167.8386752>,
    <0.7500000, -167.8063273>,
    <0.7500000, -167.8948019>,
    <0.7639098, -167.8948019>,
    <0.7540452, -167.8204595>,
    <0.7500000, -167.8566311>,
    <0.7559695, -167.8948019>,
    <0.7618948, -167.8704831>,
    <0.7661905, -167.8596112>,
    <0.7592593, -167.8386752>,
    <0.7639098, -167.8948019>,
    <0.7777778, -167.8948019>,
    <0.7638153, -167.8101657>,
    <0.7618948, -167.8704831>,
    <0.7718000, -167.8948019>,
    <0.7717096, -167.8580182>,
    <0.7618221, -167.8226380>,
    <0.7549034, -167.9635506>,
    <0.7592593, -168.0105648>,
    <0.7603542, -167.9595283>,
    <0.7500000, -167.8948019>,
    <0.7500000, -167.9893072>,
    <0.7598673, -167.9822263>,
    <0.7544313, -167.9225029>,
    <0.7500000, -167.9361047>,
    <0.7541871, -167.9989200>,
    <0.7564897, -168.0341912>,
    <0.7592593, -168.0105648>,
    <0.7500000, -167.9893072>,
    <0.7500000, -168.0684463>,
    <0.7666995, -168.0684463>,
    <0.7541871, -167.9989200>,
    <0.7500000, -168.0291459>,
    <0.7600461, -168.0684463>,
    <0.7637113, -168.0451993>,
    <0.7660227, -168.0267464>,
    <0.7592593, -168.0105648>,
    <0.7666995, -168.0684463>,
    <0.7777778, -168.0684463>,
    <0.7603542, -167.9595283>,
    <0.7637113, -168.0451993>,
    <0.7724819, -168.0684463>,
    <0.7679219, -168.0068353>,
    <0.7598673, -167.9822263>,
    <0.7615562, -167.7306785>,
    <0.7685185, -167.7539575>,
    <0.7638117, -167.7843102>,
    <0.7500000, -167.6922232>,
    <0.7638943, -167.6922232>,
    <0.7658683, -167.7710483>,
    <0.7560305, -167.7324302>,
    <0.7560800, -167.6922232>,
    <0.7659133, -167.7191767>,
    <0.7719921, -167.7297256>,
    <0.7685185, -167.7539575>,
    <0.7638943, -167.6922232>,
    <0.7777778, -167.6922232>,
    <0.7777778, -167.7804984>,
    <0.7659133, -167.7191767>,
    <0.7717034, -167.6922232>,
    <0.7777778, -167.7304241>,
    <0.7737236, -167.7688775>,
    <0.7719715, -167.7990481>,
    <0.7685185, -167.7539575>,
    <0.7777778, -167.7804984>,
    <0.7777778, -167.8774261>,
    <0.7638117, -167.7843102>,
    <0.7737236, -167.7688775>,
    <0.7777778, -167.8341797>,
    <0.7716451, -167.8365373>,
    <0.7658683, -167.7710483>,
    <0.7557810, -167.5906989>,
    <0.7592593, -167.6342972>,
    <0.7500000, -167.6048705>,
    <0.7500000, -167.5184453>,
    <0.7638646, -167.6051824>,
    <0.7540509, -167.6177446>,
    <0.7500000, -167.5563664>,
    <0.7560612, -167.5563642>,
    <0.7618515, -167.6179095>,
    <0.7661990, -167.6559815>,
    <0.7592593, -167.6342972>,
    <0.7638646, -167.6051824>,
    <0.7777778, -167.6922232>,
    <0.7638943, -167.6922232>,
    <0.7618515, -167.6179095>,
    <0.7716850, -167.6541068>,
    <0.7717034, -167.6922232>,
    <0.7618687, -167.6669079>,
    <0.7557884, -167.6559035>,
    <0.7592593, -167.6342972>,
    <0.7638943, -167.6922232>,
    <0.7500000, -167.6922232>,
    <0.7500000, -167.6048705>,
    <0.7618687, -167.6669079>,
    <0.7560800, -167.6922232>,
    <0.7500000, -167.6541051>,
    <0.7540509, -167.6177446>,
    <0.7614476, -167.9163154>,
    <0.7685185, -167.9410995>,
    <0.7633616, -167.9693101>,
    <0.7500000, -167.8774261>,
    <0.7639101, -167.8774261>,
    <0.7656020, -167.9570543>,
    <0.7557757, -167.9171438>,
    <0.7560915, -167.8774261>,
    <0.7659213, -167.9052137>,
    <0.7719961, -167.9154661>,
    <0.7685185, -167.9410995>,
    <0.7639101, -167.8774261>,
    <0.7777778, -167.8774261>,
    <0.7777778, -167.9659130>,
    <0.7659213, -167.9052137>,
    <0.7717084, -167.8774261>,
    <0.7777778, -167.9164933>,
    <0.7737121, -167.9550175>,
    <0.7718589, -167.9861922>,
    <0.7685185, -167.9410995>,
    <0.7777778, -167.9659130>,
    <0.7777778, -168.0684463>,
    <0.7633616, -167.9693101>,
    <0.7737121, -167.9550175>,
    <0.7777778, -168.0221643>,
    <0.7712616, -168.0236363>,
    <0.7656020, -167.9570543>,
    <0.7557678, -167.7681771>,
    <0.7592593, -167.8156918>,
    <0.7500000, -167.7804832>,
    <0.7500000, -167.6922232>,
    <0.7638117, -167.7843102>,
    <0.7540450, -167.7958642>,
    <0.7500000, -167.7304163>,
    <0.7560305, -167.7324302>,
    <0.7618204, -167.7980371>,
    <0.7661897, -167.8387135>,
    <0.7592593, -167.8156918>,
    <0.7638117, -167.7843102>,
    <0.7777778, -167.8774261>,
    <0.7639101, -167.8774261>,
    <0.7618204, -167.7980371>,
    <0.7716451, -167.8365373>,
    <0.7717084, -167.8774261>,
    <0.7618702, -167.8503483>,
    <0.7557924, -167.8377568>,
    <0.7592593, -167.8156918>,
    <0.7639101, -167.8774261>,
    <0.7500000, -167.8774261>,
    <0.7500000, -167.7804832>,
    <0.7618702, -167.8503483>,
    <0.7560915, -167.8774261>,
    <0.7500000, -167.8341603>,
    <0.7540450, -167.7958642>,
    <0.7556552, -167.9555509>,
    <0.7592593, -168.0047729>,
    <0.7500000, -167.9706945>,
    <0.7500000, -167.8774261>,
    <0.7633616, -167.9693101>,
    <0.7539534, -167.9852449>,
    <0.7500000, -167.9186892>,
    <0.7557757, -167.9171438>,
    <0.7614927, -167.9854662>,
    <0.7663200, -168.0277439>,
    <0.7592593, -168.0047729>,
    <0.7633616, -167.9693101>,
    <0.7777778, -168.0684463>,
    <0.7648812, -168.0684463>,
    <0.7614927, -167.9854662>,
    <0.7712616, -168.0236363>,
    <0.7725798, -168.0684463>,
    <0.7618602, -168.0342308>,
    <0.7560351, -168.0280900>,
    <0.7592593, -168.0047729>,
    <0.7648812, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7500000, -167.9706945>,
    <0.7618602, -168.0342308>,
    <0.7562072, -168.0684463>,
    <0.7500000, -168.0323704>,
    <0.7539534, -167.9852449>,
    <0.2272598, -167.9507669>,
    <0.2314815, -168.0047729>,
    <0.2222222, -167.9685482>,
    <0.2222222, -167.8774261>,
    <0.2331132, -167.9523206>,
    <0.2266441, -167.9858479>,
    <0.2222222, -167.9163560>,
    <0.2270262, -167.9104620>,
    <0.2323613, -167.9764903>,
    <0.2375516, -168.0234965>,
    <0.2314815, -168.0047729>,
    <0.2331132, -167.9523206>,
    <0.2500000, -168.0684463>,
    <0.2356116, -168.0684463>,
    <0.2323613, -167.9764903>,
    <0.2403460, -168.0020585>,
    <0.2420336, -168.0684463>,
    <0.2333647, -168.0338067>,
    <0.2278844, -168.0275534>,
    <0.2314815, -168.0047729>,
    <0.2356116, -168.0684463>,
    <0.2222222, -168.0684463>,
    <0.2222222, -167.9685482>,
    <0.2333647, -168.0338067>,
    <0.2283948, -168.0684463>,
    <0.2222222, -168.0299212>,
    <0.2266441, -167.9858479>,
    <0.2279932, -167.7682288>,
    <0.2314815, -167.8156918>,
    <0.2222222, -167.7806046>,
    <0.2222222, -167.6922232>,
    <0.2360468, -167.7843957>,
    <0.2262686, -167.7959381>,
    <0.2222222, -167.7304789>,
    <0.2282598, -167.7324778>,
    <0.2340511, -167.7980764>,
    <0.2384134, -167.8387349>,
    <0.2314815, -167.8156918>,
    <0.2360468, -167.7843957>,
    <0.2500000, -167.8774261>,
    <0.2361253, -167.8774261>,
    <0.2340511, -167.7980764>,
    <0.2439426, -167.8370395>,
    <0.2440438, -167.8774261>,
    <0.2341345, -167.8509603>,
    <0.2280128, -167.8377871>,
    <0.2314815, -167.8156918>,
    <0.2361253, -167.8774261>,
    <0.2222222, -167.8774261>,
    <0.2222222, -167.7806046>,
    <0.2341345, -167.8509603>,
    <0.2280873, -167.8774261>,
    <0.2222222, -167.8355933>,
    <0.2262686, -167.7959381>,
    <0.2330504, -167.9120681>,
    <0.2407407, -167.9410995>,
    <0.2331132, -167.9523206>,
    <0.2222222, -167.8774261>,
    <0.2361253, -167.8774261>,
    <0.2357444, -167.9484498>,
    <0.2270262, -167.9104620>,
    <0.2280873, -167.8774261>,
    <0.2384159, -167.9090260>,
    <0.2442165, -167.9205554>,
    <0.2407407, -167.9410995>,
    <0.2361253, -167.8774261>,
    <0.2500000, -167.8774261>,
    <0.2500000, -167.9862701>,
    <0.2384159, -167.9090260>,
    <0.2440438, -167.8774261>,
    <0.2500000, -167.9253845>,
    <0.2461928, -167.9676972>,
    <0.2434635, -167.9870341>,
    <0.2407407, -167.9410995>,
    <0.2500000, -167.9862701>,
    <0.2500000, -168.0684463>,
    <0.2331132, -167.9523206>,
    <0.2461928, -167.9676972>,
    <0.2500000, -168.0267368>,
    <0.2403460, -168.0020585>,
    <0.2357444, -167.9484498>,
    <0.2280032, -167.5906989>,
    <0.2314815, -167.6342972>,
    <0.2222222, -167.6048705>,
    <0.2222222, -167.5184453>,
    <0.2360868, -167.6051824>,
    <0.2262731, -167.6177446>,
    <0.2222222, -167.5563664>,
    <0.2282834, -167.5563642>,
    <0.2340737, -167.6179095>,
    <0.2384212, -167.6559815>,
    <0.2314815, -167.6342972>,
    <0.2360868, -167.6051824>,
    <0.2500000, -167.6922232>,
    <0.2361165, -167.6922232>,
    <0.2340737, -167.6179095>,
    <0.2439072, -167.6541068>,
    <0.2439256, -167.6922232>,
    <0.2340909, -167.6669079>,
    <0.2280106, -167.6559035>,
    <0.2314815, -167.6342972>,
    <0.2361165, -167.6922232>,
    <0.2222222, -167.6922232>,
    <0.2222222, -167.6048705>,
    <0.2340909, -167.6669079>,
    <0.2283022, -167.6922232>,
    <0.2222222, -167.6541051>,
    <0.2262731, -167.6177446>,
    <0.2337816, -167.7306999>,
    <0.2407407, -167.7539575>,
    <0.2360468, -167.7843957>,
    <0.2222222, -167.6922232>,
    <0.2361165, -167.6922232>,
    <0.2380977, -167.7710961>,
    <0.2282598, -167.7324778>,
    <0.2283022, -167.6922232>,
    <0.2381358, -167.7191815>,
    <0.2442143, -167.7297487>,
    <0.2407407, -167.7539575>,
    <0.2361165, -167.6922232>,
    <0.2500000, -167.6922232>,
    <0.2500000, -167.7805911>,
    <0.2381358, -167.7191815>,
    <0.2439256, -167.6922232>,
    <0.2500000, -167.7304720>,
    <0.2459459, -167.7689298>,
    <0.2441969, -167.7990926>,
    <0.2407407, -167.7539575>,
    <0.2500000, -167.7805911>,
    <0.2500000, -167.8774261>,
    <0.2360468, -167.7843957>,
    <0.2459459, -167.7689298>,
    <0.2500000, -167.8356939>,
    <0.2439426, -167.8370395>,
    <0.2380977, -167.7710961>,
    <0.2265883, -167.9583959>,
    <0.2314815, -168.0105648>,
    <0.2304274, -167.9460939>,
    <0.2222222, -167.8948019>,
    <0.2222222, -167.9821228>,
    <0.2309279, -167.9767094>,
    <0.2256969, -167.9165230>,
    <0.2222222, -167.9330494>,
    <0.2265102, -167.9952943>,
    <0.2276051, -168.0323950>,
    <0.2314815, -168.0105648>,
    <0.2222222, -167.9821228>,
    <0.2222222, -168.0684463>,
    <0.2344945, -168.0684463>,
    <0.2265102, -167.9952943>,
    <0.2222222, -168.0320027>,
    <0.2295259, -168.0684463>,
    <0.2333688, -168.0468210>,
    <0.2366008, -168.0233878>,
    <0.2314815, -168.0105648>,
    <0.2344945, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2304274, -167.9460939>,
    <0.2333688, -168.0468210>,
    <0.2397567, -168.0684463>,
    <0.2377774, -167.9920402>,
    <0.2309279, -167.9767094>,
    <0.2279940, -167.7954493>,
    <0.2314815, -167.8386752>,
    <0.2360502, -167.8102428>,
    <0.2222222, -167.7264218>,
    <0.2222222, -167.8064572>,
    <0.2340528, -167.8226735>,
    <0.2282619, -167.7630323>,
    <0.2222222, -167.7610206>,
    <0.2262688, -167.8205376>,
    <0.2280127, -167.8586841>,
    <0.2314815, -167.8386752>,
    <0.2222222, -167.8064572>,
    <0.2222222, -167.8948019>,
    <0.2361251, -167.8948019>,
    <0.2262688, -167.8205376>,
    <0.2222222, -167.8574111>,
    <0.2281115, -167.8948019>,
    <0.2341319, -167.8707107>,
    <0.2384142, -167.8596305>,
    <0.2314815, -167.8386752>,
    <0.2361251, -167.8948019>,
    <0.2500000, -167.8948019>,
    <0.2360502, -167.8102428>,
    <0.2341319, -167.8707107>,
    <0.2440379, -167.8948019>,
    <0.2439446, -167.8580964>,
    <0.2340528, -167.8226735>,
    <0.2323788, -167.9220953>,
    <0.2407407, -167.9526834>,
    <0.2361251, -167.8948019>,
    <0.2222222, -167.8948019>,
    <0.2304274, -167.9460939>,
    <0.2383423, -167.9226062>,
    <0.2281115, -167.8948019>,
    <0.2256969, -167.9165230>,
    <0.2341659, -167.9484825>,
    <0.2427920, -167.9760476>,
    <0.2407407, -167.9526834>,
    <0.2304274, -167.9460939>,
    <0.2500000, -168.0684463>,
    <0.2500000, -167.9369669>,
    <0.2341659, -167.9484825>,
    <0.2377774, -167.9920402>,
    <0.2500000, -167.9784094>,
    <0.2462103, -167.9433994>,
    <0.2442164, -167.9198135>,
    <0.2407407, -167.9526834>,
    <0.2500000, -167.9369669>,
    <0.2500000, -167.8948019>,
    <0.2361251, -167.8948019>,
    <0.2462103, -167.9433994>,
    <0.2500000, -167.9127541>,
    <0.2440379, -167.8948019>,
    <0.2383423, -167.9226062>,
    <0.2280009, -167.4265843>,
    <0.2314815, -167.4660888>,
    <0.2222222, -167.4391507>,
    <0.2222222, -167.3613758>,
    <0.2360778, -167.4397221>,
    <0.2262725, -167.4509341>,
    <0.2222222, -167.3955180>,
    <0.2282775, -167.3956156>,
    <0.2340684, -167.4512490>,
    <0.2384195, -167.4856754>,
    <0.2314815, -167.4660888>,
    <0.2360778, -167.4397221>,
    <0.2500000, -167.5184453>,
    <0.2361190, -167.5184453>,
    <0.2340684, -167.4512490>,
    <0.2439013, -167.4839601>,
    <0.2439269, -167.5184453>,
    <0.2340922, -167.4955641>,
    <0.2280112, -167.4855325>,
    <0.2314815, -167.4660888>,
    <0.2361190, -167.5184453>,
    <0.2222222, -167.5184453>,
    <0.2222222, -167.4391507>,
    <0.2340922, -167.4955641>,
    <0.2283035, -167.5184453>,
    <0.2222222, -167.4838674>,
    <0.2262725, -167.4509341>,
    <0.2337922, -167.5546111>,
    <0.2407407, -167.5763713>,
    <0.2360868, -167.6051824>,
    <0.2222222, -167.5184453>,
    <0.2361190, -167.5184453>,
    <0.2381201, -167.5925951>,
    <0.2282834, -167.5563642>,
    <0.2283035, -167.5184453>,
    <0.2381394, -167.5437683>,
    <0.2442149, -167.5545331>,
    <0.2407407, -167.5763713>,
    <0.2361190, -167.5184453>,
    <0.2500000, -167.5184453>,
    <0.2500000, -167.6048705>,
    <0.2381394, -167.5437683>,
    <0.2439269, -167.5184453>,
    <0.2500000, -167.5563664>,
    <0.2459455, -167.5923911>,
    <0.2442069, -167.6196618>,
    <0.2407407, -167.5763713>,
    <0.2500000, -167.6048705>,
    <0.2500000, -167.6922232>,
    <0.2360868, -167.6051824>,
    <0.2459455, -167.5923911>,
    <0.2500000, -167.6541051>,
    <0.2439072, -167.6541068>,
    <0.2381201, -167.5925951>,
    <0.2280037, -167.6341061>,
    <0.2314815, -167.6737665>,
    <0.2360887, -167.6473117>,
    <0.2222222, -167.5684558>,
    <0.2222222, -167.6468904>,
    <0.2340748, -167.6588757>,
    <0.2282847, -167.6029317>,
    <0.2222222, -167.6028579>,
    <0.2262733, -167.6586490>,
    <0.2280105, -167.6933751>,
    <0.2314815, -167.6737665>,
    <0.2222222, -167.6468904>,
    <0.2222222, -167.7264218>,
    <0.2361160, -167.7264218>,
    <0.2262733, -167.6586490>,
    <0.2222222, -167.6917086>,
    <0.2283019, -167.7264218>,
    <0.2340905, -167.7034090>,
    <0.2384215, -167.6934805>,
    <0.2314815, -167.6737665>,
    <0.2361160, -167.7264218>,
    <0.2500000, -167.7264218>,
    <0.2360887, -167.6473117>,
    <0.2340905, -167.7034090>,
    <0.2439253, -167.7264218>,
    <0.2439084, -167.6917804>,
    <0.2340748, -167.6588757>,
    <0.2337823, -167.7614088>,
    <0.2407407, -167.7825485>,
    <0.2361160, -167.7264218>,
    <0.2222222, -167.7264218>,
    <0.2360502, -167.8102428>,
    <0.2381355, -167.7509306>,
    <0.2283019, -167.7264218>,
    <0.2282619, -167.7630323>,
    <0.2380997, -167.7981418>,
    <0.2441977, -167.8235090>,
    <0.2407407, -167.7825485>,
    <0.2360502, -167.8102428>,
    <0.2500000, -167.8948019>,
    <0.2500000, -167.8064426>,
    <0.2380997, -167.7981418>,
    <0.2439446, -167.8580964>,
    <0.2500000, -167.8568487>,
    <0.2459460, -167.7959812>,
    <0.2442142, -167.7604587>,
    <0.2407407, -167.7825485>,
    <0.2500000, -167.8064426>,
    <0.2500000, -167.7264218>,
    <0.2361160, -167.7264218>,
    <0.2459460, -167.7959812>,
    <0.2500000, -167.7610132>,
    <0.2439253, -167.7264218>,
    <0.2381355, -167.7509306>,
    <0.2280016, -167.4848985>,
    <0.2314815, -167.5208549>,
    <0.2360805, -167.4968970>,
    <0.2222222, -167.4256532>,
    <0.2222222, -167.4961890>,
    <0.2340700, -167.5073705>,
    <0.2282793, -167.4567920>,
    <0.2222222, -167.4566011>,
    <0.2262726, -167.5069791>,
    <0.2280110, -167.5384889>,
    <0.2314815, -167.5208549>,
    <0.2222222, -167.4961890>,
    <0.2222222, -167.5684558>,
    <0.2361182, -167.5684558>,
    <0.2262726, -167.5069791>,
    <0.2222222, -167.5369298>,
    <0.2283031, -167.5684558>,
    <0.2340917, -167.5476517>,
    <0.2384200, -167.5386659>,
    <0.2314815, -167.5208549>,
    <0.2361182, -167.5684558>,
    <0.2500000, -167.5684558>,
    <0.2360805, -167.4968970>,
    <0.2340917, -167.5476517>,
    <0.2439265, -167.5684558>,
    <0.2439030, -167.5371117>,
    <0.2340700, -167.5073705>,
    <0.2337925, -167.6013336>,
    <0.2407407, -167.6211112>,
    <0.2361182, -167.5684558>,
    <0.2222222, -167.5684558>,
    <0.2360887, -167.6473117>,
    <0.2381388, -167.5914725>,
    <0.2283031, -167.5684558>,
    <0.2282847, -167.6029317>,
    <0.2381212, -167.6358644>,
    <0.2442074, -167.6604338>,
    <0.2407407, -167.6211112>,
    <0.2360887, -167.6473117>,
    <0.2500000, -167.7264218>,
    <0.2500000, -167.6468904>,
    <0.2381212, -167.6358644>,
    <0.2439084, -167.6917804>,
    <0.2500000, -167.6917086>,
    <0.2459457, -167.6356026>,
    <0.2442147, -167.6012283>,
    <0.2407407, -167.6211112>,
    <0.2500000, -167.6468904>,
    <0.2500000, -167.5684558>,
    <0.2361182, -167.5684558>,
    <0.2459457, -167.6356026>,
    <0.2500000, -167.6028579>,
    <0.2439265, -167.5684558>,
    <0.2381388, -167.5914725>,
    <0.2279988, -167.2819570>,
    <0.2314815, -167.3161845>,
    <0.2222222, -167.2924560>,
    <0.2222222, -167.2258020>,
    <0.2360695, -167.2933857>,
    <0.2262718, -167.3028339>,
    <0.2222222, -167.2550533>,
    <0.2282721, -167.2553296>,
    <0.2340636, -167.3033535>,
    <0.2384180, -167.3330804>,
    <0.2314815, -167.3161845>,
    <0.2360695, -167.2933857>,
    <0.2500000, -167.3613758>,
    <0.2361211, -167.3613758>,
    <0.2340636, -167.3033535>,
    <0.2438958, -167.3315832>,
    <0.2439280, -167.3613758>,
    <0.2340933, -167.3416247>,
    <0.2280117, -167.3328480>,
    <0.2314815, -167.3161845>,
    <0.2361211, -167.3613758>,
    <0.2222222, -167.3613758>,
    <0.2222222, -167.2924560>,
    <0.2340933, -167.3416247>,
    <0.2283046, -167.3613758>,
    <0.2222222, -167.3313235>,
    <0.2262718, -167.3028339>,
    <0.2337905, -167.3940515>,
    <0.2407407, -167.4137323>,
    <0.2360778, -167.4397221>,
    <0.2222222, -167.3613758>,
    <0.2361211, -167.3613758>,
    <0.2381148, -167.4283682>,
    <0.2282775, -167.3956156>,
    <0.2283046, -167.3613758>,
    <0.2381405, -167.3842624>,
    <0.2442154, -167.3939086>,
    <0.2407407, -167.4137323>,
    <0.2361211, -167.3613758>,
    <0.2500000, -167.3613758>,
    <0.2500000, -167.4391507>,
    <0.2381405, -167.3842624>,
    <0.2439280, -167.3613758>,
    <0.2500000, -167.3955180>,
    <0.2459449, -167.4280187>,
    <0.2442046, -167.4527626>,
    <0.2407407, -167.4137323>,
    <0.2500000, -167.4391507>,
    <0.2500000, -167.5184453>,
    <0.2360778, -167.4397221>,
    <0.2459449, -167.4280187>,
    <0.2500000, -167.4838674>,
    <0.2439013, -167.4839601>,
    <0.2381148, -167.4283682>,
    <0.2279997, -167.3534027>,
    <0.2314815, -167.3845690>,
    <0.2360729, -167.3638575>,
    <0.2222222, -167.3024008>,
    <0.2222222, -167.3627833>,
    <0.2340656, -167.3729124>,
    <0.2282744, -167.3292549>,
    <0.2222222, -167.3288803>,
    <0.2262721, -167.3723121>,
    <0.2280115, -167.3996647>,
    <0.2314815, -167.3845690>,
    <0.2222222, -167.3627833>,
    <0.2222222, -167.4256532>,
    <0.2361201, -167.4256532>,
    <0.2262721, -167.3723121>,
    <0.2222222, -167.3982231>,
    <0.2283041, -167.4256532>,
    <0.2340926, -167.4076960>,
    <0.2384186, -167.3999332>,
    <0.2314815, -167.3845690>,
    <0.2361201, -167.4256532>,
    <0.2500000, -167.4256532>,
    <0.2360729, -167.3638575>,
    <0.2340926, -167.4076960>,
    <0.2439274, -167.4256532>,
    <0.2438980, -167.3985780>,
    <0.2340656, -167.3729124>,
    <0.2337909, -167.4553644>,
    <0.2407407, -167.4732541>,
    <0.2361201, -167.4256532>,
    <0.2222222, -167.4256532>,
    <0.2360805, -167.4968970>,
    <0.2381397, -167.4464590>,
    <0.2283041, -167.4256532>,
    <0.2282793, -167.4567920>,
    <0.2381165, -167.4865678>,
    <0.2442053, -167.5086990>,
    <0.2407407, -167.4732541>,
    <0.2360805, -167.4968970>,
    <0.2500000, -167.5684558>,
    <0.2500000, -167.4961890>,
    <0.2381165, -167.4865678>,
    <0.2439030, -167.5371117>,
    <0.2500000, -167.5369298>,
    <0.2459451, -167.4861453>,
    <0.2442152, -167.4551874>,
    <0.2407407, -167.4732541>,
    <0.2500000, -167.4961890>,
    <0.2500000, -167.4256532>,
    <0.2361201, -167.4256532>,
    <0.2459451, -167.4861453>,
    <0.2500000, -167.4566011>,
    <0.2439274, -167.4256532>,
    <0.2381397, -167.4464590>,
    <0.2279250, -167.1603891>,
    <0.2314815, -167.1891429>,
    <0.2222222, -167.1671102>,
    <0.2222222, -167.1158246>,
    <0.2357740, -167.1694788>,
    <0.2262750, -167.1767539>,
    <0.2222222, -167.1358300>,
    <0.2279459, -167.1384858>,
    <0.2339003, -167.1780625>,
    <0.2383446, -167.2025564>,
    <0.2314815, -167.1891429>,
    <0.2357740, -167.1694788>,
    <0.2500000, -167.2258020>,
    <0.2361228, -167.2258020>,
    <0.2339003, -167.1780625>,
    <0.2437329, -167.2009895>,
    <0.2439288, -167.2258020>,
    <0.2340852, -167.2097079>,
    <0.2280122, -167.2019642>,
    <0.2314815, -167.1891429>,
    <0.2361228, -167.2258020>,
    <0.2222222, -167.2258020>,
    <0.2222222, -167.1671102>,
    <0.2340852, -167.2097079>,
    <0.2283056, -167.2258020>,
    <0.2222222, -167.2000642>,
    <0.2262750, -167.1767539>,
    <0.2337888, -167.2539957>,
    <0.2407407, -167.2709932>,
    <0.2360695, -167.2933857>,
    <0.2222222, -167.2258020>,
    <0.2361228, -167.2258020>,
    <0.2381101, -167.2836036>,
    <0.2282721, -167.2553296>,
    <0.2283056, -167.2258020>,
    <0.2381412, -167.2455535>,
    <0.2442159, -167.2537633>,
    <0.2407407, -167.2709932>,
    <0.2361228, -167.2258020>,
    <0.2500000, -167.2258020>,
    <0.2500000, -167.2924560>,
    <0.2381412, -167.2455535>,
    <0.2439288, -167.2258020>,
    <0.2500000, -167.2550533>,
    <0.2459444, -167.2830552>,
    <0.2442025, -167.3045527>,
    <0.2407407, -167.2709932>,
    <0.2500000, -167.2924560>,
    <0.2500000, -167.3613758>,
    <0.2360695, -167.2933857>,
    <0.2459444, -167.2830552>,
    <0.2500000, -167.3313235>,
    <0.2438958, -167.3315832>,
    <0.2381101, -167.2836036>,
    <0.2279981, -167.2436308>,
    <0.2314815, -167.2690732>,
    <0.2360663, -167.2522483>,
    <0.2222222, -167.2024179>,
    <0.2222222, -167.2507837>,
    <0.2340618, -167.2596042>,
    <0.2282701, -167.2241867>,
    <0.2222222, -167.2235884>,
    <0.2262716, -167.2587824>,
    <0.2280119, -167.2811646>,
    <0.2314815, -167.2690732>,
    <0.2222222, -167.2507837>,
    <0.2222222, -167.3024008>,
    <0.2361217, -167.3024008>,
    <0.2262716, -167.2587824>,
    <0.2222222, -167.2798504>,
    <0.2283050, -167.3024008>,
    <0.2340933, -167.2878319>,
    <0.2384174, -167.2815307>,
    <0.2314815, -167.2690732>,
    <0.2361217, -167.3024008>,
    <0.2500000, -167.3024008>,
    <0.2360663, -167.2522483>,
    <0.2340933, -167.2878319>,
    <0.2439282, -167.3024008>,
    <0.2438936, -167.2804214>,
    <0.2340618, -167.2596042>,
    <0.2337894, -167.3280360>,
    <0.2407407, -167.3434849>,
    <0.2361217, -167.3024008>,
    <0.2222222, -167.3024008>,
    <0.2360729, -167.3638575>,
    <0.2381404, -167.3203558>,
    <0.2283050, -167.3024008>,
    <0.2282744, -167.3292549>,
    <0.2381121, -167.3549573>,
    <0.2442034, -167.3739447>,
    <0.2407407, -167.3434849>,
    <0.2360729, -167.3638575>,
    <0.2500000, -167.4256532>,
    <0.2500000, -167.3627833>,
    <0.2381121, -167.3549573>,
    <0.2438980, -167.3985780>,
    <0.2500000, -167.3982231>,
    <0.2459447, -167.3543311>,
    <0.2442156, -167.3277674>,
    <0.2407407, -167.3434849>,
    <0.2500000, -167.3627833>,
    <0.2500000, -167.3024008>,
    <0.2361217, -167.3024008>,
    <0.2459447, -167.3543311>,
    <0.2500000, -167.3288803>,
    <0.2439282, -167.3024008>,
    <0.2381404, -167.3203558>,
    <0.2317739, -167.0805591>,
    <0.2352878, -167.0842391>,
    <0.2413697, -167.1011047>,
    <0.2222222, -167.0684463>,
    <0.2282159, -167.0684463>,
    <0.2392240, -167.0951545>,
    <0.2337728, -167.0881472>,
    <0.2252576, -167.0684463>,
    <0.2310556, -167.0747879>,
    <0.2351340, -167.0794539>,
    <0.2352878, -167.0842391>,
    <0.2282159, -167.0684463>,
    <0.2336412, -167.0684463>,
    <0.2433911, -167.0966841>,
    <0.2310556, -167.0747879>,
    <0.2310244, -167.0684463>,
    <0.2386362, -167.0829127>,
    <0.2393526, -167.0904817>,
    <0.2425122, -167.0994631>,
    <0.2352878, -167.0842391>,
    <0.2433911, -167.0966841>,
    <0.2500000, -167.1158246>,
    <0.2413697, -167.1011047>,
    <0.2393526, -167.0904817>,
    <0.2474323, -167.1083882>,
    <0.2465325, -167.1099105>,
    <0.2392240, -167.0951545>,
    <0.2293239, -167.0911141>,
    <0.2314815, -167.1000319>,
    <0.2222222, -167.0948736>,
    <0.2222222, -167.0684463>,
    <0.2413697, -167.1011047>,
    <0.2262175, -167.0970994>,
    <0.2222222, -167.0819272>,
    <0.2337728, -167.0881472>,
    <0.2363483, -167.1005599>,
    <0.2395982, -167.1081965>,
    <0.2314815, -167.1000319>,
    <0.2413697, -167.1011047>,
    <0.2500000, -167.1158246>,
    <0.2355417, -167.1158246>,
    <0.2363483, -167.1005599>,
    <0.2465325, -167.1099105>,
    <0.2437522, -167.1158246>,
    <0.2336483, -167.1084600>,
    <0.2278669, -167.1066387>,
    <0.2314815, -167.1000319>,
    <0.2355417, -167.1158246>,
    <0.2222222, -167.1158246>,
    <0.2222222, -167.0948736>,
    <0.2336483, -167.1084600>,
    <0.2277164, -167.1158246>,
    <0.2222222, -167.1098105>,
    <0.2262175, -167.0970994>,
    <0.2335697, -167.1384030>,
    <0.2407407, -167.1524837>,
    <0.2357740, -167.1694788>,
    <0.2222222, -167.1158246>,
    <0.2355417, -167.1158246>,
    <0.2379379, -167.1620746>,
    <0.2279459, -167.1384858>,
    <0.2277164, -167.1158246>,
    <0.2377936, -167.1317030>,
    <0.2440706, -167.1378780>,
    <0.2407407, -167.1524837>,
    <0.2355417, -167.1158246>,
    <0.2500000, -167.1158246>,
    <0.2500000, -167.1673791>,
    <0.2377936, -167.1317030>,
    <0.2437522, -167.1158246>,
    <0.2500000, -167.1360722>,
    <0.2459384, -167.1608452>,
    <0.2441287, -167.1787859>,
    <0.2407407, -167.1524837>,
    <0.2500000, -167.1673791>,
    <0.2500000, -167.2258020>,
    <0.2357740, -167.1694788>,
    <0.2459384, -167.1608452>,
    <0.2500000, -167.2002062>,
    <0.2437329, -167.2009895>,
    <0.2379379, -167.1620746>,
    <0.2280690, -167.1583892>,
    <0.2314815, -167.1778641>,
    <0.2363501, -167.1662209>,
    <0.2222222, -167.1287564>,
    <0.2222222, -167.1607154>,
    <0.2342287, -167.1712941>,
    <0.2284794, -167.1453492>,
    <0.2222222, -167.1413913>,
    <0.2262790, -167.1682287>,
    <0.2280122, -167.1858538>,
    <0.2314815, -167.1778641>,
    <0.2222222, -167.1607154>,
    <0.2222222, -167.2024179>,
    <0.2361229, -167.2024179>,
    <0.2262790, -167.1682287>,
    <0.2222222, -167.1838308>,
    <0.2283057, -167.2024179>,
    <0.2341018, -167.1917260>,
    <0.2384886, -167.1872302>,
    <0.2314815, -167.1778641>,
    <0.2361229, -167.2024179>,
    <0.2500000, -167.2024179>,
    <0.2363501, -167.1662209>,
    <0.2341018, -167.1917260>,
    <0.2439288, -167.2024179>,
    <0.2440596, -167.1866652>,
    <0.2342287, -167.1712941>,
    <0.2337880, -167.2232074>,
    <0.2407407, -167.2357456>,
    <0.2361229, -167.2024179>,
    <0.2222222, -167.2024179>,
    <0.2360663, -167.2522483>,
    <0.2381407, -167.2169804>,
    <0.2283057, -167.2024179>,
    <0.2282701, -167.2241867>,
    <0.2381084, -167.2450388>,
    <0.2442018, -167.2602946>,
    <0.2407407, -167.2357456>,
    <0.2360663, -167.2522483>,
    <0.2500000, -167.3024008>,
    <0.2500000, -167.2507837>,
    <0.2381084, -167.2450388>,
    <0.2438936, -167.2804214>,
    <0.2500000, -167.2798504>,
    <0.2459443, -167.2441968>,
    <0.2442159, -167.2228413>,
    <0.2407407, -167.2357456>,
    <0.2500000, -167.2507837>,
    <0.2500000, -167.2024179>,
    <0.2361229, -167.2024179>,
    <0.2459443, -167.2441968>,
    <0.2500000, -167.2235884>,
    <0.2439288, -167.2024179>,
    <0.2381407, -167.2169804>,
    <0.2409315, -167.0794539>,
    <0.2445481, -167.0842391>,
    <0.2433924, -167.0966841>,
    <0.2336443, -167.0684463>,
    <0.2421413, -167.0684463>,
    <0.2438518, -167.0917364>,
    <0.2386383, -167.0829127>,
    <0.2380231, -167.0684463>,
    <0.2431882, -167.0753160>,
    <0.2466723, -167.0789395>,
    <0.2445481, -167.0842391>,
    <0.2421413, -167.0684463>,
    <0.2500000, -167.0684463>,
    <0.2500000, -167.0946262>,
    <0.2431882, -167.0753160>,
    <0.2461080, -167.0684463>,
    <0.2500000, -167.0817386>,
    <0.2476972, -167.0902389>,
    <0.2469851, -167.0978435>,
    <0.2445481, -167.0842391>,
    <0.2500000, -167.0946262>,
    <0.2500000, -167.1158246>,
    <0.2433924, -167.0966841>,
    <0.2476972, -167.0902389>,
    <0.2500000, -167.1099564>,
    <0.2474328, -167.1083882>,
    <0.2438518, -167.0917364>,
    <0.2447138, -167.1106496>,
    <0.2436641, -167.1123151>,
    <0.2489978, -167.1220941>,
    <0.2462901, -167.1040945>,
    <0.2399033, -167.1040945>,
    <0.2462232, -167.1170071>,
    <0.2477498, -167.1137977>,
    <0.2428368, -167.1040945>,
    <0.2412913, -167.1071285>,
    <0.2411425, -167.1108241>,
    <0.2436641, -167.1123151>,
    <0.2399033, -167.1040945>,
    <0.2347022, -167.1040945>,
    <0.2463004, -167.1227921>,
    <0.2412913, -167.1071285>,
    <0.2372285, -167.1040945>,
    <0.2419856, -167.1158363>,
    <0.2453305, -167.1189379>,
    <0.2472406, -167.1214894>,
    <0.2436641, -167.1123151>,
    <0.2463004, -167.1227921>,
    <0.2500000, -167.1287564>,
    <0.2489978, -167.1220941>,
    <0.2453305, -167.1189379>,
    <0.2486506, -167.1265810>,
    <0.2497153, -167.1268636>,
    <0.2462232, -167.1170071>,
    <0.2354312, -167.1176324>,
    <0.2356414, -167.1205358>,
    <0.2463003, -167.1227921>,
    <0.2347021, -167.1040945>,
    <0.2250809, -167.1231073>,
    <0.2416196, -167.1218013>,
    <0.2419856, -167.1158363>,
    <0.2285743, -167.1162039>,
    <0.2299522, -167.1219211>,
    <0.2295215, -167.1252890>,
    <0.2356414, -167.1205358>,
    <0.2250809, -167.1231073>,
    <0.2222222, -167.1287564>,
    <0.2351415, -167.1287564>,
    <0.2299522, -167.1219211>,
    <0.2232602, -167.1267051>,
    <0.2274926, -167.1287564>,
    <0.2353193, -167.1258321>,
    <0.2417708, -167.1252102>,
    <0.2356414, -167.1205358>,
    <0.2351415, -167.1287564>,
    <0.2500000, -167.1287564>,
    <0.2463003, -167.1227921>,
    <0.2353193, -167.1258321>,
    <0.2435342, -167.1287564>,
    <0.2486506, -167.1265810>,
    <0.2416196, -167.1218013>,
    <0.2336136, -167.1442610>,
    <0.2407407, -167.1533103>,
    <0.2351415, -167.1287564>,
    <0.2222222, -167.1287564>,
    <0.2363501, -167.1662209>,
    <0.2379005, -167.1408554>,
    <0.2274926, -167.1287564>,
    <0.2284794, -167.1453492>,
    <0.2383285, -167.1604034>,
    <0.2442727, -167.1706661>,
    <0.2407407, -167.1533103>,
    <0.2363501, -167.1662209>,
    <0.2500000, -167.2024179>,
    <0.2500000, -167.1607153>,
    <0.2383285, -167.1604034>,
    <0.2440596, -167.1866652>,
    <0.2500000, -167.1838307>,
    <0.2460120, -167.1575259>,
    <0.2439706, -167.1428846>,
    <0.2407407, -167.1533103>,
    <0.2500000, -167.1607153>,
    <0.2500000, -167.1287564>,
    <0.2351415, -167.1287564>,
    <0.2460120, -167.1575259>,
    <0.2500000, -167.1413912>,
    <0.2435342, -167.1287564>,
    <0.2379005, -167.1408554>,
    <0.2479523, -167.1106496>,
    <0.2487634, -167.1123151>,
    <0.2477580, -167.1040945>,
    <0.2462902, -167.1040945>,
    <0.2489978, -167.1220941>,
    <0.2481883, -167.1076129>,
    <0.2469330, -167.1040945>,
    <0.2477498, -167.1137977>,
    <0.2489145, -167.1186208>,
    <0.2494403, -167.1197236>,
    <0.2487634, -167.1123151>,
    <0.2489978, -167.1220941>,
    <0.2500000, -167.1287564>,
    <0.2500000, -167.1157289>,
    <0.2489145, -167.1186208>,
    <0.2497153, -167.1268636>,
    <0.2500000, -167.1243301>,
    <0.2495050, -167.1143624>,
    <0.2491303, -167.1090583>,
    <0.2487634, -167.1123151>,
    <0.2500000, -167.1157289>,
    <0.2500000, -167.1040945>,
    <0.2477580, -167.1040945>,
    <0.2495050, -167.1143624>,
    <0.2500000, -167.1077216>,
    <0.2488097, -167.1040945>,
    <0.2481883, -167.1076129>,
    <0.2564202, -167.1109029>,
    <0.2541599, -167.1123151>,
    <0.2528587, -167.1231073>,
    <0.2624799, -167.1040945>,
    <0.2561825, -167.1040945>,
    <0.2533595, -167.1189534>,
    <0.2563520, -167.1162039>,
    <0.2593092, -167.1040945>,
    <0.2555094, -167.1068304>,
    <0.2525856, -167.1090583>,
    <0.2541599, -167.1123151>,
    <0.2561825, -167.1040945>,
    <0.2500000, -167.1040945>,
    <0.2500000, -167.1157289>,
    <0.2555094, -167.1068304>,
    <0.2530842, -167.1040945>,
    <0.2500000, -167.1077216>,
    <0.2521001, -167.1140055>,
    <0.2517546, -167.1199770>,
    <0.2541599, -167.1123151>,
    <0.2500000, -167.1157289>,
    <0.2500000, -167.1287564>,
    <0.2528587, -167.1231073>,
    <0.2521001, -167.1140055>,
    <0.2500000, -167.1243301>,
    <0.2510380, -167.1267051>,
    <0.2533595, -167.1189534>,
    <0.7422139, -167.1109163>,
    <0.7449007, -167.1123151>,
    <0.7427233, -167.1040945>,
    <0.7347022, -167.1040945>,
    <0.7465293, -167.1231612>,
    <0.7435668, -167.1072788>,
    <0.7388686, -167.1040945>,
    <0.7424221, -167.1165400>,
    <0.7458615, -167.1187138>,
    <0.7478575, -167.1209778>,
    <0.7449007, -167.1123151>,
    <0.7465293, -167.1231612>,
    <0.7500000, -167.1287564>,
    <0.7500000, -167.1196784>,
    <0.7458615, -167.1187138>,
    <0.7487200, -167.1266928>,
    <0.7500000, -167.1261981>,
    <0.7476310, -167.1162576>,
    <0.7469060, -167.1100456>,
    <0.7449007, -167.1123151>,
    <0.7500000, -167.1196784>,
    <0.7500000, -167.1040945>,
    <0.7427233, -167.1040945>,
    <0.7476310, -167.1162576>,
    <0.7500000, -167.1103620>,
    <0.7464044, -167.1040945>,
    <0.7435668, -167.1072788>,
    <0.7409320, -167.0794526>,
    <0.7445481, -167.0842391>,
    <0.7433906, -167.0966789>,
    <0.7336443, -167.0684463>,
    <0.7421450, -167.0684463>,
    <0.7438513, -167.0917279>,
    <0.7386373, -167.0829098>,
    <0.7380267, -167.0684463>,
    <0.7431907, -167.0753181>,
    <0.7466733, -167.0788822>,
    <0.7445481, -167.0842391>,
    <0.7421450, -167.0684463>,
    <0.7500000, -167.0684463>,
    <0.7500000, -167.0943971>,
    <0.7431907, -167.0753181>,
    <0.7461102, -167.0684463>,
    <0.7500000, -167.0814791>,
    <0.7476977, -167.0901074>,
    <0.7469847, -167.0977849>,
    <0.7445481, -167.0842391>,
    <0.7500000, -167.0943971>,
    <0.7500000, -167.1158246>,
    <0.7433906, -167.0966789>,
    <0.7476977, -167.0901074>,
    <0.7500000, -167.1096995>,
    <0.7474318, -167.1083851>,
    <0.7438513, -167.0917279>,
    <0.2549057, -167.9542909>,
    <0.2592592, -168.0047729>,
    <0.2500000, -167.9862701>,
    <0.2500000, -167.8774261>,
    <0.2603637, -167.9486945>,
    <0.2541851, -167.9946333>,
    <0.2500000, -167.9253845>,
    <0.2544358, -167.9079297>,
    <0.2598755, -167.9734834>,
    <0.2662271, -168.0225900>,
    <0.2592592, -168.0047729>,
    <0.2603637, -167.9486945>,
    <0.2777778, -168.0684463>,
    <0.2675076, -168.0684463>,
    <0.2598755, -167.9734834>,
    <0.2679265, -168.0007020>,
    <0.2729225, -168.0684463>,
    <0.2642061, -168.0429604>,
    <0.2566917, -168.0319839>,
    <0.2592592, -168.0047729>,
    <0.2675076, -168.0684463>,
    <0.2500000, -168.0684463>,
    <0.2500000, -167.9862701>,
    <0.2642061, -168.0429604>,
    <0.2612906, -168.0684463>,
    <0.2500000, -168.0267368>,
    <0.2541851, -167.9946333>,
    <0.2557711, -167.7682265>,
    <0.2592592, -167.8156918>,
    <0.2500000, -167.7805911>,
    <0.2500000, -167.6922232>,
    <0.2638252, -167.7844001>,
    <0.2540465, -167.7959308>,
    <0.2500000, -167.7304720>,
    <0.2560380, -167.7324803>,
    <0.2618293, -167.7980782>,
    <0.2661912, -167.8387360>,
    <0.2592592, -167.8156918>,
    <0.2638252, -167.7844001>,
    <0.2777778, -167.8774261>,
    <0.2639026, -167.8774261>,
    <0.2618293, -167.7980782>,
    <0.2717195, -167.8370336>,
    <0.2717960, -167.8774261>,
    <0.2618937, -167.8507174>,
    <0.2557905, -167.8377837>,
    <0.2592592, -167.8156918>,
    <0.2639026, -167.8774261>,
    <0.2500000, -167.8774261>,
    <0.2500000, -167.7805911>,
    <0.2618937, -167.8507174>,
    <0.2559660, -167.8774261>,
    <0.2500000, -167.8356939>,
    <0.2540465, -167.7959308>,
    <0.2606962, -167.9111615>,
    <0.2685185, -167.9410995>,
    <0.2603637, -167.9486945>,
    <0.2500000, -167.8774261>,
    <0.2639026, -167.8774261>,
    <0.2636181, -167.9456635>,
    <0.2544358, -167.9079297>,
    <0.2559660, -167.8774261>,
    <0.2660553, -167.9071206>,
    <0.2719942, -167.9092002>,
    <0.2685185, -167.9410995>,
    <0.2639026, -167.8774261>,
    <0.2777778, -167.8774261>,
    <0.2777778, -167.9408490>,
    <0.2660553, -167.9071206>,
    <0.2717960, -167.8774261>,
    <0.2777778, -167.9045528>,
    <0.2738913, -167.9409542>,
    <0.2711094, -167.9747723>,
    <0.2685185, -167.9410995>,
    <0.2777778, -167.9408490>,
    <0.2777778, -168.0684463>,
    <0.2603637, -167.9486945>,
    <0.2738913, -167.9409542>,
    <0.2777778, -167.9889759>,
    <0.2679265, -168.0007020>,
    <0.2636181, -167.9456635>,
    <0.7277795, -167.9585182>,
    <0.7314815, -168.0047729>,
    <0.7222222, -167.9852586>,
    <0.7222222, -167.8774261>,
    <0.7351919, -167.9666152>,
    <0.7258986, -167.9930067>,
    <0.7222222, -167.9261964>,
    <0.7277211, -167.9152405>,
    <0.7333106, -167.9859622>,
    <0.7395100, -168.0270702>,
    <0.7314815, -168.0047729>,
    <0.7351919, -167.9666152>,
    <0.7500000, -168.0684463>,
    <0.7413667, -168.0684463>,
    <0.7333106, -167.9859622>,
    <0.7433774, -168.0229046>,
    <0.7465579, -168.0684463>,
    <0.7376954, -168.0447985>,
    <0.7293232, -168.0317310>,
    <0.7314815, -168.0047729>,
    <0.7413667, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.7222222, -167.9852586>,
    <0.7376954, -168.0447985>,
    <0.7333675, -168.0684463>,
    <0.7222222, -168.0282490>,
    <0.7258986, -167.9930067>,
    <0.7335717, -167.9156417>,
    <0.7407408, -167.9410995>,
    <0.7351919, -167.9666152>,
    <0.7222222, -167.8774261>,
    <0.7361319, -167.8774261>,
    <0.7375522, -167.9557618>,
    <0.7277211, -167.9152405>,
    <0.7283138, -167.8774261>,
    <0.7381329, -167.9050700>,
    <0.7442182, -167.9166615>,
    <0.7407408, -167.9410995>,
    <0.7361319, -167.8774261>,
    <0.7500000, -167.8774261>,
    <0.7500000, -167.9706945>,
    <0.7381329, -167.9050700>,
    <0.7439304, -167.8774261>,
    <0.7500000, -167.9186892>,
    <0.7459386, -167.9577130>,
    <0.7439832, -167.9867139>,
    <0.7407408, -167.9410995>,
    <0.7500000, -167.9706945>,
    <0.7500000, -168.0684463>,
    <0.7351919, -167.9666152>,
    <0.7459386, -167.9577130>,
    <0.7500000, -168.0323704>,
    <0.7433774, -168.0229046>,
    <0.7375522, -167.9557618>,
    <0.2557810, -167.5906989>,
    <0.2592592, -167.6342972>,
    <0.2500000, -167.6048705>,
    <0.2500000, -167.5184453>,
    <0.2638646, -167.6051824>,
    <0.2540509, -167.6177446>,
    <0.2500000, -167.5563664>,
    <0.2560612, -167.5563642>,
    <0.2618514, -167.6179095>,
    <0.2661990, -167.6559815>,
    <0.2592592, -167.6342972>,
    <0.2638646, -167.6051824>,
    <0.2777778, -167.6922232>,
    <0.2638943, -167.6922232>,
    <0.2618514, -167.6179095>,
    <0.2716850, -167.6541068>,
    <0.2717034, -167.6922232>,
    <0.2618686, -167.6669079>,
    <0.2557884, -167.6559035>,
    <0.2592592, -167.6342972>,
    <0.2638943, -167.6922232>,
    <0.2500000, -167.6922232>,
    <0.2500000, -167.6048705>,
    <0.2618686, -167.6669079>,
    <0.2560800, -167.6922232>,
    <0.2500000, -167.6541051>,
    <0.2540509, -167.6177446>,
    <0.2615595, -167.7307010>,
    <0.2685185, -167.7539575>,
    <0.2638252, -167.7844001>,
    <0.2500000, -167.6922232>,
    <0.2638943, -167.6922232>,
    <0.2658759, -167.7710985>,
    <0.2560380, -167.7324803>,
    <0.2560800, -167.6922232>,
    <0.2659136, -167.7191818>,
    <0.2719921, -167.7297450>,
    <0.2685185, -167.7539575>,
    <0.2638943, -167.6922232>,
    <0.2777778, -167.6922232>,
    <0.2777778, -167.7805759>,
    <0.2659136, -167.7191818>,
    <0.2717034, -167.6922232>,
    <0.2777778, -167.7304643>,
    <0.2737237, -167.7689213>,
    <0.2719748, -167.7990899>,
    <0.2685185, -167.7539575>,
    <0.2777778, -167.7805759>,
    <0.2777778, -167.8774261>,
    <0.2638252, -167.7844001>,
    <0.2737237, -167.7689213>,
    <0.2777778, -167.8353309>,
    <0.2717195, -167.8370336>,
    <0.2658759, -167.7710985>,
    <0.7279901, -167.7681748>,
    <0.7314815, -167.8156918>,
    <0.7222222, -167.7804696>,
    <0.7222222, -167.6922232>,
    <0.7360346, -167.7843145>,
    <0.7262673, -167.7958569>,
    <0.7222222, -167.7304093>,
    <0.7282531, -167.7324327>,
    <0.7340431, -167.7980388>,
    <0.7384120, -167.8387146>,
    <0.7314815, -167.8156918>,
    <0.7360346, -167.7843145>,
    <0.7500000, -167.8774261>,
    <0.7361319, -167.8774261>,
    <0.7340431, -167.7980388>,
    <0.7438678, -167.8365406>,
    <0.7439304, -167.8774261>,
    <0.7340923, -167.8503499>,
    <0.7280145, -167.8377534>,
    <0.7314815, -167.8156918>,
    <0.7361319, -167.8774261>,
    <0.7222222, -167.8774261>,
    <0.7222222, -167.7804696>,
    <0.7340923, -167.8503499>,
    <0.7283138, -167.8774261>,
    <0.7222222, -167.8349051>,
    <0.7262673, -167.7958569>,
    <0.7337785, -167.7306796>,
    <0.7407408, -167.7539575>,
    <0.7360346, -167.7843145>,
    <0.7222222, -167.6922232>,
    <0.7361165, -167.6922232>,
    <0.7380908, -167.7710507>,
    <0.7282531, -167.7324327>,
    <0.7283022, -167.6922232>,
    <0.7381355, -167.7191770>,
    <0.7442143, -167.7297218>,
    <0.7407408, -167.7539575>,
    <0.7361165, -167.6922232>,
    <0.7500000, -167.6922232>,
    <0.7500000, -167.7804832>,
    <0.7381355, -167.7191770>,
    <0.7439257, -167.6922232>,
    <0.7500000, -167.7304163>,
    <0.7459458, -167.7688689>,
    <0.7441938, -167.7990453>,
    <0.7407408, -167.7539575>,
    <0.7500000, -167.7804832>,
    <0.7500000, -167.8774261>,
    <0.7360346, -167.7843145>,
    <0.7459458, -167.7688689>,
    <0.7500000, -167.8341603>,
    <0.7438678, -167.8365406>,
    <0.7380908, -167.7710507>,
    <0.2549065, -167.9504852>,
    <0.2592592, -168.0105648>,
    <0.2603668, -167.9596070>,
    <0.2500000, -167.8948019>,
    <0.2500000, -167.9369669>,
    <0.2598615, -167.9828578>,
    <0.2544393, -167.9225530>,
    <0.2500000, -167.9127541>,
    <0.2542081, -167.9704153>,
    <0.2557870, -168.0211061>,
    <0.2592592, -168.0105648>,
    <0.2500000, -167.9369669>,
    <0.2500000, -168.0684463>,
    <0.2638889, -168.0684463>,
    <0.2542081, -167.9704153>,
    <0.2500000, -167.9784094>,
    <0.2569444, -168.0684463>,
    <0.2620126, -168.0449889>,
    <0.2653232, -168.0267661>,
    <0.2592592, -168.0105648>,
    <0.2638889, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2603668, -167.9596070>,
    <0.2620126, -168.0449889>,
    <0.2708333, -168.0684463>,
    <0.2679290, -168.0068797>,
    <0.2598615, -167.9828578>,
    <0.2557720, -167.7954466>,
    <0.2592592, -167.8386752>,
    <0.2638287, -167.8102469>,
    <0.2500000, -167.7264218>,
    <0.2500000, -167.8064426>,
    <0.2618310, -167.8226752>,
    <0.2560400, -167.7630346>,
    <0.2500000, -167.7610132>,
    <0.2540467, -167.8205297>,
    <0.2557904, -167.8586804>,
    <0.2592592, -167.8386752>,
    <0.2500000, -167.8064426>,
    <0.2500000, -167.8948019>,
    <0.2639024, -167.8948019>,
    <0.2540467, -167.8205297>,
    <0.2500000, -167.8568487>,
    <0.2559657, -167.8948019>,
    <0.2618953, -167.8705397>,
    <0.2661920, -167.8596315>,
    <0.2592592, -167.8386752>,
    <0.2639024, -167.8948019>,
    <0.2777778, -167.8948019>,
    <0.2638287, -167.8102469>,
    <0.2618953, -167.8705397>,
    <0.2717958, -167.8948019>,
    <0.2717220, -167.8580940>,
    <0.2618310, -167.8226752>,
    <0.2606969, -167.9254736>,
    <0.2685185, -167.9526834>,
    <0.2639024, -167.8948019>,
    <0.2500000, -167.8948019>,
    <0.2603668, -167.9596070>,
    <0.2660573, -167.9218221>,
    <0.2559657, -167.8948019>,
    <0.2544393, -167.9225530>,
    <0.2636173, -167.9568462>,
    <0.2711102, -167.9832805>,
    <0.2685185, -167.9526834>,
    <0.2603668, -167.9596070>,
    <0.2777778, -168.0684463>,
    <0.2777778, -167.9523852>,
    <0.2636173, -167.9568462>,
    <0.2679290, -168.0068797>,
    <0.2777778, -167.9958969>,
    <0.2738918, -167.9525103>,
    <0.2719941, -167.9236681>,
    <0.2685185, -167.9526834>,
    <0.2777778, -167.9523852>,
    <0.2777778, -167.8948019>,
    <0.2639024, -167.8948019>,
    <0.2738918, -167.9525103>,
    <0.2777778, -167.9195727>,
    <0.2717958, -167.8948019>,
    <0.2660573, -167.9218221>,
    <0.7272698, -167.9637516>,
    <0.7314815, -168.0105648>,
    <0.7331532, -167.9631338>,
    <0.7222222, -167.8948019>,
    <0.7222222, -167.9865060>,
    <0.7323552, -167.9857756>,
    <0.7270036, -167.9246911>,
    <0.7222222, -167.9354614>,
    <0.7265727, -167.9978102>,
    <0.7280599, -168.0334909>,
    <0.7314815, -168.0105648>,
    <0.7222222, -167.9865060>,
    <0.7222222, -168.0684463>,
    <0.7363135, -168.0684463>,
    <0.7265727, -167.9978102>,
    <0.7222222, -168.0340031>,
    <0.7309376, -168.0684463>,
    <0.7344161, -168.0457174>,
    <0.7377371, -168.0276478>,
    <0.7314815, -168.0105648>,
    <0.7363135, -168.0684463>,
    <0.7500000, -168.0684463>,
    <0.7331532, -167.9631338>,
    <0.7344161, -168.0457174>,
    <0.7418085, -168.0684463>,
    <0.7406228, -168.0098278>,
    <0.7323552, -167.9857756>,
    <0.7330620, -167.9263553>,
    <0.7407408, -167.9526834>,
    <0.7361316, -167.8948019>,
    <0.7222222, -167.8948019>,
    <0.7331532, -167.9631338>,
    <0.7383911, -167.9231767>,
    <0.7281152, -167.8948019>,
    <0.7270036, -167.9246911>,
    <0.7358011, -167.9594868>,
    <0.7434735, -167.9933927>,
    <0.7407408, -167.9526834>,
    <0.7331532, -167.9631338>,
    <0.7500000, -168.0684463>,
    <0.7500000, -167.9893072>,
    <0.7358011, -167.9594868>,
    <0.7406228, -168.0098278>,
    <0.7500000, -168.0291459>,
    <0.7461725, -167.9741679>,
    <0.7442181, -167.9328986>,
    <0.7407408, -167.9526834>,
    <0.7500000, -167.9893072>,
    <0.7500000, -167.8948019>,
    <0.7361316, -167.8948019>,
    <0.7461725, -167.9741679>,
    <0.7500000, -167.9361047>,
    <0.7440420, -167.8948019>,
    <0.7383911, -167.9231767>,
    <0.2557787, -167.4265843>,
    <0.2592593, -167.4660888>,
    <0.2500000, -167.4391507>,
    <0.2500000, -167.3613758>,
    <0.2638556, -167.4397221>,
    <0.2540502, -167.4509341>,
    <0.2500000, -167.3955180>,
    <0.2560553, -167.3956156>,
    <0.2618462, -167.4512490>,
    <0.2661973, -167.4856754>,
    <0.2592593, -167.4660888>,
    <0.2638556, -167.4397221>,
    <0.2777778, -167.5184453>,
    <0.2638967, -167.5184453>,
    <0.2618462, -167.4512490>,
    <0.2716791, -167.4839601>,
    <0.2717047, -167.5184453>,
    <0.2618700, -167.4955641>,
    <0.2557890, -167.4855325>,
    <0.2592593, -167.4660888>,
    <0.2638967, -167.5184453>,
    <0.2500000, -167.5184453>,
    <0.2500000, -167.4391507>,
    <0.2618700, -167.4955641>,
    <0.2560813, -167.5184453>,
    <0.2500000, -167.4838674>,
    <0.2540502, -167.4509341>,
    <0.2615700, -167.5546111>,
    <0.2685185, -167.5763713>,
    <0.2638646, -167.6051824>,
    <0.2500000, -167.5184453>,
    <0.2638967, -167.5184453>,
    <0.2658978, -167.5925951>,
    <0.2560612, -167.5563642>,
    <0.2560813, -167.5184453>,
    <0.2659172, -167.5437683>,
    <0.2719927, -167.5545331>,
    <0.2685185, -167.5763713>,
    <0.2638967, -167.5184453>,
    <0.2777778, -167.5184453>,
    <0.2777778, -167.6048705>,
    <0.2659172, -167.5437683>,
    <0.2717047, -167.5184453>,
    <0.2777778, -167.5563664>,
    <0.2737233, -167.5923911>,
    <0.2719847, -167.6196618>,
    <0.2685185, -167.5763713>,
    <0.2777778, -167.6048705>,
    <0.2777778, -167.6922232>,
    <0.2638646, -167.6051824>,
    <0.2737233, -167.5923911>,
    <0.2777778, -167.6541051>,
    <0.2716850, -167.6541068>,
    <0.2658978, -167.5925951>,
    <0.7280032, -167.5906989>,
    <0.7314815, -167.6342972>,
    <0.7222222, -167.6048705>,
    <0.7222222, -167.5184453>,
    <0.7360868, -167.6051824>,
    <0.7262731, -167.6177446>,
    <0.7222222, -167.5563664>,
    <0.7282834, -167.5563642>,
    <0.7340737, -167.6179095>,
    <0.7384212, -167.6559815>,
    <0.7314815, -167.6342972>,
    <0.7360868, -167.6051824>,
    <0.7500000, -167.6922232>,
    <0.7361165, -167.6922232>,
    <0.7340737, -167.6179095>,
    <0.7439072, -167.6541068>,
    <0.7439257, -167.6922232>,
    <0.7340909, -167.6669079>,
    <0.7280106, -167.6559035>,
    <0.7314815, -167.6342972>,
    <0.7361165, -167.6922232>,
    <0.7222222, -167.6922232>,
    <0.7222222, -167.6048705>,
    <0.7340909, -167.6669079>,
    <0.7283022, -167.6922232>,
    <0.7222222, -167.6541051>,
    <0.7262731, -167.6177446>,
    <0.7337922, -167.5546111>,
    <0.7407408, -167.5763713>,
    <0.7360868, -167.6051824>,
    <0.7222222, -167.5184453>,
    <0.7361190, -167.5184453>,
    <0.7381201, -167.5925951>,
    <0.7282834, -167.5563642>,
    <0.7283035, -167.5184453>,
    <0.7381394, -167.5437683>,
    <0.7442149, -167.5545331>,
    <0.7407408, -167.5763713>,
    <0.7361190, -167.5184453>,
    <0.7500000, -167.5184453>,
    <0.7500000, -167.6048705>,
    <0.7381394, -167.5437683>,
    <0.7439269, -167.5184453>,
    <0.7500000, -167.5563664>,
    <0.7459455, -167.5923911>,
    <0.7442069, -167.6196618>,
    <0.7407408, -167.5763713>,
    <0.7500000, -167.6048705>,
    <0.7500000, -167.6922232>,
    <0.7360868, -167.6051824>,
    <0.7459455, -167.5923911>,
    <0.7500000, -167.6541051>,
    <0.7439072, -167.6541068>,
    <0.7381201, -167.5925951>,
    <0.2557814, -167.6341061>,
    <0.2592592, -167.6737665>,
    <0.2638665, -167.6473117>,
    <0.2500000, -167.5684558>,
    <0.2500000, -167.6468904>,
    <0.2618526, -167.6588757>,
    <0.2560624, -167.6029317>,
    <0.2500000, -167.6028579>,
    <0.2540510, -167.6586490>,
    <0.2557882, -167.6933751>,
    <0.2592592, -167.6737665>,
    <0.2500000, -167.6468904>,
    <0.2500000, -167.7264218>,
    <0.2638938, -167.7264218>,
    <0.2540510, -167.6586490>,
    <0.2500000, -167.6917086>,
    <0.2560797, -167.7264218>,
    <0.2618683, -167.7034090>,
    <0.2661993, -167.6934805>,
    <0.2592592, -167.6737665>,
    <0.2638938, -167.7264218>,
    <0.2777778, -167.7264218>,
    <0.2638665, -167.6473117>,
    <0.2618683, -167.7034090>,
    <0.2717031, -167.7264218>,
    <0.2716862, -167.6917804>,
    <0.2618526, -167.6588757>,
    <0.2615602, -167.7614098>,
    <0.2685185, -167.7825485>,
    <0.2638938, -167.7264218>,
    <0.2500000, -167.7264218>,
    <0.2638287, -167.8102469>,
    <0.2659133, -167.7509308>,
    <0.2560797, -167.7264218>,
    <0.2560400, -167.7630346>,
    <0.2658779, -167.7981441>,
    <0.2719757, -167.8235059>,
    <0.2685185, -167.7825485>,
    <0.2638287, -167.8102469>,
    <0.2777778, -167.8948019>,
    <0.2777778, -167.8064264>,
    <0.2658779, -167.7981441>,
    <0.2717220, -167.8580940>,
    <0.2777778, -167.8565724>,
    <0.2737238, -167.7959720>,
    <0.2719920, -167.7604546>,
    <0.2685185, -167.7825485>,
    <0.2777778, -167.8064264>,
    <0.2777778, -167.7264218>,
    <0.2638938, -167.7264218>,
    <0.2737238, -167.7959720>,
    <0.2777778, -167.7610050>,
    <0.2717031, -167.7264218>,
    <0.2659133, -167.7509308>,
    <0.7279910, -167.7953948>,
    <0.7314815, -167.8386752>,
    <0.7360381, -167.8101695>,
    <0.7222222, -167.7264218>,
    <0.7222222, -167.8063127>,
    <0.7340448, -167.8226396>,
    <0.7282552, -167.7629915>,
    <0.7222222, -167.7609467>,
    <0.7262675, -167.8204515>,
    <0.7280144, -167.8586479>,
    <0.7314815, -167.8386752>,
    <0.7222222, -167.8063127>,
    <0.7222222, -167.8948019>,
    <0.7361316, -167.8948019>,
    <0.7262675, -167.8204515>,
    <0.7222222, -167.8571284>,
    <0.7281152, -167.8948019>,
    <0.7341310, -167.8706551>,
    <0.7384128, -167.8596122>,
    <0.7314815, -167.8386752>,
    <0.7361316, -167.8948019>,
    <0.7500000, -167.8948019>,
    <0.7360381, -167.8101695>,
    <0.7341310, -167.8706551>,
    <0.7440420, -167.8948019>,
    <0.7439329, -167.8580248>,
    <0.7340448, -167.8226396>,
    <0.7337793, -167.7613904>,
    <0.7407408, -167.7825485>,
    <0.7361160, -167.7264218>,
    <0.7222222, -167.7264218>,
    <0.7360381, -167.8101695>,
    <0.7381351, -167.7509264>,
    <0.7283020, -167.7264218>,
    <0.7282552, -167.7629915>,
    <0.7380929, -167.7981009>,
    <0.7441947, -167.8234618>,
    <0.7407408, -167.7825485>,
    <0.7360381, -167.8101695>,
    <0.7500000, -167.8948019>,
    <0.7500000, -167.8063273>,
    <0.7380929, -167.7981009>,
    <0.7439329, -167.8580248>,
    <0.7500000, -167.8566311>,
    <0.7459460, -167.7959161>,
    <0.7442142, -167.7604299>,
    <0.7407408, -167.7825485>,
    <0.7500000, -167.8063273>,
    <0.7500000, -167.7264218>,
    <0.7361160, -167.7264218>,
    <0.7459460, -167.7959161>,
    <0.7500000, -167.7609541>,
    <0.7439254, -167.7264218>,
    <0.7381351, -167.7509264>,
    <0.2557794, -167.4848985>,
    <0.2592592, -167.5208549>,
    <0.2638582, -167.4968970>,
    <0.2500000, -167.4256532>,
    <0.2500000, -167.4961890>,
    <0.2618477, -167.5073705>,
    <0.2560571, -167.4567920>,
    <0.2500000, -167.4566011>,
    <0.2540504, -167.5069791>,
    <0.2557888, -167.5384889>,
    <0.2592592, -167.5208549>,
    <0.2500000, -167.4961890>,
    <0.2500000, -167.5684558>,
    <0.2638960, -167.5684558>,
    <0.2540504, -167.5069791>,
    <0.2500000, -167.5369298>,
    <0.2560809, -167.5684558>,
    <0.2618695, -167.5476517>,
    <0.2661978, -167.5386659>,
    <0.2592592, -167.5208549>,
    <0.2638960, -167.5684558>,
    <0.2777778, -167.5684558>,
    <0.2638582, -167.4968970>,
    <0.2618695, -167.5476517>,
    <0.2717042, -167.5684558>,
    <0.2716807, -167.5371117>,
    <0.2618477, -167.5073705>,
    <0.2615702, -167.6013336>,
    <0.2685185, -167.6211112>,
    <0.2638960, -167.5684558>,
    <0.2500000, -167.5684558>,
    <0.2638665, -167.6473117>,
    <0.2659166, -167.5914725>,
    <0.2560809, -167.5684558>,
    <0.2560624, -167.6029317>,
    <0.2658990, -167.6358644>,
    <0.2719851, -167.6604338>,
    <0.2685185, -167.6211112>,
    <0.2638665, -167.6473117>,
    <0.2777778, -167.7264218>,
    <0.2777778, -167.6468904>,
    <0.2658990, -167.6358644>,
    <0.2716862, -167.6917804>,
    <0.2777778, -167.6917086>,
    <0.2737235, -167.6356026>,
    <0.2719925, -167.6012283>,
    <0.2685185, -167.6211112>,
    <0.2777778, -167.6468904>,
    <0.2777778, -167.5684558>,
    <0.2638960, -167.5684558>,
    <0.2737235, -167.6356026>,
    <0.2777778, -167.6028580>,
    <0.2717042, -167.5684558>,
    <0.2659166, -167.5914725>,
    <0.7280037, -167.6341061>,
    <0.7314815, -167.6737665>,
    <0.7360888, -167.6473117>,
    <0.7222222, -167.5684558>,
    <0.7222222, -167.6468904>,
    <0.7340748, -167.6588757>,
    <0.7282847, -167.6029317>,
    <0.7222222, -167.6028579>,
    <0.7262733, -167.6586490>,
    <0.7280105, -167.6933751>,
    <0.7314815, -167.6737665>,
    <0.7222222, -167.6468904>,
    <0.7222222, -167.7264218>,
    <0.7361160, -167.7264218>,
    <0.7262733, -167.6586490>,
    <0.7222222, -167.6917086>,
    <0.7283020, -167.7264218>,
    <0.7340905, -167.7034090>,
    <0.7384216, -167.6934805>,
    <0.7314815, -167.6737665>,
    <0.7361160, -167.7264218>,
    <0.7500000, -167.7264218>,
    <0.7360888, -167.6473117>,
    <0.7340905, -167.7034090>,
    <0.7439254, -167.7264218>,
    <0.7439084, -167.6917804>,
    <0.7340748, -167.6588757>,
    <0.7337925, -167.6013336>,
    <0.7407408, -167.6211112>,
    <0.7361182, -167.5684558>,
    <0.7222222, -167.5684558>,
    <0.7360888, -167.6473117>,
    <0.7381388, -167.5914725>,
    <0.7283031, -167.5684558>,
    <0.7282847, -167.6029317>,
    <0.7381213, -167.6358644>,
    <0.7442074, -167.6604338>,
    <0.7407408, -167.6211112>,
    <0.7360888, -167.6473117>,
    <0.7500000, -167.7264218>,
    <0.7500000, -167.6468904>,
    <0.7381213, -167.6358644>,
    <0.7439084, -167.6917804>,
    <0.7500000, -167.6917086>,
    <0.7459457, -167.6356026>,
    <0.7442147, -167.6012283>,
    <0.7407408, -167.6211112>,
    <0.7500000, -167.6468904>,
    <0.7500000, -167.5684558>,
    <0.7361182, -167.5684558>,
    <0.7459457, -167.6356026>,
    <0.7500000, -167.6028579>,
    <0.7439265, -167.5684558>,
    <0.7381388, -167.5914725>,
    <0.2557766, -167.2819570>,
    <0.2592592, -167.3161845>,
    <0.2500000, -167.2924560>,
    <0.2500000, -167.2258020>,
    <0.2638472, -167.2933857>,
    <0.2540496, -167.3028339>,
    <0.2500000, -167.2550533>,
    <0.2560499, -167.2553296>,
    <0.2618413, -167.3033535>,
    <0.2661958, -167.3330804>,
    <0.2592592, -167.3161845>,
    <0.2638472, -167.2933857>,
    <0.2777778, -167.3613758>,
    <0.2638989, -167.3613758>,
    <0.2618413, -167.3033535>,
    <0.2716736, -167.3315832>,
    <0.2717057, -167.3613758>,
    <0.2618711, -167.3416247>,
    <0.2557895, -167.3328480>,
    <0.2592592, -167.3161845>,
    <0.2638989, -167.3613758>,
    <0.2500000, -167.3613758>,
    <0.2500000, -167.2924560>,
    <0.2618711, -167.3416247>,
    <0.2560824, -167.3613758>,
    <0.2500000, -167.3313235>,
    <0.2540496, -167.3028339>,
    <0.2615682, -167.3940515>,
    <0.2685185, -167.4137323>,
    <0.2638556, -167.4397221>,
    <0.2500000, -167.3613758>,
    <0.2638989, -167.3613758>,
    <0.2658926, -167.4283682>,
    <0.2560553, -167.3956156>,
    <0.2560824, -167.3613758>,
    <0.2659182, -167.3842624>,
    <0.2719932, -167.3939086>,
    <0.2685185, -167.4137323>,
    <0.2638989, -167.3613758>,
    <0.2777778, -167.3613758>,
    <0.2777778, -167.4391507>,
    <0.2659182, -167.3842624>,
    <0.2717057, -167.3613758>,
    <0.2777778, -167.3955180>,
    <0.2737227, -167.4280187>,
    <0.2719824, -167.4527626>,
    <0.2685185, -167.4137323>,
    <0.2777778, -167.4391507>,
    <0.2777778, -167.5184453>,
    <0.2638556, -167.4397221>,
    <0.2737227, -167.4280187>,
    <0.2777778, -167.4838674>,
    <0.2716791, -167.4839601>,
    <0.2658926, -167.4283682>,
    <0.7280009, -167.4265843>,
    <0.7314815, -167.4660888>,
    <0.7222222, -167.4391507>,
    <0.7222222, -167.3613758>,
    <0.7360778, -167.4397221>,
    <0.7262725, -167.4509341>,
    <0.7222222, -167.3955180>,
    <0.7282776, -167.3956156>,
    <0.7340684, -167.4512490>,
    <0.7384196, -167.4856754>,
    <0.7314815, -167.4660888>,
    <0.7360778, -167.4397221>,
    <0.7500000, -167.5184453>,
    <0.7361190, -167.5184453>,
    <0.7340684, -167.4512490>,
    <0.7439013, -167.4839601>,
    <0.7439269, -167.5184453>,
    <0.7340923, -167.4955641>,
    <0.7280112, -167.4855325>,
    <0.7314815, -167.4660888>,
    <0.7361190, -167.5184453>,
    <0.7222222, -167.5184453>,
    <0.7222222, -167.4391507>,
    <0.7340923, -167.4955641>,
    <0.7283035, -167.5184453>,
    <0.7222222, -167.4838674>,
    <0.7262725, -167.4509341>,
    <0.7337905, -167.3940515>,
    <0.7407408, -167.4137323>,
    <0.7360778, -167.4397221>,
    <0.7222222, -167.3613758>,
    <0.7361211, -167.3613758>,
    <0.7381149, -167.4283682>,
    <0.7282776, -167.3956156>,
    <0.7283046, -167.3613758>,
    <0.7381405, -167.3842624>,
    <0.7442155, -167.3939086>,
    <0.7407408, -167.4137323>,
    <0.7361211, -167.3613758>,
    <0.7500000, -167.3613758>,
    <0.7500000, -167.4391507>,
    <0.7381405, -167.3842624>,
    <0.7439280, -167.3613758>,
    <0.7500000, -167.3955180>,
    <0.7459449, -167.4280187>,
    <0.7442046, -167.4527626>,
    <0.7407408, -167.4137323>,
    <0.7500000, -167.4391507>,
    <0.7500000, -167.5184453>,
    <0.7360778, -167.4397221>,
    <0.7459449, -167.4280187>,
    <0.7500000, -167.4838674>,
    <0.7439013, -167.4839601>,
    <0.7381149, -167.4283682>,
    <0.2557775, -167.3534027>,
    <0.2592592, -167.3845690>,
    <0.2638507, -167.3638575>,
    <0.2500000, -167.3024008>,
    <0.2500000, -167.3627833>,
    <0.2618434, -167.3729124>,
    <0.2560522, -167.3292549>,
    <0.2500000, -167.3288803>,
    <0.2540499, -167.3723121>,
    <0.2557893, -167.3996647>,
    <0.2592592, -167.3845690>,
    <0.2500000, -167.3627833>,
    <0.2500000, -167.4256532>,
    <0.2638979, -167.4256532>,
    <0.2540499, -167.3723121>,
    <0.2500000, -167.3982231>,
    <0.2560819, -167.4256532>,
    <0.2618704, -167.4076960>,
    <0.2661964, -167.3999332>,
    <0.2592592, -167.3845690>,
    <0.2638979, -167.4256532>,
    <0.2777778, -167.4256532>,
    <0.2638507, -167.3638575>,
    <0.2618704, -167.4076960>,
    <0.2717052, -167.4256532>,
    <0.2716757, -167.3985780>,
    <0.2618434, -167.3729124>,
    <0.2615687, -167.4553644>,
    <0.2685185, -167.4732541>,
    <0.2638979, -167.4256532>,
    <0.2500000, -167.4256532>,
    <0.2638582, -167.4968970>,
    <0.2659175, -167.4464590>,
    <0.2560819, -167.4256532>,
    <0.2560571, -167.4567920>,
    <0.2658942, -167.4865678>,
    <0.2719831, -167.5086990>,
    <0.2685185, -167.4732541>,
    <0.2638582, -167.4968970>,
    <0.2777778, -167.5684558>,
    <0.2777778, -167.4961890>,
    <0.2658942, -167.4865678>,
    <0.2716807, -167.5371117>,
    <0.2777778, -167.5369297>,
    <0.2737229, -167.4861453>,
    <0.2719930, -167.4551874>,
    <0.2685185, -167.4732541>,
    <0.2777778, -167.4961890>,
    <0.2777778, -167.4256532>,
    <0.2638979, -167.4256532>,
    <0.2737229, -167.4861453>,
    <0.2777778, -167.4566011>,
    <0.2717052, -167.4256532>,
    <0.2659175, -167.4464590>,
    <0.7280016, -167.4848985>,
    <0.7314815, -167.5208549>,
    <0.7360805, -167.4968970>,
    <0.7222222, -167.4256532>,
    <0.7222222, -167.4961890>,
    <0.7340700, -167.5073705>,
    <0.7282793, -167.4567920>,
    <0.7222222, -167.4566011>,
    <0.7262727, -167.5069791>,
    <0.7280110, -167.5384889>,
    <0.7314815, -167.5208549>,
    <0.7222222, -167.4961890>,
    <0.7222222, -167.5684558>,
    <0.7361182, -167.5684558>,
    <0.7262727, -167.5069791>,
    <0.7222222, -167.5369298>,
    <0.7283031, -167.5684558>,
    <0.7340917, -167.5476517>,
    <0.7384200, -167.5386659>,
    <0.7314815, -167.5208549>,
    <0.7361182, -167.5684558>,
    <0.7500000, -167.5684558>,
    <0.7360805, -167.4968970>,
    <0.7340917, -167.5476517>,
    <0.7439265, -167.5684558>,
    <0.7439030, -167.5371117>,
    <0.7340700, -167.5073705>,
    <0.7337909, -167.4553644>,
    <0.7407408, -167.4732541>,
    <0.7361201, -167.4256532>,
    <0.7222222, -167.4256532>,
    <0.7360805, -167.4968970>,
    <0.7381397, -167.4464590>,
    <0.7283041, -167.4256532>,
    <0.7282793, -167.4567920>,
    <0.7381165, -167.4865678>,
    <0.7442053, -167.5086990>,
    <0.7407408, -167.4732541>,
    <0.7360805, -167.4968970>,
    <0.7500000, -167.5684558>,
    <0.7500000, -167.4961890>,
    <0.7381165, -167.4865678>,
    <0.7439030, -167.5371117>,
    <0.7500000, -167.5369298>,
    <0.7459452, -167.4861453>,
    <0.7442152, -167.4551874>,
    <0.7407408, -167.4732541>,
    <0.7500000, -167.4961890>,
    <0.7500000, -167.4256532>,
    <0.7361201, -167.4256532>,
    <0.7459452, -167.4861453>,
    <0.7500000, -167.4566011>,
    <0.7439274, -167.4256532>,
    <0.7381397, -167.4464590>,
    <0.2557043, -167.1604623>,
    <0.2592593, -167.1891429>,
    <0.2500000, -167.1673791>,
    <0.2500000, -167.1158246>,
    <0.2635578, -167.1695025>,
    <0.2540527, -167.1769048>,
    <0.2500000, -167.1360722>,
    <0.2557288, -167.1385059>,
    <0.2616814, -167.1780760>,
    <0.2661239, -167.2025623>,
    <0.2592593, -167.1891429>,
    <0.2635578, -167.1695025>,
    <0.2777778, -167.2258020>,
    <0.2639006, -167.2258020>,
    <0.2616814, -167.1780760>,
    <0.2715141, -167.2010031>,
    <0.2717066, -167.2258020>,
    <0.2618632, -167.2097096>,
    <0.2557900, -167.2020315>,
    <0.2592593, -167.1891429>,
    <0.2639006, -167.2258020>,
    <0.2500000, -167.2258020>,
    <0.2500000, -167.1673791>,
    <0.2618632, -167.2097096>,
    <0.2560833, -167.2258020>,
    <0.2500000, -167.2002062>,
    <0.2540527, -167.1769048>,
    <0.2615666, -167.2539957>,
    <0.2685185, -167.2709932>,
    <0.2638472, -167.2933857>,
    <0.2500000, -167.2258020>,
    <0.2639006, -167.2258020>,
    <0.2658879, -167.2836036>,
    <0.2560499, -167.2553296>,
    <0.2560833, -167.2258020>,
    <0.2659189, -167.2455535>,
    <0.2719937, -167.2537633>,
    <0.2685185, -167.2709932>,
    <0.2639006, -167.2258020>,
    <0.2777778, -167.2258020>,
    <0.2777778, -167.2924560>,
    <0.2659189, -167.2455535>,
    <0.2717066, -167.2258020>,
    <0.2777778, -167.2550533>,
    <0.2737222, -167.2830552>,
    <0.2719803, -167.3045527>,
    <0.2685185, -167.2709932>,
    <0.2777778, -167.2924560>,
    <0.2777778, -167.3613758>,
    <0.2638472, -167.2933857>,
    <0.2737222, -167.2830552>,
    <0.2777778, -167.3313235>,
    <0.2716736, -167.3315832>,
    <0.2658879, -167.2836036>,
    <0.7279989, -167.2819570>,
    <0.7314815, -167.3161845>,
    <0.7222222, -167.2924560>,
    <0.7222222, -167.2258020>,
    <0.7360695, -167.2933857>,
    <0.7262719, -167.3028339>,
    <0.7222222, -167.2550533>,
    <0.7282722, -167.2553296>,
    <0.7340636, -167.3033535>,
    <0.7384180, -167.3330804>,
    <0.7314815, -167.3161845>,
    <0.7360695, -167.2933857>,
    <0.7500000, -167.3613758>,
    <0.7361211, -167.3613758>,
    <0.7340636, -167.3033535>,
    <0.7438958, -167.3315832>,
    <0.7439280, -167.3613758>,
    <0.7340933, -167.3416247>,
    <0.7280118, -167.3328480>,
    <0.7314815, -167.3161845>,
    <0.7361211, -167.3613758>,
    <0.7222222, -167.3613758>,
    <0.7222222, -167.2924560>,
    <0.7340933, -167.3416247>,
    <0.7283046, -167.3613758>,
    <0.7222222, -167.3313235>,
    <0.7262719, -167.3028339>,
    <0.7337888, -167.2539957>,
    <0.7407407, -167.2709932>,
    <0.7360695, -167.2933857>,
    <0.7222222, -167.2258020>,
    <0.7361229, -167.2258020>,
    <0.7381101, -167.2836036>,
    <0.7282722, -167.2553296>,
    <0.7283056, -167.2258020>,
    <0.7381412, -167.2455535>,
    <0.7442159, -167.2537633>,
    <0.7407407, -167.2709932>,
    <0.7361229, -167.2258020>,
    <0.7500000, -167.2258020>,
    <0.7500000, -167.2924560>,
    <0.7381412, -167.2455535>,
    <0.7439288, -167.2258020>,
    <0.7500000, -167.2550533>,
    <0.7459444, -167.2830552>,
    <0.7442026, -167.3045527>,
    <0.7407407, -167.2709932>,
    <0.7500000, -167.2924560>,
    <0.7500000, -167.3613758>,
    <0.7360695, -167.2933857>,
    <0.7459444, -167.2830552>,
    <0.7500000, -167.3313235>,
    <0.7438958, -167.3315832>,
    <0.7381101, -167.2836036>,
    <0.2557758, -167.2436308>,
    <0.2592592, -167.2690732>,
    <0.2638441, -167.2522483>,
    <0.2500000, -167.2024179>,
    <0.2500000, -167.2507837>,
    <0.2618396, -167.2596042>,
    <0.2560479, -167.2241867>,
    <0.2500000, -167.2235884>,
    <0.2540494, -167.2587824>,
    <0.2557897, -167.2811646>,
    <0.2592592, -167.2690732>,
    <0.2500000, -167.2507837>,
    <0.2500000, -167.3024008>,
    <0.2638995, -167.3024008>,
    <0.2540494, -167.2587824>,
    <0.2500000, -167.2798504>,
    <0.2560828, -167.3024008>,
    <0.2618710, -167.2878319>,
    <0.2661952, -167.2815307>,
    <0.2592592, -167.2690732>,
    <0.2638995, -167.3024008>,
    <0.2777778, -167.3024008>,
    <0.2638441, -167.2522483>,
    <0.2618710, -167.2878319>,
    <0.2717060, -167.3024008>,
    <0.2716713, -167.2804214>,
    <0.2618396, -167.2596042>,
    <0.2615672, -167.3280360>,
    <0.2685185, -167.3434849>,
    <0.2638995, -167.3024008>,
    <0.2500000, -167.3024008>,
    <0.2638507, -167.3638575>,
    <0.2659181, -167.3203558>,
    <0.2560828, -167.3024008>,
    <0.2560522, -167.3292549>,
    <0.2658899, -167.3549573>,
    <0.2719812, -167.3739447>,
    <0.2685185, -167.3434849>,
    <0.2638507, -167.3638575>,
    <0.2777778, -167.4256532>,
    <0.2777778, -167.3627833>,
    <0.2658899, -167.3549573>,
    <0.2716757, -167.3985780>,
    <0.2777778, -167.3982231>,
    <0.2737225, -167.3543311>,
    <0.2719934, -167.3277674>,
    <0.2685185, -167.3434849>,
    <0.2777778, -167.3627833>,
    <0.2777778, -167.3024008>,
    <0.2638995, -167.3024008>,
    <0.2737225, -167.3543311>,
    <0.2777778, -167.3288803>,
    <0.2717060, -167.3024008>,
    <0.2659181, -167.3203558>,
    <0.7279997, -167.3534027>,
    <0.7314815, -167.3845690>,
    <0.7360729, -167.3638575>,
    <0.7222222, -167.3024008>,
    <0.7222222, -167.3627833>,
    <0.7340656, -167.3729124>,
    <0.7282744, -167.3292549>,
    <0.7222222, -167.3288803>,
    <0.7262721, -167.3723121>,
    <0.7280115, -167.3996647>,
    <0.7314815, -167.3845690>,
    <0.7222222, -167.3627833>,
    <0.7222222, -167.4256532>,
    <0.7361201, -167.4256532>,
    <0.7262721, -167.3723121>,
    <0.7222222, -167.3982231>,
    <0.7283041, -167.4256532>,
    <0.7340927, -167.4076960>,
    <0.7384186, -167.3999332>,
    <0.7314815, -167.3845690>,
    <0.7361201, -167.4256532>,
    <0.7500000, -167.4256532>,
    <0.7360729, -167.3638575>,
    <0.7340927, -167.4076960>,
    <0.7439274, -167.4256532>,
    <0.7438980, -167.3985780>,
    <0.7340656, -167.3729124>,
    <0.7337894, -167.3280360>,
    <0.7407408, -167.3434849>,
    <0.7361217, -167.3024008>,
    <0.7222222, -167.3024008>,
    <0.7360729, -167.3638575>,
    <0.7381404, -167.3203558>,
    <0.7283050, -167.3024008>,
    <0.7282744, -167.3292549>,
    <0.7381122, -167.3549573>,
    <0.7442034, -167.3739447>,
    <0.7407408, -167.3434849>,
    <0.7360729, -167.3638575>,
    <0.7500000, -167.4256532>,
    <0.7500000, -167.3627833>,
    <0.7381122, -167.3549573>,
    <0.7438980, -167.3985780>,
    <0.7500000, -167.3982231>,
    <0.7459447, -167.3543311>,
    <0.7442156, -167.3277674>,
    <0.7407408, -167.3434849>,
    <0.7500000, -167.3627833>,
    <0.7500000, -167.3024008>,
    <0.7361217, -167.3024008>,
    <0.7459447, -167.3543311>,
    <0.7500000, -167.3288803>,
    <0.7439282, -167.3024008>,
    <0.7381404, -167.3203558>,
    <0.2571292, -167.0910992>,
    <0.2592592, -167.1000319>,
    <0.2500000, -167.0946262>,
    <0.2500000, -167.0684463>,
    <0.2692576, -167.1012925>,
    <0.2539947, -167.0969584>,
    <0.2500000, -167.0817386>,
    <0.2616800, -167.0883680>,
    <0.2641881, -167.1006533>,
    <0.2674008, -167.1082434>,
    <0.2592592, -167.1000319>,
    <0.2692576, -167.1012925>,
    <0.2777778, -167.1158246>,
    <0.2633084, -167.1158246>,
    <0.2641881, -167.1006533>,
    <0.2743617, -167.1099981>,
    <0.2715225, -167.1158246>,
    <0.2614188, -167.1084546>,
    <0.2556419, -167.1065768>,
    <0.2592592, -167.1000319>,
    <0.2633084, -167.1158246>,
    <0.2500000, -167.1158246>,
    <0.2500000, -167.0946262>,
    <0.2614188, -167.1084546>,
    <0.2554877, -167.1158246>,
    <0.2500000, -167.1099564>,
    <0.2539947, -167.0969584>,
    <0.2595082, -167.0806061>,
    <0.2630656, -167.0842391>,
    <0.2692576, -167.1012925>,
    <0.2500000, -167.0684463>,
    <0.2557095, -167.0684463>,
    <0.2671164, -167.0953953>,
    <0.2616800, -167.0883680>,
    <0.2528547, -167.0684463>,
    <0.2586662, -167.0747941>,
    <0.2627018, -167.0790514>,
    <0.2630656, -167.0842391>,
    <0.2557095, -167.0684463>,
    <0.2614190, -167.0684463>,
    <0.2706130, -167.0950739>,
    <0.2586662, -167.0747941>,
    <0.2585642, -167.0684463>,
    <0.2657993, -167.0811326>,
    <0.2668605, -167.0896870>,
    <0.2701785, -167.0991075>,
    <0.2630656, -167.0842391>,
    <0.2706130, -167.0950739>,
    <0.2777778, -167.1158246>,
    <0.2692576, -167.1012925>,
    <0.2668605, -167.0896870>,
    <0.2749329, -167.1075853>,
    <0.2743617, -167.1099981>,
    <0.2671164, -167.0953953>,
    <0.2613462, -167.1384089>,
    <0.2685185, -167.1524837>,
    <0.2635578, -167.1695025>,
    <0.2500000, -167.1158246>,
    <0.2633084, -167.1158246>,
    <0.2657186, -167.1620893>,
    <0.2557288, -167.1385059>,
    <0.2554877, -167.1158246>,
    <0.2655657, -167.1317075>,
    <0.2718456, -167.1377506>,
    <0.2685185, -167.1524837>,
    <0.2633084, -167.1158246>,
    <0.2777778, -167.1158246>,
    <0.2777778, -167.1668695>,
    <0.2655657, -167.1317075>,
    <0.2715225, -167.1158246>,
    <0.2777778, -167.1355974>,
    <0.2737167, -167.1605600>,
    <0.2719080, -167.1786644>,
    <0.2685185, -167.1524837>,
    <0.2777778, -167.1668695>,
    <0.2777778, -167.2258020>,
    <0.2635578, -167.1695025>,
    <0.2737167, -167.1605600>,
    <0.2777778, -167.1999394>,
    <0.2715141, -167.2010031>,
    <0.2657186, -167.1620893>,
    <0.7279267, -167.1604767>,
    <0.7314815, -167.1891429>,
    <0.7222222, -167.1674336>,
    <0.7222222, -167.1158246>,
    <0.7357809, -167.1695057>,
    <0.7262749, -167.1769355>,
    <0.7222222, -167.1361016>,
    <0.7279518, -167.1385089>,
    <0.7339041, -167.1780778>,
    <0.7383463, -167.2025631>,
    <0.7314815, -167.1891429>,
    <0.7357809, -167.1695057>,
    <0.7500000, -167.2258020>,
    <0.7361229, -167.2258020>,
    <0.7339041, -167.1780778>,
    <0.7437368, -167.2010049>,
    <0.7439288, -167.2258020>,
    <0.7340855, -167.2097099>,
    <0.7280122, -167.2020451>,
    <0.7314815, -167.1891429>,
    <0.7361229, -167.2258020>,
    <0.7222222, -167.2258020>,
    <0.7222222, -167.1674336>,
    <0.7340855, -167.2097099>,
    <0.7283056, -167.2258020>,
    <0.7222222, -167.2002392>,
    <0.7262749, -167.1769355>,
    <0.7335723, -167.1384097>,
    <0.7407408, -167.1524837>,
    <0.7357809, -167.1695057>,
    <0.7222222, -167.1158246>,
    <0.7355453, -167.1158246>,
    <0.7379417, -167.1620898>,
    <0.7279518, -167.1385089>,
    <0.7277183, -167.1158246>,
    <0.7377969, -167.1317119>,
    <0.7440715, -167.1378791>,
    <0.7407408, -167.1524837>,
    <0.7355453, -167.1158246>,
    <0.7500000, -167.1158246>,
    <0.7500000, -167.1673835>,
    <0.7377969, -167.1317119>,
    <0.7437543, -167.1158246>,
    <0.7500000, -167.1360519>,
    <0.7459388, -167.1608484>,
    <0.7441304, -167.1787937>,
    <0.7407408, -167.1524837>,
    <0.7500000, -167.1673835>,
    <0.7500000, -167.2258020>,
    <0.7357809, -167.1695057>,
    <0.7459388, -167.1608484>,
    <0.7500000, -167.2002138>,
    <0.7437368, -167.2010049>,
    <0.7379417, -167.1620898>,
    <0.2558468, -167.1583892>,
    <0.2592593, -167.1778641>,
    <0.2641279, -167.1662209>,
    <0.2500000, -167.1287564>,
    <0.2500000, -167.1607153>,
    <0.2620065, -167.1712941>,
    <0.2562572, -167.1453493>,
    <0.2500000, -167.1413912>,
    <0.2540567, -167.1682287>,
    <0.2557900, -167.1858538>,
    <0.2592593, -167.1778641>,
    <0.2500000, -167.1607153>,
    <0.2500000, -167.2024179>,
    <0.2639007, -167.2024179>,
    <0.2540567, -167.1682287>,
    <0.2500000, -167.1838307>,
    <0.2560834, -167.2024179>,
    <0.2618796, -167.1917260>,
    <0.2662664, -167.1872302>,
    <0.2592593, -167.1778641>,
    <0.2639007, -167.2024179>,
    <0.2777778, -167.2024179>,
    <0.2641279, -167.1662209>,
    <0.2618796, -167.1917260>,
    <0.2717066, -167.2024179>,
    <0.2718374, -167.1866652>,
    <0.2620065, -167.1712941>,
    <0.2615658, -167.2232074>,
    <0.2685185, -167.2357456>,
    <0.2639007, -167.2024179>,
    <0.2500000, -167.2024179>,
    <0.2638441, -167.2522483>,
    <0.2659184, -167.2169804>,
    <0.2560834, -167.2024179>,
    <0.2560479, -167.2241867>,
    <0.2658862, -167.2450388>,
    <0.2719795, -167.2602946>,
    <0.2685185, -167.2357456>,
    <0.2638441, -167.2522483>,
    <0.2777778, -167.3024008>,
    <0.2777778, -167.2507837>,
    <0.2658862, -167.2450388>,
    <0.2716713, -167.2804214>,
    <0.2777778, -167.2798504>,
    <0.2737221, -167.2441968>,
    <0.2719937, -167.2228413>,
    <0.2685185, -167.2357456>,
    <0.2777778, -167.2507837>,
    <0.2777778, -167.2024179>,
    <0.2639007, -167.2024179>,
    <0.2737221, -167.2441968>,
    <0.2777778, -167.2235884>,
    <0.2717066, -167.2024179>,
    <0.2659184, -167.2169804>,
    <0.7279981, -167.2436308>,
    <0.7314815, -167.2690732>,
    <0.7360664, -167.2522483>,
    <0.7222222, -167.2024179>,
    <0.7222222, -167.2507837>,
    <0.7340618, -167.2596042>,
    <0.7282702, -167.2241867>,
    <0.7222222, -167.2235884>,
    <0.7262716, -167.2587824>,
    <0.7280119, -167.2811646>,
    <0.7314815, -167.2690732>,
    <0.7222222, -167.2507837>,
    <0.7222222, -167.3024008>,
    <0.7361217, -167.3024008>,
    <0.7262716, -167.2587824>,
    <0.7222222, -167.2798504>,
    <0.7283050, -167.3024008>,
    <0.7340933, -167.2878319>,
    <0.7384174, -167.2815307>,
    <0.7314815, -167.2690732>,
    <0.7361217, -167.3024008>,
    <0.7500000, -167.3024008>,
    <0.7360664, -167.2522483>,
    <0.7340933, -167.2878319>,
    <0.7439282, -167.3024008>,
    <0.7438936, -167.2804214>,
    <0.7340618, -167.2596042>,
    <0.7337881, -167.2232074>,
    <0.7407407, -167.2357456>,
    <0.7361229, -167.2024179>,
    <0.7222222, -167.2024179>,
    <0.7360664, -167.2522483>,
    <0.7381407, -167.2169804>,
    <0.7283057, -167.2024179>,
    <0.7282702, -167.2241867>,
    <0.7381085, -167.2450388>,
    <0.7442018, -167.2602946>,
    <0.7407407, -167.2357456>,
    <0.7360664, -167.2522483>,
    <0.7500000, -167.3024008>,
    <0.7500000, -167.2507837>,
    <0.7381085, -167.2450388>,
    <0.7438936, -167.2804214>,
    <0.7500000, -167.2798504>,
    <0.7459443, -167.2441968>,
    <0.7442159, -167.2228413>,
    <0.7407407, -167.2357456>,
    <0.7500000, -167.2507837>,
    <0.7500000, -167.2024179>,
    <0.7361229, -167.2024179>,
    <0.7459443, -167.2441968>,
    <0.7500000, -167.2235884>,
    <0.7439288, -167.2024179>,
    <0.7381407, -167.2169804>,
    <0.2684888, -167.0790514>,
    <0.2723248, -167.0842391>,
    <0.2706130, -167.0950739>,
    <0.2614190, -167.0684463>,
    <0.2695984, -167.0684463>,
    <0.2712991, -167.0907311>,
    <0.2657993, -167.0811326>,
    <0.2655087, -167.0684463>,
    <0.2707814, -167.0752987>,
    <0.2743697, -167.0792581>,
    <0.2723248, -167.0842391>,
    <0.2695984, -167.0684463>,
    <0.2777778, -167.0684463>,
    <0.2777778, -167.0959009>,
    <0.2707814, -167.0752987>,
    <0.2736881, -167.0684463>,
    <0.2777778, -167.0830521>,
    <0.2754587, -167.0909414>,
    <0.2746233, -167.0977596>,
    <0.2723248, -167.0842391>,
    <0.2777778, -167.0959009>,
    <0.2777778, -167.1158246>,
    <0.2706130, -167.0950739>,
    <0.2754587, -167.0909414>,
    <0.2777778, -167.1102151>,
    <0.2749329, -167.1075853>,
    <0.2712991, -167.0907311>,
    <0.7293268, -167.0910603>,
    <0.7314815, -167.1000319>,
    <0.7222222, -167.0946389>,
    <0.7222222, -167.0684463>,
    <0.7413813, -167.1011243>,
    <0.7262223, -167.0969687>,
    <0.7222222, -167.0816043>,
    <0.7337818, -167.0881626>,
    <0.7363605, -167.1005703>,
    <0.7396020, -167.1082014>,
    <0.7314815, -167.1000319>,
    <0.7413813, -167.1011243>,
    <0.7500000, -167.1158246>,
    <0.7355453, -167.1158246>,
    <0.7363605, -167.1005703>,
    <0.7465382, -167.1099202>,
    <0.7437543, -167.1158246>,
    <0.7336517, -167.1084658>,
    <0.7278678, -167.1065800>,
    <0.7314815, -167.1000319>,
    <0.7355453, -167.1158246>,
    <0.7222222, -167.1158246>,
    <0.7222222, -167.0946389>,
    <0.7336517, -167.1084658>,
    <0.7277183, -167.1158246>,
    <0.7222222, -167.1099625>,
    <0.7262223, -167.0969687>,
    <0.7317781, -167.0805640>,
    <0.7352878, -167.0842391>,
    <0.7413813, -167.1011243>,
    <0.7222222, -167.0684463>,
    <0.7282212, -167.0684463>,
    <0.7392287, -167.0951595>,
    <0.7337818, -167.0881626>,
    <0.7252611, -167.0684463>,
    <0.7310587, -167.0747877>,
    <0.7351349, -167.0794526>,
    <0.7352878, -167.0842391>,
    <0.7282212, -167.0684463>,
    <0.7336412, -167.0684463>,
    <0.7433894, -167.0966789>,
    <0.7310587, -167.0747877>,
    <0.7310286, -167.0684463>,
    <0.7386352, -167.0829098>,
    <0.7393528, -167.0904808>,
    <0.7425146, -167.0994667>,
    <0.7352878, -167.0842391>,
    <0.7433894, -167.0966789>,
    <0.7500000, -167.1158246>,
    <0.7413813, -167.1011243>,
    <0.7393528, -167.0904808>,
    <0.7474313, -167.1083851>,
    <0.7465382, -167.1099202>,
    <0.7392287, -167.0951595>,
    <0.2724917, -167.1106496>,
    <0.2714419, -167.1123151>,
    <0.2767756, -167.1220941>,
    <0.2740679, -167.1040945>,
    <0.2676812, -167.1040945>,
    <0.2740010, -167.1170071>,
    <0.2755276, -167.1137977>,
    <0.2706147, -167.1040945>,
    <0.2690692, -167.1071285>,
    <0.2689203, -167.1108241>,
    <0.2714419, -167.1123151>,
    <0.2676812, -167.1040945>,
    <0.2624800, -167.1040945>,
    <0.2740782, -167.1227923>,
    <0.2690692, -167.1071285>,
    <0.2650063, -167.1040945>,
    <0.2697636, -167.1158365>,
    <0.2731084, -167.1189381>,
    <0.2750184, -167.1214895>,
    <0.2714419, -167.1123151>,
    <0.2740782, -167.1227923>,
    <0.2777778, -167.1287564>,
    <0.2767756, -167.1220941>,
    <0.2731084, -167.1189381>,
    <0.2764284, -167.1265810>,
    <0.2774930, -167.1268636>,
    <0.2740010, -167.1170071>,
    <0.2632090, -167.1176325>,
    <0.2634192, -167.1205358>,
    <0.2740782, -167.1227923>,
    <0.2624799, -167.1040945>,
    <0.2528587, -167.1231073>,
    <0.2693974, -167.1218014>,
    <0.2697635, -167.1158365>,
    <0.2563520, -167.1162039>,
    <0.2577300, -167.1219211>,
    <0.2572993, -167.1252890>,
    <0.2634192, -167.1205358>,
    <0.2528587, -167.1231073>,
    <0.2500000, -167.1287564>,
    <0.2629193, -167.1287564>,
    <0.2577300, -167.1219211>,
    <0.2510380, -167.1267051>,
    <0.2552704, -167.1287564>,
    <0.2630971, -167.1258321>,
    <0.2695486, -167.1252102>,
    <0.2634192, -167.1205358>,
    <0.2629193, -167.1287564>,
    <0.2777778, -167.1287564>,
    <0.2740782, -167.1227923>,
    <0.2630971, -167.1258321>,
    <0.2713120, -167.1287564>,
    <0.2764284, -167.1265810>,
    <0.2693974, -167.1218014>,
    <0.2613914, -167.1442610>,
    <0.2685185, -167.1533103>,
    <0.2629193, -167.1287564>,
    <0.2500000, -167.1287564>,
    <0.2641279, -167.1662209>,
    <0.2656783, -167.1408554>,
    <0.2552704, -167.1287564>,
    <0.2562572, -167.1453493>,
    <0.2661063, -167.1604034>,
    <0.2720505, -167.1706661>,
    <0.2685185, -167.1533103>,
    <0.2641279, -167.1662209>,
    <0.2777778, -167.2024179>,
    <0.2777778, -167.1607153>,
    <0.2661063, -167.1604034>,
    <0.2718374, -167.1866652>,
    <0.2777778, -167.1838308>,
    <0.2737898, -167.1575259>,
    <0.2717483, -167.1428846>,
    <0.2685185, -167.1533103>,
    <0.2777778, -167.1607153>,
    <0.2777778, -167.1287564>,
    <0.2629193, -167.1287564>,
    <0.2737898, -167.1575259>,
    <0.2777778, -167.1413913>,
    <0.2713120, -167.1287564>,
    <0.2656783, -167.1408554>,
    <0.7280923, -167.1582978>,
    <0.7314815, -167.1778641>,
    <0.7364434, -167.1664684>,
    <0.7222222, -167.1287564>,
    <0.7222222, -167.1601023>,
    <0.7342803, -167.1714363>,
    <0.7285801, -167.1456163>,
    <0.7222222, -167.1407348>,
    <0.7262779, -167.1678822>,
    <0.7280122, -167.1857006>,
    <0.7314815, -167.1778641>,
    <0.7222222, -167.1601023>,
    <0.7222222, -167.2024179>,
    <0.7361229, -167.2024179>,
    <0.7262779, -167.1678822>,
    <0.7222222, -167.1835237>,
    <0.7283057, -167.2024179>,
    <0.7341045, -167.1917403>,
    <0.7385120, -167.1872921>,
    <0.7314815, -167.1778641>,
    <0.7361229, -167.2024179>,
    <0.7500000, -167.2024179>,
    <0.7364434, -167.1664684>,
    <0.7341045, -167.1917403>,
    <0.7439288, -167.2024179>,
    <0.7441095, -167.1867974>,
    <0.7342803, -167.1714363>,
    <0.7336976, -167.1443229>,
    <0.7407408, -167.1533103>,
    <0.7353840, -167.1287564>,
    <0.7222222, -167.1287564>,
    <0.7364434, -167.1664684>,
    <0.7380315, -167.1408919>,
    <0.7276353, -167.1287564>,
    <0.7285801, -167.1456163>,
    <0.7383829, -167.1605300>,
    <0.7442960, -167.1706942>,
    <0.7407408, -167.1533103>,
    <0.7364434, -167.1664684>,
    <0.7500000, -167.2024179>,
    <0.7500000, -167.1605800>,
    <0.7383829, -167.1605300>,
    <0.7441095, -167.1867974>,
    <0.7500000, -167.1838663>,
    <0.7460130, -167.1574497>,
    <0.7440312, -167.1428508>,
    <0.7407408, -167.1533103>,
    <0.7500000, -167.1605800>,
    <0.7500000, -167.1287564>,
    <0.7353840, -167.1287564>,
    <0.7460130, -167.1574497>,
    <0.7500000, -167.1409327>,
    <0.7437080, -167.1287564>,
    <0.7380315, -167.1408919>,
    <0.7355665, -167.1175791>,
    <0.7356415, -167.1205421>,
    <0.7465293, -167.1231655>,
    <0.7347021, -167.1041136>,
    <0.7253930, -167.1224954>,
    <0.7419590, -167.1220643>,
    <0.7424221, -167.1165494>,
    <0.7290787, -167.1152176>,
    <0.7302820, -167.1215636>,
    <0.7296602, -167.1251376>,
    <0.7356415, -167.1205421>,
    <0.7253930, -167.1224954>,
    <0.7222222, -167.1287564>,
    <0.7353840, -167.1287564>,
    <0.7302820, -167.1215636>,
    <0.7233789, -167.1264725>,
    <0.7276353, -167.1287564>,
    <0.7354696, -167.1260244>,
    <0.7418887, -167.1253051>,
    <0.7356415, -167.1205421>,
    <0.7353840, -167.1287564>,
    <0.7500000, -167.1287564>,
    <0.7465293, -167.1231655>,
    <0.7354696, -167.1260244>,
    <0.7437080, -167.1287564>,
    <0.7487200, -167.1266944>,
    <0.7419590, -167.1220643>,
    <0.7295271, -167.1107626>,
    <0.7273344, -167.1123279>,
    <0.7253930, -167.1224954>,
    <0.7347021, -167.1041136>,
    <0.7306788, -167.1041136>,
    <0.7260860, -167.1188661>,
    <0.7290787, -167.1152176>,
    <0.7328264, -167.1041136>,
    <0.7295289, -167.1069379>,
    <0.7265830, -167.1101334>,
    <0.7273344, -167.1123279>,
    <0.7306788, -167.1041136>,
    <0.7250789, -167.1041136>,
    <0.7232398, -167.1199785>,
    <0.7295289, -167.1069379>,
    <0.7281662, -167.1041136>,
    <0.7241520, -167.1121092>,
    <0.7253946, -167.1159522>,
    <0.7245474, -167.1208895>,
    <0.7273344, -167.1123279>,
    <0.7232398, -167.1199785>,
    <0.7222222, -167.1287564>,
    <0.7253930, -167.1224954>,
    <0.7253946, -167.1159522>,
    <0.7225657, -167.1257934>,
    <0.7233789, -167.1264725>,
    <0.7260860, -167.1188661>,
    <0.2757301, -167.1106496>,
    <0.2765412, -167.1123151>,
    <0.2755358, -167.1040945>,
    <0.2740679, -167.1040945>,
    <0.2767756, -167.1220941>,
    <0.2759661, -167.1076129>,
    <0.2747108, -167.1040945>,
    <0.2755276, -167.1137977>,
    <0.2766923, -167.1186208>,
    <0.2772181, -167.1197234>,
    <0.2765412, -167.1123151>,
    <0.2767756, -167.1220941>,
    <0.2777778, -167.1287564>,
    <0.2777778, -167.1157281>,
    <0.2766923, -167.1186208>,
    <0.2774930, -167.1268636>,
    <0.2777778, -167.1243298>,
    <0.2772828, -167.1143619>,
    <0.2769081, -167.1090581>,
    <0.2765412, -167.1123151>,
    <0.2777778, -167.1157281>,
    <0.2777778, -167.1040945>,
    <0.2755358, -167.1040945>,
    <0.2772828, -167.1143619>,
    <0.2777778, -167.1077212>,
    <0.2765874, -167.1040945>,
    <0.2759661, -167.1076129>,
    <0.7238672, -167.1101299>,
    <0.7231745, -167.1123215>,
    <0.7232398, -167.1199785>,
    <0.7250789, -167.1041136>,
    <0.7239755, -167.1041062>,
    <0.7232151, -167.1170887>,
    <0.7241520, -167.1121092>,
    <0.7246005, -167.1041104>,
    <0.7236306, -167.1076438>,
    <0.7228986, -167.1098044>,
    <0.7231745, -167.1123215>,
    <0.7239755, -167.1041062>,
    <0.7222222, -167.1040945>,
    <0.7222222, -167.1186953>,
    <0.7236306, -167.1076438>,
    <0.7231590, -167.1041008>,
    <0.7222222, -167.1075966>,
    <0.7225714, -167.1163585>,
    <0.7227147, -167.1199379>,
    <0.7231745, -167.1123215>,
    <0.7222222, -167.1186953>,
    <0.7222222, -167.1287564>,
    <0.7232398, -167.1199785>,
    <0.7225714, -167.1163585>,
    <0.7222222, -167.1268389>,
    <0.7225657, -167.1257934>,
    <0.7232151, -167.1170887>,
    <0.2841980, -167.1109029>,
    <0.2819377, -167.1123151>,
    <0.2806364, -167.1231073>,
    <0.2902576, -167.1040945>,
    <0.2839603, -167.1040945>,
    <0.2811373, -167.1189534>,
    <0.2841298, -167.1162039>,
    <0.2870870, -167.1040945>,
    <0.2832872, -167.1068303>,
    <0.2803634, -167.1090581>,
    <0.2819377, -167.1123151>,
    <0.2839603, -167.1040945>,
    <0.2777778, -167.1040945>,
    <0.2777778, -167.1157281>,
    <0.2832872, -167.1068303>,
    <0.2808619, -167.1040945>,
    <0.2777778, -167.1077212>,
    <0.2798779, -167.1140051>,
    <0.2795324, -167.1199767>,
    <0.2819377, -167.1123151>,
    <0.2777778, -167.1157281>,
    <0.2777778, -167.1287564>,
    <0.2806364, -167.1231073>,
    <0.2798779, -167.1140051>,
    <0.2777778, -167.1243298>,
    <0.2788158, -167.1267051>,
    <0.2811373, -167.1189534>,
    <0.7144288, -167.1109046>,
    <0.7171229, -167.1123151>,
    <0.7149455, -167.1040945>,
    <0.7069243, -167.1040945>,
    <0.7187224, -167.1231143>,
    <0.7157259, -167.1070407>,
    <0.7110908, -167.1040945>,
    <0.7145967, -167.1164632>,
    <0.7180855, -167.1188144>,
    <0.7200724, -167.1207203>,
    <0.7171229, -167.1123151>,
    <0.7187224, -167.1231143>,
    <0.7222222, -167.1287564>,
    <0.7222222, -167.1186953>,
    <0.7180855, -167.1188144>,
    <0.7209466, -167.1267000>,
    <0.7222222, -167.1268389>,
    <0.7196306, -167.1154527>,
    <0.7191282, -167.1097999>,
    <0.7171229, -167.1123151>,
    <0.7222222, -167.1186953>,
    <0.7222222, -167.1040945>,
    <0.7149455, -167.1040945>,
    <0.7196306, -167.1154527>,
    <0.7222222, -167.1075966>,
    <0.7186266, -167.1040945>,
    <0.7157259, -167.1070407>,
    <0.7131519, -167.0794526>,
    <0.7167693, -167.0842391>,
    <0.7156116, -167.0966788>,
    <0.7058635, -167.0684463>,
    <0.7143632, -167.0684463>,
    <0.7160719, -167.0917323>,
    <0.7108573, -167.0829096>,
    <0.7102443, -167.0684463>,
    <0.7154101, -167.0753177>,
    <0.7188943, -167.0789426>,
    <0.7167693, -167.0842391>,
    <0.7143632, -167.0684463>,
    <0.7222222, -167.0684463>,
    <0.7222222, -167.0946389>,
    <0.7154101, -167.0753177>,
    <0.7183302, -167.0684463>,
    <0.7222222, -167.0816043>,
    <0.7199196, -167.0902473>,
    <0.7192063, -167.0978454>,
    <0.7167693, -167.0842391>,
    <0.7222222, -167.0946389>,
    <0.7222222, -167.1158246>,
    <0.7156116, -167.0966788>,
    <0.7199196, -167.0902473>,
    <0.7222222, -167.1099625>,
    <0.7196534, -167.1083847>,
    <0.7160719, -167.0917323>,
    <0.2826835, -167.9429356>,
    <0.2870370, -168.0047729>,
    <0.2777778, -167.9408490>,
    <0.2777778, -167.8774261>,
    <0.2881415, -167.9486944>,
    <0.2819739, -167.9698185>,
    <0.2777778, -167.9045528>,
    <0.2822178, -167.9079590>,
    <0.2876378, -167.9742691>,
    <0.2931002, -168.0225900>,
    <0.2870370, -168.0047729>,
    <0.2881415, -167.9486944>,
    <0.3055555, -168.0684463>,
    <0.2916667, -168.0684463>,
    <0.2876378, -167.9742691>,
    <0.2957022, -168.0006878>,
    <0.2986111, -168.0684463>,
    <0.2897818, -168.0425234>,
    <0.2835648, -168.0206286>,
    <0.2870370, -168.0047729>,
    <0.2916667, -168.0684463>,
    <0.2777778, -168.0684463>,
    <0.2777778, -167.9408490>,
    <0.2897818, -168.0425234>,
    <0.2847222, -168.0684463>,
    <0.2777778, -167.9889759>,
    <0.2819739, -167.9698185>,
    <0.2835490, -167.7682235>,
    <0.2870370, -167.8156918>,
    <0.2777778, -167.7805759>,
    <0.2777778, -167.6922232>,
    <0.2916034, -167.7844031>,
    <0.2818243, -167.7959225>,
    <0.2777778, -167.7304643>,
    <0.2838160, -167.7324821>,
    <0.2896075, -167.7980793>,
    <0.2939690, -167.8387367>,
    <0.2870370, -167.8156918>,
    <0.2916034, -167.7844031>,
    <0.3055555, -167.8774261>,
    <0.2916800, -167.8774261>,
    <0.2896075, -167.7980793>,
    <0.2994976, -167.8370359>,
    <0.2995735, -167.8774261>,
    <0.2896713, -167.8507182>,
    <0.2835681, -167.8377800>,
    <0.2870370, -167.8156918>,
    <0.2916800, -167.8774261>,
    <0.2777778, -167.8774261>,
    <0.2777778, -167.7805759>,
    <0.2896713, -167.8507182>,
    <0.2837429, -167.8774261>,
    <0.2777778, -167.8353309>,
    <0.2818243, -167.7959225>,
    <0.2884739, -167.9111615>,
    <0.2962963, -167.9410995>,
    <0.2881415, -167.9486944>,
    <0.2777778, -167.8774261>,
    <0.2916800, -167.8774261>,
    <0.2913985, -167.9456610>,
    <0.2822178, -167.9079590>,
    <0.2837429, -167.8774261>,
    <0.2938328, -167.9071196>,
    <0.2997719, -167.9091872>,
    <0.2962963, -167.9410995>,
    <0.2916800, -167.8774261>,
    <0.3055555, -167.8774261>,
    <0.3055555, -167.9407972>,
    <0.2938328, -167.9071196>,
    <0.2995735, -167.8774261>,
    <0.3055555, -167.9045195>,
    <0.3016691, -167.9409241>,
    <0.2988872, -167.9747593>,
    <0.2962963, -167.9410995>,
    <0.3055555, -167.9407972>,
    <0.3055555, -168.0684463>,
    <0.2881415, -167.9486944>,
    <0.3016691, -167.9409241>,
    <0.3055555, -167.9888971>,
    <0.2957022, -168.0006878>,
    <0.2913985, -167.9456610>,
    <0.6975261, -167.9302248>,
    <0.7037037, -168.0047729>,
    <0.6944445, -167.9401814>,
    <0.6944445, -167.8774261>,
    <0.6975117, -167.8985187>,
    <0.6986549, -167.9695528>,
    <0.6944445, -167.9038445>,
    <0.6956861, -167.8859644>,
    <0.7003808, -167.9477528>,
    <0.7070381, -168.0100460>,
    <0.7037037, -168.0047729>,
    <0.6975117, -167.8985187>,
    <0.7222222, -168.0684463>,
    <0.7047146, -168.0684463>,
    <0.7003808, -167.9477528>,
    <0.7013953, -167.9252252>,
    <0.7109316, -168.0684463>,
    <0.7043256, -168.0439459>,
    <0.6993268, -168.0204617>,
    <0.7037037, -168.0047729>,
    <0.7047146, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6944445, -167.9401814>,
    <0.7043256, -168.0439459>,
    <0.6992997, -168.0684463>,
    <0.6944445, -167.9891217>,
    <0.6986549, -167.9695528>,
    <0.7033182, -167.8986176>,
    <0.7129630, -167.9410995>,
    <0.6975117, -167.8985187>,
    <0.6944445, -167.8774261>,
    <0.7083535, -167.8774261>,
    <0.7032309, -167.9142797>,
    <0.6956861, -167.8859644>,
    <0.7003142, -167.8774261>,
    <0.7105191, -167.9073400>,
    <0.7164402, -167.9203026>,
    <0.7129630, -167.9410995>,
    <0.7083535, -167.8774261>,
    <0.7222222, -167.8774261>,
    <0.7222222, -167.9852586>,
    <0.7105191, -167.9073400>,
    <0.7162108, -167.8774261>,
    <0.7222222, -167.9261964>,
    <0.7184147, -167.9670997>,
    <0.7137298, -167.9733308>,
    <0.7129630, -167.9410995>,
    <0.7222222, -167.9852586>,
    <0.7222222, -168.0684463>,
    <0.6975117, -167.8985187>,
    <0.7184147, -167.9670997>,
    <0.7222222, -168.0282490>,
    <0.7013953, -167.9252252>,
    <0.7032309, -167.9142797>,
    <0.2835587, -167.5906989>,
    <0.2870370, -167.6342972>,
    <0.2777778, -167.6048705>,
    <0.2777778, -167.5184453>,
    <0.2916424, -167.6051824>,
    <0.2818287, -167.6177446>,
    <0.2777778, -167.5563664>,
    <0.2838390, -167.5563642>,
    <0.2896292, -167.6179095>,
    <0.2939768, -167.6559815>,
    <0.2870370, -167.6342972>,
    <0.2916424, -167.6051824>,
    <0.3055555, -167.6922232>,
    <0.2916721, -167.6922232>,
    <0.2896292, -167.6179095>,
    <0.2994628, -167.6541068>,
    <0.2994812, -167.6922232>,
    <0.2896464, -167.6669079>,
    <0.2835662, -167.6559035>,
    <0.2870370, -167.6342972>,
    <0.2916721, -167.6922232>,
    <0.2777778, -167.6922232>,
    <0.2777778, -167.6048705>,
    <0.2896464, -167.6669079>,
    <0.2838577, -167.6922232>,
    <0.2777778, -167.6541051>,
    <0.2818287, -167.6177446>,
    <0.2893374, -167.7307017>,
    <0.2962963, -167.7539575>,
    <0.2916034, -167.7844031>,
    <0.2777778, -167.6922232>,
    <0.2916721, -167.6922232>,
    <0.2936539, -167.7711002>,
    <0.2838160, -167.7324821>,
    <0.2838577, -167.6922232>,
    <0.2936914, -167.7191820>,
    <0.2997699, -167.7297409>,
    <0.2962963, -167.7539575>,
    <0.2916721, -167.6922232>,
    <0.3055555, -167.6922232>,
    <0.3055555, -167.7805596>,
    <0.2936914, -167.7191820>,
    <0.2994812, -167.6922232>,
    <0.3055555, -167.7304559>,
    <0.3015015, -167.7689121>,
    <0.2997527, -167.7990865>,
    <0.2962963, -167.7539575>,
    <0.3055555, -167.7805596>,
    <0.3055555, -167.8774261>,
    <0.2916034, -167.7844031>,
    <0.3015015, -167.7689121>,
    <0.3055555, -167.8353092>,
    <0.2994976, -167.8370359>,
    <0.2936539, -167.7711002>,
    <0.7002126, -167.7681733>,
    <0.7037037, -167.8156918>,
    <0.6944445, -167.7804581>,
    <0.6944445, -167.6922232>,
    <0.7082577, -167.7843202>,
    <0.6984896, -167.7958509>,
    <0.6944445, -167.7304035>,
    <0.7004758, -167.7324359>,
    <0.7062659, -167.7980412>,
    <0.7106343, -167.8387160>,
    <0.7037037, -167.8156918>,
    <0.7082577, -167.7843202>,
    <0.7222222, -167.8774261>,
    <0.7083535, -167.8774261>,
    <0.7062659, -167.7980412>,
    <0.7160927, -167.8365588>,
    <0.7162108, -167.8774261>,
    <0.7063557, -167.8509015>,
    <0.7002365, -167.8377505>,
    <0.7037037, -167.8156918>,
    <0.7083535, -167.8774261>,
    <0.6944445, -167.8774261>,
    <0.6944445, -167.7804581>,
    <0.7063557, -167.8509015>,
    <0.7003142, -167.8774261>,
    <0.6944445, -167.8357431>,
    <0.6984896, -167.7958509>,
    <0.7060010, -167.7306810>,
    <0.7129630, -167.7539575>,
    <0.7082577, -167.7843202>,
    <0.6944445, -167.6922232>,
    <0.7083388, -167.6922232>,
    <0.7103136, -167.7710539>,
    <0.7004758, -167.7324359>,
    <0.7005244, -167.6922232>,
    <0.7103578, -167.7191773>,
    <0.7164365, -167.7297184>,
    <0.7129630, -167.7539575>,
    <0.7083388, -167.6922232>,
    <0.7222222, -167.6922232>,
    <0.7222222, -167.7804696>,
    <0.7103578, -167.7191773>,
    <0.7161479, -167.6922232>,
    <0.7222222, -167.7304093>,
    <0.7181681, -167.7688613>,
    <0.7164163, -167.7990433>,
    <0.7129630, -167.7539575>,
    <0.7222222, -167.7804696>,
    <0.7222222, -167.8774261>,
    <0.7082577, -167.7843202>,
    <0.7181681, -167.7688613>,
    <0.7222222, -167.8349051>,
    <0.7160927, -167.8365588>,
    <0.7103136, -167.7710539>,
    <0.2826843, -167.9543398>,
    <0.2870370, -168.0105648>,
    <0.2881446, -167.9596072>,
    <0.2777778, -167.8948019>,
    <0.2777778, -167.9523852>,
    <0.2876395, -167.9828475>,
    <0.2822203, -167.9225728>,
    <0.2777778, -167.9195727>,
    <0.2819740, -167.9787519>,
    <0.2835648, -168.0249606>,
    <0.2870370, -168.0105648>,
    <0.2777778, -167.9523852>,
    <0.2777778, -168.0684463>,
    <0.2916667, -168.0684463>,
    <0.2819740, -167.9787519>,
    <0.2777778, -167.9958969>,
    <0.2847222, -168.0684463>,
    <0.2897821, -168.0448852>,
    <0.2931010, -168.0267661>,
    <0.2870370, -168.0105648>,
    <0.2916667, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.2881446, -167.9596072>,
    <0.2897821, -168.0448852>,
    <0.2986111, -168.0684463>,
    <0.2957053, -168.0068703>,
    <0.2876395, -167.9828475>,
    <0.2835499, -167.7954433>,
    <0.2870370, -167.8386752>,
    <0.2916069, -167.8102497>,
    <0.2777778, -167.7264218>,
    <0.2777778, -167.8064264>,
    <0.2896091, -167.8226762>,
    <0.2838181, -167.7630363>,
    <0.2777778, -167.7610050>,
    <0.2818245, -167.8205208>,
    <0.2835681, -167.8586764>,
    <0.2870370, -167.8386752>,
    <0.2777778, -167.8064264>,
    <0.2777778, -167.8948019>,
    <0.2916798, -167.8948019>,
    <0.2818245, -167.8205208>,
    <0.2777778, -167.8565724>,
    <0.2837428, -167.8948019>,
    <0.2896729, -167.8705404>,
    <0.2939698, -167.8596322>,
    <0.2870370, -167.8386752>,
    <0.2916798, -167.8948019>,
    <0.3055555, -167.8948019>,
    <0.2916069, -167.8102497>,
    <0.2896729, -167.8705404>,
    <0.2995734, -167.8948019>,
    <0.2995002, -167.8580961>,
    <0.2896091, -167.8226762>,
    <0.2884746, -167.9254736>,
    <0.2962963, -167.9526834>,
    <0.2916798, -167.8948019>,
    <0.2777778, -167.8948019>,
    <0.2881446, -167.9596072>,
    <0.2938348, -167.9218212>,
    <0.2837428, -167.8948019>,
    <0.2822203, -167.9225728>,
    <0.2913970, -167.9568447>,
    <0.2988880, -167.9832680>,
    <0.2962963, -167.9526834>,
    <0.2881446, -167.9596072>,
    <0.3055555, -168.0684463>,
    <0.3055555, -167.9523352>,
    <0.2913970, -167.9568447>,
    <0.2957053, -168.0068703>,
    <0.3055555, -167.9958176>,
    <0.3016695, -167.9524813>,
    <0.2997718, -167.9236556>,
    <0.2962963, -167.9526834>,
    <0.3055555, -167.9523352>,
    <0.3055555, -167.8948019>,
    <0.2916798, -167.8948019>,
    <0.3016695, -167.9524813>,
    <0.3055555, -167.9195413>,
    <0.2995734, -167.8948019>,
    <0.2938348, -167.9218212>,
    <0.6978061, -167.9445202>,
    <0.7037037, -168.0105648>,
    <0.6986317, -167.9209770>,
    <0.6944445, -167.8948019>,
    <0.6944445, -167.9517372>,
    <0.7009808, -167.9624690>,
    <0.6961552, -167.9054961>,
    <0.6944445, -167.9189386>,
    <0.6986614, -167.9785293>,
    <0.6995288, -168.0247986>,
    <0.7037037, -168.0105648>,
    <0.6944445, -167.9517372>,
    <0.6944445, -168.0684463>,
    <0.7055227, -168.0684463>,
    <0.6986614, -167.9785293>,
    <0.6944445, -167.9959765>,
    <0.6997403, -168.0684463>,
    <0.7048194, -168.0460674>,
    <0.7075201, -168.0171086>,
    <0.7037037, -168.0105648>,
    <0.7055227, -168.0684463>,
    <0.7222222, -168.0684463>,
    <0.6986317, -167.9209770>,
    <0.7048194, -168.0460674>,
    <0.7121760, -168.0684463>,
    <0.7031373, -167.9491425>,
    <0.7009808, -167.9624690>,
    <0.7035981, -167.9158161>,
    <0.7129630, -167.9526834>,
    <0.7083532, -167.8948019>,
    <0.6944445, -167.8948019>,
    <0.6986317, -167.9209770>,
    <0.7105247, -167.9220678>,
    <0.7003227, -167.8948019>,
    <0.6961552, -167.9054961>,
    <0.7039373, -167.9327152>,
    <0.7140098, -167.9821532>,
    <0.7129630, -167.9526834>,
    <0.6986317, -167.9209770>,
    <0.7222222, -168.0684463>,
    <0.7222222, -167.9865060>,
    <0.7039373, -167.9327152>,
    <0.7031373, -167.9491425>,
    <0.7222222, -168.0340031>,
    <0.7185040, -167.9729241>,
    <0.7164402, -167.9321983>,
    <0.7129630, -167.9526834>,
    <0.7222222, -167.9865060>,
    <0.7222222, -167.8948019>,
    <0.7083532, -167.8948019>,
    <0.7185040, -167.9729241>,
    <0.7222222, -167.9354614>,
    <0.7163037, -167.8948019>,
    <0.7105247, -167.9220678>,
    <0.2835565, -167.4265843>,
    <0.2870370, -167.4660888>,
    <0.2777778, -167.4391507>,
    <0.2777778, -167.3613758>,
    <0.2916333, -167.4397221>,
    <0.2818280, -167.4509341>,
    <0.2777778, -167.3955180>,
    <0.2838331, -167.3956156>,
    <0.2896239, -167.4512490>,
    <0.2939751, -167.4856754>,
    <0.2870370, -167.4660888>,
    <0.2916333, -167.4397221>,
    <0.3055555, -167.5184453>,
    <0.2916745, -167.5184453>,
    <0.2896239, -167.4512490>,
    <0.2994568, -167.4839601>,
    <0.2994824, -167.5184453>,
    <0.2896478, -167.4955641>,
    <0.2835668, -167.4855325>,
    <0.2870370, -167.4660888>,
    <0.2916745, -167.5184453>,
    <0.2777778, -167.5184453>,
    <0.2777778, -167.4391507>,
    <0.2896478, -167.4955641>,
    <0.2838590, -167.5184453>,
    <0.2777778, -167.4838674>,
    <0.2818280, -167.4509341>,
    <0.2893477, -167.5546111>,
    <0.2962963, -167.5763713>,
    <0.2916424, -167.6051824>,
    <0.2777778, -167.5184453>,
    <0.2916745, -167.5184453>,
    <0.2936756, -167.5925951>,
    <0.2838390, -167.5563642>,
    <0.2838590, -167.5184453>,
    <0.2936950, -167.5437683>,
    <0.2997705, -167.5545331>,
    <0.2962963, -167.5763713>,
    <0.2916745, -167.5184453>,
    <0.3055555, -167.5184453>,
    <0.3055555, -167.6048705>,
    <0.2936950, -167.5437683>,
    <0.2994824, -167.5184453>,
    <0.3055555, -167.5563664>,
    <0.3015010, -167.5923911>,
    <0.2997624, -167.6196618>,
    <0.2962963, -167.5763713>,
    <0.3055555, -167.6048705>,
    <0.3055555, -167.6922232>,
    <0.2916424, -167.6051824>,
    <0.3015010, -167.5923911>,
    <0.3055555, -167.6541051>,
    <0.2994628, -167.6541068>,
    <0.2936756, -167.5925951>,
    <0.7002254, -167.5906989>,
    <0.7037037, -167.6342972>,
    <0.6944445, -167.6048705>,
    <0.6944445, -167.5184453>,
    <0.7083091, -167.6051824>,
    <0.6984954, -167.6177446>,
    <0.6944445, -167.5563664>,
    <0.7005056, -167.5563642>,
    <0.7062959, -167.6179095>,
    <0.7106434, -167.6559815>,
    <0.7037037, -167.6342972>,
    <0.7083091, -167.6051824>,
    <0.7222222, -167.6922232>,
    <0.7083388, -167.6922232>,
    <0.7062959, -167.6179095>,
    <0.7161295, -167.6541068>,
    <0.7161479, -167.6922232>,
    <0.7063131, -167.6669079>,
    <0.7002328, -167.6559035>,
    <0.7037037, -167.6342972>,
    <0.7083388, -167.6922232>,
    <0.6944445, -167.6922232>,
    <0.6944445, -167.6048705>,
    <0.7063131, -167.6669079>,
    <0.7005244, -167.6922232>,
    <0.6944445, -167.6541051>,
    <0.6984954, -167.6177446>,
    <0.7060144, -167.5546111>,
    <0.7129630, -167.5763713>,
    <0.7083091, -167.6051824>,
    <0.6944445, -167.5184453>,
    <0.7083412, -167.5184453>,
    <0.7103423, -167.5925951>,
    <0.7005056, -167.5563642>,
    <0.7005257, -167.5184453>,
    <0.7103617, -167.5437683>,
    <0.7164372, -167.5545331>,
    <0.7129630, -167.5763713>,
    <0.7083412, -167.5184453>,
    <0.7222222, -167.5184453>,
    <0.7222222, -167.6048705>,
    <0.7103617, -167.5437683>,
    <0.7161491, -167.5184453>,
    <0.7222222, -167.5563664>,
    <0.7181677, -167.5923911>,
    <0.7164291, -167.6196618>,
    <0.7129630, -167.5763713>,
    <0.7222222, -167.6048705>,
    <0.7222222, -167.6922232>,
    <0.7083091, -167.6051824>,
    <0.7181677, -167.5923911>,
    <0.7222222, -167.6541051>,
    <0.7161295, -167.6541068>,
    <0.7103423, -167.5925951>,
    <0.2835592, -167.6341061>,
    <0.2870370, -167.6737665>,
    <0.2916443, -167.6473117>,
    <0.2777778, -167.5684558>,
    <0.2777778, -167.6468904>,
    <0.2896304, -167.6588757>,
    <0.2838402, -167.6029317>,
    <0.2777778, -167.6028580>,
    <0.2818288, -167.6586490>,
    <0.2835660, -167.6933751>,
    <0.2870370, -167.6737665>,
    <0.2777778, -167.6468904>,
    <0.2777778, -167.7264218>,
    <0.2916715, -167.7264218>,
    <0.2818288, -167.6586490>,
    <0.2777778, -167.6917086>,
    <0.2838575, -167.7264218>,
    <0.2896460, -167.7034090>,
    <0.2939771, -167.6934805>,
    <0.2870370, -167.6737665>,
    <0.2916715, -167.7264218>,
    <0.3055555, -167.7264218>,
    <0.2916443, -167.6473117>,
    <0.2896460, -167.7034090>,
    <0.2994809, -167.7264218>,
    <0.2994640, -167.6917804>,
    <0.2896304, -167.6588757>,
    <0.2893381, -167.7614105>,
    <0.2962963, -167.7825485>,
    <0.2916715, -167.7264218>,
    <0.2777778, -167.7264218>,
    <0.2916069, -167.8102497>,
    <0.2936911, -167.7509310>,
    <0.2838575, -167.7264218>,
    <0.2838181, -167.7630363>,
    <0.2936559, -167.7981456>,
    <0.2997536, -167.8235022>,
    <0.2962963, -167.7825485>,
    <0.2916069, -167.8102497>,
    <0.3055555, -167.8948019>,
    <0.3055555, -167.8064088>,
    <0.2936559, -167.7981456>,
    <0.2995002, -167.8580961>,
    <0.3055555, -167.8565493>,
    <0.3015016, -167.7959622>,
    <0.2997697, -167.7604502>,
    <0.2962963, -167.7825485>,
    <0.3055555, -167.8064088>,
    <0.3055555, -167.7264218>,
    <0.2916715, -167.7264218>,
    <0.3015016, -167.7959622>,
    <0.3055555, -167.7609961>,
    <0.2994809, -167.7264218>,
    <0.2936911, -167.7509310>,
    <0.7002135, -167.7953930>,
    <0.7037037, -167.8386752>,
    <0.7082612, -167.8101747>,
    <0.6944445, -167.7264218>,
    <0.6944445, -167.8063003>,
    <0.7062676, -167.8226418>,
    <0.7004779, -167.7629945>,
    <0.6944445, -167.7609405>,
    <0.6984898, -167.8204449>,
    <0.7002365, -167.8586448>,
    <0.7037037, -167.8386752>,
    <0.6944445, -167.8063003>,
    <0.6944445, -167.8948019>,
    <0.7083532, -167.8948019>,
    <0.6984898, -167.8204449>,
    <0.6944445, -167.8569242>,
    <0.7003227, -167.8948019>,
    <0.7063557, -167.8706888>,
    <0.7106351, -167.8596134>,
    <0.7037037, -167.8386752>,
    <0.7083532, -167.8948019>,
    <0.7222222, -167.8948019>,
    <0.7082612, -167.8101747>,
    <0.7063557, -167.8706888>,
    <0.7163037, -167.8948019>,
    <0.7161930, -167.8582548>,
    <0.7062676, -167.8226418>,
    <0.7060017, -167.7613917>,
    <0.7129630, -167.7825485>,
    <0.7083382, -167.7264218>,
    <0.6944445, -167.7264218>,
    <0.7082612, -167.8101747>,
    <0.7103574, -167.7509267>,
    <0.7005242, -167.7264218>,
    <0.7004779, -167.7629945>,
    <0.7103156, -167.7981037>,
    <0.7164172, -167.8234595>,
    <0.7129630, -167.7825485>,
    <0.7082612, -167.8101747>,
    <0.7222222, -167.8948019>,
    <0.7222222, -167.8063127>,
    <0.7103156, -167.7981037>,
    <0.7161930, -167.8582548>,
    <0.7222222, -167.8571284>,
    <0.7181682, -167.7959079>,
    <0.7164364, -167.7604262>,
    <0.7129630, -167.7825485>,
    <0.7222222, -167.8063127>,
    <0.7222222, -167.7264218>,
    <0.7083382, -167.7264218>,
    <0.7181682, -167.7959079>,
    <0.7222222, -167.7609467>,
    <0.7161476, -167.7264218>,
    <0.7103574, -167.7509267>,
    <0.2835571, -167.4848985>,
    <0.2870370, -167.5208549>,
    <0.2916360, -167.4968970>,
    <0.2777778, -167.4256532>,
    <0.2777778, -167.4961890>,
    <0.2896255, -167.5073705>,
    <0.2838349, -167.4567920>,
    <0.2777778, -167.4566011>,
    <0.2818282, -167.5069791>,
    <0.2835666, -167.5384889>,
    <0.2870370, -167.5208549>,
    <0.2777778, -167.4961890>,
    <0.2777778, -167.5684558>,
    <0.2916737, -167.5684558>,
    <0.2818282, -167.5069791>,
    <0.2777778, -167.5369297>,
    <0.2838587, -167.5684558>,
    <0.2896472, -167.5476517>,
    <0.2939756, -167.5386659>,
    <0.2870370, -167.5208549>,
    <0.2916737, -167.5684558>,
    <0.3055555, -167.5684558>,
    <0.2916360, -167.4968970>,
    <0.2896472, -167.5476517>,
    <0.2994820, -167.5684558>,
    <0.2994585, -167.5371117>,
    <0.2896255, -167.5073705>,
    <0.2893480, -167.6013336>,
    <0.2962963, -167.6211112>,
    <0.2916737, -167.5684558>,
    <0.2777778, -167.5684558>,
    <0.2916443, -167.6473117>,
    <0.2936943, -167.5914725>,
    <0.2838587, -167.5684558>,
    <0.2838402, -167.6029317>,
    <0.2936768, -167.6358644>,
    <0.2997629, -167.6604338>,
    <0.2962963, -167.6211112>,
    <0.2916443, -167.6473117>,
    <0.3055555, -167.7264218>,
    <0.3055555, -167.6468904>,
    <0.2936768, -167.6358644>,
    <0.2994640, -167.6917804>,
    <0.3055555, -167.6917086>,
    <0.3015012, -167.6356026>,
    <0.2997703, -167.6012283>,
    <0.2962963, -167.6211112>,
    <0.3055555, -167.6468904>,
    <0.3055555, -167.5684558>,
    <0.2916737, -167.5684558>,
    <0.3015012, -167.6356026>,
    <0.3055555, -167.6028579>,
    <0.2994820, -167.5684558>,
    <0.2936943, -167.5914725>,
    <0.7002259, -167.6341061>,
    <0.7037037, -167.6737665>,
    <0.7083110, -167.6473117>,
    <0.6944445, -167.5684558>,
    <0.6944445, -167.6468904>,
    <0.7062970, -167.6588757>,
    <0.7005069, -167.6029317>,
    <0.6944445, -167.6028580>,
    <0.6984955, -167.6586490>,
    <0.7002327, -167.6933751>,
    <0.7037037, -167.6737665>,
    <0.6944445, -167.6468904>,
    <0.6944445, -167.7264218>,
    <0.7083382, -167.7264218>,
    <0.6984955, -167.6586490>,
    <0.6944445, -167.6917086>,
    <0.7005242, -167.7264218>,
    <0.7063127, -167.7034090>,
    <0.7106438, -167.6934805>,
    <0.7037037, -167.6737665>,
    <0.7083382, -167.7264218>,
    <0.7222222, -167.7264218>,
    <0.7083110, -167.6473117>,
    <0.7063127, -167.7034090>,
    <0.7161476, -167.7264218>,
    <0.7161307, -167.6917804>,
    <0.7062970, -167.6588757>,
    <0.7060147, -167.6013336>,
    <0.7129630, -167.6211112>,
    <0.7083404, -167.5684558>,
    <0.6944445, -167.5684558>,
    <0.7083110, -167.6473117>,
    <0.7103610, -167.5914725>,
    <0.7005253, -167.5684558>,
    <0.7005069, -167.6029317>,
    <0.7103435, -167.6358644>,
    <0.7164296, -167.6604338>,
    <0.7129630, -167.6211112>,
    <0.7083110, -167.6473117>,
    <0.7222222, -167.7264218>,
    <0.7222222, -167.6468904>,
    <0.7103435, -167.6358644>,
    <0.7161307, -167.6917804>,
    <0.7222222, -167.6917086>,
    <0.7181679, -167.6356026>,
    <0.7164370, -167.6012283>,
    <0.7129630, -167.6211112>,
    <0.7222222, -167.6468904>,
    <0.7222222, -167.5684558>,
    <0.7083404, -167.5684558>,
    <0.7181679, -167.6356026>,
    <0.7222222, -167.6028579>,
    <0.7161487, -167.5684558>,
    <0.7103610, -167.5914725>,
    <0.2835544, -167.2819570>,
    <0.2870370, -167.3161845>,
    <0.2777778, -167.2924560>,
    <0.2777778, -167.2258020>,
    <0.2916250, -167.2933857>,
    <0.2818274, -167.3028339>,
    <0.2777778, -167.2550533>,
    <0.2838277, -167.2553296>,
    <0.2896191, -167.3033535>,
    <0.2939736, -167.3330804>,
    <0.2870370, -167.3161845>,
    <0.2916250, -167.2933857>,
    <0.3055555, -167.3613758>,
    <0.2916766, -167.3613758>,
    <0.2896191, -167.3033535>,
    <0.2994513, -167.3315832>,
    <0.2994835, -167.3613758>,
    <0.2896489, -167.3416247>,
    <0.2835673, -167.3328480>,
    <0.2870370, -167.3161845>,
    <0.2916766, -167.3613758>,
    <0.2777778, -167.3613758>,
    <0.2777778, -167.2924560>,
    <0.2896489, -167.3416247>,
    <0.2838602, -167.3613758>,
    <0.2777778, -167.3313235>,
    <0.2818274, -167.3028339>,
    <0.2893460, -167.3940515>,
    <0.2962963, -167.4137323>,
    <0.2916333, -167.4397221>,
    <0.2777778, -167.3613758>,
    <0.2916766, -167.3613758>,
    <0.2936704, -167.4283682>,
    <0.2838331, -167.3956156>,
    <0.2838602, -167.3613758>,
    <0.2936960, -167.3842624>,
    <0.2997710, -167.3939086>,
    <0.2962963, -167.4137323>,
    <0.2916766, -167.3613758>,
    <0.3055555, -167.3613758>,
    <0.3055555, -167.4391507>,
    <0.2936960, -167.3842624>,
    <0.2994835, -167.3613758>,
    <0.3055555, -167.3955180>,
    <0.3015004, -167.4280187>,
    <0.2997602, -167.4527626>,
    <0.2962963, -167.4137323>,
    <0.3055555, -167.4391507>,
    <0.3055555, -167.5184453>,
    <0.2916333, -167.4397221>,
    <0.3015004, -167.4280187>,
    <0.3055555, -167.4838674>,
    <0.2994568, -167.4839601>,
    <0.2936704, -167.4283682>,
    <0.7002232, -167.4265843>,
    <0.7037037, -167.4660888>,
    <0.6944445, -167.4391507>,
    <0.6944445, -167.3613758>,
    <0.7083000, -167.4397221>,
    <0.6984947, -167.4509341>,
    <0.6944445, -167.3955180>,
    <0.7004998, -167.3956156>,
    <0.7062906, -167.4512490>,
    <0.7106418, -167.4856754>,
    <0.7037037, -167.4660888>,
    <0.7083000, -167.4397221>,
    <0.7222222, -167.5184453>,
    <0.7083412, -167.5184453>,
    <0.7062906, -167.4512490>,
    <0.7161235, -167.4839601>,
    <0.7161491, -167.5184453>,
    <0.7063145, -167.4955641>,
    <0.7002335, -167.4855325>,
    <0.7037037, -167.4660888>,
    <0.7083412, -167.5184453>,
    <0.6944445, -167.5184453>,
    <0.6944445, -167.4391507>,
    <0.7063145, -167.4955641>,
    <0.7005257, -167.5184453>,
    <0.6944445, -167.4838674>,
    <0.6984947, -167.4509341>,
    <0.7060127, -167.3940515>,
    <0.7129630, -167.4137323>,
    <0.7083000, -167.4397221>,
    <0.6944445, -167.3613758>,
    <0.7083433, -167.3613758>,
    <0.7103371, -167.4283682>,
    <0.7004998, -167.3956156>,
    <0.7005269, -167.3613758>,
    <0.7103627, -167.3842624>,
    <0.7164377, -167.3939086>,
    <0.7129630, -167.4137323>,
    <0.7083433, -167.3613758>,
    <0.7222222, -167.3613758>,
    <0.7222222, -167.4391507>,
    <0.7103627, -167.3842624>,
    <0.7161502, -167.3613758>,
    <0.7222222, -167.3955180>,
    <0.7181671, -167.4280187>,
    <0.7164269, -167.4527626>,
    <0.7129630, -167.4137323>,
    <0.7222222, -167.4391507>,
    <0.7222222, -167.5184453>,
    <0.7083000, -167.4397221>,
    <0.7181671, -167.4280187>,
    <0.7222222, -167.4838674>,
    <0.7161235, -167.4839601>,
    <0.7103371, -167.4283682>,
    <0.2835553, -167.3534027>,
    <0.2870370, -167.3845690>,
    <0.2916285, -167.3638575>,
    <0.2777778, -167.3024008>,
    <0.2777778, -167.3627833>,
    <0.2896211, -167.3729124>,
    <0.2838300, -167.3292549>,
    <0.2777778, -167.3288803>,
    <0.2818277, -167.3723121>,
    <0.2835671, -167.3996647>,
    <0.2870370, -167.3845690>,
    <0.2777778, -167.3627833>,
    <0.2777778, -167.4256532>,
    <0.2916757, -167.4256532>,
    <0.2818277, -167.3723121>,
    <0.2777778, -167.3982231>,
    <0.2838597, -167.4256532>,
    <0.2896482, -167.4076960>,
    <0.2939742, -167.3999332>,
    <0.2870370, -167.3845690>,
    <0.2916757, -167.4256532>,
    <0.3055555, -167.4256532>,
    <0.2916285, -167.3638575>,
    <0.2896482, -167.4076960>,
    <0.2994830, -167.4256532>,
    <0.2994535, -167.3985780>,
    <0.2896211, -167.3729124>,
    <0.2893464, -167.4553644>,
    <0.2962963, -167.4732541>,
    <0.2916757, -167.4256532>,
    <0.2777778, -167.4256532>,
    <0.2916360, -167.4968970>,
    <0.2936953, -167.4464590>,
    <0.2838597, -167.4256532>,
    <0.2838349, -167.4567920>,
    <0.2936720, -167.4865678>,
    <0.2997609, -167.5086990>,
    <0.2962963, -167.4732541>,
    <0.2916360, -167.4968970>,
    <0.3055555, -167.5684558>,
    <0.3055555, -167.4961890>,
    <0.2936720, -167.4865678>,
    <0.2994585, -167.5371117>,
    <0.3055555, -167.5369298>,
    <0.3015007, -167.4861453>,
    <0.2997708, -167.4551874>,
    <0.2962963, -167.4732541>,
    <0.3055555, -167.4961890>,
    <0.3055555, -167.4256532>,
    <0.2916757, -167.4256532>,
    <0.3015007, -167.4861453>,
    <0.3055555, -167.4566011>,
    <0.2994830, -167.4256532>,
    <0.2936953, -167.4464590>,
    <0.7002238, -167.4848985>,
    <0.7037037, -167.5208549>,
    <0.7083027, -167.4968970>,
    <0.6944445, -167.4256532>,
    <0.6944445, -167.4961890>,
    <0.7062922, -167.5073705>,
    <0.7005015, -167.4567920>,
    <0.6944445, -167.4566011>,
    <0.6984949, -167.5069791>,
    <0.7002333, -167.5384889>,
    <0.7037037, -167.5208549>,
    <0.6944445, -167.4961890>,
    <0.6944445, -167.5684558>,
    <0.7083404, -167.5684558>,
    <0.6984949, -167.5069791>,
    <0.6944445, -167.5369297>,
    <0.7005253, -167.5684558>,
    <0.7063139, -167.5476517>,
    <0.7106423, -167.5386659>,
    <0.7037037, -167.5208549>,
    <0.7083404, -167.5684558>,
    <0.7222222, -167.5684558>,
    <0.7083027, -167.4968970>,
    <0.7063139, -167.5476517>,
    <0.7161487, -167.5684558>,
    <0.7161252, -167.5371117>,
    <0.7062922, -167.5073705>,
    <0.7060131, -167.4553644>,
    <0.7129630, -167.4732541>,
    <0.7083423, -167.4256532>,
    <0.6944445, -167.4256532>,
    <0.7083027, -167.4968970>,
    <0.7103620, -167.4464590>,
    <0.7005264, -167.4256532>,
    <0.7005015, -167.4567920>,
    <0.7103387, -167.4865678>,
    <0.7164275, -167.5086990>,
    <0.7129630, -167.4732541>,
    <0.7083027, -167.4968970>,
    <0.7222222, -167.5684558>,
    <0.7222222, -167.4961890>,
    <0.7103387, -167.4865678>,
    <0.7161252, -167.5371117>,
    <0.7222222, -167.5369298>,
    <0.7181674, -167.4861453>,
    <0.7164374, -167.4551874>,
    <0.7129630, -167.4732541>,
    <0.7222222, -167.4961890>,
    <0.7222222, -167.4256532>,
    <0.7083423, -167.4256532>,
    <0.7181674, -167.4861453>,
    <0.7222222, -167.4566011>,
    <0.7161497, -167.4256532>,
    <0.7103620, -167.4464590>,
    <0.2834779, -167.1603184>,
    <0.2870370, -167.1891429>,
    <0.2777778, -167.1668695>,
    <0.2777778, -167.1158246>,
    <0.2913189, -167.1694365>,
    <0.2818307, -167.1766189>,
    <0.2777778, -167.1355974>,
    <0.2834916, -167.1384467>,
    <0.2894499, -167.1780382>,
    <0.2938975, -167.2025458>,
    <0.2870370, -167.1891429>,
    <0.2913189, -167.1694365>,
    <0.3055555, -167.2258020>,
    <0.2916784, -167.2258020>,
    <0.2894499, -167.1780382>,
    <0.2992826, -167.2009662>,
    <0.2994844, -167.2258020>,
    <0.2896404, -167.2097051>,
    <0.2835677, -167.2019041>,
    <0.2870370, -167.1891429>,
    <0.2916784, -167.2258020>,
    <0.2777778, -167.2258020>,
    <0.2777778, -167.1668695>,
    <0.2896404, -167.2097051>,
    <0.2838611, -167.2258020>,
    <0.2777778, -167.1999394>,
    <0.2818307, -167.1766189>,
    <0.2893444, -167.2539957>,
    <0.2962963, -167.2709932>,
    <0.2916250, -167.2933857>,
    <0.2777778, -167.2258020>,
    <0.2916784, -167.2258020>,
    <0.2936656, -167.2836036>,
    <0.2838277, -167.2553296>,
    <0.2838611, -167.2258020>,
    <0.2936967, -167.2455535>,
    <0.2997714, -167.2537633>,
    <0.2962963, -167.2709932>,
    <0.2916784, -167.2258020>,
    <0.3055555, -167.2258020>,
    <0.3055555, -167.2924560>,
    <0.2936967, -167.2455535>,
    <0.2994844, -167.2258020>,
    <0.3055555, -167.2550533>,
    <0.3014999, -167.2830552>,
    <0.2997581, -167.3045527>,
    <0.2962963, -167.2709932>,
    <0.3055555, -167.2924560>,
    <0.3055555, -167.3613758>,
    <0.2916250, -167.2933857>,
    <0.3014999, -167.2830552>,
    <0.3055555, -167.3313235>,
    <0.2994513, -167.3315832>,
    <0.2936656, -167.2836036>,
    <0.7002211, -167.2819570>,
    <0.7037037, -167.3161845>,
    <0.6944445, -167.2924560>,
    <0.6944445, -167.2258020>,
    <0.7082917, -167.2933857>,
    <0.6984941, -167.3028339>,
    <0.6944445, -167.2550533>,
    <0.7004944, -167.2553296>,
    <0.7062858, -167.3033535>,
    <0.7106402, -167.3330804>,
    <0.7037037, -167.3161845>,
    <0.7082917, -167.2933857>,
    <0.7222222, -167.3613758>,
    <0.7083433, -167.3613758>,
    <0.7062858, -167.3033535>,
    <0.7161180, -167.3315832>,
    <0.7161502, -167.3613758>,
    <0.7063156, -167.3416247>,
    <0.7002340, -167.3328480>,
    <0.7037037, -167.3161845>,
    <0.7083433, -167.3613758>,
    <0.6944445, -167.3613758>,
    <0.6944445, -167.2924560>,
    <0.7063156, -167.3416247>,
    <0.7005269, -167.3613758>,
    <0.6944445, -167.3313235>,
    <0.6984941, -167.3028339>,
    <0.7060111, -167.2539957>,
    <0.7129630, -167.2709932>,
    <0.7082917, -167.2933857>,
    <0.6944445, -167.2258020>,
    <0.7083451, -167.2258020>,
    <0.7103323, -167.2836036>,
    <0.7004944, -167.2553296>,
    <0.7005278, -167.2258020>,
    <0.7103634, -167.2455535>,
    <0.7164381, -167.2537633>,
    <0.7129630, -167.2709932>,
    <0.7083451, -167.2258020>,
    <0.7222222, -167.2258020>,
    <0.7222222, -167.2924560>,
    <0.7103634, -167.2455535>,
    <0.7161511, -167.2258020>,
    <0.7222222, -167.2550533>,
    <0.7181666, -167.2830552>,
    <0.7164248, -167.3045527>,
    <0.7129630, -167.2709932>,
    <0.7222222, -167.2924560>,
    <0.7222222, -167.3613758>,
    <0.7082917, -167.2933857>,
    <0.7181666, -167.2830552>,
    <0.7222222, -167.3313235>,
    <0.7161180, -167.3315832>,
    <0.7103323, -167.2836036>,
    <0.2835536, -167.2436308>,
    <0.2870370, -167.2690732>,
    <0.2916219, -167.2522483>,
    <0.2777778, -167.2024179>,
    <0.2777778, -167.2507837>,
    <0.2896174, -167.2596042>,
    <0.2838257, -167.2241867>,
    <0.2777778, -167.2235884>,
    <0.2818272, -167.2587824>,
    <0.2835675, -167.2811646>,
    <0.2870370, -167.2690732>,
    <0.2777778, -167.2507837>,
    <0.2777778, -167.3024008>,
    <0.2916773, -167.3024008>,
    <0.2818272, -167.2587824>,
    <0.2777778, -167.2798504>,
    <0.2838605, -167.3024008>,
    <0.2896488, -167.2878319>,
    <0.2939729, -167.2815307>,
    <0.2870370, -167.2690732>,
    <0.2916773, -167.3024008>,
    <0.3055555, -167.3024008>,
    <0.2916219, -167.2522483>,
    <0.2896488, -167.2878319>,
    <0.2994838, -167.3024008>,
    <0.2994491, -167.2804214>,
    <0.2896174, -167.2596042>,
    <0.2893449, -167.3280360>,
    <0.2962963, -167.3434849>,
    <0.2916773, -167.3024008>,
    <0.2777778, -167.3024008>,
    <0.2916285, -167.3638575>,
    <0.2936959, -167.3203558>,
    <0.2838605, -167.3024008>,
    <0.2838300, -167.3292549>,
    <0.2936677, -167.3549573>,
    <0.2997590, -167.3739447>,
    <0.2962963, -167.3434849>,
    <0.2916285, -167.3638575>,
    <0.3055555, -167.4256532>,
    <0.3055555, -167.3627833>,
    <0.2936677, -167.3549573>,
    <0.2994535, -167.3985780>,
    <0.3055555, -167.3982231>,
    <0.3015002, -167.3543311>,
    <0.2997712, -167.3277674>,
    <0.2962963, -167.3434849>,
    <0.3055555, -167.3627833>,
    <0.3055555, -167.3024008>,
    <0.2916773, -167.3024008>,
    <0.3015002, -167.3543311>,
    <0.3055555, -167.3288803>,
    <0.2994838, -167.3024008>,
    <0.2936959, -167.3203558>,
    <0.7002219, -167.3534027>,
    <0.7037037, -167.3845690>,
    <0.7082952, -167.3638575>,
    <0.6944445, -167.3024008>,
    <0.6944445, -167.3627833>,
    <0.7062878, -167.3729124>,
    <0.7004966, -167.3292549>,
    <0.6944445, -167.3288803>,
    <0.6984943, -167.3723121>,
    <0.7002337, -167.3996647>,
    <0.7037037, -167.3845690>,
    <0.6944445, -167.3627833>,
    <0.6944445, -167.4256532>,
    <0.7083423, -167.4256532>,
    <0.6984943, -167.3723121>,
    <0.6944445, -167.3982231>,
    <0.7005264, -167.4256532>,
    <0.7063149, -167.4076960>,
    <0.7106409, -167.3999332>,
    <0.7037037, -167.3845690>,
    <0.7083423, -167.4256532>,
    <0.7222222, -167.4256532>,
    <0.7082952, -167.3638575>,
    <0.7063149, -167.4076960>,
    <0.7161497, -167.4256532>,
    <0.7161202, -167.3985780>,
    <0.7062878, -167.3729124>,
    <0.7060116, -167.3280360>,
    <0.7129630, -167.3434849>,
    <0.7083439, -167.3024008>,
    <0.6944445, -167.3024008>,
    <0.7082952, -167.3638575>,
    <0.7103626, -167.3203558>,
    <0.7005272, -167.3024008>,
    <0.7004966, -167.3292549>,
    <0.7103344, -167.3549573>,
    <0.7164256, -167.3739447>,
    <0.7129630, -167.3434849>,
    <0.7082952, -167.3638575>,
    <0.7222222, -167.4256532>,
    <0.7222222, -167.3627833>,
    <0.7103344, -167.3549573>,
    <0.7161202, -167.3985780>,
    <0.7222222, -167.3982231>,
    <0.7181669, -167.3543311>,
    <0.7164378, -167.3277674>,
    <0.7129630, -167.3434849>,
    <0.7222222, -167.3627833>,
    <0.7222222, -167.3024008>,
    <0.7083439, -167.3024008>,
    <0.7181669, -167.3543311>,
    <0.7222222, -167.3288803>,
    <0.7161505, -167.3024008>,
    <0.7103626, -167.3203558>,
    <0.2872854, -167.0806062>,
    <0.2908423, -167.0842391>,
    <0.2970358, -167.1012933>,
    <0.2777778, -167.0684463>,
    <0.2834857, -167.0684463>,
    <0.2948946, -167.0953973>,
    <0.2894731, -167.0883941>,
    <0.2806318, -167.0684463>,
    <0.2864427, -167.0747941>,
    <0.2904780, -167.0790521>,
    <0.2908423, -167.0842391>,
    <0.2834857, -167.0684463>,
    <0.2891937, -167.0684463>,
    <0.2983904, -167.0950767>,
    <0.2864427, -167.0747941>,
    <0.2863397, -167.0684463>,
    <0.2935758, -167.0811352>,
    <0.2946378, -167.0896887>,
    <0.2979560, -167.0991084>,
    <0.2908423, -167.0842391>,
    <0.2983904, -167.0950767>,
    <0.3055555, -167.1158246>,
    <0.2970358, -167.1012933>,
    <0.2946378, -167.0896887>,
    <0.3027107, -167.1075869>,
    <0.3021390, -167.1099973>,
    <0.2948946, -167.0953973>,
    <0.2849071, -167.0914181>,
    <0.2870370, -167.1000319>,
    <0.2777778, -167.0959009>,
    <0.2777778, -167.0684463>,
    <0.2970358, -167.1012933>,
    <0.2817554, -167.0976755>,
    <0.2777778, -167.0830521>,
    <0.2894731, -167.0883941>,
    <0.2919507, -167.1006517>,
    <0.2951748, -167.1082436>,
    <0.2870370, -167.1000319>,
    <0.2970358, -167.1012933>,
    <0.3055555, -167.1158246>,
    <0.2910710, -167.1158246>,
    <0.2919507, -167.1006517>,
    <0.3021390, -167.1099973>,
    <0.2992906, -167.1158246>,
    <0.2891848, -167.1084404>,
    <0.2834159, -167.1068955>,
    <0.2870370, -167.1000319>,
    <0.2910710, -167.1158246>,
    <0.2777778, -167.1158246>,
    <0.2777778, -167.0959009>,
    <0.2891848, -167.1084404>,
    <0.2832581, -167.1158246>,
    <0.2777778, -167.1102151>,
    <0.2817554, -167.0976755>,
    <0.2891160, -167.1383924>,
    <0.2962963, -167.1524837>,
    <0.2913189, -167.1694365>,
    <0.2777778, -167.1158246>,
    <0.2910710, -167.1158246>,
    <0.2934872, -167.1620513>,
    <0.2834916, -167.1384467>,
    <0.2832581, -167.1158246>,
    <0.2933341, -167.1317020>,
    <0.2996196, -167.1377420>,
    <0.2962963, -167.1524837>,
    <0.2910710, -167.1158246>,
    <0.3055555, -167.1158246>,
    <0.3055555, -167.1668348>,
    <0.2933341, -167.1317020>,
    <0.2992906, -167.1158246>,
    <0.3055555, -167.1355698>,
    <0.3014939, -167.1605396>,
    <0.2996816, -167.1786393>,
    <0.2962963, -167.1524837>,
    <0.3055555, -167.1668348>,
    <0.3055555, -167.2258020>,
    <0.2913189, -167.1694365>,
    <0.3014939, -167.1605396>,
    <0.3055555, -167.1999202>,
    <0.2992826, -167.2009662>,
    <0.2934872, -167.1620513>,
    <0.7001489, -167.1604678>,
    <0.7037037, -167.1891429>,
    <0.6944445, -167.1673989>,
    <0.6944445, -167.1158246>,
    <0.7080028, -167.1695048>,
    <0.6984971, -167.1769160>,
    <0.6944445, -167.1360737>,
    <0.7001739, -167.1385084>,
    <0.7061262, -167.1780773>,
    <0.7105685, -167.2025629>,
    <0.7037037, -167.1891429>,
    <0.7080028, -167.1695048>,
    <0.7222222, -167.2258020>,
    <0.7083451, -167.2258020>,
    <0.7061262, -167.1780773>,
    <0.7159589, -167.2010043>,
    <0.7161511, -167.2258020>,
    <0.7063077, -167.2097098>,
    <0.7002344, -167.2020364>,
    <0.7037037, -167.1891429>,
    <0.7083451, -167.2258020>,
    <0.6944445, -167.2258020>,
    <0.6944445, -167.1673989>,
    <0.7063077, -167.2097098>,
    <0.7005278, -167.2258020>,
    <0.6944445, -167.2002202>,
    <0.6984971, -167.1769160>,
    <0.7057946, -167.1384095>,
    <0.7129630, -167.1524837>,
    <0.7080028, -167.1695048>,
    <0.6944445, -167.1158246>,
    <0.7077681, -167.1158246>,
    <0.7101638, -167.1620894>,
    <0.7001739, -167.1385084>,
    <0.6999407, -167.1158246>,
    <0.7100190, -167.1317090>,
    <0.7162939, -167.1378917>,
    <0.7129630, -167.1524837>,
    <0.7077681, -167.1158246>,
    <0.7222222, -167.1158246>,
    <0.7222222, -167.1674336>,
    <0.7100190, -167.1317090>,
    <0.7159769, -167.1158246>,
    <0.7222222, -167.1361016>,
    <0.7181610, -167.1608763>,
    <0.7163526, -167.1788060>,
    <0.7129630, -167.1524837>,
    <0.7222222, -167.1674336>,
    <0.7222222, -167.2258020>,
    <0.7080028, -167.1695048>,
    <0.7181610, -167.1608763>,
    <0.7222222, -167.2002392>,
    <0.7159589, -167.2010043>,
    <0.7101638, -167.1620894>,
    <0.2836246, -167.1583892>,
    <0.2870370, -167.1778641>,
    <0.2919056, -167.1662209>,
    <0.2777778, -167.1287564>,
    <0.2777778, -167.1607153>,
    <0.2897843, -167.1712941>,
    <0.2840349, -167.1453493>,
    <0.2777778, -167.1413913>,
    <0.2818345, -167.1682287>,
    <0.2835678, -167.1858538>,
    <0.2870370, -167.1778641>,
    <0.2777778, -167.1607153>,
    <0.2777778, -167.2024179>,
    <0.2916785, -167.2024179>,
    <0.2818345, -167.1682287>,
    <0.2777778, -167.1838308>,
    <0.2838612, -167.2024179>,
    <0.2896574, -167.1917260>,
    <0.2940442, -167.1872302>,
    <0.2870370, -167.1778641>,
    <0.2916785, -167.2024179>,
    <0.3055555, -167.2024179>,
    <0.2919056, -167.1662209>,
    <0.2896574, -167.1917260>,
    <0.2994844, -167.2024179>,
    <0.2996152, -167.1866652>,
    <0.2897843, -167.1712941>,
    <0.2893436, -167.2232074>,
    <0.2962963, -167.2357456>,
    <0.2916785, -167.2024179>,
    <0.2777778, -167.2024179>,
    <0.2916219, -167.2522483>,
    <0.2936962, -167.2169804>,
    <0.2838612, -167.2024179>,
    <0.2838257, -167.2241867>,
    <0.2936640, -167.2450388>,
    <0.2997573, -167.2602946>,
    <0.2962963, -167.2357456>,
    <0.2916219, -167.2522483>,
    <0.3055555, -167.3024008>,
    <0.3055555, -167.2507837>,
    <0.2936640, -167.2450388>,
    <0.2994491, -167.2804214>,
    <0.3055555, -167.2798504>,
    <0.3014999, -167.2441968>,
    <0.2997715, -167.2228413>,
    <0.2962963, -167.2357456>,
    <0.3055555, -167.2507837>,
    <0.3055555, -167.2024179>,
    <0.2916785, -167.2024179>,
    <0.3014999, -167.2441968>,
    <0.3055555, -167.2235884>,
    <0.2994844, -167.2024179>,
    <0.2936962, -167.2169804>,
    <0.7002203, -167.2436308>,
    <0.7037037, -167.2690732>,
    <0.7082886, -167.2522483>,
    <0.6944445, -167.2024179>,
    <0.6944445, -167.2507837>,
    <0.7062840, -167.2596042>,
    <0.7004924, -167.2241867>,
    <0.6944445, -167.2235884>,
    <0.6984939, -167.2587824>,
    <0.7002341, -167.2811646>,
    <0.7037037, -167.2690732>,
    <0.6944445, -167.2507837>,
    <0.6944445, -167.3024008>,
    <0.7083439, -167.3024008>,
    <0.6984939, -167.2587824>,
    <0.6944445, -167.2798504>,
    <0.7005272, -167.3024008>,
    <0.7063155, -167.2878319>,
    <0.7106396, -167.2815307>,
    <0.7037037, -167.2690732>,
    <0.7083439, -167.3024008>,
    <0.7222222, -167.3024008>,
    <0.7082886, -167.2522483>,
    <0.7063155, -167.2878319>,
    <0.7161505, -167.3024008>,
    <0.7161158, -167.2804214>,
    <0.7062840, -167.2596042>,
    <0.7060103, -167.2232074>,
    <0.7129630, -167.2357456>,
    <0.7083452, -167.2024179>,
    <0.6944445, -167.2024179>,
    <0.7082886, -167.2522483>,
    <0.7103629, -167.2169804>,
    <0.7005279, -167.2024179>,
    <0.7004924, -167.2241867>,
    <0.7103307, -167.2450388>,
    <0.7164240, -167.2602946>,
    <0.7129630, -167.2357456>,
    <0.7082886, -167.2522483>,
    <0.7222222, -167.3024008>,
    <0.7222222, -167.2507837>,
    <0.7103307, -167.2450388>,
    <0.7161158, -167.2804214>,
    <0.7222222, -167.2798504>,
    <0.7181665, -167.2441968>,
    <0.7164381, -167.2228413>,
    <0.7129630, -167.2357456>,
    <0.7222222, -167.2507837>,
    <0.7222222, -167.2024179>,
    <0.7083452, -167.2024179>,
    <0.7181665, -167.2441968>,
    <0.7222222, -167.2235884>,
    <0.7161511, -167.2024179>,
    <0.7103629, -167.2169804>,
    <0.2962651, -167.0790521>,
    <0.3001016, -167.0842391>,
    <0.2983904, -167.0950767>,
    <0.2891937, -167.0684463>,
    <0.2973746, -167.0684463>,
    <0.2990764, -167.0907318>,
    <0.2935758, -167.0811352>,
    <0.2932842, -167.0684463>,
    <0.2985578, -167.0752985>,
    <0.3021468, -167.0792324>,
    <0.3001016, -167.0842391>,
    <0.2973746, -167.0684463>,
    <0.3055555, -167.0684463>,
    <0.3055555, -167.0957980>,
    <0.2985578, -167.0752985>,
    <0.3014651, -167.0684463>,
    <0.3055555, -167.0829250>,
    <0.3032363, -167.0908826>,
    <0.3024008, -167.0977346>,
    <0.3001016, -167.0842391>,
    <0.3055555, -167.0957980>,
    <0.3055555, -167.1158246>,
    <0.2983904, -167.0950767>,
    <0.3032363, -167.0908826>,
    <0.3055555, -167.1101184>,
    <0.3027107, -167.1075869>,
    <0.2990764, -167.0907318>,
    <0.7015480, -167.0910330>,
    <0.7037037, -167.1000319>,
    <0.6944445, -167.0945365>,
    <0.6944445, -167.0684463>,
    <0.7135993, -167.1011172>,
    <0.6984448, -167.0969108>,
    <0.6944445, -167.0815501>,
    <0.7059988, -167.0881537>,
    <0.7085787, -167.1005665>,
    <0.7118233, -167.1081996>,
    <0.7037037, -167.1000319>,
    <0.7135993, -167.1011172>,
    <0.7222222, -167.1158246>,
    <0.7077681, -167.1158246>,
    <0.7085787, -167.1005665>,
    <0.7187585, -167.1099168>,
    <0.7159769, -167.1158246>,
    <0.7058741, -167.1084654>,
    <0.7000902, -167.1065544>,
    <0.7037037, -167.1000319>,
    <0.7077681, -167.1158246>,
    <0.6944445, -167.1158246>,
    <0.6944445, -167.0945365>,
    <0.7058741, -167.1084654>,
    <0.6999407, -167.1158246>,
    <0.6944445, -167.1098579>,
    <0.6984448, -167.0969108>,
    <0.7039981, -167.0805622>,
    <0.7075090, -167.0842391>,
    <0.7135993, -167.1011172>,
    <0.6944445, -167.0684463>,
    <0.7004396, -167.0684463>,
    <0.7114499, -167.0951604>,
    <0.7059988, -167.0881537>,
    <0.6974811, -167.0684463>,
    <0.7032783, -167.0747878>,
    <0.7073548, -167.0794526>,
    <0.7075090, -167.0842391>,
    <0.7004396, -167.0684463>,
    <0.7058604, -167.0684463>,
    <0.7156103, -167.0966788>,
    <0.7032783, -167.0747878>,
    <0.7032466, -167.0684463>,
    <0.7108552, -167.0829096>,
    <0.7115731, -167.0904796>,
    <0.7147352, -167.0994649>,
    <0.7075090, -167.0842391>,
    <0.7156103, -167.0966788>,
    <0.7222222, -167.1158246>,
    <0.7135993, -167.1011172>,
    <0.7115731, -167.0904796>,
    <0.7196529, -167.1083847>,
    <0.7187585, -167.1099168>,
    <0.7114499, -167.0951604>,
    <0.3002694, -167.1106496>,
    <0.2992196, -167.1123151>,
    <0.3045534, -167.1220942>,
    <0.3018457, -167.1040945>,
    <0.2954588, -167.1040945>,
    <0.3017787, -167.1170071>,
    <0.3033054, -167.1137978>,
    <0.2983923, -167.1040945>,
    <0.2968468, -167.1071285>,
    <0.2966980, -167.1108241>,
    <0.2992196, -167.1123151>,
    <0.2954588, -167.1040945>,
    <0.2902576, -167.1040945>,
    <0.3018559, -167.1227922>,
    <0.2968468, -167.1071285>,
    <0.2927839, -167.1040945>,
    <0.2975412, -167.1158365>,
    <0.3008861, -167.1189380>,
    <0.3027961, -167.1214895>,
    <0.2992196, -167.1123151>,
    <0.3018559, -167.1227922>,
    <0.3055555, -167.1287564>,
    <0.3045534, -167.1220942>,
    <0.3008861, -167.1189380>,
    <0.3042061, -167.1265810>,
    <0.3052708, -167.1268637>,
    <0.3017787, -167.1170071>,
    <0.2909868, -167.1176325>,
    <0.2911970, -167.1205358>,
    <0.3018559, -167.1227922>,
    <0.2902576, -167.1040945>,
    <0.2806364, -167.1231073>,
    <0.2971752, -167.1218013>,
    <0.2975412, -167.1158365>,
    <0.2841298, -167.1162039>,
    <0.2855078, -167.1219211>,
    <0.2850771, -167.1252890>,
    <0.2911970, -167.1205358>,
    <0.2806364, -167.1231073>,
    <0.2777778, -167.1287564>,
    <0.2906971, -167.1287564>,
    <0.2855078, -167.1219211>,
    <0.2788158, -167.1267051>,
    <0.2830482, -167.1287564>,
    <0.2908749, -167.1258321>,
    <0.2973264, -167.1252102>,
    <0.2911970, -167.1205358>,
    <0.2906971, -167.1287564>,
    <0.3055555, -167.1287564>,
    <0.3018559, -167.1227922>,
    <0.2908749, -167.1258321>,
    <0.2990898, -167.1287564>,
    <0.3042061, -167.1265810>,
    <0.2971752, -167.1218013>,
    <0.2891692, -167.1442610>,
    <0.2962963, -167.1533103>,
    <0.2906971, -167.1287564>,
    <0.2777778, -167.1287564>,
    <0.2919056, -167.1662209>,
    <0.2934561, -167.1408553>,
    <0.2830482, -167.1287564>,
    <0.2840349, -167.1453493>,
    <0.2938841, -167.1604034>,
    <0.2998283, -167.1706661>,
    <0.2962963, -167.1533103>,
    <0.2919056, -167.1662209>,
    <0.3055555, -167.2024179>,
    <0.3055555, -167.1607154>,
    <0.2938841, -167.1604034>,
    <0.2996152, -167.1866652>,
    <0.3055555, -167.1838308>,
    <0.3015676, -167.1575260>,
    <0.2995261, -167.1428846>,
    <0.2962963, -167.1533103>,
    <0.3055555, -167.1607154>,
    <0.3055555, -167.1287564>,
    <0.2906971, -167.1287564>,
    <0.3015676, -167.1575260>,
    <0.3055555, -167.1413914>,
    <0.2990898, -167.1287564>,
    <0.2934561, -167.1408553>,
    <0.7017493, -167.1107625>,
    <0.6995566, -167.1123279>,
    <0.6976153, -167.1224952>,
    <0.7069243, -167.1041136>,
    <0.7029010, -167.1041136>,
    <0.6983083, -167.1188660>,
    <0.7013010, -167.1152174>,
    <0.7050486, -167.1041136>,
    <0.7017511, -167.1069379>,
    <0.6988052, -167.1101333>,
    <0.6995566, -167.1123279>,
    <0.7029010, -167.1041136>,
    <0.6973011, -167.1041136>,
    <0.6954621, -167.1199782>,
    <0.7017511, -167.1069379>,
    <0.7003884, -167.1041136>,
    <0.6963743, -167.1121090>,
    <0.6976168, -167.1159522>,
    <0.6967696, -167.1208894>,
    <0.6995566, -167.1123279>,
    <0.6954621, -167.1199782>,
    <0.6944445, -167.1287564>,
    <0.6976153, -167.1224952>,
    <0.6976168, -167.1159522>,
    <0.6947879, -167.1257933>,
    <0.6956011, -167.1264725>,
    <0.6983083, -167.1188660>,
    <0.7003146, -167.1582978>,
    <0.7037037, -167.1778641>,
    <0.7086656, -167.1664683>,
    <0.6944445, -167.1287564>,
    <0.6944445, -167.1601024>,
    <0.7065025, -167.1714363>,
    <0.7008023, -167.1456162>,
    <0.6944445, -167.1407349>,
    <0.6985001, -167.1678823>,
    <0.7002344, -167.1857006>,
    <0.7037037, -167.1778641>,
    <0.6944445, -167.1601024>,
    <0.6944445, -167.2024179>,
    <0.7083452, -167.2024179>,
    <0.6985001, -167.1678823>,
    <0.6944445, -167.1835238>,
    <0.7005279, -167.2024179>,
    <0.7063267, -167.1917403>,
    <0.7107342, -167.1872921>,
    <0.7037037, -167.1778641>,
    <0.7083452, -167.2024179>,
    <0.7222222, -167.2024179>,
    <0.7086656, -167.1664683>,
    <0.7063267, -167.1917403>,
    <0.7161511, -167.2024179>,
    <0.7163317, -167.1867974>,
    <0.7065025, -167.1714363>,
    <0.7077814, -167.1175674>,
    <0.7078637, -167.1205421>,
    <0.7187224, -167.1231187>,
    <0.7069243, -167.1041136>,
    <0.6976153, -167.1224952>,
    <0.7141454, -167.1220327>,
    <0.7145967, -167.1164727>,
    <0.7013010, -167.1152174>,
    <0.7025001, -167.1215643>,
    <0.7018670, -167.1251375>,
    <0.7078637, -167.1205421>,
    <0.6976153, -167.1224952>,
    <0.6944445, -167.1287564>,
    <0.7075446, -167.1287564>,
    <0.7025001, -167.1215643>,
    <0.6956011, -167.1264725>,
    <0.6998264, -167.1287564>,
    <0.7076503, -167.1260345>,
    <0.7140882, -167.1252934>,
    <0.7078637, -167.1205421>,
    <0.7075446, -167.1287564>,
    <0.7222222, -167.1287564>,
    <0.7187224, -167.1231187>,
    <0.7076503, -167.1260345>,
    <0.7158797, -167.1287564>,
    <0.7209466, -167.1267016>,
    <0.7141454, -167.1220327>,
    <0.7059044, -167.1443229>,
    <0.7129630, -167.1533103>,
    <0.7075446, -167.1287564>,
    <0.6944445, -167.1287564>,
    <0.7086656, -167.1664683>,
    <0.7102230, -167.1408941>,
    <0.6998264, -167.1287564>,
    <0.7008023, -167.1456162>,
    <0.7106036, -167.1605343>,
    <0.7165183, -167.1705747>,
    <0.7129630, -167.1533103>,
    <0.7086656, -167.1664683>,
    <0.7222222, -167.2024179>,
    <0.7222222, -167.1601023>,
    <0.7106036, -167.1605343>,
    <0.7163317, -167.1867974>,
    <0.7222222, -167.1835237>,
    <0.7182360, -167.1571782>,
    <0.7162380, -167.1427314>,
    <0.7129630, -167.1533103>,
    <0.7222222, -167.1601023>,
    <0.7222222, -167.1287564>,
    <0.7075446, -167.1287564>,
    <0.7182360, -167.1571782>,
    <0.7222222, -167.1407348>,
    <0.7158797, -167.1287564>,
    <0.7102230, -167.1408941>,
    <0.3035079, -167.1106496>,
    <0.3043189, -167.1123151>,
    <0.3033135, -167.1040945>,
    <0.3018457, -167.1040945>,
    <0.3045534, -167.1220942>,
    <0.3037438, -167.1076129>,
    <0.3024885, -167.1040945>,
    <0.3033054, -167.1137978>,
    <0.3044701, -167.1186210>,
    <0.3049959, -167.1197228>,
    <0.3043189, -167.1123151>,
    <0.3045534, -167.1220942>,
    <0.3055555, -167.1287564>,
    <0.3055555, -167.1157254>,
    <0.3044701, -167.1186210>,
    <0.3052708, -167.1268637>,
    <0.3055555, -167.1243284>,
    <0.3050605, -167.1143603>,
    <0.3046859, -167.1090574>,
    <0.3043189, -167.1123151>,
    <0.3055555, -167.1157254>,
    <0.3055555, -167.1040945>,
    <0.3033135, -167.1040945>,
    <0.3050605, -167.1143603>,
    <0.3055555, -167.1077202>,
    <0.3043651, -167.1040945>,
    <0.3037438, -167.1076129>,
    <0.6960894, -167.1101299>,
    <0.6953967, -167.1123215>,
    <0.6954621, -167.1199782>,
    <0.6973011, -167.1041136>,
    <0.6961975, -167.1041062>,
    <0.6954374, -167.1170884>,
    <0.6963743, -167.1121090>,
    <0.6968226, -167.1041104>,
    <0.6958527, -167.1076438>,
    <0.6951208, -167.1098052>,
    <0.6953967, -167.1123215>,
    <0.6961975, -167.1041062>,
    <0.6944445, -167.1040945>,
    <0.6944445, -167.1186987>,
    <0.6958527, -167.1076438>,
    <0.6953811, -167.1041008>,
    <0.6944445, -167.1075975>,
    <0.6947936, -167.1163606>,
    <0.6949369, -167.1199387>,
    <0.6953967, -167.1123215>,
    <0.6944445, -167.1186987>,
    <0.6944445, -167.1287564>,
    <0.6954621, -167.1199782>,
    <0.6947936, -167.1163606>,
    <0.6944445, -167.1268392>,
    <0.6947879, -167.1257933>,
    <0.6954374, -167.1170884>,
    <0.3119758, -167.1109029>,
    <0.3097155, -167.1123151>,
    <0.3084142, -167.1231073>,
    <0.3180354, -167.1040945>,
    <0.3117380, -167.1040945>,
    <0.3089151, -167.1189533>,
    <0.3119076, -167.1162039>,
    <0.3148647, -167.1040945>,
    <0.3110649, -167.1068303>,
    <0.3081411, -167.1090574>,
    <0.3097155, -167.1123151>,
    <0.3117380, -167.1040945>,
    <0.3055555, -167.1040945>,
    <0.3055555, -167.1157254>,
    <0.3110649, -167.1068303>,
    <0.3086397, -167.1040945>,
    <0.3055555, -167.1077202>,
    <0.3076557, -167.1140037>,
    <0.3073102, -167.1199761>,
    <0.3097155, -167.1123151>,
    <0.3055555, -167.1157254>,
    <0.3055555, -167.1287564>,
    <0.3084142, -167.1231073>,
    <0.3076557, -167.1140037>,
    <0.3055555, -167.1243284>,
    <0.3065936, -167.1267051>,
    <0.3089151, -167.1189533>,
    <0.6853744, -167.0794530>,
    <0.6889915, -167.0842391>,
    <0.6878343, -167.0966801>,
    <0.6780857, -167.0684463>,
    <0.6865862, -167.0684463>,
    <0.6882946, -167.0917316>,
    <0.6830798, -167.0829104>,
    <0.6824672, -167.0684463>,
    <0.6876327, -167.0753174>,
    <0.6911167, -167.0789170>,
    <0.6889915, -167.0842391>,
    <0.6865862, -167.0684463>,
    <0.6944445, -167.0684463>,
    <0.6944445, -167.0945365>,
    <0.6876327, -167.0753174>,
    <0.6905529, -167.0684463>,
    <0.6944445, -167.0815501>,
    <0.6921417, -167.0901880>,
    <0.6914287, -167.0978201>,
    <0.6889915, -167.0842391>,
    <0.6944445, -167.0945365>,
    <0.6944445, -167.1158246>,
    <0.6878343, -167.0966801>,
    <0.6921417, -167.0901880>,
    <0.6944445, -167.1098579>,
    <0.6918760, -167.1083857>,
    <0.6882946, -167.0917316>,
    <0.6866510, -167.1109046>,
    <0.6893451, -167.1123151>,
    <0.6871677, -167.1040945>,
    <0.6791465, -167.1040945>,
    <0.6909447, -167.1231144>,
    <0.6879481, -167.1070407>,
    <0.6833130, -167.1040945>,
    <0.6868189, -167.1164632>,
    <0.6903078, -167.1188145>,
    <0.6922947, -167.1207212>,
    <0.6893451, -167.1123151>,
    <0.6909447, -167.1231144>,
    <0.6944445, -167.1287564>,
    <0.6944445, -167.1186987>,
    <0.6903078, -167.1188145>,
    <0.6931689, -167.1267000>,
    <0.6944445, -167.1268392>,
    <0.6918528, -167.1154544>,
    <0.6913504, -167.1098007>,
    <0.6893451, -167.1123151>,
    <0.6944445, -167.1186987>,
    <0.6944445, -167.1040945>,
    <0.6871677, -167.1040945>,
    <0.6918528, -167.1154544>,
    <0.6944445, -167.1075975>,
    <0.6908488, -167.1040945>,
    <0.6879481, -167.1070407>,
    <0.3104612, -167.9429221>,
    <0.3148148, -168.0047729>,
    <0.3055555, -167.9407972>,
    <0.3055555, -167.8774261>,
    <0.3159189, -167.9486921>,
    <0.3097517, -167.9697899>,
    <0.3055555, -167.9045195>,
    <0.3099954, -167.9079576>,
    <0.3154154, -167.9742677>,
    <0.3208779, -168.0225894>,
    <0.3148148, -168.0047729>,
    <0.3159189, -167.9486921>,
    <0.3333333, -168.0684463>,
    <0.3194444, -168.0684463>,
    <0.3154154, -167.9742677>,
    <0.3234798, -168.0006864>,
    <0.3263889, -168.0684463>,
    <0.3175595, -168.0425225>,
    <0.3113426, -168.0206157>,
    <0.3148148, -168.0047729>,
    <0.3194444, -168.0684463>,
    <0.3055555, -168.0684463>,
    <0.3055555, -167.9407972>,
    <0.3175595, -168.0425225>,
    <0.3125000, -168.0684463>,
    <0.3055555, -167.9888971>,
    <0.3097517, -167.9697899>,
    <0.3113268, -167.7682198>,
    <0.3148148, -167.8156918>,
    <0.3055555, -167.7805596>,
    <0.3055555, -167.6922232>,
    <0.3193814, -167.7844046>,
    <0.3096021, -167.7959135>,
    <0.3055555, -167.7304559>,
    <0.3115939, -167.7324830>,
    <0.3173854, -167.7980798>,
    <0.3217468, -167.8387371>,
    <0.3148148, -167.8156918>,
    <0.3193814, -167.7844046>,
    <0.3333333, -167.8774261>,
    <0.3194576, -167.8774261>,
    <0.3173854, -167.7980798>,
    <0.3272755, -167.8370368>,
    <0.3273512, -167.8774261>,
    <0.3174490, -167.8507178>,
    <0.3113459, -167.8377759>,
    <0.3148148, -167.8156918>,
    <0.3194576, -167.8774261>,
    <0.3055555, -167.8774261>,
    <0.3055555, -167.7805596>,
    <0.3174490, -167.8507178>,
    <0.3115206, -167.8774261>,
    <0.3055555, -167.8353092>,
    <0.3096021, -167.7959135>,
    <0.3162515, -167.9111609>,
    <0.3240741, -167.9410995>,
    <0.3159189, -167.9486921>,
    <0.3055555, -167.8774261>,
    <0.3194576, -167.8774261>,
    <0.3191762, -167.9456595>,
    <0.3099954, -167.9079576>,
    <0.3115206, -167.8774261>,
    <0.3216103, -167.9071175>,
    <0.3275496, -167.9091721>,
    <0.3240741, -167.9410995>,
    <0.3194576, -167.8774261>,
    <0.3333333, -167.8774261>,
    <0.3333333, -167.9407369>,
    <0.3216103, -167.9071175>,
    <0.3273512, -167.8774261>,
    <0.3333333, -167.9044832>,
    <0.3294468, -167.9408891>,
    <0.3266649, -167.9747437>,
    <0.3240741, -167.9410995>,
    <0.3333333, -167.9407369>,
    <0.3333333, -168.0684463>,
    <0.3159189, -167.9486921>,
    <0.3294468, -167.9408891>,
    <0.3333333, -167.9888196>,
    <0.3234798, -168.0006864>,
    <0.3191762, -167.9456595>,
    <0.6715695, -167.9427444>,
    <0.6759259, -168.0047729>,
    <0.6666667, -167.9401659>,
    <0.6666667, -167.8774261>,
    <0.6770185, -167.9486128>,
    <0.6708628, -167.9694443>,
    <0.6666667, -167.9042299>,
    <0.6710987, -167.9079039>,
    <0.6765203, -167.9742222>,
    <0.6819861, -168.0225696>,
    <0.6759259, -168.0047729>,
    <0.6770185, -167.9486128>,
    <0.6944445, -168.0684463>,
    <0.6805556, -168.0684463>,
    <0.6765203, -167.9742222>,
    <0.6845846, -168.0006428>,
    <0.6875000, -168.0684463>,
    <0.6786703, -168.0425178>,
    <0.6724537, -168.0204578>,
    <0.6759259, -168.0047729>,
    <0.6805556, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6666667, -167.9401659>,
    <0.6786703, -168.0425178>,
    <0.6736111, -168.0684463>,
    <0.6666667, -167.9886588>,
    <0.6708628, -167.9694443>,
    <0.6773614, -167.9111411>,
    <0.6851852, -167.9410995>,
    <0.6770185, -167.9486128>,
    <0.6666667, -167.8774261>,
    <0.6805752, -167.8774261>,
    <0.6802811, -167.9456112>,
    <0.6710987, -167.9079039>,
    <0.6726353, -167.8774261>,
    <0.6827205, -167.9070567>,
    <0.6886623, -167.9090332>,
    <0.6851852, -167.9410995>,
    <0.6805752, -167.8774261>,
    <0.6944445, -167.8774261>,
    <0.6944445, -167.9401814>,
    <0.6827205, -167.9070567>,
    <0.6885128, -167.8774261>,
    <0.6944445, -167.9038445>,
    <0.6905758, -167.9405650>,
    <0.6877732, -167.9745850>,
    <0.6851852, -167.9410995>,
    <0.6944445, -167.9401814>,
    <0.6944445, -168.0684463>,
    <0.6770185, -167.9486128>,
    <0.6905758, -167.9405650>,
    <0.6944445, -167.9891217>,
    <0.6845846, -168.0006428>,
    <0.6802811, -167.9456112>,
    <0.3113365, -167.5906989>,
    <0.3148148, -167.6342972>,
    <0.3055555, -167.6048705>,
    <0.3055555, -167.5184453>,
    <0.3194202, -167.6051824>,
    <0.3096065, -167.6177446>,
    <0.3055555, -167.5563664>,
    <0.3116167, -167.5563642>,
    <0.3174070, -167.6179095>,
    <0.3217545, -167.6559815>,
    <0.3148148, -167.6342972>,
    <0.3194202, -167.6051824>,
    <0.3333333, -167.6922232>,
    <0.3194499, -167.6922232>,
    <0.3174070, -167.6179095>,
    <0.3272406, -167.6541068>,
    <0.3272590, -167.6922232>,
    <0.3174242, -167.6669079>,
    <0.3113439, -167.6559035>,
    <0.3148148, -167.6342972>,
    <0.3194499, -167.6922232>,
    <0.3055555, -167.6922232>,
    <0.3055555, -167.6048705>,
    <0.3174242, -167.6669079>,
    <0.3116355, -167.6922232>,
    <0.3055555, -167.6541051>,
    <0.3096065, -167.6177446>,
    <0.3171152, -167.7307021>,
    <0.3240741, -167.7539575>,
    <0.3193814, -167.7844046>,
    <0.3055555, -167.6922232>,
    <0.3194499, -167.6922232>,
    <0.3214318, -167.7711010>,
    <0.3115939, -167.7324830>,
    <0.3116355, -167.6922232>,
    <0.3214692, -167.7191820>,
    <0.3275476, -167.7297366>,
    <0.3240741, -167.7539575>,
    <0.3194499, -167.6922232>,
    <0.3333333, -167.6922232>,
    <0.3333333, -167.7805425>,
    <0.3214692, -167.7191820>,
    <0.3272590, -167.6922232>,
    <0.3333333, -167.7304472>,
    <0.3292792, -167.7689025>,
    <0.3275305, -167.7990827>,
    <0.3240741, -167.7539575>,
    <0.3333333, -167.7805425>,
    <0.3333333, -167.8774261>,
    <0.3193814, -167.7844046>,
    <0.3292792, -167.7689025>,
    <0.3333333, -167.8352858>,
    <0.3272755, -167.8370368>,
    <0.3214318, -167.7711010>,
    <0.6724350, -167.7681727>,
    <0.6759259, -167.8156918>,
    <0.6666667, -167.7804489>,
    <0.6666667, -167.6922232>,
    <0.6804809, -167.7843268>,
    <0.6707120, -167.7958462>,
    <0.6666667, -167.7303988>,
    <0.6726986, -167.7324397>,
    <0.6784888, -167.7980440>,
    <0.6828566, -167.8387177>,
    <0.6759259, -167.8156918>,
    <0.6804809, -167.7843268>,
    <0.6944445, -167.8774261>,
    <0.6805752, -167.8774261>,
    <0.6784888, -167.7980440>,
    <0.6884237, -167.8372837>,
    <0.6885128, -167.8774261>,
    <0.6785596, -167.8506629>,
    <0.6724586, -167.8377482>,
    <0.6759259, -167.8156918>,
    <0.6805752, -167.8774261>,
    <0.6666667, -167.8774261>,
    <0.6666667, -167.7804489>,
    <0.6785596, -167.8506629>,
    <0.6726353, -167.8774261>,
    <0.6666667, -167.8351153>,
    <0.6707120, -167.7958462>,
    <0.6782234, -167.7306827>,
    <0.6851852, -167.7539575>,
    <0.6804809, -167.7843268>,
    <0.6666667, -167.6922232>,
    <0.6805610, -167.6922232>,
    <0.6825363, -167.7710575>,
    <0.6726986, -167.7324397>,
    <0.6727466, -167.6922232>,
    <0.6825800, -167.7191777>,
    <0.6886588, -167.7297155>,
    <0.6851852, -167.7539575>,
    <0.6805610, -167.6922232>,
    <0.6944445, -167.6922232>,
    <0.6944445, -167.7804581>,
    <0.6825800, -167.7191777>,
    <0.6883701, -167.6922232>,
    <0.6944445, -167.7304035>,
    <0.6903903, -167.7688548>,
    <0.6886387, -167.7990421>,
    <0.6851852, -167.7539575>,
    <0.6944445, -167.7804581>,
    <0.6944445, -167.8774261>,
    <0.6804809, -167.7843268>,
    <0.6903903, -167.7688548>,
    <0.6944445, -167.8357431>,
    <0.6884237, -167.8372837>,
    <0.6825363, -167.7710575>,
    <0.3104620, -167.9543267>,
    <0.3148148, -168.0105648>,
    <0.3159220, -167.9596049>,
    <0.3055555, -167.8948019>,
    <0.3055555, -167.9523352>,
    <0.3154171, -167.9828461>,
    <0.3099978, -167.9225714>,
    <0.3055555, -167.9195413>,
    <0.3097518, -167.9787243>,
    <0.3113426, -168.0249482>,
    <0.3148148, -168.0105648>,
    <0.3055555, -167.9523352>,
    <0.3055555, -168.0684463>,
    <0.3194444, -168.0684463>,
    <0.3097518, -167.9787243>,
    <0.3055555, -167.9958176>,
    <0.3125000, -168.0684463>,
    <0.3175599, -168.0448844>,
    <0.3208787, -168.0267656>,
    <0.3148148, -168.0105648>,
    <0.3194444, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3159220, -167.9596049>,
    <0.3175599, -168.0448844>,
    <0.3263889, -168.0684463>,
    <0.3234828, -168.0068689>,
    <0.3154171, -167.9828461>,
    <0.3113277, -167.7954392>,
    <0.3148148, -167.8386752>,
    <0.3193849, -167.8102511>,
    <0.3055555, -167.7264218>,
    <0.3055555, -167.8064088>,
    <0.3173871, -167.8226767>,
    <0.3115960, -167.7630371>,
    <0.3055555, -167.7609961>,
    <0.3096024, -167.8205110>,
    <0.3113458, -167.8586720>,
    <0.3148148, -167.8386752>,
    <0.3055555, -167.8064088>,
    <0.3055555, -167.8948019>,
    <0.3194574, -167.8948019>,
    <0.3096024, -167.8205110>,
    <0.3055555, -167.8565493>,
    <0.3115205, -167.8948019>,
    <0.3174505, -167.8705401>,
    <0.3217476, -167.8596325>,
    <0.3148148, -167.8386752>,
    <0.3194574, -167.8948019>,
    <0.3333333, -167.8948019>,
    <0.3193849, -167.8102511>,
    <0.3174505, -167.8705401>,
    <0.3273511, -167.8948019>,
    <0.3272781, -167.8580970>,
    <0.3173871, -167.8226767>,
    <0.3162523, -167.9254730>,
    <0.3240741, -167.9526834>,
    <0.3194574, -167.8948019>,
    <0.3055555, -167.8948019>,
    <0.3159220, -167.9596049>,
    <0.3216123, -167.9218193>,
    <0.3115205, -167.8948019>,
    <0.3099978, -167.9225714>,
    <0.3191747, -167.9568433>,
    <0.3266657, -167.9832528>,
    <0.3240741, -167.9526834>,
    <0.3159220, -167.9596049>,
    <0.3333333, -168.0684463>,
    <0.3333333, -167.9522766>,
    <0.3191747, -167.9568433>,
    <0.3234828, -168.0068689>,
    <0.3333333, -167.9957398>,
    <0.3294473, -167.9524473>,
    <0.3275495, -167.9236410>,
    <0.3240741, -167.9526834>,
    <0.3333333, -167.9522766>,
    <0.3333333, -167.8948019>,
    <0.3194574, -167.8948019>,
    <0.3294473, -167.9524473>,
    <0.3333333, -167.9195067>,
    <0.3273511, -167.8948019>,
    <0.3216123, -167.9218193>,
    <0.6715703, -167.9541554>,
    <0.6759259, -168.0105648>,
    <0.6770218, -167.9595339>,
    <0.6666667, -167.8948019>,
    <0.6666667, -167.9517210>,
    <0.6765221, -167.9828054>,
    <0.6711012, -167.9225233>,
    <0.6666667, -167.9192648>,
    <0.6708628, -167.9783882>,
    <0.6724537, -168.0247946>,
    <0.6759259, -168.0105648>,
    <0.6666667, -167.9517210>,
    <0.6666667, -168.0684463>,
    <0.6805556, -168.0684463>,
    <0.6708628, -167.9783882>,
    <0.6666667, -167.9955681>,
    <0.6736111, -168.0684463>,
    <0.6786706, -168.0448803>,
    <0.6819869, -168.0267478>,
    <0.6759259, -168.0105648>,
    <0.6805556, -168.0684463>,
    <0.6944445, -168.0684463>,
    <0.6770218, -167.9595339>,
    <0.6786706, -168.0448803>,
    <0.6875000, -168.0684463>,
    <0.6845877, -168.0068301>,
    <0.6765221, -167.9828054>,
    <0.6773621, -167.9254553>,
    <0.6851852, -167.9526834>,
    <0.6805749, -167.8948019>,
    <0.6666667, -167.8948019>,
    <0.6770218, -167.9595339>,
    <0.6827225, -167.9217645>,
    <0.6726351, -167.8948019>,
    <0.6711012, -167.9225233>,
    <0.6802798, -167.9567999>,
    <0.6877740, -167.9831002>,
    <0.6851852, -167.9526834>,
    <0.6770218, -167.9595339>,
    <0.6944445, -168.0684463>,
    <0.6944445, -167.9517372>,
    <0.6802798, -167.9567999>,
    <0.6845877, -168.0068301>,
    <0.6944445, -167.9959765>,
    <0.6905746, -167.9521326>,
    <0.6886622, -167.9235061>,
    <0.6851852, -167.9526834>,
    <0.6944445, -167.9517372>,
    <0.6944445, -167.8948019>,
    <0.6805749, -167.8948019>,
    <0.6905746, -167.9521326>,
    <0.6944445, -167.9189386>,
    <0.6885086, -167.8948019>,
    <0.6827225, -167.9217645>,
    <0.3113343, -167.4265843>,
    <0.3148148, -167.4660888>,
    <0.3055555, -167.4391507>,
    <0.3055555, -167.3613758>,
    <0.3194111, -167.4397221>,
    <0.3096058, -167.4509341>,
    <0.3055555, -167.3955180>,
    <0.3116109, -167.3956156>,
    <0.3174017, -167.4512490>,
    <0.3217529, -167.4856754>,
    <0.3148148, -167.4660888>,
    <0.3194111, -167.4397221>,
    <0.3333333, -167.5184453>,
    <0.3194523, -167.5184453>,
    <0.3174017, -167.4512490>,
    <0.3272346, -167.4839601>,
    <0.3272602, -167.5184453>,
    <0.3174256, -167.4955641>,
    <0.3113445, -167.4855325>,
    <0.3148148, -167.4660888>,
    <0.3194523, -167.5184453>,
    <0.3055555, -167.5184453>,
    <0.3055555, -167.4391507>,
    <0.3174256, -167.4955641>,
    <0.3116368, -167.5184453>,
    <0.3055555, -167.4838674>,
    <0.3096058, -167.4509341>,
    <0.3171255, -167.5546111>,
    <0.3240741, -167.5763713>,
    <0.3194202, -167.6051824>,
    <0.3055555, -167.5184453>,
    <0.3194523, -167.5184453>,
    <0.3214534, -167.5925951>,
    <0.3116167, -167.5563642>,
    <0.3116368, -167.5184453>,
    <0.3214727, -167.5437683>,
    <0.3275483, -167.5545331>,
    <0.3240741, -167.5763713>,
    <0.3194523, -167.5184453>,
    <0.3333333, -167.5184453>,
    <0.3333333, -167.6048705>,
    <0.3214727, -167.5437683>,
    <0.3272602, -167.5184453>,
    <0.3333333, -167.5563664>,
    <0.3292788, -167.5923911>,
    <0.3275402, -167.6196618>,
    <0.3240741, -167.5763713>,
    <0.3333333, -167.6048705>,
    <0.3333333, -167.6922232>,
    <0.3194202, -167.6051824>,
    <0.3292788, -167.5923911>,
    <0.3333333, -167.6541051>,
    <0.3272406, -167.6541068>,
    <0.3214534, -167.5925951>,
    <0.6724476, -167.5906989>,
    <0.6759259, -167.6342972>,
    <0.6666667, -167.6048705>,
    <0.6666667, -167.5184453>,
    <0.6805313, -167.6051824>,
    <0.6707176, -167.6177446>,
    <0.6666667, -167.5563664>,
    <0.6727279, -167.5563642>,
    <0.6785181, -167.6179095>,
    <0.6828657, -167.6559815>,
    <0.6759259, -167.6342972>,
    <0.6805313, -167.6051824>,
    <0.6944445, -167.6922232>,
    <0.6805610, -167.6922232>,
    <0.6785181, -167.6179095>,
    <0.6883517, -167.6541068>,
    <0.6883701, -167.6922232>,
    <0.6785353, -167.6669079>,
    <0.6724551, -167.6559035>,
    <0.6759259, -167.6342972>,
    <0.6805610, -167.6922232>,
    <0.6666667, -167.6922232>,
    <0.6666667, -167.6048705>,
    <0.6785353, -167.6669079>,
    <0.6727466, -167.6922232>,
    <0.6666667, -167.6541051>,
    <0.6707176, -167.6177446>,
    <0.6782366, -167.5546111>,
    <0.6851852, -167.5763713>,
    <0.6805313, -167.6051824>,
    <0.6666667, -167.5184453>,
    <0.6805634, -167.5184453>,
    <0.6825645, -167.5925951>,
    <0.6727279, -167.5563642>,
    <0.6727479, -167.5184453>,
    <0.6825839, -167.5437683>,
    <0.6886594, -167.5545331>,
    <0.6851852, -167.5763713>,
    <0.6805634, -167.5184453>,
    <0.6944445, -167.5184453>,
    <0.6944445, -167.6048705>,
    <0.6825839, -167.5437683>,
    <0.6883714, -167.5184453>,
    <0.6944445, -167.5563664>,
    <0.6903900, -167.5923911>,
    <0.6886513, -167.6196618>,
    <0.6851852, -167.5763713>,
    <0.6944445, -167.6048705>,
    <0.6944445, -167.6922232>,
    <0.6805313, -167.6051824>,
    <0.6903900, -167.5923911>,
    <0.6944445, -167.6541051>,
    <0.6883517, -167.6541068>,
    <0.6825645, -167.5925951>,
    <0.3113370, -167.6341061>,
    <0.3148148, -167.6737665>,
    <0.3194221, -167.6473117>,
    <0.3055555, -167.5684558>,
    <0.3055555, -167.6468904>,
    <0.3174081, -167.6588757>,
    <0.3116180, -167.6029317>,
    <0.3055555, -167.6028579>,
    <0.3096066, -167.6586490>,
    <0.3113438, -167.6933751>,
    <0.3148148, -167.6737665>,
    <0.3055555, -167.6468904>,
    <0.3055555, -167.7264218>,
    <0.3194493, -167.7264218>,
    <0.3096066, -167.6586490>,
    <0.3055555, -167.6917086>,
    <0.3116353, -167.7264218>,
    <0.3174238, -167.7034090>,
    <0.3217549, -167.6934805>,
    <0.3148148, -167.6737665>,
    <0.3194493, -167.7264218>,
    <0.3333333, -167.7264218>,
    <0.3194221, -167.6473117>,
    <0.3174238, -167.7034090>,
    <0.3272587, -167.7264218>,
    <0.3272418, -167.6917804>,
    <0.3174081, -167.6588757>,
    <0.3171160, -167.7614108>,
    <0.3240741, -167.7825485>,
    <0.3194493, -167.7264218>,
    <0.3055555, -167.7264218>,
    <0.3193849, -167.8102511>,
    <0.3214688, -167.7509311>,
    <0.3116353, -167.7264218>,
    <0.3115960, -167.7630371>,
    <0.3214338, -167.7981464>,
    <0.3275314, -167.8234980>,
    <0.3240741, -167.7825485>,
    <0.3193849, -167.8102511>,
    <0.3333333, -167.8948019>,
    <0.3333333, -167.8063904>,
    <0.3214338, -167.7981464>,
    <0.3272781, -167.8580970>,
    <0.3333333, -167.8565241>,
    <0.3292794, -167.7959518>,
    <0.3275475, -167.7604457>,
    <0.3240741, -167.7825485>,
    <0.3333333, -167.8063904>,
    <0.3333333, -167.7264218>,
    <0.3194493, -167.7264218>,
    <0.3292794, -167.7959518>,
    <0.3333333, -167.7609868>,
    <0.3272587, -167.7264218>,
    <0.3214688, -167.7509311>,
    <0.6724359, -167.7953920>,
    <0.6759259, -167.8386752>,
    <0.6804844, -167.8101807>,
    <0.6666667, -167.7264218>,
    <0.6666667, -167.8062904>,
    <0.6784905, -167.8226444>,
    <0.6727007, -167.7629979>,
    <0.6666667, -167.7609355>,
    <0.6707122, -167.8204398>,
    <0.6724585, -167.8586424>,
    <0.6759259, -167.8386752>,
    <0.6666667, -167.8062904>,
    <0.6666667, -167.8948019>,
    <0.6805749, -167.8948019>,
    <0.6707122, -167.8204398>,
    <0.6666667, -167.8563399>,
    <0.6726351, -167.8948019>,
    <0.6785611, -167.8704901>,
    <0.6828574, -167.8596150>,
    <0.6759259, -167.8386752>,
    <0.6805749, -167.8948019>,
    <0.6944445, -167.8948019>,
    <0.6804844, -167.8101807>,
    <0.6785611, -167.8704901>,
    <0.6885086, -167.8948019>,
    <0.6884222, -167.8582970>,
    <0.6784905, -167.8226444>,
    <0.6782242, -167.7613932>,
    <0.6851852, -167.7825485>,
    <0.6805604, -167.7264218>,
    <0.6666667, -167.7264218>,
    <0.6804844, -167.8101807>,
    <0.6825796, -167.7509271>,
    <0.6727464, -167.7264218>,
    <0.6727007, -167.7629979>,
    <0.6825384, -167.7981071>,
    <0.6886396, -167.8234579>,
    <0.6851852, -167.7825485>,
    <0.6804844, -167.8101807>,
    <0.6944445, -167.8948019>,
    <0.6944445, -167.8063003>,
    <0.6825384, -167.7981071>,
    <0.6884222, -167.8582970>,
    <0.6944445, -167.8569242>,
    <0.6903904, -167.7959009>,
    <0.6886586, -167.7604231>,
    <0.6851852, -167.7825485>,
    <0.6944445, -167.8063003>,
    <0.6944445, -167.7264218>,
    <0.6805604, -167.7264218>,
    <0.6903904, -167.7959009>,
    <0.6944445, -167.7609405>,
    <0.6883698, -167.7264218>,
    <0.6825796, -167.7509271>,
    <0.3113349, -167.4848985>,
    <0.3148148, -167.5208549>,
    <0.3194138, -167.4968970>,
    <0.3055555, -167.4256532>,
    <0.3055555, -167.4961890>,
    <0.3174033, -167.5073705>,
    <0.3116126, -167.4567920>,
    <0.3055555, -167.4566011>,
    <0.3096060, -167.5069791>,
    <0.3113444, -167.5384889>,
    <0.3148148, -167.5208549>,
    <0.3055555, -167.4961890>,
    <0.3055555, -167.5684558>,
    <0.3194515, -167.5684558>,
    <0.3096060, -167.5069791>,
    <0.3055555, -167.5369298>,
    <0.3116364, -167.5684558>,
    <0.3174250, -167.5476517>,
    <0.3217534, -167.5386659>,
    <0.3148148, -167.5208549>,
    <0.3194515, -167.5684558>,
    <0.3333333, -167.5684558>,
    <0.3194138, -167.4968970>,
    <0.3174250, -167.5476517>,
    <0.3272598, -167.5684558>,
    <0.3272363, -167.5371117>,
    <0.3174033, -167.5073705>,
    <0.3171258, -167.6013336>,
    <0.3240741, -167.6211112>,
    <0.3194515, -167.5684558>,
    <0.3055555, -167.5684558>,
    <0.3194221, -167.6473117>,
    <0.3214721, -167.5914725>,
    <0.3116364, -167.5684558>,
    <0.3116180, -167.6029317>,
    <0.3214546, -167.6358644>,
    <0.3275407, -167.6604338>,
    <0.3240741, -167.6211112>,
    <0.3194221, -167.6473117>,
    <0.3333333, -167.7264218>,
    <0.3333333, -167.6468904>,
    <0.3214546, -167.6358644>,
    <0.3272418, -167.6917804>,
    <0.3333333, -167.6917086>,
    <0.3292790, -167.6356026>,
    <0.3275481, -167.6012283>,
    <0.3240741, -167.6211112>,
    <0.3333333, -167.6468904>,
    <0.3333333, -167.5684558>,
    <0.3194515, -167.5684558>,
    <0.3292790, -167.6356026>,
    <0.3333333, -167.6028579>,
    <0.3272598, -167.5684558>,
    <0.3214721, -167.5914725>,
    <0.6724481, -167.6341061>,
    <0.6759259, -167.6737665>,
    <0.6805332, -167.6473117>,
    <0.6666667, -167.5684558>,
    <0.6666667, -167.6468904>,
    <0.6785193, -167.6588757>,
    <0.6727291, -167.6029317>,
    <0.6666667, -167.6028580>,
    <0.6707177, -167.6586490>,
    <0.6724549, -167.6933751>,
    <0.6759259, -167.6737665>,
    <0.6666667, -167.6468904>,
    <0.6666667, -167.7264218>,
    <0.6805604, -167.7264218>,
    <0.6707177, -167.6586490>,
    <0.6666667, -167.6917086>,
    <0.6727464, -167.7264218>,
    <0.6785349, -167.7034090>,
    <0.6828660, -167.6934805>,
    <0.6759259, -167.6737665>,
    <0.6805604, -167.7264218>,
    <0.6944445, -167.7264218>,
    <0.6805332, -167.6473117>,
    <0.6785349, -167.7034090>,
    <0.6883698, -167.7264218>,
    <0.6883529, -167.6917804>,
    <0.6785193, -167.6588757>,
    <0.6782369, -167.6013336>,
    <0.6851852, -167.6211112>,
    <0.6805626, -167.5684558>,
    <0.6666667, -167.5684558>,
    <0.6805332, -167.6473117>,
    <0.6825832, -167.5914725>,
    <0.6727476, -167.5684558>,
    <0.6727291, -167.6029317>,
    <0.6825657, -167.6358644>,
    <0.6886518, -167.6604338>,
    <0.6851852, -167.6211112>,
    <0.6805332, -167.6473117>,
    <0.6944445, -167.7264218>,
    <0.6944445, -167.6468904>,
    <0.6825657, -167.6358644>,
    <0.6883529, -167.6917804>,
    <0.6944445, -167.6917086>,
    <0.6903901, -167.6356026>,
    <0.6886592, -167.6012283>,
    <0.6851852, -167.6211112>,
    <0.6944445, -167.6468904>,
    <0.6944445, -167.5684558>,
    <0.6805626, -167.5684558>,
    <0.6903901, -167.6356026>,
    <0.6944445, -167.6028580>,
    <0.6883709, -167.5684558>,
    <0.6825832, -167.5914725>,
    <0.3113322, -167.2819570>,
    <0.3148148, -167.3161845>,
    <0.3055555, -167.2924560>,
    <0.3055555, -167.2258020>,
    <0.3194028, -167.2933857>,
    <0.3096052, -167.3028339>,
    <0.3055555, -167.2550533>,
    <0.3116055, -167.2553296>,
    <0.3173969, -167.3033535>,
    <0.3217513, -167.3330804>,
    <0.3148148, -167.3161845>,
    <0.3194028, -167.2933857>,
    <0.3333333, -167.3613758>,
    <0.3194544, -167.3613758>,
    <0.3173969, -167.3033535>,
    <0.3272291, -167.3315832>,
    <0.3272613, -167.3613758>,
    <0.3174266, -167.3416247>,
    <0.3113451, -167.3328480>,
    <0.3148148, -167.3161845>,
    <0.3194544, -167.3613758>,
    <0.3055555, -167.3613758>,
    <0.3055555, -167.2924560>,
    <0.3174266, -167.3416247>,
    <0.3116379, -167.3613758>,
    <0.3055555, -167.3313235>,
    <0.3096052, -167.3028339>,
    <0.3171238, -167.3940515>,
    <0.3240741, -167.4137323>,
    <0.3194111, -167.4397221>,
    <0.3055555, -167.3613758>,
    <0.3194544, -167.3613758>,
    <0.3214482, -167.4283682>,
    <0.3116109, -167.3956156>,
    <0.3116379, -167.3613758>,
    <0.3214738, -167.3842624>,
    <0.3275488, -167.3939086>,
    <0.3240741, -167.4137323>,
    <0.3194544, -167.3613758>,
    <0.3333333, -167.3613758>,
    <0.3333333, -167.4391507>,
    <0.3214738, -167.3842624>,
    <0.3272613, -167.3613758>,
    <0.3333333, -167.3955180>,
    <0.3292782, -167.4280187>,
    <0.3275380, -167.4527626>,
    <0.3240741, -167.4137323>,
    <0.3333333, -167.4391507>,
    <0.3333333, -167.5184453>,
    <0.3194111, -167.4397221>,
    <0.3292782, -167.4280187>,
    <0.3333333, -167.4838674>,
    <0.3272346, -167.4839601>,
    <0.3214482, -167.4283682>,
    <0.6724454, -167.4265843>,
    <0.6759259, -167.4660888>,
    <0.6666667, -167.4391507>,
    <0.6666667, -167.3613758>,
    <0.6805222, -167.4397221>,
    <0.6707169, -167.4509341>,
    <0.6666667, -167.3955180>,
    <0.6727220, -167.3956156>,
    <0.6785128, -167.4512490>,
    <0.6828640, -167.4856754>,
    <0.6759259, -167.4660888>,
    <0.6805222, -167.4397221>,
    <0.6944445, -167.5184453>,
    <0.6805634, -167.5184453>,
    <0.6785128, -167.4512490>,
    <0.6883457, -167.4839601>,
    <0.6883714, -167.5184453>,
    <0.6785367, -167.4955641>,
    <0.6724557, -167.4855325>,
    <0.6759259, -167.4660888>,
    <0.6805634, -167.5184453>,
    <0.6666667, -167.5184453>,
    <0.6666667, -167.4391507>,
    <0.6785367, -167.4955641>,
    <0.6727479, -167.5184453>,
    <0.6666667, -167.4838674>,
    <0.6707169, -167.4509341>,
    <0.6782349, -167.3940515>,
    <0.6851852, -167.4137323>,
    <0.6805222, -167.4397221>,
    <0.6666667, -167.3613758>,
    <0.6805655, -167.3613758>,
    <0.6825593, -167.4283682>,
    <0.6727220, -167.3956156>,
    <0.6727491, -167.3613758>,
    <0.6825849, -167.3842624>,
    <0.6886599, -167.3939086>,
    <0.6851852, -167.4137323>,
    <0.6805655, -167.3613758>,
    <0.6944445, -167.3613758>,
    <0.6944445, -167.4391507>,
    <0.6825849, -167.3842624>,
    <0.6883724, -167.3613758>,
    <0.6944445, -167.3955180>,
    <0.6903894, -167.4280187>,
    <0.6886491, -167.4527626>,
    <0.6851852, -167.4137323>,
    <0.6944445, -167.4391507>,
    <0.6944445, -167.5184453>,
    <0.6805222, -167.4397221>,
    <0.6903894, -167.4280187>,
    <0.6944445, -167.4838674>,
    <0.6883457, -167.4839601>,
    <0.6825593, -167.4283682>,
    <0.3113330, -167.3534027>,
    <0.3148148, -167.3845690>,
    <0.3194062, -167.3638575>,
    <0.3055555, -167.3024008>,
    <0.3055555, -167.3627833>,
    <0.3173989, -167.3729124>,
    <0.3116077, -167.3292549>,
    <0.3055555, -167.3288803>,
    <0.3096054, -167.3723121>,
    <0.3113448, -167.3996647>,
    <0.3148148, -167.3845690>,
    <0.3055555, -167.3627833>,
    <0.3055555, -167.4256532>,
    <0.3194534, -167.4256532>,
    <0.3096054, -167.3723121>,
    <0.3055555, -167.3982231>,
    <0.3116375, -167.4256532>,
    <0.3174260, -167.4076960>,
    <0.3217520, -167.3999332>,
    <0.3148148, -167.3845690>,
    <0.3194534, -167.4256532>,
    <0.3333333, -167.4256532>,
    <0.3194062, -167.3638575>,
    <0.3174260, -167.4076960>,
    <0.3272608, -167.4256532>,
    <0.3272313, -167.3985780>,
    <0.3173989, -167.3729124>,
    <0.3171242, -167.4553644>,
    <0.3240741, -167.4732541>,
    <0.3194534, -167.4256532>,
    <0.3055555, -167.4256532>,
    <0.3194138, -167.4968970>,
    <0.3214731, -167.4464590>,
    <0.3116375, -167.4256532>,
    <0.3116126, -167.4567920>,
    <0.3214498, -167.4865678>,
    <0.3275386, -167.5086990>,
    <0.3240741, -167.4732541>,
    <0.3194138, -167.4968970>,
    <0.3333333, -167.5684558>,
    <0.3333333, -167.4961891>,
    <0.3214498, -167.4865678>,
    <0.3272363, -167.5371117>,
    <0.3333333, -167.5369298>,
    <0.3292785, -167.4861453>,
    <0.3275485, -167.4551874>,
    <0.3240741, -167.4732541>,
    <0.3333333, -167.4961891>,
    <0.3333333, -167.4256532>,
    <0.3194534, -167.4256532>,
    <0.3292785, -167.4861453>,
    <0.3333333, -167.4566011>,
    <0.3272608, -167.4256532>,
    <0.3214731, -167.4464590>,
    <0.6724461, -167.4848985>,
    <0.6759259, -167.5208549>,
    <0.6805249, -167.4968970>,
    <0.6666667, -167.4256532>,
    <0.6666667, -167.4961890>,
    <0.6785144, -167.5073705>,
    <0.6727238, -167.4567920>,
    <0.6666667, -167.4566011>,
    <0.6707171, -167.5069791>,
    <0.6724555, -167.5384889>,
    <0.6759259, -167.5208549>,
    <0.6666667, -167.4961890>,
    <0.6666667, -167.5684558>,
    <0.6805626, -167.5684558>,
    <0.6707171, -167.5069791>,
    <0.6666667, -167.5369298>,
    <0.6727476, -167.5684558>,
    <0.6785362, -167.5476517>,
    <0.6828645, -167.5386659>,
    <0.6759259, -167.5208549>,
    <0.6805626, -167.5684558>,
    <0.6944445, -167.5684558>,
    <0.6805249, -167.4968970>,
    <0.6785362, -167.5476517>,
    <0.6883709, -167.5684558>,
    <0.6883474, -167.5371117>,
    <0.6785144, -167.5073705>,
    <0.6782353, -167.4553644>,
    <0.6851852, -167.4732541>,
    <0.6805646, -167.4256532>,
    <0.6666667, -167.4256532>,
    <0.6805249, -167.4968970>,
    <0.6825842, -167.4464590>,
    <0.6727486, -167.4256532>,
    <0.6727238, -167.4567920>,
    <0.6825609, -167.4865678>,
    <0.6886498, -167.5086990>,
    <0.6851852, -167.4732541>,
    <0.6805249, -167.4968970>,
    <0.6944445, -167.5684558>,
    <0.6944445, -167.4961890>,
    <0.6825609, -167.4865678>,
    <0.6883474, -167.5371117>,
    <0.6944445, -167.5369297>,
    <0.6903896, -167.4861453>,
    <0.6886597, -167.4551874>,
    <0.6851852, -167.4732541>,
    <0.6944445, -167.4961890>,
    <0.6944445, -167.4256532>,
    <0.6805646, -167.4256532>,
    <0.6903896, -167.4861453>,
    <0.6944445, -167.4566011>,
    <0.6883719, -167.4256532>,
    <0.6825842, -167.4464590>,
    <0.3112556, -167.1603094>,
    <0.3148148, -167.1891429>,
    <0.3055555, -167.1668348>,
    <0.3055555, -167.1158246>,
    <0.3190964, -167.1694354>,
    <0.3096085, -167.1765994>,
    <0.3055555, -167.1355698>,
    <0.3112692, -167.1384461>,
    <0.3172275, -167.1780376>,
    <0.3216752, -167.2025455>,
    <0.3148148, -167.1891429>,
    <0.3190964, -167.1694354>,
    <0.3333333, -167.2258020>,
    <0.3194562, -167.2258020>,
    <0.3172275, -167.1780376>,
    <0.3270602, -167.2009655>,
    <0.3272622, -167.2258020>,
    <0.3174182, -167.2097050>,
    <0.3113455, -167.2018954>,
    <0.3148148, -167.1891429>,
    <0.3194562, -167.2258020>,
    <0.3055555, -167.2258020>,
    <0.3055555, -167.1668348>,
    <0.3174182, -167.2097050>,
    <0.3116389, -167.2258020>,
    <0.3055555, -167.1999202>,
    <0.3096085, -167.1765994>,
    <0.3171221, -167.2539957>,
    <0.3240741, -167.2709932>,
    <0.3194028, -167.2933857>,
    <0.3055555, -167.2258020>,
    <0.3194562, -167.2258020>,
    <0.3214434, -167.2836036>,
    <0.3116055, -167.2553296>,
    <0.3116389, -167.2258020>,
    <0.3214745, -167.2455535>,
    <0.3275492, -167.2537633>,
    <0.3240741, -167.2709932>,
    <0.3194562, -167.2258020>,
    <0.3333333, -167.2258020>,
    <0.3333333, -167.2924560>,
    <0.3214745, -167.2455535>,
    <0.3272622, -167.2258020>,
    <0.3333333, -167.2550533>,
    <0.3292777, -167.2830552>,
    <0.3275359, -167.3045527>,
    <0.3240741, -167.2709932>,
    <0.3333333, -167.2924560>,
    <0.3333333, -167.3613758>,
    <0.3194028, -167.2933857>,
    <0.3292777, -167.2830552>,
    <0.3333333, -167.3313235>,
    <0.3272291, -167.3315832>,
    <0.3214434, -167.2836036>,
    <0.6724433, -167.2819570>,
    <0.6759259, -167.3161845>,
    <0.6666667, -167.2924560>,
    <0.6666667, -167.2258020>,
    <0.6805139, -167.2933857>,
    <0.6707163, -167.3028339>,
    <0.6666667, -167.2550533>,
    <0.6727166, -167.2553296>,
    <0.6785080, -167.3033535>,
    <0.6828625, -167.3330804>,
    <0.6759259, -167.3161845>,
    <0.6805139, -167.2933857>,
    <0.6944445, -167.3613758>,
    <0.6805655, -167.3613758>,
    <0.6785080, -167.3033535>,
    <0.6883402, -167.3315832>,
    <0.6883724, -167.3613758>,
    <0.6785378, -167.3416247>,
    <0.6724562, -167.3328480>,
    <0.6759259, -167.3161845>,
    <0.6805655, -167.3613758>,
    <0.6666667, -167.3613758>,
    <0.6666667, -167.2924560>,
    <0.6785378, -167.3416247>,
    <0.6727491, -167.3613758>,
    <0.6666667, -167.3313235>,
    <0.6707163, -167.3028339>,
    <0.6782333, -167.2539957>,
    <0.6851852, -167.2709932>,
    <0.6805139, -167.2933857>,
    <0.6666667, -167.2258020>,
    <0.6805673, -167.2258020>,
    <0.6825546, -167.2836036>,
    <0.6727166, -167.2553296>,
    <0.6727500, -167.2258020>,
    <0.6825856, -167.2455535>,
    <0.6886604, -167.2537633>,
    <0.6851852, -167.2709932>,
    <0.6805673, -167.2258020>,
    <0.6944445, -167.2258020>,
    <0.6944445, -167.2924560>,
    <0.6825856, -167.2455535>,
    <0.6883733, -167.2258020>,
    <0.6944445, -167.2550533>,
    <0.6903888, -167.2830552>,
    <0.6886470, -167.3045527>,
    <0.6851852, -167.2709932>,
    <0.6944445, -167.2924560>,
    <0.6944445, -167.3613758>,
    <0.6805139, -167.2933857>,
    <0.6903888, -167.2830552>,
    <0.6944445, -167.3313235>,
    <0.6883402, -167.3315832>,
    <0.6825546, -167.2836036>,
    <0.3113314, -167.2436308>,
    <0.3148148, -167.2690732>,
    <0.3193997, -167.2522483>,
    <0.3055555, -167.2024179>,
    <0.3055555, -167.2507837>,
    <0.3173951, -167.2596042>,
    <0.3116035, -167.2241867>,
    <0.3055555, -167.2235884>,
    <0.3096050, -167.2587824>,
    <0.3113452, -167.2811646>,
    <0.3148148, -167.2690732>,
    <0.3055555, -167.2507837>,
    <0.3055555, -167.3024008>,
    <0.3194550, -167.3024008>,
    <0.3096050, -167.2587824>,
    <0.3055555, -167.2798504>,
    <0.3116383, -167.3024008>,
    <0.3174266, -167.2878319>,
    <0.3217507, -167.2815307>,
    <0.3148148, -167.2690732>,
    <0.3194550, -167.3024008>,
    <0.3333333, -167.3024008>,
    <0.3193997, -167.2522483>,
    <0.3174266, -167.2878319>,
    <0.3272616, -167.3024008>,
    <0.3272269, -167.2804214>,
    <0.3173951, -167.2596042>,
    <0.3171227, -167.3280360>,
    <0.3240741, -167.3434849>,
    <0.3194550, -167.3024008>,
    <0.3055555, -167.3024008>,
    <0.3194062, -167.3638575>,
    <0.3214737, -167.3203558>,
    <0.3116383, -167.3024008>,
    <0.3116077, -167.3292549>,
    <0.3214455, -167.3549573>,
    <0.3275367, -167.3739447>,
    <0.3240741, -167.3434849>,
    <0.3194062, -167.3638575>,
    <0.3333333, -167.4256532>,
    <0.3333333, -167.3627833>,
    <0.3214455, -167.3549573>,
    <0.3272313, -167.3985780>,
    <0.3333333, -167.3982231>,
    <0.3292780, -167.3543311>,
    <0.3275489, -167.3277674>,
    <0.3240741, -167.3434849>,
    <0.3333333, -167.3627833>,
    <0.3333333, -167.3024008>,
    <0.3194550, -167.3024008>,
    <0.3292780, -167.3543311>,
    <0.3333333, -167.3288803>,
    <0.3272616, -167.3024008>,
    <0.3214737, -167.3203558>,
    <0.6724442, -167.3534027>,
    <0.6759259, -167.3845690>,
    <0.6805174, -167.3638575>,
    <0.6666667, -167.3024008>,
    <0.6666667, -167.3627833>,
    <0.6785101, -167.3729124>,
    <0.6727189, -167.3292549>,
    <0.6666667, -167.3288803>,
    <0.6707166, -167.3723121>,
    <0.6724560, -167.3996647>,
    <0.6759259, -167.3845690>,
    <0.6666667, -167.3627833>,
    <0.6666667, -167.4256532>,
    <0.6805646, -167.4256532>,
    <0.6707166, -167.3723121>,
    <0.6666667, -167.3982231>,
    <0.6727486, -167.4256532>,
    <0.6785371, -167.4076960>,
    <0.6828631, -167.3999332>,
    <0.6759259, -167.3845690>,
    <0.6805646, -167.4256532>,
    <0.6944445, -167.4256532>,
    <0.6805174, -167.3638575>,
    <0.6785371, -167.4076960>,
    <0.6883719, -167.4256532>,
    <0.6883424, -167.3985780>,
    <0.6785101, -167.3729124>,
    <0.6782339, -167.3280360>,
    <0.6851852, -167.3434849>,
    <0.6805662, -167.3024008>,
    <0.6666667, -167.3024008>,
    <0.6805174, -167.3638575>,
    <0.6825848, -167.3203558>,
    <0.6727495, -167.3024008>,
    <0.6727189, -167.3292549>,
    <0.6825566, -167.3549573>,
    <0.6886479, -167.3739447>,
    <0.6851852, -167.3434849>,
    <0.6805174, -167.3638575>,
    <0.6944445, -167.4256532>,
    <0.6944445, -167.3627833>,
    <0.6825566, -167.3549573>,
    <0.6883424, -167.3985780>,
    <0.6944445, -167.3982231>,
    <0.6903891, -167.3543311>,
    <0.6886601, -167.3277674>,
    <0.6851852, -167.3434849>,
    <0.6944445, -167.3627833>,
    <0.6944445, -167.3024008>,
    <0.6805662, -167.3024008>,
    <0.6903891, -167.3543311>,
    <0.6944445, -167.3288803>,
    <0.6883727, -167.3024008>,
    <0.6825848, -167.3203558>,
    <0.3126757, -167.0913766>,
    <0.3148148, -167.1000319>,
    <0.3055555, -167.0957980>,
    <0.3055555, -167.0684463>,
    <0.3247768, -167.1012305>,
    <0.3095352, -167.0976177>,
    <0.3055555, -167.0829250>,
    <0.3172062, -167.0883180>,
    <0.3197041, -167.1006201>,
    <0.3229448, -167.1082279>,
    <0.3148148, -167.1000319>,
    <0.3247768, -167.1012305>,
    <0.3333333, -167.1158246>,
    <0.3188543, -167.1158246>,
    <0.3197041, -167.1006201>,
    <0.3298996, -167.1099681>,
    <0.3270721, -167.1158246>,
    <0.3169664, -167.1084437>,
    <0.3111950, -167.1068698>,
    <0.3148148, -167.1000319>,
    <0.3188543, -167.1158246>,
    <0.3055555, -167.1158246>,
    <0.3055555, -167.0957980>,
    <0.3169664, -167.1084437>,
    <0.3110389, -167.1158246>,
    <0.3055555, -167.1101184>,
    <0.3095352, -167.0976177>,
    <0.3150546, -167.0805905>,
    <0.3186211, -167.0842391>,
    <0.3247768, -167.1012305>,
    <0.3055555, -167.0684463>,
    <0.3112650, -167.0684463>,
    <0.3226563, -167.0953772>,
    <0.3172062, -167.0883180>,
    <0.3084103, -167.0684463>,
    <0.3142198, -167.0747897>,
    <0.3182744, -167.0791008>,
    <0.3186211, -167.0842391>,
    <0.3112650, -167.0684463>,
    <0.3169745, -167.0684463>,
    <0.3262367, -167.0952715>,
    <0.3142198, -167.0747897>,
    <0.3141198, -167.0684463>,
    <0.3214149, -167.0813064>,
    <0.3224480, -167.0897829>,
    <0.3257420, -167.0991414>,
    <0.3186211, -167.0842391>,
    <0.3262367, -167.0952715>,
    <0.3333333, -167.1158246>,
    <0.3247768, -167.1012305>,
    <0.3224480, -167.0897829>,
    <0.3305274, -167.1076981>,
    <0.3298996, -167.1099681>,
    <0.3226563, -167.0953772>,
    <0.3168951, -167.1383921>,
    <0.3240741, -167.1524837>,
    <0.3190964, -167.1694354>,
    <0.3055555, -167.1158246>,
    <0.3188543, -167.1158246>,
    <0.3212650, -167.1620503>,
    <0.3112692, -167.1384461>,
    <0.3110389, -167.1158246>,
    <0.3211148, -167.1317006>,
    <0.3273987, -167.1377829>,
    <0.3240741, -167.1524837>,
    <0.3188543, -167.1158246>,
    <0.3333333, -167.1158246>,
    <0.3333333, -167.1669985>,
    <0.3211148, -167.1317006>,
    <0.3270721, -167.1158246>,
    <0.3333333, -167.1357233>,
    <0.3292716, -167.1606313>,
    <0.3274593, -167.1786799>,
    <0.3240741, -167.1524837>,
    <0.3333333, -167.1669985>,
    <0.3333333, -167.2258020>,
    <0.3190964, -167.1694354>,
    <0.3292716, -167.1606313>,
    <0.3333333, -167.2000056>,
    <0.3270602, -167.2009655>,
    <0.3212650, -167.1620503>,
    <0.6723709, -167.1604534>,
    <0.6759259, -167.1891429>,
    <0.6666667, -167.1673444>,
    <0.6666667, -167.1158246>,
    <0.6802242, -167.1695015>,
    <0.6707193, -167.1768853>,
    <0.6666667, -167.1360443>,
    <0.6723953, -167.1385054>,
    <0.6783479, -167.1780754>,
    <0.6827905, -167.2025621>,
    <0.6759259, -167.1891429>,
    <0.6802242, -167.1695015>,
    <0.6944445, -167.2258020>,
    <0.6805673, -167.2258020>,
    <0.6783479, -167.1780754>,
    <0.6881807, -167.2010024>,
    <0.6883733, -167.2258020>,
    <0.6785299, -167.2097095>,
    <0.6724566, -167.2020228>,
    <0.6759259, -167.1891429>,
    <0.6805673, -167.2258020>,
    <0.6666667, -167.2258020>,
    <0.6666667, -167.1673444>,
    <0.6785299, -167.2097095>,
    <0.6727500, -167.2258020>,
    <0.6666667, -167.2001871>,
    <0.6707193, -167.1768853>,
    <0.6780165, -167.1384086>,
    <0.6851852, -167.1524837>,
    <0.6802242, -167.1695015>,
    <0.6666667, -167.1158246>,
    <0.6799898, -167.1158246>,
    <0.6823855, -167.1620875>,
    <0.6723953, -167.1385054>,
    <0.6721625, -167.1158246>,
    <0.6822410, -167.1317092>,
    <0.6885160, -167.1378830>,
    <0.6851852, -167.1524837>,
    <0.6799898, -167.1158246>,
    <0.6944445, -167.1158246>,
    <0.6944445, -167.1673989>,
    <0.6822410, -167.1317092>,
    <0.6881989, -167.1158246>,
    <0.6944445, -167.1360737>,
    <0.6903832, -167.1608569>,
    <0.6885746, -167.1787965>,
    <0.6851852, -167.1524837>,
    <0.6944445, -167.1673989>,
    <0.6944445, -167.2258020>,
    <0.6802242, -167.1695015>,
    <0.6903832, -167.1608569>,
    <0.6944445, -167.2002202>,
    <0.6881807, -167.2010024>,
    <0.6823855, -167.1620875>,
    <0.3114023, -167.1583892>,
    <0.3148148, -167.1778641>,
    <0.3196834, -167.1662209>,
    <0.3055555, -167.1287564>,
    <0.3055555, -167.1607154>,
    <0.3175621, -167.1712941>,
    <0.3118127, -167.1453492>,
    <0.3055555, -167.1413914>,
    <0.3096123, -167.1682288>,
    <0.3113455, -167.1858539>,
    <0.3148148, -167.1778641>,
    <0.3055555, -167.1607154>,
    <0.3055555, -167.2024179>,
    <0.3194562, -167.2024179>,
    <0.3096123, -167.1682288>,
    <0.3055555, -167.1838308>,
    <0.3116390, -167.2024179>,
    <0.3174351, -167.1917260>,
    <0.3218219, -167.1872302>,
    <0.3148148, -167.1778641>,
    <0.3194562, -167.2024179>,
    <0.3333333, -167.2024179>,
    <0.3196834, -167.1662209>,
    <0.3174351, -167.1917260>,
    <0.3272621, -167.2024179>,
    <0.3273929, -167.1866652>,
    <0.3175621, -167.1712941>,
    <0.3171214, -167.2232074>,
    <0.3240741, -167.2357456>,
    <0.3194562, -167.2024179>,
    <0.3055555, -167.2024179>,
    <0.3193997, -167.2522483>,
    <0.3214740, -167.2169804>,
    <0.3116390, -167.2024179>,
    <0.3116035, -167.2241867>,
    <0.3214418, -167.2450388>,
    <0.3275351, -167.2602946>,
    <0.3240741, -167.2357456>,
    <0.3193997, -167.2522483>,
    <0.3333333, -167.3024008>,
    <0.3333333, -167.2507837>,
    <0.3214418, -167.2450388>,
    <0.3272269, -167.2804214>,
    <0.3333333, -167.2798504>,
    <0.3292776, -167.2441968>,
    <0.3275492, -167.2228413>,
    <0.3240741, -167.2357456>,
    <0.3333333, -167.2507837>,
    <0.3333333, -167.2024179>,
    <0.3194562, -167.2024179>,
    <0.3292776, -167.2441968>,
    <0.3333333, -167.2235884>,
    <0.3272621, -167.2024179>,
    <0.3214740, -167.2169804>,
    <0.6724425, -167.2436308>,
    <0.6759259, -167.2690732>,
    <0.6805108, -167.2522483>,
    <0.6666667, -167.2024179>,
    <0.6666667, -167.2507837>,
    <0.6785063, -167.2596042>,
    <0.6727146, -167.2241867>,
    <0.6666667, -167.2235884>,
    <0.6707161, -167.2587824>,
    <0.6724564, -167.2811646>,
    <0.6759259, -167.2690732>,
    <0.6666667, -167.2507837>,
    <0.6666667, -167.3024008>,
    <0.6805662, -167.3024008>,
    <0.6707161, -167.2587824>,
    <0.6666667, -167.2798504>,
    <0.6727495, -167.3024008>,
    <0.6785377, -167.2878319>,
    <0.6828618, -167.2815307>,
    <0.6759259, -167.2690732>,
    <0.6805662, -167.3024008>,
    <0.6944445, -167.3024008>,
    <0.6805108, -167.2522483>,
    <0.6785377, -167.2878319>,
    <0.6883727, -167.3024008>,
    <0.6883380, -167.2804214>,
    <0.6785063, -167.2596042>,
    <0.6782325, -167.2232074>,
    <0.6851852, -167.2357456>,
    <0.6805674, -167.2024179>,
    <0.6666667, -167.2024179>,
    <0.6805108, -167.2522483>,
    <0.6825851, -167.2169804>,
    <0.6727501, -167.2024179>,
    <0.6727146, -167.2241867>,
    <0.6825529, -167.2450388>,
    <0.6886462, -167.2602946>,
    <0.6851852, -167.2357456>,
    <0.6805108, -167.2522483>,
    <0.6944445, -167.3024008>,
    <0.6944445, -167.2507837>,
    <0.6825529, -167.2450388>,
    <0.6883380, -167.2804214>,
    <0.6944445, -167.2798504>,
    <0.6903888, -167.2441968>,
    <0.6886604, -167.2228413>,
    <0.6851852, -167.2357456>,
    <0.6944445, -167.2507837>,
    <0.6944445, -167.2024179>,
    <0.6805674, -167.2024179>,
    <0.6903888, -167.2441968>,
    <0.6944445, -167.2235884>,
    <0.6883733, -167.2024179>,
    <0.6825851, -167.2169804>,
    <0.3240614, -167.0791008>,
    <0.3278804, -167.0842391>,
    <0.3262367, -167.0952715>,
    <0.3169745, -167.0684463>,
    <0.3251539, -167.0684463>,
    <0.3268946, -167.0908558>,
    <0.3214149, -167.0813064>,
    <0.3210642, -167.0684463>,
    <0.3263365, -167.0752960>,
    <0.3299252, -167.0791235>,
    <0.3278804, -167.0842391>,
    <0.3251539, -167.0684463>,
    <0.3333333, -167.0684463>,
    <0.3333333, -167.0953622>,
    <0.3263365, -167.0752960>,
    <0.3292436, -167.0684463>,
    <0.3333333, -167.0825210>,
    <0.3310170, -167.0906373>,
    <0.3301959, -167.0976743>,
    <0.3278804, -167.0842391>,
    <0.3333333, -167.0953622>,
    <0.3333333, -167.1158246>,
    <0.3262367, -167.0952715>,
    <0.3310170, -167.0906373>,
    <0.3333333, -167.1100226>,
    <0.3305274, -167.1076981>,
    <0.3268946, -167.0908558>,
    <0.6737702, -167.0910306>,
    <0.6759259, -167.1000319>,
    <0.6666667, -167.0945275>,
    <0.6666667, -167.0684463>,
    <0.6858213, -167.1011169>,
    <0.6706671, -167.0969057>,
    <0.6666667, -167.0815405>,
    <0.6782208, -167.0881533>,
    <0.6808014, -167.1005664>,
    <0.6840454, -167.1081995>,
    <0.6759259, -167.1000319>,
    <0.6858213, -167.1011169>,
    <0.6944445, -167.1158246>,
    <0.6799898, -167.1158246>,
    <0.6808014, -167.1005664>,
    <0.6909806, -167.1099166>,
    <0.6881989, -167.1158246>,
    <0.6780961, -167.1084655>,
    <0.6723123, -167.1065522>,
    <0.6759259, -167.1000319>,
    <0.6799898, -167.1158246>,
    <0.6666667, -167.1158246>,
    <0.6666667, -167.0945275>,
    <0.6780961, -167.1084655>,
    <0.6721625, -167.1158246>,
    <0.6666667, -167.1098632>,
    <0.6706671, -167.0969057>,
    <0.6762210, -167.0805621>,
    <0.6797323, -167.0842391>,
    <0.6858213, -167.1011169>,
    <0.6666667, -167.0684463>,
    <0.6726635, -167.0684463>,
    <0.6836717, -167.0951584>,
    <0.6782208, -167.0881533>,
    <0.6697042, -167.0684463>,
    <0.6755019, -167.0747878>,
    <0.6795789, -167.0794530>,
    <0.6797323, -167.0842391>,
    <0.6726635, -167.0684463>,
    <0.6780857, -167.0684463>,
    <0.6878343, -167.0966801>,
    <0.6755019, -167.0747878>,
    <0.6754714, -167.0684463>,
    <0.6830798, -167.0829104>,
    <0.6837969, -167.0904805>,
    <0.6869581, -167.0994652>,
    <0.6797323, -167.0842391>,
    <0.6878343, -167.0966801>,
    <0.6944445, -167.1158246>,
    <0.6858213, -167.1011169>,
    <0.6837969, -167.0904805>,
    <0.6918760, -167.1083857>,
    <0.6909806, -167.1099166>,
    <0.6836717, -167.0951584>,
    <0.3280471, -167.1106496>,
    <0.3269974, -167.1123151>,
    <0.3323312, -167.1220942>,
    <0.3296235, -167.1040945>,
    <0.3232365, -167.1040945>,
    <0.3295565, -167.1170071>,
    <0.3310831, -167.1137978>,
    <0.3261701, -167.1040945>,
    <0.3246245, -167.1071285>,
    <0.3244757, -167.1108241>,
    <0.3269974, -167.1123151>,
    <0.3232365, -167.1040945>,
    <0.3180354, -167.1040945>,
    <0.3296336, -167.1227921>,
    <0.3246245, -167.1071285>,
    <0.3205617, -167.1040945>,
    <0.3253189, -167.1158363>,
    <0.3286638, -167.1189380>,
    <0.3305739, -167.1214895>,
    <0.3269974, -167.1123151>,
    <0.3296336, -167.1227921>,
    <0.3333333, -167.1287564>,
    <0.3323312, -167.1220942>,
    <0.3286638, -167.1189380>,
    <0.3319839, -167.1265810>,
    <0.3330486, -167.1268637>,
    <0.3295565, -167.1170071>,
    <0.3187645, -167.1176324>,
    <0.3189748, -167.1205358>,
    <0.3296336, -167.1227921>,
    <0.3180354, -167.1040945>,
    <0.3084142, -167.1231073>,
    <0.3249529, -167.1218013>,
    <0.3253189, -167.1158363>,
    <0.3119076, -167.1162039>,
    <0.3132855, -167.1219211>,
    <0.3128548, -167.1252890>,
    <0.3189748, -167.1205358>,
    <0.3084142, -167.1231073>,
    <0.3055555, -167.1287564>,
    <0.3184748, -167.1287564>,
    <0.3132855, -167.1219211>,
    <0.3065936, -167.1267051>,
    <0.3108260, -167.1287564>,
    <0.3186527, -167.1258320>,
    <0.3251041, -167.1252102>,
    <0.3189748, -167.1205358>,
    <0.3184748, -167.1287564>,
    <0.3333333, -167.1287564>,
    <0.3296336, -167.1227921>,
    <0.3186527, -167.1258320>,
    <0.3268675, -167.1287564>,
    <0.3319839, -167.1265810>,
    <0.3249529, -167.1218013>,
    <0.3169470, -167.1442610>,
    <0.3240741, -167.1533103>,
    <0.3184748, -167.1287564>,
    <0.3055555, -167.1287564>,
    <0.3196834, -167.1662209>,
    <0.3212339, -167.1408553>,
    <0.3108260, -167.1287564>,
    <0.3118127, -167.1453492>,
    <0.3216618, -167.1604034>,
    <0.3276060, -167.1706661>,
    <0.3240741, -167.1533103>,
    <0.3196834, -167.1662209>,
    <0.3333333, -167.2024179>,
    <0.3333333, -167.1607154>,
    <0.3216618, -167.1604034>,
    <0.3273929, -167.1866652>,
    <0.3333333, -167.1838308>,
    <0.3293453, -167.1575260>,
    <0.3273039, -167.1428846>,
    <0.3240741, -167.1533103>,
    <0.3333333, -167.1607154>,
    <0.3333333, -167.1287564>,
    <0.3184748, -167.1287564>,
    <0.3293453, -167.1575260>,
    <0.3333333, -167.1413913>,
    <0.3268675, -167.1287564>,
    <0.3212339, -167.1408553>,
    <0.6739715, -167.1107626>,
    <0.6717789, -167.1123279>,
    <0.6698375, -167.1224954>,
    <0.6791466, -167.1041136>,
    <0.6751233, -167.1041136>,
    <0.6705304, -167.1188661>,
    <0.6735231, -167.1152176>,
    <0.6772708, -167.1041136>,
    <0.6739734, -167.1069379>,
    <0.6710274, -167.1101333>,
    <0.6717789, -167.1123279>,
    <0.6751233, -167.1041136>,
    <0.6695233, -167.1041136>,
    <0.6676842, -167.1199784>,
    <0.6739734, -167.1069379>,
    <0.6726106, -167.1041136>,
    <0.6685965, -167.1121091>,
    <0.6698391, -167.1159522>,
    <0.6689918, -167.1208895>,
    <0.6717789, -167.1123279>,
    <0.6676842, -167.1199784>,
    <0.6666667, -167.1287564>,
    <0.6698375, -167.1224954>,
    <0.6698391, -167.1159522>,
    <0.6670102, -167.1257934>,
    <0.6678233, -167.1264726>,
    <0.6705304, -167.1188661>,
    <0.6725368, -167.1582978>,
    <0.6759259, -167.1778641>,
    <0.6808878, -167.1664683>,
    <0.6666667, -167.1287564>,
    <0.6666667, -167.1601024>,
    <0.6787247, -167.1714363>,
    <0.6730245, -167.1456162>,
    <0.6666667, -167.1407348>,
    <0.6707224, -167.1678823>,
    <0.6724567, -167.1857006>,
    <0.6759259, -167.1778641>,
    <0.6666667, -167.1601024>,
    <0.6666667, -167.2024179>,
    <0.6805674, -167.2024179>,
    <0.6707224, -167.1678823>,
    <0.6666667, -167.1835237>,
    <0.6727501, -167.2024179>,
    <0.6785490, -167.1917403>,
    <0.6829564, -167.1872921>,
    <0.6759259, -167.1778641>,
    <0.6805674, -167.2024179>,
    <0.6944445, -167.2024179>,
    <0.6808878, -167.1664683>,
    <0.6785490, -167.1917403>,
    <0.6883733, -167.2024179>,
    <0.6885539, -167.1867974>,
    <0.6787247, -167.1714363>,
    <0.6800037, -167.1175675>,
    <0.6800859, -167.1205421>,
    <0.6909447, -167.1231187>,
    <0.6791466, -167.1041136>,
    <0.6698375, -167.1224954>,
    <0.6863676, -167.1220327>,
    <0.6868189, -167.1164727>,
    <0.6735231, -167.1152176>,
    <0.6747222, -167.1215644>,
    <0.6740892, -167.1251376>,
    <0.6800859, -167.1205421>,
    <0.6698375, -167.1224954>,
    <0.6666667, -167.1287564>,
    <0.6797668, -167.1287564>,
    <0.6747222, -167.1215644>,
    <0.6678233, -167.1264726>,
    <0.6720486, -167.1287564>,
    <0.6798725, -167.1260344>,
    <0.6863105, -167.1252934>,
    <0.6800859, -167.1205421>,
    <0.6797668, -167.1287564>,
    <0.6944445, -167.1287564>,
    <0.6909447, -167.1231187>,
    <0.6798725, -167.1260344>,
    <0.6881019, -167.1287564>,
    <0.6931689, -167.1267016>,
    <0.6863676, -167.1220327>,
    <0.6781266, -167.1443229>,
    <0.6851852, -167.1533103>,
    <0.6797668, -167.1287564>,
    <0.6666667, -167.1287564>,
    <0.6808878, -167.1664683>,
    <0.6824453, -167.1408941>,
    <0.6720486, -167.1287564>,
    <0.6730245, -167.1456162>,
    <0.6828259, -167.1605343>,
    <0.6887405, -167.1705747>,
    <0.6851852, -167.1533103>,
    <0.6808878, -167.1664683>,
    <0.6944445, -167.2024179>,
    <0.6944445, -167.1601024>,
    <0.6828259, -167.1605343>,
    <0.6885539, -167.1867974>,
    <0.6944445, -167.1835238>,
    <0.6904582, -167.1571783>,
    <0.6884602, -167.1427314>,
    <0.6851852, -167.1533103>,
    <0.6944445, -167.1601024>,
    <0.6944445, -167.1287564>,
    <0.6797668, -167.1287564>,
    <0.6904582, -167.1571783>,
    <0.6944445, -167.1407349>,
    <0.6881019, -167.1287564>,
    <0.6824453, -167.1408941>,
    <0.6683116, -167.1101299>,
    <0.6676189, -167.1123215>,
    <0.6676842, -167.1199784>,
    <0.6695233, -167.1041136>,
    <0.6684198, -167.1041062>,
    <0.6676596, -167.1170886>,
    <0.6685965, -167.1121091>,
    <0.6690449, -167.1041104>,
    <0.6680749, -167.1076438>,
    <0.6673430, -167.1098047>,
    <0.6676189, -167.1123215>,
    <0.6684198, -167.1041062>,
    <0.6666667, -167.1040945>,
    <0.6666667, -167.1186966>,
    <0.6680749, -167.1076438>,
    <0.6676033, -167.1041008>,
    <0.6666667, -167.1075969>,
    <0.6670158, -167.1163592>,
    <0.6671591, -167.1199382>,
    <0.6676189, -167.1123215>,
    <0.6666667, -167.1186966>,
    <0.6666667, -167.1287564>,
    <0.6676842, -167.1199784>,
    <0.6670158, -167.1163592>,
    <0.6666667, -167.1268390>,
    <0.6670102, -167.1257934>,
    <0.6676596, -167.1170886>,
    <0.3312856, -167.1106496>,
    <0.3320967, -167.1123151>,
    <0.3310912, -167.1040945>,
    <0.3296235, -167.1040945>,
    <0.3323311, -167.1220942>,
    <0.3315216, -167.1076129>,
    <0.3302663, -167.1040945>,
    <0.3310831, -167.1137978>,
    <0.3322479, -167.1186210>,
    <0.3327736, -167.1197229>,
    <0.3320967, -167.1123151>,
    <0.3323311, -167.1220942>,
    <0.3333333, -167.1287564>,
    <0.3333333, -167.1157259>,
    <0.3322479, -167.1186210>,
    <0.3330486, -167.1268637>,
    <0.3333333, -167.1243286>,
    <0.3328383, -167.1143606>,
    <0.3324637, -167.1090575>,
    <0.3320967, -167.1123151>,
    <0.3333333, -167.1157259>,
    <0.3333333, -167.1040945>,
    <0.3310912, -167.1040945>,
    <0.3328383, -167.1143606>,
    <0.3333333, -167.1077204>,
    <0.3321429, -167.1040945>,
    <0.3315216, -167.1076129>,
    <0.3397535, -167.1109029>,
    <0.3374932, -167.1123151>,
    <0.3361920, -167.1231073>,
    <0.3458130, -167.1040945>,
    <0.3395157, -167.1040945>,
    <0.3366928, -167.1189534>,
    <0.3396853, -167.1162039>,
    <0.3426423, -167.1040945>,
    <0.3388426, -167.1068303>,
    <0.3359189, -167.1090575>,
    <0.3374932, -167.1123151>,
    <0.3395157, -167.1040945>,
    <0.3333333, -167.1040945>,
    <0.3333333, -167.1157259>,
    <0.3388426, -167.1068303>,
    <0.3364174, -167.1040945>,
    <0.3333333, -167.1077204>,
    <0.3354335, -167.1140039>,
    <0.3350880, -167.1199762>,
    <0.3374932, -167.1123151>,
    <0.3333333, -167.1157259>,
    <0.3333333, -167.1287564>,
    <0.3361920, -167.1231073>,
    <0.3354335, -167.1140039>,
    <0.3333333, -167.1243286>,
    <0.3343713, -167.1267051>,
    <0.3366928, -167.1189534>,
    <0.6575985, -167.0794541>,
    <0.6612148, -167.0842391>,
    <0.6600594, -167.0966849>,
    <0.6503109, -167.0684463>,
    <0.6588090, -167.0684463>,
    <0.6605189, -167.0917353>,
    <0.6553051, -167.0829132>,
    <0.6546907, -167.0684463>,
    <0.6598554, -167.0753157>,
    <0.6633393, -167.0789148>,
    <0.6612148, -167.0842391>,
    <0.6588090, -167.0684463>,
    <0.6666667, -167.0684463>,
    <0.6666667, -167.0945275>,
    <0.6598554, -167.0753157>,
    <0.6627753, -167.0684463>,
    <0.6666667, -167.0815405>,
    <0.6643643, -167.0901826>,
    <0.6636519, -167.0978191>,
    <0.6612148, -167.0842391>,
    <0.6666667, -167.0945275>,
    <0.6666667, -167.1158246>,
    <0.6600594, -167.0966849>,
    <0.6643643, -167.0901826>,
    <0.6666667, -167.1098632>,
    <0.6640997, -167.1083889>,
    <0.6605189, -167.0917353>,
    <0.6588731, -167.1109046>,
    <0.6615673, -167.1123151>,
    <0.6593899, -167.1040945>,
    <0.6513686, -167.1040945>,
    <0.6631668, -167.1231143>,
    <0.6601703, -167.1070407>,
    <0.6555351, -167.1040945>,
    <0.6590410, -167.1164632>,
    <0.6625299, -167.1188144>,
    <0.6645169, -167.1207206>,
    <0.6615673, -167.1123151>,
    <0.6631668, -167.1231143>,
    <0.6666667, -167.1287564>,
    <0.6666667, -167.1186966>,
    <0.6625299, -167.1188144>,
    <0.6653911, -167.1267000>,
    <0.6666667, -167.1268390>,
    <0.6640750, -167.1154533>,
    <0.6635726, -167.1098002>,
    <0.6615673, -167.1123151>,
    <0.6666667, -167.1186966>,
    <0.6666667, -167.1040945>,
    <0.6593899, -167.1040945>,
    <0.6640750, -167.1154533>,
    <0.6666667, -167.1075969>,
    <0.6630710, -167.1040945>,
    <0.6601703, -167.1070407>,
    <0.3382389, -167.9429063>,
    <0.3425926, -168.0047729>,
    <0.3333333, -167.9407369>,
    <0.3333333, -167.8774261>,
    <0.3436963, -167.9486892>,
    <0.3375294, -167.9697568>,
    <0.3333333, -167.9044832>,
    <0.3377729, -167.9079557>,
    <0.3431929, -167.9742661>,
    <0.3486555, -168.0225887>,
    <0.3425926, -168.0047729>,
    <0.3436963, -167.9486892>,
    <0.3611111, -168.0684463>,
    <0.3472222, -168.0684463>,
    <0.3431929, -167.9742661>,
    <0.3512574, -168.0006850>,
    <0.3541667, -168.0684463>,
    <0.3453373, -168.0425216>,
    <0.3391204, -168.0206006>,
    <0.3425926, -168.0047729>,
    <0.3472222, -168.0684463>,
    <0.3333333, -168.0684463>,
    <0.3333333, -167.9407369>,
    <0.3453373, -168.0425216>,
    <0.3402778, -168.0684463>,
    <0.3333333, -167.9888196>,
    <0.3375294, -167.9697568>,
    <0.3391046, -167.7682155>,
    <0.3425926, -167.8156918>,
    <0.3333333, -167.7805425>,
    <0.3333333, -167.6922232>,
    <0.3471592, -167.7844046>,
    <0.3373799, -167.7959040>,
    <0.3333333, -167.7304472>,
    <0.3393717, -167.7324831>,
    <0.3451632, -167.7980796>,
    <0.3495246, -167.8387371>,
    <0.3425926, -167.8156918>,
    <0.3471592, -167.7844046>,
    <0.3611111, -167.8774261>,
    <0.3472353, -167.8774261>,
    <0.3451632, -167.7980796>,
    <0.3550532, -167.8370364>,
    <0.3551290, -167.8774261>,
    <0.3452266, -167.8507166>,
    <0.3391236, -167.8377716>,
    <0.3425926, -167.8156918>,
    <0.3472353, -167.8774261>,
    <0.3333333, -167.8774261>,
    <0.3333333, -167.7805425>,
    <0.3452266, -167.8507166>,
    <0.3392983, -167.8774261>,
    <0.3333333, -167.8352858>,
    <0.3373799, -167.7959040>,
    <0.3440292, -167.9111602>,
    <0.3518518, -167.9410995>,
    <0.3436963, -167.9486892>,
    <0.3333333, -167.8774261>,
    <0.3472353, -167.8774261>,
    <0.3469538, -167.9456577>,
    <0.3377729, -167.9079557>,
    <0.3392983, -167.8774261>,
    <0.3493878, -167.9071146>,
    <0.3553273, -167.9091557>,
    <0.3518518, -167.9410995>,
    <0.3472353, -167.8774261>,
    <0.3611111, -167.8774261>,
    <0.3611111, -167.9406711>,
    <0.3493878, -167.9071146>,
    <0.3551290, -167.8774261>,
    <0.3611111, -167.9044451>,
    <0.3572245, -167.9408509>,
    <0.3544426, -167.9747265>,
    <0.3518518, -167.9410995>,
    <0.3611111, -167.9406711>,
    <0.3611111, -168.0684463>,
    <0.3436963, -167.9486892>,
    <0.3572245, -167.9408509>,
    <0.3611111, -167.9887449>,
    <0.3512574, -168.0006850>,
    <0.3469538, -167.9456577>,
    <0.6437919, -167.9427445>,
    <0.6481482, -168.0047729>,
    <0.6388889, -167.9401608>,
    <0.6388889, -167.8774261>,
    <0.6492415, -167.9486183>,
    <0.6430850, -167.9694415>,
    <0.6388889, -167.9042186>,
    <0.6433215, -167.9079076>,
    <0.6487429, -167.9742255>,
    <0.6542085, -168.0225709>,
    <0.6481482, -168.0047729>,
    <0.6492415, -167.9486183>,
    <0.6666667, -168.0684463>,
    <0.6527778, -168.0684463>,
    <0.6487429, -167.9742255>,
    <0.6568073, -168.0006463>,
    <0.6597222, -168.0684463>,
    <0.6508925, -168.0425174>,
    <0.6446759, -168.0204566>,
    <0.6481482, -168.0047729>,
    <0.6527778, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6388889, -167.9401608>,
    <0.6508925, -168.0425174>,
    <0.6458333, -168.0684463>,
    <0.6388889, -167.9885987>,
    <0.6430850, -167.9694415>,
    <0.6495836, -167.9111425>,
    <0.6574074, -167.9410995>,
    <0.6492415, -167.9486183>,
    <0.6388889, -167.8774261>,
    <0.6527967, -167.8774261>,
    <0.6525038, -167.9456145>,
    <0.6433215, -167.9079076>,
    <0.6448571, -167.8774261>,
    <0.6549425, -167.9070597>,
    <0.6608844, -167.9090294>,
    <0.6574074, -167.9410995>,
    <0.6527967, -167.8774261>,
    <0.6666667, -167.8774261>,
    <0.6666667, -167.9401659>,
    <0.6549425, -167.9070597>,
    <0.6606877, -167.8774261>,
    <0.6666667, -167.9042299>,
    <0.6627789, -167.9405579>,
    <0.6599956, -167.9745825>,
    <0.6574074, -167.9410995>,
    <0.6666667, -167.9401659>,
    <0.6666667, -168.0684463>,
    <0.6492415, -167.9486183>,
    <0.6627789, -167.9405579>,
    <0.6666667, -167.9886588>,
    <0.6568073, -168.0006463>,
    <0.6525038, -167.9456145>,
    <0.3391143, -167.5906989>,
    <0.3425926, -167.6342972>,
    <0.3333333, -167.6048705>,
    <0.3333333, -167.5184453>,
    <0.3471979, -167.6051824>,
    <0.3373842, -167.6177446>,
    <0.3333333, -167.5563664>,
    <0.3393945, -167.5563642>,
    <0.3451848, -167.6179095>,
    <0.3495323, -167.6559815>,
    <0.3425926, -167.6342972>,
    <0.3471979, -167.6051824>,
    <0.3611111, -167.6922232>,
    <0.3472276, -167.6922232>,
    <0.3451848, -167.6179095>,
    <0.3550183, -167.6541068>,
    <0.3550368, -167.6922232>,
    <0.3452020, -167.6669079>,
    <0.3391217, -167.6559035>,
    <0.3425926, -167.6342972>,
    <0.3472276, -167.6922232>,
    <0.3333333, -167.6922232>,
    <0.3333333, -167.6048705>,
    <0.3452020, -167.6669079>,
    <0.3394133, -167.6922232>,
    <0.3333333, -167.6541051>,
    <0.3373842, -167.6177446>,
    <0.3448930, -167.7307021>,
    <0.3518518, -167.7539575>,
    <0.3471592, -167.7844046>,
    <0.3333333, -167.6922232>,
    <0.3472276, -167.6922232>,
    <0.3492096, -167.7711010>,
    <0.3393717, -167.7324831>,
    <0.3394133, -167.6922232>,
    <0.3492470, -167.7191820>,
    <0.3553254, -167.7297323>,
    <0.3518518, -167.7539575>,
    <0.3472276, -167.6922232>,
    <0.3611111, -167.6922232>,
    <0.3611111, -167.7805253>,
    <0.3492470, -167.7191820>,
    <0.3550368, -167.6922232>,
    <0.3611111, -167.7304384>,
    <0.3570570, -167.7688928>,
    <0.3553083, -167.7990784>,
    <0.3518518, -167.7539575>,
    <0.3611111, -167.7805253>,
    <0.3611111, -167.8774261>,
    <0.3471592, -167.7844046>,
    <0.3570570, -167.7688928>,
    <0.3611111, -167.8352614>,
    <0.3550532, -167.8370364>,
    <0.3492096, -167.7711010>,
    <0.6446575, -167.7681730>,
    <0.6481482, -167.8156918>,
    <0.6388889, -167.7804425>,
    <0.6388889, -167.6922232>,
    <0.6527042, -167.7843343>,
    <0.6429343, -167.7958431>,
    <0.6388889, -167.7303956>,
    <0.6449214, -167.7324440>,
    <0.6507118, -167.7980473>,
    <0.6550789, -167.8387195>,
    <0.6481482, -167.8156918>,
    <0.6527042, -167.7843343>,
    <0.6666667, -167.8774261>,
    <0.6527967, -167.8774261>,
    <0.6507118, -167.7980473>,
    <0.6605989, -167.8369704>,
    <0.6606877, -167.8774261>,
    <0.6507817, -167.8506671>,
    <0.6446807, -167.8377466>,
    <0.6481482, -167.8156918>,
    <0.6527967, -167.8774261>,
    <0.6388889, -167.8774261>,
    <0.6388889, -167.7804425>,
    <0.6507817, -167.8506671>,
    <0.6448571, -167.8774261>,
    <0.6388889, -167.8351104>,
    <0.6429343, -167.7958431>,
    <0.6504459, -167.7306846>,
    <0.6574074, -167.7539575>,
    <0.6527042, -167.7843343>,
    <0.6388889, -167.6922232>,
    <0.6527832, -167.6922232>,
    <0.6547592, -167.7710617>,
    <0.6449214, -167.7324440>,
    <0.6449689, -167.6922232>,
    <0.6548023, -167.7191781>,
    <0.6608810, -167.7297132>,
    <0.6574074, -167.7539575>,
    <0.6527832, -167.6922232>,
    <0.6666667, -167.6922232>,
    <0.6666667, -167.7804489>,
    <0.6548023, -167.7191781>,
    <0.6605923, -167.6922232>,
    <0.6666667, -167.7303988>,
    <0.6626125, -167.7688497>,
    <0.6608613, -167.7990417>,
    <0.6574074, -167.7539575>,
    <0.6666667, -167.7804489>,
    <0.6666667, -167.8774261>,
    <0.6527042, -167.7843343>,
    <0.6626125, -167.7688497>,
    <0.6666667, -167.8351153>,
    <0.6605989, -167.8369704>,
    <0.6547592, -167.7710617>,
    <0.3382397, -167.9543114>,
    <0.3425926, -168.0105648>,
    <0.3436994, -167.9596023>,
    <0.3333333, -167.8948019>,
    <0.3333333, -167.9522766>,
    <0.3431946, -167.9828447>,
    <0.3377753, -167.9225697>,
    <0.3333333, -167.9195067>,
    <0.3375295, -167.9786921>,
    <0.3391204, -168.0249335>,
    <0.3425926, -168.0105648>,
    <0.3333333, -167.9522766>,
    <0.3333333, -168.0684463>,
    <0.3472222, -168.0684463>,
    <0.3375295, -167.9786921>,
    <0.3333333, -167.9957398>,
    <0.3402778, -168.0684463>,
    <0.3453376, -168.0448836>,
    <0.3486563, -168.0267649>,
    <0.3425926, -168.0105648>,
    <0.3472222, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3436994, -167.9596023>,
    <0.3453376, -168.0448836>,
    <0.3541667, -168.0684463>,
    <0.3512604, -168.0068676>,
    <0.3431946, -167.9828447>,
    <0.3391055, -167.7954347>,
    <0.3425926, -167.8386752>,
    <0.3471627, -167.8102511>,
    <0.3333333, -167.7264218>,
    <0.3333333, -167.8063904>,
    <0.3451649, -167.8226765>,
    <0.3393738, -167.7630372>,
    <0.3333333, -167.7609868>,
    <0.3373802, -167.8205007>,
    <0.3391236, -167.8586674>,
    <0.3425926, -167.8386752>,
    <0.3333333, -167.8063904>,
    <0.3333333, -167.8948019>,
    <0.3472351, -167.8948019>,
    <0.3373802, -167.8205007>,
    <0.3333333, -167.8565241>,
    <0.3392982, -167.8948019>,
    <0.3452282, -167.8705390>,
    <0.3495254, -167.8596326>,
    <0.3425926, -167.8386752>,
    <0.3472351, -167.8948019>,
    <0.3611111, -167.8948019>,
    <0.3471627, -167.8102511>,
    <0.3452282, -167.8705390>,
    <0.3551288, -167.8948019>,
    <0.3550558, -167.8580966>,
    <0.3451649, -167.8226765>,
    <0.3440299, -167.9254724>,
    <0.3518518, -167.9526834>,
    <0.3472351, -167.8948019>,
    <0.3333333, -167.8948019>,
    <0.3436994, -167.9596023>,
    <0.3493898, -167.9218167>,
    <0.3392982, -167.8948019>,
    <0.3377753, -167.9225697>,
    <0.3469523, -167.9568416>,
    <0.3544434, -167.9832362>,
    <0.3518518, -167.9526834>,
    <0.3436994, -167.9596023>,
    <0.3611111, -168.0684463>,
    <0.3611111, -167.9522128>,
    <0.3469523, -167.9568416>,
    <0.3512604, -168.0068676>,
    <0.3611111, -167.9956646>,
    <0.3572250, -167.9524103>,
    <0.3553273, -167.9236250>,
    <0.3518518, -167.9526834>,
    <0.3611111, -167.9522128>,
    <0.3611111, -167.8948019>,
    <0.3472351, -167.8948019>,
    <0.3572250, -167.9524103>,
    <0.3611111, -167.9194706>,
    <0.3551288, -167.8948019>,
    <0.3493898, -167.9218167>,
    <0.6437927, -167.9541554>,
    <0.6481482, -168.0105648>,
    <0.6492448, -167.9595385>,
    <0.6388889, -167.8948019>,
    <0.6388889, -167.9517162>,
    <0.6487447, -167.9828081>,
    <0.6433240, -167.9225265>,
    <0.6388889, -167.9192541>,
    <0.6430850, -167.9783854>,
    <0.6446759, -168.0247934>,
    <0.6481482, -168.0105648>,
    <0.6388889, -167.9517162>,
    <0.6388889, -168.0684463>,
    <0.6527778, -168.0684463>,
    <0.6430850, -167.9783854>,
    <0.6388889, -167.9955084>,
    <0.6458333, -168.0684463>,
    <0.6508928, -168.0448799>,
    <0.6542093, -168.0267490>,
    <0.6481482, -168.0105648>,
    <0.6527778, -168.0684463>,
    <0.6666667, -168.0684463>,
    <0.6492448, -167.9595385>,
    <0.6508928, -168.0448799>,
    <0.6597222, -168.0684463>,
    <0.6568104, -168.0068329>,
    <0.6487447, -167.9828081>,
    <0.6495844, -167.9254564>,
    <0.6574074, -167.9526834>,
    <0.6527964, -167.8948019>,
    <0.6388889, -167.8948019>,
    <0.6492448, -167.9595385>,
    <0.6549445, -167.9217672>,
    <0.6448569, -167.8948019>,
    <0.6433240, -167.9225265>,
    <0.6525024, -167.9568027>,
    <0.6599964, -167.9830973>,
    <0.6574074, -167.9526834>,
    <0.6492448, -167.9595385>,
    <0.6666667, -168.0684463>,
    <0.6666667, -167.9517210>,
    <0.6525024, -167.9568027>,
    <0.6568104, -168.0068329>,
    <0.6666667, -167.9955681>,
    <0.6627794, -167.9521250>,
    <0.6608843, -167.9235021>,
    <0.6574074, -167.9526834>,
    <0.6666667, -167.9517210>,
    <0.6666667, -167.8948019>,
    <0.6527964, -167.8948019>,
    <0.6627794, -167.9521250>,
    <0.6666667, -167.9192648>,
    <0.6606876, -167.8948019>,
    <0.6549445, -167.9217672>,
    <0.3391120, -167.4265843>,
    <0.3425926, -167.4660888>,
    <0.3333333, -167.4391507>,
    <0.3333333, -167.3613758>,
    <0.3471889, -167.4397221>,
    <0.3373836, -167.4509341>,
    <0.3333333, -167.3955180>,
    <0.3393886, -167.3956156>,
    <0.3451795, -167.4512490>,
    <0.3495307, -167.4856754>,
    <0.3425926, -167.4660888>,
    <0.3471889, -167.4397221>,
    <0.3611111, -167.5184453>,
    <0.3472301, -167.5184453>,
    <0.3451795, -167.4512490>,
    <0.3550124, -167.4839601>,
    <0.3550380, -167.5184453>,
    <0.3452034, -167.4955641>,
    <0.3391223, -167.4855325>,
    <0.3425926, -167.4660888>,
    <0.3472301, -167.5184453>,
    <0.3333333, -167.5184453>,
    <0.3333333, -167.4391507>,
    <0.3452034, -167.4955641>,
    <0.3394146, -167.5184453>,
    <0.3333333, -167.4838674>,
    <0.3373836, -167.4509341>,
    <0.3449033, -167.5546111>,
    <0.3518518, -167.5763713>,
    <0.3471979, -167.6051824>,
    <0.3333333, -167.5184453>,
    <0.3472301, -167.5184453>,
    <0.3492312, -167.5925951>,
    <0.3393945, -167.5563642>,
    <0.3394146, -167.5184453>,
    <0.3492505, -167.5437683>,
    <0.3553260, -167.5545331>,
    <0.3518518, -167.5763713>,
    <0.3472301, -167.5184453>,
    <0.3611111, -167.5184453>,
    <0.3611111, -167.6048705>,
    <0.3492505, -167.5437683>,
    <0.3550380, -167.5184453>,
    <0.3611111, -167.5563664>,
    <0.3570566, -167.5923911>,
    <0.3553180, -167.6196618>,
    <0.3518518, -167.5763713>,
    <0.3611111, -167.6048705>,
    <0.3611111, -167.6922232>,
    <0.3471979, -167.6051824>,
    <0.3570566, -167.5923911>,
    <0.3611111, -167.6541051>,
    <0.3550183, -167.6541068>,
    <0.3492312, -167.5925951>,
    <0.6446699, -167.5906989>,
    <0.6481482, -167.6342972>,
    <0.6388889, -167.6048705>,
    <0.6388889, -167.5184453>,
    <0.6527535, -167.6051824>,
    <0.6429398, -167.6177446>,
    <0.6388889, -167.5563664>,
    <0.6449501, -167.5563642>,
    <0.6507403, -167.6179095>,
    <0.6550879, -167.6559815>,
    <0.6481482, -167.6342972>,
    <0.6527535, -167.6051824>,
    <0.6666667, -167.6922232>,
    <0.6527832, -167.6922232>,
    <0.6507403, -167.6179095>,
    <0.6605739, -167.6541068>,
    <0.6605923, -167.6922232>,
    <0.6507575, -167.6669079>,
    <0.6446773, -167.6559035>,
    <0.6481482, -167.6342972>,
    <0.6527832, -167.6922232>,
    <0.6388889, -167.6922232>,
    <0.6388889, -167.6048705>,
    <0.6507575, -167.6669079>,
    <0.6449689, -167.6922232>,
    <0.6388889, -167.6541051>,
    <0.6429398, -167.6177446>,
    <0.6504589, -167.5546111>,
    <0.6574074, -167.5763713>,
    <0.6527535, -167.6051824>,
    <0.6388889, -167.5184453>,
    <0.6527856, -167.5184453>,
    <0.6547868, -167.5925951>,
    <0.6449501, -167.5563642>,
    <0.6449702, -167.5184453>,
    <0.6548061, -167.5437683>,
    <0.6608816, -167.5545331>,
    <0.6574074, -167.5763713>,
    <0.6527856, -167.5184453>,
    <0.6666667, -167.5184453>,
    <0.6666667, -167.6048705>,
    <0.6548061, -167.5437683>,
    <0.6605936, -167.5184453>,
    <0.6666667, -167.5563664>,
    <0.6626122, -167.5923911>,
    <0.6608736, -167.6196618>,
    <0.6574074, -167.5763713>,
    <0.6666667, -167.6048705>,
    <0.6666667, -167.6922232>,
    <0.6527535, -167.6051824>,
    <0.6626122, -167.5923911>,
    <0.6666667, -167.6541051>,
    <0.6605739, -167.6541068>,
    <0.6547868, -167.5925951>,
    <0.3391148, -167.6341061>,
    <0.3425926, -167.6737665>,
    <0.3471999, -167.6473117>,
    <0.3333333, -167.5684558>,
    <0.3333333, -167.6468904>,
    <0.3451859, -167.6588757>,
    <0.3393958, -167.6029317>,
    <0.3333333, -167.6028579>,
    <0.3373844, -167.6586490>,
    <0.3391216, -167.6933751>,
    <0.3425926, -167.6737665>,
    <0.3333333, -167.6468904>,
    <0.3333333, -167.7264218>,
    <0.3472271, -167.7264218>,
    <0.3373844, -167.6586490>,
    <0.3333333, -167.6917086>,
    <0.3394130, -167.7264218>,
    <0.3452016, -167.7034090>,
    <0.3495327, -167.6934805>,
    <0.3425926, -167.6737665>,
    <0.3472271, -167.7264218>,
    <0.3611111, -167.7264218>,
    <0.3471999, -167.6473117>,
    <0.3452016, -167.7034090>,
    <0.3550365, -167.7264218>,
    <0.3550195, -167.6917804>,
    <0.3451859, -167.6588757>,
    <0.3448937, -167.7614108>,
    <0.3518518, -167.7825485>,
    <0.3472271, -167.7264218>,
    <0.3333333, -167.7264218>,
    <0.3471627, -167.8102511>,
    <0.3492466, -167.7509311>,
    <0.3394130, -167.7264218>,
    <0.3393738, -167.7630372>,
    <0.3492116, -167.7981464>,
    <0.3553092, -167.8234934>,
    <0.3518518, -167.7825485>,
    <0.3471627, -167.8102511>,
    <0.3611111, -167.8948019>,
    <0.3611111, -167.8063719>,
    <0.3492116, -167.7981464>,
    <0.3550558, -167.8580966>,
    <0.3611111, -167.8564978>,
    <0.3570572, -167.7959414>,
    <0.3553253, -167.7604410>,
    <0.3518518, -167.7825485>,
    <0.3611111, -167.8063719>,
    <0.3611111, -167.7264218>,
    <0.3472271, -167.7264218>,
    <0.3570572, -167.7959414>,
    <0.3611111, -167.7609773>,
    <0.3550365, -167.7264218>,
    <0.3492466, -167.7509311>,
    <0.6446584, -167.7953920>,
    <0.6481482, -167.8386752>,
    <0.6527078, -167.8101876>,
    <0.6388889, -167.7264218>,
    <0.6388889, -167.8062834>,
    <0.6507135, -167.8226473>,
    <0.6449235, -167.7630018>,
    <0.6388889, -167.7609320>,
    <0.6429345, -167.8204364>,
    <0.6446806, -167.8586406>,
    <0.6481482, -167.8386752>,
    <0.6388889, -167.8062834>,
    <0.6388889, -167.8948019>,
    <0.6527964, -167.8948019>,
    <0.6429345, -167.8204364>,
    <0.6388889, -167.8563347>,
    <0.6448569, -167.8948019>,
    <0.6507833, -167.8704939>,
    <0.6550797, -167.8596167>,
    <0.6481482, -167.8386752>,
    <0.6527964, -167.8948019>,
    <0.6666667, -167.8948019>,
    <0.6527078, -167.8101876>,
    <0.6507833, -167.8704939>,
    <0.6606876, -167.8948019>,
    <0.6606015, -167.8580370>,
    <0.6507135, -167.8226473>,
    <0.6504467, -167.7613949>,
    <0.6574074, -167.7825485>,
    <0.6527827, -167.7264218>,
    <0.6388889, -167.7264218>,
    <0.6527078, -167.8101876>,
    <0.6548019, -167.7509275>,
    <0.6449686, -167.7264218>,
    <0.6449235, -167.7630018>,
    <0.6547613, -167.7981109>,
    <0.6608621, -167.8234571>,
    <0.6574074, -167.7825485>,
    <0.6527078, -167.8101876>,
    <0.6666667, -167.8948019>,
    <0.6666667, -167.8062904>,
    <0.6547613, -167.7981109>,
    <0.6606015, -167.8580370>,
    <0.6666667, -167.8563399>,
    <0.6626127, -167.7958954>,
    <0.6608809, -167.7604206>,
    <0.6574074, -167.7825485>,
    <0.6666667, -167.8062904>,
    <0.6666667, -167.7264218>,
    <0.6527827, -167.7264218>,
    <0.6626127, -167.7958954>,
    <0.6666667, -167.7609355>,
    <0.6605920, -167.7264218>,
    <0.6548019, -167.7509275>,
    <0.3391127, -167.4848985>,
    <0.3425926, -167.5208549>,
    <0.3471916, -167.4968970>,
    <0.3333333, -167.4256532>,
    <0.3333333, -167.4961891>,
    <0.3451811, -167.5073705>,
    <0.3393904, -167.4567920>,
    <0.3333333, -167.4566011>,
    <0.3373838, -167.5069791>,
    <0.3391221, -167.5384889>,
    <0.3425926, -167.5208549>,
    <0.3333333, -167.4961891>,
    <0.3333333, -167.5684558>,
    <0.3472293, -167.5684558>,
    <0.3373838, -167.5069791>,
    <0.3333333, -167.5369298>,
    <0.3394142, -167.5684558>,
    <0.3452028, -167.5476517>,
    <0.3495311, -167.5386659>,
    <0.3425926, -167.5208549>,
    <0.3472293, -167.5684558>,
    <0.3611111, -167.5684558>,
    <0.3471916, -167.4968970>,
    <0.3452028, -167.5476517>,
    <0.3550376, -167.5684558>,
    <0.3550141, -167.5371117>,
    <0.3451811, -167.5073705>,
    <0.3449036, -167.6013336>,
    <0.3518518, -167.6211112>,
    <0.3472293, -167.5684558>,
    <0.3333333, -167.5684558>,
    <0.3471999, -167.6473117>,
    <0.3492499, -167.5914725>,
    <0.3394142, -167.5684558>,
    <0.3393958, -167.6029317>,
    <0.3492324, -167.6358644>,
    <0.3553185, -167.6604338>,
    <0.3518518, -167.6211112>,
    <0.3471999, -167.6473117>,
    <0.3611111, -167.7264218>,
    <0.3611111, -167.6468904>,
    <0.3492324, -167.6358644>,
    <0.3550195, -167.6917804>,
    <0.3611111, -167.6917086>,
    <0.3570568, -167.6356026>,
    <0.3553258, -167.6012283>,
    <0.3518518, -167.6211112>,
    <0.3611111, -167.6468904>,
    <0.3611111, -167.5684558>,
    <0.3472293, -167.5684558>,
    <0.3570568, -167.6356026>,
    <0.3611111, -167.6028579>,
    <0.3550376, -167.5684558>,
    <0.3492499, -167.5914725>,
    <0.6446703, -167.6341061>,
    <0.6481482, -167.6737665>,
    <0.6527554, -167.6473117>,
    <0.6388889, -167.5684558>,
    <0.6388889, -167.6468904>,
    <0.6507415, -167.6588757>,
    <0.6449514, -167.6029317>,
    <0.6388889, -167.6028579>,
    <0.6429399, -167.6586490>,
    <0.6446772, -167.6933751>,
    <0.6481482, -167.6737665>,
    <0.6388889, -167.6468904>,
    <0.6388889, -167.7264218>,
    <0.6527827, -167.7264218>,
    <0.6429399, -167.6586490>,
    <0.6388889, -167.6917086>,
    <0.6449686, -167.7264218>,
    <0.6507572, -167.7034090>,
    <0.6550882, -167.6934805>,
    <0.6481482, -167.6737665>,
    <0.6527827, -167.7264218>,
    <0.6666667, -167.7264218>,
    <0.6527554, -167.6473117>,
    <0.6507572, -167.7034090>,
    <0.6605920, -167.7264218>,
    <0.6605751, -167.6917804>,
    <0.6507415, -167.6588757>,
    <0.6504592, -167.6013336>,
    <0.6574074, -167.6211112>,
    <0.6527849, -167.5684558>,
    <0.6388889, -167.5684558>,
    <0.6527554, -167.6473117>,
    <0.6548055, -167.5914725>,
    <0.6449698, -167.5684558>,
    <0.6449514, -167.6029317>,
    <0.6547879, -167.6358644>,
    <0.6608740, -167.6604338>,
    <0.6574074, -167.6211112>,
    <0.6527554, -167.6473117>,
    <0.6666667, -167.7264218>,
    <0.6666667, -167.6468904>,
    <0.6547879, -167.6358644>,
    <0.6605751, -167.6917804>,
    <0.6666667, -167.6917086>,
    <0.6626124, -167.6356026>,
    <0.6608814, -167.6012283>,
    <0.6574074, -167.6211112>,
    <0.6666667, -167.6468904>,
    <0.6666667, -167.5684558>,
    <0.6527849, -167.5684558>,
    <0.6626124, -167.6356026>,
    <0.6666667, -167.6028580>,
    <0.6605931, -167.5684558>,
    <0.6548055, -167.5914725>,
    <0.3391100, -167.2819570>,
    <0.3425926, -167.3161845>,
    <0.3333333, -167.2924560>,
    <0.3333333, -167.2258020>,
    <0.3471806, -167.2933857>,
    <0.3373830, -167.3028339>,
    <0.3333333, -167.2550533>,
    <0.3393833, -167.2553296>,
    <0.3451747, -167.3033535>,
    <0.3495291, -167.3330804>,
    <0.3425926, -167.3161845>,
    <0.3471806, -167.2933857>,
    <0.3611111, -167.3613758>,
    <0.3472322, -167.3613758>,
    <0.3451747, -167.3033535>,
    <0.3550069, -167.3315832>,
    <0.3550391, -167.3613758>,
    <0.3452044, -167.3416247>,
    <0.3391229, -167.3328480>,
    <0.3425926, -167.3161845>,
    <0.3472322, -167.3613758>,
    <0.3333333, -167.3613758>,
    <0.3333333, -167.2924560>,
    <0.3452044, -167.3416247>,
    <0.3394157, -167.3613758>,
    <0.3333333, -167.3313235>,
    <0.3373830, -167.3028339>,
    <0.3449016, -167.3940515>,
    <0.3518518, -167.4137323>,
    <0.3471889, -167.4397221>,
    <0.3333333, -167.3613758>,
    <0.3472322, -167.3613758>,
    <0.3492260, -167.4283682>,
    <0.3393886, -167.3956156>,
    <0.3394157, -167.3613758>,
    <0.3492516, -167.3842624>,
    <0.3553266, -167.3939086>,
    <0.3518518, -167.4137323>,
    <0.3472322, -167.3613758>,
    <0.3611111, -167.3613758>,
    <0.3611111, -167.4391506>,
    <0.3492516, -167.3842624>,
    <0.3550391, -167.3613758>,
    <0.3611111, -167.3955180>,
    <0.3570560, -167.4280187>,
    <0.3553157, -167.4527626>,
    <0.3518518, -167.4137323>,
    <0.3611111, -167.4391506>,
    <0.3611111, -167.5184453>,
    <0.3471889, -167.4397221>,
    <0.3570560, -167.4280187>,
    <0.3611111, -167.4838674>,
    <0.3550124, -167.4839601>,
    <0.3492260, -167.4283682>,
    <0.6446676, -167.4265843>,
    <0.6481482, -167.4660888>,
    <0.6388889, -167.4391507>,
    <0.6388889, -167.3613758>,
    <0.6527445, -167.4397221>,
    <0.6429391, -167.4509341>,
    <0.6388889, -167.3955180>,
    <0.6449442, -167.3956156>,
    <0.6507351, -167.4512490>,
    <0.6550862, -167.4856754>,
    <0.6481482, -167.4660888>,
    <0.6527445, -167.4397221>,
    <0.6666667, -167.5184453>,
    <0.6527856, -167.5184453>,
    <0.6507351, -167.4512490>,
    <0.6605680, -167.4839601>,
    <0.6605936, -167.5184453>,
    <0.6507589, -167.4955641>,
    <0.6446779, -167.4855325>,
    <0.6481482, -167.4660888>,
    <0.6527856, -167.5184453>,
    <0.6388889, -167.5184453>,
    <0.6388889, -167.4391507>,
    <0.6507589, -167.4955641>,
    <0.6449702, -167.5184453>,
    <0.6388889, -167.4838674>,
    <0.6429391, -167.4509341>,
    <0.6504571, -167.3940515>,
    <0.6574074, -167.4137323>,
    <0.6527445, -167.4397221>,
    <0.6388889, -167.3613758>,
    <0.6527878, -167.3613758>,
    <0.6547815, -167.4283682>,
    <0.6449442, -167.3956156>,
    <0.6449713, -167.3613758>,
    <0.6548072, -167.3842624>,
    <0.6608821, -167.3939086>,
    <0.6574074, -167.4137323>,
    <0.6527878, -167.3613758>,
    <0.6666667, -167.3613758>,
    <0.6666667, -167.4391507>,
    <0.6548072, -167.3842624>,
    <0.6605946, -167.3613758>,
    <0.6666667, -167.3955180>,
    <0.6626116, -167.4280187>,
    <0.6608713, -167.4527626>,
    <0.6574074, -167.4137323>,
    <0.6666667, -167.4391507>,
    <0.6666667, -167.5184453>,
    <0.6527445, -167.4397221>,
    <0.6626116, -167.4280187>,
    <0.6666667, -167.4838674>,
    <0.6605680, -167.4839601>,
    <0.6547815, -167.4283682>,
    <0.3391108, -167.3534027>,
    <0.3425926, -167.3845690>,
    <0.3471840, -167.3638575>,
    <0.3333333, -167.3024008>,
    <0.3333333, -167.3627833>,
    <0.3451767, -167.3729124>,
    <0.3393855, -167.3292549>,
    <0.3333333, -167.3288803>,
    <0.3373832, -167.3723121>,
    <0.3391226, -167.3996647>,
    <0.3425926, -167.3845690>,
    <0.3333333, -167.3627833>,
    <0.3333333, -167.4256532>,
    <0.3472312, -167.4256532>,
    <0.3373832, -167.3723121>,
    <0.3333333, -167.3982231>,
    <0.3394152, -167.4256532>,
    <0.3452038, -167.4076960>,
    <0.3495297, -167.3999332>,
    <0.3425926, -167.3845690>,
    <0.3472312, -167.4256532>,
    <0.3611111, -167.4256532>,
    <0.3471840, -167.3638575>,
    <0.3452038, -167.4076960>,
    <0.3550385, -167.4256532>,
    <0.3550091, -167.3985780>,
    <0.3451767, -167.3729124>,
    <0.3449020, -167.4553644>,
    <0.3518518, -167.4732541>,
    <0.3472312, -167.4256532>,
    <0.3333333, -167.4256532>,
    <0.3471916, -167.4968970>,
    <0.3492508, -167.4464590>,
    <0.3394152, -167.4256532>,
    <0.3393904, -167.4567920>,
    <0.3492276, -167.4865678>,
    <0.3553164, -167.5086990>,
    <0.3518518, -167.4732541>,
    <0.3471916, -167.4968970>,
    <0.3611111, -167.5684558>,
    <0.3611111, -167.4961890>,
    <0.3492276, -167.4865678>,
    <0.3550141, -167.5371117>,
    <0.3611111, -167.5369298>,
    <0.3570563, -167.4861453>,
    <0.3553263, -167.4551874>,
    <0.3518518, -167.4732541>,
    <0.3611111, -167.4961890>,
    <0.3611111, -167.4256532>,
    <0.3472312, -167.4256532>,
    <0.3570563, -167.4861453>,
    <0.3611111, -167.4566011>,
    <0.3550385, -167.4256532>,
    <0.3492508, -167.4464590>,
    <0.6446683, -167.4848985>,
    <0.6481482, -167.5208549>,
    <0.6527471, -167.4968970>,
    <0.6388889, -167.4256532>,
    <0.6388889, -167.4961890>,
    <0.6507367, -167.5073705>,
    <0.6449460, -167.4567920>,
    <0.6388889, -167.4566011>,
    <0.6429393, -167.5069791>,
    <0.6446777, -167.5384889>,
    <0.6481482, -167.5208549>,
    <0.6388889, -167.4961890>,
    <0.6388889, -167.5684558>,
    <0.6527849, -167.5684558>,
    <0.6429393, -167.5069791>,
    <0.6388889, -167.5369298>,
    <0.6449698, -167.5684558>,
    <0.6507584, -167.5476517>,
    <0.6550867, -167.5386659>,
    <0.6481482, -167.5208549>,
    <0.6527849, -167.5684558>,
    <0.6666667, -167.5684558>,
    <0.6527471, -167.4968970>,
    <0.6507584, -167.5476517>,
    <0.6605931, -167.5684558>,
    <0.6605697, -167.5371117>,
    <0.6507367, -167.5073705>,
    <0.6504576, -167.4553644>,
    <0.6574074, -167.4732541>,
    <0.6527868, -167.4256532>,
    <0.6388889, -167.4256532>,
    <0.6527471, -167.4968970>,
    <0.6548064, -167.4464590>,
    <0.6449708, -167.4256532>,
    <0.6449460, -167.4567920>,
    <0.6547832, -167.4865678>,
    <0.6608720, -167.5086990>,
    <0.6574074, -167.4732541>,
    <0.6527471, -167.4968970>,
    <0.6666667, -167.5684558>,
    <0.6666667, -167.4961890>,
    <0.6547832, -167.4865678>,
    <0.6605697, -167.5371117>,
    <0.6666667, -167.5369298>,
    <0.6626118, -167.4861453>,
    <0.6608819, -167.4551874>,
    <0.6574074, -167.4732541>,
    <0.6666667, -167.4961890>,
    <0.6666667, -167.4256532>,
    <0.6527868, -167.4256532>,
    <0.6626118, -167.4861453>,
    <0.6666667, -167.4566011>,
    <0.6605941, -167.4256532>,
    <0.6548064, -167.4464590>,
    <0.3390347, -167.1603558>,
    <0.3425926, -167.1891429>,
    <0.3333333, -167.1669985>,
    <0.3333333, -167.1158246>,
    <0.3468797, -167.1694571>,
    <0.3373862, -167.1766913>,
    <0.3333333, -167.1357233>,
    <0.3390519, -167.1384655>,
    <0.3450083, -167.1780500>,
    <0.3494543, -167.2025510>,
    <0.3425926, -167.1891429>,
    <0.3468797, -167.1694571>,
    <0.3611111, -167.2258020>,
    <0.3472339, -167.2258020>,
    <0.3450083, -167.1780500>,
    <0.3548410, -167.2009776>,
    <0.3550399, -167.2258020>,
    <0.3451961, -167.2097065>,
    <0.3391233, -167.2019363>,
    <0.3425926, -167.1891429>,
    <0.3472339, -167.2258020>,
    <0.3333333, -167.2258020>,
    <0.3333333, -167.1669985>,
    <0.3451961, -167.2097065>,
    <0.3394167, -167.2258020>,
    <0.3333333, -167.2000056>,
    <0.3373862, -167.1766913>,
    <0.3448999, -167.2539957>,
    <0.3518518, -167.2709932>,
    <0.3471806, -167.2933857>,
    <0.3333333, -167.2258020>,
    <0.3472339, -167.2258020>,
    <0.3492212, -167.2836036>,
    <0.3393833, -167.2553296>,
    <0.3394167, -167.2258020>,
    <0.3492523, -167.2455535>,
    <0.3553270, -167.2537633>,
    <0.3518518, -167.2709932>,
    <0.3472339, -167.2258020>,
    <0.3611111, -167.2258020>,
    <0.3611111, -167.2924560>,
    <0.3492523, -167.2455535>,
    <0.3550399, -167.2258020>,
    <0.3611111, -167.2550533>,
    <0.3570555, -167.2830552>,
    <0.3553137, -167.3045527>,
    <0.3518518, -167.2709932>,
    <0.3611111, -167.2924560>,
    <0.3611111, -167.3613758>,
    <0.3471806, -167.2933857>,
    <0.3570555, -167.2830552>,
    <0.3611111, -167.3313235>,
    <0.3550069, -167.3315832>,
    <0.3492212, -167.2836036>,
    <0.6446655, -167.2819570>,
    <0.6481482, -167.3161845>,
    <0.6388889, -167.2924560>,
    <0.6388889, -167.2258020>,
    <0.6527362, -167.2933857>,
    <0.6429385, -167.3028339>,
    <0.6388889, -167.2550533>,
    <0.6449388, -167.2553296>,
    <0.6507302, -167.3033535>,
    <0.6550847, -167.3330804>,
    <0.6481482, -167.3161845>,
    <0.6527362, -167.2933857>,
    <0.6666667, -167.3613758>,
    <0.6527878, -167.3613758>,
    <0.6507302, -167.3033535>,
    <0.6605625, -167.3315832>,
    <0.6605946, -167.3613758>,
    <0.6507600, -167.3416247>,
    <0.6446784, -167.3328480>,
    <0.6481482, -167.3161845>,
    <0.6527878, -167.3613758>,
    <0.6388889, -167.3613758>,
    <0.6388889, -167.2924560>,
    <0.6507600, -167.3416247>,
    <0.6449713, -167.3613758>,
    <0.6388889, -167.3313235>,
    <0.6429385, -167.3028339>,
    <0.6504555, -167.2539957>,
    <0.6574074, -167.2709932>,
    <0.6527362, -167.2933857>,
    <0.6388889, -167.2258020>,
    <0.6527895, -167.2258020>,
    <0.6547768, -167.2836036>,
    <0.6449388, -167.2553296>,
    <0.6449722, -167.2258020>,
    <0.6548078, -167.2455535>,
    <0.6608826, -167.2537633>,
    <0.6574074, -167.2709932>,
    <0.6527895, -167.2258020>,
    <0.6666667, -167.2258020>,
    <0.6666667, -167.2924560>,
    <0.6548078, -167.2455535>,
    <0.6605955, -167.2258020>,
    <0.6666667, -167.2550533>,
    <0.6626111, -167.2830552>,
    <0.6608692, -167.3045527>,
    <0.6574074, -167.2709932>,
    <0.6666667, -167.2924560>,
    <0.6666667, -167.3613758>,
    <0.6527362, -167.2933857>,
    <0.6626111, -167.2830552>,
    <0.6666667, -167.3313235>,
    <0.6605625, -167.3315832>,
    <0.6547768, -167.2836036>,
    <0.3391092, -167.2436308>,
    <0.3425926, -167.2690732>,
    <0.3471775, -167.2522483>,
    <0.3333333, -167.2024179>,
    <0.3333333, -167.2507837>,
    <0.3451729, -167.2596042>,
    <0.3393813, -167.2241867>,
    <0.3333333, -167.2235884>,
    <0.3373827, -167.2587824>,
    <0.3391230, -167.2811646>,
    <0.3425926, -167.2690732>,
    <0.3333333, -167.2507837>,
    <0.3333333, -167.3024008>,
    <0.3472328, -167.3024008>,
    <0.3373827, -167.2587824>,
    <0.3333333, -167.2798504>,
    <0.3394161, -167.3024008>,
    <0.3452044, -167.2878319>,
    <0.3495285, -167.2815307>,
    <0.3425926, -167.2690732>,
    <0.3472328, -167.3024008>,
    <0.3611111, -167.3024008>,
    <0.3471775, -167.2522483>,
    <0.3452044, -167.2878319>,
    <0.3550393, -167.3024008>,
    <0.3550047, -167.2804214>,
    <0.3451729, -167.2596042>,
    <0.3449005, -167.3280360>,
    <0.3518518, -167.3434849>,
    <0.3472328, -167.3024008>,
    <0.3333333, -167.3024008>,
    <0.3471840, -167.3638575>,
    <0.3492515, -167.3203558>,
    <0.3394161, -167.3024008>,
    <0.3393855, -167.3292549>,
    <0.3492233, -167.3549573>,
    <0.3553145, -167.3739447>,
    <0.3518518, -167.3434849>,
    <0.3471840, -167.3638575>,
    <0.3611111, -167.4256532>,
    <0.3611111, -167.3627833>,
    <0.3492233, -167.3549573>,
    <0.3550091, -167.3985780>,
    <0.3611111, -167.3982231>,
    <0.3570558, -167.3543311>,
    <0.3553267, -167.3277674>,
    <0.3518518, -167.3434849>,
    <0.3611111, -167.3627833>,
    <0.3611111, -167.3024008>,
    <0.3472328, -167.3024008>,
    <0.3570558, -167.3543311>,
    <0.3611111, -167.3288803>,
    <0.3550393, -167.3024008>,
    <0.3492515, -167.3203558>,
    <0.6446664, -167.3534027>,
    <0.6481482, -167.3845690>,
    <0.6527396, -167.3638575>,
    <0.6388889, -167.3024008>,
    <0.6388889, -167.3627833>,
    <0.6507323, -167.3729124>,
    <0.6449411, -167.3292549>,
    <0.6388889, -167.3288803>,
    <0.6429388, -167.3723121>,
    <0.6446782, -167.3996647>,
    <0.6481482, -167.3845690>,
    <0.6388889, -167.3627833>,
    <0.6388889, -167.4256532>,
    <0.6527868, -167.4256532>,
    <0.6429388, -167.3723121>,
    <0.6388889, -167.3982231>,
    <0.6449708, -167.4256532>,
    <0.6507593, -167.4076960>,
    <0.6550853, -167.3999332>,
    <0.6481482, -167.3845690>,
    <0.6527868, -167.4256532>,
    <0.6666667, -167.4256532>,
    <0.6527396, -167.3638575>,
    <0.6507593, -167.4076960>,
    <0.6605941, -167.4256532>,
    <0.6605647, -167.3985780>,
    <0.6507323, -167.3729124>,
    <0.6504561, -167.3280360>,
    <0.6574074, -167.3434849>,
    <0.6527884, -167.3024008>,
    <0.6388889, -167.3024008>,
    <0.6527396, -167.3638575>,
    <0.6548070, -167.3203558>,
    <0.6449717, -167.3024008>,
    <0.6449411, -167.3292549>,
    <0.6547788, -167.3549573>,
    <0.6608701, -167.3739447>,
    <0.6574074, -167.3434849>,
    <0.6527396, -167.3638575>,
    <0.6666667, -167.4256532>,
    <0.6666667, -167.3627833>,
    <0.6547788, -167.3549573>,
    <0.6605647, -167.3985780>,
    <0.6666667, -167.3982231>,
    <0.6626114, -167.3543311>,
    <0.6608823, -167.3277674>,
    <0.6574074, -167.3434849>,
    <0.6666667, -167.3627833>,
    <0.6666667, -167.3024008>,
    <0.6527884, -167.3024008>,
    <0.6626114, -167.3543311>,
    <0.6666667, -167.3288803>,
    <0.6605949, -167.3024008>,
    <0.6548070, -167.3203558>,
    <0.3428407, -167.0806047>,
    <0.3463989, -167.0842391>,
    <0.3525877, -167.1012870>,
    <0.3333333, -167.0684463>,
    <0.3390428, -167.0684463>,
    <0.3504519, -167.0954037>,
    <0.3450194, -167.0883783>,
    <0.3361881, -167.0684463>,
    <0.3419996, -167.0747943>,
    <0.3460359, -167.0790536>,
    <0.3463989, -167.0842391>,
    <0.3390428, -167.0684463>,
    <0.3447523, -167.0684463>,
    <0.3539493, -167.0950827>,
    <0.3419996, -167.0747943>,
    <0.3418976, -167.0684463>,
    <0.3491354, -167.0811406>,
    <0.3501952, -167.0896912>,
    <0.3535118, -167.0991084>,
    <0.3463989, -167.0842391>,
    <0.3539493, -167.0950827>,
    <0.3611111, -167.1158246>,
    <0.3525877, -167.1012870>,
    <0.3501952, -167.0896912>,
    <0.3582679, -167.1075901>,
    <0.3576930, -167.1099946>,
    <0.3504519, -167.0954037>,
    <0.3404617, -167.0912818>,
    <0.3425926, -167.1000319>,
    <0.3333333, -167.0953622>,
    <0.3333333, -167.0684463>,
    <0.3525877, -167.1012870>,
    <0.3373170, -167.0973712>,
    <0.3333333, -167.0825210>,
    <0.3450194, -167.0883783>,
    <0.3475101, -167.1006494>,
    <0.3507309, -167.1082420>,
    <0.3425926, -167.1000319>,
    <0.3525877, -167.1012870>,
    <0.3611111, -167.1158246>,
    <0.3466322, -167.1158246>,
    <0.3475101, -167.1006494>,
    <0.3576930, -167.1099946>,
    <0.3548499, -167.1158246>,
    <0.3447445, -167.1084447>,
    <0.3389729, -167.1067608>,
    <0.3425926, -167.1000319>,
    <0.3466322, -167.1158246>,
    <0.3333333, -167.1158246>,
    <0.3333333, -167.0953622>,
    <0.3447445, -167.1084447>,
    <0.3388164, -167.1158246>,
    <0.3333333, -167.1100226>,
    <0.3373170, -167.0973712>,
    <0.3446743, -167.1383975>,
    <0.3518518, -167.1524837>,
    <0.3468797, -167.1694571>,
    <0.3333333, -167.1158246>,
    <0.3466322, -167.1158246>,
    <0.3490456, -167.1620632>,
    <0.3390519, -167.1384655>,
    <0.3388164, -167.1158246>,
    <0.3488927, -167.1317012>,
    <0.3551766, -167.1377416>,
    <0.3518518, -167.1524837>,
    <0.3466322, -167.1158246>,
    <0.3611111, -167.1158246>,
    <0.3611111, -167.1668335>,
    <0.3488927, -167.1317012>,
    <0.3548499, -167.1158246>,
    <0.3611111, -167.1355784>,
    <0.3570496, -167.1605391>,
    <0.3552384, -167.1786441>,
    <0.3518518, -167.1524837>,
    <0.3611111, -167.1668335>,
    <0.3611111, -167.2258020>,
    <0.3468797, -167.1694571>,
    <0.3570496, -167.1605391>,
    <0.3611111, -167.1999174>,
    <0.3548410, -167.2009776>,
    <0.3490456, -167.1620632>,
    <0.6445930, -167.1604399>,
    <0.6481482, -167.1891429>,
    <0.6388889, -167.1672922>,
    <0.6388889, -167.1158246>,
    <0.6524461, -167.1695000>,
    <0.6429416, -167.1768560>,
    <0.6388889, -167.1360023>,
    <0.6446173, -167.1385045>,
    <0.6505699, -167.1780746>,
    <0.6550126, -167.2025617>,
    <0.6481482, -167.1891429>,
    <0.6524461, -167.1695000>,
    <0.6666667, -167.2258020>,
    <0.6527895, -167.2258020>,
    <0.6505699, -167.1780746>,
    <0.6604026, -167.2010014>,
    <0.6605955, -167.2258020>,
    <0.6507521, -167.2097094>,
    <0.6446789, -167.2020097>,
    <0.6481482, -167.1891429>,
    <0.6527895, -167.2258020>,
    <0.6388889, -167.2258020>,
    <0.6388889, -167.1672922>,
    <0.6507521, -167.2097094>,
    <0.6449722, -167.2258020>,
    <0.6388889, -167.2001584>,
    <0.6429416, -167.1768560>,
    <0.6502389, -167.1384082>,
    <0.6574074, -167.1524837>,
    <0.6524461, -167.1695000>,
    <0.6388889, -167.1158246>,
    <0.6522133, -167.1158246>,
    <0.6546075, -167.1620867>,
    <0.6446173, -167.1385045>,
    <0.6443853, -167.1158246>,
    <0.6544633, -167.1317051>,
    <0.6607385, -167.1378694>,
    <0.6574074, -167.1524837>,
    <0.6522133, -167.1158246>,
    <0.6666667, -167.1158246>,
    <0.6666667, -167.1673444>,
    <0.6544633, -167.1317051>,
    <0.6604220, -167.1158246>,
    <0.6666667, -167.1360443>,
    <0.6626053, -167.1608261>,
    <0.6607967, -167.1787825>,
    <0.6574074, -167.1524837>,
    <0.6666667, -167.1673444>,
    <0.6666667, -167.2258020>,
    <0.6524461, -167.1695000>,
    <0.6626053, -167.1608261>,
    <0.6666667, -167.2001871>,
    <0.6604026, -167.2010014>,
    <0.6546075, -167.1620867>,
    <0.3391801, -167.1583892>,
    <0.3425926, -167.1778641>,
    <0.3474612, -167.1662209>,
    <0.3333333, -167.1287564>,
    <0.3333333, -167.1607154>,
    <0.3453398, -167.1712941>,
    <0.3395905, -167.1453492>,
    <0.3333333, -167.1413913>,
    <0.3373901, -167.1682287>,
    <0.3391233, -167.1858538>,
    <0.3425926, -167.1778641>,
    <0.3333333, -167.1607154>,
    <0.3333333, -167.2024179>,
    <0.3472340, -167.2024179>,
    <0.3373901, -167.1682287>,
    <0.3333333, -167.1838308>,
    <0.3394168, -167.2024179>,
    <0.3452129, -167.1917260>,
    <0.3495997, -167.1872302>,
    <0.3425926, -167.1778641>,
    <0.3472340, -167.2024179>,
    <0.3611111, -167.2024179>,
    <0.3474612, -167.1662209>,
    <0.3452129, -167.1917260>,
    <0.3550399, -167.2024179>,
    <0.3551707, -167.1866652>,
    <0.3453398, -167.1712941>,
    <0.3448992, -167.2232074>,
    <0.3518518, -167.2357456>,
    <0.3472340, -167.2024179>,
    <0.3333333, -167.2024179>,
    <0.3471775, -167.2522483>,
    <0.3492518, -167.2169804>,
    <0.3394168, -167.2024179>,
    <0.3393813, -167.2241867>,
    <0.3492196, -167.2450388>,
    <0.3553129, -167.2602946>,
    <0.3518518, -167.2357456>,
    <0.3471775, -167.2522483>,
    <0.3611111, -167.3024008>,
    <0.3611111, -167.2507837>,
    <0.3492196, -167.2450388>,
    <0.3550047, -167.2804214>,
    <0.3611111, -167.2798504>,
    <0.3570554, -167.2441968>,
    <0.3553270, -167.2228413>,
    <0.3518518, -167.2357456>,
    <0.3611111, -167.2507837>,
    <0.3611111, -167.2024179>,
    <0.3472340, -167.2024179>,
    <0.3570554, -167.2441968>,
    <0.3611111, -167.2235884>,
    <0.3550399, -167.2024179>,
    <0.3492518, -167.2169804>,
    <0.6446647, -167.2436308>,
    <0.6481482, -167.2690732>,
    <0.6527330, -167.2522483>,
    <0.6388889, -167.2024179>,
    <0.6388889, -167.2507837>,
    <0.6507285, -167.2596042>,
    <0.6449368, -167.2241867>,
    <0.6388889, -167.2235884>,
    <0.6429383, -167.2587824>,
    <0.6446786, -167.2811646>,
    <0.6481482, -167.2690732>,
    <0.6388889, -167.2507837>,
    <0.6388889, -167.3024008>,
    <0.6527884, -167.3024008>,
    <0.6429383, -167.2587824>,
    <0.6388889, -167.2798504>,
    <0.6449717, -167.3024008>,
    <0.6507600, -167.2878319>,
    <0.6550841, -167.2815307>,
    <0.6481482, -167.2690732>,
    <0.6527884, -167.3024008>,
    <0.6666667, -167.3024008>,
    <0.6527330, -167.2522483>,
    <0.6507600, -167.2878319>,
    <0.6605949, -167.3024008>,
    <0.6605603, -167.2804214>,
    <0.6507285, -167.2596042>,
    <0.6504547, -167.2232074>,
    <0.6574074, -167.2357456>,
    <0.6527896, -167.2024179>,
    <0.6388889, -167.2024179>,
    <0.6527330, -167.2522483>,
    <0.6548073, -167.2169804>,
    <0.6449723, -167.2024179>,
    <0.6449368, -167.2241867>,
    <0.6547751, -167.2450388>,
    <0.6608684, -167.2602946>,
    <0.6574074, -167.2357456>,
    <0.6527330, -167.2522483>,
    <0.6666667, -167.3024008>,
    <0.6666667, -167.2507837>,
    <0.6547751, -167.2450388>,
    <0.6605603, -167.2804214>,
    <0.6666667, -167.2798504>,
    <0.6626110, -167.2441968>,
    <0.6608826, -167.2228413>,
    <0.6574074, -167.2357456>,
    <0.6666667, -167.2507837>,
    <0.6666667, -167.2024179>,
    <0.6527896, -167.2024179>,
    <0.6626110, -167.2441968>,
    <0.6666667, -167.2235884>,
    <0.6605955, -167.2024179>,
    <0.6548073, -167.2169804>,
    <0.3518229, -167.0790536>,
    <0.3556582, -167.0842391>,
    <0.3539493, -167.0950827>,
    <0.3447523, -167.0684463>,
    <0.3529317, -167.0684463>,
    <0.3546342, -167.0907366>,
    <0.3491354, -167.0811406>,
    <0.3488420, -167.0684463>,
    <0.3541145, -167.0752977>,
    <0.3577030, -167.0792565>,
    <0.3556582, -167.0842391>,
    <0.3529317, -167.0684463>,
    <0.3611111, -167.0684463>,
    <0.3611111, -167.0958943>,
    <0.3541145, -167.0752977>,
    <0.3570214, -167.0684463>,
    <0.3611111, -167.0828767>,
    <0.3587925, -167.0909384>,
    <0.3579574, -167.0977602>,
    <0.3556582, -167.0842391>,
    <0.3611111, -167.0958943>,
    <0.3611111, -167.1158246>,
    <0.3539493, -167.0950827>,
    <0.3587925, -167.0909384>,
    <0.3611111, -167.1102282>,
    <0.3582679, -167.1075901>,
    <0.3546342, -167.0907366>,
    <0.6459906, -167.0909911>,
    <0.6481482, -167.1000319>,
    <0.6388889, -167.0943815>,
    <0.6388889, -167.0684463>,
    <0.6580364, -167.1011047>,
    <0.6428898, -167.0968230>,
    <0.6388889, -167.0814635>,
    <0.6504342, -167.0881382>,
    <0.6530187, -167.1005603>,
    <0.6562661, -167.1081965>,
    <0.6481482, -167.1000319>,
    <0.6580364, -167.1011047>,
    <0.6666667, -167.1158246>,
    <0.6522133, -167.1158246>,
    <0.6530187, -167.1005603>,
    <0.6631995, -167.1099109>,
    <0.6604220, -167.1158246>,
    <0.6503189, -167.1084650>,
    <0.6445348, -167.1065157>,
    <0.6481482, -167.1000319>,
    <0.6522133, -167.1158246>,
    <0.6388889, -167.1158246>,
    <0.6388889, -167.0943815>,
    <0.6503189, -167.1084650>,
    <0.6443853, -167.1158246>,
    <0.6388889, -167.1097075>,
    <0.6428898, -167.0968230>,
    <0.6484407, -167.0805591>,
    <0.6519545, -167.0842391>,
    <0.6580364, -167.1011047>,
    <0.6388889, -167.0684463>,
    <0.6448829, -167.0684463>,
    <0.6558896, -167.0951515>,
    <0.6504342, -167.0881382>,
    <0.6419245, -167.0684463>,
    <0.6477225, -167.0747878>,
    <0.6518008, -167.0794541>,
    <0.6519545, -167.0842391>,
    <0.6448829, -167.0684463>,
    <0.6503079, -167.0684463>,
    <0.6600581, -167.0966849>,
    <0.6477225, -167.0747878>,
    <0.6476914, -167.0684463>,
    <0.6553030, -167.0829132>,
    <0.6560196, -167.0904825>,
    <0.6591789, -167.0994633>,
    <0.6519545, -167.0842391>,
    <0.6600581, -167.0966849>,
    <0.6666667, -167.1158246>,
    <0.6580364, -167.1011047>,
    <0.6560196, -167.0904825>,
    <0.6640993, -167.1083889>,
    <0.6631995, -167.1099109>,
    <0.6558896, -167.0951515>,
    <0.3558250, -167.1106495>,
    <0.3547752, -167.1123151>,
    <0.3601089, -167.1220939>,
    <0.3574013, -167.1040945>,
    <0.3510145, -167.1040945>,
    <0.3573343, -167.1170071>,
    <0.3588609, -167.1137976>,
    <0.3539480, -167.1040945>,
    <0.3524025, -167.1071285>,
    <0.3522536, -167.1108241>,
    <0.3547752, -167.1123151>,
    <0.3510145, -167.1040945>,
    <0.3458131, -167.1040945>,
    <0.3574114, -167.1227922>,
    <0.3524025, -167.1071285>,
    <0.3483396, -167.1040945>,
    <0.3530967, -167.1158363>,
    <0.3564416, -167.1189379>,
    <0.3583516, -167.1214894>,
    <0.3547752, -167.1123151>,
    <0.3574114, -167.1227922>,
    <0.3611111, -167.1287564>,
    <0.3601089, -167.1220939>,
    <0.3564416, -167.1189379>,
    <0.3597617, -167.1265810>,
    <0.3608264, -167.1268636>,
    <0.3573343, -167.1170071>,
    <0.3465422, -167.1176324>,
    <0.3467525, -167.1205358>,
    <0.3574114, -167.1227922>,
    <0.3458130, -167.1040945>,
    <0.3361920, -167.1231073>,
    <0.3527307, -167.1218013>,
    <0.3530966, -167.1158363>,
    <0.3396853, -167.1162039>,
    <0.3410633, -167.1219211>,
    <0.3406326, -167.1252890>,
    <0.3467525, -167.1205358>,
    <0.3361920, -167.1231073>,
    <0.3333333, -167.1287564>,
    <0.3462526, -167.1287564>,
    <0.3410633, -167.1219211>,
    <0.3343713, -167.1267051>,
    <0.3386038, -167.1287564>,
    <0.3464305, -167.1258320>,
    <0.3528819, -167.1252102>,
    <0.3467525, -167.1205358>,
    <0.3462526, -167.1287564>,
    <0.3611111, -167.1287564>,
    <0.3574114, -167.1227922>,
    <0.3464305, -167.1258320>,
    <0.3546454, -167.1287564>,
    <0.3597616, -167.1265810>,
    <0.3527307, -167.1218013>,
    <0.3447248, -167.1442610>,
    <0.3518518, -167.1533103>,
    <0.3462526, -167.1287564>,
    <0.3333333, -167.1287564>,
    <0.3474612, -167.1662209>,
    <0.3490117, -167.1408553>,
    <0.3386038, -167.1287564>,
    <0.3395905, -167.1453492>,
    <0.3494396, -167.1604034>,
    <0.3553838, -167.1706661>,
    <0.3518518, -167.1533103>,
    <0.3474612, -167.1662209>,
    <0.3611111, -167.2024179>,
    <0.3611111, -167.1607152>,
    <0.3494396, -167.1604034>,
    <0.3551707, -167.1866652>,
    <0.3611111, -167.1838307>,
    <0.3571231, -167.1575259>,
    <0.3550817, -167.1428846>,
    <0.3518518, -167.1533103>,
    <0.3611111, -167.1607152>,
    <0.3611111, -167.1287564>,
    <0.3462526, -167.1287564>,
    <0.3571231, -167.1575259>,
    <0.3611111, -167.1413911>,
    <0.3546454, -167.1287564>,
    <0.3490117, -167.1408553>,
    <0.6461936, -167.1107626>,
    <0.6440010, -167.1123279>,
    <0.6420597, -167.1224953>,
    <0.6513685, -167.1041136>,
    <0.6473453, -167.1041136>,
    <0.6427526, -167.1188660>,
    <0.6457453, -167.1152175>,
    <0.6494928, -167.1041136>,
    <0.6461954, -167.1069379>,
    <0.6432496, -167.1101332>,
    <0.6440010, -167.1123279>,
    <0.6473453, -167.1041136>,
    <0.6417456, -167.1041136>,
    <0.6399065, -167.1199779>,
    <0.6461954, -167.1069379>,
    <0.6448327, -167.1041136>,
    <0.6408188, -167.1121088>,
    <0.6420612, -167.1159521>,
    <0.6412140, -167.1208894>,
    <0.6440010, -167.1123279>,
    <0.6399065, -167.1199779>,
    <0.6388889, -167.1287564>,
    <0.6420597, -167.1224953>,
    <0.6420612, -167.1159521>,
    <0.6392324, -167.1257932>,
    <0.6400455, -167.1264725>,
    <0.6427526, -167.1188660>,
    <0.6447590, -167.1582978>,
    <0.6481482, -167.1778641>,
    <0.6531100, -167.1664683>,
    <0.6388889, -167.1287564>,
    <0.6388889, -167.1601026>,
    <0.6509469, -167.1714363>,
    <0.6452467, -167.1456162>,
    <0.6388889, -167.1407350>,
    <0.6429446, -167.1678824>,
    <0.6446789, -167.1857006>,
    <0.6481482, -167.1778641>,
    <0.6388889, -167.1601026>,
    <0.6388889, -167.2024179>,
    <0.6527896, -167.2024179>,
    <0.6429446, -167.1678824>,
    <0.6388889, -167.1835239>,
    <0.6449723, -167.2024179>,
    <0.6507712, -167.1917403>,
    <0.6551786, -167.1872921>,
    <0.6481482, -167.1778641>,
    <0.6527896, -167.2024179>,
    <0.6666667, -167.2024179>,
    <0.6531100, -167.1664683>,
    <0.6507712, -167.1917403>,
    <0.6605955, -167.2024179>,
    <0.6607762, -167.1867974>,
    <0.6509469, -167.1714363>,
    <0.6522258, -167.1175674>,
    <0.6523080, -167.1205421>,
    <0.6631668, -167.1231187>,
    <0.6513685, -167.1041136>,
    <0.6420597, -167.1224953>,
    <0.6585898, -167.1220327>,
    <0.6590410, -167.1164727>,
    <0.6457453, -167.1152175>,
    <0.6469444, -167.1215643>,
    <0.6463114, -167.1251376>,
    <0.6523080, -167.1205421>,
    <0.6420597, -167.1224953>,
    <0.6388889, -167.1287564>,
    <0.6519890, -167.1287564>,
    <0.6469444, -167.1215643>,
    <0.6400455, -167.1264725>,
    <0.6442708, -167.1287564>,
    <0.6520947, -167.1260344>,
    <0.6585326, -167.1252934>,
    <0.6523080, -167.1205421>,
    <0.6519890, -167.1287564>,
    <0.6666667, -167.1287564>,
    <0.6631668, -167.1231187>,
    <0.6520947, -167.1260344>,
    <0.6603242, -167.1287564>,
    <0.6653910, -167.1267016>,
    <0.6585898, -167.1220327>,
    <0.6503488, -167.1443228>,
    <0.6574074, -167.1533103>,
    <0.6519890, -167.1287564>,
    <0.6388889, -167.1287564>,
    <0.6531100, -167.1664683>,
    <0.6546675, -167.1408940>,
    <0.6442708, -167.1287564>,
    <0.6452467, -167.1456162>,
    <0.6550481, -167.1605343>,
    <0.6609627, -167.1705747>,
    <0.6574074, -167.1533103>,
    <0.6531100, -167.1664683>,
    <0.6666667, -167.2024179>,
    <0.6666667, -167.1601024>,
    <0.6550481, -167.1605343>,
    <0.6607762, -167.1867974>,
    <0.6666667, -167.1835237>,
    <0.6626804, -167.1571782>,
    <0.6606824, -167.1427314>,
    <0.6574074, -167.1533103>,
    <0.6666667, -167.1601024>,
    <0.6666667, -167.1287564>,
    <0.6519890, -167.1287564>,
    <0.6626804, -167.1571782>,
    <0.6666667, -167.1407348>,
    <0.6603242, -167.1287564>,
    <0.6546675, -167.1408940>,
    <0.3590635, -167.1106495>,
    <0.3598745, -167.1123151>,
    <0.3588693, -167.1040945>,
    <0.3574013, -167.1040945>,
    <0.3601089, -167.1220939>,
    <0.3592995, -167.1076129>,
    <0.3580442, -167.1040945>,
    <0.3588609, -167.1137976>,
    <0.3600256, -167.1186205>,
    <0.3605514, -167.1197249>,
    <0.3598745, -167.1123151>,
    <0.3601089, -167.1220939>,
    <0.3611111, -167.1287564>,
    <0.3611111, -167.1157341>,
    <0.3600256, -167.1186205>,
    <0.3608264, -167.1268636>,
    <0.3611111, -167.1243329>,
    <0.3606161, -167.1143655>,
    <0.3602415, -167.1090596>,
    <0.3598745, -167.1123151>,
    <0.3611111, -167.1157341>,
    <0.3611111, -167.1040945>,
    <0.3588693, -167.1040945>,
    <0.3606161, -167.1143655>,
    <0.3611111, -167.1077233>,
    <0.3599209, -167.1040945>,
    <0.3592995, -167.1076129>,
    <0.6405338, -167.1101298>,
    <0.6398411, -167.1123215>,
    <0.6399065, -167.1199779>,
    <0.6417456, -167.1041136>,
    <0.6406419, -167.1041062>,
    <0.6398819, -167.1170881>,
    <0.6408188, -167.1121088>,
    <0.6412670, -167.1041104>,
    <0.6402970, -167.1076438>,
    <0.6395652, -167.1098060>,
    <0.6398411, -167.1123215>,
    <0.6406419, -167.1041062>,
    <0.6388889, -167.1040945>,
    <0.6388889, -167.1187016>,
    <0.6402970, -167.1076438>,
    <0.6398254, -167.1041008>,
    <0.6388889, -167.1075981>,
    <0.6392380, -167.1163624>,
    <0.6393814, -167.1199394>,
    <0.6398411, -167.1123215>,
    <0.6388889, -167.1187016>,
    <0.6388889, -167.1287564>,
    <0.6399065, -167.1199779>,
    <0.6392380, -167.1163624>,
    <0.6388889, -167.1268396>,
    <0.6392324, -167.1257932>,
    <0.6398819, -167.1170881>,
    <0.3675312, -167.1109029>,
    <0.3652710, -167.1123151>,
    <0.3639697, -167.1231074>,
    <0.3735907, -167.1040945>,
    <0.3672936, -167.1040945>,
    <0.3644705, -167.1189536>,
    <0.3674630, -167.1162040>,
    <0.3704202, -167.1040945>,
    <0.3666204, -167.1068305>,
    <0.3636967, -167.1090596>,
    <0.3652710, -167.1123151>,
    <0.3672936, -167.1040945>,
    <0.3611111, -167.1040945>,
    <0.3611111, -167.1157341>,
    <0.3666204, -167.1068305>,
    <0.3641953, -167.1040945>,
    <0.3611111, -167.1077233>,
    <0.3632112, -167.1140080>,
    <0.3628657, -167.1199783>,
    <0.3652710, -167.1123151>,
    <0.3611111, -167.1157341>,
    <0.3611111, -167.1287564>,
    <0.3639697, -167.1231074>,
    <0.3632112, -167.1140080>,
    <0.3611111, -167.1243329>,
    <0.3621491, -167.1267052>,
    <0.3644705, -167.1189536>,
    <0.6298213, -167.0794545>,
    <0.6334370, -167.0842391>,
    <0.6322821, -167.0966863>,
    <0.6225332, -167.0684463>,
    <0.6310328, -167.0684463>,
    <0.6327416, -167.0917335>,
    <0.6275276, -167.0829140>,
    <0.6269144, -167.0684463>,
    <0.6320785, -167.0753152>,
    <0.6355619, -167.0788783>,
    <0.6334370, -167.0842391>,
    <0.6310328, -167.0684463>,
    <0.6388889, -167.0684463>,
    <0.6388889, -167.0943815>,
    <0.6320785, -167.0753152>,
    <0.6349985, -167.0684463>,
    <0.6388889, -167.0814635>,
    <0.6365864, -167.0900980>,
    <0.6358742, -167.0977829>,
    <0.6334370, -167.0842391>,
    <0.6388889, -167.0943815>,
    <0.6388889, -167.1158246>,
    <0.6322821, -167.0966863>,
    <0.6365864, -167.0900980>,
    <0.6388889, -167.1097075>,
    <0.6363223, -167.1083900>,
    <0.6327416, -167.0917335>,
    <0.3660165, -167.9428888>,
    <0.3703704, -168.0047729>,
    <0.3611111, -167.9406711>,
    <0.3611111, -167.8774261>,
    <0.3714735, -167.9486851>,
    <0.3653072, -167.9697206>,
    <0.3611111, -167.9044451>,
    <0.3655503, -167.9079530>,
    <0.3709704, -167.9742639>,
    <0.3764332, -168.0225876>,
    <0.3703704, -168.0047729>,
    <0.3714735, -167.9486851>,
    <0.3888889, -168.0684463>,
    <0.3750000, -168.0684463>,
    <0.3709704, -167.9742639>,
    <0.3790349, -168.0006829>,
    <0.3819444, -168.0684463>,
    <0.3731150, -168.0425207>,
    <0.3668981, -168.0205841>,
    <0.3703704, -168.0047729>,
    <0.3750000, -168.0684463>,
    <0.3611111, -168.0684463>,
    <0.3611111, -167.9406711>,
    <0.3731150, -168.0425207>,
    <0.3680555, -168.0684463>,
    <0.3611111, -167.9887449>,
    <0.3653072, -167.9697206>,
    <0.3668823, -167.7682109>,
    <0.3703704, -167.8156918>,
    <0.3611111, -167.7805253>,
    <0.3611111, -167.6922232>,
    <0.3749368, -167.7844032>,
    <0.3651577, -167.7958942>,
    <0.3611111, -167.7304384>,
    <0.3671494, -167.7324824>,
    <0.3729409, -167.7980788>,
    <0.3773023, -167.8387368>,
    <0.3703704, -167.8156918>,
    <0.3749368, -167.7844032>,
    <0.3888889, -167.8774261>,
    <0.3750131, -167.8774261>,
    <0.3729409, -167.7980788>,
    <0.3828817, -167.8373744>,
    <0.3829568, -167.8774261>,
    <0.3730043, -167.8507145>,
    <0.3669014, -167.8377673>,
    <0.3703704, -167.8156918>,
    <0.3750131, -167.8774261>,
    <0.3611111, -167.8774261>,
    <0.3611111, -167.7805253>,
    <0.3730043, -167.8507145>,
    <0.3670761, -167.8774261>,
    <0.3611111, -167.8352614>,
    <0.3651577, -167.7958942>,
    <0.3718068, -167.9111592>,
    <0.3796296, -167.9410995>,
    <0.3714735, -167.9486851>,
    <0.3611111, -167.8774261>,
    <0.3750131, -167.8774261>,
    <0.3747313, -167.9456552>,
    <0.3655503, -167.9079530>,
    <0.3670761, -167.8774261>,
    <0.3771654, -167.9071108>,
    <0.3831051, -167.9091384>,
    <0.3796296, -167.9410995>,
    <0.3750131, -167.8774261>,
    <0.3888889, -167.8774261>,
    <0.3888889, -167.9406021>,
    <0.3771654, -167.9071108>,
    <0.3829568, -167.8774261>,
    <0.3888889, -167.9039052>,
    <0.3850225, -167.9408098>,
    <0.3822202, -167.9747082>,
    <0.3796296, -167.9410995>,
    <0.3888889, -167.9406021>,
    <0.3888889, -168.0684463>,
    <0.3714735, -167.9486851>,
    <0.3850225, -167.9408098>,
    <0.3888889, -167.9891238>,
    <0.3790349, -168.0006829>,
    <0.3747313, -167.9456552>,
    <0.6160143, -167.9427483>,
    <0.6203704, -168.0047729>,
    <0.6111111, -167.9401705>,
    <0.6111111, -167.8774261>,
    <0.6214645, -167.9486237>,
    <0.6153072, -167.9694466>,
    <0.6111111, -167.9042150>,
    <0.6155442, -167.9079114>,
    <0.6209656, -167.9742286>,
    <0.6264310, -168.0225723>,
    <0.6203704, -168.0047729>,
    <0.6214645, -167.9486237>,
    <0.6388889, -168.0684463>,
    <0.6250000, -168.0684463>,
    <0.6209656, -167.9742286>,
    <0.6290300, -168.0006492>,
    <0.6319445, -168.0684463>,
    <0.6231147, -168.0425170>,
    <0.6168982, -168.0204590>,
    <0.6203704, -168.0047729>,
    <0.6250000, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.6111111, -167.9401705>,
    <0.6231147, -168.0425170>,
    <0.6180556, -168.0684463>,
    <0.6111111, -167.9885502>,
    <0.6153072, -167.9694466>,
    <0.6218059, -167.9111438>,
    <0.6296296, -167.9410995>,
    <0.6214645, -167.9486237>,
    <0.6111111, -167.8774261>,
    <0.6250182, -167.8774261>,
    <0.6247265, -167.9456177>,
    <0.6155442, -167.9079114>,
    <0.6170789, -167.8774261>,
    <0.6271646, -167.9070635>,
    <0.6331064, -167.9090281>,
    <0.6296296, -167.9410995>,
    <0.6250182, -167.8774261>,
    <0.6388889, -167.8774261>,
    <0.6388889, -167.9401608>,
    <0.6271646, -167.9070635>,
    <0.6329096, -167.8774261>,
    <0.6388889, -167.9042186>,
    <0.6350012, -167.9405549>,
    <0.6322180, -167.9745826>,
    <0.6296296, -167.9410995>,
    <0.6388889, -167.9401608>,
    <0.6388889, -168.0684463>,
    <0.6214645, -167.9486237>,
    <0.6350012, -167.9405549>,
    <0.6388889, -167.9885987>,
    <0.6290300, -168.0006492>,
    <0.6247265, -167.9456177>,
    <0.3668921, -167.5906989>,
    <0.3703704, -167.6342972>,
    <0.3611111, -167.6048705>,
    <0.3611111, -167.5184453>,
    <0.3749757, -167.6051824>,
    <0.3651620, -167.6177446>,
    <0.3611111, -167.5563664>,
    <0.3671723, -167.5563642>,
    <0.3729626, -167.6179095>,
    <0.3773101, -167.6559815>,
    <0.3703704, -167.6342972>,
    <0.3749757, -167.6051824>,
    <0.3888889, -167.6922232>,
    <0.3750054, -167.6922232>,
    <0.3729626, -167.6179095>,
    <0.3827961, -167.6541068>,
    <0.3828145, -167.6922232>,
    <0.3729798, -167.6669079>,
    <0.3668995, -167.6559035>,
    <0.3703704, -167.6342972>,
    <0.3750054, -167.6922232>,
    <0.3611111, -167.6922232>,
    <0.3611111, -167.6048705>,
    <0.3729798, -167.6669079>,
    <0.3671911, -167.6922232>,
    <0.3611111, -167.6541051>,
    <0.3651620, -167.6177446>,
    <0.3726707, -167.7307018>,
    <0.3796296, -167.7539575>,
    <0.3749368, -167.7844032>,
    <0.3611111, -167.6922232>,
    <0.3750054, -167.6922232>,
    <0.3769873, -167.7711002>,
    <0.3671494, -167.7324824>,
    <0.3671911, -167.6922232>,
    <0.3770248, -167.7191820>,
    <0.3831032, -167.7297281>,
    <0.3796296, -167.7539575>,
    <0.3750054, -167.6922232>,
    <0.3888889, -167.6922232>,
    <0.3888889, -167.7805085>,
    <0.3770248, -167.7191820>,
    <0.3828145, -167.6922232>,
    <0.3888889, -167.7304297>,
    <0.3848348, -167.7688833>,
    <0.3830860, -167.7990738>,
    <0.3796296, -167.7539575>,
    <0.3888889, -167.7805085>,
    <0.3888889, -167.8774261>,
    <0.3749368, -167.7844032>,
    <0.3848348, -167.7688833>,
    <0.3888889, -167.8359290>,
    <0.3828817, -167.8373744>,
    <0.3769873, -167.7711002>,
    <0.6168801, -167.7681741>,
    <0.6203704, -167.8156918>,
    <0.6111111, -167.7804389>,
    <0.6111111, -167.6922232>,
    <0.6249277, -167.7843426>,
    <0.6151567, -167.7958417>,
    <0.6111111, -167.7303938>,
    <0.6171444, -167.7324486>,
    <0.6229349, -167.7980509>,
    <0.6273013, -167.8387216>,
    <0.6203704, -167.8156918>,
    <0.6249277, -167.7843426>,
    <0.6388889, -167.8774261>,
    <0.6250182, -167.8774261>,
    <0.6229349, -167.7980509>,
    <0.6328222, -167.8369778>,
    <0.6329096, -167.8774261>,
    <0.6230039, -167.8506718>,
    <0.6169027, -167.8377457>,
    <0.6203704, -167.8156918>,
    <0.6250182, -167.8774261>,
    <0.6111111, -167.8774261>,
    <0.6111111, -167.7804389>,
    <0.6230039, -167.8506718>,
    <0.6170789, -167.8774261>,
    <0.6111111, -167.8351098>,
    <0.6151567, -167.7958417>,
    <0.6226685, -167.7306866>,
    <0.6296296, -167.7539575>,
    <0.6249277, -167.7843426>,
    <0.6111111, -167.6922232>,
    <0.6250054, -167.6922232>,
    <0.6269821, -167.7710663>,
    <0.6171444, -167.7324486>,
    <0.6171911, -167.6922232>,
    <0.6270245, -167.7191786>,
    <0.6331032, -167.7297116>,
    <0.6296296, -167.7539575>,
    <0.6250054, -167.6922232>,
    <0.6388889, -167.6922232>,
    <0.6388889, -167.7804425>,
    <0.6270245, -167.7191786>,
    <0.6328146, -167.6922232>,
    <0.6388889, -167.7303956>,
    <0.6348347, -167.7688461>,
    <0.6330838, -167.7990422>,
    <0.6296296, -167.7539575>,
    <0.6388889, -167.7804425>,
    <0.6388889, -167.8774261>,
    <0.6249277, -167.7843426>,
    <0.6348347, -167.7688461>,
    <0.6388889, -167.8351104>,
    <0.6328222, -167.8369778>,
    <0.6269821, -167.7710663>,
    <0.3660173, -167.9542945>,
    <0.3703704, -168.0105648>,
    <0.3714766, -167.9595985>,
    <0.3611111, -167.8948019>,
    <0.3611111, -167.9522128>,
    <0.3709721, -167.9828426>,
    <0.3655527, -167.9225672>,
    <0.3611111, -167.9194706>,
    <0.3653073, -167.9786571>,
    <0.3668981, -168.0249176>,
    <0.3703704, -168.0105648>,
    <0.3611111, -167.9522128>,
    <0.3611111, -168.0684463>,
    <0.3750000, -168.0684463>,
    <0.3653073, -167.9786571>,
    <0.3611111, -167.9956646>,
    <0.3680555, -168.0684463>,
    <0.3731153, -168.0448828>,
    <0.3764340, -168.0267640>,
    <0.3703704, -168.0105648>,
    <0.3750000, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3714766, -167.9595985>,
    <0.3731153, -168.0448828>,
    <0.3819444, -168.0684463>,
    <0.3790379, -168.0068657>,
    <0.3709721, -167.9828426>,
    <0.6310954, -167.1109046>,
    <0.6337896, -167.1123151>,
    <0.6316121, -167.1040945>,
    <0.6235910, -167.1040945>,
    <0.6353891, -167.1231144>,
    <0.6323925, -167.1070408>,
    <0.6277574, -167.1040945>,
    <0.6312634, -167.1164632>,
    <0.6347523, -167.1188146>,
    <0.6367391, -167.1207219>,
    <0.6337896, -167.1123151>,
    <0.6353891, -167.1231144>,
    <0.6388889, -167.1287564>,
    <0.6388889, -167.1187016>,
    <0.6347523, -167.1188146>,
    <0.6376133, -167.1267000>,
    <0.6388889, -167.1268396>,
    <0.6362973, -167.1154558>,
    <0.6357949, -167.1098014>,
    <0.6337896, -167.1123151>,
    <0.6388889, -167.1187016>,
    <0.6388889, -167.1040945>,
    <0.6316121, -167.1040945>,
    <0.6362973, -167.1154558>,
    <0.6388889, -167.1075981>,
    <0.6352932, -167.1040945>,
    <0.6323925, -167.1070408>,
    <0.3668832, -167.7954297>,
    <0.3703704, -167.8386752>,
    <0.3749402, -167.8102497>,
    <0.3611111, -167.7264218>,
    <0.3611111, -167.8063719>,
    <0.3729426, -167.8226757>,
    <0.3671515, -167.7630365>,
    <0.3611111, -167.7609773>,
    <0.3651579, -167.8204903>,
    <0.3669014, -167.8586628>,
    <0.3703704, -167.8386752>,
    <0.3611111, -167.8063719>,
    <0.3611111, -167.8948019>,
    <0.3750129, -167.8948019>,
    <0.3651579, -167.8204903>,
    <0.3611111, -167.8564978>,
    <0.3670760, -167.8948019>,
    <0.3730058, -167.8705371>,
    <0.3773031, -167.8596322>,
    <0.3703704, -167.8386752>,
    <0.3750129, -167.8948019>,
    <0.3888889, -167.8948019>,
    <0.3749402, -167.8102497>,
    <0.3730058, -167.8705371>,
    <0.3829311, -167.8948019>,
    <0.3828583, -167.8582467>,
    <0.3729426, -167.8226757>,
    <0.3718075, -167.9254714>,
    <0.3796296, -167.9526834>,
    <0.3750129, -167.8948019>,
    <0.3611111, -167.8948019>,
    <0.3714766, -167.9595985>,
    <0.3771674, -167.9218132>,
    <0.3670760, -167.8948019>,
    <0.3655527, -167.9225672>,
    <0.3747298, -167.9568393>,
    <0.3822210, -167.9832185>,
    <0.3796296, -167.9526834>,
    <0.3714766, -167.9595985>,
    <0.3888889, -168.0684463>,
    <0.3888889, -167.9521458>,
    <0.3747298, -167.9568393>,
    <0.3790379, -168.0068657>,
    <0.3888889, -167.9958039>,
    <0.3850126, -167.9523708>,
    <0.3831051, -167.9236083>,
    <0.3796296, -167.9526834>,
    <0.3888889, -167.9521458>,
    <0.3888889, -167.8948019>,
    <0.3750129, -167.8948019>,
    <0.3850126, -167.9523708>,
    <0.3888889, -167.9191892>,
    <0.3829311, -167.8948019>,
    <0.3771674, -167.9218132>,
    <0.6160151, -167.9541589>,
    <0.6203704, -168.0105648>,
    <0.6214678, -167.9595434>,
    <0.6111111, -167.8948019>,
    <0.6111111, -167.9517252>,
    <0.6209673, -167.9828110>,
    <0.6155467, -167.9225299>,
    <0.6111111, -167.9192507>,
    <0.6153072, -167.9783902>,
    <0.6168982, -168.0247957>,
    <0.6203704, -168.0105648>,
    <0.6111111, -167.9517252>,
    <0.6111111, -168.0684463>,
    <0.6250000, -168.0684463>,
    <0.6153072, -167.9783902>,
    <0.6111111, -167.9954605>,
    <0.6180556, -168.0684463>,
    <0.6231150, -168.0448796>,
    <0.6264318, -168.0267502>,
    <0.6203704, -168.0105648>,
    <0.6250000, -168.0684463>,
    <0.6388889, -168.0684463>,
    <0.6214678, -167.9595434>,
    <0.6231150, -168.0448796>,
    <0.6319445, -168.0684463>,
    <0.6290331, -168.0068356>,
    <0.6209673, -167.9828110>,
    <0.6218066, -167.9254577>,
    <0.6296296, -167.9526834>,
    <0.6250179, -167.8948019>,
    <0.6111111, -167.8948019>,
    <0.6214678, -167.9595434>,
    <0.6271666, -167.9217706>,
    <0.6170788, -167.8948019>,
    <0.6155467, -167.9225299>,
    <0.6247251, -167.9568056>,
    <0.6322188, -167.9830973>,
    <0.6296296, -167.9526834>,
    <0.6214678, -167.9595434>,
    <0.6388889, -168.0684463>,
    <0.6388889, -167.9517162>,
    <0.6247251, -167.9568056>,
    <0.6290331, -168.0068356>,
    <0.6388889, -167.9955084>,
    <0.6350017, -167.9521222>,
    <0.6331063, -167.9235009>,
    <0.6296296, -167.9526834>,
    <0.6388889, -167.9517162>,
    <0.6388889, -167.8948019>,
    <0.6250179, -167.8948019>,
    <0.6350017, -167.9521222>,
    <0.6388889, -167.9192541>,
    <0.6329094, -167.8948019>,
    <0.6271666, -167.9217706>,
    <0.3668898, -167.4265843>,
    <0.3703704, -167.4660888>,
    <0.3611111, -167.4391506>,
    <0.3611111, -167.3613758>,
    <0.3749667, -167.4397221>,
    <0.3651613, -167.4509341>,
    <0.3611111, -167.3955180>,
    <0.3671664, -167.3956156>,
    <0.3729573, -167.4512490>,
    <0.3773084, -167.4856754>,
    <0.3703704, -167.4660888>,
    <0.3749667, -167.4397221>,
    <0.3888889, -167.5184453>,
    <0.3750078, -167.5184453>,
    <0.3729573, -167.4512490>,
    <0.3827902, -167.4839601>,
    <0.3828158, -167.5184453>,
    <0.3729811, -167.4955641>,
    <0.3669001, -167.4855325>,
    <0.3703704, -167.4660888>,
    <0.3750078, -167.5184453>,
    <0.3611111, -167.5184453>,
    <0.3611111, -167.4391506>,
    <0.3729811, -167.4955641>,
    <0.3671924, -167.5184453>,
    <0.3611111, -167.4838674>,
    <0.3651613, -167.4509341>,
    <0.3726811, -167.5546111>,
    <0.3796296, -167.5763713>,
    <0.3749757, -167.6051824>,
    <0.3611111, -167.5184453>,
    <0.3750078, -167.5184453>,
    <0.3770090, -167.5925951>,
    <0.3671723, -167.5563642>,
    <0.3671924, -167.5184453>,
    <0.3770283, -167.5437683>,
    <0.3831038, -167.5545331>,
    <0.3796296, -167.5763713>,
    <0.3750078, -167.5184453>,
    <0.3888889, -167.5184453>,
    <0.3888889, -167.6048705>,
    <0.3770283, -167.5437683>,
    <0.3828158, -167.5184453>,
    <0.3888889, -167.5563664>,
    <0.3848344, -167.5923911>,
    <0.3830958, -167.6196618>,
    <0.3796296, -167.5763713>,
    <0.3888889, -167.6048705>,
    <0.3888889, -167.6922232>,
    <0.3749757, -167.6051824>,
    <0.3848344, -167.5923911>,
    <0.3888889, -167.6541051>,
    <0.3827961, -167.6541068>,
    <0.3770090, -167.5925951>,
    <0.6168921, -167.5906989>,
    <0.6203704, -167.6342972>,
    <0.6111111, -167.6048705>,
    <0.6111111, -167.5184453>,
    <0.6249757, -167.6051824>,
    <0.6151620, -167.6177446>,
    <0.6111111, -167.5563664>,
    <0.6171723, -167.5563642>,
    <0.6229626, -167.6179095>,
    <0.6273101, -167.6559815>,
    <0.6203704, -167.6342972>,
    <0.6249757, -167.6051824>,
    <0.6388889, -167.6922232>,
    <0.6250054, -167.6922232>,
    <0.6229626, -167.6179095>,
    <0.6327961, -167.6541068>,
    <0.6328146, -167.6922232>,
    <0.6229798, -167.6669079>,
    <0.6168995, -167.6559035>,
    <0.6203704, -167.6342972>,
    <0.6250054, -167.6922232>,
    <0.6111111, -167.6922232>,
    <0.6111111, -167.6048705>,
    <0.6229798, -167.6669079>,
    <0.6171911, -167.6922232>,
    <0.6111111, -167.6541051>,
    <0.6151620, -167.6177446>,
    <0.6226811, -167.5546111>,
    <0.6296296, -167.5763713>,
    <0.6249757, -167.6051824>,
    <0.6111111, -167.5184453>,
    <0.6250079, -167.5184453>,
    <0.6270090, -167.5925951>,
    <0.6171723, -167.5563642>,
    <0.6171924, -167.5184453>,
    <0.6270283, -167.5437683>,
    <0.6331038, -167.5545331>,
    <0.6296296, -167.5763713>,
    <0.6250079, -167.5184453>,
    <0.6388889, -167.5184453>,
    <0.6388889, -167.6048705>,
    <0.6270283, -167.5437683>,
    <0.6328158, -167.5184453>,
    <0.6388889, -167.5563664>,
    <0.6348344, -167.5923911>,
    <0.6330958, -167.6196618>,
    <0.6296296, -167.5763713>,
    <0.6388889, -167.6048705>,
    <0.6388889, -167.6922232>,
    <0.6249757, -167.6051824>,
    <0.6348344, -167.5923911>,
    <0.6388889, -167.6541051>,
    <0.6327961, -167.6541068>,
    <0.6270090, -167.5925951>,
    <0.3668926, -167.6341061>,
    <0.3703704, -167.6737665>,
    <0.3749776, -167.6473117>,
    <0.3611111, -167.5684558>,
    <0.3611111, -167.6468904>,
    <0.3729637, -167.6588757>,
    <0.3671736, -167.6029317>,
    <0.3611111, -167.6028579>,
    <0.3651621, -167.6586490>,
    <0.3668994, -167.6933751>,
    <0.3703704, -167.6737665>,
    <0.3611111, -167.6468904>,
    <0.3611111, -167.7264218>,
    <0.3750049, -167.7264218>,
    <0.3651621, -167.6586490>,
    <0.3611111, -167.6917086>,
    <0.3671908, -167.7264218>,
    <0.3729794, -167.7034090>,
    <0.3773104, -167.6934805>,
    <0.3703704, -167.6737665>,
    <0.3750049, -167.7264218>,
    <0.3888889, -167.7264218>,
    <0.3749776, -167.6473117>,
    <0.3729794, -167.7034090>,
    <0.3828142, -167.7264218>,
    <0.3827973, -167.6917804>,
    <0.3729637, -167.6588757>,
    <0.3726715, -167.7614105>,
    <0.3796296, -167.7825485>,
    <0.3750049, -167.7264218>,
    <0.3611111, -167.7264218>,
    <0.3749402, -167.8102497>,
    <0.3770244, -167.7509310>,
    <0.3671908, -167.7264218>,
    <0.3671515, -167.7630365>,
    <0.3769893, -167.7981456>,
    <0.3830869, -167.8234885>,
    <0.3796296, -167.7825485>,
    <0.3749402, -167.8102497>,
    <0.3888889, -167.8948019>,
    <0.3888889, -167.8063538>,
    <0.3769893, -167.7981456>,
    <0.3828583, -167.8582467>,
    <0.3888889, -167.8568003>,
    <0.3848349, -167.7959312>,
    <0.3831031, -167.7604365>,
    <0.3796296, -167.7825485>,
    <0.3888889, -167.8063538>,
    <0.3888889, -167.7264218>,
    <0.3750049, -167.7264218>,
    <0.3848349, -167.7959312>,
    <0.3888889, -167.7609681>,
    <0.3828142, -167.7264218>,
    <0.3770244, -167.7509310>,
    <0.6168810, -167.7953929>,
    <0.6203704, -167.8386752>,
    <0.6249312, -167.8101950>,
    <0.6111111, -167.7264218>,
    <0.6111111, -167.8062795>,
    <0.6229366, -167.8226506>,
    <0.6171464, -167.7630060>,
    <0.6111111, -167.7609300>,
    <0.6151569, -167.8204347>,
    <0.6169026, -167.8586396>,
    <0.6203704, -167.8386752>,
    <0.6111111, -167.8062795>,
    <0.6111111, -167.8948019>,
    <0.6250179, -167.8948019>,
    <0.6151569, -167.8204347>,
    <0.6111111, -167.8563340>,
    <0.6170788, -167.8948019>,
    <0.6230054, -167.8704981>,
    <0.6273021, -167.8596185>,
    <0.6203704, -167.8386752>,
    <0.6250179, -167.8948019>,
    <0.6388889, -167.8948019>,
    <0.6249312, -167.8101950>,
    <0.6230054, -167.8704981>,
    <0.6329094, -167.8948019>,
    <0.6328249, -167.8580436>,
    <0.6229366, -167.8226506>,
    <0.6226692, -167.7613968>,
    <0.6296296, -167.7825485>,
    <0.6250049, -167.7264218>,
    <0.6111111, -167.7264218>,
    <0.6249312, -167.8101950>,
    <0.6270241, -167.7509279>,
    <0.6171908, -167.7264218>,
    <0.6171464, -167.7630060>,
    <0.6269842, -167.7981150>,
    <0.6330847, -167.8234572>,
    <0.6296296, -167.7825485>,
    <0.6249312, -167.8101950>,
    <0.6388889, -167.8948019>,
    <0.6388889, -167.8062834>,
    <0.6269842, -167.7981150>,
    <0.6328249, -167.8580436>,
    <0.6388889, -167.8563347>,
    <0.6348349, -167.7958915>,
    <0.6331031, -167.7604189>,
    <0.6296296, -167.7825485>,
    <0.6388889, -167.8062834>,
    <0.6388889, -167.7264218>,
    <0.6250049, -167.7264218>,
    <0.6348349, -167.7958915>,
    <0.6388889, -167.7609320>,
    <0.6328142, -167.7264218>,
    <0.6270241, -167.7509279>,
    <0.3668905, -167.4848985>,
    <0.3703704, -167.5208549>,
    <0.3749694, -167.4968970>,
    <0.3611111, -167.4256532>,
    <0.3611111, -167.4961890>,
    <0.3729589, -167.5073705>,
    <0.3671682, -167.4567920>,
    <0.3611111, -167.4566011>,
    <0.3651615, -167.5069791>,
    <0.3668999, -167.5384889>,
    <0.3703704, -167.5208549>,
    <0.3611111, -167.4961890>,
    <0.3611111, -167.5684558>,
    <0.3750071, -167.5684558>,
    <0.3651615, -167.5069791>,
    <0.3611111, -167.5369298>,
    <0.3671920, -167.5684558>,
    <0.3729806, -167.5476517>,
    <0.3773089, -167.5386659>,
    <0.3703704, -167.5208549>,
    <0.3750071, -167.5684558>,
    <0.3888889, -167.5684558>,
    <0.3749694, -167.4968970>,
    <0.3729806, -167.5476517>,
    <0.3828154, -167.5684558>,
    <0.3827919, -167.5371117>,
    <0.3729589, -167.5073705>,
    <0.3726814, -167.6013336>,
    <0.3796296, -167.6211112>,
    <0.3750071, -167.5684558>,
    <0.3611111, -167.5684558>,
    <0.3749776, -167.6473117>,
    <0.3770277, -167.5914725>,
    <0.3671920, -167.5684558>,
    <0.3671736, -167.6029317>,
    <0.3770101, -167.6358644>,
    <0.3830963, -167.6604338>,
    <0.3796296, -167.6211112>,
    <0.3749776, -167.6473117>,
    <0.3888889, -167.7264218>,
    <0.3888889, -167.6468904>,
    <0.3770101, -167.6358644>,
    <0.3827973, -167.6917804>,
    <0.3888889, -167.6917086>,
    <0.3848346, -167.6356026>,
    <0.3831036, -167.6012283>,
    <0.3796296, -167.6211112>,
    <0.3888889, -167.6468904>,
    <0.3888889, -167.5684558>,
    <0.3750071, -167.5684558>,
    <0.3848346, -167.6356026>,
    <0.3888889, -167.6028579>,
    <0.3828154, -167.5684558>,
    <0.3770277, -167.5914725>,
    <0.6168926, -167.6341061>,
    <0.6203704, -167.6737665>,
    <0.6249776, -167.6473117>,
    <0.6111111, -167.5684558>,
    <0.6111111, -167.6468904>,
    <0.6229637, -167.6588757>,
    <0.6171736, -167.6029317>,
    <0.6111111, -167.6028579>,
    <0.6151622, -167.6586490>,
    <0.6168994, -167.6933751>,
    <0.6203704, -167.6737665>,
    <0.6111111, -167.6468904>,
    <0.6111111, -167.7264218>,
    <0.6250049, -167.7264218>,
    <0.6151622, -167.6586490>,
    <0.6111111, -167.6917086>,
    <0.6171908, -167.7264218>,
    <0.6229794, -167.7034090>,
    <0.6273105, -167.6934805>,
    <0.6203704, -167.6737665>,
    <0.6250049, -167.7264218>,
    <0.6388889, -167.7264218>,
    <0.6249776, -167.6473117>,
    <0.6229794, -167.7034090>,
    <0.6328142, -167.7264218>,
    <0.6327973, -167.6917804>,
    <0.6229637, -167.6588757>,
    <0.6226814, -167.6013336>,
    <0.6296296, -167.6211112>,
    <0.6250071, -167.5684558>,
    <0.6111111, -167.5684558>,
    <0.6249776, -167.6473117>,
    <0.6270277, -167.5914725>,
    <0.6171920, -167.5684558>,
    <0.6171736, -167.6029317>,
    <0.6270101, -167.6358644>,
    <0.6330963, -167.6604338>,
    <0.6296296, -167.6211112>,
    <0.6249776, -167.6473117>,
    <0.6388889, -167.7264218>,
    <0.6388889, -167.6468904>,
    <0.6270101, -167.6358644>,
    <0.6327973, -167.6917804>,
    <0.6388889, -167.6917086>,
    <0.6348346, -167.6356026>,
    <0.6331036, -167.6012283>,
    <0.6296296, -167.6211112>,
    <0.6388889, -167.6468904>,
    <0.6388889, -167.5684558>,
    <0.6250071, -167.5684558>,
    <0.6348346, -167.6356026>,
    <0.6388889, -167.6028579>,
    <0.6328154, -167.5684558>,
    <0.6270277, -167.5914725>,
    <0.3668877, -167.2819570>,
    <0.3703704, -167.3161845>,
    <0.3611111, -167.2924560>,
    <0.3611111, -167.2258020>,
    <0.3749584, -167.2933857>,
    <0.3651607, -167.3028339>,
    <0.3611111, -167.2550533>,
    <0.3671610, -167.2553296>,
    <0.3729524, -167.3033535>,
    <0.3773069, -167.3330804>,
    <0.3703704, -167.3161845>,
    <0.3749584, -167.2933857>,
    <0.3888889, -167.3613758>,
    <0.3750100, -167.3613758>,
    <0.3729524, -167.3033535>,
    <0.3827847, -167.3315832>,
    <0.3828169, -167.3613758>,
    <0.3729822, -167.3416247>,
    <0.3669006, -167.3328480>,
    <0.3703704, -167.3161845>,
    <0.3750100, -167.3613758>,
    <0.3611111, -167.3613758>,
    <0.3611111, -167.2924560>,
    <0.3729822, -167.3416247>,
    <0.3671935, -167.3613758>,
    <0.3611111, -167.3313235>,
    <0.3651607, -167.3028339>,
    <0.3726793, -167.3940515>,
    <0.3796296, -167.4137323>,
    <0.3749667, -167.4397221>,
    <0.3611111, -167.3613758>,
    <0.3750100, -167.3613758>,
    <0.3770037, -167.4283682>,
    <0.3671664, -167.3956156>,
    <0.3671935, -167.3613758>,
    <0.3770294, -167.3842624>,
    <0.3831043, -167.3939086>,
    <0.3796296, -167.4137323>,
    <0.3750100, -167.3613758>,
    <0.3888889, -167.3613758>,
    <0.3888889, -167.4391507>,
    <0.3770294, -167.3842624>,
    <0.3828169, -167.3613758>,
    <0.3888889, -167.3955180>,
    <0.3848338, -167.4280187>,
    <0.3830935, -167.4527626>,
    <0.3796296, -167.4137323>,
    <0.3888889, -167.4391507>,
    <0.3888889, -167.5184453>,
    <0.3749667, -167.4397221>,
    <0.3848338, -167.4280187>,
    <0.3888889, -167.4838674>,
    <0.3827902, -167.4839601>,
    <0.3770037, -167.4283682>,
    <0.6168898, -167.4265843>,
    <0.6203704, -167.4660888>,
    <0.6111111, -167.4391506>,
    <0.6111111, -167.3613758>,
    <0.6249667, -167.4397221>,
    <0.6151614, -167.4509341>,
    <0.6111111, -167.3955180>,
    <0.6171664, -167.3956156>,
    <0.6229573, -167.4512490>,
    <0.6273085, -167.4856754>,
    <0.6203704, -167.4660888>,
    <0.6249667, -167.4397221>,
    <0.6388889, -167.5184453>,
    <0.6250079, -167.5184453>,
    <0.6229573, -167.4512490>,
    <0.6327902, -167.4839601>,
    <0.6328158, -167.5184453>,
    <0.6229812, -167.4955641>,
    <0.6169001, -167.4855325>,
    <0.6203704, -167.4660888>,
    <0.6250079, -167.5184453>,
    <0.6111111, -167.5184453>,
    <0.6111111, -167.4391506>,
    <0.6229812, -167.4955641>,
    <0.6171924, -167.5184453>,
    <0.6111111, -167.4838674>,
    <0.6151614, -167.4509341>,
    <0.6226794, -167.3940515>,
    <0.6296296, -167.4137323>,
    <0.6249667, -167.4397221>,
    <0.6111111, -167.3613758>,
    <0.6250100, -167.3613758>,
    <0.6270037, -167.4283682>,
    <0.6171664, -167.3956156>,
    <0.6171935, -167.3613758>,
    <0.6270294, -167.3842624>,
    <0.6331044, -167.3939086>,
    <0.6296296, -167.4137323>,
    <0.6250100, -167.3613758>,
    <0.6388889, -167.3613758>,
    <0.6388889, -167.4391507>,
    <0.6270294, -167.3842624>,
    <0.6328169, -167.3613758>,
    <0.6388889, -167.3955180>,
    <0.6348338, -167.4280187>,
    <0.6330935, -167.4527626>,
    <0.6296296, -167.4137323>,
    <0.6388889, -167.4391507>,
    <0.6388889, -167.5184453>,
    <0.6249667, -167.4397221>,
    <0.6348338, -167.4280187>,
    <0.6388889, -167.4838674>,
    <0.6327902, -167.4839601>,
    <0.6270037, -167.4283682>,
    <0.3668886, -167.3534027>,
    <0.3703704, -167.3845690>,
    <0.3749618, -167.3638575>,
    <0.3611111, -167.3024008>,
    <0.3611111, -167.3627833>,
    <0.3729545, -167.3729124>,
    <0.3671633, -167.3292549>,
    <0.3611111, -167.3288803>,
    <0.3651610, -167.3723121>,
    <0.3669004, -167.3996647>,
    <0.3703704, -167.3845690>,
    <0.3611111, -167.3627833>,
    <0.3611111, -167.4256532>,
    <0.3750090, -167.4256532>,
    <0.3651610, -167.3723121>,
    <0.3611111, -167.3982231>,
    <0.3671930, -167.4256532>,
    <0.3729815, -167.4076960>,
    <0.3773075, -167.3999332>,
    <0.3703704, -167.3845690>,
    <0.3750090, -167.4256532>,
    <0.3888889, -167.4256532>,
    <0.3749618, -167.3638575>,
    <0.3729815, -167.4076960>,
    <0.3828163, -167.4256532>,
    <0.3827869, -167.3985780>,
    <0.3729545, -167.3729124>,
    <0.3726798, -167.4553644>,
    <0.3796296, -167.4732541>,
    <0.3750090, -167.4256532>,
    <0.3611111, -167.4256532>,
    <0.3749694, -167.4968970>,
    <0.3770286, -167.4464590>,
    <0.3671930, -167.4256532>,
    <0.3671682, -167.4567920>,
    <0.3770054, -167.4865678>,
    <0.3830942, -167.5086990>,
    <0.3796296, -167.4732541>,
    <0.3749694, -167.4968970>,
    <0.3888889, -167.5684558>,
    <0.3888889, -167.4961890>,
    <0.3770054, -167.4865678>,
    <0.3827919, -167.5371117>,
    <0.3888889, -167.5369298>,
    <0.3848340, -167.4861453>,
    <0.3831041, -167.4551874>,
    <0.3796296, -167.4732541>,
    <0.3888889, -167.4961890>,
    <0.3888889, -167.4256532>,
    <0.3750090, -167.4256532>,
    <0.3848340, -167.4861453>,
    <0.3888889, -167.4566011>,
    <0.3828163, -167.4256532>,
    <0.3770286, -167.4464590>,
    <0.6168905, -167.4848985>,
    <0.6203704, -167.5208549>,
    <0.6249694, -167.4968970>,
    <0.6111111, -167.4256532>,
    <0.6111111, -167.4961890>,
    <0.6229589, -167.5073705>,
    <0.6171682, -167.4567920>,
    <0.6111111, -167.4566011>,
    <0.6151615, -167.5069791>,
    <0.6168999, -167.5384889>,
    <0.6203704, -167.5208549>,
    <0.6111111, -167.4961890>,
    <0.6111111, -167.5684558>,
    <0.6250071, -167.5684558>,
    <0.6151615, -167.5069791>,
    <0.6111111, -167.5369298>,
    <0.6171920, -167.5684558>,
    <0.6229806, -167.5476517>,
    <0.6273089, -167.5386659>,
    <0.6203704, -167.5208549>,
    <0.6250071, -167.5684558>,
    <0.6388889, -167.5684558>,
    <0.6249694, -167.4968970>,
    <0.6229806, -167.5476517>,
    <0.6328154, -167.5684558>,
    <0.6327919, -167.5371117>,
    <0.6229589, -167.5073705>,
    <0.6226798, -167.4553644>,
    <0.6296296, -167.4732541>,
    <0.6250090, -167.4256532>,
    <0.6111111, -167.4256532>,
    <0.6249694, -167.4968970>,
    <0.6270286, -167.4464590>,
    <0.6171930, -167.4256532>,
    <0.6171682, -167.4567920>,
    <0.6270054, -167.4865678>,
    <0.6330942, -167.5086990>,
    <0.6296296, -167.4732541>,
    <0.6249694, -167.4968970>,
    <0.6388889, -167.5684558>,
    <0.6388889, -167.4961890>,
    <0.6270054, -167.4865678>,
    <0.6327919, -167.5371117>,
    <0.6388889, -167.5369298>,
    <0.6348340, -167.4861453>,
    <0.6331041, -167.4551874>,
    <0.6296296, -167.4732541>,
    <0.6388889, -167.4961890>,
    <0.6388889, -167.4256532>,
    <0.6250090, -167.4256532>,
    <0.6348340, -167.4861453>,
    <0.6388889, -167.4566011>,
    <0.6328163, -167.4256532>,
    <0.6270286, -167.4464590>,
    <0.3668111, -167.1603088>,
    <0.3703704, -167.1891429>,
    <0.3611111, -167.1668335>,
    <0.3611111, -167.1158246>,
    <0.3746517, -167.1694344>,
    <0.3651640, -167.1765987>,
    <0.3611111, -167.1355784>,
    <0.3668244, -167.1384446>,
    <0.3727829, -167.1780370>,
    <0.3772307, -167.2025453>,
    <0.3703704, -167.1891429>,
    <0.3746517, -167.1694344>,
    <0.3888889, -167.2258020>,
    <0.3750117, -167.2258020>,
    <0.3727829, -167.1780370>,
    <0.3826156, -167.2009650>,
    <0.3828177, -167.2258020>,
    <0.3729737, -167.2097050>,
    <0.3669011, -167.2018951>,
    <0.3703704, -167.1891429>,
    <0.3750117, -167.2258020>,
    <0.3611111, -167.2258020>,
    <0.3611111, -167.1668335>,
    <0.3729737, -167.2097050>,
    <0.3671945, -167.2258020>,
    <0.3611111, -167.1999174>,
    <0.3651640, -167.1765987>,
    <0.3726777, -167.2539957>,
    <0.3796296, -167.2709932>,
    <0.3749584, -167.2933857>,
    <0.3611111, -167.2258020>,
    <0.3750117, -167.2258020>,
    <0.3769990, -167.2836036>,
    <0.3671610, -167.2553296>,
    <0.3671945, -167.2258020>,
    <0.3770300, -167.2455535>,
    <0.3831048, -167.2537633>,
    <0.3796296, -167.2709932>,
    <0.3750117, -167.2258020>,
    <0.3888889, -167.2258020>,
    <0.3888889, -167.2924560>,
    <0.3770300, -167.2455535>,
    <0.3828177, -167.2258020>,
    <0.3888889, -167.2550533>,
    <0.3848333, -167.2830552>,
    <0.3830914, -167.3045527>,
    <0.3796296, -167.2709932>,
    <0.3888889, -167.2924560>,
    <0.3888889, -167.3613758>,
    <0.3749584, -167.2933857>,
    <0.3848333, -167.2830552>,
    <0.3888889, -167.3313235>,
    <0.3827847, -167.3315832>,
    <0.3769990, -167.2836036>,
    <0.6168877, -167.2819570>,
    <0.6203704, -167.3161845>,
    <0.6111111, -167.2924560>,
    <0.6111111, -167.2258020>,
    <0.6249584, -167.2933857>,
    <0.6151608, -167.3028339>,
    <0.6111111, -167.2550533>,
    <0.6171610, -167.2553296>,
    <0.6229525, -167.3033535>,
    <0.6273069, -167.3330804>,
    <0.6203704, -167.3161845>,
    <0.6249584, -167.2933857>,
    <0.6388889, -167.3613758>,
    <0.6250100, -167.3613758>,
    <0.6229525, -167.3033535>,
    <0.6327847, -167.3315832>,
    <0.6328169, -167.3613758>,
    <0.6229822, -167.3416247>,
    <0.6169007, -167.3328480>,
    <0.6203704, -167.3161845>,
    <0.6250100, -167.3613758>,
    <0.6111111, -167.3613758>,
    <0.6111111, -167.2924560>,
    <0.6229822, -167.3416247>,
    <0.6171935, -167.3613758>,
    <0.6111111, -167.3313235>,
    <0.6151608, -167.3028339>,
    <0.6226777, -167.2539957>,
    <0.6296296, -167.2709932>,
    <0.6249584, -167.2933857>,
    <0.6111111, -167.2258020>,
    <0.6250117, -167.2258020>,
    <0.6269990, -167.2836036>,
    <0.6171610, -167.2553296>,
    <0.6171945, -167.2258020>,
    <0.6270301, -167.2455535>,
    <0.6331048, -167.2537633>,
    <0.6296296, -167.2709932>,
    <0.6250117, -167.2258020>,
    <0.6388889, -167.2258020>,
    <0.6388889, -167.2924560>,
    <0.6270301, -167.2455535>,
    <0.6328177, -167.2258020>,
    <0.6388889, -167.2550533>,
    <0.6348333, -167.2830552>,
    <0.6330915, -167.3045527>,
    <0.6296296, -167.2709932>,
    <0.6388889, -167.2924560>,
    <0.6388889, -167.3613758>,
    <0.6249584, -167.2933857>,
    <0.6348333, -167.2830552>,
    <0.6388889, -167.3313235>,
    <0.6327847, -167.3315832>,
    <0.6269990, -167.2836036>,
    <0.3668870, -167.2436308>,
    <0.3703704, -167.2690732>,
    <0.3749552, -167.2522483>,
    <0.3611111, -167.2024179>,
    <0.3611111, -167.2507837>,
    <0.3729507, -167.2596042>,
    <0.3671590, -167.2241867>,
    <0.3611111, -167.2235884>,
    <0.3651605, -167.2587824>,
    <0.3669008, -167.2811646>,
    <0.3703704, -167.2690732>,
    <0.3611111, -167.2507837>,
    <0.3611111, -167.3024008>,
    <0.3750106, -167.3024008>,
    <0.3651605, -167.2587824>,
    <0.3611111, -167.2798504>,
    <0.3671939, -167.3024008>,
    <0.3729822, -167.2878319>,
    <0.3773063, -167.2815307>,
    <0.3703704, -167.2690732>,
    <0.3750106, -167.3024008>,
    <0.3888889, -167.3024008>,
    <0.3749552, -167.2522483>,
    <0.3729822, -167.2878319>,
    <0.3828171, -167.3024008>,
    <0.3827825, -167.2804214>,
    <0.3729507, -167.2596042>,
    <0.3726783, -167.3280360>,
    <0.3796296, -167.3434849>,
    <0.3750106, -167.3024008>,
    <0.3611111, -167.3024008>,
    <0.3749618, -167.3638575>,
    <0.3770292, -167.3203558>,
    <0.3671939, -167.3024008>,
    <0.3671633, -167.3292549>,
    <0.3770010, -167.3549573>,
    <0.3830923, -167.3739447>,
    <0.3796296, -167.3434849>,
    <0.3749618, -167.3638575>,
    <0.3888889, -167.4256532>,
    <0.3888889, -167.3627833>,
    <0.3770010, -167.3549573>,
    <0.3827869, -167.3985780>,
    <0.3888889, -167.3982231>,
    <0.3848336, -167.3543311>,
    <0.3831045, -167.3277674>,
    <0.3796296, -167.3434849>,
    <0.3888889, -167.3627833>,
    <0.3888889, -167.3024008>,
    <0.3750106, -167.3024008>,
    <0.3848336, -167.3543311>,
    <0.3888889, -167.3288803>,
    <0.3828171, -167.3024008>,
    <0.3770292, -167.3203558>,
    <0.6168886, -167.3534027>,
    <0.6203704, -167.3845690>,
    <0.6249618, -167.3638575>,
    <0.6111111, -167.3024008>,
    <0.6111111, -167.3627833>,
    <0.6229545, -167.3729124>,
    <0.6171633, -167.3292549>,
    <0.6111111, -167.3288803>,
    <0.6151610, -167.3723121>,
    <0.6169004, -167.3996647>,
    <0.6203704, -167.3845690>,
    <0.6111111, -167.3627833>,
    <0.6111111, -167.4256532>,
    <0.6250090, -167.4256532>,
    <0.6151610, -167.3723121>,
    <0.6111111, -167.3982231>,
    <0.6171930, -167.4256532>,
    <0.6229815, -167.4076960>,
    <0.6273075, -167.3999332>,
    <0.6203704, -167.3845690>,
    <0.6250090, -167.4256532>,
    <0.6388889, -167.4256532>,
    <0.6249618, -167.3638575>,
    <0.6229815, -167.4076960>,
    <0.6328163, -167.4256532>,
    <0.6327869, -167.3985780>,
    <0.6229545, -167.3729124>,
    <0.6226783, -167.3280360>,
    <0.6296296, -167.3434849>,
    <0.6250106, -167.3024008>,
    <0.6111111, -167.3024008>,
    <0.6249618, -167.3638575>,
    <0.6270293, -167.3203558>,
    <0.6171939, -167.3024008>,
    <0.6171633, -167.3292549>,
    <0.6270011, -167.3549573>,
    <0.6330923, -167.3739447>,
    <0.6296296, -167.3434849>,
    <0.6249618, -167.3638575>,
    <0.6388889, -167.4256532>,
    <0.6388889, -167.3627833>,
    <0.6270011, -167.3549573>,
    <0.6327869, -167.3985780>,
    <0.6388889, -167.3982231>,
    <0.6348336, -167.3543311>,
    <0.6331045, -167.3277674>,
    <0.6296296, -167.3434849>,
    <0.6388889, -167.3627833>,
    <0.6388889, -167.3024008>,
    <0.6250106, -167.3024008>,
    <0.6348336, -167.3543311>,
    <0.6388889, -167.3288803>,
    <0.6328171, -167.3024008>,
    <0.6270293, -167.3203558>,
    <0.3706671, -167.0805641>,
    <0.3741767, -167.0842391>,
    <0.3802704, -167.1011247>,
    <0.3611111, -167.0684463>,
    <0.3671103, -167.0684463>,
    <0.3781196, -167.0951650>,
    <0.3726859, -167.0881886>,
    <0.3641501, -167.0684463>,
    <0.3699477, -167.0747877>,
    <0.3740238, -167.0794525>,
    <0.3741767, -167.0842391>,
    <0.3671103, -167.0684463>,
    <0.3725301, -167.0684463>,
    <0.3822781, -167.0966785>,
    <0.3699477, -167.0747877>,
    <0.3699177, -167.0684463>,
    <0.3775240, -167.0829095>,
    <0.3782416, -167.0904806>,
    <0.3814035, -167.0994667>,
    <0.3741767, -167.0842391>,
    <0.3822781, -167.0966785>,
    <0.3888889, -167.1158246>,
    <0.3802704, -167.1011247>,
    <0.3782416, -167.0904806>,
    <0.3863201, -167.1083848>,
    <0.3854266, -167.1099193>,
    <0.3781196, -167.0951650>,
    <0.3682157, -167.0913743>,
    <0.3703704, -167.1000319>,
    <0.3611111, -167.0958943>,
    <0.3611111, -167.0684463>,
    <0.3802704, -167.1011247>,
    <0.3650941, -167.0976741>,
    <0.3611111, -167.0828767>,
    <0.3726859, -167.0881886>,
    <0.3752349, -167.1005689>,
    <0.3784869, -167.1082015>,
    <0.3703704, -167.1000319>,
    <0.3802704, -167.1011247>,
    <0.3888889, -167.1158246>,
    <0.3744180, -167.1158246>,
    <0.3752349, -167.1005689>,
    <0.3854266, -167.1099193>,
    <0.3826328, -167.1158246>,
    <0.3725283, -167.1084517>,
    <0.3667526, -167.1068939>,
    <0.3703704, -167.1000319>,
    <0.3744180, -167.1158246>,
    <0.3611111, -167.1158246>,
    <0.3611111, -167.0958943>,
    <0.3725283, -167.1084517>,
    <0.3665989, -167.1158246>,
    <0.3611111, -167.1102282>,
    <0.3650941, -167.0976741>,
    <0.3724526, -167.1383919>,
    <0.3796296, -167.1524837>,
    <0.3746517, -167.1694344>,
    <0.3611111, -167.1158246>,
    <0.3744180, -167.1158246>,
    <0.3768206, -167.1620488>,
    <0.3668244, -167.1384446>,
    <0.3665989, -167.1158246>,
    <0.3766758, -167.1317065>,
    <0.3829563, -167.1378791>,
    <0.3796296, -167.1524837>,
    <0.3744180, -167.1158246>,
    <0.3888889, -167.1158246>,
    <0.3888889, -167.1673834>,
    <0.3766758, -167.1317065>,
    <0.3826328, -167.1158246>,
    <0.3888889, -167.1360516>,
    <0.3848271, -167.1608473>,
    <0.3830148, -167.1787759>,
    <0.3796296, -167.1524837>,
    <0.3888889, -167.1673834>,
    <0.3888889, -167.2258020>,
    <0.3746517, -167.1694344>,
    <0.3848271, -167.1608473>,
    <0.3888889, -167.2002137>,
    <0.3826156, -167.2009650>,
    <0.3768206, -167.1620488>,
    <0.6168156, -167.1604642>,
    <0.6203704, -167.1891429>,
    <0.6111111, -167.1673836>,
    <0.6111111, -167.1158246>,
    <0.6246697, -167.1695056>,
    <0.6151638, -167.1769075>,
    <0.6111111, -167.1360519>,
    <0.6168409, -167.1385099>,
    <0.6227929, -167.1780778>,
    <0.6272352, -167.2025631>,
    <0.6203704, -167.1891429>,
    <0.6246697, -167.1695056>,
    <0.6388889, -167.2258020>,
    <0.6250117, -167.2258020>,
    <0.6227929, -167.1780778>,
    <0.6326256, -167.2010046>,
    <0.6328177, -167.2258020>,
    <0.6229743, -167.2097098>,
    <0.6169011, -167.2020326>,
    <0.6203704, -167.1891429>,
    <0.6250117, -167.2258020>,
    <0.6111111, -167.2258020>,
    <0.6111111, -167.1673836>,
    <0.6229743, -167.2097098>,
    <0.6171945, -167.2258020>,
    <0.6111111, -167.2002138>,
    <0.6151638, -167.1769075>,
    <0.6224618, -167.1384097>,
    <0.6296296, -167.1524837>,
    <0.6246697, -167.1695056>,
    <0.6111111, -167.1158246>,
    <0.6244368, -167.1158246>,
    <0.6268305, -167.1620899>,
    <0.6168409, -167.1385099>,
    <0.6166086, -167.1158246>,
    <0.6266863, -167.1317049>,
    <0.6329611, -167.1378563>,
    <0.6296296, -167.1524837>,
    <0.6244368, -167.1158246>,
    <0.6388889, -167.1158246>,
    <0.6388889, -167.1672922>,
    <0.6266863, -167.1317049>,
    <0.6326450, -167.1158246>,
    <0.6388889, -167.1360023>,
    <0.6348275, -167.1607968>,
    <0.6330193, -167.1787709>,
    <0.6296296, -167.1524837>,
    <0.6388889, -167.1672922>,
    <0.6388889, -167.2258020>,
    <0.6246697, -167.1695056>,
    <0.6348275, -167.1607968>,
    <0.6388889, -167.2001584>,
    <0.6326256, -167.2010046>,
    <0.6268305, -167.1620899>,
    <0.3669579, -167.1583892>,
    <0.3703704, -167.1778641>,
    <0.3752390, -167.1662210>,
    <0.3611111, -167.1287564>,
    <0.3611111, -167.1607152>,
    <0.3731176, -167.1712941>,
    <0.3673683, -167.1453493>,
    <0.3611111, -167.1413911>,
    <0.3651679, -167.1682286>,
    <0.3669011, -167.1858538>,
    <0.3703704, -167.1778641>,
    <0.3611111, -167.1607152>,
    <0.3611111, -167.2024179>,
    <0.3750118, -167.2024179>,
    <0.3651679, -167.1682286>,
    <0.3611111, -167.1838307>,
    <0.3671946, -167.2024179>,
    <0.3729907, -167.1917260>,
    <0.3773775, -167.1872302>,
    <0.3703704, -167.1778641>,
    <0.3750118, -167.2024179>,
    <0.3888889, -167.2024179>,
    <0.3752390, -167.1662210>,
    <0.3729907, -167.1917260>,
    <0.3828177, -167.2024179>,
    <0.3829485, -167.1866652>,
    <0.3731176, -167.1712941>,
    <0.3726769, -167.2232074>,
    <0.3796296, -167.2357456>,
    <0.3750118, -167.2024179>,
    <0.3611111, -167.2024179>,
    <0.3749552, -167.2522483>,
    <0.3770295, -167.2169804>,
    <0.3671946, -167.2024179>,
    <0.3671590, -167.2241867>,
    <0.3769973, -167.2450388>,
    <0.3830907, -167.2602946>,
    <0.3796296, -167.2357456>,
    <0.3749552, -167.2522483>,
    <0.3888889, -167.3024008>,
    <0.3888889, -167.2507837>,
    <0.3769973, -167.2450388>,
    <0.3827825, -167.2804214>,
    <0.3888889, -167.2798504>,
    <0.3848332, -167.2441968>,
    <0.3831048, -167.2228413>,
    <0.3796296, -167.2357456>,
    <0.3888889, -167.2507837>,
    <0.3888889, -167.2024179>,
    <0.3750118, -167.2024179>,
    <0.3848332, -167.2441968>,
    <0.3888889, -167.2235884>,
    <0.3828177, -167.2024179>,
    <0.3770295, -167.2169804>,
    <0.6168870, -167.2436308>,
    <0.6203704, -167.2690732>,
    <0.6249553, -167.2522483>,
    <0.6111111, -167.2024179>,
    <0.6111111, -167.2507837>,
    <0.6229507, -167.2596042>,
    <0.6171590, -167.2241867>,
    <0.6111111, -167.2235884>,
    <0.6151605, -167.2587824>,
    <0.6169008, -167.2811646>,
    <0.6203704, -167.2690732>,
    <0.6111111, -167.2507837>,
    <0.6111111, -167.3024008>,
    <0.6250106, -167.3024008>,
    <0.6151605, -167.2587824>,
    <0.6111111, -167.2798504>,
    <0.6171939, -167.3024008>,
    <0.6229822, -167.2878319>,
    <0.6273063, -167.2815307>,
    <0.6203704, -167.2690732>,
    <0.6250106, -167.3024008>,
    <0.6388889, -167.3024008>,
    <0.6249553, -167.2522483>,
    <0.6229822, -167.2878319>,
    <0.6328171, -167.3024008>,
    <0.6327825, -167.2804214>,
    <0.6229507, -167.2596042>,
    <0.6226770, -167.2232074>,
    <0.6296296, -167.2357456>,
    <0.6250118, -167.2024179>,
    <0.6111111, -167.2024179>,
    <0.6249553, -167.2522483>,
    <0.6270296, -167.2169804>,
    <0.6171946, -167.2024179>,
    <0.6171590, -167.2241867>,
    <0.6269973, -167.2450388>,
    <0.6330907, -167.2602946>,
    <0.6296296, -167.2357456>,
    <0.6249553, -167.2522483>,
    <0.6388889, -167.3024008>,
    <0.6388889, -167.2507837>,
    <0.6269973, -167.2450388>,
    <0.6327825, -167.2804214>,
    <0.6388889, -167.2798504>,
    <0.6348332, -167.2441968>,
    <0.6331048, -167.2228413>,
    <0.6296296, -167.2357456>,
    <0.6388889, -167.2507837>,
    <0.6388889, -167.2024179>,
    <0.6250118, -167.2024179>,
    <0.6348332, -167.2441968>,
    <0.6388889, -167.2235884>,
    <0.6328177, -167.2024179>,
    <0.6270296, -167.2169804>,
    <0.3798192, -167.0794525>,
    <0.3834360, -167.0842391>,
    <0.3822781, -167.0966785>,
    <0.3725301, -167.0684463>,
    <0.3810326, -167.0684463>,
    <0.3827389, -167.0917276>,
    <0.3775240, -167.0829095>,
    <0.3769135, -167.0684463>,
    <0.3820784, -167.0753181>,
    <0.3855616, -167.0788822>,
    <0.3834360, -167.0842391>,
    <0.3810326, -167.0684463>,
    <0.3888889, -167.0684463>,
    <0.3888889, -167.0943971>,
    <0.3820784, -167.0753181>,
    <0.3849985, -167.0684463>,
    <0.3888889, -167.0814793>,
    <0.3865861, -167.0901074>,
    <0.3858730, -167.0977848>,
    <0.3834360, -167.0842391>,
    <0.3888889, -167.0943971>,
    <0.3888889, -167.1158246>,
    <0.3822781, -167.0966785>,
    <0.3865861, -167.0901074>,
    <0.3888889, -167.1096992>,
    <0.3863201, -167.1083848>,
    <0.3827389, -167.0917276>,
    <0.6182128, -167.0909949>,
    <0.6203704, -167.1000319>,
    <0.6111111, -167.0943969>,
    <0.6111111, -167.0684463>,
    <0.6302586, -167.1011046>,
    <0.6151121, -167.0968318>,
    <0.6111111, -167.0814789>,
    <0.6226564, -167.0881381>,
    <0.6252413, -167.1005603>,
    <0.6284887, -167.1081965>,
    <0.6203704, -167.1000319>,
    <0.6302586, -167.1011046>,
    <0.6388889, -167.1158246>,
    <0.6244368, -167.1158246>,
    <0.6252413, -167.1005603>,
    <0.6354217, -167.1099109>,
    <0.6326450, -167.1158246>,
    <0.6225418, -167.1084649>,
    <0.6167573, -167.1065195>,
    <0.6203704, -167.1000319>,
    <0.6244368, -167.1158246>,
    <0.6111111, -167.1158246>,
    <0.6111111, -167.0943969>,
    <0.6225418, -167.1084649>,
    <0.6166086, -167.1158246>,
    <0.6111111, -167.1096993>,
    <0.6151121, -167.0968318>,
    <0.6206630, -167.0805591>,
    <0.6241767, -167.0842391>,
    <0.6302586, -167.1011046>,
    <0.6111111, -167.0684463>,
    <0.6171056, -167.0684463>,
    <0.6281110, -167.0951493>,
    <0.6226564, -167.0881381>,
    <0.6141470, -167.0684463>,
    <0.6199450, -167.0747878>,
    <0.6240233, -167.0794545>,
    <0.6241767, -167.0842391>,
    <0.6171056, -167.0684463>,
    <0.6225301, -167.0684463>,
    <0.6322808, -167.0966863>,
    <0.6199450, -167.0747878>,
    <0.6199142, -167.0684463>,
    <0.6275255, -167.0829140>,
    <0.6282424, -167.0904837>,
    <0.6314013, -167.0994637>,
    <0.6241767, -167.0842391>,
    <0.6322808, -167.0966863>,
    <0.6388889, -167.1158246>,
    <0.6302586, -167.1011046>,
    <0.6282424, -167.0904837>,
    <0.6363219, -167.1083900>,
    <0.6354217, -167.1099109>,
    <0.6281110, -167.0951493>,
    <0.3836027, -167.1106496>,
    <0.3825529, -167.1123151>,
    <0.3878867, -167.1220941>,
    <0.3851791, -167.1040945>,
    <0.3787922, -167.1040945>,
    <0.3851121, -167.1170071>,
    <0.3866387, -167.1137977>,
    <0.3817258, -167.1040945>,
    <0.3801802, -167.1071285>,
    <0.3800313, -167.1108242>,
    <0.3825529, -167.1123151>,
    <0.3787922, -167.1040945>,
    <0.3735908, -167.1040945>,
    <0.3851894, -167.1227925>,
    <0.3801802, -167.1071285>,
    <0.3761173, -167.1040945>,
    <0.3808747, -167.1158369>,
    <0.3842195, -167.1189382>,
    <0.3861295, -167.1214895>,
    <0.3825529, -167.1123151>,
    <0.3851894, -167.1227925>,
    <0.3888889, -167.1287564>,
    <0.3878867, -167.1220941>,
    <0.3842195, -167.1189382>,
    <0.3875395, -167.1265811>,
    <0.3886042, -167.1268636>,
    <0.3851121, -167.1170071>,
    <0.3743200, -167.1176326>,
    <0.3745302, -167.1205358>,
    <0.3851894, -167.1227925>,
    <0.3735907, -167.1040945>,
    <0.3639697, -167.1231074>,
    <0.3805086, -167.1218015>,
    <0.3808747, -167.1158369>,
    <0.3674630, -167.1162040>,
    <0.3688411, -167.1219212>,
    <0.3684104, -167.1252890>,
    <0.3745302, -167.1205358>,
    <0.3639697, -167.1231074>,
    <0.3611111, -167.1287564>,
    <0.3740304, -167.1287564>,
    <0.3688411, -167.1219212>,
    <0.3621491, -167.1267052>,
    <0.3663816, -167.1287564>,
    <0.3742082, -167.1258321>,
    <0.3806597, -167.1252103>,
    <0.3745302, -167.1205358>,
    <0.3740304, -167.1287564>,
    <0.3888889, -167.1287564>,
    <0.3851894, -167.1227925>,
    <0.3742082, -167.1258321>,
    <0.3824232, -167.1287564>,
    <0.3875395, -167.1265811>,
    <0.3805086, -167.1218015>,
    <0.3725025, -167.1442610>,
    <0.3796296, -167.1533103>,
    <0.3740304, -167.1287564>,
    <0.3611111, -167.1287564>,
    <0.3752390, -167.1662210>,
    <0.3767894, -167.1408553>,
    <0.3663816, -167.1287564>,
    <0.3673683, -167.1453493>,
    <0.3772174, -167.1604034>,
    <0.3831616, -167.1706661>,
    <0.3796296, -167.1533103>,
    <0.3752390, -167.1662210>,
    <0.3888889, -167.2024179>,
    <0.3888889, -167.1607153>,
    <0.3772174, -167.1604034>,
    <0.3829485, -167.1866652>,
    <0.3888889, -167.1838308>,
    <0.3849009, -167.1575259>,
    <0.3828595, -167.1428846>,
    <0.3796296, -167.1533103>,
    <0.3888889, -167.1607153>,
    <0.3888889, -167.1287564>,
    <0.3740304, -167.1287564>,
    <0.3849009, -167.1575259>,
    <0.3888889, -167.1413913>,
    <0.3824232, -167.1287564>,
    <0.3767894, -167.1408553>,
    <0.6184159, -167.1107626>,
    <0.6162233, -167.1123279>,
    <0.6142818, -167.1224956>,
    <0.6235909, -167.1041136>,
    <0.6195676, -167.1041136>,
    <0.6149748, -167.1188662>,
    <0.6179674, -167.1152179>,
    <0.6217151, -167.1041136>,
    <0.6184177, -167.1069379>,
    <0.6154718, -167.1101334>,
    <0.6162233, -167.1123279>,
    <0.6195676, -167.1041136>,
    <0.6139677, -167.1041136>,
    <0.6121287, -167.1199784>,
    <0.6184177, -167.1069379>,
    <0.6170550, -167.1041136>,
    <0.6130409, -167.1121091>,
    <0.6142835, -167.1159522>,
    <0.6134362, -167.1208896>,
    <0.6162233, -167.1123279>,
    <0.6121287, -167.1199784>,
    <0.6111111, -167.1287564>,
    <0.6142818, -167.1224956>,
    <0.6142835, -167.1159522>,
    <0.6114546, -167.1257934>,
    <0.6122677, -167.1264726>,
    <0.6149748, -167.1188662>,
    <0.6169812, -167.1582978>,
    <0.6203704, -167.1778641>,
    <0.6253323, -167.1664684>,
    <0.6111111, -167.1287564>,
    <0.6111111, -167.1601023>,
    <0.6231692, -167.1714363>,
    <0.6174690, -167.1456163>,
    <0.6111111, -167.1407348>,
    <0.6151668, -167.1678823>,
    <0.6169011, -167.1857006>,
    <0.6203704, -167.1778641>,
    <0.6111111, -167.1601023>,
    <0.6111111, -167.2024179>,
    <0.6250118, -167.2024179>,
    <0.6151668, -167.1678823>,
    <0.6111111, -167.1835237>,
    <0.6171946, -167.2024179>,
    <0.6229934, -167.1917403>,
    <0.6274008, -167.1872921>,
    <0.6203704, -167.1778641>,
    <0.6250118, -167.2024179>,
    <0.6388889, -167.2024179>,
    <0.6253323, -167.1664684>,
    <0.6229934, -167.1917403>,
    <0.6328177, -167.2024179>,
    <0.6329984, -167.1867974>,
    <0.6231692, -167.1714363>,
    <0.6244480, -167.1175675>,
    <0.6245303, -167.1205421>,
    <0.6353891, -167.1231188>,
    <0.6235909, -167.1041136>,
    <0.6142818, -167.1224956>,
    <0.6308120, -167.1220327>,
    <0.6312633, -167.1164728>,
    <0.6179674, -167.1152179>,
    <0.6191666, -167.1215645>,
    <0.6185336, -167.1251376>,
    <0.6245303, -167.1205421>,
    <0.6142818, -167.1224956>,
    <0.6111111, -167.1287564>,
    <0.6242112, -167.1287564>,
    <0.6191666, -167.1215645>,
    <0.6122677, -167.1264726>,
    <0.6164930, -167.1287564>,
    <0.6243170, -167.1260344>,
    <0.6307549, -167.1252934>,
    <0.6245303, -167.1205421>,
    <0.6242112, -167.1287564>,
    <0.6388889, -167.1287564>,
    <0.6353891, -167.1231188>,
    <0.6243170, -167.1260344>,
    <0.6325464, -167.1287564>,
    <0.6376133, -167.1267016>,
    <0.6308120, -167.1220327>,
    <0.6225711, -167.1443229>,
    <0.6296296, -167.1533103>,
    <0.6242112, -167.1287564>,
    <0.6111111, -167.1287564>,
    <0.6253323, -167.1664684>,
    <0.6268897, -167.1408940>,
    <0.6164930, -167.1287564>,
    <0.6174690, -167.1456163>,
    <0.6272703, -167.1605343>,
    <0.6331849, -167.1705748>,
    <0.6296296, -167.1533103>,
    <0.6253323, -167.1664684>,
    <0.6388889, -167.2024179>,
    <0.6388889, -167.1601026>,
    <0.6272703, -167.1605343>,
    <0.6329984, -167.1867974>,
    <0.6388889, -167.1835239>,
    <0.6349026, -167.1571784>,
    <0.6329047, -167.1427314>,
    <0.6296296, -167.1533103>,
    <0.6388889, -167.1601026>,
    <0.6388889, -167.1287564>,
    <0.6242112, -167.1287564>,
    <0.6349026, -167.1571784>,
    <0.6388889, -167.1407350>,
    <0.6325464, -167.1287564>,
    <0.6268897, -167.1408940>,
    <0.3868412, -167.1106496>,
    <0.3876523, -167.1123151>,
    <0.3866469, -167.1040945>,
    <0.3851791, -167.1040945>,
    <0.3878867, -167.1220941>,
    <0.3870772, -167.1076129>,
    <0.3858219, -167.1040945>,
    <0.3866387, -167.1137977>,
    <0.3878034, -167.1186208>,
    <0.3883292, -167.1197237>,
    <0.3876523, -167.1123151>,
    <0.3878867, -167.1220941>,
    <0.3888889, -167.1287564>,
    <0.3888889, -167.1157290>,
    <0.3878034, -167.1186208>,
    <0.3886042, -167.1268636>,
    <0.3888889, -167.1243302>,
    <0.3883939, -167.1143625>,
    <0.3880192, -167.1090583>,
    <0.3876523, -167.1123151>,
    <0.3888889, -167.1157290>,
    <0.3888889, -167.1040945>,
    <0.3866469, -167.1040945>,
    <0.3883939, -167.1143625>,
    <0.3888889, -167.1077216>,
    <0.3876986, -167.1040945>,
    <0.3870772, -167.1076129>,
    <0.6127560, -167.1101299>,
    <0.6120633, -167.1123215>,
    <0.6121287, -167.1199784>,
    <0.6139677, -167.1041136>,
    <0.6128643, -167.1041062>,
    <0.6121040, -167.1170887>,
    <0.6130409, -167.1121091>,
    <0.6134893, -167.1041104>,
    <0.6125194, -167.1076438>,
    <0.6117875, -167.1098046>,
    <0.6120633, -167.1123215>,
    <0.6128643, -167.1041062>,
    <0.6111111, -167.1040945>,
    <0.6111111, -167.1186961>,
    <0.6125194, -167.1076438>,
    <0.6120478, -167.1041008>,
    <0.6111111, -167.1075968>,
    <0.6114602, -167.1163590>,
    <0.6116036, -167.1199381>,
    <0.6120633, -167.1123215>,
    <0.6111111, -167.1186961>,
    <0.6111111, -167.1287564>,
    <0.6121287, -167.1199784>,
    <0.6114602, -167.1163590>,
    <0.6111111, -167.1268389>,
    <0.6114546, -167.1257934>,
    <0.6121040, -167.1170887>,
    <0.3921505, -167.9315675>,
    <0.3981481, -168.0047729>,
    <0.3888889, -167.9406021>,
    <0.3888889, -167.8774261>,
    <0.3926760, -167.9034689>,
    <0.3931199, -167.9699252>,
    <0.3888889, -167.9039052>,
    <0.3904350, -167.8880585>,
    <0.3952189, -167.9505450>,
    <0.4018645, -168.0112836>,
    <0.3981481, -168.0047729>,
    <0.3926760, -167.9034689>,
    <0.4166667, -168.0684463>,
    <0.3999671, -168.0684463>,
    <0.3952189, -167.9505450>,
    <0.3970689, -167.9336776>,
    <0.4066205, -168.0684463>,
    <0.3992713, -168.0440892>,
    <0.3939733, -168.0205669>,
    <0.3981481, -168.0047729>,
    <0.3999671, -168.0684463>,
    <0.3888889, -168.0684463>,
    <0.3888889, -167.9406021>,
    <0.3992713, -168.0440892>,
    <0.3941847, -168.0684463>,
    <0.3888889, -167.9891238>,
    <0.3931199, -167.9699252>,
    <0.3946600, -167.7682059>,
    <0.3981481, -167.8156918>,
    <0.3888889, -167.7805085>,
    <0.3888889, -167.6922232>,
    <0.4027141, -167.7844001>,
    <0.3929354, -167.7958846>,
    <0.3888889, -167.7304297>,
    <0.3949269, -167.7324808>,
    <0.4007184, -167.7980772>,
    <0.4050800, -167.8387360>,
    <0.3981481, -167.8156918>,
    <0.4027141, -167.7844001>,
    <0.4166667, -167.8774261>,
    <0.4027911, -167.8774261>,
    <0.4007184, -167.7980772>,
    <0.4106345, -167.8372081>,
    <0.4107359, -167.8774261>,
    <0.4008013, -167.8509694>,
    <0.3946793, -167.8377631>,
    <0.3981481, -167.8156918>,
    <0.4027911, -167.8774261>,
    <0.3888889, -167.8774261>,
    <0.3888889, -167.7805085>,
    <0.4008013, -167.8509694>,
    <0.3947485, -167.8774261>,
    <0.3888889, -167.8359290>,
    <0.3929354, -167.7958846>,
    <0.3979408, -167.8998551>,
    <0.4074074, -167.9410995>,
    <0.3926760, -167.9034689>,
    <0.3888889, -167.8774261>,
    <0.4027911, -167.8774261>,
    <0.3980333, -167.9171538>,
    <0.3904350, -167.8880585>,
    <0.3947485, -167.8774261>,
    <0.4049799, -167.9076161>,
    <0.4108830, -167.9176364>,
    <0.4074074, -167.9410995>,
    <0.4027911, -167.8774261>,
    <0.4166667, -167.8774261>,
    <0.4166667, -167.9745941>,
    <0.4049799, -167.9076161>,
    <0.4107359, -167.8774261>,
    <0.4166667, -167.9198146>,
    <0.4129403, -167.9611144>,
    <0.4083542, -167.9719022>,
    <0.4074074, -167.9410995>,
    <0.4166667, -167.9745941>,
    <0.4166667, -168.0684463>,
    <0.3926760, -167.9034689>,
    <0.4129403, -167.9611144>,
    <0.4166667, -168.0262891>,
    <0.3970689, -167.9336776>,
    <0.3980333, -167.9171538>,
    <0.5882367, -167.9427555>,
    <0.5925926, -168.0047729>,
    <0.5833333, -167.9401931>,
    <0.5833333, -167.8774261>,
    <0.5936877, -167.9486301>,
    <0.5875294, -167.9694589>,
    <0.5833333, -167.9042187>,
    <0.5877671, -167.9079158>,
    <0.5931883, -167.9742323>,
    <0.5986534, -168.0225739>,
    <0.5925926, -168.0047729>,
    <0.5936877, -167.9486301>,
    <0.6111111, -168.0684463>,
    <0.5972222, -168.0684463>,
    <0.5931883, -167.9742323>,
    <0.6012527, -168.0006528>,
    <0.6041667, -168.0684463>,
    <0.5953369, -168.0425169>,
    <0.5891204, -168.0204647>,
    <0.5925926, -168.0047729>,
    <0.5972222, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5833333, -167.9401931>,
    <0.5953369, -168.0425169>,
    <0.5902778, -168.0684463>,
    <0.5833333, -167.9885150>,
    <0.5875294, -167.9694589>,
    <0.5940281, -167.9111454>,
    <0.6018519, -167.9410995>,
    <0.5936877, -167.9486301>,
    <0.5833333, -167.8774261>,
    <0.5972396, -167.8774261>,
    <0.5969493, -167.9456216>,
    <0.5877671, -167.9079158>,
    <0.5893007, -167.8774261>,
    <0.5993868, -167.9070680>,
    <0.6053284, -167.9090305>,
    <0.6018519, -167.9410995>,
    <0.5972396, -167.8774261>,
    <0.6111111, -167.8774261>,
    <0.6111111, -167.9401705>,
    <0.5993868, -167.9070680>,
    <0.6051314, -167.8774261>,
    <0.6111111, -167.9042150>,
    <0.6072235, -167.9405605>,
    <0.6044404, -167.9745866>,
    <0.6018519, -167.9410995>,
    <0.6111111, -167.9401705>,
    <0.6111111, -168.0684463>,
    <0.5936877, -167.9486301>,
    <0.6072235, -167.9405605>,
    <0.6111111, -167.9885502>,
    <0.6012527, -168.0006528>,
    <0.5969493, -167.9456216>,
    <0.3946698, -167.5906989>,
    <0.3981481, -167.6342972>,
    <0.3888889, -167.6048705>,
    <0.3888889, -167.5184453>,
    <0.4027535, -167.6051824>,
    <0.3929398, -167.6177446>,
    <0.3888889, -167.5563664>,
    <0.3949501, -167.5563642>,
    <0.4007403, -167.6179095>,
    <0.4050879, -167.6559815>,
    <0.3981481, -167.6342972>,
    <0.4027535, -167.6051824>,
    <0.4166667, -167.6922232>,
    <0.4027832, -167.6922232>,
    <0.4007403, -167.6179095>,
    <0.4105739, -167.6541068>,
    <0.4105923, -167.6922232>,
    <0.4007575, -167.6669079>,
    <0.3946773, -167.6559035>,
    <0.3981481, -167.6342972>,
    <0.4027832, -167.6922232>,
    <0.3888889, -167.6922232>,
    <0.3888889, -167.6048705>,
    <0.4007575, -167.6669079>,
    <0.3949689, -167.6922232>,
    <0.3888889, -167.6541051>,
    <0.3929398, -167.6177446>,
    <0.4004484, -167.7307010>,
    <0.4074074, -167.7539575>,
    <0.4027141, -167.7844001>,
    <0.3888889, -167.6922232>,
    <0.4027832, -167.6922232>,
    <0.4047648, -167.7710985>,
    <0.3949269, -167.7324808>,
    <0.3949689, -167.6922232>,
    <0.4048025, -167.7191818>,
    <0.4108810, -167.7297241>,
    <0.4074074, -167.7539575>,
    <0.4027832, -167.6922232>,
    <0.4166667, -167.6922232>,
    <0.4166667, -167.7804924>,
    <0.4048025, -167.7191818>,
    <0.4105923, -167.6922232>,
    <0.4166667, -167.7304215>,
    <0.4126126, -167.7688743>,
    <0.4108637, -167.7990690>,
    <0.4074074, -167.7539575>,
    <0.4166667, -167.7804924>,
    <0.4166667, -167.8774261>,
    <0.4027141, -167.7844001>,
    <0.4126126, -167.7688743>,
    <0.4166667, -167.8358856>,
    <0.4106345, -167.8372081>,
    <0.4047648, -167.7710985>,
    <0.5891026, -167.7681761>,
    <0.5925926, -167.8156918>,
    <0.5833333, -167.7804384>,
    <0.5833333, -167.6922232>,
    <0.5971512, -167.7843511>,
    <0.5873791, -167.7958420>,
    <0.5833333, -167.7303936>,
    <0.5893673, -167.7324535>,
    <0.5951580, -167.7980547>,
    <0.5995236, -167.8387237>,
    <0.5925926, -167.8156918>,
    <0.5971512, -167.7843511>,
    <0.6111111, -167.8774261>,
    <0.5972396, -167.8774261>,
    <0.5951580, -167.7980547>,
    <0.6050456, -167.8369854>,
    <0.6051314, -167.8774261>,
    <0.5952261, -167.8506769>,
    <0.5891247, -167.8377456>,
    <0.5925926, -167.8156918>,
    <0.5972396, -167.8774261>,
    <0.5833333, -167.8774261>,
    <0.5833333, -167.7804384>,
    <0.5952261, -167.8506769>,
    <0.5893007, -167.8774261>,
    <0.5833333, -167.8351135>,
    <0.5873791, -167.7958420>,
    <0.5948910, -167.7306887>,
    <0.6018519, -167.7539575>,
    <0.5971512, -167.7843511>,
    <0.5833333, -167.6922232>,
    <0.5972276, -167.6922232>,
    <0.5992051, -167.7710711>,
    <0.5893673, -167.7324535>,
    <0.5894133, -167.6922232>,
    <0.5992468, -167.7191790>,
    <0.6053254, -167.7297107>,
    <0.6018519, -167.7539575>,
    <0.5972276, -167.6922232>,
    <0.6111111, -167.6922232>,
    <0.6111111, -167.7804389>,
    <0.5992468, -167.7191790>,
    <0.6050368, -167.6922232>,
    <0.6111111, -167.7303938>,
    <0.6070570, -167.7688441>,
    <0.6053063, -167.7990434>,
    <0.6018519, -167.7539575>,
    <0.6111111, -167.7804389>,
    <0.6111111, -167.8774261>,
    <0.5971512, -167.7843511>,
    <0.6070570, -167.7688441>,
    <0.6111111, -167.8351098>,
    <0.6050456, -167.8369854>,
    <0.5992051, -167.7710711>,
    <0.3934328, -167.9520130>,
    <0.3981481, -168.0105648>,
    <0.3978052, -167.9505394>,
    <0.3888889, -167.8948019>,
    <0.3888889, -167.9521458>,
    <0.3979636, -167.9782717>,
    <0.3926819, -167.9185130>,
    <0.3888889, -167.9191892>,
    <0.3931338, -167.9789283>,
    <0.3946759, -168.0249008>,
    <0.3981481, -168.0105648>,
    <0.3888889, -167.9521458>,
    <0.3888889, -168.0684463>,
    <0.4027778, -168.0684463>,
    <0.3931338, -167.9789283>,
    <0.3888889, -167.9958039>,
    <0.3958333, -168.0684463>,
    <0.4009509, -168.0456058>,
    <0.4038494, -168.0244992>,
    <0.3981481, -168.0105648>,
    <0.4027778, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.3978052, -167.9505394>,
    <0.4009509, -168.0456058>,
    <0.4097222, -168.0684463>,
    <0.4051899, -167.9967027>,
    <0.3979636, -167.9782717>,
    <0.3946609, -167.7954245>,
    <0.3981481, -167.8386752>,
    <0.4027176, -167.8102470>,
    <0.3888889, -167.7264218>,
    <0.3888889, -167.8063538>,
    <0.4007201, -167.8226744>,
    <0.3949290, -167.7630351>,
    <0.3888889, -167.7609681>,
    <0.3929357, -167.8204799>,
    <0.3946792, -167.8586582>,
    <0.3981481, -167.8386752>,
    <0.3888889, -167.8063538>,
    <0.3888889, -167.8948019>,
    <0.4027909, -167.8948019>,
    <0.3929357, -167.8204799>,
    <0.3888889, -167.8568003>,
    <0.3948025, -167.8948019>,
    <0.4007931, -167.8706499>,
    <0.4050808, -167.8596315>,
    <0.3981481, -167.8386752>,
    <0.4027909, -167.8948019>,
    <0.4166667, -167.8948019>,
    <0.4027176, -167.8102470>,
    <0.4007931, -167.8706499>,
    <0.4107341, -167.8948019>,
    <0.4106485, -167.8583218>,
    <0.4007201, -167.8226744>,
    <0.3992231, -167.9232067>,
    <0.4074074, -167.9526834>,
    <0.4027909, -167.8948019>,
    <0.3888889, -167.8948019>,
    <0.3978052, -167.9505394>,
    <0.4049877, -167.9223450>,
    <0.3948025, -167.8948019>,
    <0.3926819, -167.9185130>,
    <0.4014145, -167.9513453>,
    <0.4096365, -167.9783443>,
    <0.4074074, -167.9526834>,
    <0.3978052, -167.9505394>,
    <0.4166667, -168.0684463>,
    <0.4166667, -167.9417080>,
    <0.4014145, -167.9513453>,
    <0.4051899, -167.9967027>,
    <0.4166667, -167.9859274>,
    <0.4128606, -167.9462194>,
    <0.4108829, -167.9209988>,
    <0.4074074, -167.9526834>,
    <0.4166667, -167.9417080>,
    <0.4166667, -167.8948019>,
    <0.4027909, -167.8948019>,
    <0.4128606, -167.9462194>,
    <0.4166667, -167.9144287>,
    <0.4107341, -167.8948019>,
    <0.4049877, -167.9223450>,
    <0.5882375, -167.9541658>,
    <0.5925926, -168.0105648>,
    <0.5936909, -167.9595492>,
    <0.5833333, -167.8948019>,
    <0.5833333, -167.9517471>,
    <0.5931900, -167.9828143>,
    <0.5877696, -167.9225338>,
    <0.5833333, -167.9192542>,
    <0.5875294, -167.9784021>,
    <0.5891204, -168.0248011>,
    <0.5925926, -168.0105648>,
    <0.5833333, -167.9517471>,
    <0.5833333, -168.0684463>,
    <0.5972222, -168.0684463>,
    <0.5875294, -167.9784021>,
    <0.5833333, -167.9954262>,
    <0.5902778, -168.0684463>,
    <0.5953372, -168.0448795>,
    <0.5986542, -168.0267517>,
    <0.5925926, -168.0105648>,
    <0.5972222, -168.0684463>,
    <0.6111111, -168.0684463>,
    <0.5936909, -167.9595492>,
    <0.5953372, -168.0448795>,
    <0.6041667, -168.0684463>,
    <0.6012558, -168.0068388>,
    <0.5931900, -167.9828143>,
    <0.5940289, -167.9254591>,
    <0.6018519, -167.9526834>,
    <0.5972393, -167.8948019>,
    <0.5833333, -167.8948019>,
    <0.5936909, -167.9595492>,
    <0.5993888, -167.9217746>,
    <0.5893006, -167.8948019>,
    <0.5877696, -167.9225338>,
    <0.5969479, -167.9568091>,
    <0.6044413, -167.9831010>,
    <0.6018519, -167.9526834>,
    <0.5936909, -167.9595492>,
    <0.6111111, -168.0684463>,
    <0.6111111, -167.9517252>,
    <0.5969479, -167.9568091>,
    <0.6012558, -168.0068388>,
    <0.6111111, -167.9954605>,
    <0.6072240, -167.9521275>,
    <0.6053284, -167.9235031>,
    <0.6018519, -167.9526834>,
    <0.6111111, -167.9517252>,
    <0.6111111, -167.8948019>,
    <0.5972393, -167.8948019>,
    <0.6072240, -167.9521275>,
    <0.6111111, -167.9192507>,
    <0.6051312, -167.8948019>,
    <0.5993888, -167.9217746>,
    <0.3946676, -167.4265843>,
    <0.3981481, -167.4660888>,
    <0.3888889, -167.4391507>,
    <0.3888889, -167.3613758>,
    <0.4027444, -167.4397221>,
    <0.3929391, -167.4509341>,
    <0.3888889, -167.3955180>,
    <0.3949442, -167.3956156>,
    <0.4007350, -167.4512490>,
    <0.4050862, -167.4856754>,
    <0.3981481, -167.4660888>,
    <0.4027444, -167.4397221>,
    <0.4166667, -167.5184453>,
    <0.4027856, -167.5184453>,
    <0.4007350, -167.4512490>,
    <0.4105680, -167.4839601>,
    <0.4105936, -167.5184453>,
    <0.4007589, -167.4955641>,
    <0.3946779, -167.4855325>,
    <0.3981481, -167.4660888>,
    <0.4027856, -167.5184453>,
    <0.3888889, -167.5184453>,
    <0.3888889, -167.4391507>,
    <0.4007589, -167.4955641>,
    <0.3949701, -167.5184453>,
    <0.3888889, -167.4838674>,
    <0.3929391, -167.4509341>,
    <0.4004588, -167.5546111>,
    <0.4074074, -167.5763713>,
    <0.4027535, -167.6051824>,
    <0.3888889, -167.5184453>,
    <0.4027856, -167.5184453>,
    <0.4047867, -167.5925951>,
    <0.3949501, -167.5563642>,
    <0.3949701, -167.5184453>,
    <0.4048061, -167.5437683>,
    <0.4108816, -167.5545331>,
    <0.4074074, -167.5763713>,
    <0.4027856, -167.5184453>,
    <0.4166667, -167.5184453>,
    <0.4166667, -167.6048705>,
    <0.4048061, -167.5437683>,
    <0.4105936, -167.5184453>,
    <0.4166667, -167.5563664>,
    <0.4126122, -167.5923911>,
    <0.4108736, -167.6196618>,
    <0.4074074, -167.5763713>,
    <0.4166667, -167.6048705>,
    <0.4166667, -167.6922232>,
    <0.4027535, -167.6051824>,
    <0.4126122, -167.5923911>,
    <0.4166667, -167.6541051>,
    <0.4105739, -167.6541068>,
    <0.4047867, -167.5925951>,
    <0.5891143, -167.5906989>,
    <0.5925926, -167.6342972>,
    <0.5833333, -167.6048705>,
    <0.5833333, -167.5184453>,
    <0.5971979, -167.6051824>,
    <0.5873842, -167.6177446>,
    <0.5833333, -167.5563664>,
    <0.5893945, -167.5563642>,
    <0.5951848, -167.6179095>,
    <0.5995323, -167.6559815>,
    <0.5925926, -167.6342972>,
    <0.5971979, -167.6051824>,
    <0.6111111, -167.6922232>,
    <0.5972276, -167.6922232>,
    <0.5951848, -167.6179095>,
    <0.6050184, -167.6541068>,
    <0.6050368, -167.6922232>,
    <0.5952020, -167.6669079>,
    <0.5891217, -167.6559035>,
    <0.5925926, -167.6342972>,
    <0.5972276, -167.6922232>,
    <0.5833333, -167.6922232>,
    <0.5833333, -167.6048705>,
    <0.5952020, -167.6669079>,
    <0.5894133, -167.6922232>,
    <0.5833333, -167.6541051>,
    <0.5873842, -167.6177446>,
    <0.5949033, -167.5546111>,
    <0.6018519, -167.5763713>,
    <0.5971979, -167.6051824>,
    <0.5833333, -167.5184453>,
    <0.5972301, -167.5184453>,
    <0.5992312, -167.5925951>,
    <0.5893945, -167.5563642>,
    <0.5894146, -167.5184453>,
    <0.5992505, -167.5437683>,
    <0.6053260, -167.5545331>,
    <0.6018519, -167.5763713>,
    <0.5972301, -167.5184453>,
    <0.6111111, -167.5184453>,
    <0.6111111, -167.6048705>,
    <0.5992505, -167.5437683>,
    <0.6050380, -167.5184453>,
    <0.6111111, -167.5563664>,
    <0.6070566, -167.5923911>,
    <0.6053180, -167.6196618>,
    <0.6018519, -167.5763713>,
    <0.6111111, -167.6048705>,
    <0.6111111, -167.6922232>,
    <0.5971979, -167.6051824>,
    <0.6070566, -167.5923911>,
    <0.6111111, -167.6541051>,
    <0.6050184, -167.6541068>,
    <0.5992312, -167.5925951>,
    <0.3946703, -167.6341061>,
    <0.3981481, -167.6737665>,
    <0.4027554, -167.6473117>,
    <0.3888889, -167.5684558>,
    <0.3888889, -167.6468904>,
    <0.4007415, -167.6588757>,
    <0.3949513, -167.6029317>,
    <0.3888889, -167.6028579>,
    <0.3929399, -167.6586490>,
    <0.3946771, -167.6933751>,
    <0.3981481, -167.6737665>,
    <0.3888889, -167.6468904>,
    <0.3888889, -167.7264218>,
    <0.4027826, -167.7264218>,
    <0.3929399, -167.6586490>,
    <0.3888889, -167.6917086>,
    <0.3949686, -167.7264218>,
    <0.4007571, -167.7034090>,
    <0.4050882, -167.6934805>,
    <0.3981481, -167.6737665>,
    <0.4027826, -167.7264218>,
    <0.4166667, -167.7264218>,
    <0.4027554, -167.6473117>,
    <0.4007571, -167.7034090>,
    <0.4105920, -167.7264218>,
    <0.4105751, -167.6917804>,
    <0.4007415, -167.6588757>,
    <0.4004491, -167.7614098>,
    <0.4074074, -167.7825485>,
    <0.4027826, -167.7264218>,
    <0.3888889, -167.7264218>,
    <0.4027176, -167.8102470>,
    <0.4048022, -167.7509309>,
    <0.3949686, -167.7264218>,
    <0.3949290, -167.7630351>,
    <0.4047668, -167.7981441>,
    <0.4108646, -167.8234835>,
    <0.4074074, -167.7825485>,
    <0.4027176, -167.8102470>,
    <0.4166667, -167.8948019>,
    <0.4166667, -167.8063366>,
    <0.4047668, -167.7981441>,
    <0.4106485, -167.8583218>,
    <0.4166667, -167.8571134>,
    <0.4126127, -167.7959216>,
    <0.4108808, -167.7604322>,
    <0.4074074, -167.7825485>,
    <0.4166667, -167.8063366>,
    <0.4166667, -167.7264218>,
    <0.4027826, -167.7264218>,
    <0.4126127, -167.7959216>,
    <0.4166667, -167.7609594>,
    <0.4105920, -167.7264218>,
    <0.4048022, -167.7509309>,
    <0.5891035, -167.7953946>,
    <0.5925926, -167.8386752>,
    <0.5971547, -167.8102027>,
    <0.5833333, -167.7264218>,
    <0.5833333, -167.8062788>,
    <0.5951597, -167.8226540>,
    <0.5893694, -167.7630104>,
    <0.5833333, -167.7609297>,
    <0.5873793, -167.8204348>,
    <0.5891247, -167.8586395>,
    <0.5925926, -167.8386752>,
    <0.5833333, -167.8062788>,
    <0.5833333, -167.8948019>,
    <0.5972393, -167.8948019>,
    <0.5873793, -167.8204348>,
    <0.5833333, -167.8563381>,
    <0.5893006, -167.8948019>,
    <0.5952276, -167.8705028>,
    <0.5995244, -167.8596205>,
    <0.5925926, -167.8386752>,
    <0.5972393, -167.8948019>,
    <0.6111111, -167.8948019>,
    <0.5971547, -167.8102027>,
    <0.5952276, -167.8705028>,
    <0.6051312, -167.8948019>,
    <0.6050482, -167.8580506>,
    <0.5951597, -167.8226540>,
    <0.5948918, -167.7613987>,
    <0.6018519, -167.7825485>,
    <0.5972271, -167.7264218>,
    <0.5833333, -167.7264218>,
    <0.5971547, -167.8102027>,
    <0.5992464, -167.7509283>,
    <0.5894131, -167.7264218>,
    <0.5893694, -167.7630104>,
    <0.5992071, -167.7981193>,
    <0.6053072, -167.8234582>,
    <0.6018519, -167.7825485>,
    <0.5971547, -167.8102027>,
    <0.6111111, -167.8948019>,
    <0.6111111, -167.8062795>,
    <0.5992071, -167.7981193>,
    <0.6050482, -167.8580506>,
    <0.6111111, -167.8563340>,
    <0.6070571, -167.7958893>,
    <0.6053253, -167.7604179>,
    <0.6018519, -167.7825485>,
    <0.6111111, -167.8062795>,
    <0.6111111, -167.7264218>,
    <0.5972271, -167.7264218>,
    <0.6070571, -167.7958893>,
    <0.6111111, -167.7609300>,
    <0.6050365, -167.7264218>,
    <0.5992464, -167.7509283>,
    <0.6020414, -167.0794526>,
    <0.6056582, -167.0842391>,
    <0.6045005, -167.0966789>,
    <0.5947523, -167.0684463>,
    <0.6032547, -167.0684463>,
    <0.6049612, -167.0917279>,
    <0.5997463, -167.0829097>,
    <0.5991356, -167.0684463>,
    <0.6043005, -167.0753181>,
    <0.6077838, -167.0788821>,
    <0.6056582, -167.0842391>,
    <0.6032547, -167.0684463>,
    <0.6111111, -167.0684463>,
    <0.6111111, -167.0943969>,
    <0.6043005, -167.0753181>,
    <0.6072206, -167.0684463>,
    <0.6111111, -167.0814789>,
    <0.6088084, -167.0901073>,
    <0.6080952, -167.0977849>,
    <0.6056582, -167.0842391>,
    <0.6111111, -167.0943969>,
    <0.6111111, -167.1158246>,
    <0.6045005, -167.0966789>,
    <0.6088084, -167.0901073>,
    <0.6111111, -167.1096993>,
    <0.6085424, -167.1083851>,
    <0.6049612, -167.0917279>,
    <0.3953090, -167.1109029>,
    <0.3930488, -167.1123151>,
    <0.3917475, -167.1231074>,
    <0.4013685, -167.1040945>,
    <0.3950713, -167.1040945>,
    <0.3922483, -167.1189535>,
    <0.3952408, -167.1162040>,
    <0.3981979, -167.1040945>,
    <0.3943982, -167.1068304>,
    <0.3914745, -167.1090583>,
    <0.3930488, -167.1123151>,
    <0.3950713, -167.1040945>,
    <0.3888889, -167.1040945>,
    <0.3888889, -167.1157290>,
    <0.3943982, -167.1068304>,
    <0.3919730, -167.1040945>,
    <0.3888889, -167.1077216>,
    <0.3909890, -167.1140055>,
    <0.3906435, -167.1199770>,
    <0.3930488, -167.1123151>,
    <0.3888889, -167.1157290>,
    <0.3888889, -167.1287564>,
    <0.3917475, -167.1231074>,
    <0.3909890, -167.1140055>,
    <0.3888889, -167.1243302>,
    <0.3899269, -167.1267052>,
    <0.3922483, -167.1189535>,
    <0.3946683, -167.4848985>,
    <0.3981481, -167.5208549>,
    <0.4027471, -167.4968970>,
    <0.3888889, -167.4256532>,
    <0.3888889, -167.4961890>,
    <0.4007366, -167.5073705>,
    <0.3949460, -167.4567920>,
    <0.3888889, -167.4566011>,
    <0.3929393, -167.5069791>,
    <0.3946777, -167.5384889>,
    <0.3981481, -167.5208549>,
    <0.3888889, -167.4961890>,
    <0.3888889, -167.5684558>,
    <0.4027848, -167.5684558>,
    <0.3929393, -167.5069791>,
    <0.3888889, -167.5369298>,
    <0.3949698, -167.5684558>,
    <0.4007584, -167.5476517>,
    <0.4050867, -167.5386659>,
    <0.3981481, -167.5208549>,
    <0.4027848, -167.5684558>,
    <0.4166667, -167.5684558>,
    <0.4027471, -167.4968970>,
    <0.4007584, -167.5476517>,
    <0.4105931, -167.5684558>,
    <0.4105696, -167.5371117>,
    <0.4007366, -167.5073705>,
    <0.4004591, -167.6013336>,
    <0.4074074, -167.6211112>,
    <0.4027848, -167.5684558>,
    <0.3888889, -167.5684558>,
    <0.4027554, -167.6473117>,
    <0.4048055, -167.5914725>,
    <0.3949698, -167.5684558>,
    <0.3949513, -167.6029317>,
    <0.4047879, -167.6358644>,
    <0.4108740, -167.6604338>,
    <0.4074074, -167.6211112>,
    <0.4027554, -167.6473117>,
    <0.4166667, -167.7264218>,
    <0.4166667, -167.6468904>,
    <0.4047879, -167.6358644>,
    <0.4105751, -167.6917804>,
    <0.4166667, -167.6917086>,
    <0.4126124, -167.6356026>,
    <0.4108814, -167.6012283>,
    <0.4074074, -167.6211112>,
    <0.4166667, -167.6468904>,
    <0.4166667, -167.5684558>,
    <0.4027848, -167.5684558>,
    <0.4126124, -167.6356026>,
    <0.4166667, -167.6028580>,
    <0.4105931, -167.5684558>,
    <0.4048055, -167.5914725>,
    <0.5891148, -167.6341061>,
    <0.5925926, -167.6737665>,
    <0.5971999, -167.6473117>,
    <0.5833333, -167.5684558>,
    <0.5833333, -167.6468904>,
    <0.5951859, -167.6588757>,
    <0.5893958, -167.6029317>,
    <0.5833333, -167.6028579>,
    <0.5873844, -167.6586490>,
    <0.5891216, -167.6933751>,
    <0.5925926, -167.6737665>,
    <0.5833333, -167.6468904>,
    <0.5833333, -167.7264218>,
    <0.5972271, -167.7264218>,
    <0.5873844, -167.6586490>,
    <0.5833333, -167.6917086>,
    <0.5894131, -167.7264218>,
    <0.5952016, -167.7034090>,
    <0.5995327, -167.6934805>,
    <0.5925926, -167.6737665>,
    <0.5972271, -167.7264218>,
    <0.6111111, -167.7264218>,
    <0.5971999, -167.6473117>,
    <0.5952016, -167.7034090>,
    <0.6050365, -167.7264218>,
    <0.6050195, -167.6917804>,
    <0.5951859, -167.6588757>,
    <0.5949036, -167.6013336>,
    <0.6018519, -167.6211112>,
    <0.5972293, -167.5684558>,
    <0.5833333, -167.5684558>,
    <0.5971999, -167.6473117>,
    <0.5992499, -167.5914725>,
    <0.5894142, -167.5684558>,
    <0.5893958, -167.6029317>,
    <0.5992324, -167.6358644>,
    <0.6053185, -167.6604338>,
    <0.6018519, -167.6211112>,
    <0.5971999, -167.6473117>,
    <0.6111111, -167.7264218>,
    <0.6111111, -167.6468904>,
    <0.5992324, -167.6358644>,
    <0.6050195, -167.6917804>,
    <0.6111111, -167.6917086>,
    <0.6070568, -167.6356026>,
    <0.6053258, -167.6012283>,
    <0.6018519, -167.6211112>,
    <0.6111111, -167.6468904>,
    <0.6111111, -167.5684558>,
    <0.5972293, -167.5684558>,
    <0.6070568, -167.6356026>,
    <0.6111111, -167.6028579>,
    <0.6050376, -167.5684558>,
    <0.5992499, -167.5914725>,
    <0.3946655, -167.2819570>,
    <0.3981481, -167.3161845>,
    <0.3888889, -167.2924560>,
    <0.3888889, -167.2258020>,
    <0.4027361, -167.2933857>,
    <0.3929385, -167.3028339>,
    <0.3888889, -167.2550533>,
    <0.3949388, -167.2553296>,
    <0.4007302, -167.3033535>,
    <0.4050847, -167.3330804>,
    <0.3981481, -167.3161845>,
    <0.4027361, -167.2933857>,
    <0.4166667, -167.3613758>,
    <0.4027878, -167.3613758>,
    <0.4007302, -167.3033535>,
    <0.4105624, -167.3315832>,
    <0.4105946, -167.3613758>,
    <0.4007600, -167.3416247>,
    <0.3946784, -167.3328480>,
    <0.3981481, -167.3161845>,
    <0.4027878, -167.3613758>,
    <0.3888889, -167.3613758>,
    <0.3888889, -167.2924560>,
    <0.4007600, -167.3416247>,
    <0.3949713, -167.3613758>,
    <0.3888889, -167.3313235>,
    <0.3929385, -167.3028339>,
    <0.4004571, -167.3940515>,
    <0.4074074, -167.4137323>,
    <0.4027444, -167.4397221>,
    <0.3888889, -167.3613758>,
    <0.4027878, -167.3613758>,
    <0.4047815, -167.4283682>,
    <0.3949442, -167.3956156>,
    <0.3949713, -167.3613758>,
    <0.4048071, -167.3842624>,
    <0.4108821, -167.3939086>,
    <0.4074074, -167.4137323>,
    <0.4027878, -167.3613758>,
    <0.4166667, -167.3613758>,
    <0.4166667, -167.4391507>,
    <0.4048071, -167.3842624>,
    <0.4105946, -167.3613758>,
    <0.4166667, -167.3955180>,
    <0.4126116, -167.4280187>,
    <0.4108713, -167.4527626>,
    <0.4074074, -167.4137323>,
    <0.4166667, -167.4391507>,
    <0.4166667, -167.5184453>,
    <0.4027444, -167.4397221>,
    <0.4126116, -167.4280187>,
    <0.4166667, -167.4838674>,
    <0.4105680, -167.4839601>,
    <0.4047815, -167.4283682>,
    <0.5891120, -167.4265843>,
    <0.5925926, -167.4660888>,
    <0.5833333, -167.4391507>,
    <0.5833333, -167.3613758>,
    <0.5971889, -167.4397221>,
    <0.5873836, -167.4509341>,
    <0.5833333, -167.3955180>,
    <0.5893887, -167.3956156>,
    <0.5951795, -167.4512490>,
    <0.5995307, -167.4856754>,
    <0.5925926, -167.4660888>,
    <0.5971889, -167.4397221>,
    <0.6111111, -167.5184453>,
    <0.5972301, -167.5184453>,
    <0.5951795, -167.4512490>,
    <0.6050124, -167.4839601>,
    <0.6050380, -167.5184453>,
    <0.5952034, -167.4955641>,
    <0.5891223, -167.4855325>,
    <0.5925926, -167.4660888>,
    <0.5972301, -167.5184453>,
    <0.5833333, -167.5184453>,
    <0.5833333, -167.4391507>,
    <0.5952034, -167.4955641>,
    <0.5894146, -167.5184453>,
    <0.5833333, -167.4838674>,
    <0.5873836, -167.4509341>,
    <0.5949016, -167.3940515>,
    <0.6018519, -167.4137323>,
    <0.5971889, -167.4397221>,
    <0.5833333, -167.3613758>,
    <0.5972322, -167.3613758>,
    <0.5992260, -167.4283682>,
    <0.5893887, -167.3956156>,
    <0.5894157, -167.3613758>,
    <0.5992516, -167.3842624>,
    <0.6053266, -167.3939086>,
    <0.6018519, -167.4137323>,
    <0.5972322, -167.3613758>,
    <0.6111111, -167.3613758>,
    <0.6111111, -167.4391506>,
    <0.5992516, -167.3842624>,
    <0.6050391, -167.3613758>,
    <0.6111111, -167.3955180>,
    <0.6070560, -167.4280187>,
    <0.6053157, -167.4527626>,
    <0.6018519, -167.4137323>,
    <0.6111111, -167.4391506>,
    <0.6111111, -167.5184453>,
    <0.5971889, -167.4397221>,
    <0.6070560, -167.4280187>,
    <0.6111111, -167.4838674>,
    <0.6050124, -167.4839601>,
    <0.5992260, -167.4283682>,
    <0.6033177, -167.1109046>,
    <0.6060118, -167.1123151>,
    <0.6038344, -167.1040945>,
    <0.5958131, -167.1040945>,
    <0.6076113, -167.1231144>,
    <0.6046148, -167.1070407>,
    <0.5999797, -167.1040945>,
    <0.6034856, -167.1164632>,
    <0.6069744, -167.1188144>,
    <0.6089613, -167.1207205>,
    <0.6060118, -167.1123151>,
    <0.6076113, -167.1231144>,
    <0.6111111, -167.1287564>,
    <0.6111111, -167.1186961>,
    <0.6069744, -167.1188144>,
    <0.6098355, -167.1267000>,
    <0.6111111, -167.1268389>,
    <0.6085195, -167.1154531>,
    <0.6080171, -167.1098001>,
    <0.6060118, -167.1123151>,
    <0.6111111, -167.1186961>,
    <0.6111111, -167.1040945>,
    <0.6038344, -167.1040945>,
    <0.6085195, -167.1154531>,
    <0.6111111, -167.1075968>,
    <0.6075155, -167.1040945>,
    <0.6046148, -167.1070407>,
    <0.3946664, -167.3534027>,
    <0.3981481, -167.3845690>,
    <0.4027396, -167.3638575>,
    <0.3888889, -167.3024008>,
    <0.3888889, -167.3627833>,
    <0.4007323, -167.3729124>,
    <0.3949411, -167.3292549>,
    <0.3888889, -167.3288803>,
    <0.3929388, -167.3723121>,
    <0.3946782, -167.3996647>,
    <0.3981481, -167.3845690>,
    <0.3888889, -167.3627833>,
    <0.3888889, -167.4256532>,
    <0.4027868, -167.4256532>,
    <0.3929388, -167.3723121>,
    <0.3888889, -167.3982231>,
    <0.3949708, -167.4256532>,
    <0.4007593, -167.4076960>,
    <0.4050853, -167.3999332>,
    <0.3981481, -167.3845690>,
    <0.4027868, -167.4256532>,
    <0.4166667, -167.4256532>,
    <0.4027396, -167.3638575>,
    <0.4007593, -167.4076960>,
    <0.4105941, -167.4256532>,
    <0.4105646, -167.3985780>,
    <0.4007323, -167.3729124>,
    <0.4004575, -167.4553644>,
    <0.4074074, -167.4732541>,
    <0.4027868, -167.4256532>,
    <0.3888889, -167.4256532>,
    <0.4027471, -167.4968970>,
    <0.4048064, -167.4464590>,
    <0.3949708, -167.4256532>,
    <0.3949460, -167.4567920>,
    <0.4047831, -167.4865678>,
    <0.4108720, -167.5086990>,
    <0.4074074, -167.4732541>,
    <0.4027471, -167.4968970>,
    <0.4166667, -167.5684558>,
    <0.4166667, -167.4961890>,
    <0.4047831, -167.4865678>,
    <0.4105696, -167.5371117>,
    <0.4166667, -167.5369298>,
    <0.4126118, -167.4861453>,
    <0.4108819, -167.4551874>,
    <0.4074074, -167.4732541>,
    <0.4166667, -167.4961890>,
    <0.4166667, -167.4256532>,
    <0.4027868, -167.4256532>,
    <0.4126118, -167.4861453>,
    <0.4166667, -167.4566011>,
    <0.4105941, -167.4256532>,
    <0.4048064, -167.4464590>,
    <0.5891127, -167.4848985>,
    <0.5925926, -167.5208549>,
    <0.5971916, -167.4968970>,
    <0.5833333, -167.4256532>,
    <0.5833333, -167.4961891>,
    <0.5951811, -167.5073705>,
    <0.5893904, -167.4567920>,
    <0.5833333, -167.4566011>,
    <0.5873838, -167.5069791>,
    <0.5891221, -167.5384889>,
    <0.5925926, -167.5208549>,
    <0.5833333, -167.4961891>,
    <0.5833333, -167.5684558>,
    <0.5972293, -167.5684558>,
    <0.5873838, -167.5069791>,
    <0.5833333, -167.5369298>,
    <0.5894142, -167.5684558>,
    <0.5952028, -167.5476517>,
    <0.5995312, -167.5386659>,
    <0.5925926, -167.5208549>,
    <0.5972293, -167.5684558>,
    <0.6111111, -167.5684558>,
    <0.5971916, -167.4968970>,
    <0.5952028, -167.5476517>,
    <0.6050376, -167.5684558>,
    <0.6050141, -167.5371117>,
    <0.5951811, -167.5073705>,
    <0.5949020, -167.4553644>,
    <0.6018519, -167.4732541>,
    <0.5972312, -167.4256532>,
    <0.5833333, -167.4256532>,
    <0.5971916, -167.4968970>,
    <0.5992509, -167.4464590>,
    <0.5894153, -167.4256532>,
    <0.5893904, -167.4567920>,
    <0.5992276, -167.4865678>,
    <0.6053164, -167.5086990>,
    <0.6018519, -167.4732541>,
    <0.5971916, -167.4968970>,
    <0.6111111, -167.5684558>,
    <0.6111111, -167.4961890>,
    <0.5992276, -167.4865678>,
    <0.6050141, -167.5371117>,
    <0.6111111, -167.5369298>,
    <0.6070563, -167.4861453>,
    <0.6053263, -167.4551874>,
    <0.6018519, -167.4732541>,
    <0.6111111, -167.4961890>,
    <0.6111111, -167.4256532>,
    <0.5972312, -167.4256532>,
    <0.6070563, -167.4861453>,
    <0.6111111, -167.4566011>,
    <0.6050386, -167.4256532>,
    <0.5992509, -167.4464590>,
    <0.3945933, -167.1604641>,
    <0.3981481, -167.1891429>,
    <0.3888889, -167.1673834>,
    <0.3888889, -167.1158246>,
    <0.4024475, -167.1695055>,
    <0.3929416, -167.1769073>,
    <0.3888889, -167.1360516>,
    <0.3946186, -167.1385098>,
    <0.4005707, -167.1780777>,
    <0.4050129, -167.2025631>,
    <0.3981481, -167.1891429>,
    <0.4024475, -167.1695055>,
    <0.4166667, -167.2258020>,
    <0.4027895, -167.2258020>,
    <0.4005707, -167.1780777>,
    <0.4104034, -167.2010045>,
    <0.4105955, -167.2258020>,
    <0.4007521, -167.2097098>,
    <0.3946789, -167.2020325>,
    <0.3981481, -167.1891429>,
    <0.4027895, -167.2258020>,
    <0.3888889, -167.2258020>,
    <0.3888889, -167.1673834>,
    <0.4007521, -167.2097098>,
    <0.3949722, -167.2258020>,
    <0.3888889, -167.2002137>,
    <0.3929416, -167.1769073>,
    <0.4004555, -167.2539957>,
    <0.4074074, -167.2709932>,
    <0.4027361, -167.2933857>,
    <0.3888889, -167.2258020>,
    <0.4027895, -167.2258020>,
    <0.4047768, -167.2836036>,
    <0.3949388, -167.2553296>,
    <0.3949722, -167.2258020>,
    <0.4048078, -167.2455535>,
    <0.4108826, -167.2537633>,
    <0.4074074, -167.2709932>,
    <0.4027895, -167.2258020>,
    <0.4166667, -167.2258020>,
    <0.4166667, -167.2924560>,
    <0.4048078, -167.2455535>,
    <0.4105955, -167.2258020>,
    <0.4166667, -167.2550533>,
    <0.4126110, -167.2830552>,
    <0.4108692, -167.3045527>,
    <0.4074074, -167.2709932>,
    <0.4166667, -167.2924560>,
    <0.4166667, -167.3613758>,
    <0.4027361, -167.2933857>,
    <0.4126110, -167.2830552>,
    <0.4166667, -167.3313235>,
    <0.4105624, -167.3315832>,
    <0.4047768, -167.2836036>,
    <0.5891100, -167.2819570>,
    <0.5925926, -167.3161845>,
    <0.5833333, -167.2924560>,
    <0.5833333, -167.2258020>,
    <0.5971806, -167.2933857>,
    <0.5873830, -167.3028339>,
    <0.5833333, -167.2550533>,
    <0.5893833, -167.2553296>,
    <0.5951747, -167.3033535>,
    <0.5995291, -167.3330804>,
    <0.5925926, -167.3161845>,
    <0.5971806, -167.2933857>,
    <0.6111111, -167.3613758>,
    <0.5972322, -167.3613758>,
    <0.5951747, -167.3033535>,
    <0.6050069, -167.3315832>,
    <0.6050391, -167.3613758>,
    <0.5952044, -167.3416247>,
    <0.5891229, -167.3328480>,
    <0.5925926, -167.3161845>,
    <0.5972322, -167.3613758>,
    <0.5833333, -167.3613758>,
    <0.5833333, -167.2924560>,
    <0.5952044, -167.3416247>,
    <0.5894157, -167.3613758>,
    <0.5833333, -167.3313235>,
    <0.5873830, -167.3028339>,
    <0.5948999, -167.2539957>,
    <0.6018519, -167.2709932>,
    <0.5971806, -167.2933857>,
    <0.5833333, -167.2258020>,
    <0.5972340, -167.2258020>,
    <0.5992212, -167.2836036>,
    <0.5893833, -167.2553296>,
    <0.5894167, -167.2258020>,
    <0.5992523, -167.2455535>,
    <0.6053270, -167.2537633>,
    <0.6018519, -167.2709932>,
    <0.5972340, -167.2258020>,
    <0.6111111, -167.2258020>,
    <0.6111111, -167.2924560>,
    <0.5992523, -167.2455535>,
    <0.6050400, -167.2258020>,
    <0.6111111, -167.2550533>,
    <0.6070555, -167.2830552>,
    <0.6053137, -167.3045527>,
    <0.6018519, -167.2709932>,
    <0.6111111, -167.2924560>,
    <0.6111111, -167.3613758>,
    <0.5971806, -167.2933857>,
    <0.6070555, -167.2830552>,
    <0.6111111, -167.3313235>,
    <0.6050069, -167.3315832>,
    <0.5992212, -167.2836036>,
    <0.3946647, -167.2436308>,
    <0.3981481, -167.2690732>,
    <0.4027330, -167.2522483>,
    <0.3888889, -167.2024179>,
    <0.3888889, -167.2507837>,
    <0.4007285, -167.2596042>,
    <0.3949368, -167.2241867>,
    <0.3888889, -167.2235884>,
    <0.3929383, -167.2587824>,
    <0.3946786, -167.2811646>,
    <0.3981481, -167.2690732>,
    <0.3888889, -167.2507837>,
    <0.3888889, -167.3024008>,
    <0.4027884, -167.3024008>,
    <0.3929383, -167.2587824>,
    <0.3888889, -167.2798504>,
    <0.3949717, -167.3024008>,
    <0.4007599, -167.2878319>,
    <0.4050840, -167.2815307>,
    <0.3981481, -167.2690732>,
    <0.4027884, -167.3024008>,
    <0.4166667, -167.3024008>,
    <0.4027330, -167.2522483>,
    <0.4007599, -167.2878319>,
    <0.4105949, -167.3024008>,
    <0.4105602, -167.2804214>,
    <0.4007285, -167.2596042>,
    <0.4004561, -167.3280360>,
    <0.4074074, -167.3434849>,
    <0.4027884, -167.3024008>,
    <0.3888889, -167.3024008>,
    <0.4027396, -167.3638575>,
    <0.4048070, -167.3203558>,
    <0.3949717, -167.3024008>,
    <0.3949411, -167.3292549>,
    <0.4047788, -167.3549573>,
    <0.4108701, -167.3739447>,
    <0.4074074, -167.3434849>,
    <0.4027396, -167.3638575>,
    <0.4166667, -167.4256532>,
    <0.4166667, -167.3627833>,
    <0.4047788, -167.3549573>,
    <0.4105646, -167.3985780>,
    <0.4166667, -167.3982231>,
    <0.4126113, -167.3543311>,
    <0.4108823, -167.3277674>,
    <0.4074074, -167.3434849>,
    <0.4166667, -167.3627833>,
    <0.4166667, -167.3024008>,
    <0.4027884, -167.3024008>,
    <0.4126113, -167.3543311>,
    <0.4166667, -167.3288803>,
    <0.4105949, -167.3024008>,
    <0.4048070, -167.3203558>,
    <0.5891108, -167.3534027>,
    <0.5925926, -167.3845690>,
    <0.5971840, -167.3638575>,
    <0.5833333, -167.3024008>,
    <0.5833333, -167.3627833>,
    <0.5951767, -167.3729124>,
    <0.5893855, -167.3292549>,
    <0.5833333, -167.3288803>,
    <0.5873832, -167.3723121>,
    <0.5891226, -167.3996647>,
    <0.5925926, -167.3845690>,
    <0.5833333, -167.3627833>,
    <0.5833333, -167.4256532>,
    <0.5972312, -167.4256532>,
    <0.5873832, -167.3723121>,
    <0.5833333, -167.3982231>,
    <0.5894153, -167.4256532>,
    <0.5952038, -167.4076960>,
    <0.5995297, -167.3999332>,
    <0.5925926, -167.3845690>,
    <0.5972312, -167.4256532>,
    <0.6111111, -167.4256532>,
    <0.5971840, -167.3638575>,
    <0.5952038, -167.4076960>,
    <0.6050386, -167.4256532>,
    <0.6050091, -167.3985780>,
    <0.5951767, -167.3729124>,
    <0.5949005, -167.3280360>,
    <0.6018519, -167.3434849>,
    <0.5972328, -167.3024008>,
    <0.5833333, -167.3024008>,
    <0.5971840, -167.3638575>,
    <0.5992515, -167.3203558>,
    <0.5894161, -167.3024008>,
    <0.5893855, -167.3292549>,
    <0.5992233, -167.3549573>,
    <0.6053145, -167.3739447>,
    <0.6018519, -167.3434849>,
    <0.5971840, -167.3638575>,
    <0.6111111, -167.4256532>,
    <0.6111111, -167.3627833>,
    <0.5992233, -167.3549573>,
    <0.6050091, -167.3985780>,
    <0.6111111, -167.3982231>,
    <0.6070558, -167.3543311>,
    <0.6053267, -167.3277674>,
    <0.6018519, -167.3434849>,
    <0.6111111, -167.3627833>,
    <0.6111111, -167.3024008>,
    <0.5972328, -167.3024008>,
    <0.6070558, -167.3543311>,
    <0.6111111, -167.3288803>,
    <0.6050393, -167.3024008>,
    <0.5992515, -167.3203558>,
    <0.3959906, -167.0909950>,
    <0.3981481, -167.1000319>,
    <0.3888889, -167.0943971>,
    <0.3888889, -167.0684463>,
    <0.4080364, -167.1011047>,
    <0.3928898, -167.0968319>,
    <0.3888889, -167.0814793>,
    <0.4004342, -167.0881382>,
    <0.4030186, -167.1005603>,
    <0.4062664, -167.1081965>,
    <0.3981481, -167.1000319>,
    <0.4080364, -167.1011047>,
    <0.4166667, -167.1158246>,
    <0.4022143, -167.1158246>,
    <0.4030186, -167.1005603>,
    <0.4131994, -167.1099109>,
    <0.4104226, -167.1158246>,
    <0.4003194, -167.1084649>,
    <0.3945351, -167.1065196>,
    <0.3981481, -167.1000319>,
    <0.4022143, -167.1158246>,
    <0.3888889, -167.1158246>,
    <0.3888889, -167.0943971>,
    <0.4003194, -167.1084649>,
    <0.3943862, -167.1158246>,
    <0.3888889, -167.1096992>,
    <0.3928898, -167.0968319>,
    <0.3984406, -167.0805591>,
    <0.4019545, -167.0842391>,
    <0.4080364, -167.1011047>,
    <0.3888889, -167.0684463>,
    <0.3948829, -167.0684463>,
    <0.4058896, -167.0951515>,
    <0.4004342, -167.0881382>,
    <0.3919245, -167.0684463>,
    <0.3977224, -167.0747878>,
    <0.4018008, -167.0794542>,
    <0.4019545, -167.0842391>,
    <0.3948829, -167.0684463>,
    <0.4003079, -167.0684463>,
    <0.4100581, -167.0966849>,
    <0.3977224, -167.0747878>,
    <0.3976914, -167.0684463>,
    <0.4053030, -167.0829132>,
    <0.4060196, -167.0904825>,
    <0.4091789, -167.0994633>,
    <0.4019545, -167.0842391>,
    <0.4100581, -167.0966849>,
    <0.4166667, -167.1158246>,
    <0.4080364, -167.1011047>,
    <0.4060196, -167.0904825>,
    <0.4140993, -167.1083889>,
    <0.4131994, -167.1099109>,
    <0.4058896, -167.0951515>,
    <0.4002395, -167.1384096>,
    <0.4074074, -167.1524837>,
    <0.4024475, -167.1695055>,
    <0.3888889, -167.1158246>,
    <0.4022143, -167.1158246>,
    <0.4046083, -167.1620899>,
    <0.3946186, -167.1385098>,
    <0.3943862, -167.1158246>,
    <0.4044639, -167.1317049>,
    <0.4107388, -167.1378694>,
    <0.4074074, -167.1524837>,
    <0.4022143, -167.1158246>,
    <0.4166667, -167.1158246>,
    <0.4166667, -167.1673444>,
    <0.4044639, -167.1317049>,
    <0.4104226, -167.1158246>,
    <0.4166667, -167.1360443>,
    <0.4126053, -167.1608261>,
    <0.4107970, -167.1787839>,
    <0.4074074, -167.1524837>,
    <0.4166667, -167.1673444>,
    <0.4166667, -167.2258020>,
    <0.4024475, -167.1695055>,
    <0.4126053, -167.1608261>,
    <0.4166667, -167.2001871>,
    <0.4104034, -167.2010045>,
    <0.4046083, -167.1620899>,
    <0.5890350, -167.1603744>,
    <0.5925926, -167.1891429>,
    <0.5833333, -167.1670695>,
    <0.5833333, -167.1158246>,
    <0.5968805, -167.1694605>,
    <0.5873862, -167.1767312>,
    <0.5833333, -167.1357703>,
    <0.5890526, -167.1384682>,
    <0.5950088, -167.1780519>,
    <0.5994546, -167.2025518>,
    <0.5925926, -167.1891429>,
    <0.5968805, -167.1694605>,
    <0.6111111, -167.2258020>,
    <0.5972340, -167.2258020>,
    <0.5950088, -167.1780519>,
    <0.6048416, -167.2009796>,
    <0.6050400, -167.2258020>,
    <0.5951962, -167.2097068>,
    <0.5891233, -167.2019541>,
    <0.5925926, -167.1891429>,
    <0.5972340, -167.2258020>,
    <0.5833333, -167.2258020>,
    <0.5833333, -167.1670695>,
    <0.5951962, -167.2097068>,
    <0.5894167, -167.2258020>,
    <0.5833333, -167.2000468>,
    <0.5873862, -167.1767312>,
    <0.5946780, -167.1383984>,
    <0.6018519, -167.1524837>,
    <0.5968805, -167.1694605>,
    <0.5833333, -167.1158246>,
    <0.5966461, -167.1158246>,
    <0.5990465, -167.1620638>,
    <0.5890526, -167.1384682>,
    <0.5888243, -167.1158246>,
    <0.5989016, -167.1317082>,
    <0.6051800, -167.1378792>,
    <0.6018519, -167.1524837>,
    <0.5966461, -167.1158246>,
    <0.6111111, -167.1158246>,
    <0.6111111, -167.1673836>,
    <0.5989016, -167.1317082>,
    <0.6048588, -167.1158246>,
    <0.6111111, -167.1360519>,
    <0.6070496, -167.1608478>,
    <0.6052387, -167.1787824>,
    <0.6018519, -167.1524837>,
    <0.6111111, -167.1673836>,
    <0.6111111, -167.2258020>,
    <0.5968805, -167.1694605>,
    <0.6070496, -167.1608478>,
    <0.6111111, -167.2002138>,
    <0.6048416, -167.2009796>,
    <0.5990465, -167.1620638>,
    <0.3947357, -167.1583892>,
    <0.3981481, -167.1778641>,
    <0.4030168, -167.1662209>,
    <0.3888889, -167.1287564>,
    <0.3888889, -167.1607153>,
    <0.4008954, -167.1712941>,
    <0.3951460, -167.1453493>,
    <0.3888889, -167.1413913>,
    <0.3929456, -167.1682287>,
    <0.3946789, -167.1858538>,
    <0.3981481, -167.1778641>,
    <0.3888889, -167.1607153>,
    <0.3888889, -167.2024179>,
    <0.4027896, -167.2024179>,
    <0.3929456, -167.1682287>,
    <0.3888889, -167.1838308>,
    <0.3949723, -167.2024179>,
    <0.4007685, -167.1917260>,
    <0.4051553, -167.1872302>,
    <0.3981481, -167.1778641>,
    <0.4027896, -167.2024179>,
    <0.4166667, -167.2024179>,
    <0.4030168, -167.1662209>,
    <0.4007685, -167.1917260>,
    <0.4105955, -167.2024179>,
    <0.4107263, -167.1866652>,
    <0.4008954, -167.1712941>,
    <0.4004547, -167.2232074>,
    <0.4074074, -167.2357456>,
    <0.4027896, -167.2024179>,
    <0.3888889, -167.2024179>,
    <0.4027330, -167.2522483>,
    <0.4048073, -167.2169804>,
    <0.3949723, -167.2024179>,
    <0.3949368, -167.2241867>,
    <0.4047751, -167.2450388>,
    <0.4108684, -167.2602946>,
    <0.4074074, -167.2357456>,
    <0.4027330, -167.2522483>,
    <0.4166667, -167.3024008>,
    <0.4166667, -167.2507837>,
    <0.4047751, -167.2450388>,
    <0.4105602, -167.2804214>,
    <0.4166667, -167.2798504>,
    <0.4126110, -167.2441968>,
    <0.4108826, -167.2228413>,
    <0.4074074, -167.2357456>,
    <0.4166667, -167.2507837>,
    <0.4166667, -167.2024179>,
    <0.4027896, -167.2024179>,
    <0.4126110, -167.2441968>,
    <0.4166667, -167.2235884>,
    <0.4105955, -167.2024179>,
    <0.4048073, -167.2169804>,
    <0.5891092, -167.2436308>,
    <0.5925926, -167.2690732>,
    <0.5971775, -167.2522483>,
    <0.5833333, -167.2024179>,
    <0.5833333, -167.2507837>,
    <0.5951729, -167.2596042>,
    <0.5893813, -167.2241867>,
    <0.5833333, -167.2235884>,
    <0.5873828, -167.2587824>,
    <0.5891230, -167.2811646>,
    <0.5925926, -167.2690732>,
    <0.5833333, -167.2507837>,
    <0.5833333, -167.3024008>,
    <0.5972328, -167.3024008>,
    <0.5873828, -167.2587824>,
    <0.5833333, -167.2798504>,
    <0.5894161, -167.3024008>,
    <0.5952044, -167.2878319>,
    <0.5995285, -167.2815307>,
    <0.5925926, -167.2690732>,
    <0.5972328, -167.3024008>,
    <0.6111111, -167.3024008>,
    <0.5971775, -167.2522483>,
    <0.5952044, -167.2878319>,
    <0.6050393, -167.3024008>,
    <0.6050047, -167.2804214>,
    <0.5951729, -167.2596042>,
    <0.5948992, -167.2232074>,
    <0.6018519, -167.2357456>,
    <0.5972340, -167.2024179>,
    <0.5833333, -167.2024179>,
    <0.5971775, -167.2522483>,
    <0.5992518, -167.2169804>,
    <0.5894168, -167.2024179>,
    <0.5893813, -167.2241867>,
    <0.5992196, -167.2450388>,
    <0.6053129, -167.2602946>,
    <0.6018519, -167.2357456>,
    <0.5971775, -167.2522483>,
    <0.6111111, -167.3024008>,
    <0.6111111, -167.2507837>,
    <0.5992196, -167.2450388>,
    <0.6050047, -167.2804214>,
    <0.6111111, -167.2798504>,
    <0.6070554, -167.2441968>,
    <0.6053270, -167.2228413>,
    <0.6018519, -167.2357456>,
    <0.6111111, -167.2507837>,
    <0.6111111, -167.2024179>,
    <0.5972340, -167.2024179>,
    <0.6070554, -167.2441968>,
    <0.6111111, -167.2235884>,
    <0.6050399, -167.2024179>,
    <0.5992518, -167.2169804>,
    <0.5928926, -167.0805640>,
    <0.5964017, -167.0842391>,
    <0.6024940, -167.1011244>,
    <0.5833385, -167.0684463>,
    <0.5893364, -167.0684463>,
    <0.6003430, -167.0951629>,
    <0.5949060, -167.0881797>,
    <0.5863768, -167.0684463>,
    <0.5921733, -167.0747877>,
    <0.5962488, -167.0794526>,
    <0.5964017, -167.0842391>,
    <0.5893364, -167.0684463>,
    <0.5947554, -167.0684463>,
    <0.6045017, -167.0966789>,
    <0.5921733, -167.0747877>,
    <0.5921433, -167.0684463>,
    <0.5997484, -167.0829097>,
    <0.6004659, -167.0904808>,
    <0.6036271, -167.0994668>,
    <0.5964017, -167.0842391>,
    <0.6045017, -167.0966789>,
    <0.6111111, -167.1158246>,
    <0.6024940, -167.1011244>,
    <0.6004659, -167.0904808>,
    <0.6085429, -167.1083851>,
    <0.6076496, -167.1099195>,
    <0.6003430, -167.0951629>,
    <0.4075985, -167.0794542>,
    <0.4112148, -167.0842391>,
    <0.4100593, -167.0966849>,
    <0.4003109, -167.0684463>,
    <0.4088090, -167.0684463>,
    <0.4105188, -167.0917353>,
    <0.4053051, -167.0829132>,
    <0.4046907, -167.0684463>,
    <0.4098554, -167.0753157>,
    <0.4133393, -167.0789148>,
    <0.4112148, -167.0842391>,
    <0.4088090, -167.0684463>,
    <0.4166667, -167.0684463>,
    <0.4166667, -167.0945275>,
    <0.4098554, -167.0753157>,
    <0.4127753, -167.0684463>,
    <0.4166667, -167.0816213>,
    <0.4143641, -167.0901822>,
    <0.4136519, -167.0978190>,
    <0.4112148, -167.0842391>,
    <0.4166667, -167.0945275>,
    <0.4166667, -167.1158246>,
    <0.4100593, -167.0966849>,
    <0.4143641, -167.0901822>,
    <0.4166667, -167.1098561>,
    <0.4140997, -167.1083889>,
    <0.4105188, -167.0917353>,
    <0.5904379, -167.0912675>,
    <0.5925926, -167.1000319>,
    <0.5833333, -167.0954675>,
    <0.5833333, -167.0684463>,
    <0.6024924, -167.1011244>,
    <0.5873221, -167.0974337>,
    <0.5833333, -167.0824313>,
    <0.5949030, -167.0881797>,
    <0.5974622, -167.1005693>,
    <0.6007106, -167.1082014>,
    <0.5925926, -167.1000319>,
    <0.6024924, -167.1011244>,
    <0.6111111, -167.1158246>,
    <0.5966461, -167.1158246>,
    <0.5974622, -167.1005693>,
    <0.6076489, -167.1099195>,
    <0.6048588, -167.1158246>,
    <0.5947549, -167.1084564>,
    <0.5889763, -167.1067872>,
    <0.5925926, -167.1000319>,
    <0.5966461, -167.1158246>,
    <0.5833333, -167.1158246>,
    <0.5833333, -167.0954675>,
    <0.5947549, -167.1084564>,
    <0.5888243, -167.1158246>,
    <0.5833333, -167.1101308>,
    <0.5873221, -167.0974337>,
    <0.4113805, -167.1106496>,
    <0.4103307, -167.1123151>,
    <0.4156645, -167.1220941>,
    <0.4129568, -167.1040945>,
    <0.4065699, -167.1040945>,
    <0.4128898, -167.1170071>,
    <0.4144164, -167.1137977>,
    <0.4095034, -167.1040945>,
    <0.4079579, -167.1071285>,
    <0.4078090, -167.1108241>,
    <0.4103307, -167.1123151>,
    <0.4065699, -167.1040945>,
    <0.4013685, -167.1040945>,
    <0.4129670, -167.1227923>,
    <0.4079579, -167.1071285>,
    <0.4038950, -167.1040945>,
    <0.4086523, -167.1158365>,
    <0.4119972, -167.1189380>,
    <0.4139072, -167.1214895>,
    <0.4103307, -167.1123151>,
    <0.4129670, -167.1227923>,
    <0.4166667, -167.1287564>,
    <0.4156645, -167.1220941>,
    <0.4119972, -167.1189380>,
    <0.4153172, -167.1265810>,
    <0.4163819, -167.1268636>,
    <0.4128898, -167.1170071>,
    <0.4020977, -167.1176325>,
    <0.4023080, -167.1205358>,
    <0.4129670, -167.1227923>,
    <0.4013685, -167.1040945>,
    <0.3917475, -167.1231074>,
    <0.4082862, -167.1218014>,
    <0.4086523, -167.1158365>,
    <0.3952408, -167.1162040>,
    <0.3966188, -167.1219212>,
    <0.3961881, -167.1252890>,
    <0.4023080, -167.1205358>,
    <0.3917475, -167.1231074>,
    <0.3888889, -167.1287564>,
    <0.4018082, -167.1287564>,
    <0.3966188, -167.1219212>,
    <0.3899269, -167.1267052>,
    <0.3941593, -167.1287564>,
    <0.4019860, -167.1258320>,
    <0.4084375, -167.1252102>,
    <0.4023080, -167.1205358>,
    <0.4018082, -167.1287564>,
    <0.4166667, -167.1287564>,
    <0.4129670, -167.1227923>,
    <0.4019860, -167.1258320>,
    <0.4102009, -167.1287564>,
    <0.4153172, -167.1265810>,
    <0.4082862, -167.1218014>,
    <0.4002803, -167.1442610>,
    <0.4074074, -167.1533103>,
    <0.4018082, -167.1287564>,
    <0.3888889, -167.1287564>,
    <0.4030168, -167.1662209>,
    <0.4045672, -167.1408553>,
    <0.3941593, -167.1287564>,
    <0.3951460, -167.1453493>,
    <0.4049952, -167.1604034>,
    <0.4109394, -167.1706661>,
    <0.4074074, -167.1533103>,
    <0.4030168, -167.1662209>,
    <0.4166667, -167.2024179>,
    <0.4166667, -167.1607154>,
    <0.4049952, -167.1604034>,
    <0.4107263, -167.1866652>,
    <0.4166667, -167.1838308>,
    <0.4126787, -167.1575260>,
    <0.4106372, -167.1428846>,
    <0.4074074, -167.1533103>,
    <0.4166667, -167.1607154>,
    <0.4166667, -167.1287564>,
    <0.4018082, -167.1287564>,
    <0.4126787, -167.1575260>,
    <0.4166667, -167.1413913>,
    <0.4102009, -167.1287564>,
    <0.4045672, -167.1408553>,
    <0.5906382, -167.1107625>,
    <0.5884455, -167.1123279>,
    <0.5865042, -167.1224952>,
    <0.5958132, -167.1041136>,
    <0.5917900, -167.1041136>,
    <0.5871972, -167.1188660>,
    <0.5901899, -167.1152174>,
    <0.5939375, -167.1041136>,
    <0.5906401, -167.1069379>,
    <0.5876941, -167.1101334>,
    <0.5884455, -167.1123279>,
    <0.5917900, -167.1041136>,
    <0.5861900, -167.1041136>,
    <0.5843509, -167.1199784>,
    <0.5906401, -167.1069379>,
    <0.5892774, -167.1041136>,
    <0.5852632, -167.1121091>,
    <0.5865058, -167.1159522>,
    <0.5856585, -167.1208895>,
    <0.5884455, -167.1123279>,
    <0.5843509, -167.1199784>,
    <0.5833333, -167.1287564>,
    <0.5865042, -167.1224952>,
    <0.5865058, -167.1159522>,
    <0.5836768, -167.1257934>,
    <0.5844900, -167.1264725>,
    <0.5871972, -167.1188660>,
    <0.5892034, -167.1582978>,
    <0.5925926, -167.1778641>,
    <0.5975545, -167.1664684>,
    <0.5833333, -167.1287564>,
    <0.5833333, -167.1601023>,
    <0.5953914, -167.1714363>,
    <0.5896912, -167.1456163>,
    <0.5833333, -167.1407348>,
    <0.5873890, -167.1678822>,
    <0.5891233, -167.1857006>,
    <0.5925926, -167.1778641>,
    <0.5833333, -167.1601023>,
    <0.5833333, -167.2024179>,
    <0.5972340, -167.2024179>,
    <0.5873890, -167.1678822>,
    <0.5833333, -167.1835237>,
    <0.5894168, -167.2024179>,
    <0.5952156, -167.1917403>,
    <0.5996231, -167.1872921>,
    <0.5925926, -167.1778641>,
    <0.5972340, -167.2024179>,
    <0.6111111, -167.2024179>,
    <0.5975545, -167.1664684>,
    <0.5952156, -167.1917403>,
    <0.6050399, -167.2024179>,
    <0.6052206, -167.1867974>,
    <0.5953914, -167.1714363>,
    <0.5966703, -167.1175674>,
    <0.5967526, -167.1205421>,
    <0.6076113, -167.1231187>,
    <0.5958132, -167.1041136>,
    <0.5865042, -167.1224952>,
    <0.6030343, -167.1220327>,
    <0.6034856, -167.1164727>,
    <0.5901899, -167.1152174>,
    <0.5913890, -167.1215643>,
    <0.5907559, -167.1251375>,
    <0.5967526, -167.1205421>,
    <0.5865042, -167.1224952>,
    <0.5833333, -167.1287564>,
    <0.5964335, -167.1287564>,
    <0.5913890, -167.1215643>,
    <0.5844900, -167.1264725>,
    <0.5887153, -167.1287564>,
    <0.5965392, -167.1260345>,
    <0.6029771, -167.1252934>,
    <0.5967526, -167.1205421>,
    <0.5964335, -167.1287564>,
    <0.6111111, -167.1287564>,
    <0.6076113, -167.1231187>,
    <0.5965392, -167.1260345>,
    <0.6047686, -167.1287564>,
    <0.6098355, -167.1267016>,
    <0.6030343, -167.1220327>,
    <0.5947933, -167.1443229>,
    <0.6018519, -167.1533103>,
    <0.5964335, -167.1287564>,
    <0.5833333, -167.1287564>,
    <0.5975545, -167.1664684>,
    <0.5991119, -167.1408941>,
    <0.5887153, -167.1287564>,
    <0.5896912, -167.1456163>,
    <0.5994925, -167.1605343>,
    <0.6054072, -167.1705747>,
    <0.6018519, -167.1533103>,
    <0.5975545, -167.1664684>,
    <0.6111111, -167.2024179>,
    <0.6111111, -167.1601023>,
    <0.5994925, -167.1605343>,
    <0.6052206, -167.1867974>,
    <0.6111111, -167.1835237>,
    <0.6071249, -167.1571782>,
    <0.6051269, -167.1427314>,
    <0.6018519, -167.1533103>,
    <0.6111111, -167.1601023>,
    <0.6111111, -167.1287564>,
    <0.5964335, -167.1287564>,
    <0.6071249, -167.1571782>,
    <0.6111111, -167.1407348>,
    <0.6047686, -167.1287564>,
    <0.5991119, -167.1408941>,
    <0.4212097, -167.9488775>,
    <0.4259259, -168.0047729>,
    <0.4166667, -167.9745941>,
    <0.4166667, -167.8774261>,
    <0.4255794, -167.9387168>,
    <0.4208338, -167.9881760>,
    <0.4166667, -167.9198146>,
    <0.4204369, -167.9033533>,
    <0.4257482, -167.9708956>,
    <0.4318583, -168.0200956>,
    <0.4259259, -168.0047729>,
    <0.4255794, -167.9387168>,
    <0.4444444, -168.0684463>,
    <0.4314833, -168.0684463>,
    <0.4257482, -167.9708956>,
    <0.4332921, -167.9917547>,
    <0.4366537, -168.0684463>,
    <0.4288606, -168.0383970>,
    <0.4226856, -168.0290649>,
    <0.4259259, -168.0047729>,
    <0.4314833, -168.0684463>,
    <0.4166667, -168.0684463>,
    <0.4166667, -167.9745941>,
    <0.4288606, -168.0383970>,
    <0.4259634, -168.0684463>,
    <0.4166667, -168.0262891>,
    <0.4208338, -167.9881760>,
    <0.4224376, -167.7682008>,
    <0.4259259, -167.8156918>,
    <0.4166667, -167.7804924>,
    <0.4166667, -167.6922232>,
    <0.4304912, -167.7843959>,
    <0.4207132, -167.7958753>,
    <0.4166667, -167.7304215>,
    <0.4227044, -167.7324785>,
    <0.4284958, -167.7980752>,
    <0.4328577, -167.8387349>,
    <0.4259259, -167.8156918>,
    <0.4304912, -167.7843959>,
    <0.4444444, -167.8774261>,
    <0.4305692, -167.8774261>,
    <0.4284958, -167.7980752>,
    <0.4384299, -167.8373256>,
    <0.4385189, -167.8774261>,
    <0.4285691, -167.8508342>,
    <0.4224571, -167.8377591>,
    <0.4259259, -167.8156918>,
    <0.4305692, -167.8774261>,
    <0.4166667, -167.8774261>,
    <0.4166667, -167.7804924>,
    <0.4285691, -167.8508342>,
    <0.4225813, -167.8774261>,
    <0.4166667, -167.8358856>,
    <0.4207132, -167.7958753>,
    <0.4270001, -167.9086671>,
    <0.4351852, -167.9410995>,
    <0.4255794, -167.9387168>,
    <0.4166667, -167.8774261>,
    <0.4305692, -167.8774261>,
    <0.4291443, -167.9396011>,
    <0.4204369, -167.9033533>,
    <0.4225813, -167.8774261>,
    <0.4327632, -167.9076901>,
    <0.4386608, -167.9062922>,
    <0.4351852, -167.9410995>,
    <0.4305692, -167.8774261>,
    <0.4444444, -167.8774261>,
    <0.4444444, -167.9292172>,
    <0.4327632, -167.9076901>,
    <0.4385189, -167.8774261>,
    <0.4444444, -167.8990220>,
    <0.4406391, -167.9341006>,
    <0.4374134, -167.9693699>,
    <0.4351852, -167.9410995>,
    <0.4444444, -167.9292172>,
    <0.4444444, -168.0684463>,
    <0.4255794, -167.9387168>,
    <0.4406391, -167.9341006>,
    <0.4444444, -167.9756913>,
    <0.4332921, -167.9917547>,
    <0.4291443, -167.9396011>,
    <0.5604592, -167.9427660>,
    <0.5648148, -168.0047729>,
    <0.5555556, -167.9402278>,
    <0.5555556, -167.8774261>,
    <0.5659110, -167.9486373>,
    <0.5597516, -167.9694778>,
    <0.5555556, -167.9042294>,
    <0.5599900, -167.9079207>,
    <0.5654111, -167.9742365>,
    <0.5708759, -168.0225757>,
    <0.5648148, -168.0047729>,
    <0.5659110, -167.9486373>,
    <0.5833333, -168.0684463>,
    <0.5694444, -168.0684463>,
    <0.5654111, -167.9742365>,
    <0.5734755, -168.0006569>,
    <0.5763889, -168.0684463>,
    <0.5675591, -168.0425169>,
    <0.5613426, -168.0204733>,
    <0.5648148, -168.0047729>,
    <0.5694444, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5555556, -167.9402278>,
    <0.5675591, -168.0425169>,
    <0.5625000, -168.0684463>,
    <0.5555556, -167.9884946>,
    <0.5597516, -167.9694778>,
    <0.5662504, -167.9111472>,
    <0.5740741, -167.9410995>,
    <0.5659110, -167.9486373>,
    <0.5555556, -167.8774261>,
    <0.5694611, -167.8774261>,
    <0.5691721, -167.9456260>,
    <0.5599900, -167.9079207>,
    <0.5615225, -167.8774261>,
    <0.5716089, -167.9070731>,
    <0.5775505, -167.9090362>,
    <0.5740741, -167.9410995>,
    <0.5694611, -167.8774261>,
    <0.5833333, -167.8774261>,
    <0.5833333, -167.9401931>,
    <0.5716089, -167.9070731>,
    <0.5773532, -167.8774261>,
    <0.5833333, -167.9042187>,
    <0.5794459, -167.9405737>,
    <0.5766629, -167.9745941>,
    <0.5740741, -167.9410995>,
    <0.5833333, -167.9401931>,
    <0.5833333, -168.0684463>,
    <0.5659110, -167.9486373>,
    <0.5794459, -167.9405737>,
    <0.5833333, -167.9885150>,
    <0.5734755, -168.0006569>,
    <0.5691721, -167.9456260>,
    <0.4146190, -167.1106496>,
    <0.4154300, -167.1123151>,
    <0.4144246, -167.1040945>,
    <0.4129568, -167.1040945>,
    <0.4156645, -167.1220941>,
    <0.4148549, -167.1076129>,
    <0.4135996, -167.1040945>,
    <0.4144164, -167.1137977>,
    <0.4155812, -167.1186208>,
    <0.4161070, -167.1197235>,
    <0.4154300, -167.1123151>,
    <0.4156645, -167.1220941>,
    <0.4166667, -167.1287564>,
    <0.4166667, -167.1157282>,
    <0.4155812, -167.1186208>,
    <0.4163819, -167.1268636>,
    <0.4166667, -167.1243298>,
    <0.4161716, -167.1143619>,
    <0.4157970, -167.1090581>,
    <0.4154300, -167.1123151>,
    <0.4166667, -167.1157282>,
    <0.4166667, -167.1040945>,
    <0.4144246, -167.1040945>,
    <0.4161716, -167.1143619>,
    <0.4166667, -167.1077212>,
    <0.4154763, -167.1040945>,
    <0.4148549, -167.1076129>,
    <0.5849783, -167.1101299>,
    <0.5842856, -167.1123215>,
    <0.5843509, -167.1199784>,
    <0.5861900, -167.1041136>,
    <0.5850866, -167.1041062>,
    <0.5843263, -167.1170887>,
    <0.5852632, -167.1121091>,
    <0.5857116, -167.1041104>,
    <0.5847417, -167.1076438>,
    <0.5840097, -167.1098044>,
    <0.5842856, -167.1123215>,
    <0.5850866, -167.1041062>,
    <0.5833333, -167.1040945>,
    <0.5833333, -167.1186955>,
    <0.5847417, -167.1076438>,
    <0.5842701, -167.1041008>,
    <0.5833333, -167.1075966>,
    <0.5836825, -167.1163585>,
    <0.5838258, -167.1199380>,
    <0.5842856, -167.1123215>,
    <0.5833333, -167.1186955>,
    <0.5833333, -167.1287564>,
    <0.5843509, -167.1199784>,
    <0.5836825, -167.1163585>,
    <0.5833333, -167.1268389>,
    <0.5836768, -167.1257934>,
    <0.5843263, -167.1170887>,
    <0.4224476, -167.5906989>,
    <0.4259259, -167.6342972>,
    <0.4166667, -167.6048705>,
    <0.4166667, -167.5184453>,
    <0.4305313, -167.6051824>,
    <0.4207176, -167.6177446>,
    <0.4166667, -167.5563664>,
    <0.4227279, -167.5563642>,
    <0.4285181, -167.6179095>,
    <0.4328656, -167.6559815>,
    <0.4259259, -167.6342972>,
    <0.4305313, -167.6051824>,
    <0.4444444, -167.6922232>,
    <0.4305610, -167.6922232>,
    <0.4285181, -167.6179095>,
    <0.4383517, -167.6541068>,
    <0.4383701, -167.6922232>,
    <0.4285353, -167.6669079>,
    <0.4224551, -167.6559035>,
    <0.4259259, -167.6342972>,
    <0.4305610, -167.6922232>,
    <0.4166667, -167.6922232>,
    <0.4166667, -167.6048705>,
    <0.4285353, -167.6669079>,
    <0.4227466, -167.6922232>,
    <0.4166667, -167.6541051>,
    <0.4207176, -167.6177446>,
    <0.4282260, -167.7306999>,
    <0.4351852, -167.7539575>,
    <0.4304912, -167.7843959>,
    <0.4166667, -167.6922232>,
    <0.4305610, -167.6922232>,
    <0.4325422, -167.7710961>,
    <0.4227044, -167.7324785>,
    <0.4227466, -167.6922232>,
    <0.4325803, -167.7191816>,
    <0.4386588, -167.7297204>,
    <0.4351852, -167.7539575>,
    <0.4305610, -167.6922232>,
    <0.4444444, -167.6922232>,
    <0.4444444, -167.7804778>,
    <0.4325803, -167.7191816>,
    <0.4383701, -167.6922232>,
    <0.4444444, -167.7304140>,
    <0.4403903, -167.7688661>,
    <0.4386413, -167.7990643>,
    <0.4351852, -167.7539575>,
    <0.4444444, -167.7804778>,
    <0.4444444, -167.8774261>,
    <0.4304912, -167.7843959>,
    <0.4403903, -167.7688661>,
    <0.4444444, -167.8359460>,
    <0.4384299, -167.8373256>,
    <0.4325422, -167.7710961>,
    <0.5613252, -167.7681789>,
    <0.5648148, -167.8156918>,
    <0.5555556, -167.7804408>,
    <0.5555556, -167.6922232>,
    <0.5693747, -167.7843598>,
    <0.5596015, -167.7958439>,
    <0.5555556, -167.7303949>,
    <0.5615903, -167.7324583>,
    <0.5673811, -167.7980585>,
    <0.5717460, -167.8387259>,
    <0.5648148, -167.8156918>,
    <0.5693747, -167.7843598>,
    <0.5833333, -167.8774261>,
    <0.5694611, -167.8774261>,
    <0.5673811, -167.7980585>,
    <0.5772690, -167.8369933>,
    <0.5773532, -167.8774261>,
    <0.5674483, -167.8506823>,
    <0.5613468, -167.8377462>,
    <0.5648148, -167.8156918>,
    <0.5694611, -167.8774261>,
    <0.5555556, -167.8774261>,
    <0.5555556, -167.7804408>,
    <0.5674483, -167.8506823>,
    <0.5615225, -167.8774261>,
    <0.5555556, -167.8351215>,
    <0.5596015, -167.7958439>,
    <0.5671136, -167.7306909>,
    <0.5740741, -167.7539575>,
    <0.5693747, -167.7843598>,
    <0.5555556, -167.6922232>,
    <0.5694499, -167.6922232>,
    <0.5714280, -167.7710759>,
    <0.5615903, -167.7324583>,
    <0.5616355, -167.6922232>,
    <0.5714690, -167.7191795>,
    <0.5775477, -167.7297106>,
    <0.5740741, -167.7539575>,
    <0.5694499, -167.6922232>,
    <0.5833333, -167.6922232>,
    <0.5833333, -167.7804384>,
    <0.5714690, -167.7191795>,
    <0.5772590, -167.6922232>,
    <0.5833333, -167.7303936>,
    <0.5792792, -167.7688438>,
    <0.5775289, -167.7990454>,
    <0.5740741, -167.7539575>,
    <0.5833333, -167.7804384>,
    <0.5833333, -167.8774261>,
    <0.5693747, -167.7843598>,
    <0.5792792, -167.7688438>,
    <0.5833333, -167.8351135>,
    <0.5772690, -167.8369933>,
    <0.5714280, -167.7710759>,
    <0.4210322, -167.9482885>,
    <0.4259259, -168.0105648>,
    <0.4248695, -167.9460793>,
    <0.4166667, -167.8948019>,
    <0.4166667, -167.9417080>,
    <0.4253587, -167.9759422>,
    <0.4201435, -167.9165361>,
    <0.4166667, -167.9144287>,
    <0.4209492, -167.9735555>,
    <0.4223919, -168.0222913>,
    <0.4259259, -168.0105648>,
    <0.4166667, -167.9417080>,
    <0.4166667, -168.0684463>,
    <0.4303082, -168.0684463>,
    <0.4209492, -167.9735555>,
    <0.4166667, -167.9859274>,
    <0.4250931, -168.0684463>,
    <0.4285911, -168.0457670>,
    <0.4313870, -168.0233842>,
    <0.4259259, -168.0105648>,
    <0.4303082, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4248695, -167.9460793>,
    <0.4285911, -168.0457670>,
    <0.4352553, -168.0684463>,
    <0.4321659, -167.9916906>,
    <0.4253587, -167.9759422>,
    <0.4224385, -167.7954192>,
    <0.4259259, -167.8386752>,
    <0.4304947, -167.8102432>,
    <0.4166667, -167.7264218>,
    <0.4166667, -167.8063366>,
    <0.4284974, -167.8226725>,
    <0.4227064, -167.7630330>,
    <0.4166667, -167.7609594>,
    <0.4207134, -167.8204700>,
    <0.4224571, -167.8586539>,
    <0.4259259, -167.8386752>,
    <0.4166667, -167.8063366>,
    <0.4166667, -167.8948019>,
    <0.4305690, -167.8948019>,
    <0.4207134, -167.8204700>,
    <0.4166667, -167.8571134>,
    <0.4225554, -167.8948019>,
    <0.4285754, -167.8707029>,
    <0.4328585, -167.8596306>,
    <0.4259259, -167.8386752>,
    <0.4305690, -167.8948019>,
    <0.4444444, -167.8948019>,
    <0.4304947, -167.8102432>,
    <0.4285754, -167.8707029>,
    <0.4385252, -167.8948019>,
    <0.4384328, -167.8583612>,
    <0.4284974, -167.8226725>,
    <0.4268226, -167.9220916>,
    <0.4351852, -167.9526834>,
    <0.4305690, -167.8948019>,
    <0.4166667, -167.8948019>,
    <0.4248695, -167.9460793>,
    <0.4327850, -167.9225882>,
    <0.4225554, -167.8948019>,
    <0.4201435, -167.9165361>,
    <0.4286171, -167.9484786>,
    <0.4372359, -167.9759385>,
    <0.4351852, -167.9526834>,
    <0.4248695, -167.9460793>,
    <0.4444444, -168.0684463>,
    <0.4444444, -167.9365451>,
    <0.4286171, -167.9484786>,
    <0.4321659, -167.9916906>,
    <0.4444444, -167.9784771>,
    <0.4406722, -167.9431200>,
    <0.4386608, -167.9197081>,
    <0.4351852, -167.9526834>,
    <0.4444444, -167.9365451>,
    <0.4444444, -167.8948019>,
    <0.4305690, -167.8948019>,
    <0.4406722, -167.9431200>,
    <0.4444444, -167.9122356>,
    <0.4385252, -167.8948019>,
    <0.4327850, -167.9225882>,
    <0.5604600, -167.9541759>,
    <0.5648148, -168.0105648>,
    <0.5659141, -167.9595553>,
    <0.5555556, -167.8948019>,
    <0.5555556, -167.9517813>,
    <0.5654128, -167.9828178>,
    <0.5599925, -167.9225381>,
    <0.5555556, -167.9192646>,
    <0.5597517, -167.9784207>,
    <0.5613426, -168.0248097>,
    <0.5648148, -168.0105648>,
    <0.5555556, -167.9517813>,
    <0.5555556, -168.0684463>,
    <0.5694445, -168.0684463>,
    <0.5597517, -167.9784207>,
    <0.5555556, -167.9954063>,
    <0.5625000, -168.0684463>,
    <0.5675595, -168.0448794>,
    <0.5708767, -168.0267532>,
    <0.5648148, -168.0105648>,
    <0.5694445, -168.0684463>,
    <0.5833333, -168.0684463>,
    <0.5659141, -167.9595553>,
    <0.5675595, -168.0448794>,
    <0.5763889, -168.0684463>,
    <0.5734786, -168.0068421>,
    <0.5654128, -167.9828178>,
    <0.5662511, -167.9254606>,
    <0.5740741, -167.9526834>,
    <0.5694608, -167.8948019>,
    <0.5555556, -167.8948019>,
    <0.5659141, -167.9595553>,
    <0.5716110, -167.9217792>,
    <0.5615224, -167.8948019>,
    <0.5599925, -167.9225381>,
    <0.5691707, -167.9568128>,
    <0.5766637, -167.9831080>,
    <0.5740741, -167.9526834>,
    <0.5659141, -167.9595553>,
    <0.5833333, -168.0684463>,
    <0.5833333, -167.9517471>,
    <0.5691707, -167.9568128>,
    <0.5734786, -168.0068421>,
    <0.5833333, -167.9954262>,
    <0.5794463, -167.9521401>,
    <0.5775504, -167.9235086>,
    <0.5740741, -167.9526834>,
    <0.5833333, -167.9517471>,
    <0.5833333, -167.8948019>,
    <0.5694608, -167.8948019>,
    <0.5794463, -167.9521401>,
    <0.5833333, -167.9192542>,
    <0.5773530, -167.8948019>,
    <0.5716110, -167.9217792>,
    <0.4224454, -167.4265843>,
    <0.4259259, -167.4660888>,
    <0.4166667, -167.4391507>,
    <0.4166667, -167.3613758>,
    <0.4305222, -167.4397221>,
    <0.4207169, -167.4509341>,
    <0.4166667, -167.3955180>,
    <0.4227220, -167.3956156>,
    <0.4285128, -167.4512490>,
    <0.4328640, -167.4856754>,
    <0.4259259, -167.4660888>,
    <0.4305222, -167.4397221>,
    <0.4444444, -167.5184453>,
    <0.4305634, -167.5184453>,
    <0.4285128, -167.4512490>,
    <0.4383457, -167.4839601>,
    <0.4383713, -167.5184453>,
    <0.4285367, -167.4955641>,
    <0.4224557, -167.4855325>,
    <0.4259259, -167.4660888>,
    <0.4305634, -167.5184453>,
    <0.4166667, -167.5184453>,
    <0.4166667, -167.4391507>,
    <0.4285367, -167.4955641>,
    <0.4227479, -167.5184453>,
    <0.4166667, -167.4838674>,
    <0.4207169, -167.4509341>,
    <0.4282366, -167.5546111>,
    <0.4351852, -167.5763713>,
    <0.4305313, -167.6051824>,
    <0.4166667, -167.5184453>,
    <0.4305634, -167.5184453>,
    <0.4325645, -167.5925951>,
    <0.4227279, -167.5563642>,
    <0.4227479, -167.5184453>,
    <0.4325839, -167.5437683>,
    <0.4386594, -167.5545331>,
    <0.4351852, -167.5763713>,
    <0.4305634, -167.5184453>,
    <0.4444444, -167.5184453>,
    <0.4444444, -167.6048705>,
    <0.4325839, -167.5437683>,
    <0.4383713, -167.5184453>,
    <0.4444444, -167.5563664>,
    <0.4403899, -167.5923911>,
    <0.4386513, -167.6196618>,
    <0.4351852, -167.5763713>,
    <0.4444444, -167.6048705>,
    <0.4444444, -167.6922232>,
    <0.4305313, -167.6051824>,
    <0.4403899, -167.5923911>,
    <0.4444444, -167.6541051>,
    <0.4383517, -167.6541068>,
    <0.4325645, -167.5925951>,
    <0.5613365, -167.5906989>,
    <0.5648148, -167.6342972>,
    <0.5555556, -167.6048705>,
    <0.5555556, -167.5184453>,
    <0.5694202, -167.6051824>,
    <0.5596065, -167.6177446>,
    <0.5555556, -167.5563664>,
    <0.5616168, -167.5563642>,
    <0.5674070, -167.6179095>,
    <0.5717546, -167.6559815>,
    <0.5648148, -167.6342972>,
    <0.5694202, -167.6051824>,
    <0.5833333, -167.6922232>,
    <0.5694499, -167.6922232>,
    <0.5674070, -167.6179095>,
    <0.5772406, -167.6541068>,
    <0.5772590, -167.6922232>,
    <0.5674242, -167.6669079>,
    <0.5613440, -167.6559035>,
    <0.5648148, -167.6342972>,
    <0.5694499, -167.6922232>,
    <0.5555556, -167.6922232>,
    <0.5555556, -167.6048705>,
    <0.5674242, -167.6669079>,
    <0.5616355, -167.6922232>,
    <0.5555556, -167.6541051>,
    <0.5596065, -167.6177446>,
    <0.5671255, -167.5546111>,
    <0.5740741, -167.5763713>,
    <0.5694202, -167.6051824>,
    <0.5555556, -167.5184453>,
    <0.5694523, -167.5184453>,
    <0.5714534, -167.5925951>,
    <0.5616168, -167.5563642>,
    <0.5616368, -167.5184453>,
    <0.5714728, -167.5437683>,
    <0.5775483, -167.5545331>,
    <0.5740741, -167.5763713>,
    <0.5694523, -167.5184453>,
    <0.5833333, -167.5184453>,
    <0.5833333, -167.6048705>,
    <0.5714728, -167.5437683>,
    <0.5772602, -167.5184453>,
    <0.5833333, -167.5563664>,
    <0.5792788, -167.5923911>,
    <0.5775402, -167.6196618>,
    <0.5740741, -167.5763713>,
    <0.5833333, -167.6048705>,
    <0.5833333, -167.6922232>,
    <0.5694202, -167.6051824>,
    <0.5792788, -167.5923911>,
    <0.5833333, -167.6541051>,
    <0.5772406, -167.6541068>,
    <0.5714534, -167.5925951>,
    <0.4224481, -167.6341061>,
    <0.4259259, -167.6737665>,
    <0.4305332, -167.6473117>,
    <0.4166667, -167.5684558>,
    <0.4166667, -167.6468904>,
    <0.4285192, -167.6588757>,
    <0.4227291, -167.6029317>,
    <0.4166667, -167.6028580>,
    <0.4207177, -167.6586490>,
    <0.4224549, -167.6933751>,
    <0.4259259, -167.6737665>,
    <0.4166667, -167.6468904>,
    <0.4166667, -167.7264218>,
    <0.4305604, -167.7264218>,
    <0.4207177, -167.6586490>,
    <0.4166667, -167.6917086>,
    <0.4227464, -167.7264218>,
    <0.4285349, -167.7034090>,
    <0.4328660, -167.6934805>,
    <0.4259259, -167.6737665>,
    <0.4305604, -167.7264218>,
    <0.4444444, -167.7264218>,
    <0.4305332, -167.6473117>,
    <0.4285349, -167.7034090>,
    <0.4383698, -167.7264218>,
    <0.4383529, -167.6917804>,
    <0.4285192, -167.6588757>,
    <0.4282268, -167.7614089>,
    <0.4351852, -167.7825485>,
    <0.4305604, -167.7264218>,
    <0.4166667, -167.7264218>,
    <0.4304947, -167.8102432>,
    <0.4325799, -167.7509307>,
    <0.4227464, -167.7264218>,
    <0.4227064, -167.7630330>,
    <0.4325442, -167.7981420>,
    <0.4386422, -167.8234787>,
    <0.4351852, -167.7825485>,
    <0.4304947, -167.8102432>,
    <0.4444444, -167.8948019>,
    <0.4444444, -167.8063209>,
    <0.4325442, -167.7981420>,
    <0.4384328, -167.8583612>,
    <0.4444444, -167.8572675>,
    <0.4403905, -167.7959127>,
    <0.4386586, -167.7604283>,
    <0.4351852, -167.7825485>,
    <0.4444444, -167.8063209>,
    <0.4444444, -167.7264218>,
    <0.4305604, -167.7264218>,
    <0.4403905, -167.7959127>,
    <0.4444444, -167.7609514>,
    <0.4383698, -167.7264218>,
    <0.4325799, -167.7509307>,
    <0.5613260, -167.7953972>,
    <0.5648148, -167.8386752>,
    <0.5693782, -167.8102106>,
    <0.5555556, -167.7264218>,
    <0.5555556, -167.8062814>,
    <0.5673828, -167.8226575>,
    <0.5615923, -167.7630148>,
    <0.5555556, -167.7609311>,
    <0.5596017, -167.8204368>,
    <0.5613467, -167.8586401>,
    <0.5648148, -167.8386752>,
    <0.5555556, -167.8062814>,
    <0.5555556, -167.8948019>,
    <0.5694608, -167.8948019>,
    <0.5596017, -167.8204368>,
    <0.5555556, -167.8563468>,
    <0.5615224, -167.8948019>,
    <0.5674498, -167.8705077>,
    <0.5717468, -167.8596224>,
    <0.5648148, -167.8386752>,
    <0.5694608, -167.8948019>,
    <0.5833333, -167.8948019>,
    <0.5693782, -167.8102106>,
    <0.5674498, -167.8705077>,
    <0.5773530, -167.8948019>,
    <0.5772716, -167.8580577>,
    <0.5673828, -167.8226575>,
    <0.5671143, -167.7614007>,
    <0.5740741, -167.7825485>,
    <0.5694493, -167.7264218>,
    <0.5555556, -167.7264218>,
    <0.5693782, -167.8102106>,
    <0.5714687, -167.7509288>,
    <0.5616353, -167.7264218>,
    <0.5615923, -167.7630148>,
    <0.5714301, -167.7981237>,
    <0.5775298, -167.8234600>,
    <0.5740741, -167.7825485>,
    <0.5693782, -167.8102106>,
    <0.5833333, -167.8948019>,
    <0.5833333, -167.8062788>,
    <0.5714301, -167.7981237>,
    <0.5772716, -167.8580577>,
    <0.5833333, -167.8563381>,
    <0.5792793, -167.7958890>,
    <0.5775475, -167.7604178>,
    <0.5740741, -167.7825485>,
    <0.5833333, -167.8062788>,
    <0.5833333, -167.7264218>,
    <0.5694493, -167.7264218>,
    <0.5792793, -167.7958890>,
    <0.5833333, -167.7609297>,
    <0.5772587, -167.7264218>,
    <0.5714687, -167.7509288>,
    <0.4224460, -167.4848985>,
    <0.4259259, -167.5208549>,
    <0.4305249, -167.4968970>,
    <0.4166667, -167.4256532>,
    <0.4166667, -167.4961890>,
    <0.4285144, -167.5073705>,
    <0.4227238, -167.4567920>,
    <0.4166667, -167.4566011>,
    <0.4207171, -167.5069791>,
    <0.4224555, -167.5384889>,
    <0.4259259, -167.5208549>,
    <0.4166667, -167.4961890>,
    <0.4166667, -167.5684558>,
    <0.4305626, -167.5684558>,
    <0.4207171, -167.5069791>,
    <0.4166667, -167.5369298>,
    <0.4227475, -167.5684558>,
    <0.4285361, -167.5476517>,
    <0.4328645, -167.5386659>,
    <0.4259259, -167.5208549>,
    <0.4305626, -167.5684558>,
    <0.4444444, -167.5684558>,
    <0.4305249, -167.4968970>,
    <0.4285361, -167.5476517>,
    <0.4383709, -167.5684558>,
    <0.4383474, -167.5371117>,
    <0.4285144, -167.5073705>,
    <0.4282369, -167.6013336>,
    <0.4351852, -167.6211112>,
    <0.4305626, -167.5684558>,
    <0.4166667, -167.5684558>,
    <0.4305332, -167.6473117>,
    <0.4325832, -167.5914725>,
    <0.4227475, -167.5684558>,
    <0.4227291, -167.6029317>,
    <0.4325657, -167.6358644>,
    <0.4386518, -167.6604338>,
    <0.4351852, -167.6211112>,
    <0.4305332, -167.6473117>,
    <0.4444444, -167.7264218>,
    <0.4444444, -167.6468904>,
    <0.4325657, -167.6358644>,
    <0.4383529, -167.6917804>,
    <0.4444444, -167.6917086>,
    <0.4403901, -167.6356026>,
    <0.4386592, -167.6012283>,
    <0.4351852, -167.6211112>,
    <0.4444444, -167.6468904>,
    <0.4444444, -167.5684558>,
    <0.4305626, -167.5684558>,
    <0.4403901, -167.6356026>,
    <0.4444444, -167.6028580>,
    <0.4383709, -167.5684558>,
    <0.4325832, -167.5914725>,
    <0.5613370, -167.6341061>,
    <0.5648148, -167.6737665>,
    <0.5694221, -167.6473117>,
    <0.5555556, -167.5684558>,
    <0.5555556, -167.6468904>,
    <0.5674081, -167.6588757>,
    <0.5616180, -167.6029317>,
    <0.5555556, -167.6028579>,
    <0.5596066, -167.6586490>,
    <0.5613438, -167.6933751>,
    <0.5648148, -167.6737665>,
    <0.5555556, -167.6468904>,
    <0.5555556, -167.7264218>,
    <0.5694493, -167.7264218>,
    <0.5596066, -167.6586490>,
    <0.5555556, -167.6917086>,
    <0.5616353, -167.7264218>,
    <0.5674238, -167.7034090>,
    <0.5717549, -167.6934805>,
    <0.5648148, -167.6737665>,
    <0.5694493, -167.7264218>,
    <0.5833333, -167.7264218>,
    <0.5694221, -167.6473117>,
    <0.5674238, -167.7034090>,
    <0.5772587, -167.7264218>,
    <0.5772418, -167.6917804>,
    <0.5674081, -167.6588757>,
    <0.5671258, -167.6013336>,
    <0.5740741, -167.6211112>,
    <0.5694515, -167.5684558>,
    <0.5555556, -167.5684558>,
    <0.5694221, -167.6473117>,
    <0.5714721, -167.5914725>,
    <0.5616364, -167.5684558>,
    <0.5616180, -167.6029317>,
    <0.5714546, -167.6358644>,
    <0.5775407, -167.6604338>,
    <0.5740741, -167.6211112>,
    <0.5694221, -167.6473117>,
    <0.5833333, -167.7264218>,
    <0.5833333, -167.6468904>,
    <0.5714546, -167.6358644>,
    <0.5772418, -167.6917804>,
    <0.5833333, -167.6917086>,
    <0.5792790, -167.6356026>,
    <0.5775481, -167.6012283>,
    <0.5740741, -167.6211112>,
    <0.5833333, -167.6468904>,
    <0.5833333, -167.5684558>,
    <0.5694515, -167.5684558>,
    <0.5792790, -167.6356026>,
    <0.5833333, -167.6028579>,
    <0.5772598, -167.5684558>,
    <0.5714721, -167.5914725>,
    <0.4224433, -167.2819570>,
    <0.4259259, -167.3161845>,
    <0.4166667, -167.2924560>,
    <0.4166667, -167.2258020>,
    <0.4305139, -167.2933857>,
    <0.4207163, -167.3028339>,
    <0.4166667, -167.2550533>,
    <0.4227166, -167.2553296>,
    <0.4285080, -167.3033535>,
    <0.4328625, -167.3330804>,
    <0.4259259, -167.3161845>,
    <0.4305139, -167.2933857>,
    <0.4444444, -167.3613758>,
    <0.4305655, -167.3613758>,
    <0.4285080, -167.3033535>,
    <0.4383402, -167.3315832>,
    <0.4383724, -167.3613758>,
    <0.4285378, -167.3416247>,
    <0.4224562, -167.3328480>,
    <0.4259259, -167.3161845>,
    <0.4305655, -167.3613758>,
    <0.4166667, -167.3613758>,
    <0.4166667, -167.2924560>,
    <0.4285378, -167.3416247>,
    <0.4227491, -167.3613758>,
    <0.4166667, -167.3313235>,
    <0.4207163, -167.3028339>,
    <0.4282349, -167.3940515>,
    <0.4351852, -167.4137323>,
    <0.4305222, -167.4397221>,
    <0.4166667, -167.3613758>,
    <0.4305655, -167.3613758>,
    <0.4325593, -167.4283682>,
    <0.4227220, -167.3956156>,
    <0.4227491, -167.3613758>,
    <0.4325849, -167.3842624>,
    <0.4386599, -167.3939086>,
    <0.4351852, -167.4137323>,
    <0.4305655, -167.3613758>,
    <0.4444444, -167.3613758>,
    <0.4444444, -167.4391507>,
    <0.4325849, -167.3842624>,
    <0.4383724, -167.3613758>,
    <0.4444444, -167.3955180>,
    <0.4403893, -167.4280187>,
    <0.4386491, -167.4527626>,
    <0.4351852, -167.4137323>,
    <0.4444444, -167.4391507>,
    <0.4444444, -167.5184453>,
    <0.4305222, -167.4397221>,
    <0.4403893, -167.4280187>,
    <0.4444444, -167.4838674>,
    <0.4383457, -167.4839601>,
    <0.4325593, -167.4283682>,
    <0.5613343, -167.4265843>,
    <0.5648148, -167.4660888>,
    <0.5555556, -167.4391507>,
    <0.5555556, -167.3613758>,
    <0.5694111, -167.4397221>,
    <0.5596058, -167.4509341>,
    <0.5555556, -167.3955180>,
    <0.5616109, -167.3956156>,
    <0.5674017, -167.4512490>,
    <0.5717529, -167.4856754>,
    <0.5648148, -167.4660888>,
    <0.5694111, -167.4397221>,
    <0.5833333, -167.5184453>,
    <0.5694523, -167.5184453>,
    <0.5674017, -167.4512490>,
    <0.5772346, -167.4839601>,
    <0.5772602, -167.5184453>,
    <0.5674256, -167.4955641>,
    <0.5613446, -167.4855325>,
    <0.5648148, -167.4660888>,
    <0.5694523, -167.5184453>,
    <0.5555556, -167.5184453>,
    <0.5555556, -167.4391507>,
    <0.5674256, -167.4955641>,
    <0.5616368, -167.5184453>,
    <0.5555556, -167.4838674>,
    <0.5596058, -167.4509341>,
    <0.5671238, -167.3940515>,
    <0.5740741, -167.4137323>,
    <0.5694111, -167.4397221>,
    <0.5555556, -167.3613758>,
    <0.5694544, -167.3613758>,
    <0.5714482, -167.4283682>,
    <0.5616109, -167.3956156>,
    <0.5616380, -167.3613758>,
    <0.5714738, -167.3842624>,
    <0.5775488, -167.3939086>,
    <0.5740741, -167.4137323>,
    <0.5694544, -167.3613758>,
    <0.5833333, -167.3613758>,
    <0.5833333, -167.4391507>,
    <0.5714738, -167.3842624>,
    <0.5772613, -167.3613758>,
    <0.5833333, -167.3955180>,
    <0.5792782, -167.4280187>,
    <0.5775380, -167.4527626>,
    <0.5740741, -167.4137323>,
    <0.5833333, -167.4391507>,
    <0.5833333, -167.5184453>,
    <0.5694111, -167.4397221>,
    <0.5792782, -167.4280187>,
    <0.5833333, -167.4838674>,
    <0.5772346, -167.4839601>,
    <0.5714482, -167.4283682>,
    <0.5740604, -167.0790979>,
    <0.5778804, -167.0842391>,
    <0.5762328, -167.0952600>,
    <0.5669746, -167.0684463>,
    <0.5751539, -167.0684463>,
    <0.5768921, -167.0908497>,
    <0.5714115, -167.0812964>,
    <0.5710643, -167.0684463>,
    <0.5763367, -167.0752973>,
    <0.5799253, -167.0791498>,
    <0.5778804, -167.0842391>,
    <0.5751539, -167.0684463>,
    <0.5833333, -167.0684463>,
    <0.5833333, -167.0954675>,
    <0.5763367, -167.0752973>,
    <0.5792436, -167.0684463>,
    <0.5833333, -167.0824313>,
    <0.5810176, -167.0906990>,
    <0.5801950, -167.0976978>,
    <0.5778804, -167.0842391>,
    <0.5833333, -167.0954675>,
    <0.5833333, -167.1158246>,
    <0.5762328, -167.0952600>,
    <0.5810176, -167.0906990>,
    <0.5833333, -167.1101308>,
    <0.5805252, -167.1076916>,
    <0.5768921, -167.0908497>,
    <0.4224442, -167.3534027>,
    <0.4259259, -167.3845690>,
    <0.4305174, -167.3638575>,
    <0.4166667, -167.3024008>,
    <0.4166667, -167.3627833>,
    <0.4285100, -167.3729124>,
    <0.4227189, -167.3292549>,
    <0.4166667, -167.3288803>,
    <0.4207165, -167.3723121>,
    <0.4224560, -167.3996647>,
    <0.4259259, -167.3845690>,
    <0.4166667, -167.3627833>,
    <0.4166667, -167.4256532>,
    <0.4305646, -167.4256532>,
    <0.4207165, -167.3723121>,
    <0.4166667, -167.3982231>,
    <0.4227486, -167.4256532>,
    <0.4285371, -167.4076960>,
    <0.4328631, -167.3999332>,
    <0.4259259, -167.3845690>,
    <0.4305646, -167.4256532>,
    <0.4444444, -167.4256532>,
    <0.4305174, -167.3638575>,
    <0.4285371, -167.4076960>,
    <0.4383719, -167.4256532>,
    <0.4383424, -167.3985780>,
    <0.4285100, -167.3729124>,
    <0.4282353, -167.4553644>,
    <0.4351852, -167.4732541>,
    <0.4305646, -167.4256532>,
    <0.4166667, -167.4256532>,
    <0.4305249, -167.4968970>,
    <0.4325842, -167.4464590>,
    <0.4227486, -167.4256532>,
    <0.4227238, -167.4567920>,
    <0.4325609, -167.4865678>,
    <0.4386497, -167.5086990>,
    <0.4351852, -167.4732541>,
    <0.4305249, -167.4968970>,
    <0.4444444, -167.5684558>,
    <0.4444444, -167.4961890>,
    <0.4325609, -167.4865678>,
    <0.4383474, -167.5371117>,
    <0.4444444, -167.5369297>,
    <0.4403896, -167.4861453>,
    <0.4386597, -167.4551874>,
    <0.4351852, -167.4732541>,
    <0.4444444, -167.4961890>,
    <0.4444444, -167.4256532>,
    <0.4305646, -167.4256532>,
    <0.4403896, -167.4861453>,
    <0.4444444, -167.4566011>,
    <0.4383719, -167.4256532>,
    <0.4325842, -167.4464590>,
    <0.5613349, -167.4848985>,
    <0.5648148, -167.5208549>,
    <0.5694138, -167.4968970>,
    <0.5555556, -167.4256532>,
    <0.5555556, -167.4961890>,
    <0.5674033, -167.5073705>,
    <0.5616126, -167.4567920>,
    <0.5555556, -167.4566011>,
    <0.5596060, -167.5069791>,
    <0.5613444, -167.5384889>,
    <0.5648148, -167.5208549>,
    <0.5555556, -167.4961890>,
    <0.5555556, -167.5684558>,
    <0.5694515, -167.5684558>,
    <0.5596060, -167.5069791>,
    <0.5555556, -167.5369298>,
    <0.5616364, -167.5684558>,
    <0.5674250, -167.5476517>,
    <0.5717534, -167.5386659>,
    <0.5648148, -167.5208549>,
    <0.5694515, -167.5684558>,
    <0.5833333, -167.5684558>,
    <0.5694138, -167.4968970>,
    <0.5674250, -167.5476517>,
    <0.5772598, -167.5684558>,
    <0.5772363, -167.5371117>,
    <0.5674033, -167.5073705>,
    <0.5671242, -167.4553644>,
    <0.5740741, -167.4732541>,
    <0.5694535, -167.4256532>,
    <0.5555556, -167.4256532>,
    <0.5694138, -167.4968970>,
    <0.5714731, -167.4464590>,
    <0.5616375, -167.4256532>,
    <0.5616126, -167.4567920>,
    <0.5714498, -167.4865678>,
    <0.5775386, -167.5086990>,
    <0.5740741, -167.4732541>,
    <0.5694138, -167.4968970>,
    <0.5833333, -167.5684558>,
    <0.5833333, -167.4961891>,
    <0.5714498, -167.4865678>,
    <0.5772363, -167.5371117>,
    <0.5833333, -167.5369298>,
    <0.5792785, -167.4861453>,
    <0.5775486, -167.4551874>,
    <0.5740741, -167.4732541>,
    <0.5833333, -167.4961891>,
    <0.5833333, -167.4256532>,
    <0.5694535, -167.4256532>,
    <0.5792785, -167.4861453>,
    <0.5833333, -167.4566011>,
    <0.5772608, -167.4256532>,
    <0.5714731, -167.4464590>,
    <0.4223709, -167.1604533>,
    <0.4259259, -167.1891429>,
    <0.4166667, -167.1673444>,
    <0.4166667, -167.1158246>,
    <0.4302242, -167.1695015>,
    <0.4207193, -167.1768853>,
    <0.4166667, -167.1360443>,
    <0.4223953, -167.1385053>,
    <0.4283479, -167.1780754>,
    <0.4327905, -167.2025621>,
    <0.4259259, -167.1891429>,
    <0.4302242, -167.1695015>,
    <0.4444444, -167.2258020>,
    <0.4305673, -167.2258020>,
    <0.4283479, -167.1780754>,
    <0.4381806, -167.2010024>,
    <0.4383733, -167.2258020>,
    <0.4285298, -167.2097095>,
    <0.4224566, -167.2020228>,
    <0.4259259, -167.1891429>,
    <0.4305673, -167.2258020>,
    <0.4166667, -167.2258020>,
    <0.4166667, -167.1673444>,
    <0.4285298, -167.2097095>,
    <0.4227500, -167.2258020>,
    <0.4166667, -167.2001871>,
    <0.4207193, -167.1768853>,
    <0.4282333, -167.2539957>,
    <0.4351852, -167.2709932>,
    <0.4305139, -167.2933857>,
    <0.4166667, -167.2258020>,
    <0.4305673, -167.2258020>,
    <0.4325545, -167.2836036>,
    <0.4227166, -167.2553296>,
    <0.4227500, -167.2258020>,
    <0.4325856, -167.2455535>,
    <0.4386603, -167.2537633>,
    <0.4351852, -167.2709932>,
    <0.4305673, -167.2258020>,
    <0.4444444, -167.2258020>,
    <0.4444444, -167.2924560>,
    <0.4325856, -167.2455535>,
    <0.4383733, -167.2258020>,
    <0.4444444, -167.2550533>,
    <0.4403888, -167.2830552>,
    <0.4386470, -167.3045527>,
    <0.4351852, -167.2709932>,
    <0.4444444, -167.2924560>,
    <0.4444444, -167.3613758>,
    <0.4305139, -167.2933857>,
    <0.4403888, -167.2830552>,
    <0.4444444, -167.3313235>,
    <0.4383402, -167.3315832>,
    <0.4325545, -167.2836036>,
    <0.5613322, -167.2819570>,
    <0.5648148, -167.3161845>,
    <0.5555556, -167.2924560>,
    <0.5555556, -167.2258020>,
    <0.5694028, -167.2933857>,
    <0.5596052, -167.3028339>,
    <0.5555556, -167.2550533>,
    <0.5616055, -167.2553296>,
    <0.5673969, -167.3033535>,
    <0.5717514, -167.3330804>,
    <0.5648148, -167.3161845>,
    <0.5694028, -167.2933857>,
    <0.5833333, -167.3613758>,
    <0.5694544, -167.3613758>,
    <0.5673969, -167.3033535>,
    <0.5772291, -167.3315832>,
    <0.5772613, -167.3613758>,
    <0.5674267, -167.3416247>,
    <0.5613451, -167.3328480>,
    <0.5648148, -167.3161845>,
    <0.5694544, -167.3613758>,
    <0.5555556, -167.3613758>,
    <0.5555556, -167.2924560>,
    <0.5674267, -167.3416247>,
    <0.5616380, -167.3613758>,
    <0.5555556, -167.3313235>,
    <0.5596052, -167.3028339>,
    <0.5671222, -167.2539957>,
    <0.5740741, -167.2709932>,
    <0.5694028, -167.2933857>,
    <0.5555556, -167.2258020>,
    <0.5694562, -167.2258020>,
    <0.5714434, -167.2836036>,
    <0.5616055, -167.2553296>,
    <0.5616389, -167.2258020>,
    <0.5714745, -167.2455535>,
    <0.5775492, -167.2537633>,
    <0.5740741, -167.2709932>,
    <0.5694562, -167.2258020>,
    <0.5833333, -167.2258020>,
    <0.5833333, -167.2924560>,
    <0.5714745, -167.2455535>,
    <0.5772622, -167.2258020>,
    <0.5833333, -167.2550533>,
    <0.5792777, -167.2830552>,
    <0.5775359, -167.3045527>,
    <0.5740741, -167.2709932>,
    <0.5833333, -167.2924560>,
    <0.5833333, -167.3613758>,
    <0.5694028, -167.2933857>,
    <0.5792777, -167.2830552>,
    <0.5833333, -167.3313235>,
    <0.5772291, -167.3315832>,
    <0.5714434, -167.2836036>,
    <0.4230869, -167.1109029>,
    <0.4208266, -167.1123151>,
    <0.4195253, -167.1231073>,
    <0.4291465, -167.1040945>,
    <0.4228491, -167.1040945>,
    <0.4200262, -167.1189534>,
    <0.4230187, -167.1162039>,
    <0.4259758, -167.1040945>,
    <0.4221760, -167.1068303>,
    <0.4192523, -167.1090581>,
    <0.4208266, -167.1123151>,
    <0.4228491, -167.1040945>,
    <0.4166667, -167.1040945>,
    <0.4166667, -167.1157282>,
    <0.4221760, -167.1068303>,
    <0.4197508, -167.1040945>,
    <0.4166667, -167.1077212>,
    <0.4187668, -167.1140051>,
    <0.4184213, -167.1199768>,
    <0.4208266, -167.1123151>,
    <0.4166667, -167.1157282>,
    <0.4166667, -167.1287564>,
    <0.4195253, -167.1231073>,
    <0.4187668, -167.1140051>,
    <0.4166667, -167.1243298>,
    <0.4177047, -167.1267052>,
    <0.4200262, -167.1189534>,
    <0.4478180, -167.9294911>,
    <0.4537037, -168.0047729>,
    <0.4444444, -167.9292172>,
    <0.4444444, -167.8774261>,
    <0.4486794, -167.9065484>,
    <0.4486695, -167.9636933>,
    <0.4444444, -167.8990220>,
    <0.4461748, -167.8893253>,
    <0.4510068, -167.9520487>,
    <0.4575320, -168.0120535>,
    <0.4537037, -168.0047729>,
    <0.4486794, -167.9065484>,
    <0.4722222, -168.0684463>,
    <0.4555227, -168.0684463>,
    <0.4510068, -167.9520487>,
    <0.4532445, -167.9379417>,
    <0.4621761, -168.0684463>,
    <0.4548222, -168.0439257>,
    <0.4495288, -168.0177207>,
    <0.4537037, -168.0047729>,
    <0.4555227, -168.0684463>,
    <0.4444444, -168.0684463>,
    <0.4444444, -167.9292172>,
    <0.4548222, -168.0439257>,
    <0.4497403, -168.0684463>,
    <0.4444444, -167.9756913>,
    <0.4486695, -167.9636933>,
    <0.4224425, -167.2436308>,
    <0.4259259, -167.2690732>,
    <0.4305108, -167.2522483>,
    <0.4166667, -167.2024179>,
    <0.4166667, -167.2507837>,
    <0.4285063, -167.2596042>,
    <0.4227146, -167.2241867>,
    <0.4166667, -167.2235884>,
    <0.4207161, -167.2587824>,
    <0.4224563, -167.2811646>,
    <0.4259259, -167.2690732>,
    <0.4166667, -167.2507837>,
    <0.4166667, -167.3024008>,
    <0.4305661, -167.3024008>,
    <0.4207161, -167.2587824>,
    <0.4166667, -167.2798504>,
    <0.4227494, -167.3024008>,
    <0.4285377, -167.2878319>,
    <0.4328618, -167.2815307>,
    <0.4259259, -167.2690732>,
    <0.4305661, -167.3024008>,
    <0.4444444, -167.3024008>,
    <0.4305108, -167.2522483>,
    <0.4285377, -167.2878319>,
    <0.4383727, -167.3024008>,
    <0.4383380, -167.2804214>,
    <0.4285063, -167.2596042>,
    <0.4282338, -167.3280360>,
    <0.4351852, -167.3434849>,
    <0.4305661, -167.3024008>,
    <0.4166667, -167.3024008>,
    <0.4305174, -167.3638575>,
    <0.4325848, -167.3203558>,
    <0.4227494, -167.3024008>,
    <0.4227189, -167.3292549>,
    <0.4325566, -167.3549573>,
    <0.4386479, -167.3739447>,
    <0.4351852, -167.3434849>,
    <0.4305174, -167.3638575>,
    <0.4444444, -167.4256532>,
    <0.4444444, -167.3627833>,
    <0.4325566, -167.3549573>,
    <0.4383424, -167.3985780>,
    <0.4444444, -167.3982231>,
    <0.4403891, -167.3543311>,
    <0.4386601, -167.3277674>,
    <0.4351852, -167.3434849>,
    <0.4444444, -167.3627833>,
    <0.4444444, -167.3024008>,
    <0.4305661, -167.3024008>,
    <0.4403891, -167.3543311>,
    <0.4444444, -167.3288803>,
    <0.4383727, -167.3024008>,
    <0.4325848, -167.3203558>,
    <0.5613330, -167.3534027>,
    <0.5648148, -167.3845690>,
    <0.5694063, -167.3638575>,
    <0.5555556, -167.3024008>,
    <0.5555556, -167.3627833>,
    <0.5673989, -167.3729124>,
    <0.5616077, -167.3292549>,
    <0.5555556, -167.3288803>,
    <0.5596054, -167.3723121>,
    <0.5613448, -167.3996647>,
    <0.5648148, -167.3845690>,
    <0.5555556, -167.3627833>,
    <0.5555556, -167.4256532>,
    <0.5694535, -167.4256532>,
    <0.5596054, -167.3723121>,
    <0.5555556, -167.3982231>,
    <0.5616375, -167.4256532>,
    <0.5674260, -167.4076960>,
    <0.5717520, -167.3999332>,
    <0.5648148, -167.3845690>,
    <0.5694535, -167.4256532>,
    <0.5833333, -167.4256532>,
    <0.5694063, -167.3638575>,
    <0.5674260, -167.4076960>,
    <0.5772608, -167.4256532>,
    <0.5772313, -167.3985780>,
    <0.5673989, -167.3729124>,
    <0.5671227, -167.3280360>,
    <0.5740741, -167.3434849>,
    <0.5694550, -167.3024008>,
    <0.5555556, -167.3024008>,
    <0.5694063, -167.3638575>,
    <0.5714737, -167.3203558>,
    <0.5616383, -167.3024008>,
    <0.5616077, -167.3292549>,
    <0.5714455, -167.3549573>,
    <0.5775368, -167.3739447>,
    <0.5740741, -167.3434849>,
    <0.5694063, -167.3638575>,
    <0.5833333, -167.4256532>,
    <0.5833333, -167.3627833>,
    <0.5714455, -167.3549573>,
    <0.5772313, -167.3985780>,
    <0.5833333, -167.3982231>,
    <0.5792780, -167.3543311>,
    <0.5775489, -167.3277674>,
    <0.5740741, -167.3434849>,
    <0.5833333, -167.3627833>,
    <0.5833333, -167.3024008>,
    <0.5694550, -167.3024008>,
    <0.5792780, -167.3543311>,
    <0.5833333, -167.3288803>,
    <0.5772616, -167.3024008>,
    <0.5714737, -167.3203558>,
    <0.4502152, -167.7681958>,
    <0.4537037, -167.8156918>,
    <0.4444444, -167.7804778>,
    <0.4444444, -167.6922232>,
    <0.4582682, -167.7843904>,
    <0.4484909, -167.7958668>,
    <0.4444444, -167.7304140>,
    <0.4504817, -167.7324754>,
    <0.4562730, -167.7980726>,
    <0.4606354, -167.8387336>,
    <0.4537037, -167.8156918>,
    <0.4582682, -167.7843904>,
    <0.4722222, -167.8774261>,
    <0.4583474, -167.8774261>,
    <0.4562730, -167.7980726>,
    <0.4661023, -167.8366226>,
    <0.4662040, -167.8774261>,
    <0.4563540, -167.8509261>,
    <0.4502350, -167.8377554>,
    <0.4537037, -167.8156918>,
    <0.4583474, -167.8774261>,
    <0.4444444, -167.8774261>,
    <0.4444444, -167.7804778>,
    <0.4563540, -167.8509261>,
    <0.4503193, -167.8774261>,
    <0.4444444, -167.8359460>,
    <0.4484909, -167.7958668>,
    <0.4536085, -167.9006250>,
    <0.4629630, -167.9410995>,
    <0.4486794, -167.9065484>,
    <0.4444444, -167.8774261>,
    <0.4583474, -167.8774261>,
    <0.4539745, -167.9193569>,
    <0.4461748, -167.8893253>,
    <0.4503193, -167.8774261>,
    <0.4605235, -167.9074464>,
    <0.4664387, -167.9180474>,
    <0.4629630, -167.9410995>,
    <0.4583474, -167.8774261>,
    <0.4722222, -167.8774261>,
    <0.4722222, -167.9762380>,
    <0.4605235, -167.9074464>,
    <0.4662040, -167.8774261>,
    <0.4722222, -167.9213599>,
    <0.4683956, -167.9617159>,
    <0.4640217, -167.9730830>,
    <0.4629630, -167.9410995>,
    <0.4722222, -167.9762380>,
    <0.4722222, -168.0684463>,
    <0.4486794, -167.9065484>,
    <0.4683956, -167.9617159>,
    <0.4722222, -168.0234811>,
    <0.4532445, -167.9379417>,
    <0.4539745, -167.9193569>,
    <0.5326817, -167.9399685>,
    <0.5370370, -168.0047729>,
    <0.5277778, -167.9290301>,
    <0.5277778, -167.8774261>,
    <0.5381343, -167.9486450>,
    <0.5319818, -167.9634198>,
    <0.5277778, -167.8992980>,
    <0.5322110, -167.9079119>,
    <0.5376338, -167.9742490>,
    <0.5430984, -168.0225776>,
    <0.5370370, -168.0047729>,
    <0.5381343, -167.9486450>,
    <0.5555556, -168.0684463>,
    <0.5416667, -168.0684463>,
    <0.5376338, -167.9742490>,
    <0.5456994, -168.0006681>,
    <0.5486111, -168.0684463>,
    <0.5397868, -168.0425914>,
    <0.5335648, -168.0176739>,
    <0.5370370, -168.0047729>,
    <0.5416667, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5277778, -167.9290301>,
    <0.5397868, -168.0425914>,
    <0.5347222, -168.0684463>,
    <0.5277778, -167.9752795>,
    <0.5319818, -167.9634198>,
    <0.5384727, -167.9111491>,
    <0.5462963, -167.9410995>,
    <0.5381343, -167.9486450>,
    <0.5277778, -167.8774261>,
    <0.5416826, -167.8774261>,
    <0.5413937, -167.9456317>,
    <0.5322110, -167.9079119>,
    <0.5337446, -167.8774261>,
    <0.5438312, -167.9070786>,
    <0.5497725, -167.9090448>,
    <0.5462963, -167.9410995>,
    <0.5416826, -167.8774261>,
    <0.5555556, -167.8774261>,
    <0.5555556, -167.9402278>,
    <0.5438312, -167.9070786>,
    <0.5495750, -167.8774261>,
    <0.5555556, -167.9042294>,
    <0.5516682, -167.9405938>,
    <0.5488854, -167.9746046>,
    <0.5462963, -167.9410995>,
    <0.5555556, -167.9402278>,
    <0.5555556, -168.0684463>,
    <0.5381343, -167.9486450>,
    <0.5516682, -167.9405938>,
    <0.5555556, -167.9884946>,
    <0.5456994, -168.0006681>,
    <0.5413937, -167.9456317>,
    <0.5755399, -167.1109046>,
    <0.5782340, -167.1123151>,
    <0.5760566, -167.1040945>,
    <0.5680354, -167.1040945>,
    <0.5798335, -167.1231143>,
    <0.5768370, -167.1070407>,
    <0.5722019, -167.1040945>,
    <0.5757078, -167.1164632>,
    <0.5791966, -167.1188144>,
    <0.5811836, -167.1207203>,
    <0.5782340, -167.1123151>,
    <0.5798335, -167.1231143>,
    <0.5833333, -167.1287564>,
    <0.5833333, -167.1186955>,
    <0.5791966, -167.1188144>,
    <0.5820577, -167.1267000>,
    <0.5833333, -167.1268389>,
    <0.5807417, -167.1154528>,
    <0.5802393, -167.1097999>,
    <0.5782340, -167.1123151>,
    <0.5833333, -167.1186955>,
    <0.5833333, -167.1040945>,
    <0.5760566, -167.1040945>,
    <0.5807417, -167.1154528>,
    <0.5833333, -167.1075966>,
    <0.5797377, -167.1040945>,
    <0.5768370, -167.1070407>,
    <0.4502254, -167.5906989>,
    <0.4537037, -167.6342972>,
    <0.4444444, -167.6048705>,
    <0.4444444, -167.5184453>,
    <0.4583091, -167.6051824>,
    <0.4484953, -167.6177446>,
    <0.4444444, -167.5563664>,
    <0.4505056, -167.5563642>,
    <0.4562959, -167.6179095>,
    <0.4606434, -167.6559815>,
    <0.4537037, -167.6342972>,
    <0.4583091, -167.6051824>,
    <0.4722222, -167.6922232>,
    <0.4583387, -167.6922232>,
    <0.4562959, -167.6179095>,
    <0.4661295, -167.6541068>,
    <0.4661479, -167.6922232>,
    <0.4563131, -167.6669079>,
    <0.4502328, -167.6559035>,
    <0.4537037, -167.6342972>,
    <0.4583387, -167.6922232>,
    <0.4444444, -167.6922232>,
    <0.4444444, -167.6048705>,
    <0.4563131, -167.6669079>,
    <0.4505244, -167.6922232>,
    <0.4444444, -167.6541051>,
    <0.4484953, -167.6177446>,
    <0.4560036, -167.7306986>,
    <0.4629630, -167.7539575>,
    <0.4582682, -167.7843904>,
    <0.4444444, -167.6922232>,
    <0.4583387, -167.6922232>,
    <0.4603195, -167.7710930>,
    <0.4504817, -167.7324754>,
    <0.4505244, -167.6922232>,
    <0.4603580, -167.7191812>,
    <0.4664365, -167.7297172>,
    <0.4629630, -167.7539575>,
    <0.4583387, -167.6922232>,
    <0.4722222, -167.6922232>,
    <0.4722222, -167.7804649>,
    <0.4603580, -167.7191812>,
    <0.4661479, -167.6922232>,
    <0.4722222, -167.7304074>,
    <0.4681681, -167.7688588>,
    <0.4664189, -167.7990597>,
    <0.4629630, -167.7539575>,
    <0.4722222, -167.7804649>,
    <0.4722222, -167.8774261>,
    <0.4582682, -167.7843904>,
    <0.4681681, -167.7688588>,
    <0.4722222, -167.8348693>,
    <0.4661023, -167.8366226>,
    <0.4603195, -167.7710930>,
    <0.5335477, -167.7681824>,
    <0.5370370, -167.8156918>,
    <0.5277778, -167.7804462>,
    <0.5277778, -167.6922232>,
    <0.5415982, -167.7843683>,
    <0.5318238, -167.7958475>,
    <0.5277778, -167.7303977>,
    <0.5338132, -167.7324631>,
    <0.5396042, -167.7980624>,
    <0.5439683, -167.8387280>,
    <0.5370370, -167.8156918>,
    <0.5415982, -167.7843683>,
    <0.5555556, -167.8774261>,
    <0.5416826, -167.8774261>,
    <0.5396042, -167.7980624>,
    <0.5494924, -167.8370012>,
    <0.5495750, -167.8774261>,
    <0.5396705, -167.8506878>,
    <0.5335688, -167.8377475>,
    <0.5370370, -167.8156918>,
    <0.5416826, -167.8774261>,
    <0.5277778, -167.8774261>,
    <0.5277778, -167.7804462>,
    <0.5396705, -167.8506878>,
    <0.5337446, -167.8774261>,
    <0.5277778, -167.8353065>,
    <0.5318238, -167.7958475>,
    <0.5393361, -167.7306931>,
    <0.5462963, -167.7539575>,
    <0.5415982, -167.7843683>,
    <0.5277778, -167.6922232>,
    <0.5416721, -167.6922232>,
    <0.5436510, -167.7710807>,
    <0.5338132, -167.7324631>,
    <0.5338578, -167.6922232>,
    <0.5436913, -167.7191800>,
    <0.5497699, -167.7297112>,
    <0.5462963, -167.7539575>,
    <0.5416721, -167.6922232>,
    <0.5555556, -167.6922232>,
    <0.5555556, -167.7804408>,
    <0.5436913, -167.7191800>,
    <0.5494812, -167.6922232>,
    <0.5555556, -167.7303949>,
    <0.5515014, -167.7688452>,
    <0.5497514, -167.7990482>,
    <0.5462963, -167.7539575>,
    <0.5555556, -167.7804408>,
    <0.5555556, -167.8774261>,
    <0.5415982, -167.7843683>,
    <0.5515014, -167.7688452>,
    <0.5555556, -167.8351215>,
    <0.5494924, -167.8370012>,
    <0.5436510, -167.7710807>,
    <0.4237823, -167.0910514>,
    <0.4259259, -167.1000319>,
    <0.4166667, -167.0945275>,
    <0.4166667, -167.0684463>,
    <0.4358699, -167.1011998>,
    <0.4206645, -167.0969041>,
    <0.4166667, -167.0816213>,
    <0.4282805, -167.0882552>,
    <0.4308337, -167.1006083>,
    <0.4340559, -167.1082202>,
    <0.4259259, -167.1000319>,
    <0.4358699, -167.1011998>,
    <0.4444444, -167.1158246>,
    <0.4299833, -167.1158246>,
    <0.4308337, -167.1006083>,
    <0.4410031, -167.1099550>,
    <0.4381946, -167.1158246>,
    <0.4280912, -167.1084599>,
    <0.4223106, -167.1065522>,
    <0.4259259, -167.1000319>,
    <0.4299833, -167.1158246>,
    <0.4166667, -167.1158246>,
    <0.4166667, -167.0945275>,
    <0.4280912, -167.1084599>,
    <0.4221589, -167.1158246>,
    <0.4166667, -167.1098561>,
    <0.4206645, -167.0969041>,
    <0.4261613, -167.0805829>,
    <0.4297323, -167.0842391>,
    <0.4358699, -167.1011998>,
    <0.4166667, -167.0684463>,
    <0.4223762, -167.0684463>,
    <0.4337444, -167.0953261>,
    <0.4282805, -167.0882552>,
    <0.4195214, -167.0684463>,
    <0.4253298, -167.0747876>,
    <0.4293937, -167.0791246>,
    <0.4297323, -167.0842391>,
    <0.4223762, -167.0684463>,
    <0.4280857, -167.0684463>,
    <0.4373807, -167.0953667>,
    <0.4253298, -167.0747876>,
    <0.4252309, -167.0684463>,
    <0.4325550, -167.0813903>,
    <0.4335742, -167.0898287>,
    <0.4368568, -167.0991575>,
    <0.4297323, -167.0842391>,
    <0.4373807, -167.0953667>,
    <0.4444444, -167.1158246>,
    <0.4358699, -167.1011998>,
    <0.4335742, -167.0898287>,
    <0.4416571, -167.1077519>,
    <0.4410031, -167.1099550>,
    <0.4337444, -167.0953261>,
    <0.4280149, -167.1384086>,
    <0.4351852, -167.1524837>,
    <0.4302242, -167.1695015>,
    <0.4166667, -167.1158246>,
    <0.4299833, -167.1158246>,
    <0.4323854, -167.1620880>,
    <0.4223953, -167.1385053>,
    <0.4221589, -167.1158246>,
    <0.4322370, -167.1317071>,
    <0.4385144, -167.1377944>,
    <0.4351852, -167.1524837>,
    <0.4299833, -167.1158246>,
    <0.4444444, -167.1158246>,
    <0.4444444, -167.1670444>,
    <0.4322370, -167.1317071>,
    <0.4381946, -167.1158246>,
    <0.4444444, -167.1357720>,
    <0.4403832, -167.1606580>,
    <0.4385746, -167.1787079>,
    <0.4351852, -167.1524837>,
    <0.4444444, -167.1670444>,
    <0.4444444, -167.2258020>,
    <0.4302242, -167.1695015>,
    <0.4403832, -167.1606580>,
    <0.4444444, -167.2000293>,
    <0.4381806, -167.2010024>,
    <0.4323854, -167.1620880>,
    <0.5612568, -167.1603502>,
    <0.5648148, -167.1891429>,
    <0.5555556, -167.1669784>,
    <0.5555556, -167.1158246>,
    <0.5691013, -167.1694547>,
    <0.5596084, -167.1766799>,
    <0.5555556, -167.1357215>,
    <0.5612734, -167.1384628>,
    <0.5672302, -167.1780486>,
    <0.5716764, -167.2025504>,
    <0.5648148, -167.1891429>,
    <0.5691013, -167.1694547>,
    <0.5833333, -167.2258020>,
    <0.5694562, -167.2258020>,
    <0.5672302, -167.1780486>,
    <0.5770630, -167.2009763>,
    <0.5772622, -167.2258020>,
    <0.5674183, -167.2097063>,
    <0.5613455, -167.2019313>,
    <0.5648148, -167.1891429>,
    <0.5694562, -167.2258020>,
    <0.5555556, -167.2258020>,
    <0.5555556, -167.1669784>,
    <0.5674183, -167.2097063>,
    <0.5616389, -167.2258020>,
    <0.5555556, -167.1999914>,
    <0.5596084, -167.1766799>,
    <0.5668971, -167.1383969>,
    <0.5740741, -167.1524837>,
    <0.5691013, -167.1694547>,
    <0.5555556, -167.1158246>,
    <0.5688576, -167.1158246>,
    <0.5712677, -167.1620614>,
    <0.5612734, -167.1384628>,
    <0.5610402, -167.1158246>,
    <0.5711174, -167.1317054>,
    <0.5773996, -167.1378006>,
    <0.5740741, -167.1524837>,
    <0.5688576, -167.1158246>,
    <0.5833333, -167.1158246>,
    <0.5833333, -167.1670695>,
    <0.5711174, -167.1317054>,
    <0.5770741, -167.1158246>,
    <0.5833333, -167.1357703>,
    <0.5792718, -167.1606715>,
    <0.5774605, -167.1787025>,
    <0.5740741, -167.1524837>,
    <0.5833333, -167.1670695>,
    <0.5833333, -167.2258020>,
    <0.5691013, -167.1694547>,
    <0.5792718, -167.1606715>,
    <0.5833333, -167.2000468>,
    <0.5770630, -167.2009763>,
    <0.5712677, -167.1620614>,
    <0.4478143, -167.9407737>,
    <0.4537037, -168.0105648>,
    <0.4486646, -167.9211829>,
    <0.4444444, -167.8948019>,
    <0.4444444, -167.9365451>,
    <0.4509990, -167.9625893>,
    <0.4461686, -167.9055800>,
    <0.4444444, -167.9122356>,
    <0.4486733, -167.9703509>,
    <0.4495288, -168.0210006>,
    <0.4537037, -168.0105648>,
    <0.4444444, -167.9365451>,
    <0.4444444, -168.0684463>,
    <0.4555227, -168.0684463>,
    <0.4486733, -167.9703509>,
    <0.4444444, -167.9784771>,
    <0.4497403, -168.0684463>,
    <0.4548240, -168.0462129>,
    <0.4575283, -168.0171601>,
    <0.4537037, -168.0105648>,
    <0.4555227, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4486646, -167.9211829>,
    <0.4548240, -168.0462129>,
    <0.4621760, -168.0684463>,
    <0.4531995, -167.9495314>,
    <0.4509990, -167.9625893>,
    <0.4502161, -167.7954141>,
    <0.4537037, -167.8386752>,
    <0.4582717, -167.8102383>,
    <0.4444444, -167.7264218>,
    <0.4444444, -167.8063209>,
    <0.4562747, -167.8226702>,
    <0.4504838, -167.7630303>,
    <0.4444444, -167.7609514>,
    <0.4484911, -167.8204609>,
    <0.4502349, -167.8586500>,
    <0.4537037, -167.8386752>,
    <0.4444444, -167.8063209>,
    <0.4444444, -167.8948019>,
    <0.4583471, -167.8948019>,
    <0.4484911, -167.8204609>,
    <0.4444444, -167.8572675>,
    <0.4503193, -167.8948019>,
    <0.4563557, -167.8707304>,
    <0.4606362, -167.8596293>,
    <0.4537037, -167.8386752>,
    <0.4583471, -167.8948019>,
    <0.4722222, -167.8948019>,
    <0.4582717, -167.8102383>,
    <0.4563557, -167.8707304>,
    <0.4663001, -167.8948019>,
    <0.4662031, -167.8583157>,
    <0.4562747, -167.8226702>,
    <0.4536048, -167.9158675>,
    <0.4629630, -167.9526834>,
    <0.4583471, -167.8948019>,
    <0.4444444, -167.8948019>,
    <0.4486646, -167.9211829>,
    <0.4605250, -167.9221116>,
    <0.4503193, -167.8948019>,
    <0.4461686, -167.9055800>,
    <0.4539479, -167.9328225>,
    <0.4640180, -167.9820686>,
    <0.4629630, -167.9526834>,
    <0.4486646, -167.9211829>,
    <0.4722222, -168.0684463>,
    <0.4722222, -167.9859616>,
    <0.4539479, -167.9328225>,
    <0.4531995, -167.9495314>,
    <0.4722222, -168.0339467>,
    <0.4685039, -167.9725977>,
    <0.4664386, -167.9320622>,
    <0.4629630, -167.9526834>,
    <0.4722222, -167.9859616>,
    <0.4722222, -167.8948019>,
    <0.4583471, -167.8948019>,
    <0.4685039, -167.9725977>,
    <0.4722222, -167.9349131>,
    <0.4663001, -167.8948019>,
    <0.4605250, -167.9221116>,
    <0.5326825, -167.9541886>,
    <0.5370370, -168.0105648>,
    <0.5381375, -167.9595627>,
    <0.5277778, -167.8948019>,
    <0.5277778, -167.9518248>,
    <0.5376356, -167.9828222>,
    <0.5322155, -167.9225430>,
    <0.5277778, -167.9192810>,
    <0.5319739, -167.9784445>,
    <0.5335648, -168.0248205>,
    <0.5370370, -168.0105648>,
    <0.5277778, -167.9518248>,
    <0.5277778, -168.0684463>,
    <0.5416667, -168.0684463>,
    <0.5319739, -167.9784445>,
    <0.5277778, -167.9954031>,
    <0.5347222, -168.0684463>,
    <0.5397817, -168.0448796>,
    <0.5430992, -168.0267550>,
    <0.5370370, -168.0105648>,
    <0.5416667, -168.0684463>,
    <0.5555556, -168.0684463>,
    <0.5381375, -167.9595627>,
    <0.5397817, -168.0448796>,
    <0.5486111, -168.0684463>,
    <0.5457015, -168.0068465>,
    <0.5376356, -167.9828222>,
    <0.5384735, -167.9254625>,
    <0.5462963, -167.9526834>,
    <0.5416823, -167.8948019>,
    <0.5277778, -167.8948019>,
    <0.5381375, -167.9595627>,
    <0.5438332, -167.9217842>,
    <0.5337442, -167.8948019>,
    <0.5322155, -167.9225430>,
    <0.5413935, -167.9568173>,
    <0.5488862, -167.9831184>,
    <0.5462963, -167.9526834>,
    <0.5381375, -167.9595627>,
    <0.5555556, -168.0684463>,
    <0.5555556, -167.9517813>,
    <0.5413935, -167.9568173>,
    <0.5457015, -168.0068465>,
    <0.5555556, -167.9954063>,
    <0.5516687, -167.9521600>,
    <0.5497724, -167.9235171>,
    <0.5462963, -167.9526834>,
    <0.5555556, -167.9517813>,
    <0.5555556, -167.8948019>,
    <0.5416823, -167.8948019>,
    <0.5516687, -167.9521600>,
    <0.5555556, -167.9192646>,
    <0.5495748, -167.8948019>,
    <0.5438332, -167.9217842>,
    <0.4225134, -167.1583892>,
    <0.4259259, -167.1778641>,
    <0.4307945, -167.1662209>,
    <0.4166667, -167.1287564>,
    <0.4166667, -167.1607154>,
    <0.4286732, -167.1712941>,
    <0.4229238, -167.1453493>,
    <0.4166667, -167.1413913>,
    <0.4207234, -167.1682287>,
    <0.4224567, -167.1858538>,
    <0.4259259, -167.1778641>,
    <0.4166667, -167.1607154>,
    <0.4166667, -167.2024179>,
    <0.4305674, -167.2024179>,
    <0.4207234, -167.1682287>,
    <0.4166667, -167.1838308>,
    <0.4227501, -167.2024179>,
    <0.4285463, -167.1917260>,
    <0.4329331, -167.1872302>,
    <0.4259259, -167.1778641>,
    <0.4305674, -167.2024179>,
    <0.4444444, -167.2024179>,
    <0.4307945, -167.1662209>,
    <0.4285463, -167.1917260>,
    <0.4383733, -167.2024179>,
    <0.4385041, -167.1866652>,
    <0.4286732, -167.1712941>,
    <0.4282325, -167.2232074>,
    <0.4351852, -167.2357456>,
    <0.4305674, -167.2024179>,
    <0.4166667, -167.2024179>,
    <0.4305108, -167.2522483>,
    <0.4325851, -167.2169804>,
    <0.4227501, -167.2024179>,
    <0.4227146, -167.2241867>,
    <0.4325529, -167.2450388>,
    <0.4386462, -167.2602946>,
    <0.4351852, -167.2357456>,
    <0.4305108, -167.2522483>,
    <0.4444444, -167.3024008>,
    <0.4444444, -167.2507837>,
    <0.4325529, -167.2450388>,
    <0.4383380, -167.2804214>,
    <0.4444444, -167.2798504>,
    <0.4403888, -167.2441968>,
    <0.4386604, -167.2228413>,
    <0.4351852, -167.2357456>,
    <0.4444444, -167.2507837>,
    <0.4444444, -167.2024179>,
    <0.4305674, -167.2024179>,
    <0.4403888, -167.2441968>,
    <0.4444444, -167.2235884>,
    <0.4383733, -167.2024179>,
    <0.4325851, -167.2169804>,
    <0.5613314, -167.2436308>,
    <0.5648148, -167.2690732>,
    <0.5693997, -167.2522483>,
    <0.5555556, -167.2024179>,
    <0.5555556, -167.2507837>,
    <0.5673952, -167.2596042>,
    <0.5616035, -167.2241867>,
    <0.5555556, -167.2235884>,
    <0.5596050, -167.2587824>,
    <0.5613452, -167.2811646>,
    <0.5648148, -167.2690732>,
    <0.5555556, -167.2507837>,
    <0.5555556, -167.3024008>,
    <0.5694550, -167.3024008>,
    <0.5596050, -167.2587824>,
    <0.5555556, -167.2798504>,
    <0.5616383, -167.3024008>,
    <0.5674266, -167.2878319>,
    <0.5717507, -167.2815307>,
    <0.5648148, -167.2690732>,
    <0.5694550, -167.3024008>,
    <0.5833333, -167.3024008>,
    <0.5693997, -167.2522483>,
    <0.5674266, -167.2878319>,
    <0.5772616, -167.3024008>,
    <0.5772269, -167.2804214>,
    <0.5673952, -167.2596042>,
    <0.5671214, -167.2232074>,
    <0.5740741, -167.2357456>,
    <0.5694563, -167.2024179>,
    <0.5555556, -167.2024179>,
    <0.5693997, -167.2522483>,
    <0.5714740, -167.2169804>,
    <0.5616390, -167.2024179>,
    <0.5616035, -167.2241867>,
    <0.5714418, -167.2450388>,
    <0.5775351, -167.2602946>,
    <0.5740741, -167.2357456>,
    <0.5693997, -167.2522483>,
    <0.5833333, -167.3024008>,
    <0.5833333, -167.2507837>,
    <0.5714418, -167.2450388>,
    <0.5772269, -167.2804214>,
    <0.5833333, -167.2798504>,
    <0.5792776, -167.2441968>,
    <0.5775493, -167.2228413>,
    <0.5740741, -167.2357456>,
    <0.5833333, -167.2507837>,
    <0.5833333, -167.2024179>,
    <0.5694563, -167.2024179>,
    <0.5792776, -167.2441968>,
    <0.5833333, -167.2235884>,
    <0.5772622, -167.2024179>,
    <0.5714740, -167.2169804>,
    <0.4777696, -167.9561953>,
    <0.4814815, -168.0047729>,
    <0.4722222, -167.9762380>,
    <0.4722222, -167.8774261>,
    <0.4851526, -167.9663445>,
    <0.4758944, -167.9875548>,
    <0.4722222, -167.9213599>,
    <0.4777046, -167.9151272>,
    <0.4833029, -167.9857069>,
    <0.4896108, -168.0270025>,
    <0.4814815, -168.0047729>,
    <0.4851526, -167.9663445>,
    <0.5000000, -168.0684463>,
    <0.4918090, -168.0684463>,
    <0.4833029, -167.9857069>,
    <0.4933782, -168.0229102>,
    <0.4967695, -168.0684463>,
    <0.4879087, -168.0443998>,
    <0.4794337, -168.0294759>,
    <0.4814815, -168.0047729>,
    <0.4918090, -168.0684463>,
    <0.4722222, -168.0684463>,
    <0.4722222, -167.9762380>,
    <0.4879087, -168.0443998>,
    <0.4838095, -168.0684463>,
    <0.4722222, -168.0234811>,
    <0.4758944, -167.9875548>,
    <0.4502231, -167.4265843>,
    <0.4537037, -167.4660888>,
    <0.4444444, -167.4391507>,
    <0.4444444, -167.3613758>,
    <0.4583000, -167.4397221>,
    <0.4484947, -167.4509341>,
    <0.4444444, -167.3955180>,
    <0.4504998, -167.3956156>,
    <0.4562906, -167.4512490>,
    <0.4606418, -167.4856754>,
    <0.4537037, -167.4660888>,
    <0.4583000, -167.4397221>,
    <0.4722222, -167.5184453>,
    <0.4583412, -167.5184453>,
    <0.4562906, -167.4512490>,
    <0.4661235, -167.4839601>,
    <0.4661491, -167.5184453>,
    <0.4563145, -167.4955641>,
    <0.4502334, -167.4855325>,
    <0.4537037, -167.4660888>,
    <0.4583412, -167.5184453>,
    <0.4444444, -167.5184453>,
    <0.4444444, -167.4391507>,
    <0.4563145, -167.4955641>,
    <0.4505257, -167.5184453>,
    <0.4444444, -167.4838674>,
    <0.4484947, -167.4509341>,
    <0.4560144, -167.5546111>,
    <0.4629630, -167.5763713>,
    <0.4583091, -167.6051824>,
    <0.4444444, -167.5184453>,
    <0.4583412, -167.5184453>,
    <0.4603423, -167.5925951>,
    <0.4505056, -167.5563642>,
    <0.4505257, -167.5184453>,
    <0.4603616, -167.5437683>,
    <0.4664371, -167.5545331>,
    <0.4629630, -167.5763713>,
    <0.4583412, -167.5184453>,
    <0.4722222, -167.5184453>,
    <0.4722222, -167.6048705>,
    <0.4603616, -167.5437683>,
    <0.4661491, -167.5184453>,
    <0.4722222, -167.5563664>,
    <0.4681677, -167.5923911>,
    <0.4664291, -167.6196618>,
    <0.4629630, -167.5763713>,
    <0.4722222, -167.6048705>,
    <0.4722222, -167.6922232>,
    <0.4583091, -167.6051824>,
    <0.4681677, -167.5923911>,
    <0.4722222, -167.6541051>,
    <0.4661295, -167.6541068>,
    <0.4603423, -167.5925951>,
    <0.5335587, -167.5906989>,
    <0.5370370, -167.6342972>,
    <0.5277778, -167.6048705>,
    <0.5277778, -167.5184453>,
    <0.5416424, -167.6051824>,
    <0.5318287, -167.6177446>,
    <0.5277778, -167.5563664>,
    <0.5338390, -167.5563642>,
    <0.5396292, -167.6179095>,
    <0.5439768, -167.6559815>,
    <0.5370370, -167.6342972>,
    <0.5416424, -167.6051824>,
    <0.5555556, -167.6922232>,
    <0.5416721, -167.6922232>,
    <0.5396292, -167.6179095>,
    <0.5494628, -167.6541068>,
    <0.5494812, -167.6922232>,
    <0.5396464, -167.6669079>,
    <0.5335662, -167.6559035>,
    <0.5370370, -167.6342972>,
    <0.5416721, -167.6922232>,
    <0.5277778, -167.6922232>,
    <0.5277778, -167.6048705>,
    <0.5396464, -167.6669079>,
    <0.5338578, -167.6922232>,
    <0.5277778, -167.6541051>,
    <0.5318287, -167.6177446>,
    <0.5393477, -167.5546111>,
    <0.5462963, -167.5763713>,
    <0.5416424, -167.6051824>,
    <0.5277778, -167.5184453>,
    <0.5416745, -167.5184453>,
    <0.5436756, -167.5925951>,
    <0.5338390, -167.5563642>,
    <0.5338590, -167.5184453>,
    <0.5436950, -167.5437683>,
    <0.5497705, -167.5545331>,
    <0.5462963, -167.5763713>,
    <0.5416745, -167.5184453>,
    <0.5555556, -167.5184453>,
    <0.5555556, -167.6048705>,
    <0.5436950, -167.5437683>,
    <0.5494825, -167.5184453>,
    <0.5555556, -167.5563664>,
    <0.5515011, -167.5923911>,
    <0.5497625, -167.6196618>,
    <0.5462963, -167.5763713>,
    <0.5555556, -167.6048705>,
    <0.5555556, -167.6922232>,
    <0.5416424, -167.6051824>,
    <0.5515011, -167.5923911>,
    <0.5555556, -167.6541051>,
    <0.5494628, -167.6541068>,
    <0.5436756, -167.5925951>,
    <0.4502259, -167.6341061>,
    <0.4537037, -167.6737665>,
    <0.4583110, -167.6473117>,
    <0.4444444, -167.5684558>,
    <0.4444444, -167.6468904>,
    <0.4562970, -167.6588757>,
    <0.4505069, -167.6029317>,
    <0.4444444, -167.6028580>,
    <0.4484955, -167.6586490>,
    <0.4502327, -167.6933751>,
    <0.4537037, -167.6737665>,
    <0.4444444, -167.6468904>,
    <0.4444444, -167.7264218>,
    <0.4583382, -167.7264218>,
    <0.4484955, -167.6586490>,
    <0.4444444, -167.6917086>,
    <0.4505242, -167.7264218>,
    <0.4563127, -167.7034090>,
    <0.4606438, -167.6934805>,
    <0.4537037, -167.6737665>,
    <0.4583382, -167.7264218>,
    <0.4722222, -167.7264218>,
    <0.4583110, -167.6473117>,
    <0.4563127, -167.7034090>,
    <0.4661476, -167.7264218>,
    <0.4661306, -167.6917804>,
    <0.4562970, -167.6588757>,
    <0.4560043, -167.7614076>,
    <0.4629630, -167.7825485>,
    <0.4583382, -167.7264218>,
    <0.4444444, -167.7264218>,
    <0.4582717, -167.8102383>,
    <0.4603577, -167.7509304>,
    <0.4505242, -167.7264218>,
    <0.4504838, -167.7630303>,
    <0.4603216, -167.7981392>,
    <0.4664198, -167.8234740>,
    <0.4629630, -167.7825485>,
    <0.4582717, -167.8102383>,
    <0.4722222, -167.8948019>,
    <0.4722222, -167.8063071>,
    <0.4603216, -167.7981392>,
    <0.4662031, -167.8583157>,
    <0.4722222, -167.8571863>,
    <0.4681683, -167.7959050>,
    <0.4664364, -167.7604248>,
    <0.4629630, -167.7825485>,
    <0.4722222, -167.8063071>,
    <0.4722222, -167.7264218>,
    <0.4583382, -167.7264218>,
    <0.4681683, -167.7959050>,
    <0.4722222, -167.7609443>,
    <0.4661476, -167.7264218>,
    <0.4603577, -167.7509304>,
    <0.5335486, -167.7954006>,
    <0.5370370, -167.8386752>,
    <0.5416017, -167.8102183>,
    <0.5277778, -167.7264218>,
    <0.5277778, -167.8062871>,
    <0.5396058, -167.8226610>,
    <0.5338153, -167.7630191>,
    <0.5277778, -167.7609340>,
    <0.5318240, -167.8204406>,
    <0.5335687, -167.8586415>,
    <0.5370370, -167.8386752>,
    <0.5277778, -167.8062871>,
    <0.5277778, -167.8948019>,
    <0.5416823, -167.8948019>,
    <0.5318240, -167.8204406>,
    <0.5277778, -167.8563598>,
    <0.5337442, -167.8948019>,
    <0.5396720, -167.8705128>,
    <0.5439692, -167.8596244>,
    <0.5370370, -167.8386752>,
    <0.5416823, -167.8948019>,
    <0.5555556, -167.8948019>,
    <0.5416017, -167.8102183>,
    <0.5396720, -167.8705128>,
    <0.5495748, -167.8948019>,
    <0.5494950, -167.8580648>,
    <0.5396058, -167.8226610>,
    <0.5393368, -167.7614026>,
    <0.5462963, -167.7825485>,
    <0.5416715, -167.7264218>,
    <0.5277778, -167.7264218>,
    <0.5416017, -167.8102183>,
    <0.5436909, -167.7509292>,
    <0.5338575, -167.7264218>,
    <0.5338153, -167.7630191>,
    <0.5436530, -167.7981280>,
    <0.5497523, -167.8234625>,
    <0.5462963, -167.7825485>,
    <0.5416017, -167.8102183>,
    <0.5555556, -167.8948019>,
    <0.5555556, -167.8062814>,
    <0.5436530, -167.7981280>,
    <0.5494950, -167.8580648>,
    <0.5555556, -167.8563468>,
    <0.5515016, -167.7958904>,
    <0.5497697, -167.7604184>,
    <0.5462963, -167.7825485>,
    <0.5555556, -167.8062814>,
    <0.5555556, -167.7264218>,
    <0.5416715, -167.7264218>,
    <0.5515016, -167.7958904>,
    <0.5555556, -167.7609311>,
    <0.5494809, -167.7264218>,
    <0.5436909, -167.7509292>,
    <0.4779927, -167.7681909>,
    <0.4814815, -167.8156918>,
    <0.4722222, -167.7804649>,
    <0.4722222, -167.6922232>,
    <0.4860450, -167.7843838>,
    <0.4762685, -167.7958591>,
    <0.4722222, -167.7304074>,
    <0.4782589, -167.7324717>,
    <0.4840501, -167.7980694>,
    <0.4884130, -167.8387319>,
    <0.4814815, -167.8156918>,
    <0.4860450, -167.7843838>,
    <0.5000000, -167.8774261>,
    <0.4861257, -167.8774261>,
    <0.4840501, -167.7980694>,
    <0.4939624, -167.8371714>,
    <0.4940116, -167.8774261>,
    <0.4840917, -167.8503887>,
    <0.4780129, -167.8377522>,
    <0.4814815, -167.8156918>,
    <0.4861257, -167.8774261>,
    <0.4722222, -167.8774261>,
    <0.4722222, -167.7804649>,
    <0.4840917, -167.8503887>,
    <0.4783115, -167.8774261>,
    <0.4722222, -167.8348693>,
    <0.4762685, -167.7958591>,
    <0.4835603, -167.9155740>,
    <0.4907407, -167.9410995>,
    <0.4851526, -167.9663445>,
    <0.4722222, -167.8774261>,
    <0.4861257, -167.8774261>,
    <0.4875332, -167.9555897>,
    <0.4777046, -167.9151272>,
    <0.4783115, -167.8774261>,
    <0.4881307, -167.9050882>,
    <0.4942166, -167.9166809>,
    <0.4907407, -167.9410995>,
    <0.4861257, -167.8774261>,
    <0.5000000, -167.8774261>,
    <0.5000000, -167.9707722>,
    <0.4881307, -167.9050882>,
    <0.4940116, -167.8774261>,
    <0.5000000, -167.9176205>,
    <0.4960044, -167.9579678>,
    <0.4939733, -167.9866656>,
    <0.4907407, -167.9410995>,
    <0.5000000, -167.9707722>,
    <0.5000000, -168.0684463>,
    <0.4851526, -167.9663445>,
    <0.4960044, -167.9579678>,
    <0.5000000, -168.0353248>,
    <0.4933782, -168.0229102>,
    <0.4875332, -167.9555897>,
    <0.5045423, -167.9479173>,
    <0.5092593, -168.0047729>,
    <0.5000000, -167.9707722>,
    <0.5000000, -167.8774261>,
    <0.5089101, -167.9386982>,
    <0.5042993, -167.9865597>,
    <0.5000000, -167.9176205>,
    <0.5038023, -167.9035733>,
    <0.5090685, -167.9686777>,
    <0.5142254, -168.0200909>,
    <0.5092593, -168.0047729>,
    <0.5089101, -167.9386982>,
    <0.5277778, -168.0684463>,
    <0.5109544, -168.0684463>,
    <0.5090685, -167.9686777>,
    <0.5161103, -167.9882125>,
    <0.5179802, -168.0684463>,
    <0.5100894, -168.0359554>,
    <0.5050534, -168.0281094>,
    <0.5092593, -168.0047729>,
    <0.5109544, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.5000000, -167.9707722>,
    <0.5100894, -168.0359554>,
    <0.5046102, -168.0684463>,
    <0.5000000, -168.0353248>,
    <0.5042993, -167.9865597>,
    <0.5103332, -167.9086624>,
    <0.5185185, -167.9410995>,
    <0.5089101, -167.9386982>,
    <0.5000000, -167.8774261>,
    <0.5139041, -167.8774261>,
    <0.5125820, -167.9396159>,
    <0.5038023, -167.9035733>,
    <0.5059141, -167.8774261>,
    <0.5160961, -167.9076729>,
    <0.5219946, -167.9062454>,
    <0.5185185, -167.9410995>,
    <0.5139041, -167.8774261>,
    <0.5277778, -167.8774261>,
    <0.5277778, -167.9290301>,
    <0.5160961, -167.9076729>,
    <0.5218100, -167.8774261>,
    <0.5277778, -167.8992980>,
    <0.5239544, -167.9340138>,
    <0.5207460, -167.9693185>,
    <0.5185185, -167.9410995>,
    <0.5277778, -167.9290301>,
    <0.5277778, -168.0684463>,
    <0.5089101, -167.9386982>,
    <0.5239544, -167.9340138>,
    <0.5277778, -167.9752795>,
    <0.5161103, -167.9882125>,
    <0.5125820, -167.9396159>,
    <0.5650584, -167.0805923>,
    <0.5686229, -167.0842391>,
    <0.5747824, -167.1012374>,
    <0.5555607, -167.0684463>,
    <0.5612676, -167.0684463>,
    <0.5726586, -167.0953764>,
    <0.5672091, -167.0883177>,
    <0.5584142, -167.0684463>,
    <0.5642220, -167.0747897>,
    <0.5682745, -167.0790979>,
    <0.5686229, -167.0842391>,
    <0.5612676, -167.0684463>,
    <0.5669746, -167.0684463>,
    <0.5762328, -167.0952600>,
    <0.5642220, -167.0747897>,
    <0.5641211, -167.0684463>,
    <0.5714115, -167.0812964>,
    <0.5724468, -167.0897770>,
    <0.5757429, -167.0991403>,
    <0.5686229, -167.0842391>,
    <0.5762328, -167.0952600>,
    <0.5833333, -167.1158246>,
    <0.5747824, -167.1012374>,
    <0.5724468, -167.0897770>,
    <0.5805252, -167.1076916>,
    <0.5799025, -167.1099718>,
    <0.5726586, -167.0953764>,
    <0.4351807, -167.0791246>,
    <0.4389915, -167.0842391>,
    <0.4373807, -167.0953667>,
    <0.4280857, -167.0684463>,
    <0.4362651, -167.0684463>,
    <0.4380247, -167.0909177>,
    <0.4325550, -167.0813903>,
    <0.4321754, -167.0684463>,
    <0.4374475, -167.0752958>,
    <0.4410364, -167.0790995>,
    <0.4389915, -167.0842391>,
    <0.4362651, -167.0684463>,
    <0.4444444, -167.0684463>,
    <0.4444444, -167.0952665>,
    <0.4374475, -167.0752958>,
    <0.4403547, -167.0684463>,
    <0.4444444, -167.0823113>,
    <0.4421301, -167.0905863>,
    <0.4413153, -167.0976742>,
    <0.4389915, -167.0842391>,
    <0.4444444, -167.0952665>,
    <0.4444444, -167.1158246>,
    <0.4373807, -167.0953667>,
    <0.4421301, -167.0905863>,
    <0.4444444, -167.1100137>,
    <0.4416571, -167.1077519>,
    <0.4380247, -167.0909177>,
    <0.5626767, -167.0912918>,
    <0.5648148, -167.1000319>,
    <0.5555556, -167.0954519>,
    <0.5555556, -167.0684463>,
    <0.5747809, -167.1012374>,
    <0.5595406, -167.0974230>,
    <0.5555556, -167.0825221>,
    <0.5672061, -167.0883177>,
    <0.5697106, -167.1006241>,
    <0.5729467, -167.1082296>,
    <0.5648148, -167.1000319>,
    <0.5747809, -167.1012374>,
    <0.5833333, -167.1158246>,
    <0.5688576, -167.1158246>,
    <0.5697106, -167.1006241>,
    <0.5799018, -167.1099718>,
    <0.5770741, -167.1158246>,
    <0.5669695, -167.1084489>,
    <0.5611959, -167.1067833>,
    <0.5648148, -167.1000319>,
    <0.5688576, -167.1158246>,
    <0.5555556, -167.1158246>,
    <0.5555556, -167.0954519>,
    <0.5669695, -167.1084489>,
    <0.5610402, -167.1158246>,
    <0.5555556, -167.1101311>,
    <0.5595406, -167.0974230>,
    <0.4780032, -167.5906989>,
    <0.4814815, -167.6342972>,
    <0.4722222, -167.6048705>,
    <0.4722222, -167.5184453>,
    <0.4860868, -167.6051824>,
    <0.4762731, -167.6177446>,
    <0.4722222, -167.5563664>,
    <0.4782834, -167.5563642>,
    <0.4840737, -167.6179095>,
    <0.4884212, -167.6559815>,
    <0.4814815, -167.6342972>,
    <0.4860868, -167.6051824>,
    <0.5000000, -167.6922232>,
    <0.4861165, -167.6922232>,
    <0.4840737, -167.6179095>,
    <0.4939072, -167.6541068>,
    <0.4939257, -167.6922232>,
    <0.4840909, -167.6669079>,
    <0.4780106, -167.6559035>,
    <0.4814815, -167.6342972>,
    <0.4861165, -167.6922232>,
    <0.4722222, -167.6922232>,
    <0.4722222, -167.6048705>,
    <0.4840909, -167.6669079>,
    <0.4783022, -167.6922232>,
    <0.4722222, -167.6541051>,
    <0.4762731, -167.6177446>,
    <0.4837811, -167.7306969>,
    <0.4907407, -167.7539575>,
    <0.4860450, -167.7843838>,
    <0.4722222, -167.6922232>,
    <0.4861165, -167.6922232>,
    <0.4880967, -167.7710893>,
    <0.4782589, -167.7324717>,
    <0.4783022, -167.6922232>,
    <0.4881358, -167.7191809>,
    <0.4942143, -167.7297145>,
    <0.4907407, -167.7539575>,
    <0.4861165, -167.6922232>,
    <0.5000000, -167.6922232>,
    <0.5000000, -167.7804543>,
    <0.4881358, -167.7191809>,
    <0.4939257, -167.6922232>,
    <0.5000000, -167.7304019>,
    <0.4959459, -167.7688528>,
    <0.4941964, -167.7990554>,
    <0.4907407, -167.7539575>,
    <0.5000000, -167.7804543>,
    <0.5000000, -167.8774261>,
    <0.4860450, -167.7843838>,
    <0.4959459, -167.7688528>,
    <0.5000000, -167.8350486>,
    <0.4939624, -167.8371714>,
    <0.4880967, -167.7710893>,
    <0.5057702, -167.7681864>,
    <0.5092593, -167.8156918>,
    <0.5000000, -167.7804543>,
    <0.5000000, -167.6922232>,
    <0.5138217, -167.7843763>,
    <0.5040462, -167.7958526>,
    <0.5000000, -167.7304019>,
    <0.5060361, -167.7324676>,
    <0.5118272, -167.7980660>,
    <0.5161907, -167.8387301>,
    <0.5092593, -167.8156918>,
    <0.5138217, -167.7843763>,
    <0.5277778, -167.8774261>,
    <0.5139041, -167.8774261>,
    <0.5118272, -167.7980660>,
    <0.5217164, -167.8370130>,
    <0.5218100, -167.8774261>,
    <0.5119022, -167.8508194>,
    <0.5057908, -167.8377495>,
    <0.5092593, -167.8156918>,
    <0.5139041, -167.8774261>,
    <0.5000000, -167.8774261>,
    <0.5000000, -167.7804543>,
    <0.5119022, -167.8508194>,
    <0.5059141, -167.8774261>,
    <0.5000000, -167.8350486>,
    <0.5040462, -167.7958526>,
    <0.5115586, -167.7306951>,
    <0.5185185, -167.7539575>,
    <0.5138217, -167.7843763>,
    <0.5000000, -167.6922232>,
    <0.5138943, -167.6922232>,
    <0.5158739, -167.7710852>,
    <0.5060361, -167.7324676>,
    <0.5060800, -167.6922232>,
    <0.5159135, -167.7191805>,
    <0.5219921, -167.7297125>,
    <0.5185185, -167.7539575>,
    <0.5138943, -167.6922232>,
    <0.5277778, -167.6922232>,
    <0.5277778, -167.7804462>,
    <0.5159135, -167.7191805>,
    <0.5217034, -167.6922232>,
    <0.5277778, -167.7303977>,
    <0.5237237, -167.7688482>,
    <0.5219739, -167.7990515>,
    <0.5185185, -167.7539575>,
    <0.5277778, -167.7804462>,
    <0.5277778, -167.8774261>,
    <0.5138217, -167.7843763>,
    <0.5237237, -167.7688482>,
    <0.5277778, -167.8353065>,
    <0.5217164, -167.8370130>,
    <0.5158739, -167.7710852>,
    <0.4502238, -167.4848985>,
    <0.4537037, -167.5208549>,
    <0.4583027, -167.4968970>,
    <0.4444444, -167.4256532>,
    <0.4444444, -167.4961890>,
    <0.4562922, -167.5073705>,
    <0.4505015, -167.4567920>,
    <0.4444444, -167.4566011>,
    <0.4484949, -167.5069791>,
    <0.4502332, -167.5384889>,
    <0.4537037, -167.5208549>,
    <0.4444444, -167.4961890>,
    <0.4444444, -167.5684558>,
    <0.4583404, -167.5684558>,
    <0.4484949, -167.5069791>,
    <0.4444444, -167.5369297>,
    <0.4505253, -167.5684558>,
    <0.4563139, -167.5476517>,
    <0.4606423, -167.5386659>,
    <0.4537037, -167.5208549>,
    <0.4583404, -167.5684558>,
    <0.4722222, -167.5684558>,
    <0.4583027, -167.4968970>,
    <0.4563139, -167.5476517>,
    <0.4661487, -167.5684558>,
    <0.4661252, -167.5371117>,
    <0.4562922, -167.5073705>,
    <0.4560147, -167.6013336>,
    <0.4629630, -167.6211112>,
    <0.4583404, -167.5684558>,
    <0.4444444, -167.5684558>,
    <0.4583110, -167.6473117>,
    <0.4603610, -167.5914725>,
    <0.4505253, -167.5684558>,
    <0.4505069, -167.6029317>,
    <0.4603435, -167.6358644>,
    <0.4664296, -167.6604338>,
    <0.4629630, -167.6211112>,
    <0.4583110, -167.6473117>,
    <0.4722222, -167.7264218>,
    <0.4722222, -167.6468904>,
    <0.4603435, -167.6358644>,
    <0.4661306, -167.6917804>,
    <0.4722222, -167.6917086>,
    <0.4681679, -167.6356026>,
    <0.4664370, -167.6012283>,
    <0.4629630, -167.6211112>,
    <0.4722222, -167.6468904>,
    <0.4722222, -167.5684558>,
    <0.4583404, -167.5684558>,
    <0.4681679, -167.6356026>,
    <0.4722222, -167.6028579>,
    <0.4661487, -167.5684558>,
    <0.4603610, -167.5914725>,
    <0.5335592, -167.6341061>,
    <0.5370370, -167.6737665>,
    <0.5416443, -167.6473117>,
    <0.5277778, -167.5684558>,
    <0.5277778, -167.6468904>,
    <0.5396304, -167.6588757>,
    <0.5338402, -167.6029317>,
    <0.5277778, -167.6028580>,
    <0.5318288, -167.6586490>,
    <0.5335660, -167.6933751>,
    <0.5370370, -167.6737665>,
    <0.5277778, -167.6468904>,
    <0.5277778, -167.7264218>,
    <0.5416715, -167.7264218>,
    <0.5318288, -167.6586490>,
    <0.5277778, -167.6917086>,
    <0.5338575, -167.7264218>,
    <0.5396460, -167.7034090>,
    <0.5439771, -167.6934805>,
    <0.5370370, -167.6737665>,
    <0.5416715, -167.7264218>,
    <0.5555556, -167.7264218>,
    <0.5416443, -167.6473117>,
    <0.5396460, -167.7034090>,
    <0.5494809, -167.7264218>,
    <0.5494640, -167.6917804>,
    <0.5396304, -167.6588757>,
    <0.5393480, -167.6013336>,
    <0.5462963, -167.6211112>,
    <0.5416737, -167.5684558>,
    <0.5277778, -167.5684558>,
    <0.5416443, -167.6473117>,
    <0.5436944, -167.5914725>,
    <0.5338587, -167.5684558>,
    <0.5338402, -167.6029317>,
    <0.5436768, -167.6358644>,
    <0.5497629, -167.6604338>,
    <0.5462963, -167.6211112>,
    <0.5416443, -167.6473117>,
    <0.5555556, -167.7264218>,
    <0.5555556, -167.6468904>,
    <0.5436768, -167.6358644>,
    <0.5494640, -167.6917804>,
    <0.5555556, -167.6917086>,
    <0.5515013, -167.6356026>,
    <0.5497703, -167.6012283>,
    <0.5462963, -167.6211112>,
    <0.5555556, -167.6468904>,
    <0.5555556, -167.5684558>,
    <0.5416737, -167.5684558>,
    <0.5515013, -167.6356026>,
    <0.5555556, -167.6028579>,
    <0.5494820, -167.5684558>,
    <0.5436944, -167.5914725>,
    <0.4765873, -167.9593493>,
    <0.4814815, -168.0105648>,
    <0.4804233, -167.9460688>,
    <0.4722222, -167.8948019>,
    <0.4722222, -167.9859616>,
    <0.4809265, -167.9767363>,
    <0.4756945, -167.9165081>,
    <0.4722222, -167.9349131>,
    <0.4765113, -167.9973582>,
    <0.4775763, -168.0333548>,
    <0.4814815, -168.0105648>,
    <0.4722222, -167.9859616>,
    <0.4722222, -168.0684463>,
    <0.4843793, -168.0684463>,
    <0.4765113, -167.9973582>,
    <0.4722222, -168.0339467>,
    <0.4796384, -168.0684463>,
    <0.4832717, -168.0463233>,
    <0.4865710, -168.0233815>,
    <0.4814815, -168.0105648>,
    <0.4843793, -168.0684463>,
    <0.5000000, -168.0684463>,
    <0.4804233, -167.9460688>,
    <0.4832717, -168.0463233>,
    <0.4896274, -168.0684463>,
    <0.4877750, -167.9920254>,
    <0.4809265, -167.9767363>,
    <0.4502211, -167.2819570>,
    <0.4537037, -167.3161845>,
    <0.4444444, -167.2924560>,
    <0.4444444, -167.2258020>,
    <0.4582917, -167.2933857>,
    <0.4484941, -167.3028339>,
    <0.4444444, -167.2550533>,
    <0.4504944, -167.2553296>,
    <0.4562858, -167.3033535>,
    <0.4606402, -167.3330804>,
    <0.4537037, -167.3161845>,
    <0.4582917, -167.2933857>,
    <0.4722222, -167.3613758>,
    <0.4583433, -167.3613758>,
    <0.4562858, -167.3033535>,
    <0.4661180, -167.3315832>,
    <0.4661502, -167.3613758>,
    <0.4563155, -167.3416247>,
    <0.4502340, -167.3328480>,
    <0.4537037, -167.3161845>,
    <0.4583433, -167.3613758>,
    <0.4444444, -167.3613758>,
    <0.4444444, -167.2924560>,
    <0.4563155, -167.3416247>,
    <0.4505268, -167.3613758>,
    <0.4444444, -167.3313235>,
    <0.4484941, -167.3028339>,
    <0.4560127, -167.3940515>,
    <0.4629630, -167.4137323>,
    <0.4583000, -167.4397221>,
    <0.4444444, -167.3613758>,
    <0.4583433, -167.3613758>,
    <0.4603371, -167.4283682>,
    <0.4504998, -167.3956156>,
    <0.4505268, -167.3613758>,
    <0.4603627, -167.3842624>,
    <0.4664377, -167.3939086>,
    <0.4629630, -167.4137323>,
    <0.4583433, -167.3613758>,
    <0.4722222, -167.3613758>,
    <0.4722222, -167.4391507>,
    <0.4603627, -167.3842624>,
    <0.4661502, -167.3613758>,
    <0.4722222, -167.3955180>,
    <0.4681671, -167.4280187>,
    <0.4664269, -167.4527626>,
    <0.4629630, -167.4137323>,
    <0.4722222, -167.4391507>,
    <0.4722222, -167.5184453>,
    <0.4583000, -167.4397221>,
    <0.4681671, -167.4280187>,
    <0.4722222, -167.4838674>,
    <0.4661235, -167.4839601>,
    <0.4603371, -167.4283682>,
    <0.5335565, -167.4265843>,
    <0.5370370, -167.4660888>,
    <0.5277778, -167.4391507>,
    <0.5277778, -167.3613758>,
    <0.5416333, -167.4397221>,
    <0.5318280, -167.4509341>,
    <0.5277778, -167.3955180>,
    <0.5338331, -167.3956156>,
    <0.5396239, -167.4512490>,
    <0.5439751, -167.4856754>,
    <0.5370370, -167.4660888>,
    <0.5416333, -167.4397221>,
    <0.5555556, -167.5184453>,
    <0.5416745, -167.5184453>,
    <0.5396239, -167.4512490>,
    <0.5494568, -167.4839601>,
    <0.5494825, -167.5184453>,
    <0.5396478, -167.4955641>,
    <0.5335668, -167.4855325>,
    <0.5370370, -167.4660888>,
    <0.5416745, -167.5184453>,
    <0.5277778, -167.5184453>,
    <0.5277778, -167.4391507>,
    <0.5396478, -167.4955641>,
    <0.5338590, -167.5184453>,
    <0.5277778, -167.4838674>,
    <0.5318280, -167.4509341>,
    <0.5393460, -167.3940515>,
    <0.5462963, -167.4137323>,
    <0.5416333, -167.4397221>,
    <0.5277778, -167.3613758>,
    <0.5416767, -167.3613758>,
    <0.5436704, -167.4283682>,
    <0.5338331, -167.3956156>,
    <0.5338602, -167.3613758>,
    <0.5436960, -167.3842624>,
    <0.5497710, -167.3939086>,
    <0.5462963, -167.4137323>,
    <0.5416767, -167.3613758>,
    <0.5555556, -167.3613758>,
    <0.5555556, -167.4391507>,
    <0.5436960, -167.3842624>,
    <0.5494835, -167.3613758>,
    <0.5555556, -167.3955180>,
    <0.5515005, -167.4280187>,
    <0.5497602, -167.4527626>,
    <0.5462963, -167.4137323>,
    <0.5555556, -167.4391507>,
    <0.5555556, -167.5184453>,
    <0.5416333, -167.4397221>,
    <0.5515005, -167.4280187>,
    <0.5555556, -167.4838674>,
    <0.5494568, -167.4839601>,
    <0.5436704, -167.4283682>,
    <0.4779936, -167.7954091>,
    <0.4814815, -167.8386752>,
    <0.4860485, -167.8102322>,
    <0.4722222, -167.7264218>,
    <0.4722222, -167.8063071>,
    <0.4840518, -167.8226674>,
    <0.4782610, -167.7630269>,
    <0.4722222, -167.7609443>,
    <0.4762687, -167.8204528>,
    <0.4780129, -167.8586466>,
    <0.4814815, -167.8386752>,
    <0.4722222, -167.8063071>,
    <0.4722222, -167.8948019>,
    <0.4861255, -167.8948019>,
    <0.4762687, -167.8204528>,
    <0.4722222, -167.8571863>,
    <0.4781117, -167.8948019>,
    <0.4841308, -167.8706942>,
    <0.4884139, -167.8596278>,
    <0.4814815, -167.8386752>,
    <0.4861255, -167.8948019>,
    <0.5000000, -167.8948019>,
    <0.4860485, -167.8102322>,
    <0.4841308, -167.8706942>,
    <0.4940382, -167.8948019>,
    <0.4939424, -167.8580830>,
    <0.4840518, -167.8226674>,
    <0.4823779, -167.9220890>,
    <0.4907407, -167.9526834>,
    <0.4861255, -167.8948019>,
    <0.4722222, -167.8948019>,
    <0.4804233, -167.9460688>,
    <0.4883402, -167.9225779>,
    <0.4781117, -167.8948019>,
    <0.4756945, -167.9165081>,
    <0.4841592, -167.9484638>,
    <0.4927910, -167.9759032>,
    <0.4907407, -167.9526834>,
    <0.4804233, -167.9460688>,
    <0.5000000, -168.0684463>,
    <0.5000000, -167.9364144>,
    <0.4841592, -167.9484638>,
    <0.4877750, -167.9920254>,
    <0.5000000, -167.9780654>,
    <0.4962098, -167.9430739>,
    <0.4942166, -167.9196754>,
    <0.4907407, -167.9526834>,
    <0.5000000, -167.9364144>,
    <0.5000000, -167.8948019>,
    <0.4861255, -167.8948019>,
    <0.4962098, -167.9430739>,
    <0.5000000, -167.9124763>,
    <0.4940382, -167.8948019>,
    <0.4883402, -167.9225779>,
    <0.5049050, -167.9503375>,
    <0.5092593, -168.0105648>,
    <0.5103607, -167.9595688>,
    <0.5000000, -167.8948019>,
    <0.5000000, -167.9364144>,
    <0.5098582, -167.9828358>,
    <0.5044355, -167.9225289>,
    <0.5000000, -167.9124763>,
    <0.5042081, -167.9701139>,
    <0.5057870, -168.0209680>,
    <0.5092593, -168.0105648>,
    <0.5000000, -167.9364144>,
    <0.5000000, -168.0684463>,
    <0.5138889, -168.0684463>,
    <0.5042081, -167.9701139>,
    <0.5000000, -167.9780654>,
    <0.5069444, -168.0684463>,
    <0.5120117, -168.0449767>,
    <0.5153217, -168.0267566>,
    <0.5092593, -168.0105648>,
    <0.5138889, -168.0684463>,
    <0.5277778, -168.0684463>,
    <0.5103607, -167.9595688>,
    <0.5120117, -168.0449767>,
    <0.5208333, -168.0684463>,
    <0.5179257, -168.0068587>,
    <0.5098582, -167.9828358>,
    <0.5106958, -167.9254640>,
    <0.5185185, -167.9526834>,
    <0.5139039, -167.8948019>,
    <0.5000000, -167.8948019>,
    <0.5103607, -167.9595688>,
    <0.5160555, -167.9217893>,
    <0.5059665, -167.8948019>,
    <0.5044355, -167.9225289>,
    <0.5136146, -167.9568225>,
    <0.5211087, -167.9831308>,
    <0.5185185, -167.9526834>,
    <0.5103607, -167.9595688>,
    <0.5277778, -168.0684463>,
    <0.5277778, -167.9518248>,
    <0.5136146, -167.9568225>,
    <0.5179257, -168.0068587>,
    <0.5277778, -167.9954031>,
    <0.5238910, -167.9521852>,
    <0.5219945, -167.9235280>,
    <0.5185185, -167.9526834>,
    <0.5277778, -167.9518248>,
    <0.5277778, -167.8948019>,
    <0.5139039, -167.8948019>,
    <0.5238910, -167.9521852>,
    <0.5277778, -167.9192810>,
    <0.5217967, -167.8948019>,
    <0.5160555, -167.9217893>,
    <0.4391582, -167.1106496>,
    <0.4381085, -167.1123151>,
    <0.4434422, -167.1220942>,
    <0.4407346, -167.1040945>,
    <0.4343477, -167.1040945>,
    <0.4406676, -167.1170071>,
    <0.4421942, -167.1137978>,
    <0.4372812, -167.1040945>,
    <0.4357357, -167.1071285>,
    <0.4355869, -167.1108241>,
    <0.4381085, -167.1123151>,
    <0.4343477, -167.1040945>,
    <0.4291465, -167.1040945>,
    <0.4407448, -167.1227922>,
    <0.4357357, -167.1071285>,
    <0.4316728, -167.1040945>,
    <0.4364301, -167.1158365>,
    <0.4397750, -167.1189380>,
    <0.4416850, -167.1214895>,
    <0.4381085, -167.1123151>,
    <0.4407448, -167.1227922>,
    <0.4444444, -167.1287564>,
    <0.4434422, -167.1220942>,
    <0.4397750, -167.1189380>,
    <0.4430950, -167.1265810>,
    <0.4441597, -167.1268636>,
    <0.4406676, -167.1170071>,
    <0.4298756, -167.1176325>,
    <0.4300859, -167.1205358>,
    <0.4407448, -167.1227922>,
    <0.4291465, -167.1040945>,
    <0.4195253, -167.1231073>,
    <0.4360641, -167.1218013>,
    <0.4364301, -167.1158365>,
    <0.4230187, -167.1162039>,
    <0.4243967, -167.1219211>,
    <0.4239660, -167.1252890>,
    <0.4300859, -167.1205358>,
    <0.4195253, -167.1231073>,
    <0.4166667, -167.1287564>,
    <0.4295859, -167.1287564>,
    <0.4243967, -167.1219211>,
    <0.4177047, -167.1267052>,
    <0.4219371, -167.1287564>,
    <0.4297638, -167.1258321>,
    <0.4362153, -167.1252102>,
    <0.4300859, -167.1205358>,
    <0.4295859, -167.1287564>,
    <0.4444444, -167.1287564>,
    <0.4407448, -167.1227922>,
    <0.4297638, -167.1258321>,
    <0.4379787, -167.1287564>,
    <0.4430950, -167.1265810>,
    <0.4360641, -167.1218013>,
    <0.4280581, -167.1442610>,
    <0.4351852, -167.1533103>,
    <0.4295859, -167.1287564>,
    <0.4166667, -167.1287564>,
    <0.4307945, -167.1662209>,
    <0.4323450, -167.1408553>,
    <0.4219371, -167.1287564>,
    <0.4229238, -167.1453493>,
    <0.4327730, -167.1604034>,
    <0.4387171, -167.1706661>,
    <0.4351852, -167.1533103>,
    <0.4307945, -167.1662209>,
    <0.4444444, -167.2024179>,
    <0.4444444, -167.1607154>,
    <0.4327730, -167.1604034>,
    <0.4385041, -167.1866652>,
    <0.4444444, -167.1838308>,
    <0.4404564, -167.1575260>,
    <0.4384150, -167.1428846>,
    <0.4351852, -167.1533103>,
    <0.4444444, -167.1607154>,
    <0.4444444, -167.1287564>,
    <0.4295859, -167.1287564>,
    <0.4404564, -167.1575260>,
    <0.4444444, -167.1413914>,
    <0.4379787, -167.1287564>,
    <0.4323450, -167.1408553>,
    <0.5614257, -167.1582979>,
    <0.5648148, -167.1778641>,
    <0.5697767, -167.1664683>,
    <0.5555556, -167.1287564>,
    <0.5555556, -167.1601026>,
    <0.5676136, -167.1714363>,
    <0.5619134, -167.1456162>,
    <0.5555556, -167.1407351>,
    <0.5596113, -167.1678824>,
    <0.5613456, -167.1857007>,
    <0.5648148, -167.1778641>,
    <0.5555556, -167.1601026>,
    <0.5555556, -167.2024179>,
    <0.5694563, -167.2024179>,
    <0.5596113, -167.1678824>,
    <0.5555556, -167.1835239>,
    <0.5616390, -167.2024179>,
    <0.5674379, -167.1917403>,
    <0.5718453, -167.1872921>,
    <0.5648148, -167.1778641>,
    <0.5694563, -167.2024179>,
    <0.5833333, -167.2024179>,
    <0.5697767, -167.1664683>,
    <0.5674379, -167.1917403>,
    <0.5772622, -167.2024179>,
    <0.5774428, -167.1867974>,
    <0.5676136, -167.1714363>,
    <0.5688926, -167.1175674>,
    <0.5689748, -167.1205421>,
    <0.5798335, -167.1231187>,
    <0.5680355, -167.1041136>,
    <0.5587264, -167.1224952>,
    <0.5752566, -167.1220327>,
    <0.5757078, -167.1164727>,
    <0.5624121, -167.1152174>,
    <0.5636112, -167.1215643>,
    <0.5629781, -167.1251375>,
    <0.5689748, -167.1205421>,
    <0.5587264, -167.1224952>,
    <0.5555556, -167.1287564>,
    <0.5686557, -167.1287564>,
    <0.5636112, -167.1215643>,
    <0.5567122, -167.1264725>,
    <0.5609375, -167.1287564>,
    <0.5687614, -167.1260345>,
    <0.5751993, -167.1252934>,
    <0.5689748, -167.1205421>,
    <0.5686557, -167.1287564>,
    <0.5833333, -167.1287564>,
    <0.5798335, -167.1231187>,
    <0.5687614, -167.1260345>,
    <0.5769908, -167.1287564>,
    <0.5820577, -167.1267016>,
    <0.5752566, -167.1220327>,
    <0.5670155, -167.1443228>,
    <0.5740741, -167.1533103>,
    <0.5686557, -167.1287564>,
    <0.5555556, -167.1287564>,
    <0.5697767, -167.1664683>,
    <0.5713341, -167.1408941>,
    <0.5609375, -167.1287564>,
    <0.5619134, -167.1456162>,
    <0.5717147, -167.1605343>,
    <0.5776294, -167.1705747>,
    <0.5740741, -167.1533103>,
    <0.5697767, -167.1664683>,
    <0.5833333, -167.2024179>,
    <0.5833333, -167.1601023>,
    <0.5717147, -167.1605343>,
    <0.5774428, -167.1867974>,
    <0.5833333, -167.1835237>,
    <0.5793471, -167.1571782>,
    <0.5773491, -167.1427314>,
    <0.5740741, -167.1533103>,
    <0.5833333, -167.1601023>,
    <0.5833333, -167.1287564>,
    <0.5686557, -167.1287564>,
    <0.5793471, -167.1571782>,
    <0.5833333, -167.1407348>,
    <0.5769908, -167.1287564>,
    <0.5713341, -167.1408941>,
    <0.4780009, -167.4265843>,
    <0.4814815, -167.4660888>,
    <0.4722222, -167.4391507>,
    <0.4722222, -167.3613758>,
    <0.4860778, -167.4397221>,
    <0.4762725, -167.4509341>,
    <0.4722222, -167.3955180>,
    <0.4782775, -167.3956156>,
    <0.4840684, -167.4512490>,
    <0.4884196, -167.4856754>,
    <0.4814815, -167.4660888>,
    <0.4860778, -167.4397221>,
    <0.5000000, -167.5184453>,
    <0.4861190, -167.5184453>,
    <0.4840684, -167.4512490>,
    <0.4939013, -167.4839601>,
    <0.4939269, -167.5184453>,
    <0.4840923, -167.4955641>,
    <0.4780112, -167.4855325>,
    <0.4814815, -167.4660888>,
    <0.4861190, -167.5184453>,
    <0.4722222, -167.5184453>,
    <0.4722222, -167.4391507>,
    <0.4840923, -167.4955641>,
    <0.4783035, -167.5184453>,
    <0.4722222, -167.4838674>,
    <0.4762725, -167.4509341>,
    <0.4837922, -167.5546111>,
    <0.4907407, -167.5763713>,
    <0.4860868, -167.6051824>,
    <0.4722222, -167.5184453>,
    <0.4861190, -167.5184453>,
    <0.4881201, -167.5925951>,
    <0.4782834, -167.5563642>,
    <0.4783035, -167.5184453>,
    <0.4881394, -167.5437683>,
    <0.4942149, -167.5545331>,
    <0.4907407, -167.5763713>,
    <0.4861190, -167.5184453>,
    <0.5000000, -167.5184453>,
    <0.5000000, -167.6048705>,
    <0.4881394, -167.5437683>,
    <0.4939269, -167.5184453>,
    <0.5000000, -167.5563664>,
    <0.4959455, -167.5923911>,
    <0.4942069, -167.6196618>,
    <0.4907407, -167.5763713>,
    <0.5000000, -167.6048705>,
    <0.5000000, -167.6922232>,
    <0.4860868, -167.6051824>,
    <0.4959455, -167.5923911>,
    <0.5000000, -167.6541051>,
    <0.4939072, -167.6541068>,
    <0.4881201, -167.5925951>,
    <0.5057810, -167.5906989>,
    <0.5092593, -167.6342972>,
    <0.5000000, -167.6048705>,
    <0.5000000, -167.5184453>,
    <0.5138646, -167.6051824>,
    <0.5040509, -167.6177446>,
    <0.5000000, -167.5563664>,
    <0.5060612, -167.5563642>,
    <0.5118514, -167.6179095>,
    <0.5161990, -167.6559815>,
    <0.5092593, -167.6342972>,
    <0.5138646, -167.6051824>,
    <0.5277778, -167.6922232>,
    <0.5138943, -167.6922232>,
    <0.5118514, -167.6179095>,
    <0.5216850, -167.6541068>,
    <0.5217034, -167.6922232>,
    <0.5118687, -167.6669079>,
    <0.5057884, -167.6559035>,
    <0.5092593, -167.6342972>,
    <0.5138943, -167.6922232>,
    <0.5000000, -167.6922232>,
    <0.5000000, -167.6048705>,
    <0.5118687, -167.6669079>,
    <0.5060800, -167.6922232>,
    <0.5000000, -167.6541051>,
    <0.5040509, -167.6177446>,
    <0.5115700, -167.5546111>,
    <0.5185185, -167.5763713>,
    <0.5138646, -167.6051824>,
    <0.5000000, -167.5184453>,
    <0.5138967, -167.5184453>,
    <0.5158979, -167.5925951>,
    <0.5060612, -167.5563642>,
    <0.5060813, -167.5184453>,
    <0.5159172, -167.5437683>,
    <0.5219927, -167.5545331>,
    <0.5185185, -167.5763713>,
    <0.5138967, -167.5184453>,
    <0.5277778, -167.5184453>,
    <0.5277778, -167.6048705>,
    <0.5159172, -167.5437683>,
    <0.5217047, -167.5184453>,
    <0.5277778, -167.5563664>,
    <0.5237233, -167.5923911>,
    <0.5219847, -167.6196618>,
    <0.5185185, -167.5763713>,
    <0.5277778, -167.6048705>,
    <0.5277778, -167.6922232>,
    <0.5138646, -167.6051824>,
    <0.5237233, -167.5923911>,
    <0.5277778, -167.6541051>,
    <0.5216850, -167.6541068>,
    <0.5158979, -167.5925951>,
    <0.5628604, -167.1107625>,
    <0.5606678, -167.1123279>,
    <0.5587264, -167.1224952>,
    <0.5680355, -167.1041136>,
    <0.5640120, -167.1041136>,
    <0.5594194, -167.1188659>,
    <0.5624121, -167.1152174>,
    <0.5661597, -167.1041136>,
    <0.5628622, -167.1069379>,
    <0.5599163, -167.1101332>,
    <0.5606678, -167.1123279>,
    <0.5640120, -167.1041136>,
    <0.5584122, -167.1041136>,
    <0.5565732, -167.1199778>,
    <0.5628622, -167.1069379>,
    <0.5614994, -167.1041136>,
    <0.5574854, -167.1121087>,
    <0.5587279, -167.1159521>,
    <0.5578807, -167.1208893>,
    <0.5606678, -167.1123279>,
    <0.5565732, -167.1199778>,
    <0.5555556, -167.1287564>,
    <0.5587264, -167.1224952>,
    <0.5587279, -167.1159521>,
    <0.5558991, -167.1257931>,
    <0.5567122, -167.1264725>,
    <0.5594194, -167.1188659>,
    <0.4780037, -167.6341061>,
    <0.4814815, -167.6737665>,
    <0.4860887, -167.6473117>,
    <0.4722222, -167.5684558>,
    <0.4722222, -167.6468904>,
    <0.4840748, -167.6588757>,
    <0.4782847, -167.6029317>,
    <0.4722222, -167.6028579>,
    <0.4762733, -167.6586490>,
    <0.4780105, -167.6933751>,
    <0.4814815, -167.6737665>,
    <0.4722222, -167.6468904>,
    <0.4722222, -167.7264218>,
    <0.4861160, -167.7264218>,
    <0.4762733, -167.6586490>,
    <0.4722222, -167.6917086>,
    <0.4783019, -167.7264218>,
    <0.4840905, -167.7034090>,
    <0.4884216, -167.6934805>,
    <0.4814815, -167.6737665>,
    <0.4861160, -167.7264218>,
    <0.5000000, -167.7264218>,
    <0.4860887, -167.6473117>,
    <0.4840905, -167.7034090>,
    <0.4939253, -167.7264218>,
    <0.4939084, -167.6917804>,
    <0.4840748, -167.6588757>,
    <0.4837819, -167.7614061>,
    <0.4907407, -167.7825485>,
    <0.4861160, -167.7264218>,
    <0.4722222, -167.7264218>,
    <0.4860485, -167.8102322>,
    <0.4881354, -167.7509300>,
    <0.4783019, -167.7264218>,
    <0.4782610, -167.7630269>,
    <0.4880988, -167.7981358>,
    <0.4941973, -167.8234696>,
    <0.4907407, -167.7825485>,
    <0.4860485, -167.8102322>,
    <0.5000000, -167.8948019>,
    <0.5000000, -167.8062957>,
    <0.4880988, -167.7981358>,
    <0.4939424, -167.8580830>,
    <0.5000000, -167.8566253>,
    <0.4959460, -167.7958985>,
    <0.4942142, -167.7604220>,
    <0.4907407, -167.7825485>,
    <0.5000000, -167.8062957>,
    <0.5000000, -167.7264218>,
    <0.4861160, -167.7264218>,
    <0.4959460, -167.7958985>,
    <0.5000000, -167.7609385>,
    <0.4939253, -167.7264218>,
    <0.4881354, -167.7509300>,
    <0.5057711, -167.7954046>,
    <0.5092593, -167.8386752>,
    <0.5138252, -167.8102256>,
    <0.5000000, -167.7264218>,
    <0.5000000, -167.8062957>,
    <0.5118289, -167.8226643>,
    <0.5060382, -167.7630232>,
    <0.5000000, -167.7609385>,
    <0.5040464, -167.8204459>,
    <0.5057908, -167.8586437>,
    <0.5092593, -167.8386752>,
    <0.5000000, -167.8062957>,
    <0.5000000, -167.8948019>,
    <0.5139039, -167.8948019>,
    <0.5040464, -167.8204459>,
    <0.5000000, -167.8566253>,
    <0.5059665, -167.8948019>,
    <0.5118943, -167.8705176>,
    <0.5161915, -167.8596262>,
    <0.5092593, -167.8386752>,
    <0.5139039, -167.8948019>,
    <0.5277778, -167.8948019>,
    <0.5138252, -167.8102256>,
    <0.5118943, -167.8705176>,
    <0.5217967, -167.8948019>,
    <0.5217183, -167.8580715>,
    <0.5118289, -167.8226643>,
    <0.5115594, -167.7614044>,
    <0.5185185, -167.7825485>,
    <0.5138938, -167.7264218>,
    <0.5000000, -167.7264218>,
    <0.5138252, -167.8102256>,
    <0.5159132, -167.7509296>,
    <0.5060797, -167.7264218>,
    <0.5060382, -167.7630232>,
    <0.5158759, -167.7981321>,
    <0.5219748, -167.8234658>,
    <0.5185185, -167.7825485>,
    <0.5138252, -167.8102256>,
    <0.5277778, -167.8948019>,
    <0.5277778, -167.8062871>,
    <0.5158759, -167.7981321>,
    <0.5217183, -167.8580715>,
    <0.5277778, -167.8563598>,
    <0.5237238, -167.7958936>,
    <0.5219920, -167.7604198>,
    <0.5185185, -167.7825485>,
    <0.5277778, -167.8062871>,
    <0.5277778, -167.7264218>,
    <0.5138938, -167.7264218>,
    <0.5237238, -167.7958936>,
    <0.5277778, -167.7609340>,
    <0.5217031, -167.7264218>,
    <0.5159132, -167.7509296>,
    <0.4502219, -167.3534027>,
    <0.4537037, -167.3845690>,
    <0.4582951, -167.3638575>,
    <0.4444444, -167.3024008>,
    <0.4444444, -167.3627833>,
    <0.4562878, -167.3729124>,
    <0.4504966, -167.3292549>,
    <0.4444444, -167.3288803>,
    <0.4484943, -167.3723121>,
    <0.4502337, -167.3996647>,
    <0.4537037, -167.3845690>,
    <0.4444444, -167.3627833>,
    <0.4444444, -167.4256532>,
    <0.4583423, -167.4256532>,
    <0.4484943, -167.3723121>,
    <0.4444444, -167.3982231>,
    <0.4505264, -167.4256532>,
    <0.4563149, -167.4076960>,
    <0.4606409, -167.3999332>,
    <0.4537037, -167.3845690>,
    <0.4583423, -167.4256532>,
    <0.4722222, -167.4256532>,
    <0.4582951, -167.3638575>,
    <0.4563149, -167.4076960>,
    <0.4661497, -167.4256532>,
    <0.4661202, -167.3985780>,
    <0.4562878, -167.3729124>,
    <0.4560131, -167.4553644>,
    <0.4629630, -167.4732541>,
    <0.4583423, -167.4256532>,
    <0.4444444, -167.4256532>,
    <0.4583027, -167.4968970>,
    <0.4603620, -167.4464590>,
    <0.4505264, -167.4256532>,
    <0.4505015, -167.4567920>,
    <0.4603387, -167.4865678>,
    <0.4664275, -167.5086990>,
    <0.4629630, -167.4732541>,
    <0.4583027, -167.4968970>,
    <0.4722222, -167.5684558>,
    <0.4722222, -167.4961890>,
    <0.4603387, -167.4865678>,
    <0.4661252, -167.5371117>,
    <0.4722222, -167.5369298>,
    <0.4681674, -167.4861453>,
    <0.4664374, -167.4551874>,
    <0.4629630, -167.4732541>,
    <0.4722222, -167.4961890>,
    <0.4722222, -167.4256532>,
    <0.4583423, -167.4256532>,
    <0.4681674, -167.4861453>,
    <0.4722222, -167.4566011>,
    <0.4661497, -167.4256532>,
    <0.4603620, -167.4464590>,
    <0.5335572, -167.4848985>,
    <0.5370370, -167.5208549>,
    <0.5416360, -167.4968970>,
    <0.5277778, -167.4256532>,
    <0.5277778, -167.4961890>,
    <0.5396255, -167.5073705>,
    <0.5338349, -167.4567920>,
    <0.5277778, -167.4566011>,
    <0.5318282, -167.5069791>,
    <0.5335666, -167.5384889>,
    <0.5370370, -167.5208549>,
    <0.5277778, -167.4961890>,
    <0.5277778, -167.5684558>,
    <0.5416737, -167.5684558>,
    <0.5318282, -167.5069791>,
    <0.5277778, -167.5369297>,
    <0.5338587, -167.5684558>,
    <0.5396473, -167.5476517>,
    <0.5439756, -167.5386659>,
    <0.5370370, -167.5208549>,
    <0.5416737, -167.5684558>,
    <0.5555556, -167.5684558>,
    <0.5416360, -167.4968970>,
    <0.5396473, -167.5476517>,
    <0.5494820, -167.5684558>,
    <0.5494585, -167.5371117>,
    <0.5396255, -167.5073705>,
    <0.5393464, -167.4553644>,
    <0.5462963, -167.4732541>,
    <0.5416757, -167.4256532>,
    <0.5277778, -167.4256532>,
    <0.5416360, -167.4968970>,
    <0.5436953, -167.4464590>,
    <0.5338597, -167.4256532>,
    <0.5338349, -167.4567920>,
    <0.5436720, -167.4865678>,
    <0.5497609, -167.5086990>,
    <0.5462963, -167.4732541>,
    <0.5416360, -167.4968970>,
    <0.5555556, -167.5684558>,
    <0.5555556, -167.4961890>,
    <0.5436720, -167.4865678>,
    <0.5494585, -167.5371117>,
    <0.5555556, -167.5369298>,
    <0.5515007, -167.4861453>,
    <0.5497708, -167.4551874>,
    <0.5462963, -167.4732541>,
    <0.5555556, -167.4961890>,
    <0.5555556, -167.4256532>,
    <0.5416757, -167.4256532>,
    <0.5515007, -167.4861453>,
    <0.5555556, -167.4566011>,
    <0.5494830, -167.4256532>,
    <0.5436953, -167.4464590>,
    <0.4423967, -167.1106496>,
    <0.4432078, -167.1123151>,
    <0.4422023, -167.1040945>,
    <0.4407346, -167.1040945>,
    <0.4434422, -167.1220942>,
    <0.4426327, -167.1076129>,
    <0.4413773, -167.1040945>,
    <0.4421942, -167.1137978>,
    <0.4433590, -167.1186210>,
    <0.4438847, -167.1197228>,
    <0.4432078, -167.1123151>,
    <0.4434422, -167.1220942>,
    <0.4444444, -167.1287564>,
    <0.4444444, -167.1157255>,
    <0.4433590, -167.1186210>,
    <0.4441597, -167.1268636>,
    <0.4444444, -167.1243285>,
    <0.4439494, -167.1143604>,
    <0.4435748, -167.1090574>,
    <0.4432078, -167.1123151>,
    <0.4444444, -167.1157255>,
    <0.4444444, -167.1040945>,
    <0.4422023, -167.1040945>,
    <0.4439494, -167.1143604>,
    <0.4444444, -167.1077202>,
    <0.4432540, -167.1040945>,
    <0.4426327, -167.1076129>,
    <0.5572004, -167.1101298>,
    <0.5565078, -167.1123215>,
    <0.5565732, -167.1199778>,
    <0.5584122, -167.1041136>,
    <0.5573085, -167.1041062>,
    <0.5565485, -167.1170881>,
    <0.5574854, -167.1121087>,
    <0.5579336, -167.1041104>,
    <0.5569637, -167.1076438>,
    <0.5562318, -167.1098063>,
    <0.5565078, -167.1123215>,
    <0.5573085, -167.1041062>,
    <0.5555556, -167.1040945>,
    <0.5555556, -167.1187029>,
    <0.5569637, -167.1076438>,
    <0.5564920, -167.1041008>,
    <0.5555556, -167.1075984>,
    <0.5559047, -167.1163632>,
    <0.5560480, -167.1199397>,
    <0.5565078, -167.1123215>,
    <0.5555556, -167.1187029>,
    <0.5555556, -167.1287564>,
    <0.5565732, -167.1199778>,
    <0.5559047, -167.1163632>,
    <0.5555556, -167.1268397>,
    <0.5558991, -167.1257931>,
    <0.5565485, -167.1170881>,
    <0.4780016, -167.4848985>,
    <0.4814815, -167.5208549>,
    <0.4860805, -167.4968970>,
    <0.4722222, -167.4256532>,
    <0.4722222, -167.4961890>,
    <0.4840700, -167.5073705>,
    <0.4782793, -167.4567920>,
    <0.4722222, -167.4566011>,
    <0.4762727, -167.5069791>,
    <0.4780110, -167.5384889>,
    <0.4814815, -167.5208549>,
    <0.4722222, -167.4961890>,
    <0.4722222, -167.5684558>,
    <0.4861182, -167.5684558>,
    <0.4762727, -167.5069791>,
    <0.4722222, -167.5369298>,
    <0.4783031, -167.5684558>,
    <0.4840917, -167.5476517>,
    <0.4884200, -167.5386659>,
    <0.4814815, -167.5208549>,
    <0.4861182, -167.5684558>,
    <0.5000000, -167.5684558>,
    <0.4860805, -167.4968970>,
    <0.4840917, -167.5476517>,
    <0.4939265, -167.5684558>,
    <0.4939030, -167.5371117>,
    <0.4840700, -167.5073705>,
    <0.4837925, -167.6013336>,
    <0.4907407, -167.6211112>,
    <0.4861182, -167.5684558>,
    <0.4722222, -167.5684558>,
    <0.4860887, -167.6473117>,
    <0.4881388, -167.5914725>,
    <0.4783031, -167.5684558>,
    <0.4782847, -167.6029317>,
    <0.4881213, -167.6358644>,
    <0.4942074, -167.6604338>,
    <0.4907407, -167.6211112>,
    <0.4860887, -167.6473117>,
    <0.5000000, -167.7264218>,
    <0.5000000, -167.6468904>,
    <0.4881213, -167.6358644>,
    <0.4939084, -167.6917804>,
    <0.5000000, -167.6917086>,
    <0.4959457, -167.6356026>,
    <0.4942147, -167.6012283>,
    <0.4907407, -167.6211112>,
    <0.5000000, -167.6468904>,
    <0.5000000, -167.5684558>,
    <0.4861182, -167.5684558>,
    <0.4959457, -167.6356026>,
    <0.5000000, -167.6028579>,
    <0.4939265, -167.5684558>,
    <0.4881388, -167.5914725>,
    <0.5057814, -167.6341061>,
    <0.5092593, -167.6737665>,
    <0.5138665, -167.6473117>,
    <0.5000000, -167.5684558>,
    <0.5000000, -167.6468904>,
    <0.5118526, -167.6588757>,
    <0.5060625, -167.6029317>,
    <0.5000000, -167.6028579>,
    <0.5040510, -167.6586490>,
    <0.5057883, -167.6933751>,
    <0.5092593, -167.6737665>,
    <0.5000000, -167.6468904>,
    <0.5000000, -167.7264218>,
    <0.5138938, -167.7264218>,
    <0.5040510, -167.6586490>,
    <0.5000000, -167.6917086>,
    <0.5060797, -167.7264218>,
    <0.5118683, -167.7034090>,
    <0.5161993, -167.6934805>,
    <0.5092593, -167.6737665>,
    <0.5138938, -167.7264218>,
    <0.5277778, -167.7264218>,
    <0.5138665, -167.6473117>,
    <0.5118683, -167.7034090>,
    <0.5217031, -167.7264218>,
    <0.5216862, -167.6917804>,
    <0.5118526, -167.6588757>,
    <0.5115703, -167.6013336>,
    <0.5185185, -167.6211112>,
    <0.5138960, -167.5684558>,
    <0.5000000, -167.5684558>,
    <0.5138665, -167.6473117>,
    <0.5159166, -167.5914725>,
    <0.5060809, -167.5684558>,
    <0.5060625, -167.6029317>,
    <0.5158990, -167.6358644>,
    <0.5219852, -167.6604338>,
    <0.5185185, -167.6211112>,
    <0.5138665, -167.6473117>,
    <0.5277778, -167.7264218>,
    <0.5277778, -167.6468904>,
    <0.5158990, -167.6358644>,
    <0.5216862, -167.6917804>,
    <0.5277778, -167.6917086>,
    <0.5237235, -167.6356026>,
    <0.5219925, -167.6012283>,
    <0.5185185, -167.6211112>,
    <0.5277778, -167.6468904>,
    <0.5277778, -167.5684558>,
    <0.5138960, -167.5684558>,
    <0.5237235, -167.6356026>,
    <0.5277778, -167.6028580>,
    <0.5217042, -167.5684558>,
    <0.5159166, -167.5914725>,
    <0.4501465, -167.1603700>,
    <0.4537037, -167.1891429>,
    <0.4444444, -167.1670444>,
    <0.4444444, -167.1158246>,
    <0.4579936, -167.1694682>,
    <0.4484973, -167.1767170>,
    <0.4444444, -167.1357720>,
    <0.4501656, -167.1384757>,
    <0.4561210, -167.1780564>,
    <0.4605661, -167.2025537>,
    <0.4537037, -167.1891429>,
    <0.4579936, -167.1694682>,
    <0.4722222, -167.2258020>,
    <0.4583451, -167.2258020>,
    <0.4561210, -167.1780564>,
    <0.4659537, -167.2009838>,
    <0.4661511, -167.2258020>,
    <0.4563073, -167.2097072>,
    <0.4502344, -167.2019478>,
    <0.4537037, -167.1891429>,
    <0.4583451, -167.2258020>,
    <0.4444444, -167.2258020>,
    <0.4444444, -167.1670444>,
    <0.4563073, -167.2097072>,
    <0.4505278, -167.2258020>,
    <0.4444444, -167.2000293>,
    <0.4484973, -167.1767170>,
    <0.4560110, -167.2539957>,
    <0.4629630, -167.2709932>,
    <0.4582917, -167.2933857>,
    <0.4444444, -167.2258020>,
    <0.4583451, -167.2258020>,
    <0.4603323, -167.2836036>,
    <0.4504944, -167.2553296>,
    <0.4505278, -167.2258020>,
    <0.4603634, -167.2455535>,
    <0.4664381, -167.2537633>,
    <0.4629630, -167.2709932>,
    <0.4583451, -167.2258020>,
    <0.4722222, -167.2258020>,
    <0.4722222, -167.2924560>,
    <0.4603634, -167.2455535>,
    <0.4661511, -167.2258020>,
    <0.4722222, -167.2550533>,
    <0.4681666, -167.2830552>,
    <0.4664248, -167.3045527>,
    <0.4629630, -167.2709932>,
    <0.4722222, -167.2924560>,
    <0.4722222, -167.3613758>,
    <0.4582917, -167.2933857>,
    <0.4681666, -167.2830552>,
    <0.4722222, -167.3313235>,
    <0.4661180, -167.3315832>,
    <0.4603323, -167.2836036>,
    <0.5335544, -167.2819570>,
    <0.5370370, -167.3161845>,
    <0.5277778, -167.2924560>,
    <0.5277778, -167.2258020>,
    <0.5416250, -167.2933857>,
    <0.5318274, -167.3028339>,
    <0.5277778, -167.2550533>,
    <0.5338277, -167.2553296>,
    <0.5396191, -167.3033535>,
    <0.5439736, -167.3330804>,
    <0.5370370, -167.3161845>,
    <0.5416250, -167.2933857>,
    <0.5555556, -167.3613758>,
    <0.5416767, -167.3613758>,
    <0.5396191, -167.3033535>,
    <0.5494513, -167.3315832>,
    <0.5494835, -167.3613758>,
    <0.5396489, -167.3416247>,
    <0.5335673, -167.3328480>,
    <0.5370370, -167.3161845>,
    <0.5416767, -167.3613758>,
    <0.5277778, -167.3613758>,
    <0.5277778, -167.2924560>,
    <0.5396489, -167.3416247>,
    <0.5338602, -167.3613758>,
    <0.5277778, -167.3313235>,
    <0.5318274, -167.3028339>,
    <0.5393444, -167.2539957>,
    <0.5462963, -167.2709932>,
    <0.5416250, -167.2933857>,
    <0.5277778, -167.2258020>,
    <0.5416784, -167.2258020>,
    <0.5436657, -167.2836036>,
    <0.5338277, -167.2553296>,
    <0.5338611, -167.2258020>,
    <0.5436967, -167.2455535>,
    <0.5497715, -167.2537633>,
    <0.5462963, -167.2709932>,
    <0.5416784, -167.2258020>,
    <0.5555556, -167.2258020>,
    <0.5555556, -167.2924560>,
    <0.5436967, -167.2455535>,
    <0.5494844, -167.2258020>,
    <0.5555556, -167.2550533>,
    <0.5514999, -167.2830552>,
    <0.5497581, -167.3045527>,
    <0.5462963, -167.2709932>,
    <0.5555556, -167.2924560>,
    <0.5555556, -167.3613758>,
    <0.5416250, -167.2933857>,
    <0.5514999, -167.2830552>,
    <0.5555556, -167.3313235>,
    <0.5494513, -167.3315832>,
    <0.5436657, -167.2836036>,
    <0.4779988, -167.2819570>,
    <0.4814815, -167.3161845>,
    <0.4722222, -167.2924560>,
    <0.4722222, -167.2258020>,
    <0.4860695, -167.2933857>,
    <0.4762719, -167.3028339>,
    <0.4722222, -167.2550533>,
    <0.4782722, -167.2553296>,
    <0.4840636, -167.3033535>,
    <0.4884180, -167.3330804>,
    <0.4814815, -167.3161845>,
    <0.4860695, -167.2933857>,
    <0.5000000, -167.3613758>,
    <0.4861211, -167.3613758>,
    <0.4840636, -167.3033535>,
    <0.4938958, -167.3315832>,
    <0.4939280, -167.3613758>,
    <0.4840933, -167.3416247>,
    <0.4780118, -167.3328480>,
    <0.4814815, -167.3161845>,
    <0.4861211, -167.3613758>,
    <0.4722222, -167.3613758>,
    <0.4722222, -167.2924560>,
    <0.4840933, -167.3416247>,
    <0.4783046, -167.3613758>,
    <0.4722222, -167.3313235>,
    <0.4762719, -167.3028339>,
    <0.4837905, -167.3940515>,
    <0.4907407, -167.4137323>,
    <0.4860778, -167.4397221>,
    <0.4722222, -167.3613758>,
    <0.4861211, -167.3613758>,
    <0.4881148, -167.4283682>,
    <0.4782775, -167.3956156>,
    <0.4783046, -167.3613758>,
    <0.4881405, -167.3842624>,
    <0.4942155, -167.3939086>,
    <0.4907407, -167.4137323>,
    <0.4861211, -167.3613758>,
    <0.5000000, -167.3613758>,
    <0.5000000, -167.4391507>,
    <0.4881405, -167.3842624>,
    <0.4939280, -167.3613758>,
    <0.5000000, -167.3955180>,
    <0.4959449, -167.4280187>,
    <0.4942046, -167.4527626>,
    <0.4907407, -167.4137323>,
    <0.5000000, -167.4391507>,
    <0.5000000, -167.5184453>,
    <0.4860778, -167.4397221>,
    <0.4959449, -167.4280187>,
    <0.5000000, -167.4838674>,
    <0.4939013, -167.4839601>,
    <0.4881148, -167.4283682>,
    <0.5057787, -167.4265843>,
    <0.5092593, -167.4660888>,
    <0.5000000, -167.4391507>,
    <0.5000000, -167.3613758>,
    <0.5138556, -167.4397221>,
    <0.5040502, -167.4509341>,
    <0.5000000, -167.3955180>,
    <0.5060553, -167.3956156>,
    <0.5118462, -167.4512490>,
    <0.5161973, -167.4856754>,
    <0.5092593, -167.4660888>,
    <0.5138556, -167.4397221>,
    <0.5277778, -167.5184453>,
    <0.5138967, -167.5184453>,
    <0.5118462, -167.4512490>,
    <0.5216791, -167.4839601>,
    <0.5217047, -167.5184453>,
    <0.5118700, -167.4955641>,
    <0.5057890, -167.4855325>,
    <0.5092593, -167.4660888>,
    <0.5138967, -167.5184453>,
    <0.5000000, -167.5184453>,
    <0.5000000, -167.4391507>,
    <0.5118700, -167.4955641>,
    <0.5060813, -167.5184453>,
    <0.5000000, -167.4838674>,
    <0.5040502, -167.4509341>,
    <0.5115682, -167.3940515>,
    <0.5185185, -167.4137323>,
    <0.5138556, -167.4397221>,
    <0.5000000, -167.3613758>,
    <0.5138989, -167.3613758>,
    <0.5158926, -167.4283682>,
    <0.5060553, -167.3956156>,
    <0.5060824, -167.3613758>,
    <0.5159183, -167.3842624>,
    <0.5219932, -167.3939086>,
    <0.5185185, -167.4137323>,
    <0.5138989, -167.3613758>,
    <0.5277778, -167.3613758>,
    <0.5277778, -167.4391507>,
    <0.5159183, -167.3842624>,
    <0.5217057, -167.3613758>,
    <0.5277778, -167.3955180>,
    <0.5237227, -167.4280187>,
    <0.5219824, -167.4527626>,
    <0.5185185, -167.4137323>,
    <0.5277778, -167.4391507>,
    <0.5277778, -167.5184453>,
    <0.5138556, -167.4397221>,
    <0.5237227, -167.4280187>,
    <0.5277778, -167.4838674>,
    <0.5216791, -167.4839601>,
    <0.5158926, -167.4283682>,
    <0.4502203, -167.2436308>,
    <0.4537037, -167.2690732>,
    <0.4582886, -167.2522483>,
    <0.4444444, -167.2024179>,
    <0.4444444, -167.2507837>,
    <0.4562840, -167.2596042>,
    <0.4504924, -167.2241867>,
    <0.4444444, -167.2235884>,
    <0.4484939, -167.2587824>,
    <0.4502341, -167.2811646>,
    <0.4537037, -167.2690732>,
    <0.4444444, -167.2507837>,
    <0.4444444, -167.3024008>,
    <0.4583439, -167.3024008>,
    <0.4484939, -167.2587824>,
    <0.4444444, -167.2798504>,
    <0.4505272, -167.3024008>,
    <0.4563155, -167.2878319>,
    <0.4606396, -167.2815307>,
    <0.4537037, -167.2690732>,
    <0.4583439, -167.3024008>,
    <0.4722222, -167.3024008>,
    <0.4582886, -167.2522483>,
    <0.4563155, -167.2878319>,
    <0.4661505, -167.3024008>,
    <0.4661158, -167.2804214>,
    <0.4562840, -167.2596042>,
    <0.4560116, -167.3280360>,
    <0.4629630, -167.3434849>,
    <0.4583439, -167.3024008>,
    <0.4444444, -167.3024008>,
    <0.4582951, -167.3638575>,
    <0.4603626, -167.3203558>,
    <0.4505272, -167.3024008>,
    <0.4504966, -167.3292549>,
    <0.4603344, -167.3549573>,
    <0.4664256, -167.3739447>,
    <0.4629630, -167.3434849>,
    <0.4582951, -167.3638575>,
    <0.4722222, -167.4256532>,
    <0.4722222, -167.3627833>,
    <0.4603344, -167.3549573>,
    <0.4661202, -167.3985780>,
    <0.4722222, -167.3982231>,
    <0.4681669, -167.3543311>,
    <0.4664378, -167.3277674>,
    <0.4629630, -167.3434849>,
    <0.4722222, -167.3627833>,
    <0.4722222, -167.3024008>,
    <0.4583439, -167.3024008>,
    <0.4681669, -167.3543311>,
    <0.4722222, -167.3288803>,
    <0.4661505, -167.3024008>,
    <0.4603626, -167.3203558>,
    <0.5335553, -167.3534027>,
    <0.5370370, -167.3845690>,
    <0.5416285, -167.3638575>,
    <0.5277778, -167.3024008>,
    <0.5277778, -167.3627833>,
    <0.5396212, -167.3729124>,
    <0.5338300, -167.3292549>,
    <0.5277778, -167.3288803>,
    <0.5318277, -167.3723121>,
    <0.5335671, -167.3996647>,
    <0.5370370, -167.3845690>,
    <0.5277778, -167.3627833>,
    <0.5277778, -167.4256532>,
    <0.5416757, -167.4256532>,
    <0.5318277, -167.3723121>,
    <0.5277778, -167.3982231>,
    <0.5338597, -167.4256532>,
    <0.5396482, -167.4076960>,
    <0.5439742, -167.3999332>,
    <0.5370370, -167.3845690>,
    <0.5416757, -167.4256532>,
    <0.5555556, -167.4256532>,
    <0.5416285, -167.3638575>,
    <0.5396482, -167.4076960>,
    <0.5494830, -167.4256532>,
    <0.5494535, -167.3985780>,
    <0.5396212, -167.3729124>,
    <0.5393450, -167.3280360>,
    <0.5462963, -167.3434849>,
    <0.5416773, -167.3024008>,
    <0.5277778, -167.3024008>,
    <0.5416285, -167.3638575>,
    <0.5436959, -167.3203558>,
    <0.5338606, -167.3024008>,
    <0.5338300, -167.3292549>,
    <0.5436677, -167.3549573>,
    <0.5497590, -167.3739447>,
    <0.5462963, -167.3434849>,
    <0.5416285, -167.3638575>,
    <0.5555556, -167.4256532>,
    <0.5555556, -167.3627833>,
    <0.5436677, -167.3549573>,
    <0.5494535, -167.3985780>,
    <0.5555556, -167.3982231>,
    <0.5515002, -167.3543311>,
    <0.5497712, -167.3277674>,
    <0.5462963, -167.3434849>,
    <0.5555556, -167.3627833>,
    <0.5555556, -167.3024008>,
    <0.5416773, -167.3024008>,
    <0.5515002, -167.3543311>,
    <0.5555556, -167.3288803>,
    <0.5494838, -167.3024008>,
    <0.5436959, -167.3203558>,
    <0.5462827, -167.0791031>,
    <0.5501016, -167.0842391>,
    <0.5484609, -167.0952809>,
    <0.5391937, -167.0684463>,
    <0.5473746, -167.0684463>,
    <0.5491173, -167.0908631>,
    <0.5436378, -167.0813149>,
    <0.5432842, -167.0684463>,
    <0.5485572, -167.0752947>,
    <0.5521468, -167.0791459>,
    <0.5501016, -167.0842391>,
    <0.5473746, -167.0684463>,
    <0.5555556, -167.0684463>,
    <0.5555556, -167.0954519>,
    <0.5485572, -167.0752947>,
    <0.5514651, -167.0684463>,
    <0.5555556, -167.0825221>,
    <0.5532389, -167.0906890>,
    <0.5524184, -167.0976991>,
    <0.5501016, -167.0842391>,
    <0.5555556, -167.0954519>,
    <0.5555556, -167.1158246>,
    <0.5484609, -167.0952809>,
    <0.5532389, -167.0906890>,
    <0.5555556, -167.1101311>,
    <0.5527509, -167.1077032>,
    <0.5491173, -167.0908631>,
    <0.4779997, -167.3534027>,
    <0.4814815, -167.3845690>,
    <0.4860729, -167.3638575>,
    <0.4722222, -167.3024008>,
    <0.4722222, -167.3627833>,
    <0.4840656, -167.3729124>,
    <0.4782744, -167.3292549>,
    <0.4722222, -167.3288803>,
    <0.4762721, -167.3723121>,
    <0.4780115, -167.3996647>,
    <0.4814815, -167.3845690>,
    <0.4722222, -167.3627833>,
    <0.4722222, -167.4256532>,
    <0.4861201, -167.4256532>,
    <0.4762721, -167.3723121>,
    <0.4722222, -167.3982231>,
    <0.4783041, -167.4256532>,
    <0.4840926, -167.4076960>,
    <0.4884186, -167.3999332>,
    <0.4814815, -167.3845690>,
    <0.4861201, -167.4256532>,
    <0.5000000, -167.4256532>,
    <0.4860729, -167.3638575>,
    <0.4840926, -167.4076960>,
    <0.4939274, -167.4256532>,
    <0.4938980, -167.3985780>,
    <0.4840656, -167.3729124>,
    <0.4837909, -167.4553644>,
    <0.4907407, -167.4732541>,
    <0.4861201, -167.4256532>,
    <0.4722222, -167.4256532>,
    <0.4860805, -167.4968970>,
    <0.4881397, -167.4464590>,
    <0.4783041, -167.4256532>,
    <0.4782793, -167.4567920>,
    <0.4881165, -167.4865678>,
    <0.4942053, -167.5086990>,
    <0.4907407, -167.4732541>,
    <0.4860805, -167.4968970>,
    <0.5000000, -167.5684558>,
    <0.5000000, -167.4961890>,
    <0.4881165, -167.4865678>,
    <0.4939030, -167.5371117>,
    <0.5000000, -167.5369298>,
    <0.4959451, -167.4861453>,
    <0.4942152, -167.4551874>,
    <0.4907407, -167.4732541>,
    <0.5000000, -167.4961890>,
    <0.5000000, -167.4256532>,
    <0.4861201, -167.4256532>,
    <0.4959451, -167.4861453>,
    <0.5000000, -167.4566011>,
    <0.4939274, -167.4256532>,
    <0.4881397, -167.4464590>,
    <0.5057794, -167.4848985>,
    <0.5092593, -167.5208549>,
    <0.5138583, -167.4968970>,
    <0.5000000, -167.4256532>,
    <0.5000000, -167.4961890>,
    <0.5118478, -167.5073705>,
    <0.5060571, -167.4567920>,
    <0.5000000, -167.4566011>,
    <0.5040504, -167.5069791>,
    <0.5057888, -167.5384889>,
    <0.5092593, -167.5208549>,
    <0.5000000, -167.4961890>,
    <0.5000000, -167.5684558>,
    <0.5138960, -167.5684558>,
    <0.5040504, -167.5069791>,
    <0.5000000, -167.5369298>,
    <0.5060809, -167.5684558>,
    <0.5118695, -167.5476517>,
    <0.5161978, -167.5386659>,
    <0.5092593, -167.5208549>,
    <0.5138960, -167.5684558>,
    <0.5277778, -167.5684558>,
    <0.5138583, -167.4968970>,
    <0.5118695, -167.5476517>,
    <0.5217042, -167.5684558>,
    <0.5216808, -167.5371117>,
    <0.5118478, -167.5073705>,
    <0.5115687, -167.4553644>,
    <0.5185185, -167.4732541>,
    <0.5138979, -167.4256532>,
    <0.5000000, -167.4256532>,
    <0.5138583, -167.4968970>,
    <0.5159175, -167.4464590>,
    <0.5060819, -167.4256532>,
    <0.5060571, -167.4567920>,
    <0.5158943, -167.4865678>,
    <0.5219831, -167.5086990>,
    <0.5185185, -167.4732541>,
    <0.5138583, -167.4968970>,
    <0.5277778, -167.5684558>,
    <0.5277778, -167.4961890>,
    <0.5158943, -167.4865678>,
    <0.5216808, -167.5371117>,
    <0.5277778, -167.5369297>,
    <0.5237229, -167.4861453>,
    <0.5219930, -167.4551874>,
    <0.5185185, -167.4732541>,
    <0.5277778, -167.4961890>,
    <0.5277778, -167.4256532>,
    <0.5138979, -167.4256532>,
    <0.5237229, -167.4861453>,
    <0.5277778, -167.4566011>,
    <0.5217052, -167.4256532>,
    <0.5159175, -167.4464590>,
    <0.4837888, -167.2539957>,
    <0.4907407, -167.2709932>,
    <0.4860695, -167.2933857>,
    <0.4722222, -167.2258020>,
    <0.4861228, -167.2258020>,
    <0.4881101, -167.2836036>,
    <0.4782722, -167.2553296>,
    <0.4783056, -167.2258020>,
    <0.4881412, -167.2455535>,
    <0.4942159, -167.2537633>,
    <0.4907407, -167.2709932>,
    <0.4861228, -167.2258020>,
    <0.5000000, -167.2258020>,
    <0.5000000, -167.2924560>,
    <0.4881412, -167.2455535>,
    <0.4939288, -167.2258020>,
    <0.5000000, -167.2550533>,
    <0.4959444, -167.2830552>,
    <0.4942026, -167.3045527>,
    <0.4907407, -167.2709932>,
    <0.5000000, -167.2924560>,
    <0.5000000, -167.3613758>,
    <0.4860695, -167.2933857>,
    <0.4959444, -167.2830552>,
    <0.5000000, -167.3313235>,
    <0.4938958, -167.3315832>,
    <0.4881101, -167.2836036>,
    <0.5057766, -167.2819570>,
    <0.5092593, -167.3161845>,
    <0.5000000, -167.2924560>,
    <0.5000000, -167.2258020>,
    <0.5138473, -167.2933857>,
    <0.5040496, -167.3028339>,
    <0.5000000, -167.2550533>,
    <0.5060499, -167.2553296>,
    <0.5118413, -167.3033535>,
    <0.5161958, -167.3330804>,
    <0.5092593, -167.3161845>,
    <0.5138473, -167.2933857>,
    <0.5277778, -167.3613758>,
    <0.5138989, -167.3613758>,
    <0.5118413, -167.3033535>,
    <0.5216736, -167.3315832>,
    <0.5217057, -167.3613758>,
    <0.5118711, -167.3416247>,
    <0.5057895, -167.3328480>,
    <0.5092593, -167.3161845>,
    <0.5138989, -167.3613758>,
    <0.5000000, -167.3613758>,
    <0.5000000, -167.2924560>,
    <0.5118711, -167.3416247>,
    <0.5060824, -167.3613758>,
    <0.5000000, -167.3313235>,
    <0.5040496, -167.3028339>,
    <0.5115666, -167.2539957>,
    <0.5185185, -167.2709932>,
    <0.5138473, -167.2933857>,
    <0.5000000, -167.2258020>,
    <0.5139006, -167.2258020>,
    <0.5158879, -167.2836036>,
    <0.5060499, -167.2553296>,
    <0.5060834, -167.2258020>,
    <0.5159189, -167.2455535>,
    <0.5219937, -167.2537633>,
    <0.5185185, -167.2709932>,
    <0.5139006, -167.2258020>,
    <0.5277778, -167.2258020>,
    <0.5277778, -167.2924560>,
    <0.5159189, -167.2455535>,
    <0.5217066, -167.2258020>,
    <0.5277778, -167.2550533>,
    <0.5237222, -167.2830552>,
    <0.5219803, -167.3045527>,
    <0.5185185, -167.2709932>,
    <0.5277778, -167.2924560>,
    <0.5277778, -167.3613758>,
    <0.5138473, -167.2933857>,
    <0.5237222, -167.2830552>,
    <0.5277778, -167.3313235>,
    <0.5216736, -167.3315832>,
    <0.5158879, -167.2836036>,
    <0.4515561, -167.0912293>,
    <0.4537037, -167.1000319>,
    <0.4444444, -167.0952665>,
    <0.4444444, -167.0684463>,
    <0.4636317, -167.1011725>,
    <0.4484347, -167.0973201>,
    <0.4444444, -167.0823113>,
    <0.4560465, -167.0882350>,
    <0.4585927, -167.1005936>,
    <0.4618284, -167.1082134>,
    <0.4537037, -167.1000319>,
    <0.4636317, -167.1011725>,
    <0.4722222, -167.1158246>,
    <0.4577558, -167.1158246>,
    <0.4585927, -167.1005936>,
    <0.4687731, -167.1099418>,
    <0.4659690, -167.1158246>,
    <0.4558647, -167.1084543>,
    <0.4500871, -167.1067369>,
    <0.4537037, -167.1000319>,
    <0.4577558, -167.1158246>,
    <0.4444444, -167.1158246>,
    <0.4444444, -167.0952665>,
    <0.4558647, -167.1084543>,
    <0.4499344, -167.1158246>,
    <0.4444444, -167.1100137>,
    <0.4484347, -167.0973201>,
    <0.4539344, -167.0805760>,
    <0.4575090, -167.0842391>,
    <0.4636317, -167.1011725>,
    <0.4444444, -167.0684463>,
    <0.4501524, -167.0684463>,
    <0.4615130, -167.0953127>,
    <0.4560465, -167.0882350>,
    <0.4472984, -167.0684463>,
    <0.4531053, -167.0747854>,
    <0.4571771, -167.0791459>,
    <0.4575090, -167.0842391>,
    <0.4501524, -167.0684463>,
    <0.4558604, -167.0684463>,
    <0.4651866, -167.0954520>,
    <0.4531053, -167.0747854>,
    <0.4530064, -167.0684463>,
    <0.4603564, -167.0814651>,
    <0.4613645, -167.0898698>,
    <0.4646374, -167.0991721>,
    <0.4575090, -167.0842391>,
    <0.4651866, -167.0954520>,
    <0.4722222, -167.1158246>,
    <0.4636317, -167.1011725>,
    <0.4613645, -167.0898698>,
    <0.4694513, -167.1078010>,
    <0.4687731, -167.1099418>,
    <0.4615130, -167.0953127>,
    <0.4557892, -167.1384003>,
    <0.4629630, -167.1524837>,
    <0.4579936, -167.1694682>,
    <0.4444444, -167.1158246>,
    <0.4577558, -167.1158246>,
    <0.4601586, -167.1620687>,
    <0.4501656, -167.1384757>,
    <0.4499344, -167.1158246>,
    <0.4600115, -167.1317048>,
    <0.4662908, -167.1378238>,
    <0.4629630, -167.1524837>,
    <0.4577558, -167.1158246>,
    <0.4722222, -167.1158246>,
    <0.4722222, -167.1671622>,
    <0.4600115, -167.1317048>,
    <0.4659690, -167.1158246>,
    <0.4722222, -167.1358716>,
    <0.4681607, -167.1607236>,
    <0.4663502, -167.1787290>,
    <0.4629630, -167.1524837>,
    <0.4722222, -167.1671622>,
    <0.4722222, -167.2258020>,
    <0.4579936, -167.1694682>,
    <0.4681607, -167.1607236>,
    <0.4722222, -167.2000928>,
    <0.4659537, -167.2009838>,
    <0.4601586, -167.1620687>,
    <0.4779251, -167.1604025>,
    <0.4814815, -167.1891429>,
    <0.4722222, -167.1671622>,
    <0.4722222, -167.1158246>,
    <0.4857744, -167.1694803>,
    <0.4762750, -167.1767831>,
    <0.4722222, -167.1358716>,
    <0.4779461, -167.1384865>,
    <0.4839005, -167.1780633>,
    <0.4883447, -167.2025568>,
    <0.4814815, -167.1891429>,
    <0.4857744, -167.1694803>,
    <0.5000000, -167.2258020>,
    <0.4861228, -167.2258020>,
    <0.4839005, -167.1780633>,
    <0.4937332, -167.2009905>,
    <0.4939288, -167.2258020>,
    <0.4840852, -167.2097081>,
    <0.4780122, -167.2019772>,
    <0.4814815, -167.1891429>,
    <0.4861228, -167.2258020>,
    <0.4722222, -167.2258020>,
    <0.4722222, -167.1671622>,
    <0.4840852, -167.2097081>,
    <0.4783056, -167.2258020>,
    <0.4722222, -167.2000928>,
    <0.4762750, -167.1767831>,
    <0.5334777, -167.1602961>,
    <0.5370370, -167.1891429>,
    <0.5277778, -167.1667832>,
    <0.5277778, -167.1158246>,
    <0.5413182, -167.1694338>,
    <0.5318307, -167.1765704>,
    <0.5277778, -167.1355291>,
    <0.5334912, -167.1384453>,
    <0.5394495, -167.1780367>,
    <0.5438973, -167.2025451>,
    <0.5370370, -167.1891429>,
    <0.5413182, -167.1694338>,
    <0.5555556, -167.2258020>,
    <0.5416784, -167.2258020>,
    <0.5394495, -167.1780367>,
    <0.5492822, -167.2009644>,
    <0.5494844, -167.2258020>,
    <0.5396404, -167.2097049>,
    <0.5335678, -167.2018825>,
    <0.5370370, -167.1891429>,
    <0.5416784, -167.2258020>,
    <0.5277778, -167.2258020>,
    <0.5277778, -167.1667832>,
    <0.5396404, -167.2097049>,
    <0.5338611, -167.2258020>,
    <0.5277778, -167.1998918>,
    <0.5318307, -167.1765704>,
    <0.5391175, -167.1383917>,
    <0.5462963, -167.1524837>,
    <0.5413182, -167.1694338>,
    <0.5277778, -167.1158246>,
    <0.5410776, -167.1158246>,
    <0.5434869, -167.1620496>,
    <0.5334912, -167.1384453>,
    <0.5332617, -167.1158246>,
    <0.5433371, -167.1316964>,
    <0.5496212, -167.1377779>,
    <0.5462963, -167.1524837>,
    <0.5410776, -167.1158246>,
    <0.5555556, -167.1158246>,
    <0.5555556, -167.1669784>,
    <0.5433371, -167.1316964>,
    <0.5492951, -167.1158246>,
    <0.5555556, -167.1357215>,
    <0.5514937, -167.1606199>,
    <0.5496814, -167.1786745>,
    <0.5462963, -167.1524837>,
    <0.5555556, -167.1669784>,
    <0.5555556, -167.2258020>,
    <0.5413182, -167.1694338>,
    <0.5514937, -167.1606199>,
    <0.5555556, -167.1999914>,
    <0.5492822, -167.2009644>,
    <0.5434869, -167.1620496>,
    <0.4508647, -167.1109029>,
    <0.4486044, -167.1123151>,
    <0.4473031, -167.1231073>,
    <0.4569243, -167.1040945>,
    <0.4506269, -167.1040945>,
    <0.4478040, -167.1189533>,
    <0.4507965, -167.1162039>,
    <0.4537536, -167.1040945>,
    <0.4499538, -167.1068303>,
    <0.4470300, -167.1090574>,
    <0.4486044, -167.1123151>,
    <0.4506269, -167.1040945>,
    <0.4444444, -167.1040945>,
    <0.4444444, -167.1157255>,
    <0.4499538, -167.1068303>,
    <0.4475286, -167.1040945>,
    <0.4444444, -167.1077202>,
    <0.4465446, -167.1140038>,
    <0.4461991, -167.1199761>,
    <0.4486044, -167.1123151>,
    <0.4444444, -167.1157255>,
    <0.4444444, -167.1287564>,
    <0.4473031, -167.1231073>,
    <0.4465446, -167.1140038>,
    <0.4444444, -167.1243285>,
    <0.4454825, -167.1267051>,
    <0.4478040, -167.1189533>,
    <0.4502912, -167.1583892>,
    <0.4537037, -167.1778641>,
    <0.4585723, -167.1662209>,
    <0.4444444, -167.1287564>,
    <0.4444444, -167.1607154>,
    <0.4564510, -167.1712941>,
    <0.4507016, -167.1453492>,
    <0.4444444, -167.1413914>,
    <0.4485012, -167.1682288>,
    <0.4502344, -167.1858539>,
    <0.4537037, -167.1778641>,
    <0.4444444, -167.1607154>,
    <0.4444444, -167.2024179>,
    <0.4583451, -167.2024179>,
    <0.4485012, -167.1682288>,
    <0.4444444, -167.1838308>,
    <0.4505279, -167.2024179>,
    <0.4563240, -167.1917260>,
    <0.4607108, -167.1872302>,
    <0.4537037, -167.1778641>,
    <0.4583451, -167.2024179>,
    <0.4722222, -167.2024179>,
    <0.4585723, -167.1662209>,
    <0.4563240, -167.1917260>,
    <0.4661510, -167.2024179>,
    <0.4662818, -167.1866652>,
    <0.4564510, -167.1712941>,
    <0.4560103, -167.2232074>,
    <0.4629630, -167.2357456>,
    <0.4583451, -167.2024179>,
    <0.4444444, -167.2024179>,
    <0.4582886, -167.2522483>,
    <0.4603629, -167.2169804>,
    <0.4505279, -167.2024179>,
    <0.4504924, -167.2241867>,
    <0.4603307, -167.2450388>,
    <0.4664240, -167.2602946>,
    <0.4629630, -167.2357456>,
    <0.4582886, -167.2522483>,
    <0.4722222, -167.3024008>,
    <0.4722222, -167.2507837>,
    <0.4603307, -167.2450388>,
    <0.4661158, -167.2804214>,
    <0.4722222, -167.2798504>,
    <0.4681665, -167.2441968>,
    <0.4664381, -167.2228413>,
    <0.4629630, -167.2357456>,
    <0.4722222, -167.2507837>,
    <0.4722222, -167.2024179>,
    <0.4583451, -167.2024179>,
    <0.4681665, -167.2441968>,
    <0.4722222, -167.2235884>,
    <0.4661510, -167.2024179>,
    <0.4603629, -167.2169804>,
    <0.5335536, -167.2436308>,
    <0.5370370, -167.2690732>,
    <0.5416219, -167.2522483>,
    <0.5277778, -167.2024179>,
    <0.5277778, -167.2507837>,
    <0.5396174, -167.2596042>,
    <0.5338257, -167.2241867>,
    <0.5277778, -167.2235884>,
    <0.5318272, -167.2587824>,
    <0.5335675, -167.2811646>,
    <0.5370370, -167.2690732>,
    <0.5277778, -167.2507837>,
    <0.5277778, -167.3024008>,
    <0.5416773, -167.3024008>,
    <0.5318272, -167.2587824>,
    <0.5277778, -167.2798504>,
    <0.5338606, -167.3024008>,
    <0.5396488, -167.2878319>,
    <0.5439729, -167.2815307>,
    <0.5370370, -167.2690732>,
    <0.5416773, -167.3024008>,
    <0.5555556, -167.3024008>,
    <0.5416219, -167.2522483>,
    <0.5396488, -167.2878319>,
    <0.5494838, -167.3024008>,
    <0.5494491, -167.2804214>,
    <0.5396174, -167.2596042>,
    <0.5393436, -167.2232074>,
    <0.5462963, -167.2357456>,
    <0.5416785, -167.2024179>,
    <0.5277778, -167.2024179>,
    <0.5416219, -167.2522483>,
    <0.5436962, -167.2169804>,
    <0.5338612, -167.2024179>,
    <0.5338257, -167.2241867>,
    <0.5436640, -167.2450388>,
    <0.5497573, -167.2602946>,
    <0.5462963, -167.2357456>,
    <0.5416219, -167.2522483>,
    <0.5555556, -167.3024008>,
    <0.5555556, -167.2507837>,
    <0.5436640, -167.2450388>,
    <0.5494491, -167.2804214>,
    <0.5555556, -167.2798504>,
    <0.5514999, -167.2441968>,
    <0.5497715, -167.2228413>,
    <0.5462963, -167.2357456>,
    <0.5555556, -167.2507837>,
    <0.5555556, -167.2024179>,
    <0.5416785, -167.2024179>,
    <0.5514999, -167.2441968>,
    <0.5555556, -167.2235884>,
    <0.5494844, -167.2024179>,
    <0.5436962, -167.2169804>,
    <0.4779981, -167.2436308>,
    <0.4814815, -167.2690732>,
    <0.4860664, -167.2522483>,
    <0.4722222, -167.2024179>,
    <0.4722222, -167.2507837>,
    <0.4840618, -167.2596042>,
    <0.4782701, -167.2241867>,
    <0.4722222, -167.2235884>,
    <0.4762716, -167.2587824>,
    <0.4780119, -167.2811646>,
    <0.4814815, -167.2690732>,
    <0.4722222, -167.2507837>,
    <0.4722222, -167.3024008>,
    <0.4861217, -167.3024008>,
    <0.4762716, -167.2587824>,
    <0.4722222, -167.2798504>,
    <0.4783050, -167.3024008>,
    <0.4840933, -167.2878319>,
    <0.4884174, -167.2815307>,
    <0.4814815, -167.2690732>,
    <0.4861217, -167.3024008>,
    <0.5000000, -167.3024008>,
    <0.4860664, -167.2522483>,
    <0.4840933, -167.2878319>,
    <0.4939282, -167.3024008>,
    <0.4938936, -167.2804214>,
    <0.4840618, -167.2596042>,
    <0.4837894, -167.3280360>,
    <0.4907407, -167.3434849>,
    <0.4861217, -167.3024008>,
    <0.4722222, -167.3024008>,
    <0.4860729, -167.3638575>,
    <0.4881404, -167.3203558>,
    <0.4783050, -167.3024008>,
    <0.4782744, -167.3292549>,
    <0.4881122, -167.3549573>,
    <0.4942034, -167.3739447>,
    <0.4907407, -167.3434849>,
    <0.4860729, -167.3638575>,
    <0.5000000, -167.4256532>,
    <0.5000000, -167.3627833>,
    <0.4881122, -167.3549573>,
    <0.4938980, -167.3985780>,
    <0.5000000, -167.3982231>,
    <0.4959447, -167.3543311>,
    <0.4942156, -167.3277674>,
    <0.4907407, -167.3434849>,
    <0.5000000, -167.3627833>,
    <0.5000000, -167.3024008>,
    <0.4861217, -167.3024008>,
    <0.4959447, -167.3543311>,
    <0.5000000, -167.3288803>,
    <0.4939282, -167.3024008>,
    <0.4881404, -167.3203558>,
    <0.5057775, -167.3534027>,
    <0.5092593, -167.3845690>,
    <0.5138507, -167.3638575>,
    <0.5000000, -167.3024008>,
    <0.5000000, -167.3627833>,
    <0.5118434, -167.3729124>,
    <0.5060522, -167.3292549>,
    <0.5000000, -167.3288803>,
    <0.5040499, -167.3723121>,
    <0.5057893, -167.3996647>,
    <0.5092593, -167.3845690>,
    <0.5000000, -167.3627833>,
    <0.5000000, -167.4256532>,
    <0.5138979, -167.4256532>,
    <0.5040499, -167.3723121>,
    <0.5000000, -167.3982231>,
    <0.5060819, -167.4256532>,
    <0.5118704, -167.4076960>,
    <0.5161964, -167.3999332>,
    <0.5092593, -167.3845690>,
    <0.5138979, -167.4256532>,
    <0.5277778, -167.4256532>,
    <0.5138507, -167.3638575>,
    <0.5118704, -167.4076960>,
    <0.5217052, -167.4256532>,
    <0.5216758, -167.3985780>,
    <0.5118434, -167.3729124>,
    <0.5115672, -167.3280360>,
    <0.5185185, -167.3434849>,
    <0.5138995, -167.3024008>,
    <0.5000000, -167.3024008>,
    <0.5138507, -167.3638575>,
    <0.5159181, -167.3203558>,
    <0.5060828, -167.3024008>,
    <0.5060522, -167.3292549>,
    <0.5158899, -167.3549573>,
    <0.5219812, -167.3739447>,
    <0.5185185, -167.3434849>,
    <0.5138507, -167.3638575>,
    <0.5277778, -167.4256532>,
    <0.5277778, -167.3627833>,
    <0.5158899, -167.3549573>,
    <0.5216758, -167.3985780>,
    <0.5277778, -167.3982231>,
    <0.5237225, -167.3543311>,
    <0.5219934, -167.3277674>,
    <0.5185185, -167.3434849>,
    <0.5277778, -167.3627833>,
    <0.5277778, -167.3024008>,
    <0.5138995, -167.3024008>,
    <0.5237225, -167.3543311>,
    <0.5277778, -167.3288803>,
    <0.5217060, -167.3024008>,
    <0.5159181, -167.3203558>,
    <0.5477621, -167.1109046>,
    <0.5504562, -167.1123151>,
    <0.5482787, -167.1040945>,
    <0.5402576, -167.1040945>,
    <0.5520558, -167.1231144>,
    <0.5490592, -167.1070408>,
    <0.5444240, -167.1040945>,
    <0.5479300, -167.1164633>,
    <0.5514189, -167.1188146>,
    <0.5534058, -167.1207222>,
    <0.5504562, -167.1123151>,
    <0.5520558, -167.1231144>,
    <0.5555556, -167.1287564>,
    <0.5555556, -167.1187029>,
    <0.5514189, -167.1188146>,
    <0.5542800, -167.1267000>,
    <0.5555556, -167.1268397>,
    <0.5529639, -167.1154565>,
    <0.5524615, -167.1098018>,
    <0.5504562, -167.1123151>,
    <0.5555556, -167.1187029>,
    <0.5555556, -167.1040945>,
    <0.5482787, -167.1040945>,
    <0.5529639, -167.1154565>,
    <0.5555556, -167.1075984>,
    <0.5519599, -167.1040945>,
    <0.5490592, -167.1070408>,
    <0.4629659, -167.0791459>,
    <0.4667693, -167.0842391>,
    <0.4651880, -167.0954520>,
    <0.4558634, -167.0684463>,
    <0.4640428, -167.0684463>,
    <0.4658198, -167.0909719>,
    <0.4603586, -167.0814651>,
    <0.4599531, -167.0684463>,
    <0.4652252, -167.0752949>,
    <0.4688141, -167.0790372>,
    <0.4667693, -167.0842391>,
    <0.4640428, -167.0684463>,
    <0.4722222, -167.0684463>,
    <0.4722222, -167.0950173>,
    <0.4652252, -167.0752949>,
    <0.4681325, -167.0684463>,
    <0.4722222, -167.0820099>,
    <0.4699093, -167.0904455>,
    <0.4691004, -167.0976333>,
    <0.4667693, -167.0842391>,
    <0.4722222, -167.0950173>,
    <0.4722222, -167.1158246>,
    <0.4651880, -167.0954520>,
    <0.4699093, -167.0904455>,
    <0.4722222, -167.1099626>,
    <0.4694518, -167.1078010>,
    <0.4658198, -167.0909719>,
    <0.5348964, -167.0913370>,
    <0.5370370, -167.1000319>,
    <0.5277778, -167.0956495>,
    <0.5277778, -167.0684463>,
    <0.5469930, -167.1012202>,
    <0.5317580, -167.0975333>,
    <0.5277778, -167.0828212>,
    <0.5394213, -167.0883057>,
    <0.5419232, -167.1006151>,
    <0.5451658, -167.1082253>,
    <0.5370370, -167.1000319>,
    <0.5469930, -167.1012202>,
    <0.5555556, -167.1158246>,
    <0.5410776, -167.1158246>,
    <0.5419232, -167.1006151>,
    <0.5521190, -167.1099632>,
    <0.5492951, -167.1158246>,
    <0.5391890, -167.1084430>,
    <0.5334175, -167.1068327>,
    <0.5370370, -167.1000319>,
    <0.5410776, -167.1158246>,
    <0.5277778, -167.1158246>,
    <0.5277778, -167.0956495>,
    <0.5391890, -167.1084430>,
    <0.5332617, -167.1158246>,
    <0.5277778, -167.1099696>,
    <0.5317580, -167.0975333>,
    <0.5372754, -167.0805880>,
    <0.5408434, -167.0842391>,
    <0.5469930, -167.1012202>,
    <0.5277778, -167.0684463>,
    <0.5334873, -167.0684463>,
    <0.5448788, -167.0953821>,
    <0.5394213, -167.0883057>,
    <0.5306325, -167.0684463>,
    <0.5364421, -167.0747900>,
    <0.5404974, -167.0791031>,
    <0.5408434, -167.0842391>,
    <0.5334873, -167.0684463>,
    <0.5391968, -167.0684463>,
    <0.5484622, -167.0952809>,
    <0.5364421, -167.0747900>,
    <0.5363420, -167.0684463>,
    <0.5436400, -167.0813149>,
    <0.5446714, -167.0897870>,
    <0.5479635, -167.0991412>,
    <0.5408434, -167.0842391>,
    <0.5484622, -167.0952809>,
    <0.5555556, -167.1158246>,
    <0.5469930, -167.1012202>,
    <0.5446714, -167.0897870>,
    <0.5527514, -167.1077032>,
    <0.5521190, -167.1099632>,
    <0.5448788, -167.0953821>,
    <0.4793256, -167.0911530>,
    <0.4814815, -167.1000319>,
    <0.4722222, -167.0950173>,
    <0.4722222, -167.0684463>,
    <0.4913766, -167.1011164>,
    <0.4762170, -167.0971808>,
    <0.4722222, -167.0820099>,
    <0.4837813, -167.0881617>,
    <0.4863530, -167.1005658>,
    <0.4895997, -167.1081994>,
    <0.4814815, -167.1000319>,
    <0.4913766, -167.1011164>,
    <0.5000000, -167.1158246>,
    <0.4855405, -167.1158246>,
    <0.4863530, -167.1005658>,
    <0.4965358, -167.1099160>,
    <0.4937512, -167.1158246>,
    <0.4836478, -167.1084605>,
    <0.4778666, -167.1066746>,
    <0.4814815, -167.1000319>,
    <0.4855405, -167.1158246>,
    <0.4722222, -167.1158246>,
    <0.4722222, -167.0950173>,
    <0.4836478, -167.1084605>,
    <0.4777158, -167.1158246>,
    <0.4722222, -167.1099626>,
    <0.4762170, -167.0971808>,
    <0.4835695, -167.1384033>,
    <0.4907407, -167.1524837>,
    <0.4857744, -167.1694803>,
    <0.4722222, -167.1158246>,
    <0.4855405, -167.1158246>,
    <0.4879381, -167.1620754>,
    <0.4779461, -167.1384865>,
    <0.4777158, -167.1158246>,
    <0.4877935, -167.1317071>,
    <0.4940703, -167.1378917>,
    <0.4907407, -167.1524837>,
    <0.4855405, -167.1158246>,
    <0.5000000, -167.1158246>,
    <0.5000000, -167.1674339>,
    <0.4877935, -167.1317071>,
    <0.4937512, -167.1158246>,
    <0.5000000, -167.1361019>,
    <0.4959385, -167.1608762>,
    <0.4941288, -167.1788000>,
    <0.4907407, -167.1524837>,
    <0.5000000, -167.1674339>,
    <0.5000000, -167.2258020>,
    <0.4857744, -167.1694803>,
    <0.4959385, -167.1608762>,
    <0.5000000, -167.2002394>,
    <0.4937332, -167.2009905>,
    <0.4879381, -167.1620754>,
    <0.5057045, -167.1604768>,
    <0.5092593, -167.1891429>,
    <0.5000000, -167.1674339>,
    <0.5000000, -167.1158246>,
    <0.5135587, -167.1695059>,
    <0.5040527, -167.1769357>,
    <0.5000000, -167.1361019>,
    <0.5057296, -167.1385090>,
    <0.5116819, -167.1780779>,
    <0.5161241, -167.2025632>,
    <0.5092593, -167.1891429>,
    <0.5135587, -167.1695059>,
    <0.5277778, -167.2258020>,
    <0.5139006, -167.2258020>,
    <0.5116819, -167.1780779>,
    <0.5215146, -167.2010050>,
    <0.5217066, -167.2258020>,
    <0.5118632, -167.2097099>,
    <0.5057900, -167.2020452>,
    <0.5092593, -167.1891429>,
    <0.5139006, -167.2258020>,
    <0.5000000, -167.2258020>,
    <0.5000000, -167.1674339>,
    <0.5118632, -167.2097099>,
    <0.5060834, -167.2258020>,
    <0.5000000, -167.2002394>,
    <0.5040527, -167.1769357>,
    <0.5113466, -167.1384097>,
    <0.5185185, -167.1524837>,
    <0.5135587, -167.1695059>,
    <0.5000000, -167.1158246>,
    <0.5133094, -167.1158246>,
    <0.5157192, -167.1620911>,
    <0.5057296, -167.1385090>,
    <0.5054884, -167.1158246>,
    <0.5155663, -167.1317075>,
    <0.5218459, -167.1377291>,
    <0.5185185, -167.1524837>,
    <0.5133094, -167.1158246>,
    <0.5277778, -167.1158246>,
    <0.5277778, -167.1667832>,
    <0.5155663, -167.1317075>,
    <0.5215232, -167.1158246>,
    <0.5277778, -167.1355291>,
    <0.5237168, -167.1605116>,
    <0.5219082, -167.1786437>,
    <0.5185185, -167.1524837>,
    <0.5277778, -167.1667832>,
    <0.5277778, -167.2258020>,
    <0.5135587, -167.1695059>,
    <0.5237168, -167.1605116>,
    <0.5277778, -167.1998918>,
    <0.5215146, -167.2010050>,
    <0.5157192, -167.1620911>,
    <0.4817763, -167.0805620>,
    <0.4852878, -167.0842391>,
    <0.4913766, -167.1011164>,
    <0.4722222, -167.0684463>,
    <0.4782185, -167.0684463>,
    <0.4892280, -167.0951609>,
    <0.4837813, -167.0881617>,
    <0.4752593, -167.0684463>,
    <0.4810571, -167.0747878>,
    <0.4851343, -167.0794529>,
    <0.4852878, -167.0842391>,
    <0.4782185, -167.0684463>,
    <0.4836412, -167.0684463>,
    <0.4933897, -167.0966798>,
    <0.4810571, -167.0747878>,
    <0.4810264, -167.0684463>,
    <0.4886353, -167.0829102>,
    <0.4893521, -167.0904800>,
    <0.4925135, -167.0994650>,
    <0.4852878, -167.0842391>,
    <0.4933897, -167.0966798>,
    <0.5000000, -167.1158246>,
    <0.4913766, -167.1011164>,
    <0.4893521, -167.0904800>,
    <0.4974314, -167.1083853>,
    <0.4965358, -167.1099160>,
    <0.4892280, -167.0951609>,
    <0.5184896, -167.0790538>,
    <0.5223249, -167.0842391>,
    <0.5206163, -167.0950836>,
    <0.5114190, -167.0684463>,
    <0.5195984, -167.0684463>,
    <0.5213015, -167.0907344>,
    <0.5158024, -167.0811415>,
    <0.5155087, -167.0684463>,
    <0.5207813, -167.0752980>,
    <0.5243697, -167.0791953>,
    <0.5223249, -167.0842391>,
    <0.5195984, -167.0684463>,
    <0.5277778, -167.0684463>,
    <0.5277778, -167.0956495>,
    <0.5207813, -167.0752980>,
    <0.5236881, -167.0684463>,
    <0.5277778, -167.0828212>,
    <0.5254589, -167.0907973>,
    <0.5246242, -167.0976992>,
    <0.5223249, -167.0842391>,
    <0.5277778, -167.0956495>,
    <0.5277778, -167.1158246>,
    <0.5206163, -167.0950836>,
    <0.5254589, -167.0907973>,
    <0.5277778, -167.1099696>,
    <0.5249348, -167.1075909>,
    <0.5213015, -167.0907344>,
    <0.4837881, -167.2232074>,
    <0.4907407, -167.2357456>,
    <0.4861229, -167.2024179>,
    <0.4722222, -167.2024179>,
    <0.4860664, -167.2522483>,
    <0.4881407, -167.2169804>,
    <0.4783057, -167.2024179>,
    <0.4782701, -167.2241867>,
    <0.4881084, -167.2450388>,
    <0.4942018, -167.2602946>,
    <0.4907407, -167.2357456>,
    <0.4860664, -167.2522483>,
    <0.5000000, -167.3024008>,
    <0.5000000, -167.2507837>,
    <0.4881084, -167.2450388>,
    <0.4938936, -167.2804214>,
    <0.5000000, -167.2798504>,
    <0.4959443, -167.2441968>,
    <0.4942159, -167.2228413>,
    <0.4907407, -167.2357456>,
    <0.5000000, -167.2507837>,
    <0.5000000, -167.2024179>,
    <0.4861229, -167.2024179>,
    <0.4959443, -167.2441968>,
    <0.5000000, -167.2235884>,
    <0.4939288, -167.2024179>,
    <0.4881407, -167.2169804>,
    <0.5057758, -167.2436308>,
    <0.5092593, -167.2690732>,
    <0.5138441, -167.2522483>,
    <0.5000000, -167.2024179>,
    <0.5000000, -167.2507837>,
    <0.5118396, -167.2596042>,
    <0.5060479, -167.2241867>,
    <0.5000000, -167.2235884>,
    <0.5040494, -167.2587824>,
    <0.5057897, -167.2811646>,
    <0.5092593, -167.2690732>,
    <0.5000000, -167.2507837>,
    <0.5000000, -167.3024008>,
    <0.5138995, -167.3024008>,
    <0.5040494, -167.2587824>,
    <0.5000000, -167.2798504>,
    <0.5060828, -167.3024008>,
    <0.5118711, -167.2878319>,
    <0.5161952, -167.2815307>,
    <0.5092593, -167.2690732>,
    <0.5138995, -167.3024008>,
    <0.5277778, -167.3024008>,
    <0.5138441, -167.2522483>,
    <0.5118711, -167.2878319>,
    <0.5217060, -167.3024008>,
    <0.5216714, -167.2804214>,
    <0.5118396, -167.2596042>,
    <0.5115658, -167.2232074>,
    <0.5185185, -167.2357456>,
    <0.5139007, -167.2024179>,
    <0.5000000, -167.2024179>,
    <0.5138441, -167.2522483>,
    <0.5159184, -167.2169804>,
    <0.5060835, -167.2024179>,
    <0.5060479, -167.2241867>,
    <0.5158862, -167.2450388>,
    <0.5219796, -167.2602946>,
    <0.5185185, -167.2357456>,
    <0.5138441, -167.2522483>,
    <0.5277778, -167.3024008>,
    <0.5277778, -167.2507837>,
    <0.5158862, -167.2450388>,
    <0.5216714, -167.2804214>,
    <0.5277778, -167.2798504>,
    <0.5237221, -167.2441968>,
    <0.5219937, -167.2228413>,
    <0.5185185, -167.2357456>,
    <0.5277778, -167.2507837>,
    <0.5277778, -167.2024179>,
    <0.5139007, -167.2024179>,
    <0.5237221, -167.2441968>,
    <0.5277778, -167.2235884>,
    <0.5217066, -167.2024179>,
    <0.5159184, -167.2169804>,
    <0.4576534, -167.1176324>,
    <0.4578637, -167.1205358>,
    <0.4685226, -167.1227921>,
    <0.4569243, -167.1040945>,
    <0.4473031, -167.1231073>,
    <0.4638418, -167.1218013>,
    <0.4642078, -167.1158363>,
    <0.4507965, -167.1162039>,
    <0.4521744, -167.1219211>,
    <0.4517437, -167.1252890>,
    <0.4578637, -167.1205358>,
    <0.4473031, -167.1231073>,
    <0.4444444, -167.1287564>,
    <0.4573637, -167.1287564>,
    <0.4521744, -167.1219211>,
    <0.4454825, -167.1267051>,
    <0.4497149, -167.1287564>,
    <0.4575416, -167.1258321>,
    <0.4639930, -167.1252102>,
    <0.4578637, -167.1205358>,
    <0.4573637, -167.1287564>,
    <0.4722222, -167.1287564>,
    <0.4685226, -167.1227921>,
    <0.4575416, -167.1258321>,
    <0.4657564, -167.1287564>,
    <0.4708728, -167.1265810>,
    <0.4638418, -167.1218013>,
    <0.4558359, -167.1442610>,
    <0.4629630, -167.1533103>,
    <0.4573637, -167.1287564>,
    <0.4444444, -167.1287564>,
    <0.4585723, -167.1662209>,
    <0.4601227, -167.1408554>,
    <0.4497149, -167.1287564>,
    <0.4507016, -167.1453492>,
    <0.4605507, -167.1604034>,
    <0.4664949, -167.1706661>,
    <0.4629630, -167.1533103>,
    <0.4585723, -167.1662209>,
    <0.4722222, -167.2024179>,
    <0.4722222, -167.1607154>,
    <0.4605507, -167.1604034>,
    <0.4662818, -167.1866652>,
    <0.4722222, -167.1838308>,
    <0.4682342, -167.1575260>,
    <0.4661928, -167.1428846>,
    <0.4629630, -167.1533103>,
    <0.4722222, -167.1607154>,
    <0.4722222, -167.1287564>,
    <0.4573637, -167.1287564>,
    <0.4682342, -167.1575260>,
    <0.4722222, -167.1413913>,
    <0.4657564, -167.1287564>,
    <0.4601227, -167.1408554>,
    <0.4780690, -167.1583892>,
    <0.4814815, -167.1778641>,
    <0.4863501, -167.1662209>,
    <0.4722222, -167.1287564>,
    <0.4722222, -167.1607154>,
    <0.4842287, -167.1712941>,
    <0.4784794, -167.1453493>,
    <0.4722222, -167.1413913>,
    <0.4762790, -167.1682287>,
    <0.4780122, -167.1858538>,
    <0.4814815, -167.1778641>,
    <0.4722222, -167.1607154>,
    <0.4722222, -167.2024179>,
    <0.4861229, -167.2024179>,
    <0.4762790, -167.1682287>,
    <0.4722222, -167.1838308>,
    <0.4783057, -167.2024179>,
    <0.4841018, -167.1917260>,
    <0.4884886, -167.1872302>,
    <0.4814815, -167.1778641>,
    <0.4861229, -167.2024179>,
    <0.5000000, -167.2024179>,
    <0.4863501, -167.1662209>,
    <0.4841018, -167.1917260>,
    <0.4939288, -167.2024179>,
    <0.4940596, -167.1866652>,
    <0.4842287, -167.1712941>,
    <0.5336479, -167.1582978>,
    <0.5370370, -167.1778641>,
    <0.5419990, -167.1664684>,
    <0.5277778, -167.1287564>,
    <0.5277778, -167.1601023>,
    <0.5398358, -167.1714363>,
    <0.5341356, -167.1456163>,
    <0.5277778, -167.1407347>,
    <0.5318335, -167.1678822>,
    <0.5335678, -167.1857006>,
    <0.5370370, -167.1778641>,
    <0.5277778, -167.1601023>,
    <0.5277778, -167.2024179>,
    <0.5416785, -167.2024179>,
    <0.5318335, -167.1678822>,
    <0.5277778, -167.1835237>,
    <0.5338612, -167.2024179>,
    <0.5396601, -167.1917403>,
    <0.5440675, -167.1872921>,
    <0.5370370, -167.1778641>,
    <0.5416785, -167.2024179>,
    <0.5555556, -167.2024179>,
    <0.5419990, -167.1664684>,
    <0.5396601, -167.1917403>,
    <0.5494844, -167.2024179>,
    <0.5496651, -167.1867974>,
    <0.5398358, -167.1714363>,
    <0.5411147, -167.1175675>,
    <0.5411970, -167.1205421>,
    <0.5520558, -167.1231188>,
    <0.5402577, -167.1041136>,
    <0.5309484, -167.1224956>,
    <0.5474787, -167.1220327>,
    <0.5479301, -167.1164728>,
    <0.5346340, -167.1152180>,
    <0.5358333, -167.1215645>,
    <0.5352003, -167.1251377>,
    <0.5411970, -167.1205421>,
    <0.5309484, -167.1224956>,
    <0.5277778, -167.1287564>,
    <0.5408779, -167.1287564>,
    <0.5358333, -167.1215645>,
    <0.5289343, -167.1264727>,
    <0.5331597, -167.1287564>,
    <0.5409836, -167.1260344>,
    <0.5474216, -167.1252934>,
    <0.5411970, -167.1205421>,
    <0.5408779, -167.1287564>,
    <0.5555556, -167.1287564>,
    <0.5520558, -167.1231188>,
    <0.5409836, -167.1260344>,
    <0.5492130, -167.1287564>,
    <0.5542800, -167.1267016>,
    <0.5474787, -167.1220327>,
    <0.5392377, -167.1443229>,
    <0.5462963, -167.1533103>,
    <0.5408779, -167.1287564>,
    <0.5277778, -167.1287564>,
    <0.5419990, -167.1664684>,
    <0.5435564, -167.1408940>,
    <0.5331597, -167.1287564>,
    <0.5341356, -167.1456163>,
    <0.5439370, -167.1605343>,
    <0.5498516, -167.1705748>,
    <0.5462963, -167.1533103>,
    <0.5419990, -167.1664684>,
    <0.5555556, -167.2024179>,
    <0.5555556, -167.1601026>,
    <0.5439370, -167.1605343>,
    <0.5496651, -167.1867974>,
    <0.5555556, -167.1835239>,
    <0.5515693, -167.1571784>,
    <0.5495713, -167.1427314>,
    <0.5462963, -167.1533103>,
    <0.5555556, -167.1601026>,
    <0.5555556, -167.1287564>,
    <0.5408779, -167.1287564>,
    <0.5515693, -167.1571784>,
    <0.5555556, -167.1407351>,
    <0.5492130, -167.1287564>,
    <0.5435564, -167.1408940>,
    <0.4669360, -167.1106496>,
    <0.4658863, -167.1123151>,
    <0.4712200, -167.1220942>,
    <0.4685123, -167.1040945>,
    <0.4621255, -167.1040945>,
    <0.4684454, -167.1170071>,
    <0.4699720, -167.1137978>,
    <0.4650590, -167.1040945>,
    <0.4635135, -167.1071285>,
    <0.4633647, -167.1108241>,
    <0.4658863, -167.1123151>,
    <0.4621255, -167.1040945>,
    <0.4569245, -167.1040945>,
    <0.4685226, -167.1227921>,
    <0.4635135, -167.1071285>,
    <0.4594507, -167.1040945>,
    <0.4642079, -167.1158363>,
    <0.4675528, -167.1189380>,
    <0.4694628, -167.1214895>,
    <0.4658863, -167.1123151>,
    <0.4685226, -167.1227921>,
    <0.4722222, -167.1287564>,
    <0.4712200, -167.1220942>,
    <0.4675528, -167.1189380>,
    <0.4708728, -167.1265810>,
    <0.4719375, -167.1268636>,
    <0.4684454, -167.1170071>,
    <0.5350826, -167.1107627>,
    <0.5328900, -167.1123279>,
    <0.5309484, -167.1224956>,
    <0.5402577, -167.1041136>,
    <0.5362343, -167.1041136>,
    <0.5316414, -167.1188663>,
    <0.5346340, -167.1152180>,
    <0.5383819, -167.1041136>,
    <0.5350844, -167.1069379>,
    <0.5321385, -167.1101334>,
    <0.5328900, -167.1123279>,
    <0.5362343, -167.1041136>,
    <0.5306344, -167.1041136>,
    <0.5287953, -167.1199785>,
    <0.5350844, -167.1069379>,
    <0.5337217, -167.1041136>,
    <0.5297076, -167.1121092>,
    <0.5309502, -167.1159522>,
    <0.5301029, -167.1208896>,
    <0.5328900, -167.1123279>,
    <0.5287953, -167.1199785>,
    <0.5277778, -167.1287564>,
    <0.5309484, -167.1224956>,
    <0.5309502, -167.1159522>,
    <0.5281213, -167.1257934>,
    <0.5289343, -167.1264727>,
    <0.5316414, -167.1188663>,
    <0.4909313, -167.0794529>,
    <0.4945481, -167.0842391>,
    <0.4933909, -167.0966798>,
    <0.4836443, -167.0684463>,
    <0.4921420, -167.0684463>,
    <0.4938510, -167.0917331>,
    <0.4886374, -167.0829102>,
    <0.4880239, -167.0684463>,
    <0.4931889, -167.0753176>,
    <0.4966725, -167.0789416>,
    <0.4945481, -167.0842391>,
    <0.4921420, -167.0684463>,
    <0.5000000, -167.0684463>,
    <0.5000000, -167.0946348>,
    <0.4931889, -167.0753176>,
    <0.4961084, -167.0684463>,
    <0.5000000, -167.0817477>,
    <0.4976974, -167.0902442>,
    <0.4969847, -167.0978446>,
    <0.4945481, -167.0842391>,
    <0.5000000, -167.0946348>,
    <0.5000000, -167.1158246>,
    <0.4933909, -167.0966798>,
    <0.4976974, -167.0902442>,
    <0.5000000, -167.1099512>,
    <0.4974318, -167.1083853>,
    <0.4938510, -167.0917331>,
    <0.5071292, -167.0911014>,
    <0.5092593, -167.1000319>,
    <0.5000000, -167.0946348>,
    <0.5000000, -167.0684463>,
    <0.5192576, -167.1012925>,
    <0.5039948, -167.0969633>,
    <0.5000000, -167.0817477>,
    <0.5116800, -167.0883679>,
    <0.5141890, -167.1006534>,
    <0.5174010, -167.1082434>,
    <0.5092593, -167.1000319>,
    <0.5192576, -167.1012925>,
    <0.5277778, -167.1158246>,
    <0.5133094, -167.1158246>,
    <0.5141890, -167.1006534>,
    <0.5243616, -167.1099980>,
    <0.5215232, -167.1158246>,
    <0.5114193, -167.1084546>,
    <0.5056422, -167.1065790>,
    <0.5092593, -167.1000319>,
    <0.5133094, -167.1158246>,
    <0.5000000, -167.1158246>,
    <0.5000000, -167.0946348>,
    <0.5114193, -167.1084546>,
    <0.5054884, -167.1158246>,
    <0.5000000, -167.1099512>,
    <0.5039948, -167.0969633>,
    <0.5095082, -167.0806060>,
    <0.5130656, -167.0842391>,
    <0.5192576, -167.1012925>,
    <0.5000000, -167.0684463>,
    <0.5057095, -167.0684463>,
    <0.5171138, -167.0953881>,
    <0.5116800, -167.0883679>,
    <0.5028548, -167.0684463>,
    <0.5086662, -167.0747940>,
    <0.5127026, -167.0790538>,
    <0.5130656, -167.0842391>,
    <0.5057095, -167.0684463>,
    <0.5114190, -167.0684463>,
    <0.5206163, -167.0950836>,
    <0.5086662, -167.0747940>,
    <0.5085643, -167.0684463>,
    <0.5158024, -167.0811415>,
    <0.5168628, -167.0896927>,
    <0.5201793, -167.0991100>,
    <0.5130656, -167.0842391>,
    <0.5206163, -167.0950836>,
    <0.5277778, -167.1158246>,
    <0.5192576, -167.1012925>,
    <0.5168628, -167.0896927>,
    <0.5249348, -167.1075909>,
    <0.5243616, -167.1099980>,
    <0.5171138, -167.0953881>,
    <0.4701745, -167.1106496>,
    <0.4709856, -167.1123151>,
    <0.4699801, -167.1040945>,
    <0.4685123, -167.1040945>,
    <0.4712200, -167.1220942>,
    <0.4704105, -167.1076129>,
    <0.4691551, -167.1040945>,
    <0.4699720, -167.1137978>,
    <0.4711368, -167.1186209>,
    <0.4716625, -167.1197229>,
    <0.4709856, -167.1123151>,
    <0.4712200, -167.1220942>,
    <0.4722222, -167.1287564>,
    <0.4722222, -167.1157260>,
    <0.4711368, -167.1186209>,
    <0.4719375, -167.1268636>,
    <0.4722222, -167.1243286>,
    <0.4717272, -167.1143606>,
    <0.4713525, -167.1090575>,
    <0.4709856, -167.1123151>,
    <0.4722222, -167.1157260>,
    <0.4722222, -167.1040945>,
    <0.4699801, -167.1040945>,
    <0.4717272, -167.1143606>,
    <0.4722222, -167.1077205>,
    <0.4710318, -167.1040945>,
    <0.4704105, -167.1076129>,
    <0.5294227, -167.1101299>,
    <0.5287300, -167.1123215>,
    <0.5287953, -167.1199785>,
    <0.5306344, -167.1041136>,
    <0.5295310, -167.1041062>,
    <0.5287707, -167.1170888>,
    <0.5297076, -167.1121092>,
    <0.5301560, -167.1041104>,
    <0.5291861, -167.1076438>,
    <0.5284541, -167.1098044>,
    <0.5287300, -167.1123215>,
    <0.5295310, -167.1041062>,
    <0.5277778, -167.1040945>,
    <0.5277778, -167.1186952>,
    <0.5291861, -167.1076438>,
    <0.5287145, -167.1041008>,
    <0.5277778, -167.1075965>,
    <0.5281269, -167.1163584>,
    <0.5282702, -167.1199379>,
    <0.5287300, -167.1123215>,
    <0.5277778, -167.1186952>,
    <0.5277778, -167.1287564>,
    <0.5287953, -167.1199785>,
    <0.5281269, -167.1163584>,
    <0.5277778, -167.1268388>,
    <0.5281213, -167.1257934>,
    <0.5287707, -167.1170888>,
    <0.4836136, -167.1442610>,
    <0.4907407, -167.1533103>,
    <0.4851415, -167.1287564>,
    <0.4722222, -167.1287564>,
    <0.4863501, -167.1662209>,
    <0.4879005, -167.1408554>,
    <0.4774926, -167.1287564>,
    <0.4784794, -167.1453493>,
    <0.4883285, -167.1604034>,
    <0.4942727, -167.1706661>,
    <0.4907407, -167.1533103>,
    <0.4863501, -167.1662209>,
    <0.5000000, -167.2024179>,
    <0.5000000, -167.1607153>,
    <0.4883285, -167.1604034>,
    <0.4940596, -167.1866652>,
    <0.5000000, -167.1838307>,
    <0.4960120, -167.1575259>,
    <0.4939706, -167.1428846>,
    <0.4907407, -167.1533103>,
    <0.5000000, -167.1607153>,
    <0.5000000, -167.1287564>,
    <0.4851415, -167.1287564>,
    <0.4960120, -167.1575259>,
    <0.5000000, -167.1413912>,
    <0.4935342, -167.1287564>,
    <0.4879005, -167.1408554>,
    <0.5058468, -167.1583892>,
    <0.5092593, -167.1778641>,
    <0.5141279, -167.1662209>,
    <0.5000000, -167.1287564>,
    <0.5000000, -167.1607153>,
    <0.5120065, -167.1712941>,
    <0.5062572, -167.1453493>,
    <0.5000000, -167.1413912>,
    <0.5040568, -167.1682287>,
    <0.5057900, -167.1858538>,
    <0.5092593, -167.1778641>,
    <0.5000000, -167.1607153>,
    <0.5000000, -167.2024179>,
    <0.5139007, -167.2024179>,
    <0.5040568, -167.1682287>,
    <0.5000000, -167.1838307>,
    <0.5060835, -167.2024179>,
    <0.5118796, -167.1917260>,
    <0.5162664, -167.1872302>,
    <0.5092593, -167.1778641>,
    <0.5139007, -167.2024179>,
    <0.5277778, -167.2024179>,
    <0.5141279, -167.1662209>,
    <0.5118796, -167.1917260>,
    <0.5217066, -167.2024179>,
    <0.5218374, -167.1866652>,
    <0.5120065, -167.1712941>,
    <0.5114155, -167.1442610>,
    <0.5185185, -167.1533103>,
    <0.5130155, -167.1287564>,
    <0.5000000, -167.1287564>,
    <0.5141279, -167.1662209>,
    <0.5157321, -167.1408774>,
    <0.5053225, -167.1287564>,
    <0.5062572, -167.1453493>,
    <0.5161088, -167.1603961>,
    <0.5220505, -167.1705129>,
    <0.5185185, -167.1533103>,
    <0.5141279, -167.1662209>,
    <0.5277778, -167.2024179>,
    <0.5277778, -167.1601023>,
    <0.5161088, -167.1603961>,
    <0.5218374, -167.1866652>,
    <0.5277778, -167.1835237>,
    <0.5237886, -167.1571761>,
    <0.5217724, -167.1427313>,
    <0.5185185, -167.1533103>,
    <0.5277778, -167.1601023>,
    <0.5277778, -167.1287564>,
    <0.5130155, -167.1287564>,
    <0.5237886, -167.1571761>,
    <0.5277778, -167.1407347>,
    <0.5213846, -167.1287564>,
    <0.5157321, -167.1408774>,
    <0.4786425, -167.1109028>,
    <0.4763822, -167.1123151>,
    <0.4750809, -167.1231073>,
    <0.4847021, -167.1040945>,
    <0.4784047, -167.1040945>,
    <0.4755818, -167.1189533>,
    <0.4785743, -167.1162039>,
    <0.4815314, -167.1040945>,
    <0.4777316, -167.1068303>,
    <0.4748078, -167.1090575>,
    <0.4763822, -167.1123151>,
    <0.4784047, -167.1040945>,
    <0.4722222, -167.1040945>,
    <0.4722222, -167.1157260>,
    <0.4777316, -167.1068303>,
    <0.4753064, -167.1040945>,
    <0.4722222, -167.1077205>,
    <0.4743224, -167.1140040>,
    <0.4739769, -167.1199762>,
    <0.4763822, -167.1123151>,
    <0.4722222, -167.1157260>,
    <0.4722222, -167.1287564>,
    <0.4750809, -167.1231073>,
    <0.4743224, -167.1140040>,
    <0.4722222, -167.1243286>,
    <0.4732603, -167.1267051>,
    <0.4755818, -167.1189533>,
    <0.4854312, -167.1176324>,
    <0.4856414, -167.1205358>,
    <0.4963004, -167.1227922>,
    <0.4847021, -167.1040945>,
    <0.4750809, -167.1231073>,
    <0.4916196, -167.1218013>,
    <0.4919856, -167.1158363>,
    <0.4785743, -167.1162039>,
    <0.4799522, -167.1219211>,
    <0.4795215, -167.1252890>,
    <0.4856414, -167.1205358>,
    <0.4750809, -167.1231073>,
    <0.4722222, -167.1287564>,
    <0.4851415, -167.1287564>,
    <0.4799522, -167.1219211>,
    <0.4732603, -167.1267051>,
    <0.4774926, -167.1287564>,
    <0.4853194, -167.1258321>,
    <0.4917708, -167.1252102>,
    <0.4856414, -167.1205358>,
    <0.4851415, -167.1287564>,
    <0.5000000, -167.1287564>,
    <0.4963004, -167.1227922>,
    <0.4853194, -167.1258321>,
    <0.4935342, -167.1287564>,
    <0.4986506, -167.1265810>,
    <0.4916196, -167.1218013>,
    <0.5132817, -167.1174287>,
    <0.5134192, -167.1205358>,
    <0.5240112, -167.1226843>,
    <0.5124799, -167.1040945>,
    <0.5032165, -167.1224002>,
    <0.5195074, -167.1217707>,
    <0.5197368, -167.1157935>,
    <0.5068698, -167.1151807>,
    <0.5079589, -167.1215336>,
    <0.5074128, -167.1251122>,
    <0.5134192, -167.1205358>,
    <0.5032165, -167.1224002>,
    <0.5000000, -167.1287564>,
    <0.5130155, -167.1287564>,
    <0.5079589, -167.1215336>,
    <0.5011806, -167.1264234>,
    <0.5053225, -167.1287564>,
    <0.5131536, -167.1259441>,
    <0.5195559, -167.1251832>,
    <0.5134192, -167.1205358>,
    <0.5130155, -167.1287564>,
    <0.5277778, -167.1287564>,
    <0.5240112, -167.1226843>,
    <0.5131536, -167.1259441>,
    <0.5213846, -167.1287564>,
    <0.5263965, -167.1265296>,
    <0.5195074, -167.1217707>,
    <0.5198695, -167.1107971>,
    <0.5226785, -167.1123151>,
    <0.5203087, -167.1040945>,
    <0.5124798, -167.1040945>,
    <0.5240112, -167.1226843>,
    <0.5211577, -167.1070396>,
    <0.5164654, -167.1040945>,
    <0.5197368, -167.1157935>,
    <0.5234803, -167.1185536>,
    <0.5255613, -167.1206128>,
    <0.5226785, -167.1123151>,
    <0.5240112, -167.1226843>,
    <0.5277778, -167.1287564>,
    <0.5277778, -167.1186952>,
    <0.5234803, -167.1185536>,
    <0.5263965, -167.1265296>,
    <0.5277778, -167.1268388>,
    <0.5251806, -167.1154457>,
    <0.5246357, -167.1097998>,
    <0.5226785, -167.1123151>,
    <0.5277778, -167.1186952>,
    <0.5277778, -167.1040945>,
    <0.5203087, -167.1040945>,
    <0.5251806, -167.1154457>,
    <0.5277778, -167.1075965>,
    <0.5240648, -167.1040945>,
    <0.5211577, -167.1070396>,
    <0.4947139, -167.1106496>,
    <0.4936641, -167.1123151>,
    <0.4989978, -167.1220941>,
    <0.4962902, -167.1040945>,
    <0.4899034, -167.1040945>,
    <0.4962232, -167.1170071>,
    <0.4977498, -167.1137978>,
    <0.4928369, -167.1040945>,
    <0.4912914, -167.1071285>,
    <0.4911425, -167.1108241>,
    <0.4936641, -167.1123151>,
    <0.4899034, -167.1040945>,
    <0.4847022, -167.1040945>,
    <0.4963004, -167.1227922>,
    <0.4912914, -167.1071285>,
    <0.4872285, -167.1040945>,
    <0.4919857, -167.1158363>,
    <0.4953306, -167.1189380>,
    <0.4972406, -167.1214895>,
    <0.4936641, -167.1123151>,
    <0.4963004, -167.1227922>,
    <0.5000000, -167.1287564>,
    <0.4989978, -167.1220941>,
    <0.4953306, -167.1189380>,
    <0.4986506, -167.1265810>,
    <0.4997153, -167.1268636>,
    <0.4962232, -167.1170071>,
    <0.5065668, -167.1107261>,
    <0.5041600, -167.1123151>,
    <0.5032165, -167.1224002>,
    <0.5124799, -167.1040945>,
    <0.5064108, -167.1040945>,
    <0.5035800, -167.1185147>,
    <0.5068698, -167.1151807>,
    <0.5095056, -167.1040945>,
    <0.5056610, -167.1068330>,
    <0.5026427, -167.1090583>,
    <0.5041600, -167.1123151>,
    <0.5064108, -167.1040945>,
    <0.5000000, -167.1040945>,
    <0.5000000, -167.1157290>,
    <0.5056610, -167.1068330>,
    <0.5032278, -167.1040945>,
    <0.5000000, -167.1077216>,
    <0.5021071, -167.1139998>,
    <0.5018441, -167.1198002>,
    <0.5041600, -167.1123151>,
    <0.5000000, -167.1157290>,
    <0.5000000, -167.1287564>,
    <0.5032165, -167.1224002>,
    <0.5021071, -167.1139998>,
    <0.5000000, -167.1243301>,
    <0.5011806, -167.1264234>,
    <0.5035800, -167.1185147>,
    <0.4979524, -167.1106496>,
    <0.4987634, -167.1123151>,
    <0.4977581, -167.1040945>,
    <0.4962903, -167.1040945>,
    <0.4989978, -167.1220941>,
    <0.4981884, -167.1076129>,
    <0.4969331, -167.1040945>,
    <0.4977499, -167.1137978>,
    <0.4989146, -167.1186208>,
    <0.4994403, -167.1197237>,
    <0.4987634, -167.1123151>,
    <0.4989978, -167.1220941>,
    <0.5000000, -167.1287564>,
    <0.5000000, -167.1157290>,
    <0.4989146, -167.1186208>,
    <0.4997153, -167.1268636>,
    <0.5000000, -167.1243301>,
    <0.4995050, -167.1143624>,
    <0.4991304, -167.1090583>,
    <0.4987634, -167.1123151>,
    <0.5000000, -167.1157290>,
    <0.5000000, -167.1040945>,
    <0.4977581, -167.1040945>,
    <0.4995050, -167.1143624>,
    <0.5000000, -167.1077216>,
    <0.4988097, -167.1040945>,
    <0.4981884, -167.1076129>
  }
  texture_list {
    1,
    texture { T_peinture_rouge_goutiere }
  }
  face_indices {
    35712,   // 0 triangles and 17856 quads
    <8, 7, 0>, 0,
    <8, 0, 4>, 0,
    <8, 4, 1>, 0,
    <8, 1, 5>, 0,
    <8, 5, 2>, 0,
    <8, 2, 6>, 0,
    <8, 6, 3>, 0,
    <8, 3, 7>, 0,
    <14, 13, 0>, 0,
    <14, 0, 7>, 0,
    <14, 7, 3>, 0,
    <14, 3, 11>, 0,
    <14, 11, 9>, 0,
    <14, 9, 12>, 0,
    <14, 12, 10>, 0,
    <14, 10, 13>, 0,
    <18, 4, 0>, 0,
    <18, 0, 13>, 0,
    <18, 13, 10>, 0,
    <18, 10, 16>, 0,
    <18, 16, 15>, 0,
    <18, 15, 17>, 0,
    <18, 17, 1>, 0,
    <18, 1, 4>, 0,
    <27, 26, 19>, 0,
    <27, 19, 23>, 0,
    <27, 23, 20>, 0,
    <27, 20, 24>, 0,
    <27, 24, 21>, 0,
    <27, 21, 25>, 0,
    <27, 25, 22>, 0,
    <27, 22, 26>, 0,
    <30, 29, 19>, 0,
    <30, 19, 26>, 0,
    <30, 26, 22>, 0,
    <30, 22, 28>, 0,
    <30, 28, 15>, 0,
    <30, 15, 16>, 0,
    <30, 16, 10>, 0,
    <30, 10, 29>, 0,
    <32, 23, 19>, 0,
    <32, 19, 29>, 0,
    <32, 29, 10>, 0,
    <32, 10, 12>, 0,
    <32, 12, 9>, 0,
    <32, 9, 31>, 0,
    <32, 31, 20>, 0,
    <32, 20, 23>, 0,
    <41, 40, 33>, 0,
    <41, 33, 37>, 0,
    <41, 37, 34>, 0,
    <41, 34, 38>, 0,
    <41, 38, 35>, 0,
    <41, 35, 39>, 0,
    <41, 39, 36>, 0,
    <41, 36, 40>, 0,
    <44, 43, 33>, 0,
    <44, 33, 40>, 0,
    <44, 40, 36>, 0,
    <44, 36, 42>, 0,
    <44, 42, 9>, 0,
    <44, 9, 11>, 0,
    <44, 11, 3>, 0,
    <44, 3, 43>, 0,
    <46, 37, 33>, 0,
    <46, 33, 43>, 0,
    <46, 43, 3>, 0,
    <46, 3, 6>, 0,
    <46, 6, 2>, 0,
    <46, 2, 45>, 0,
    <46, 45, 34>, 0,
    <46, 34, 37>, 0,
    <55, 54, 47>, 0,
    <55, 47, 51>, 0,
    <55, 51, 48>, 0,
    <55, 48, 52>, 0,
    <55, 52, 49>, 0,
    <55, 49, 53>, 0,
    <55, 53, 50>, 0,
    <55, 50, 54>, 0,
    <61, 60, 47>, 0,
    <61, 47, 54>, 0,
    <61, 54, 50>, 0,
    <61, 50, 58>, 0,
    <61, 58, 56>, 0,
    <61, 56, 59>, 0,
    <61, 59, 57>, 0,
    <61, 57, 60>, 0,
    <64, 51, 47>, 0,
    <64, 47, 60>, 0,
    <64, 60, 57>, 0,
    <64, 57, 62>, 0,
    <64, 62, 35>, 0,
    <64, 35, 63>, 0,
    <64, 63, 48>, 0,
    <64, 48, 51>, 0,
    <68, 67, 65>, 0,
    <68, 65, 66>, 0,
    <68, 66, 36>, 0,
    <68, 36, 39>, 0,
    <68, 39, 35>, 0,
    <68, 35, 62>, 0,
    <68, 62, 57>, 0,
    <68, 57, 67>, 0,
    <72, 71, 65>, 0,
    <72, 65, 67>, 0,
    <72, 67, 57>, 0,
    <72, 57, 59>, 0,
    <72, 59, 56>, 0,
    <72, 56, 70>, 0,
    <72, 70, 69>, 0,
    <72, 69, 71>, 0,
    <74, 66, 65>, 0,
    <74, 65, 71>, 0,
    <74, 71, 69>, 0,
    <74, 69, 73>, 0,
    <74, 73, 9>, 0,
    <74, 9, 42>, 0,
    <74, 42, 36>, 0,
    <74, 36, 66>, 0,
    <80, 79, 75>, 0,
    <80, 75, 77>, 0,
    <80, 77, 76>, 0,
    <80, 76, 78>, 0,
    <80, 78, 21>, 0,
    <80, 21, 24>, 0,
    <80, 24, 20>, 0,
    <80, 20, 79>, 0,
    <84, 83, 75>, 0,
    <84, 75, 79>, 0,
    <84, 79, 20>, 0,
    <84, 20, 31>, 0,
    <84, 31, 9>, 0,
    <84, 9, 82>, 0,
    <84, 82, 81>, 0,
    <84, 81, 83>, 0,
    <88, 77, 75>, 0,
    <88, 75, 83>, 0,
    <88, 83, 81>, 0,
    <88, 81, 86>, 0,
    <88, 86, 85>, 0,
    <88, 85, 87>, 0,
    <88, 87, 76>, 0,
    <88, 76, 77>, 0,
    <97, 96, 89>, 0,
    <97, 89, 93>, 0,
    <97, 93, 90>, 0,
    <97, 90, 94>, 0,
    <97, 94, 91>, 0,
    <97, 91, 95>, 0,
    <97, 95, 92>, 0,
    <97, 92, 96>, 0,
    <100, 99, 89>, 0,
    <100, 89, 96>, 0,
    <100, 96, 92>, 0,
    <100, 92, 98>, 0,
    <100, 98, 21>, 0,
    <100, 21, 78>, 0,
    <100, 78, 76>, 0,
    <100, 76, 99>, 0,
    <102, 93, 89>, 0,
    <102, 89, 99>, 0,
    <102, 99, 76>, 0,
    <102, 76, 87>, 0,
    <102, 87, 85>, 0,
    <102, 85, 101>, 0,
    <102, 101, 90>, 0,
    <102, 90, 93>, 0,
    <108, 107, 103>, 0,
    <108, 103, 105>, 0,
    <108, 105, 104>, 0,
    <108, 104, 106>, 0,
    <108, 106, 91>, 0,
    <108, 91, 94>, 0,
    <108, 94, 90>, 0,
    <108, 90, 107>, 0,
    <112, 111, 103>, 0,
    <112, 103, 107>, 0,
    <112, 107, 90>, 0,
    <112, 90, 101>, 0,
    <112, 101, 85>, 0,
    <112, 85, 110>, 0,
    <112, 110, 109>, 0,
    <112, 109, 111>, 0,
    <116, 105, 103>, 0,
    <116, 103, 111>, 0,
    <116, 111, 109>, 0,
    <116, 109, 114>, 0,
    <116, 114, 113>, 0,
    <116, 113, 115>, 0,
    <116, 115, 104>, 0,
    <116, 104, 105>, 0,
    <125, 124, 117>, 0,
    <125, 117, 121>, 0,
    <125, 121, 118>, 0,
    <125, 118, 122>, 0,
    <125, 122, 119>, 0,
    <125, 119, 123>, 0,
    <125, 123, 120>, 0,
    <125, 120, 124>, 0,
    <130, 129, 117>, 0,
    <130, 117, 124>, 0,
    <130, 124, 120>, 0,
    <130, 120, 127>, 0,
    <130, 127, 56>, 0,
    <130, 56, 128>, 0,
    <130, 128, 126>, 0,
    <130, 126, 129>, 0,
    <133, 121, 117>, 0,
    <133, 117, 129>, 0,
    <133, 129, 126>, 0,
    <133, 126, 131>, 0,
    <133, 131, 9>, 0,
    <133, 9, 132>, 0,
    <133, 132, 118>, 0,
    <133, 118, 121>, 0,
    <141, 140, 134>, 0,
    <141, 134, 137>, 0,
    <141, 137, 135>, 0,
    <141, 135, 138>, 0,
    <141, 138, 56>, 0,
    <141, 56, 139>, 0,
    <141, 139, 136>, 0,
    <141, 136, 140>, 0,
    <146, 145, 134>, 0,
    <146, 134, 140>, 0,
    <146, 140, 136>, 0,
    <146, 136, 143>, 0,
    <146, 143, 9>, 0,
    <146, 9, 144>, 0,
    <146, 144, 142>, 0,
    <146, 142, 145>, 0,
    <149, 137, 134>, 0,
    <149, 134, 145>, 0,
    <149, 145, 142>, 0,
    <149, 142, 147>, 0,
    <149, 147, 119>, 0,
    <149, 119, 148>, 0,
    <149, 148, 135>, 0,
    <149, 135, 137>, 0,
    <158, 157, 150>, 0,
    <158, 150, 154>, 0,
    <158, 154, 151>, 0,
    <158, 151, 155>, 0,
    <158, 155, 152>, 0,
    <158, 152, 156>, 0,
    <158, 156, 153>, 0,
    <158, 153, 157>, 0,
    <161, 160, 150>, 0,
    <161, 150, 157>, 0,
    <161, 157, 153>, 0,
    <161, 153, 159>, 0,
    <161, 159, 113>, 0,
    <161, 113, 114>, 0,
    <161, 114, 109>, 0,
    <161, 109, 160>, 0,
    <163, 154, 150>, 0,
    <163, 150, 160>, 0,
    <163, 160, 109>, 0,
    <163, 109, 110>, 0,
    <163, 110, 85>, 0,
    <163, 85, 162>, 0,
    <163, 162, 151>, 0,
    <163, 151, 154>, 0,
    <172, 171, 164>, 0,
    <172, 164, 168>, 0,
    <172, 168, 165>, 0,
    <172, 165, 169>, 0,
    <172, 169, 166>, 0,
    <172, 166, 170>, 0,
    <172, 170, 167>, 0,
    <172, 167, 171>, 0,
    <175, 174, 164>, 0,
    <175, 164, 171>, 0,
    <175, 171, 167>, 0,
    <175, 167, 173>, 0,
    <175, 173, 56>, 0,
    <175, 56, 58>, 0,
    <175, 58, 50>, 0,
    <175, 50, 174>, 0,
    <177, 168, 164>, 0,
    <177, 164, 174>, 0,
    <177, 174, 50>, 0,
    <177, 50, 53>, 0,
    <177, 53, 49>, 0,
    <177, 49, 176>, 0,
    <177, 176, 165>, 0,
    <177, 165, 168>, 0,
    <186, 185, 178>, 0,
    <186, 178, 182>, 0,
    <186, 182, 179>, 0,
    <186, 179, 183>, 0,
    <186, 183, 180>, 0,
    <186, 180, 184>, 0,
    <186, 184, 181>, 0,
    <186, 181, 185>, 0,
    <192, 191, 178>, 0,
    <192, 178, 185>, 0,
    <192, 185, 181>, 0,
    <192, 181, 189>, 0,
    <192, 189, 187>, 0,
    <192, 187, 190>, 0,
    <192, 190, 188>, 0,
    <192, 188, 191>, 0,
    <195, 182, 178>, 0,
    <195, 178, 191>, 0,
    <195, 191, 188>, 0,
    <195, 188, 193>, 0,
    <195, 193, 166>, 0,
    <195, 166, 194>, 0,
    <195, 194, 179>, 0,
    <195, 179, 182>, 0,
    <199, 198, 196>, 0,
    <199, 196, 197>, 0,
    <199, 197, 167>, 0,
    <199, 167, 170>, 0,
    <199, 170, 166>, 0,
    <199, 166, 193>, 0,
    <199, 193, 188>, 0,
    <199, 188, 198>, 0,
    <203, 202, 196>, 0,
    <203, 196, 198>, 0,
    <203, 198, 188>, 0,
    <203, 188, 190>, 0,
    <203, 190, 187>, 0,
    <203, 187, 201>, 0,
    <203, 201, 200>, 0,
    <203, 200, 202>, 0,
    <205, 197, 196>, 0,
    <205, 196, 202>, 0,
    <205, 202, 200>, 0,
    <205, 200, 204>, 0,
    <205, 204, 56>, 0,
    <205, 56, 173>, 0,
    <205, 173, 167>, 0,
    <205, 167, 197>, 0,
    <211, 210, 206>, 0,
    <211, 206, 208>, 0,
    <211, 208, 207>, 0,
    <211, 207, 209>, 0,
    <211, 209, 152>, 0,
    <211, 152, 155>, 0,
    <211, 155, 151>, 0,
    <211, 151, 210>, 0,
    <215, 214, 206>, 0,
    <215, 206, 210>, 0,
    <215, 210, 151>, 0,
    <215, 151, 162>, 0,
    <215, 162, 85>, 0,
    <215, 85, 213>, 0,
    <215, 213, 212>, 0,
    <215, 212, 214>, 0,
    <219, 208, 206>, 0,
    <219, 206, 214>, 0,
    <219, 214, 212>, 0,
    <219, 212, 217>, 0,
    <219, 217, 216>, 0,
    <219, 216, 218>, 0,
    <219, 218, 207>, 0,
    <219, 207, 208>, 0,
    <225, 224, 220>, 0,
    <225, 220, 222>, 0,
    <225, 222, 221>, 0,
    <225, 221, 223>, 0,
    <225, 223, 152>, 0,
    <225, 152, 209>, 0,
    <225, 209, 207>, 0,
    <225, 207, 224>, 0,
    <229, 228, 220>, 0,
    <229, 220, 224>, 0,
    <229, 224, 207>, 0,
    <229, 207, 218>, 0,
    <229, 218, 216>, 0,
    <229, 216, 227>, 0,
    <229, 227, 226>, 0,
    <229, 226, 228>, 0,
    <233, 222, 220>, 0,
    <233, 220, 228>, 0,
    <233, 228, 226>, 0,
    <233, 226, 231>, 0,
    <233, 231, 230>, 0,
    <233, 230, 232>, 0,
    <233, 232, 221>, 0,
    <233, 221, 222>, 0,
    <239, 238, 234>, 0,
    <239, 234, 236>, 0,
    <239, 236, 235>, 0,
    <239, 235, 237>, 0,
    <239, 237, 230>, 0,
    <239, 230, 231>, 0,
    <239, 231, 226>, 0,
    <239, 226, 238>, 0,
    <243, 242, 234>, 0,
    <243, 234, 238>, 0,
    <243, 238, 226>, 0,
    <243, 226, 227>, 0,
    <243, 227, 216>, 0,
    <243, 216, 241>, 0,
    <243, 241, 240>, 0,
    <243, 240, 242>, 0,
    <247, 236, 234>, 0,
    <247, 234, 242>, 0,
    <247, 242, 240>, 0,
    <247, 240, 245>, 0,
    <247, 245, 244>, 0,
    <247, 244, 246>, 0,
    <247, 246, 235>, 0,
    <247, 235, 236>, 0,
    <255, 254, 248>, 0,
    <255, 248, 251>, 0,
    <255, 251, 249>, 0,
    <255, 249, 252>, 0,
    <255, 252, 187>, 0,
    <255, 187, 253>, 0,
    <255, 253, 250>, 0,
    <255, 250, 254>, 0,
    <260, 259, 248>, 0,
    <260, 248, 254>, 0,
    <260, 254, 250>, 0,
    <260, 250, 257>, 0,
    <260, 257, 56>, 0,
    <260, 56, 258>, 0,
    <260, 258, 256>, 0,
    <260, 256, 259>, 0,
    <264, 251, 248>, 0,
    <264, 248, 259>, 0,
    <264, 259, 256>, 0,
    <264, 256, 262>, 0,
    <264, 262, 261>, 0,
    <264, 261, 263>, 0,
    <264, 263, 249>, 0,
    <264, 249, 251>, 0,
    <273, 272, 265>, 0,
    <273, 265, 269>, 0,
    <273, 269, 266>, 0,
    <273, 266, 270>, 0,
    <273, 270, 267>, 0,
    <273, 267, 271>, 0,
    <273, 271, 268>, 0,
    <273, 268, 272>, 0,
    <279, 278, 265>, 0,
    <279, 265, 272>, 0,
    <279, 272, 268>, 0,
    <279, 268, 276>, 0,
    <279, 276, 274>, 0,
    <279, 274, 277>, 0,
    <279, 277, 275>, 0,
    <279, 275, 278>, 0,
    <283, 269, 265>, 0,
    <283, 265, 278>, 0,
    <283, 278, 275>, 0,
    <283, 275, 281>, 0,
    <283, 281, 280>, 0,
    <283, 280, 282>, 0,
    <283, 282, 266>, 0,
    <283, 266, 269>, 0,
    <292, 291, 284>, 0,
    <292, 284, 288>, 0,
    <292, 288, 285>, 0,
    <292, 285, 289>, 0,
    <292, 289, 286>, 0,
    <292, 286, 290>, 0,
    <292, 290, 287>, 0,
    <292, 287, 291>, 0,
    <295, 294, 284>, 0,
    <295, 284, 291>, 0,
    <295, 291, 287>, 0,
    <295, 287, 293>, 0,
    <295, 293, 280>, 0,
    <295, 280, 281>, 0,
    <295, 281, 275>, 0,
    <295, 275, 294>, 0,
    <297, 288, 284>, 0,
    <297, 284, 294>, 0,
    <297, 294, 275>, 0,
    <297, 275, 277>, 0,
    <297, 277, 274>, 0,
    <297, 274, 296>, 0,
    <297, 296, 285>, 0,
    <297, 285, 288>, 0,
    <306, 305, 298>, 0,
    <306, 298, 302>, 0,
    <306, 302, 299>, 0,
    <306, 299, 303>, 0,
    <306, 303, 300>, 0,
    <306, 300, 304>, 0,
    <306, 304, 301>, 0,
    <306, 301, 305>, 0,
    <312, 311, 298>, 0,
    <312, 298, 305>, 0,
    <312, 305, 301>, 0,
    <312, 301, 309>, 0,
    <312, 309, 307>, 0,
    <312, 307, 310>, 0,
    <312, 310, 308>, 0,
    <312, 308, 311>, 0,
    <316, 302, 298>, 0,
    <316, 298, 311>, 0,
    <316, 311, 308>, 0,
    <316, 308, 314>, 0,
    <316, 314, 313>, 0,
    <316, 313, 315>, 0,
    <316, 315, 299>, 0,
    <316, 299, 302>, 0,
    <322, 321, 317>, 0,
    <322, 317, 319>, 0,
    <322, 319, 318>, 0,
    <322, 318, 320>, 0,
    <322, 320, 313>, 0,
    <322, 313, 314>, 0,
    <322, 314, 308>, 0,
    <322, 308, 321>, 0,
    <326, 325, 317>, 0,
    <326, 317, 321>, 0,
    <326, 321, 308>, 0,
    <326, 308, 310>, 0,
    <326, 310, 307>, 0,
    <326, 307, 324>, 0,
    <326, 324, 323>, 0,
    <326, 323, 325>, 0,
    <329, 319, 317>, 0,
    <329, 317, 325>, 0,
    <329, 325, 323>, 0,
    <329, 323, 327>, 0,
    <329, 327, 267>, 0,
    <329, 267, 328>, 0,
    <329, 328, 318>, 0,
    <329, 318, 319>, 0,
    <335, 334, 330>, 0,
    <335, 330, 332>, 0,
    <335, 332, 331>, 0,
    <335, 331, 333>, 0,
    <335, 333, 313>, 0,
    <335, 313, 320>, 0,
    <335, 320, 318>, 0,
    <335, 318, 334>, 0,
    <337, 336, 330>, 0,
    <337, 330, 334>, 0,
    <337, 334, 318>, 0,
    <337, 318, 328>, 0,
    <337, 328, 267>, 0,
    <337, 267, 270>, 0,
    <337, 270, 266>, 0,
    <337, 266, 336>, 0,
    <339, 332, 330>, 0,
    <339, 330, 336>, 0,
    <339, 336, 266>, 0,
    <339, 266, 282>, 0,
    <339, 282, 280>, 0,
    <339, 280, 338>, 0,
    <339, 338, 331>, 0,
    <339, 331, 332>, 0,
    <347, 346, 340>, 0,
    <347, 340, 343>, 0,
    <347, 343, 341>, 0,
    <347, 341, 344>, 0,
    <347, 344, 300>, 0,
    <347, 300, 345>, 0,
    <347, 345, 342>, 0,
    <347, 342, 346>, 0,
    <353, 352, 340>, 0,
    <353, 340, 346>, 0,
    <353, 346, 342>, 0,
    <353, 342, 350>, 0,
    <353, 350, 348>, 0,
    <353, 348, 351>, 0,
    <353, 351, 349>, 0,
    <353, 349, 352>, 0,
    <357, 343, 340>, 0,
    <357, 340, 352>, 0,
    <357, 352, 349>, 0,
    <357, 349, 355>, 0,
    <357, 355, 354>, 0,
    <357, 354, 356>, 0,
    <357, 356, 341>, 0,
    <357, 341, 343>, 0,
    <361, 360, 358>, 0,
    <361, 358, 359>, 0,
    <361, 359, 342>, 0,
    <361, 342, 345>, 0,
    <361, 345, 300>, 0,
    <361, 300, 303>, 0,
    <361, 303, 299>, 0,
    <361, 299, 360>, 0,
    <365, 364, 358>, 0,
    <365, 358, 360>, 0,
    <365, 360, 299>, 0,
    <365, 299, 315>, 0,
    <365, 315, 313>, 0,
    <365, 313, 363>, 0,
    <365, 363, 362>, 0,
    <365, 362, 364>, 0,
    <367, 359, 358>, 0,
    <367, 358, 364>, 0,
    <367, 364, 362>, 0,
    <367, 362, 366>, 0,
    <367, 366, 348>, 0,
    <367, 348, 350>, 0,
    <367, 350, 342>, 0,
    <367, 342, 359>, 0,
    <373, 372, 368>, 0,
    <373, 368, 370>, 0,
    <373, 370, 287>, 0,
    <373, 287, 290>, 0,
    <373, 290, 286>, 0,
    <373, 286, 371>, 0,
    <373, 371, 369>, 0,
    <373, 369, 372>, 0,
    <379, 378, 368>, 0,
    <379, 368, 372>, 0,
    <379, 372, 369>, 0,
    <379, 369, 376>, 0,
    <379, 376, 374>, 0,
    <379, 374, 377>, 0,
    <379, 377, 375>, 0,
    <379, 375, 378>, 0,
    <381, 370, 368>, 0,
    <381, 368, 378>, 0,
    <381, 378, 375>, 0,
    <381, 375, 380>, 0,
    <381, 380, 280>, 0,
    <381, 280, 293>, 0,
    <381, 293, 287>, 0,
    <381, 287, 370>, 0,
    <390, 389, 382>, 0,
    <390, 382, 386>, 0,
    <390, 386, 383>, 0,
    <390, 383, 387>, 0,
    <390, 387, 384>, 0,
    <390, 384, 388>, 0,
    <390, 388, 385>, 0,
    <390, 385, 389>, 0,
    <393, 392, 382>, 0,
    <393, 382, 389>, 0,
    <393, 389, 385>, 0,
    <393, 385, 391>, 0,
    <393, 391, 374>, 0,
    <393, 374, 376>, 0,
    <393, 376, 369>, 0,
    <393, 369, 392>, 0,
    <395, 386, 382>, 0,
    <395, 382, 392>, 0,
    <395, 392, 369>, 0,
    <395, 369, 371>, 0,
    <395, 371, 286>, 0,
    <395, 286, 394>, 0,
    <395, 394, 383>, 0,
    <395, 383, 386>, 0,
    <404, 403, 396>, 0,
    <404, 396, 400>, 0,
    <404, 400, 397>, 0,
    <404, 397, 401>, 0,
    <404, 401, 398>, 0,
    <404, 398, 402>, 0,
    <404, 402, 399>, 0,
    <404, 399, 403>, 0,
    <407, 406, 396>, 0,
    <407, 396, 403>, 0,
    <407, 403, 399>, 0,
    <407, 399, 405>, 0,
    <407, 405, 354>, 0,
    <407, 354, 355>, 0,
    <407, 355, 349>, 0,
    <407, 349, 406>, 0,
    <409, 400, 396>, 0,
    <409, 396, 406>, 0,
    <409, 406, 349>, 0,
    <409, 349, 351>, 0,
    <409, 351, 348>, 0,
    <409, 348, 408>, 0,
    <409, 408, 397>, 0,
    <409, 397, 400>, 0,
    <418, 417, 410>, 0,
    <418, 410, 414>, 0,
    <418, 414, 411>, 0,
    <418, 411, 415>, 0,
    <418, 415, 412>, 0,
    <418, 412, 416>, 0,
    <418, 416, 413>, 0,
    <418, 413, 417>, 0,
    <421, 420, 410>, 0,
    <421, 410, 417>, 0,
    <421, 417, 413>, 0,
    <421, 413, 419>, 0,
    <421, 419, 374>, 0,
    <421, 374, 391>, 0,
    <421, 391, 385>, 0,
    <421, 385, 420>, 0,
    <423, 414, 410>, 0,
    <423, 410, 420>, 0,
    <423, 420, 385>, 0,
    <423, 385, 388>, 0,
    <423, 388, 384>, 0,
    <423, 384, 422>, 0,
    <423, 422, 411>, 0,
    <423, 411, 414>, 0,
    <432, 431, 424>, 0,
    <432, 424, 428>, 0,
    <432, 428, 425>, 0,
    <432, 425, 429>, 0,
    <432, 429, 426>, 0,
    <432, 426, 430>, 0,
    <432, 430, 427>, 0,
    <432, 427, 431>, 0,
    <435, 434, 424>, 0,
    <435, 424, 431>, 0,
    <435, 431, 427>, 0,
    <435, 427, 433>, 0,
    <435, 433, 244>, 0,
    <435, 244, 245>, 0,
    <435, 245, 240>, 0,
    <435, 240, 434>, 0,
    <437, 428, 424>, 0,
    <437, 424, 434>, 0,
    <437, 434, 240>, 0,
    <437, 240, 241>, 0,
    <437, 241, 216>, 0,
    <437, 216, 436>, 0,
    <437, 436, 425>, 0,
    <437, 425, 428>, 0,
    <446, 445, 438>, 0,
    <446, 438, 442>, 0,
    <446, 442, 439>, 0,
    <446, 439, 443>, 0,
    <446, 443, 440>, 0,
    <446, 440, 444>, 0,
    <446, 444, 441>, 0,
    <446, 441, 445>, 0,
    <449, 448, 438>, 0,
    <449, 438, 445>, 0,
    <449, 445, 441>, 0,
    <449, 441, 447>, 0,
    <449, 447, 398>, 0,
    <449, 398, 401>, 0,
    <449, 401, 397>, 0,
    <449, 397, 448>, 0,
    <451, 442, 438>, 0,
    <451, 438, 448>, 0,
    <451, 448, 397>, 0,
    <451, 397, 408>, 0,
    <451, 408, 348>, 0,
    <451, 348, 450>, 0,
    <451, 450, 439>, 0,
    <451, 439, 442>, 0,
    <457, 456, 452>, 0,
    <457, 452, 454>, 0,
    <457, 454, 413>, 0,
    <457, 413, 416>, 0,
    <457, 416, 412>, 0,
    <457, 412, 455>, 0,
    <457, 455, 453>, 0,
    <457, 453, 456>, 0,
    <463, 462, 452>, 0,
    <463, 452, 456>, 0,
    <463, 456, 453>, 0,
    <463, 453, 460>, 0,
    <463, 460, 458>, 0,
    <463, 458, 461>, 0,
    <463, 461, 459>, 0,
    <463, 459, 462>, 0,
    <465, 454, 452>, 0,
    <465, 452, 462>, 0,
    <465, 462, 459>, 0,
    <465, 459, 464>, 0,
    <465, 464, 374>, 0,
    <465, 374, 419>, 0,
    <465, 419, 413>, 0,
    <465, 413, 454>, 0,
    <474, 473, 466>, 0,
    <474, 466, 470>, 0,
    <474, 470, 467>, 0,
    <474, 467, 471>, 0,
    <474, 471, 468>, 0,
    <474, 468, 472>, 0,
    <474, 472, 469>, 0,
    <474, 469, 473>, 0,
    <477, 476, 466>, 0,
    <477, 466, 473>, 0,
    <477, 473, 469>, 0,
    <477, 469, 475>, 0,
    <477, 475, 187>, 0,
    <477, 187, 189>, 0,
    <477, 189, 181>, 0,
    <477, 181, 476>, 0,
    <479, 470, 466>, 0,
    <479, 466, 476>, 0,
    <479, 476, 181>, 0,
    <479, 181, 184>, 0,
    <479, 184, 180>, 0,
    <479, 180, 478>, 0,
    <479, 478, 467>, 0,
    <479, 467, 470>, 0,
    <488, 487, 480>, 0,
    <488, 480, 484>, 0,
    <488, 484, 481>, 0,
    <488, 481, 485>, 0,
    <488, 485, 482>, 0,
    <488, 482, 486>, 0,
    <488, 486, 483>, 0,
    <488, 483, 487>, 0,
    <494, 493, 480>, 0,
    <494, 480, 487>, 0,
    <494, 487, 483>, 0,
    <494, 483, 491>, 0,
    <494, 491, 489>, 0,
    <494, 489, 492>, 0,
    <494, 492, 490>, 0,
    <494, 490, 493>, 0,
    <497, 484, 480>, 0,
    <497, 480, 493>, 0,
    <497, 493, 490>, 0,
    <497, 490, 495>, 0,
    <497, 495, 468>, 0,
    <497, 468, 496>, 0,
    <497, 496, 481>, 0,
    <497, 481, 484>, 0,
    <501, 500, 498>, 0,
    <501, 498, 499>, 0,
    <501, 499, 469>, 0,
    <501, 469, 472>, 0,
    <501, 472, 468>, 0,
    <501, 468, 495>, 0,
    <501, 495, 490>, 0,
    <501, 490, 500>, 0,
    <505, 504, 498>, 0,
    <505, 498, 500>, 0,
    <505, 500, 490>, 0,
    <505, 490, 492>, 0,
    <505, 492, 489>, 0,
    <505, 489, 503>, 0,
    <505, 503, 502>, 0,
    <505, 502, 504>, 0,
    <507, 499, 498>, 0,
    <507, 498, 504>, 0,
    <507, 504, 502>, 0,
    <507, 502, 506>, 0,
    <507, 506, 187>, 0,
    <507, 187, 475>, 0,
    <507, 475, 469>, 0,
    <507, 469, 499>, 0,
    <513, 512, 508>, 0,
    <513, 508, 510>, 0,
    <513, 510, 509>, 0,
    <513, 509, 511>, 0,
    <513, 511, 426>, 0,
    <513, 426, 429>, 0,
    <513, 429, 425>, 0,
    <513, 425, 512>, 0,
    <517, 516, 508>, 0,
    <517, 508, 512>, 0,
    <517, 512, 425>, 0,
    <517, 425, 436>, 0,
    <517, 436, 216>, 0,
    <517, 216, 515>, 0,
    <517, 515, 514>, 0,
    <517, 514, 516>, 0,
    <521, 510, 508>, 0,
    <521, 508, 516>, 0,
    <521, 516, 514>, 0,
    <521, 514, 519>, 0,
    <521, 519, 518>, 0,
    <521, 518, 520>, 0,
    <521, 520, 509>, 0,
    <521, 509, 510>, 0,
    <530, 529, 522>, 0,
    <530, 522, 526>, 0,
    <530, 526, 523>, 0,
    <530, 523, 527>, 0,
    <530, 527, 524>, 0,
    <530, 524, 528>, 0,
    <530, 528, 525>, 0,
    <530, 525, 529>, 0,
    <533, 532, 522>, 0,
    <533, 522, 529>, 0,
    <533, 529, 525>, 0,
    <533, 525, 531>, 0,
    <533, 531, 426>, 0,
    <533, 426, 511>, 0,
    <533, 511, 509>, 0,
    <533, 509, 532>, 0,
    <535, 526, 522>, 0,
    <535, 522, 532>, 0,
    <535, 532, 509>, 0,
    <535, 509, 520>, 0,
    <535, 520, 518>, 0,
    <535, 518, 534>, 0,
    <535, 534, 523>, 0,
    <535, 523, 526>, 0,
    <541, 540, 536>, 0,
    <541, 536, 538>, 0,
    <541, 538, 537>, 0,
    <541, 537, 539>, 0,
    <541, 539, 524>, 0,
    <541, 524, 527>, 0,
    <541, 527, 523>, 0,
    <541, 523, 540>, 0,
    <545, 544, 536>, 0,
    <545, 536, 540>, 0,
    <545, 540, 523>, 0,
    <545, 523, 534>, 0,
    <545, 534, 518>, 0,
    <545, 518, 543>, 0,
    <545, 543, 542>, 0,
    <545, 542, 544>, 0,
    <549, 538, 536>, 0,
    <549, 536, 544>, 0,
    <549, 544, 542>, 0,
    <549, 542, 547>, 0,
    <549, 547, 546>, 0,
    <549, 546, 548>, 0,
    <549, 548, 537>, 0,
    <549, 537, 538>, 0,
    <558, 557, 550>, 0,
    <558, 550, 554>, 0,
    <558, 554, 551>, 0,
    <558, 551, 555>, 0,
    <558, 555, 552>, 0,
    <558, 552, 556>, 0,
    <558, 556, 553>, 0,
    <558, 553, 557>, 0,
    <564, 563, 550>, 0,
    <564, 550, 557>, 0,
    <564, 557, 553>, 0,
    <564, 553, 561>, 0,
    <564, 561, 559>, 0,
    <564, 559, 562>, 0,
    <564, 562, 560>, 0,
    <564, 560, 563>, 0,
    <568, 554, 550>, 0,
    <568, 550, 563>, 0,
    <568, 563, 560>, 0,
    <568, 560, 566>, 0,
    <568, 566, 565>, 0,
    <568, 565, 567>, 0,
    <568, 567, 551>, 0,
    <568, 551, 554>, 0,
    <574, 573, 569>, 0,
    <574, 569, 571>, 0,
    <574, 571, 553>, 0,
    <574, 553, 556>, 0,
    <574, 556, 552>, 0,
    <574, 552, 572>, 0,
    <574, 572, 570>, 0,
    <574, 570, 573>, 0,
    <579, 578, 569>, 0,
    <579, 569, 573>, 0,
    <579, 573, 570>, 0,
    <579, 570, 576>, 0,
    <579, 576, 440>, 0,
    <579, 440, 577>, 0,
    <579, 577, 575>, 0,
    <579, 575, 578>, 0,
    <581, 571, 569>, 0,
    <581, 569, 578>, 0,
    <581, 578, 575>, 0,
    <581, 575, 580>, 0,
    <581, 580, 559>, 0,
    <581, 559, 561>, 0,
    <581, 561, 553>, 0,
    <581, 553, 571>, 0,
    <585, 584, 582>, 0,
    <585, 582, 583>, 0,
    <585, 583, 575>, 0,
    <585, 575, 577>, 0,
    <585, 577, 440>, 0,
    <585, 440, 443>, 0,
    <585, 443, 439>, 0,
    <585, 439, 584>, 0,
    <589, 588, 582>, 0,
    <589, 582, 584>, 0,
    <589, 584, 439>, 0,
    <589, 439, 450>, 0,
    <589, 450, 348>, 0,
    <589, 348, 587>, 0,
    <589, 587, 586>, 0,
    <589, 586, 588>, 0,
    <591, 583, 582>, 0,
    <591, 582, 588>, 0,
    <591, 588, 586>, 0,
    <591, 586, 590>, 0,
    <591, 590, 559>, 0,
    <591, 559, 580>, 0,
    <591, 580, 575>, 0,
    <591, 575, 583>, 0,
    <600, 599, 592>, 0,
    <600, 592, 596>, 0,
    <600, 596, 593>, 0,
    <600, 593, 597>, 0,
    <600, 597, 594>, 0,
    <600, 594, 598>, 0,
    <600, 598, 595>, 0,
    <600, 595, 599>, 0,
    <606, 605, 592>, 0,
    <606, 592, 599>, 0,
    <606, 599, 595>, 0,
    <606, 595, 603>, 0,
    <606, 603, 601>, 0,
    <606, 601, 604>, 0,
    <606, 604, 602>, 0,
    <606, 602, 605>, 0,
    <609, 596, 592>, 0,
    <609, 592, 605>, 0,
    <609, 605, 602>, 0,
    <609, 602, 607>, 0,
    <609, 607, 458>, 0,
    <609, 458, 608>, 0,
    <609, 608, 593>, 0,
    <609, 593, 596>, 0,
    <613, 612, 610>, 0,
    <613, 610, 611>, 0,
    <613, 611, 459>, 0,
    <613, 459, 461>, 0,
    <613, 461, 458>, 0,
    <613, 458, 607>, 0,
    <613, 607, 602>, 0,
    <613, 602, 612>, 0,
    <617, 616, 610>, 0,
    <617, 610, 612>, 0,
    <617, 612, 602>, 0,
    <617, 602, 604>, 0,
    <617, 604, 601>, 0,
    <617, 601, 615>, 0,
    <617, 615, 614>, 0,
    <617, 614, 616>, 0,
    <619, 611, 610>, 0,
    <619, 610, 616>, 0,
    <619, 616, 614>, 0,
    <619, 614, 618>, 0,
    <619, 618, 374>, 0,
    <619, 374, 464>, 0,
    <619, 464, 459>, 0,
    <619, 459, 611>, 0,
    <628, 627, 620>, 0,
    <628, 620, 624>, 0,
    <628, 624, 621>, 0,
    <628, 621, 625>, 0,
    <628, 625, 622>, 0,
    <628, 622, 626>, 0,
    <628, 626, 623>, 0,
    <628, 623, 627>, 0,
    <631, 630, 620>, 0,
    <631, 620, 627>, 0,
    <631, 627, 623>, 0,
    <631, 623, 629>, 0,
    <631, 629, 601>, 0,
    <631, 601, 603>, 0,
    <631, 603, 595>, 0,
    <631, 595, 630>, 0,
    <633, 624, 620>, 0,
    <633, 620, 630>, 0,
    <633, 630, 595>, 0,
    <633, 595, 598>, 0,
    <633, 598, 594>, 0,
    <633, 594, 632>, 0,
    <633, 632, 621>, 0,
    <633, 621, 624>, 0,
    <641, 640, 634>, 0,
    <641, 634, 637>, 0,
    <641, 637, 635>, 0,
    <641, 635, 638>, 0,
    <641, 638, 489>, 0,
    <641, 489, 639>, 0,
    <641, 639, 636>, 0,
    <641, 636, 640>, 0,
    <646, 645, 634>, 0,
    <646, 634, 640>, 0,
    <646, 640, 636>, 0,
    <646, 636, 643>, 0,
    <646, 643, 187>, 0,
    <646, 187, 644>, 0,
    <646, 644, 642>, 0,
    <646, 642, 645>, 0,
    <650, 637, 634>, 0,
    <650, 634, 645>, 0,
    <650, 645, 642>, 0,
    <650, 642, 648>, 0,
    <650, 648, 647>, 0,
    <650, 647, 649>, 0,
    <650, 649, 635>, 0,
    <650, 635, 637>, 0,
    <659, 658, 651>, 0,
    <659, 651, 655>, 0,
    <659, 655, 652>, 0,
    <659, 652, 656>, 0,
    <659, 656, 653>, 0,
    <659, 653, 657>, 0,
    <659, 657, 654>, 0,
    <659, 654, 658>, 0,
    <662, 661, 651>, 0,
    <662, 651, 658>, 0,
    <662, 658, 654>, 0,
    <662, 654, 660>, 0,
    <662, 660, 601>, 0,
    <662, 601, 629>, 0,
    <662, 629, 623>, 0,
    <662, 623, 661>, 0,
    <664, 655, 651>, 0,
    <664, 651, 661>, 0,
    <664, 661, 623>, 0,
    <664, 623, 626>, 0,
    <664, 626, 622>, 0,
    <664, 622, 663>, 0,
    <664, 663, 652>, 0,
    <664, 652, 655>, 0,
    <673, 672, 665>, 0,
    <673, 665, 669>, 0,
    <673, 669, 666>, 0,
    <673, 666, 670>, 0,
    <673, 670, 667>, 0,
    <673, 667, 671>, 0,
    <673, 671, 668>, 0,
    <673, 668, 672>, 0,
    <676, 675, 665>, 0,
    <676, 665, 672>, 0,
    <676, 672, 668>, 0,
    <676, 668, 674>, 0,
    <676, 674, 565>, 0,
    <676, 565, 566>, 0,
    <676, 566, 560>, 0,
    <676, 560, 675>, 0,
    <678, 669, 665>, 0,
    <678, 665, 675>, 0,
    <678, 675, 560>, 0,
    <678, 560, 562>, 0,
    <678, 562, 559>, 0,
    <678, 559, 677>, 0,
    <678, 677, 666>, 0,
    <678, 666, 669>, 0,
    <684, 683, 679>, 0,
    <684, 679, 681>, 0,
    <684, 681, 654>, 0,
    <684, 654, 657>, 0,
    <684, 657, 653>, 0,
    <684, 653, 682>, 0,
    <684, 682, 680>, 0,
    <684, 680, 683>, 0,
    <690, 689, 679>, 0,
    <690, 679, 683>, 0,
    <690, 683, 680>, 0,
    <690, 680, 687>, 0,
    <690, 687, 685>, 0,
    <690, 685, 688>, 0,
    <690, 688, 686>, 0,
    <690, 686, 689>, 0,
    <692, 681, 679>, 0,
    <692, 679, 689>, 0,
    <692, 689, 686>, 0,
    <692, 686, 691>, 0,
    <692, 691, 601>, 0,
    <692, 601, 660>, 0,
    <692, 660, 654>, 0,
    <692, 654, 681>, 0,
    <701, 700, 693>, 0,
    <701, 693, 697>, 0,
    <701, 697, 694>, 0,
    <701, 694, 698>, 0,
    <701, 698, 695>, 0,
    <701, 695, 699>, 0,
    <701, 699, 696>, 0,
    <701, 696, 700>, 0,
    <704, 703, 693>, 0,
    <704, 693, 700>, 0,
    <704, 700, 696>, 0,
    <704, 696, 702>, 0,
    <704, 702, 546>, 0,
    <704, 546, 547>, 0,
    <704, 547, 542>, 0,
    <704, 542, 703>, 0,
    <706, 697, 693>, 0,
    <706, 693, 703>, 0,
    <706, 703, 542>, 0,
    <706, 542, 543>, 0,
    <706, 543, 518>, 0,
    <706, 518, 705>, 0,
    <706, 705, 694>, 0,
    <706, 694, 697>, 0,
    <715, 714, 707>, 0,
    <715, 707, 711>, 0,
    <715, 711, 708>, 0,
    <715, 708, 712>, 0,
    <715, 712, 709>, 0,
    <715, 709, 713>, 0,
    <715, 713, 710>, 0,
    <715, 710, 714>, 0,
    <721, 720, 707>, 0,
    <721, 707, 714>, 0,
    <721, 714, 710>, 0,
    <721, 710, 718>, 0,
    <721, 718, 716>, 0,
    <721, 716, 719>, 0,
    <721, 719, 717>, 0,
    <721, 717, 720>, 0,
    <725, 711, 707>, 0,
    <725, 707, 720>, 0,
    <725, 720, 717>, 0,
    <725, 717, 723>, 0,
    <725, 723, 722>, 0,
    <725, 722, 724>, 0,
    <725, 724, 708>, 0,
    <725, 708, 711>, 0,
    <731, 730, 726>, 0,
    <731, 726, 728>, 0,
    <731, 728, 710>, 0,
    <731, 710, 713>, 0,
    <731, 713, 709>, 0,
    <731, 709, 729>, 0,
    <731, 729, 727>, 0,
    <731, 727, 730>, 0,
    <736, 735, 726>, 0,
    <736, 726, 730>, 0,
    <736, 730, 727>, 0,
    <736, 727, 733>, 0,
    <736, 733, 667>, 0,
    <736, 667, 734>, 0,
    <736, 734, 732>, 0,
    <736, 732, 735>, 0,
    <738, 728, 726>, 0,
    <738, 726, 735>, 0,
    <738, 735, 732>, 0,
    <738, 732, 737>, 0,
    <738, 737, 716>, 0,
    <738, 716, 718>, 0,
    <738, 718, 710>, 0,
    <738, 710, 728>, 0,
    <742, 741, 739>, 0,
    <742, 739, 740>, 0,
    <742, 740, 732>, 0,
    <742, 732, 734>, 0,
    <742, 734, 667>, 0,
    <742, 667, 670>, 0,
    <742, 670, 666>, 0,
    <742, 666, 741>, 0,
    <746, 745, 739>, 0,
    <746, 739, 741>, 0,
    <746, 741, 666>, 0,
    <746, 666, 677>, 0,
    <746, 677, 559>, 0,
    <746, 559, 744>, 0,
    <746, 744, 743>, 0,
    <746, 743, 745>, 0,
    <748, 740, 739>, 0,
    <748, 739, 745>, 0,
    <748, 745, 743>, 0,
    <748, 743, 747>, 0,
    <748, 747, 716>, 0,
    <748, 716, 737>, 0,
    <748, 737, 732>, 0,
    <748, 732, 740>, 0,
    <757, 756, 749>, 0,
    <757, 749, 753>, 0,
    <757, 753, 750>, 0,
    <757, 750, 754>, 0,
    <757, 754, 751>, 0,
    <757, 751, 755>, 0,
    <757, 755, 752>, 0,
    <757, 752, 756>, 0,
    <763, 762, 749>, 0,
    <763, 749, 756>, 0,
    <763, 756, 752>, 0,
    <763, 752, 760>, 0,
    <763, 760, 758>, 0,
    <763, 758, 761>, 0,
    <763, 761, 759>, 0,
    <763, 759, 762>, 0,
    <766, 753, 749>, 0,
    <766, 749, 762>, 0,
    <766, 762, 759>, 0,
    <766, 759, 764>, 0,
    <766, 764, 685>, 0,
    <766, 685, 765>, 0,
    <766, 765, 750>, 0,
    <766, 750, 753>, 0,
    <770, 769, 767>, 0,
    <770, 767, 768>, 0,
    <770, 768, 686>, 0,
    <770, 686, 688>, 0,
    <770, 688, 685>, 0,
    <770, 685, 764>, 0,
    <770, 764, 759>, 0,
    <770, 759, 769>, 0,
    <774, 773, 767>, 0,
    <774, 767, 769>, 0,
    <774, 769, 759>, 0,
    <774, 759, 761>, 0,
    <774, 761, 758>, 0,
    <774, 758, 772>, 0,
    <774, 772, 771>, 0,
    <774, 771, 773>, 0,
    <776, 768, 767>, 0,
    <776, 767, 773>, 0,
    <776, 773, 771>, 0,
    <776, 771, 775>, 0,
    <776, 775, 601>, 0,
    <776, 601, 691>, 0,
    <776, 691, 686>, 0,
    <776, 686, 768>, 0,
    <785, 784, 777>, 0,
    <785, 777, 781>, 0,
    <785, 781, 778>, 0,
    <785, 778, 782>, 0,
    <785, 782, 779>, 0,
    <785, 779, 783>, 0,
    <785, 783, 780>, 0,
    <785, 780, 784>, 0,
    <788, 787, 777>, 0,
    <788, 777, 784>, 0,
    <788, 784, 780>, 0,
    <788, 780, 786>, 0,
    <788, 786, 758>, 0,
    <788, 758, 760>, 0,
    <788, 760, 752>, 0,
    <788, 752, 787>, 0,
    <790, 781, 777>, 0,
    <790, 777, 787>, 0,
    <790, 787, 752>, 0,
    <790, 752, 755>, 0,
    <790, 755, 751>, 0,
    <790, 751, 789>, 0,
    <790, 789, 778>, 0,
    <790, 778, 781>, 0,
    <799, 798, 791>, 0,
    <799, 791, 795>, 0,
    <799, 795, 792>, 0,
    <799, 792, 796>, 0,
    <799, 796, 793>, 0,
    <799, 793, 797>, 0,
    <799, 797, 794>, 0,
    <799, 794, 798>, 0,
    <802, 801, 791>, 0,
    <802, 791, 798>, 0,
    <802, 798, 794>, 0,
    <802, 794, 800>, 0,
    <802, 800, 722>, 0,
    <802, 722, 723>, 0,
    <802, 723, 717>, 0,
    <802, 717, 801>, 0,
    <804, 795, 791>, 0,
    <804, 791, 801>, 0,
    <804, 801, 717>, 0,
    <804, 717, 719>, 0,
    <804, 719, 716>, 0,
    <804, 716, 803>, 0,
    <804, 803, 792>, 0,
    <804, 792, 795>, 0,
    <813, 812, 805>, 0,
    <813, 805, 809>, 0,
    <813, 809, 806>, 0,
    <813, 806, 810>, 0,
    <813, 810, 807>, 0,
    <813, 807, 811>, 0,
    <813, 811, 808>, 0,
    <813, 808, 812>, 0,
    <816, 815, 805>, 0,
    <816, 805, 812>, 0,
    <816, 812, 808>, 0,
    <816, 808, 814>, 0,
    <816, 814, 758>, 0,
    <816, 758, 786>, 0,
    <816, 786, 780>, 0,
    <816, 780, 815>, 0,
    <818, 809, 805>, 0,
    <818, 805, 815>, 0,
    <818, 815, 780>, 0,
    <818, 780, 783>, 0,
    <818, 783, 779>, 0,
    <818, 779, 817>, 0,
    <818, 817, 806>, 0,
    <818, 806, 809>, 0,
    <827, 826, 819>, 0,
    <827, 819, 823>, 0,
    <827, 823, 820>, 0,
    <827, 820, 824>, 0,
    <827, 824, 821>, 0,
    <827, 821, 825>, 0,
    <827, 825, 822>, 0,
    <827, 822, 826>, 0,
    <830, 829, 819>, 0,
    <830, 819, 826>, 0,
    <830, 826, 822>, 0,
    <830, 822, 828>, 0,
    <830, 828, 489>, 0,
    <830, 489, 491>, 0,
    <830, 491, 483>, 0,
    <830, 483, 829>, 0,
    <832, 823, 819>, 0,
    <832, 819, 829>, 0,
    <832, 829, 483>, 0,
    <832, 483, 486>, 0,
    <832, 486, 482>, 0,
    <832, 482, 831>, 0,
    <832, 831, 820>, 0,
    <832, 820, 823>, 0,
    <841, 840, 833>, 0,
    <841, 833, 837>, 0,
    <841, 837, 834>, 0,
    <841, 834, 838>, 0,
    <841, 838, 835>, 0,
    <841, 835, 839>, 0,
    <841, 839, 836>, 0,
    <841, 836, 840>, 0,
    <847, 846, 833>, 0,
    <847, 833, 840>, 0,
    <847, 840, 836>, 0,
    <847, 836, 844>, 0,
    <847, 844, 842>, 0,
    <847, 842, 845>, 0,
    <847, 845, 843>, 0,
    <847, 843, 846>, 0,
    <850, 837, 833>, 0,
    <850, 833, 846>, 0,
    <850, 846, 843>, 0,
    <850, 843, 848>, 0,
    <850, 848, 821>, 0,
    <850, 821, 849>, 0,
    <850, 849, 834>, 0,
    <850, 834, 837>, 0,
    <854, 853, 851>, 0,
    <854, 851, 852>, 0,
    <854, 852, 822>, 0,
    <854, 822, 825>, 0,
    <854, 825, 821>, 0,
    <854, 821, 848>, 0,
    <854, 848, 843>, 0,
    <854, 843, 853>, 0,
    <858, 857, 851>, 0,
    <858, 851, 853>, 0,
    <858, 853, 843>, 0,
    <858, 843, 845>, 0,
    <858, 845, 842>, 0,
    <858, 842, 856>, 0,
    <858, 856, 855>, 0,
    <858, 855, 857>, 0,
    <860, 852, 851>, 0,
    <860, 851, 857>, 0,
    <860, 857, 855>, 0,
    <860, 855, 859>, 0,
    <860, 859, 489>, 0,
    <860, 489, 828>, 0,
    <860, 828, 822>, 0,
    <860, 822, 852>, 0,
    <866, 865, 861>, 0,
    <866, 861, 863>, 0,
    <866, 863, 862>, 0,
    <866, 862, 864>, 0,
    <866, 864, 695>, 0,
    <866, 695, 698>, 0,
    <866, 698, 694>, 0,
    <866, 694, 865>, 0,
    <870, 869, 861>, 0,
    <870, 861, 865>, 0,
    <870, 865, 694>, 0,
    <870, 694, 705>, 0,
    <870, 705, 518>, 0,
    <870, 518, 868>, 0,
    <870, 868, 867>, 0,
    <870, 867, 869>, 0,
    <874, 863, 861>, 0,
    <874, 861, 869>, 0,
    <874, 869, 867>, 0,
    <874, 867, 872>, 0,
    <874, 872, 871>, 0,
    <874, 871, 873>, 0,
    <874, 873, 862>, 0,
    <874, 862, 863>, 0,
    <880, 879, 875>, 0,
    <880, 875, 877>, 0,
    <880, 877, 876>, 0,
    <880, 876, 878>, 0,
    <880, 878, 695>, 0,
    <880, 695, 864>, 0,
    <880, 864, 862>, 0,
    <880, 862, 879>, 0,
    <884, 883, 875>, 0,
    <884, 875, 879>, 0,
    <884, 879, 862>, 0,
    <884, 862, 873>, 0,
    <884, 873, 871>, 0,
    <884, 871, 882>, 0,
    <884, 882, 881>, 0,
    <884, 881, 883>, 0,
    <888, 877, 875>, 0,
    <888, 875, 883>, 0,
    <888, 883, 881>, 0,
    <888, 881, 886>, 0,
    <888, 886, 885>, 0,
    <888, 885, 887>, 0,
    <888, 887, 876>, 0,
    <888, 876, 877>, 0,
    <894, 893, 889>, 0,
    <894, 889, 891>, 0,
    <894, 891, 890>, 0,
    <894, 890, 892>, 0,
    <894, 892, 885>, 0,
    <894, 885, 886>, 0,
    <894, 886, 881>, 0,
    <894, 881, 893>, 0,
    <898, 897, 889>, 0,
    <898, 889, 893>, 0,
    <898, 893, 881>, 0,
    <898, 881, 882>, 0,
    <898, 882, 871>, 0,
    <898, 871, 896>, 0,
    <898, 896, 895>, 0,
    <898, 895, 897>, 0,
    <902, 891, 889>, 0,
    <902, 889, 897>, 0,
    <902, 897, 895>, 0,
    <902, 895, 900>, 0,
    <902, 900, 899>, 0,
    <902, 899, 901>, 0,
    <902, 901, 890>, 0,
    <902, 890, 891>, 0,
    <911, 910, 903>, 0,
    <911, 903, 907>, 0,
    <911, 907, 904>, 0,
    <911, 904, 908>, 0,
    <911, 908, 905>, 0,
    <911, 905, 909>, 0,
    <911, 909, 906>, 0,
    <911, 906, 910>, 0,
    <914, 913, 903>, 0,
    <914, 903, 910>, 0,
    <914, 910, 906>, 0,
    <914, 906, 912>, 0,
    <914, 912, 793>, 0,
    <914, 793, 796>, 0,
    <914, 796, 792>, 0,
    <914, 792, 913>, 0,
    <916, 907, 903>, 0,
    <916, 903, 913>, 0,
    <916, 913, 792>, 0,
    <916, 792, 803>, 0,
    <916, 803, 716>, 0,
    <916, 716, 915>, 0,
    <916, 915, 904>, 0,
    <916, 904, 907>, 0,
    <922, 921, 917>, 0,
    <922, 917, 919>, 0,
    <922, 919, 808>, 0,
    <922, 808, 811>, 0,
    <922, 811, 807>, 0,
    <922, 807, 920>, 0,
    <922, 920, 918>, 0,
    <922, 918, 921>, 0,
    <928, 927, 917>, 0,
    <928, 917, 921>, 0,
    <928, 921, 918>, 0,
    <928, 918, 925>, 0,
    <928, 925, 923>, 0,
    <928, 923, 926>, 0,
    <928, 926, 924>, 0,
    <928, 924, 927>, 0,
    <930, 919, 917>, 0,
    <930, 917, 927>, 0,
    <930, 927, 924>, 0,
    <930, 924, 929>, 0,
    <930, 929, 758>, 0,
    <930, 758, 814>, 0,
    <930, 814, 808>, 0,
    <930, 808, 919>, 0,
    <939, 938, 931>, 0,
    <939, 931, 935>, 0,
    <939, 935, 932>, 0,
    <939, 932, 936>, 0,
    <939, 936, 933>, 0,
    <939, 933, 937>, 0,
    <939, 937, 934>, 0,
    <939, 934, 938>, 0,
    <945, 944, 931>, 0,
    <945, 931, 938>, 0,
    <945, 938, 934>, 0,
    <945, 934, 942>, 0,
    <945, 942, 940>, 0,
    <945, 940, 943>, 0,
    <945, 943, 941>, 0,
    <945, 941, 944>, 0,
    <949, 935, 931>, 0,
    <949, 931, 944>, 0,
    <949, 944, 941>, 0,
    <949, 941, 947>, 0,
    <949, 947, 946>, 0,
    <949, 946, 948>, 0,
    <949, 948, 932>, 0,
    <949, 932, 935>, 0,
    <955, 954, 950>, 0,
    <955, 950, 952>, 0,
    <955, 952, 934>, 0,
    <955, 934, 937>, 0,
    <955, 937, 933>, 0,
    <955, 933, 953>, 0,
    <955, 953, 951>, 0,
    <955, 951, 954>, 0,
    <960, 959, 950>, 0,
    <960, 950, 954>, 0,
    <960, 954, 951>, 0,
    <960, 951, 957>, 0,
    <960, 957, 905>, 0,
    <960, 905, 958>, 0,
    <960, 958, 956>, 0,
    <960, 956, 959>, 0,
    <962, 952, 950>, 0,
    <962, 950, 959>, 0,
    <962, 959, 956>, 0,
    <962, 956, 961>, 0,
    <962, 961, 940>, 0,
    <962, 940, 942>, 0,
    <962, 942, 934>, 0,
    <962, 934, 952>, 0,
    <966, 965, 963>, 0,
    <966, 963, 964>, 0,
    <966, 964, 956>, 0,
    <966, 956, 958>, 0,
    <966, 958, 905>, 0,
    <966, 905, 908>, 0,
    <966, 908, 904>, 0,
    <966, 904, 965>, 0,
    <970, 969, 963>, 0,
    <970, 963, 965>, 0,
    <970, 965, 904>, 0,
    <970, 904, 915>, 0,
    <970, 915, 716>, 0,
    <970, 716, 968>, 0,
    <970, 968, 967>, 0,
    <970, 967, 969>, 0,
    <972, 964, 963>, 0,
    <972, 963, 969>, 0,
    <972, 969, 967>, 0,
    <972, 967, 971>, 0,
    <972, 971, 940>, 0,
    <972, 940, 961>, 0,
    <972, 961, 956>, 0,
    <972, 956, 964>, 0,
    <981, 980, 973>, 0,
    <981, 973, 977>, 0,
    <981, 977, 974>, 0,
    <981, 974, 978>, 0,
    <981, 978, 975>, 0,
    <981, 975, 979>, 0,
    <981, 979, 976>, 0,
    <981, 976, 980>, 0,
    <987, 986, 973>, 0,
    <987, 973, 980>, 0,
    <987, 980, 976>, 0,
    <987, 976, 984>, 0,
    <987, 984, 982>, 0,
    <987, 982, 985>, 0,
    <987, 985, 983>, 0,
    <987, 983, 986>, 0,
    <990, 977, 973>, 0,
    <990, 973, 986>, 0,
    <990, 986, 983>, 0,
    <990, 983, 988>, 0,
    <990, 988, 923>, 0,
    <990, 923, 989>, 0,
    <990, 989, 974>, 0,
    <990, 974, 977>, 0,
    <994, 993, 991>, 0,
    <994, 991, 992>, 0,
    <994, 992, 924>, 0,
    <994, 924, 926>, 0,
    <994, 926, 923>, 0,
    <994, 923, 988>, 0,
    <994, 988, 983>, 0,
    <994, 983, 993>, 0,
    <998, 997, 991>, 0,
    <998, 991, 993>, 0,
    <998, 993, 983>, 0,
    <998, 983, 985>, 0,
    <998, 985, 982>, 0,
    <998, 982, 996>, 0,
    <998, 996, 995>, 0,
    <998, 995, 997>, 0,
    <1000, 992, 991>, 0,
    <1000, 991, 997>, 0,
    <1000, 997, 995>, 0,
    <1000, 995, 999>, 0,
    <1000, 999, 758>, 0,
    <1000, 758, 929>, 0,
    <1000, 929, 924>, 0,
    <1000, 924, 992>, 0,
    <1009, 1008, 1001>, 0,
    <1009, 1001, 1005>, 0,
    <1009, 1005, 1002>, 0,
    <1009, 1002, 1006>, 0,
    <1009, 1006, 1003>, 0,
    <1009, 1003, 1007>, 0,
    <1009, 1007, 1004>, 0,
    <1009, 1004, 1008>, 0,
    <1012, 1011, 1001>, 0,
    <1012, 1001, 1008>, 0,
    <1012, 1008, 1004>, 0,
    <1012, 1004, 1010>, 0,
    <1012, 1010, 982>, 0,
    <1012, 982, 984>, 0,
    <1012, 984, 976>, 0,
    <1012, 976, 1011>, 0,
    <1014, 1005, 1001>, 0,
    <1014, 1001, 1011>, 0,
    <1014, 1011, 976>, 0,
    <1014, 976, 979>, 0,
    <1014, 979, 975>, 0,
    <1014, 975, 1013>, 0,
    <1014, 1013, 1002>, 0,
    <1014, 1002, 1005>, 0,
    <1023, 1022, 1015>, 0,
    <1023, 1015, 1019>, 0,
    <1023, 1019, 1016>, 0,
    <1023, 1016, 1020>, 0,
    <1023, 1020, 1017>, 0,
    <1023, 1017, 1021>, 0,
    <1023, 1021, 1018>, 0,
    <1023, 1018, 1022>, 0,
    <1026, 1025, 1015>, 0,
    <1026, 1015, 1022>, 0,
    <1026, 1022, 1018>, 0,
    <1026, 1018, 1024>, 0,
    <1026, 1024, 899>, 0,
    <1026, 899, 900>, 0,
    <1026, 900, 895>, 0,
    <1026, 895, 1025>, 0,
    <1028, 1019, 1015>, 0,
    <1028, 1015, 1025>, 0,
    <1028, 1025, 895>, 0,
    <1028, 895, 896>, 0,
    <1028, 896, 871>, 0,
    <1028, 871, 1027>, 0,
    <1028, 1027, 1016>, 0,
    <1028, 1016, 1019>, 0,
    <1037, 1036, 1029>, 0,
    <1037, 1029, 1033>, 0,
    <1037, 1033, 1030>, 0,
    <1037, 1030, 1034>, 0,
    <1037, 1034, 1031>, 0,
    <1037, 1031, 1035>, 0,
    <1037, 1035, 1032>, 0,
    <1037, 1032, 1036>, 0,
    <1040, 1039, 1029>, 0,
    <1040, 1029, 1036>, 0,
    <1040, 1036, 1032>, 0,
    <1040, 1032, 1038>, 0,
    <1040, 1038, 842>, 0,
    <1040, 842, 844>, 0,
    <1040, 844, 836>, 0,
    <1040, 836, 1039>, 0,
    <1042, 1033, 1029>, 0,
    <1042, 1029, 1039>, 0,
    <1042, 1039, 836>, 0,
    <1042, 836, 839>, 0,
    <1042, 839, 835>, 0,
    <1042, 835, 1041>, 0,
    <1042, 1041, 1030>, 0,
    <1042, 1030, 1033>, 0,
    <1051, 1050, 1043>, 0,
    <1051, 1043, 1047>, 0,
    <1051, 1047, 1044>, 0,
    <1051, 1044, 1048>, 0,
    <1051, 1048, 1045>, 0,
    <1051, 1045, 1049>, 0,
    <1051, 1049, 1046>, 0,
    <1051, 1046, 1050>, 0,
    <1057, 1056, 1043>, 0,
    <1057, 1043, 1050>, 0,
    <1057, 1050, 1046>, 0,
    <1057, 1046, 1054>, 0,
    <1057, 1054, 1052>, 0,
    <1057, 1052, 1055>, 0,
    <1057, 1055, 1053>, 0,
    <1057, 1053, 1056>, 0,
    <1060, 1047, 1043>, 0,
    <1060, 1043, 1056>, 0,
    <1060, 1056, 1053>, 0,
    <1060, 1053, 1058>, 0,
    <1060, 1058, 1031>, 0,
    <1060, 1031, 1059>, 0,
    <1060, 1059, 1044>, 0,
    <1060, 1044, 1047>, 0,
    <1064, 1063, 1061>, 0,
    <1064, 1061, 1062>, 0,
    <1064, 1062, 1032>, 0,
    <1064, 1032, 1035>, 0,
    <1064, 1035, 1031>, 0,
    <1064, 1031, 1058>, 0,
    <1064, 1058, 1053>, 0,
    <1064, 1053, 1063>, 0,
    <1068, 1067, 1061>, 0,
    <1068, 1061, 1063>, 0,
    <1068, 1063, 1053>, 0,
    <1068, 1053, 1055>, 0,
    <1068, 1055, 1052>, 0,
    <1068, 1052, 1066>, 0,
    <1068, 1066, 1065>, 0,
    <1068, 1065, 1067>, 0,
    <1070, 1062, 1061>, 0,
    <1070, 1061, 1067>, 0,
    <1070, 1067, 1065>, 0,
    <1070, 1065, 1069>, 0,
    <1070, 1069, 842>, 0,
    <1070, 842, 1038>, 0,
    <1070, 1038, 1032>, 0,
    <1070, 1032, 1062>, 0,
    <1076, 1075, 1071>, 0,
    <1076, 1071, 1073>, 0,
    <1076, 1073, 1072>, 0,
    <1076, 1072, 1074>, 0,
    <1076, 1074, 1017>, 0,
    <1076, 1017, 1020>, 0,
    <1076, 1020, 1016>, 0,
    <1076, 1016, 1075>, 0,
    <1080, 1079, 1071>, 0,
    <1080, 1071, 1075>, 0,
    <1080, 1075, 1016>, 0,
    <1080, 1016, 1027>, 0,
    <1080, 1027, 871>, 0,
    <1080, 871, 1078>, 0,
    <1080, 1078, 1077>, 0,
    <1080, 1077, 1079>, 0,
    <1084, 1073, 1071>, 0,
    <1084, 1071, 1079>, 0,
    <1084, 1079, 1077>, 0,
    <1084, 1077, 1082>, 0,
    <1084, 1082, 1081>, 0,
    <1084, 1081, 1083>, 0,
    <1084, 1083, 1072>, 0,
    <1084, 1072, 1073>, 0,
    <1093, 1092, 1085>, 0,
    <1093, 1085, 1089>, 0,
    <1093, 1089, 1086>, 0,
    <1093, 1086, 1090>, 0,
    <1093, 1090, 1087>, 0,
    <1093, 1087, 1091>, 0,
    <1093, 1091, 1088>, 0,
    <1093, 1088, 1092>, 0,
    <1096, 1095, 1085>, 0,
    <1096, 1085, 1092>, 0,
    <1096, 1092, 1088>, 0,
    <1096, 1088, 1094>, 0,
    <1096, 1094, 1017>, 0,
    <1096, 1017, 1074>, 0,
    <1096, 1074, 1072>, 0,
    <1096, 1072, 1095>, 0,
    <1098, 1089, 1085>, 0,
    <1098, 1085, 1095>, 0,
    <1098, 1095, 1072>, 0,
    <1098, 1072, 1083>, 0,
    <1098, 1083, 1081>, 0,
    <1098, 1081, 1097>, 0,
    <1098, 1097, 1086>, 0,
    <1098, 1086, 1089>, 0,
    <1104, 1103, 1099>, 0,
    <1104, 1099, 1101>, 0,
    <1104, 1101, 1100>, 0,
    <1104, 1100, 1102>, 0,
    <1104, 1102, 1087>, 0,
    <1104, 1087, 1090>, 0,
    <1104, 1090, 1086>, 0,
    <1104, 1086, 1103>, 0,
    <1108, 1107, 1099>, 0,
    <1108, 1099, 1103>, 0,
    <1108, 1103, 1086>, 0,
    <1108, 1086, 1097>, 0,
    <1108, 1097, 1081>, 0,
    <1108, 1081, 1106>, 0,
    <1108, 1106, 1105>, 0,
    <1108, 1105, 1107>, 0,
    <1112, 1101, 1099>, 0,
    <1112, 1099, 1107>, 0,
    <1112, 1107, 1105>, 0,
    <1112, 1105, 1110>, 0,
    <1112, 1110, 1109>, 0,
    <1112, 1109, 1111>, 0,
    <1112, 1111, 1100>, 0,
    <1112, 1100, 1101>, 0,
    <1121, 1120, 1113>, 0,
    <1121, 1113, 1117>, 0,
    <1121, 1117, 1114>, 0,
    <1121, 1114, 1118>, 0,
    <1121, 1118, 1115>, 0,
    <1121, 1115, 1119>, 0,
    <1121, 1119, 1116>, 0,
    <1121, 1116, 1120>, 0,
    <1124, 1123, 1113>, 0,
    <1124, 1113, 1120>, 0,
    <1124, 1120, 1116>, 0,
    <1124, 1116, 1122>, 0,
    <1124, 1122, 946>, 0,
    <1124, 946, 947>, 0,
    <1124, 947, 941>, 0,
    <1124, 941, 1123>, 0,
    <1126, 1117, 1113>, 0,
    <1126, 1113, 1123>, 0,
    <1126, 1123, 941>, 0,
    <1126, 941, 943>, 0,
    <1126, 943, 940>, 0,
    <1126, 940, 1125>, 0,
    <1126, 1125, 1114>, 0,
    <1126, 1114, 1117>, 0,
    <1135, 1134, 1127>, 0,
    <1135, 1127, 1131>, 0,
    <1135, 1131, 1128>, 0,
    <1135, 1128, 1132>, 0,
    <1135, 1132, 1129>, 0,
    <1135, 1129, 1133>, 0,
    <1135, 1133, 1130>, 0,
    <1135, 1130, 1134>, 0,
    <1138, 1137, 1127>, 0,
    <1138, 1127, 1134>, 0,
    <1138, 1134, 1130>, 0,
    <1138, 1130, 1136>, 0,
    <1138, 1136, 982>, 0,
    <1138, 982, 1010>, 0,
    <1138, 1010, 1004>, 0,
    <1138, 1004, 1137>, 0,
    <1140, 1131, 1127>, 0,
    <1140, 1127, 1137>, 0,
    <1140, 1137, 1004>, 0,
    <1140, 1004, 1007>, 0,
    <1140, 1007, 1003>, 0,
    <1140, 1003, 1139>, 0,
    <1140, 1139, 1128>, 0,
    <1140, 1128, 1131>, 0,
    <1149, 1148, 1141>, 0,
    <1149, 1141, 1145>, 0,
    <1149, 1145, 1142>, 0,
    <1149, 1142, 1146>, 0,
    <1149, 1146, 1143>, 0,
    <1149, 1143, 1147>, 0,
    <1149, 1147, 1144>, 0,
    <1149, 1144, 1148>, 0,
    <1155, 1154, 1141>, 0,
    <1155, 1141, 1148>, 0,
    <1155, 1148, 1144>, 0,
    <1155, 1144, 1152>, 0,
    <1155, 1152, 1150>, 0,
    <1155, 1150, 1153>, 0,
    <1155, 1153, 1151>, 0,
    <1155, 1151, 1154>, 0,
    <1159, 1145, 1141>, 0,
    <1159, 1141, 1154>, 0,
    <1159, 1154, 1151>, 0,
    <1159, 1151, 1157>, 0,
    <1159, 1157, 1156>, 0,
    <1159, 1156, 1158>, 0,
    <1159, 1158, 1142>, 0,
    <1159, 1142, 1145>, 0,
    <1165, 1164, 1160>, 0,
    <1165, 1160, 1162>, 0,
    <1165, 1162, 1144>, 0,
    <1165, 1144, 1147>, 0,
    <1165, 1147, 1143>, 0,
    <1165, 1143, 1163>, 0,
    <1165, 1163, 1161>, 0,
    <1165, 1161, 1164>, 0,
    <1170, 1169, 1160>, 0,
    <1170, 1160, 1164>, 0,
    <1170, 1164, 1161>, 0,
    <1170, 1161, 1167>, 0,
    <1170, 1167, 1115>, 0,
    <1170, 1115, 1168>, 0,
    <1170, 1168, 1166>, 0,
    <1170, 1166, 1169>, 0,
    <1172, 1162, 1160>, 0,
    <1172, 1160, 1169>, 0,
    <1172, 1169, 1166>, 0,
    <1172, 1166, 1171>, 0,
    <1172, 1171, 1150>, 0,
    <1172, 1150, 1152>, 0,
    <1172, 1152, 1144>, 0,
    <1172, 1144, 1162>, 0,
    <1176, 1175, 1173>, 0,
    <1176, 1173, 1174>, 0,
    <1176, 1174, 1166>, 0,
    <1176, 1166, 1168>, 0,
    <1176, 1168, 1115>, 0,
    <1176, 1115, 1118>, 0,
    <1176, 1118, 1114>, 0,
    <1176, 1114, 1175>, 0,
    <1180, 1179, 1173>, 0,
    <1180, 1173, 1175>, 0,
    <1180, 1175, 1114>, 0,
    <1180, 1114, 1125>, 0,
    <1180, 1125, 940>, 0,
    <1180, 940, 1178>, 0,
    <1180, 1178, 1177>, 0,
    <1180, 1177, 1179>, 0,
    <1182, 1174, 1173>, 0,
    <1182, 1173, 1179>, 0,
    <1182, 1179, 1177>, 0,
    <1182, 1177, 1181>, 0,
    <1182, 1181, 1150>, 0,
    <1182, 1150, 1171>, 0,
    <1182, 1171, 1166>, 0,
    <1182, 1166, 1174>, 0,
    <1191, 1190, 1183>, 0,
    <1191, 1183, 1187>, 0,
    <1191, 1187, 1184>, 0,
    <1191, 1184, 1188>, 0,
    <1191, 1188, 1185>, 0,
    <1191, 1185, 1189>, 0,
    <1191, 1189, 1186>, 0,
    <1191, 1186, 1190>, 0,
    <1197, 1196, 1183>, 0,
    <1197, 1183, 1190>, 0,
    <1197, 1190, 1186>, 0,
    <1197, 1186, 1194>, 0,
    <1197, 1194, 1192>, 0,
    <1197, 1192, 1195>, 0,
    <1197, 1195, 1193>, 0,
    <1197, 1193, 1196>, 0,
    <1200, 1187, 1183>, 0,
    <1200, 1183, 1196>, 0,
    <1200, 1196, 1193>, 0,
    <1200, 1193, 1198>, 0,
    <1200, 1198, 1129>, 0,
    <1200, 1129, 1199>, 0,
    <1200, 1199, 1184>, 0,
    <1200, 1184, 1187>, 0,
    <1204, 1203, 1201>, 0,
    <1204, 1201, 1202>, 0,
    <1204, 1202, 1130>, 0,
    <1204, 1130, 1133>, 0,
    <1204, 1133, 1129>, 0,
    <1204, 1129, 1198>, 0,
    <1204, 1198, 1193>, 0,
    <1204, 1193, 1203>, 0,
    <1208, 1207, 1201>, 0,
    <1208, 1201, 1203>, 0,
    <1208, 1203, 1193>, 0,
    <1208, 1193, 1195>, 0,
    <1208, 1195, 1192>, 0,
    <1208, 1192, 1206>, 0,
    <1208, 1206, 1205>, 0,
    <1208, 1205, 1207>, 0,
    <1210, 1202, 1201>, 0,
    <1210, 1201, 1207>, 0,
    <1210, 1207, 1205>, 0,
    <1210, 1205, 1209>, 0,
    <1210, 1209, 982>, 0,
    <1210, 982, 1136>, 0,
    <1210, 1136, 1130>, 0,
    <1210, 1130, 1202>, 0,
    <1219, 1218, 1211>, 0,
    <1219, 1211, 1215>, 0,
    <1219, 1215, 1212>, 0,
    <1219, 1212, 1216>, 0,
    <1219, 1216, 1213>, 0,
    <1219, 1213, 1217>, 0,
    <1219, 1217, 1214>, 0,
    <1219, 1214, 1218>, 0,
    <1222, 1221, 1211>, 0,
    <1222, 1211, 1218>, 0,
    <1222, 1218, 1214>, 0,
    <1222, 1214, 1220>, 0,
    <1222, 1220, 1192>, 0,
    <1222, 1192, 1194>, 0,
    <1222, 1194, 1186>, 0,
    <1222, 1186, 1221>, 0,
    <1224, 1215, 1211>, 0,
    <1224, 1211, 1221>, 0,
    <1224, 1221, 1186>, 0,
    <1224, 1186, 1189>, 0,
    <1224, 1189, 1185>, 0,
    <1224, 1185, 1223>, 0,
    <1224, 1223, 1212>, 0,
    <1224, 1212, 1215>, 0,
    <1233, 1232, 1225>, 0,
    <1233, 1225, 1229>, 0,
    <1233, 1229, 1226>, 0,
    <1233, 1226, 1230>, 0,
    <1233, 1230, 1227>, 0,
    <1233, 1227, 1231>, 0,
    <1233, 1231, 1228>, 0,
    <1233, 1228, 1232>, 0,
    <1236, 1235, 1225>, 0,
    <1236, 1225, 1232>, 0,
    <1236, 1232, 1228>, 0,
    <1236, 1228, 1234>, 0,
    <1236, 1234, 1192>, 0,
    <1236, 1192, 1220>, 0,
    <1236, 1220, 1214>, 0,
    <1236, 1214, 1235>, 0,
    <1238, 1229, 1225>, 0,
    <1238, 1225, 1235>, 0,
    <1238, 1235, 1214>, 0,
    <1238, 1214, 1217>, 0,
    <1238, 1217, 1213>, 0,
    <1238, 1213, 1237>, 0,
    <1238, 1237, 1226>, 0,
    <1238, 1226, 1229>, 0,
    <1247, 1246, 1239>, 0,
    <1247, 1239, 1243>, 0,
    <1247, 1243, 1240>, 0,
    <1247, 1240, 1244>, 0,
    <1247, 1244, 1241>, 0,
    <1247, 1241, 1245>, 0,
    <1247, 1245, 1242>, 0,
    <1247, 1242, 1246>, 0,
    <1250, 1249, 1239>, 0,
    <1250, 1239, 1246>, 0,
    <1250, 1246, 1242>, 0,
    <1250, 1242, 1248>, 0,
    <1250, 1248, 1156>, 0,
    <1250, 1156, 1157>, 0,
    <1250, 1157, 1151>, 0,
    <1250, 1151, 1249>, 0,
    <1252, 1243, 1239>, 0,
    <1252, 1239, 1249>, 0,
    <1252, 1249, 1151>, 0,
    <1252, 1151, 1153>, 0,
    <1252, 1153, 1150>, 0,
    <1252, 1150, 1251>, 0,
    <1252, 1251, 1240>, 0,
    <1252, 1240, 1243>, 0,
    <1261, 1260, 1253>, 0,
    <1261, 1253, 1257>, 0,
    <1261, 1257, 1254>, 0,
    <1261, 1254, 1258>, 0,
    <1261, 1258, 1255>, 0,
    <1261, 1255, 1259>, 0,
    <1261, 1259, 1256>, 0,
    <1261, 1256, 1260>, 0,
    <1264, 1263, 1253>, 0,
    <1264, 1253, 1260>, 0,
    <1264, 1260, 1256>, 0,
    <1264, 1256, 1262>, 0,
    <1264, 1262, 1109>, 0,
    <1264, 1109, 1110>, 0,
    <1264, 1110, 1105>, 0,
    <1264, 1105, 1263>, 0,
    <1266, 1257, 1253>, 0,
    <1266, 1253, 1263>, 0,
    <1266, 1263, 1105>, 0,
    <1266, 1105, 1106>, 0,
    <1266, 1106, 1081>, 0,
    <1266, 1081, 1265>, 0,
    <1266, 1265, 1254>, 0,
    <1266, 1254, 1257>, 0,
    <1275, 1274, 1267>, 0,
    <1275, 1267, 1271>, 0,
    <1275, 1271, 1268>, 0,
    <1275, 1268, 1272>, 0,
    <1275, 1272, 1269>, 0,
    <1275, 1269, 1273>, 0,
    <1275, 1273, 1270>, 0,
    <1275, 1270, 1274>, 0,
    <1278, 1277, 1267>, 0,
    <1278, 1267, 1274>, 0,
    <1278, 1274, 1270>, 0,
    <1278, 1270, 1276>, 0,
    <1278, 1276, 1241>, 0,
    <1278, 1241, 1244>, 0,
    <1278, 1244, 1240>, 0,
    <1278, 1240, 1277>, 0,
    <1280, 1271, 1267>, 0,
    <1280, 1267, 1277>, 0,
    <1280, 1277, 1240>, 0,
    <1280, 1240, 1251>, 0,
    <1280, 1251, 1150>, 0,
    <1280, 1150, 1279>, 0,
    <1280, 1279, 1268>, 0,
    <1280, 1268, 1271>, 0,
    <1286, 1285, 1281>, 0,
    <1286, 1281, 1283>, 0,
    <1286, 1283, 1228>, 0,
    <1286, 1228, 1231>, 0,
    <1286, 1231, 1227>, 0,
    <1286, 1227, 1284>, 0,
    <1286, 1284, 1282>, 0,
    <1286, 1282, 1285>, 0,
    <1292, 1291, 1281>, 0,
    <1292, 1281, 1285>, 0,
    <1292, 1285, 1282>, 0,
    <1292, 1282, 1289>, 0,
    <1292, 1289, 1287>, 0,
    <1292, 1287, 1290>, 0,
    <1292, 1290, 1288>, 0,
    <1292, 1288, 1291>, 0,
    <1294, 1283, 1281>, 0,
    <1294, 1281, 1291>, 0,
    <1294, 1291, 1288>, 0,
    <1294, 1288, 1293>, 0,
    <1294, 1293, 1192>, 0,
    <1294, 1192, 1234>, 0,
    <1294, 1234, 1228>, 0,
    <1294, 1228, 1283>, 0,
    <1303, 1302, 1295>, 0,
    <1303, 1295, 1299>, 0,
    <1303, 1299, 1296>, 0,
    <1303, 1296, 1300>, 0,
    <1303, 1300, 1297>, 0,
    <1303, 1297, 1301>, 0,
    <1303, 1301, 1298>, 0,
    <1303, 1298, 1302>, 0,
    <1306, 1305, 1295>, 0,
    <1306, 1295, 1302>, 0,
    <1306, 1302, 1298>, 0,
    <1306, 1298, 1304>, 0,
    <1306, 1304, 1052>, 0,
    <1306, 1052, 1054>, 0,
    <1306, 1054, 1046>, 0,
    <1306, 1046, 1305>, 0,
    <1308, 1299, 1295>, 0,
    <1308, 1295, 1305>, 0,
    <1308, 1305, 1046>, 0,
    <1308, 1046, 1049>, 0,
    <1308, 1049, 1045>, 0,
    <1308, 1045, 1307>, 0,
    <1308, 1307, 1296>, 0,
    <1308, 1296, 1299>, 0,
    <1317, 1316, 1309>, 0,
    <1317, 1309, 1313>, 0,
    <1317, 1313, 1310>, 0,
    <1317, 1310, 1314>, 0,
    <1317, 1314, 1311>, 0,
    <1317, 1311, 1315>, 0,
    <1317, 1315, 1312>, 0,
    <1317, 1312, 1316>, 0,
    <1323, 1322, 1309>, 0,
    <1323, 1309, 1316>, 0,
    <1323, 1316, 1312>, 0,
    <1323, 1312, 1320>, 0,
    <1323, 1320, 1318>, 0,
    <1323, 1318, 1321>, 0,
    <1323, 1321, 1319>, 0,
    <1323, 1319, 1322>, 0,
    <1326, 1313, 1309>, 0,
    <1326, 1309, 1322>, 0,
    <1326, 1322, 1319>, 0,
    <1326, 1319, 1324>, 0,
    <1326, 1324, 1297>, 0,
    <1326, 1297, 1325>, 0,
    <1326, 1325, 1310>, 0,
    <1326, 1310, 1313>, 0,
    <1330, 1329, 1327>, 0,
    <1330, 1327, 1328>, 0,
    <1330, 1328, 1298>, 0,
    <1330, 1298, 1301>, 0,
    <1330, 1301, 1297>, 0,
    <1330, 1297, 1324>, 0,
    <1330, 1324, 1319>, 0,
    <1330, 1319, 1329>, 0,
    <1334, 1333, 1327>, 0,
    <1334, 1327, 1329>, 0,
    <1334, 1329, 1319>, 0,
    <1334, 1319, 1321>, 0,
    <1334, 1321, 1318>, 0,
    <1334, 1318, 1332>, 0,
    <1334, 1332, 1331>, 0,
    <1334, 1331, 1333>, 0,
    <1336, 1328, 1327>, 0,
    <1336, 1327, 1333>, 0,
    <1336, 1333, 1331>, 0,
    <1336, 1331, 1335>, 0,
    <1336, 1335, 1052>, 0,
    <1336, 1052, 1304>, 0,
    <1336, 1304, 1298>, 0,
    <1336, 1298, 1328>, 0,
    <1344, 1343, 1337>, 0,
    <1344, 1337, 1340>, 0,
    <1344, 1340, 1338>, 0,
    <1344, 1338, 1341>, 0,
    <1344, 1341, 1081>, 0,
    <1344, 1081, 1342>, 0,
    <1344, 1342, 1339>, 0,
    <1344, 1339, 1343>, 0,
    <1350, 1349, 1337>, 0,
    <1350, 1337, 1343>, 0,
    <1350, 1343, 1339>, 0,
    <1350, 1339, 1347>, 0,
    <1350, 1347, 1345>, 0,
    <1350, 1345, 1348>, 0,
    <1350, 1348, 1346>, 0,
    <1350, 1346, 1349>, 0,
    <1354, 1340, 1337>, 0,
    <1354, 1337, 1349>, 0,
    <1354, 1349, 1346>, 0,
    <1354, 1346, 1352>, 0,
    <1354, 1352, 1351>, 0,
    <1354, 1351, 1353>, 0,
    <1354, 1353, 1338>, 0,
    <1354, 1338, 1340>, 0,
    <1360, 1359, 1355>, 0,
    <1360, 1355, 1357>, 0,
    <1360, 1357, 1356>, 0,
    <1360, 1356, 1358>, 0,
    <1360, 1358, 1255>, 0,
    <1360, 1255, 1258>, 0,
    <1360, 1258, 1254>, 0,
    <1360, 1254, 1359>, 0,
    <1364, 1363, 1355>, 0,
    <1364, 1355, 1359>, 0,
    <1364, 1359, 1254>, 0,
    <1364, 1254, 1265>, 0,
    <1364, 1265, 1081>, 0,
    <1364, 1081, 1362>, 0,
    <1364, 1362, 1361>, 0,
    <1364, 1361, 1363>, 0,
    <1367, 1357, 1355>, 0,
    <1367, 1355, 1363>, 0,
    <1367, 1363, 1361>, 0,
    <1367, 1361, 1365>, 0,
    <1367, 1365, 1345>, 0,
    <1367, 1345, 1366>, 0,
    <1367, 1366, 1356>, 0,
    <1367, 1356, 1357>, 0,
    <1376, 1375, 1368>, 0,
    <1376, 1368, 1372>, 0,
    <1376, 1372, 1369>, 0,
    <1376, 1369, 1373>, 0,
    <1376, 1373, 1370>, 0,
    <1376, 1370, 1374>, 0,
    <1376, 1374, 1371>, 0,
    <1376, 1371, 1375>, 0,
    <1379, 1378, 1368>, 0,
    <1379, 1368, 1375>, 0,
    <1379, 1375, 1371>, 0,
    <1379, 1371, 1377>, 0,
    <1379, 1377, 1255>, 0,
    <1379, 1255, 1358>, 0,
    <1379, 1358, 1356>, 0,
    <1379, 1356, 1378>, 0,
    <1381, 1372, 1368>, 0,
    <1381, 1368, 1378>, 0,
    <1381, 1378, 1356>, 0,
    <1381, 1356, 1366>, 0,
    <1381, 1366, 1345>, 0,
    <1381, 1345, 1380>, 0,
    <1381, 1380, 1369>, 0,
    <1381, 1369, 1372>, 0,
    <1387, 1386, 1382>, 0,
    <1387, 1382, 1384>, 0,
    <1387, 1384, 1383>, 0,
    <1387, 1383, 1385>, 0,
    <1387, 1385, 1370>, 0,
    <1387, 1370, 1373>, 0,
    <1387, 1373, 1369>, 0,
    <1387, 1369, 1386>, 0,
    <1391, 1390, 1382>, 0,
    <1391, 1382, 1386>, 0,
    <1391, 1386, 1369>, 0,
    <1391, 1369, 1380>, 0,
    <1391, 1380, 1345>, 0,
    <1391, 1345, 1389>, 0,
    <1391, 1389, 1388>, 0,
    <1391, 1388, 1390>, 0,
    <1395, 1384, 1382>, 0,
    <1395, 1382, 1390>, 0,
    <1395, 1390, 1388>, 0,
    <1395, 1388, 1393>, 0,
    <1395, 1393, 1392>, 0,
    <1395, 1392, 1394>, 0,
    <1395, 1394, 1383>, 0,
    <1395, 1383, 1384>, 0,
    <1404, 1403, 1396>, 0,
    <1404, 1396, 1400>, 0,
    <1404, 1400, 1397>, 0,
    <1404, 1397, 1401>, 0,
    <1404, 1401, 1398>, 0,
    <1404, 1398, 1402>, 0,
    <1404, 1402, 1399>, 0,
    <1404, 1399, 1403>, 0,
    <1409, 1408, 1396>, 0,
    <1409, 1396, 1403>, 0,
    <1409, 1403, 1399>, 0,
    <1409, 1399, 1406>, 0,
    <1409, 1406, 1318>, 0,
    <1409, 1318, 1407>, 0,
    <1409, 1407, 1405>, 0,
    <1409, 1405, 1408>, 0,
    <1412, 1400, 1396>, 0,
    <1412, 1396, 1408>, 0,
    <1412, 1408, 1405>, 0,
    <1412, 1405, 1410>, 0,
    <1412, 1410, 1052>, 0,
    <1412, 1052, 1411>, 0,
    <1412, 1411, 1397>, 0,
    <1412, 1397, 1400>, 0,
    <1421, 1420, 1413>, 0,
    <1421, 1413, 1417>, 0,
    <1421, 1417, 1414>, 0,
    <1421, 1414, 1418>, 0,
    <1421, 1418, 1415>, 0,
    <1421, 1415, 1419>, 0,
    <1421, 1419, 1416>, 0,
    <1421, 1416, 1420>, 0,
    <1427, 1426, 1413>, 0,
    <1427, 1413, 1420>, 0,
    <1427, 1420, 1416>, 0,
    <1427, 1416, 1424>, 0,
    <1427, 1424, 1422>, 0,
    <1427, 1422, 1425>, 0,
    <1427, 1425, 1423>, 0,
    <1427, 1423, 1426>, 0,
    <1431, 1417, 1413>, 0,
    <1431, 1413, 1426>, 0,
    <1431, 1426, 1423>, 0,
    <1431, 1423, 1429>, 0,
    <1431, 1429, 1428>, 0,
    <1431, 1428, 1430>, 0,
    <1431, 1430, 1414>, 0,
    <1431, 1414, 1417>, 0,
    <1437, 1436, 1432>, 0,
    <1437, 1432, 1434>, 0,
    <1437, 1434, 1416>, 0,
    <1437, 1416, 1419>, 0,
    <1437, 1419, 1415>, 0,
    <1437, 1415, 1435>, 0,
    <1437, 1435, 1433>, 0,
    <1437, 1433, 1436>, 0,
    <1442, 1441, 1432>, 0,
    <1442, 1432, 1436>, 0,
    <1442, 1436, 1433>, 0,
    <1442, 1433, 1439>, 0,
    <1442, 1439, 1269>, 0,
    <1442, 1269, 1440>, 0,
    <1442, 1440, 1438>, 0,
    <1442, 1438, 1441>, 0,
    <1444, 1434, 1432>, 0,
    <1444, 1432, 1441>, 0,
    <1444, 1441, 1438>, 0,
    <1444, 1438, 1443>, 0,
    <1444, 1443, 1422>, 0,
    <1444, 1422, 1424>, 0,
    <1444, 1424, 1416>, 0,
    <1444, 1416, 1434>, 0,
    <1448, 1447, 1445>, 0,
    <1448, 1445, 1446>, 0,
    <1448, 1446, 1438>, 0,
    <1448, 1438, 1440>, 0,
    <1448, 1440, 1269>, 0,
    <1448, 1269, 1272>, 0,
    <1448, 1272, 1268>, 0,
    <1448, 1268, 1447>, 0,
    <1452, 1451, 1445>, 0,
    <1452, 1445, 1447>, 0,
    <1452, 1447, 1268>, 0,
    <1452, 1268, 1279>, 0,
    <1452, 1279, 1150>, 0,
    <1452, 1150, 1450>, 0,
    <1452, 1450, 1449>, 0,
    <1452, 1449, 1451>, 0,
    <1454, 1446, 1445>, 0,
    <1454, 1445, 1451>, 0,
    <1454, 1451, 1449>, 0,
    <1454, 1449, 1453>, 0,
    <1454, 1453, 1422>, 0,
    <1454, 1422, 1443>, 0,
    <1454, 1443, 1438>, 0,
    <1454, 1438, 1446>, 0,
    <1463, 1462, 1455>, 0,
    <1463, 1455, 1459>, 0,
    <1463, 1459, 1456>, 0,
    <1463, 1456, 1460>, 0,
    <1463, 1460, 1457>, 0,
    <1463, 1457, 1461>, 0,
    <1463, 1461, 1458>, 0,
    <1463, 1458, 1462>, 0,
    <1469, 1468, 1455>, 0,
    <1469, 1455, 1462>, 0,
    <1469, 1462, 1458>, 0,
    <1469, 1458, 1466>, 0,
    <1469, 1466, 1464>, 0,
    <1469, 1464, 1467>, 0,
    <1469, 1467, 1465>, 0,
    <1469, 1465, 1468>, 0,
    <1472, 1459, 1455>, 0,
    <1472, 1455, 1468>, 0,
    <1472, 1468, 1465>, 0,
    <1472, 1465, 1470>, 0,
    <1472, 1470, 1287>, 0,
    <1472, 1287, 1471>, 0,
    <1472, 1471, 1456>, 0,
    <1472, 1456, 1459>, 0,
    <1476, 1475, 1473>, 0,
    <1476, 1473, 1474>, 0,
    <1476, 1474, 1288>, 0,
    <1476, 1288, 1290>, 0,
    <1476, 1290, 1287>, 0,
    <1476, 1287, 1470>, 0,
    <1476, 1470, 1465>, 0,
    <1476, 1465, 1475>, 0,
    <1480, 1479, 1473>, 0,
    <1480, 1473, 1475>, 0,
    <1480, 1475, 1465>, 0,
    <1480, 1465, 1467>, 0,
    <1480, 1467, 1464>, 0,
    <1480, 1464, 1478>, 0,
    <1480, 1478, 1477>, 0,
    <1480, 1477, 1479>, 0,
    <1482, 1474, 1473>, 0,
    <1482, 1473, 1479>, 0,
    <1482, 1479, 1477>, 0,
    <1482, 1477, 1481>, 0,
    <1482, 1481, 1192>, 0,
    <1482, 1192, 1293>, 0,
    <1482, 1293, 1288>, 0,
    <1482, 1288, 1474>, 0,
    <1491, 1490, 1483>, 0,
    <1491, 1483, 1487>, 0,
    <1491, 1487, 1484>, 0,
    <1491, 1484, 1488>, 0,
    <1491, 1488, 1485>, 0,
    <1491, 1485, 1489>, 0,
    <1491, 1489, 1486>, 0,
    <1491, 1486, 1490>, 0,
    <1494, 1493, 1483>, 0,
    <1494, 1483, 1490>, 0,
    <1494, 1490, 1486>, 0,
    <1494, 1486, 1492>, 0,
    <1494, 1492, 1464>, 0,
    <1494, 1464, 1466>, 0,
    <1494, 1466, 1458>, 0,
    <1494, 1458, 1493>, 0,
    <1496, 1487, 1483>, 0,
    <1496, 1483, 1493>, 0,
    <1496, 1493, 1458>, 0,
    <1496, 1458, 1461>, 0,
    <1496, 1461, 1457>, 0,
    <1496, 1457, 1495>, 0,
    <1496, 1495, 1484>, 0,
    <1496, 1484, 1487>, 0,
    <1505, 1504, 1497>, 0,
    <1505, 1497, 1501>, 0,
    <1505, 1501, 1498>, 0,
    <1505, 1498, 1502>, 0,
    <1505, 1502, 1499>, 0,
    <1505, 1499, 1503>, 0,
    <1505, 1503, 1500>, 0,
    <1505, 1500, 1504>, 0,
    <1508, 1507, 1497>, 0,
    <1508, 1497, 1504>, 0,
    <1508, 1504, 1500>, 0,
    <1508, 1500, 1506>, 0,
    <1508, 1506, 1428>, 0,
    <1508, 1428, 1429>, 0,
    <1508, 1429, 1423>, 0,
    <1508, 1423, 1507>, 0,
    <1510, 1501, 1497>, 0,
    <1510, 1497, 1507>, 0,
    <1510, 1507, 1423>, 0,
    <1510, 1423, 1425>, 0,
    <1510, 1425, 1422>, 0,
    <1510, 1422, 1509>, 0,
    <1510, 1509, 1498>, 0,
    <1510, 1498, 1501>, 0,
    <1519, 1518, 1511>, 0,
    <1519, 1511, 1515>, 0,
    <1519, 1515, 1512>, 0,
    <1519, 1512, 1516>, 0,
    <1519, 1516, 1513>, 0,
    <1519, 1513, 1517>, 0,
    <1519, 1517, 1514>, 0,
    <1519, 1514, 1518>, 0,
    <1522, 1521, 1511>, 0,
    <1522, 1511, 1518>, 0,
    <1522, 1518, 1514>, 0,
    <1522, 1514, 1520>, 0,
    <1522, 1520, 1464>, 0,
    <1522, 1464, 1492>, 0,
    <1522, 1492, 1486>, 0,
    <1522, 1486, 1521>, 0,
    <1524, 1515, 1511>, 0,
    <1524, 1511, 1521>, 0,
    <1524, 1521, 1486>, 0,
    <1524, 1486, 1489>, 0,
    <1524, 1489, 1485>, 0,
    <1524, 1485, 1523>, 0,
    <1524, 1523, 1512>, 0,
    <1524, 1512, 1515>, 0,
    <1533, 1532, 1525>, 0,
    <1533, 1525, 1529>, 0,
    <1533, 1529, 1526>, 0,
    <1533, 1526, 1530>, 0,
    <1533, 1530, 1527>, 0,
    <1533, 1527, 1531>, 0,
    <1533, 1531, 1528>, 0,
    <1533, 1528, 1532>, 0,
    <1536, 1535, 1525>, 0,
    <1536, 1525, 1532>, 0,
    <1536, 1532, 1528>, 0,
    <1536, 1528, 1534>, 0,
    <1536, 1534, 1392>, 0,
    <1536, 1392, 1393>, 0,
    <1536, 1393, 1388>, 0,
    <1536, 1388, 1535>, 0,
    <1538, 1529, 1525>, 0,
    <1538, 1525, 1535>, 0,
    <1538, 1535, 1388>, 0,
    <1538, 1388, 1389>, 0,
    <1538, 1389, 1345>, 0,
    <1538, 1345, 1537>, 0,
    <1538, 1537, 1526>, 0,
    <1538, 1526, 1529>, 0,
    <1547, 1546, 1539>, 0,
    <1547, 1539, 1543>, 0,
    <1547, 1543, 1540>, 0,
    <1547, 1540, 1544>, 0,
    <1547, 1544, 1541>, 0,
    <1547, 1541, 1545>, 0,
    <1547, 1545, 1542>, 0,
    <1547, 1542, 1546>, 0,
    <1550, 1549, 1539>, 0,
    <1550, 1539, 1546>, 0,
    <1550, 1546, 1542>, 0,
    <1550, 1542, 1548>, 0,
    <1550, 1548, 1499>, 0,
    <1550, 1499, 1502>, 0,
    <1550, 1502, 1498>, 0,
    <1550, 1498, 1549>, 0,
    <1552, 1543, 1539>, 0,
    <1552, 1539, 1549>, 0,
    <1552, 1549, 1498>, 0,
    <1552, 1498, 1509>, 0,
    <1552, 1509, 1422>, 0,
    <1552, 1422, 1551>, 0,
    <1552, 1551, 1540>, 0,
    <1552, 1540, 1543>, 0,
    <1561, 1560, 1553>, 0,
    <1561, 1553, 1557>, 0,
    <1561, 1557, 1554>, 0,
    <1561, 1554, 1558>, 0,
    <1561, 1558, 1555>, 0,
    <1561, 1555, 1559>, 0,
    <1561, 1559, 1556>, 0,
    <1561, 1556, 1560>, 0,
    <1564, 1563, 1553>, 0,
    <1564, 1553, 1560>, 0,
    <1564, 1560, 1556>, 0,
    <1564, 1556, 1562>, 0,
    <1564, 1562, 1318>, 0,
    <1564, 1318, 1320>, 0,
    <1564, 1320, 1312>, 0,
    <1564, 1312, 1563>, 0,
    <1566, 1557, 1553>, 0,
    <1566, 1553, 1563>, 0,
    <1566, 1563, 1312>, 0,
    <1566, 1312, 1315>, 0,
    <1566, 1315, 1311>, 0,
    <1566, 1311, 1565>, 0,
    <1566, 1565, 1554>, 0,
    <1566, 1554, 1557>, 0,
    <1575, 1574, 1567>, 0,
    <1575, 1567, 1571>, 0,
    <1575, 1571, 1568>, 0,
    <1575, 1568, 1572>, 0,
    <1575, 1572, 1569>, 0,
    <1575, 1569, 1573>, 0,
    <1575, 1573, 1570>, 0,
    <1575, 1570, 1574>, 0,
    <1581, 1580, 1567>, 0,
    <1581, 1567, 1574>, 0,
    <1581, 1574, 1570>, 0,
    <1581, 1570, 1578>, 0,
    <1581, 1578, 1576>, 0,
    <1581, 1576, 1579>, 0,
    <1581, 1579, 1577>, 0,
    <1581, 1577, 1580>, 0,
    <1584, 1571, 1567>, 0,
    <1584, 1567, 1580>, 0,
    <1584, 1580, 1577>, 0,
    <1584, 1577, 1582>, 0,
    <1584, 1582, 1555>, 0,
    <1584, 1555, 1583>, 0,
    <1584, 1583, 1568>, 0,
    <1584, 1568, 1571>, 0,
    <1588, 1587, 1585>, 0,
    <1588, 1585, 1586>, 0,
    <1588, 1586, 1556>, 0,
    <1588, 1556, 1559>, 0,
    <1588, 1559, 1555>, 0,
    <1588, 1555, 1582>, 0,
    <1588, 1582, 1577>, 0,
    <1588, 1577, 1587>, 0,
    <1592, 1591, 1585>, 0,
    <1592, 1585, 1587>, 0,
    <1592, 1587, 1577>, 0,
    <1592, 1577, 1579>, 0,
    <1592, 1579, 1576>, 0,
    <1592, 1576, 1590>, 0,
    <1592, 1590, 1589>, 0,
    <1592, 1589, 1591>, 0,
    <1594, 1586, 1585>, 0,
    <1594, 1585, 1591>, 0,
    <1594, 1591, 1589>, 0,
    <1594, 1589, 1593>, 0,
    <1594, 1593, 1318>, 0,
    <1594, 1318, 1562>, 0,
    <1594, 1562, 1556>, 0,
    <1594, 1556, 1586>, 0,
    <1602, 1601, 1595>, 0,
    <1602, 1595, 1598>, 0,
    <1602, 1598, 1596>, 0,
    <1602, 1596, 1599>, 0,
    <1602, 1599, 1345>, 0,
    <1602, 1345, 1600>, 0,
    <1602, 1600, 1597>, 0,
    <1602, 1597, 1601>, 0,
    <1608, 1607, 1595>, 0,
    <1608, 1595, 1601>, 0,
    <1608, 1601, 1597>, 0,
    <1608, 1597, 1605>, 0,
    <1608, 1605, 1603>, 0,
    <1608, 1603, 1606>, 0,
    <1608, 1606, 1604>, 0,
    <1608, 1604, 1607>, 0,
    <1612, 1598, 1595>, 0,
    <1612, 1595, 1607>, 0,
    <1612, 1607, 1604>, 0,
    <1612, 1604, 1610>, 0,
    <1612, 1610, 1609>, 0,
    <1612, 1609, 1611>, 0,
    <1612, 1611, 1596>, 0,
    <1612, 1596, 1598>, 0,
    <1618, 1617, 1613>, 0,
    <1618, 1613, 1615>, 0,
    <1618, 1615, 1614>, 0,
    <1618, 1614, 1616>, 0,
    <1618, 1616, 1527>, 0,
    <1618, 1527, 1530>, 0,
    <1618, 1530, 1526>, 0,
    <1618, 1526, 1617>, 0,
    <1622, 1621, 1613>, 0,
    <1622, 1613, 1617>, 0,
    <1622, 1617, 1526>, 0,
    <1622, 1526, 1537>, 0,
    <1622, 1537, 1345>, 0,
    <1622, 1345, 1620>, 0,
    <1622, 1620, 1619>, 0,
    <1622, 1619, 1621>, 0,
    <1625, 1615, 1613>, 0,
    <1625, 1613, 1621>, 0,
    <1625, 1621, 1619>, 0,
    <1625, 1619, 1623>, 0,
    <1625, 1623, 1603>, 0,
    <1625, 1603, 1624>, 0,
    <1625, 1624, 1614>, 0,
    <1625, 1614, 1615>, 0,
    <1631, 1630, 1626>, 0,
    <1631, 1626, 1628>, 0,
    <1631, 1628, 1627>, 0,
    <1631, 1627, 1629>, 0,
    <1631, 1629, 1527>, 0,
    <1631, 1527, 1616>, 0,
    <1631, 1616, 1614>, 0,
    <1631, 1614, 1630>, 0,
    <1635, 1634, 1626>, 0,
    <1635, 1626, 1630>, 0,
    <1635, 1630, 1614>, 0,
    <1635, 1614, 1624>, 0,
    <1635, 1624, 1603>, 0,
    <1635, 1603, 1633>, 0,
    <1635, 1633, 1632>, 0,
    <1635, 1632, 1634>, 0,
    <1639, 1628, 1626>, 0,
    <1639, 1626, 1634>, 0,
    <1639, 1634, 1632>, 0,
    <1639, 1632, 1637>, 0,
    <1639, 1637, 1636>, 0,
    <1639, 1636, 1638>, 0,
    <1639, 1638, 1627>, 0,
    <1639, 1627, 1628>, 0,
    <1645, 1644, 1640>, 0,
    <1645, 1640, 1642>, 0,
    <1645, 1642, 1641>, 0,
    <1645, 1641, 1643>, 0,
    <1645, 1643, 1636>, 0,
    <1645, 1636, 1637>, 0,
    <1645, 1637, 1632>, 0,
    <1645, 1632, 1644>, 0,
    <1649, 1648, 1640>, 0,
    <1649, 1640, 1644>, 0,
    <1649, 1644, 1632>, 0,
    <1649, 1632, 1633>, 0,
    <1649, 1633, 1603>, 0,
    <1649, 1603, 1647>, 0,
    <1649, 1647, 1646>, 0,
    <1649, 1646, 1648>, 0,
    <1653, 1642, 1640>, 0,
    <1653, 1640, 1648>, 0,
    <1653, 1648, 1646>, 0,
    <1653, 1646, 1651>, 0,
    <1653, 1651, 1650>, 0,
    <1653, 1650, 1652>, 0,
    <1653, 1652, 1641>, 0,
    <1653, 1641, 1642>, 0,
    <1662, 1661, 1654>, 0,
    <1662, 1654, 1658>, 0,
    <1662, 1658, 1655>, 0,
    <1662, 1655, 1659>, 0,
    <1662, 1659, 1656>, 0,
    <1662, 1656, 1660>, 0,
    <1662, 1660, 1657>, 0,
    <1662, 1657, 1661>, 0,
    <1667, 1666, 1654>, 0,
    <1667, 1654, 1661>, 0,
    <1667, 1661, 1657>, 0,
    <1667, 1657, 1664>, 0,
    <1667, 1664, 1576>, 0,
    <1667, 1576, 1665>, 0,
    <1667, 1665, 1663>, 0,
    <1667, 1663, 1666>, 0,
    <1670, 1658, 1654>, 0,
    <1670, 1654, 1666>, 0,
    <1670, 1666, 1663>, 0,
    <1670, 1663, 1668>, 0,
    <1670, 1668, 1318>, 0,
    <1670, 1318, 1669>, 0,
    <1670, 1669, 1655>, 0,
    <1670, 1655, 1658>, 0,
    <1676, 1675, 1671>, 0,
    <1676, 1671, 1673>, 0,
    <1676, 1673, 1514>, 0,
    <1676, 1514, 1517>, 0,
    <1676, 1517, 1513>, 0,
    <1676, 1513, 1674>, 0,
    <1676, 1674, 1672>, 0,
    <1676, 1672, 1675>, 0,
    <1682, 1681, 1671>, 0,
    <1682, 1671, 1675>, 0,
    <1682, 1675, 1672>, 0,
    <1682, 1672, 1679>, 0,
    <1682, 1679, 1677>, 0,
    <1682, 1677, 1680>, 0,
    <1682, 1680, 1678>, 0,
    <1682, 1678, 1681>, 0,
    <1684, 1673, 1671>, 0,
    <1684, 1671, 1681>, 0,
    <1684, 1681, 1678>, 0,
    <1684, 1678, 1683>, 0,
    <1684, 1683, 1464>, 0,
    <1684, 1464, 1520>, 0,
    <1684, 1520, 1514>, 0,
    <1684, 1514, 1673>, 0,
    <1692, 1691, 1685>, 0,
    <1692, 1685, 1688>, 0,
    <1692, 1688, 1686>, 0,
    <1692, 1686, 1689>, 0,
    <1692, 1689, 1541>, 0,
    <1692, 1541, 1690>, 0,
    <1692, 1690, 1687>, 0,
    <1692, 1687, 1691>, 0,
    <1698, 1697, 1685>, 0,
    <1698, 1685, 1691>, 0,
    <1698, 1691, 1687>, 0,
    <1698, 1687, 1695>, 0,
    <1698, 1695, 1693>, 0,
    <1698, 1693, 1696>, 0,
    <1698, 1696, 1694>, 0,
    <1698, 1694, 1697>, 0,
    <1702, 1688, 1685>, 0,
    <1702, 1685, 1697>, 0,
    <1702, 1697, 1694>, 0,
    <1702, 1694, 1700>, 0,
    <1702, 1700, 1699>, 0,
    <1702, 1699, 1701>, 0,
    <1702, 1701, 1686>, 0,
    <1702, 1686, 1688>, 0,
    <1706, 1705, 1703>, 0,
    <1706, 1703, 1704>, 0,
    <1706, 1704, 1687>, 0,
    <1706, 1687, 1690>, 0,
    <1706, 1690, 1541>, 0,
    <1706, 1541, 1544>, 0,
    <1706, 1544, 1540>, 0,
    <1706, 1540, 1705>, 0,
    <1710, 1709, 1703>, 0,
    <1710, 1703, 1705>, 0,
    <1710, 1705, 1540>, 0,
    <1710, 1540, 1551>, 0,
    <1710, 1551, 1422>, 0,
    <1710, 1422, 1708>, 0,
    <1710, 1708, 1707>, 0,
    <1710, 1707, 1709>, 0,
    <1712, 1704, 1703>, 0,
    <1712, 1703, 1709>, 0,
    <1712, 1709, 1707>, 0,
    <1712, 1707, 1711>, 0,
    <1712, 1711, 1693>, 0,
    <1712, 1693, 1695>, 0,
    <1712, 1695, 1687>, 0,
    <1712, 1687, 1704>, 0,
    <1718, 1717, 1713>, 0,
    <1718, 1713, 1715>, 0,
    <1718, 1715, 1678>, 0,
    <1718, 1678, 1680>, 0,
    <1718, 1680, 1677>, 0,
    <1718, 1677, 1716>, 0,
    <1718, 1716, 1714>, 0,
    <1718, 1714, 1717>, 0,
    <1724, 1723, 1713>, 0,
    <1724, 1713, 1717>, 0,
    <1724, 1717, 1714>, 0,
    <1724, 1714, 1721>, 0,
    <1724, 1721, 1719>, 0,
    <1724, 1719, 1722>, 0,
    <1724, 1722, 1720>, 0,
    <1724, 1720, 1723>, 0,
    <1726, 1715, 1713>, 0,
    <1726, 1713, 1723>, 0,
    <1726, 1723, 1720>, 0,
    <1726, 1720, 1725>, 0,
    <1726, 1725, 1464>, 0,
    <1726, 1464, 1683>, 0,
    <1726, 1683, 1678>, 0,
    <1726, 1678, 1715>, 0,
    <1735, 1734, 1727>, 0,
    <1735, 1727, 1731>, 0,
    <1735, 1731, 1728>, 0,
    <1735, 1728, 1732>, 0,
    <1735, 1732, 1729>, 0,
    <1735, 1729, 1733>, 0,
    <1735, 1733, 1730>, 0,
    <1735, 1730, 1734>, 0,
    <1738, 1737, 1727>, 0,
    <1738, 1727, 1734>, 0,
    <1738, 1734, 1730>, 0,
    <1738, 1730, 1736>, 0,
    <1738, 1736, 1719>, 0,
    <1738, 1719, 1721>, 0,
    <1738, 1721, 1714>, 0,
    <1738, 1714, 1737>, 0,
    <1740, 1731, 1727>, 0,
    <1740, 1727, 1737>, 0,
    <1740, 1737, 1714>, 0,
    <1740, 1714, 1716>, 0,
    <1740, 1716, 1677>, 0,
    <1740, 1677, 1739>, 0,
    <1740, 1739, 1728>, 0,
    <1740, 1728, 1731>, 0,
    <1749, 1748, 1741>, 0,
    <1749, 1741, 1745>, 0,
    <1749, 1745, 1742>, 0,
    <1749, 1742, 1746>, 0,
    <1749, 1746, 1743>, 0,
    <1749, 1743, 1747>, 0,
    <1749, 1747, 1744>, 0,
    <1749, 1744, 1748>, 0,
    <1752, 1751, 1741>, 0,
    <1752, 1741, 1748>, 0,
    <1752, 1748, 1744>, 0,
    <1752, 1744, 1750>, 0,
    <1752, 1750, 1699>, 0,
    <1752, 1699, 1700>, 0,
    <1752, 1700, 1694>, 0,
    <1752, 1694, 1751>, 0,
    <1754, 1745, 1741>, 0,
    <1754, 1741, 1751>, 0,
    <1754, 1751, 1694>, 0,
    <1754, 1694, 1696>, 0,
    <1754, 1696, 1693>, 0,
    <1754, 1693, 1753>, 0,
    <1754, 1753, 1742>, 0,
    <1754, 1742, 1745>, 0,
    <1763, 1762, 1755>, 0,
    <1763, 1755, 1759>, 0,
    <1763, 1759, 1756>, 0,
    <1763, 1756, 1760>, 0,
    <1763, 1760, 1757>, 0,
    <1763, 1757, 1761>, 0,
    <1763, 1761, 1758>, 0,
    <1763, 1758, 1762>, 0,
    <1766, 1765, 1755>, 0,
    <1766, 1755, 1762>, 0,
    <1766, 1762, 1758>, 0,
    <1766, 1758, 1764>, 0,
    <1766, 1764, 1650>, 0,
    <1766, 1650, 1651>, 0,
    <1766, 1651, 1646>, 0,
    <1766, 1646, 1765>, 0,
    <1768, 1759, 1755>, 0,
    <1768, 1755, 1765>, 0,
    <1768, 1765, 1646>, 0,
    <1768, 1646, 1647>, 0,
    <1768, 1647, 1603>, 0,
    <1768, 1603, 1767>, 0,
    <1768, 1767, 1756>, 0,
    <1768, 1756, 1759>, 0,
    <1774, 1773, 1769>, 0,
    <1774, 1769, 1771>, 0,
    <1774, 1771, 1730>, 0,
    <1774, 1730, 1733>, 0,
    <1774, 1733, 1729>, 0,
    <1774, 1729, 1772>, 0,
    <1774, 1772, 1770>, 0,
    <1774, 1770, 1773>, 0,
    <1780, 1779, 1769>, 0,
    <1780, 1769, 1773>, 0,
    <1780, 1773, 1770>, 0,
    <1780, 1770, 1777>, 0,
    <1780, 1777, 1775>, 0,
    <1780, 1775, 1778>, 0,
    <1780, 1778, 1776>, 0,
    <1780, 1776, 1779>, 0,
    <1782, 1771, 1769>, 0,
    <1782, 1769, 1779>, 0,
    <1782, 1779, 1776>, 0,
    <1782, 1776, 1781>, 0,
    <1782, 1781, 1719>, 0,
    <1782, 1719, 1736>, 0,
    <1782, 1736, 1730>, 0,
    <1782, 1730, 1771>, 0,
    <1791, 1790, 1783>, 0,
    <1791, 1783, 1787>, 0,
    <1791, 1787, 1784>, 0,
    <1791, 1784, 1788>, 0,
    <1791, 1788, 1785>, 0,
    <1791, 1785, 1789>, 0,
    <1791, 1789, 1786>, 0,
    <1791, 1786, 1790>, 0,
    <1794, 1793, 1783>, 0,
    <1794, 1783, 1790>, 0,
    <1794, 1790, 1786>, 0,
    <1794, 1786, 1792>, 0,
    <1794, 1792, 1743>, 0,
    <1794, 1743, 1746>, 0,
    <1794, 1746, 1742>, 0,
    <1794, 1742, 1793>, 0,
    <1796, 1787, 1783>, 0,
    <1796, 1783, 1793>, 0,
    <1796, 1793, 1742>, 0,
    <1796, 1742, 1753>, 0,
    <1796, 1753, 1693>, 0,
    <1796, 1693, 1795>, 0,
    <1796, 1795, 1784>, 0,
    <1796, 1784, 1787>, 0,
    <1805, 1804, 1797>, 0,
    <1805, 1797, 1801>, 0,
    <1805, 1801, 1798>, 0,
    <1805, 1798, 1802>, 0,
    <1805, 1802, 1799>, 0,
    <1805, 1799, 1803>, 0,
    <1805, 1803, 1800>, 0,
    <1805, 1800, 1804>, 0,
    <1808, 1807, 1797>, 0,
    <1808, 1797, 1804>, 0,
    <1808, 1804, 1800>, 0,
    <1808, 1800, 1806>, 0,
    <1808, 1806, 1576>, 0,
    <1808, 1576, 1578>, 0,
    <1808, 1578, 1570>, 0,
    <1808, 1570, 1807>, 0,
    <1810, 1801, 1797>, 0,
    <1810, 1797, 1807>, 0,
    <1810, 1807, 1570>, 0,
    <1810, 1570, 1573>, 0,
    <1810, 1573, 1569>, 0,
    <1810, 1569, 1809>, 0,
    <1810, 1809, 1798>, 0,
    <1810, 1798, 1801>, 0,
    <1819, 1818, 1811>, 0,
    <1819, 1811, 1815>, 0,
    <1819, 1815, 1812>, 0,
    <1819, 1812, 1816>, 0,
    <1819, 1816, 1813>, 0,
    <1819, 1813, 1817>, 0,
    <1819, 1817, 1814>, 0,
    <1819, 1814, 1818>, 0,
    <1825, 1824, 1811>, 0,
    <1825, 1811, 1818>, 0,
    <1825, 1818, 1814>, 0,
    <1825, 1814, 1822>, 0,
    <1825, 1822, 1820>, 0,
    <1825, 1820, 1823>, 0,
    <1825, 1823, 1821>, 0,
    <1825, 1821, 1824>, 0,
    <1828, 1815, 1811>, 0,
    <1828, 1811, 1824>, 0,
    <1828, 1824, 1821>, 0,
    <1828, 1821, 1826>, 0,
    <1828, 1826, 1799>, 0,
    <1828, 1799, 1827>, 0,
    <1828, 1827, 1812>, 0,
    <1828, 1812, 1815>, 0,
    <1832, 1831, 1829>, 0,
    <1832, 1829, 1830>, 0,
    <1832, 1830, 1800>, 0,
    <1832, 1800, 1803>, 0,
    <1832, 1803, 1799>, 0,
    <1832, 1799, 1826>, 0,
    <1832, 1826, 1821>, 0,
    <1832, 1821, 1831>, 0,
    <1836, 1835, 1829>, 0,
    <1836, 1829, 1831>, 0,
    <1836, 1831, 1821>, 0,
    <1836, 1821, 1823>, 0,
    <1836, 1823, 1820>, 0,
    <1836, 1820, 1834>, 0,
    <1836, 1834, 1833>, 0,
    <1836, 1833, 1835>, 0,
    <1838, 1830, 1829>, 0,
    <1838, 1829, 1835>, 0,
    <1838, 1835, 1833>, 0,
    <1838, 1833, 1837>, 0,
    <1838, 1837, 1576>, 0,
    <1838, 1576, 1806>, 0,
    <1838, 1806, 1800>, 0,
    <1838, 1800, 1830>, 0,
    <1846, 1845, 1839>, 0,
    <1846, 1839, 1842>, 0,
    <1846, 1842, 1840>, 0,
    <1846, 1840, 1843>, 0,
    <1846, 1843, 1603>, 0,
    <1846, 1603, 1844>, 0,
    <1846, 1844, 1841>, 0,
    <1846, 1841, 1845>, 0,
    <1852, 1851, 1839>, 0,
    <1852, 1839, 1845>, 0,
    <1852, 1845, 1841>, 0,
    <1852, 1841, 1849>, 0,
    <1852, 1849, 1847>, 0,
    <1852, 1847, 1850>, 0,
    <1852, 1850, 1848>, 0,
    <1852, 1848, 1851>, 0,
    <1856, 1842, 1839>, 0,
    <1856, 1839, 1851>, 0,
    <1856, 1851, 1848>, 0,
    <1856, 1848, 1854>, 0,
    <1856, 1854, 1853>, 0,
    <1856, 1853, 1855>, 0,
    <1856, 1855, 1840>, 0,
    <1856, 1840, 1842>, 0,
    <1862, 1861, 1857>, 0,
    <1862, 1857, 1859>, 0,
    <1862, 1859, 1858>, 0,
    <1862, 1858, 1860>, 0,
    <1862, 1860, 1757>, 0,
    <1862, 1757, 1760>, 0,
    <1862, 1760, 1756>, 0,
    <1862, 1756, 1861>, 0,
    <1866, 1865, 1857>, 0,
    <1866, 1857, 1861>, 0,
    <1866, 1861, 1756>, 0,
    <1866, 1756, 1767>, 0,
    <1866, 1767, 1603>, 0,
    <1866, 1603, 1864>, 0,
    <1866, 1864, 1863>, 0,
    <1866, 1863, 1865>, 0,
    <1869, 1859, 1857>, 0,
    <1869, 1857, 1865>, 0,
    <1869, 1865, 1863>, 0,
    <1869, 1863, 1867>, 0,
    <1869, 1867, 1847>, 0,
    <1869, 1847, 1868>, 0,
    <1869, 1868, 1858>, 0,
    <1869, 1858, 1859>, 0,
    <1878, 1877, 1870>, 0,
    <1878, 1870, 1874>, 0,
    <1878, 1874, 1871>, 0,
    <1878, 1871, 1875>, 0,
    <1878, 1875, 1872>, 0,
    <1878, 1872, 1876>, 0,
    <1878, 1876, 1873>, 0,
    <1878, 1873, 1877>, 0,
    <1881, 1880, 1870>, 0,
    <1881, 1870, 1877>, 0,
    <1881, 1877, 1873>, 0,
    <1881, 1873, 1879>, 0,
    <1881, 1879, 1757>, 0,
    <1881, 1757, 1860>, 0,
    <1881, 1860, 1858>, 0,
    <1881, 1858, 1880>, 0,
    <1883, 1874, 1870>, 0,
    <1883, 1870, 1880>, 0,
    <1883, 1880, 1858>, 0,
    <1883, 1858, 1868>, 0,
    <1883, 1868, 1847>, 0,
    <1883, 1847, 1882>, 0,
    <1883, 1882, 1871>, 0,
    <1883, 1871, 1874>, 0,
    <1892, 1891, 1884>, 0,
    <1892, 1884, 1888>, 0,
    <1892, 1888, 1885>, 0,
    <1892, 1885, 1889>, 0,
    <1892, 1889, 1886>, 0,
    <1892, 1886, 1890>, 0,
    <1892, 1890, 1887>, 0,
    <1892, 1887, 1891>, 0,
    <1897, 1896, 1884>, 0,
    <1897, 1884, 1891>, 0,
    <1897, 1891, 1887>, 0,
    <1897, 1887, 1894>, 0,
    <1897, 1894, 1820>, 0,
    <1897, 1820, 1895>, 0,
    <1897, 1895, 1893>, 0,
    <1897, 1893, 1896>, 0,
    <1900, 1888, 1884>, 0,
    <1900, 1884, 1896>, 0,
    <1900, 1896, 1893>, 0,
    <1900, 1893, 1898>, 0,
    <1900, 1898, 1576>, 0,
    <1900, 1576, 1899>, 0,
    <1900, 1899, 1885>, 0,
    <1900, 1885, 1888>, 0,
    <1906, 1905, 1901>, 0,
    <1906, 1901, 1903>, 0,
    <1906, 1903, 1902>, 0,
    <1906, 1902, 1904>, 0,
    <1906, 1904, 1872>, 0,
    <1906, 1872, 1875>, 0,
    <1906, 1875, 1871>, 0,
    <1906, 1871, 1905>, 0,
    <1910, 1909, 1901>, 0,
    <1910, 1901, 1905>, 0,
    <1910, 1905, 1871>, 0,
    <1910, 1871, 1882>, 0,
    <1910, 1882, 1847>, 0,
    <1910, 1847, 1908>, 0,
    <1910, 1908, 1907>, 0,
    <1910, 1907, 1909>, 0,
    <1914, 1903, 1901>, 0,
    <1914, 1901, 1909>, 0,
    <1914, 1909, 1907>, 0,
    <1914, 1907, 1912>, 0,
    <1914, 1912, 1911>, 0,
    <1914, 1911, 1913>, 0,
    <1914, 1913, 1902>, 0,
    <1914, 1902, 1903>, 0,
    <1923, 1922, 1915>, 0,
    <1923, 1915, 1919>, 0,
    <1923, 1919, 1916>, 0,
    <1923, 1916, 1920>, 0,
    <1923, 1920, 1917>, 0,
    <1923, 1917, 1921>, 0,
    <1923, 1921, 1918>, 0,
    <1923, 1918, 1922>, 0,
    <1929, 1928, 1915>, 0,
    <1929, 1915, 1922>, 0,
    <1929, 1922, 1918>, 0,
    <1929, 1918, 1926>, 0,
    <1929, 1926, 1924>, 0,
    <1929, 1924, 1927>, 0,
    <1929, 1927, 1925>, 0,
    <1929, 1925, 1928>, 0,
    <1933, 1919, 1915>, 0,
    <1933, 1915, 1928>, 0,
    <1933, 1928, 1925>, 0,
    <1933, 1925, 1931>, 0,
    <1933, 1931, 1930>, 0,
    <1933, 1930, 1932>, 0,
    <1933, 1932, 1916>, 0,
    <1933, 1916, 1919>, 0,
    <1939, 1938, 1934>, 0,
    <1939, 1934, 1936>, 0,
    <1939, 1936, 1918>, 0,
    <1939, 1918, 1921>, 0,
    <1939, 1921, 1917>, 0,
    <1939, 1917, 1937>, 0,
    <1939, 1937, 1935>, 0,
    <1939, 1935, 1938>, 0,
    <1944, 1943, 1934>, 0,
    <1944, 1934, 1938>, 0,
    <1944, 1938, 1935>, 0,
    <1944, 1935, 1941>, 0,
    <1944, 1941, 1785>, 0,
    <1944, 1785, 1942>, 0,
    <1944, 1942, 1940>, 0,
    <1944, 1940, 1943>, 0,
    <1946, 1936, 1934>, 0,
    <1946, 1934, 1943>, 0,
    <1946, 1943, 1940>, 0,
    <1946, 1940, 1945>, 0,
    <1946, 1945, 1924>, 0,
    <1946, 1924, 1926>, 0,
    <1946, 1926, 1918>, 0,
    <1946, 1918, 1936>, 0,
    <1950, 1949, 1947>, 0,
    <1950, 1947, 1948>, 0,
    <1950, 1948, 1940>, 0,
    <1950, 1940, 1942>, 0,
    <1950, 1942, 1785>, 0,
    <1950, 1785, 1788>, 0,
    <1950, 1788, 1784>, 0,
    <1950, 1784, 1949>, 0,
    <1954, 1953, 1947>, 0,
    <1954, 1947, 1949>, 0,
    <1954, 1949, 1784>, 0,
    <1954, 1784, 1795>, 0,
    <1954, 1795, 1693>, 0,
    <1954, 1693, 1952>, 0,
    <1954, 1952, 1951>, 0,
    <1954, 1951, 1953>, 0,
    <1956, 1948, 1947>, 0,
    <1956, 1947, 1953>, 0,
    <1956, 1953, 1951>, 0,
    <1956, 1951, 1955>, 0,
    <1956, 1955, 1924>, 0,
    <1956, 1924, 1945>, 0,
    <1956, 1945, 1940>, 0,
    <1956, 1940, 1948>, 0,
    <1962, 1961, 1957>, 0,
    <1962, 1957, 1959>, 0,
    <1962, 1959, 1776>, 0,
    <1962, 1776, 1778>, 0,
    <1962, 1778, 1775>, 0,
    <1962, 1775, 1960>, 0,
    <1962, 1960, 1958>, 0,
    <1962, 1958, 1961>, 0,
    <1968, 1967, 1957>, 0,
    <1968, 1957, 1961>, 0,
    <1968, 1961, 1958>, 0,
    <1968, 1958, 1965>, 0,
    <1968, 1965, 1963>, 0,
    <1968, 1963, 1966>, 0,
    <1968, 1966, 1964>, 0,
    <1968, 1964, 1967>, 0,
    <1970, 1959, 1957>, 0,
    <1970, 1957, 1967>, 0,
    <1970, 1967, 1964>, 0,
    <1970, 1964, 1969>, 0,
    <1970, 1969, 1719>, 0,
    <1970, 1719, 1781>, 0,
    <1970, 1781, 1776>, 0,
    <1970, 1776, 1959>, 0,
    <1979, 1978, 1971>, 0,
    <1979, 1971, 1975>, 0,
    <1979, 1975, 1972>, 0,
    <1979, 1972, 1976>, 0,
    <1979, 1976, 1973>, 0,
    <1979, 1973, 1977>, 0,
    <1979, 1977, 1974>, 0,
    <1979, 1974, 1978>, 0,
    <1982, 1981, 1971>, 0,
    <1982, 1971, 1978>, 0,
    <1982, 1978, 1974>, 0,
    <1982, 1974, 1980>, 0,
    <1982, 1980, 1963>, 0,
    <1982, 1963, 1965>, 0,
    <1982, 1965, 1958>, 0,
    <1982, 1958, 1981>, 0,
    <1984, 1975, 1971>, 0,
    <1984, 1971, 1981>, 0,
    <1984, 1981, 1958>, 0,
    <1984, 1958, 1960>, 0,
    <1984, 1960, 1775>, 0,
    <1984, 1775, 1983>, 0,
    <1984, 1983, 1972>, 0,
    <1984, 1972, 1975>, 0,
    <1993, 1992, 1985>, 0,
    <1993, 1985, 1989>, 0,
    <1993, 1989, 1986>, 0,
    <1993, 1986, 1990>, 0,
    <1993, 1990, 1987>, 0,
    <1993, 1987, 1991>, 0,
    <1993, 1991, 1988>, 0,
    <1993, 1988, 1992>, 0,
    <1996, 1995, 1985>, 0,
    <1996, 1985, 1992>, 0,
    <1996, 1992, 1988>, 0,
    <1996, 1988, 1994>, 0,
    <1996, 1994, 1963>, 0,
    <1996, 1963, 1980>, 0,
    <1996, 1980, 1974>, 0,
    <1996, 1974, 1995>, 0,
    <1998, 1989, 1985>, 0,
    <1998, 1985, 1995>, 0,
    <1998, 1995, 1974>, 0,
    <1998, 1974, 1977>, 0,
    <1998, 1977, 1973>, 0,
    <1998, 1973, 1997>, 0,
    <1998, 1997, 1986>, 0,
    <1998, 1986, 1989>, 0,
    <2007, 2006, 1999>, 0,
    <2007, 1999, 2003>, 0,
    <2007, 2003, 2000>, 0,
    <2007, 2000, 2004>, 0,
    <2007, 2004, 2001>, 0,
    <2007, 2001, 2005>, 0,
    <2007, 2005, 2002>, 0,
    <2007, 2002, 2006>, 0,
    <2010, 2009, 1999>, 0,
    <2010, 1999, 2006>, 0,
    <2010, 2006, 2002>, 0,
    <2010, 2002, 2008>, 0,
    <2010, 2008, 1963>, 0,
    <2010, 1963, 1994>, 0,
    <2010, 1994, 1988>, 0,
    <2010, 1988, 2009>, 0,
    <2012, 2003, 1999>, 0,
    <2012, 1999, 2009>, 0,
    <2012, 2009, 1988>, 0,
    <2012, 1988, 1991>, 0,
    <2012, 1991, 1987>, 0,
    <2012, 1987, 2011>, 0,
    <2012, 2011, 2000>, 0,
    <2012, 2000, 2003>, 0,
    <2018, 2017, 2013>, 0,
    <2018, 2013, 2015>, 0,
    <2018, 2015, 2002>, 0,
    <2018, 2002, 2005>, 0,
    <2018, 2005, 2001>, 0,
    <2018, 2001, 2016>, 0,
    <2018, 2016, 2014>, 0,
    <2018, 2014, 2017>, 0,
    <2024, 2023, 2013>, 0,
    <2024, 2013, 2017>, 0,
    <2024, 2017, 2014>, 0,
    <2024, 2014, 2021>, 0,
    <2024, 2021, 2019>, 0,
    <2024, 2019, 2022>, 0,
    <2024, 2022, 2020>, 0,
    <2024, 2020, 2023>, 0,
    <2026, 2015, 2013>, 0,
    <2026, 2013, 2023>, 0,
    <2026, 2023, 2020>, 0,
    <2026, 2020, 2025>, 0,
    <2026, 2025, 1963>, 0,
    <2026, 1963, 2008>, 0,
    <2026, 2008, 2002>, 0,
    <2026, 2002, 2015>, 0,
    <2035, 2034, 2027>, 0,
    <2035, 2027, 2031>, 0,
    <2035, 2031, 2028>, 0,
    <2035, 2028, 2032>, 0,
    <2035, 2032, 2029>, 0,
    <2035, 2029, 2033>, 0,
    <2035, 2033, 2030>, 0,
    <2035, 2030, 2034>, 0,
    <2038, 2037, 2027>, 0,
    <2038, 2027, 2034>, 0,
    <2038, 2034, 2030>, 0,
    <2038, 2030, 2036>, 0,
    <2038, 2036, 1911>, 0,
    <2038, 1911, 1912>, 0,
    <2038, 1912, 1907>, 0,
    <2038, 1907, 2037>, 0,
    <2040, 2031, 2027>, 0,
    <2040, 2027, 2037>, 0,
    <2040, 2037, 1907>, 0,
    <2040, 1907, 1908>, 0,
    <2040, 1908, 1847>, 0,
    <2040, 1847, 2039>, 0,
    <2040, 2039, 2028>, 0,
    <2040, 2028, 2031>, 0,
    <2049, 2048, 2041>, 0,
    <2049, 2041, 2045>, 0,
    <2049, 2045, 2042>, 0,
    <2049, 2042, 2046>, 0,
    <2049, 2046, 2043>, 0,
    <2049, 2043, 2047>, 0,
    <2049, 2047, 2044>, 0,
    <2049, 2044, 2048>, 0,
    <2052, 2051, 2041>, 0,
    <2052, 2041, 2048>, 0,
    <2052, 2048, 2044>, 0,
    <2052, 2044, 2050>, 0,
    <2052, 2050, 1820>, 0,
    <2052, 1820, 1822>, 0,
    <2052, 1822, 1814>, 0,
    <2052, 1814, 2051>, 0,
    <2054, 2045, 2041>, 0,
    <2054, 2041, 2051>, 0,
    <2054, 2051, 1814>, 0,
    <2054, 1814, 1817>, 0,
    <2054, 1817, 1813>, 0,
    <2054, 1813, 2053>, 0,
    <2054, 2053, 2042>, 0,
    <2054, 2042, 2045>, 0,
    <2063, 2062, 2055>, 0,
    <2063, 2055, 2059>, 0,
    <2063, 2059, 2056>, 0,
    <2063, 2056, 2060>, 0,
    <2063, 2060, 2057>, 0,
    <2063, 2057, 2061>, 0,
    <2063, 2061, 2058>, 0,
    <2063, 2058, 2062>, 0,
    <2069, 2068, 2055>, 0,
    <2069, 2055, 2062>, 0,
    <2069, 2062, 2058>, 0,
    <2069, 2058, 2066>, 0,
    <2069, 2066, 2064>, 0,
    <2069, 2064, 2067>, 0,
    <2069, 2067, 2065>, 0,
    <2069, 2065, 2068>, 0,
    <2072, 2059, 2055>, 0,
    <2072, 2055, 2068>, 0,
    <2072, 2068, 2065>, 0,
    <2072, 2065, 2070>, 0,
    <2072, 2070, 2043>, 0,
    <2072, 2043, 2071>, 0,
    <2072, 2071, 2056>, 0,
    <2072, 2056, 2059>, 0,
    <2076, 2075, 2073>, 0,
    <2076, 2073, 2074>, 0,
    <2076, 2074, 2044>, 0,
    <2076, 2044, 2047>, 0,
    <2076, 2047, 2043>, 0,
    <2076, 2043, 2070>, 0,
    <2076, 2070, 2065>, 0,
    <2076, 2065, 2075>, 0,
    <2080, 2079, 2073>, 0,
    <2080, 2073, 2075>, 0,
    <2080, 2075, 2065>, 0,
    <2080, 2065, 2067>, 0,
    <2080, 2067, 2064>, 0,
    <2080, 2064, 2078>, 0,
    <2080, 2078, 2077>, 0,
    <2080, 2077, 2079>, 0,
    <2082, 2074, 2073>, 0,
    <2082, 2073, 2079>, 0,
    <2082, 2079, 2077>, 0,
    <2082, 2077, 2081>, 0,
    <2082, 2081, 1820>, 0,
    <2082, 1820, 2050>, 0,
    <2082, 2050, 2044>, 0,
    <2082, 2044, 2074>, 0,
    <2090, 2089, 2083>, 0,
    <2090, 2083, 2086>, 0,
    <2090, 2086, 2084>, 0,
    <2090, 2084, 2087>, 0,
    <2090, 2087, 1930>, 0,
    <2090, 1930, 2088>, 0,
    <2090, 2088, 2085>, 0,
    <2090, 2085, 2089>, 0,
    <2096, 2095, 2083>, 0,
    <2096, 2083, 2089>, 0,
    <2096, 2089, 2085>, 0,
    <2096, 2085, 2093>, 0,
    <2096, 2093, 2091>, 0,
    <2096, 2091, 2094>, 0,
    <2096, 2094, 2092>, 0,
    <2096, 2092, 2095>, 0,
    <2100, 2086, 2083>, 0,
    <2100, 2083, 2095>, 0,
    <2100, 2095, 2092>, 0,
    <2100, 2092, 2098>, 0,
    <2100, 2098, 2097>, 0,
    <2100, 2097, 2099>, 0,
    <2100, 2099, 2084>, 0,
    <2100, 2084, 2086>, 0,
    <2104, 2103, 2101>, 0,
    <2104, 2101, 2102>, 0,
    <2104, 2102, 2085>, 0,
    <2104, 2085, 2088>, 0,
    <2104, 2088, 1930>, 0,
    <2104, 1930, 1931>, 0,
    <2104, 1931, 1925>, 0,
    <2104, 1925, 2103>, 0,
    <2108, 2107, 2101>, 0,
    <2108, 2101, 2103>, 0,
    <2108, 2103, 1925>, 0,
    <2108, 1925, 1927>, 0,
    <2108, 1927, 1924>, 0,
    <2108, 1924, 2106>, 0,
    <2108, 2106, 2105>, 0,
    <2108, 2105, 2107>, 0,
    <2110, 2102, 2101>, 0,
    <2110, 2101, 2107>, 0,
    <2110, 2107, 2105>, 0,
    <2110, 2105, 2109>, 0,
    <2110, 2109, 2091>, 0,
    <2110, 2091, 2093>, 0,
    <2110, 2093, 2085>, 0,
    <2110, 2085, 2102>, 0,
    <2116, 2115, 2111>, 0,
    <2116, 2111, 2113>, 0,
    <2116, 2113, 2020>, 0,
    <2116, 2020, 2022>, 0,
    <2116, 2022, 2019>, 0,
    <2116, 2019, 2114>, 0,
    <2116, 2114, 2112>, 0,
    <2116, 2112, 2115>, 0,
    <2122, 2121, 2111>, 0,
    <2122, 2111, 2115>, 0,
    <2122, 2115, 2112>, 0,
    <2122, 2112, 2119>, 0,
    <2122, 2119, 2117>, 0,
    <2122, 2117, 2120>, 0,
    <2122, 2120, 2118>, 0,
    <2122, 2118, 2121>, 0,
    <2124, 2113, 2111>, 0,
    <2124, 2111, 2121>, 0,
    <2124, 2121, 2118>, 0,
    <2124, 2118, 2123>, 0,
    <2124, 2123, 1963>, 0,
    <2124, 1963, 2025>, 0,
    <2124, 2025, 2020>, 0,
    <2124, 2020, 2113>, 0,
    <2133, 2132, 2125>, 0,
    <2133, 2125, 2129>, 0,
    <2133, 2129, 2126>, 0,
    <2133, 2126, 2130>, 0,
    <2133, 2130, 2127>, 0,
    <2133, 2127, 2131>, 0,
    <2133, 2131, 2128>, 0,
    <2133, 2128, 2132>, 0,
    <2136, 2135, 2125>, 0,
    <2136, 2125, 2132>, 0,
    <2136, 2132, 2128>, 0,
    <2136, 2128, 2134>, 0,
    <2136, 2134, 2117>, 0,
    <2136, 2117, 2119>, 0,
    <2136, 2119, 2112>, 0,
    <2136, 2112, 2135>, 0,
    <2138, 2129, 2125>, 0,
    <2138, 2125, 2135>, 0,
    <2138, 2135, 2112>, 0,
    <2138, 2112, 2114>, 0,
    <2138, 2114, 2019>, 0,
    <2138, 2019, 2137>, 0,
    <2138, 2137, 2126>, 0,
    <2138, 2126, 2129>, 0,
    <2144, 2143, 2139>, 0,
    <2144, 2139, 2141>, 0,
    <2144, 2141, 2140>, 0,
    <2144, 2140, 2142>, 0,
    <2144, 2142, 2029>, 0,
    <2144, 2029, 2032>, 0,
    <2144, 2032, 2028>, 0,
    <2144, 2028, 2143>, 0,
    <2148, 2147, 2139>, 0,
    <2148, 2139, 2143>, 0,
    <2148, 2143, 2028>, 0,
    <2148, 2028, 2039>, 0,
    <2148, 2039, 1847>, 0,
    <2148, 1847, 2146>, 0,
    <2148, 2146, 2145>, 0,
    <2148, 2145, 2147>, 0,
    <2152, 2141, 2139>, 0,
    <2152, 2139, 2147>, 0,
    <2152, 2147, 2145>, 0,
    <2152, 2145, 2150>, 0,
    <2152, 2150, 2149>, 0,
    <2152, 2149, 2151>, 0,
    <2152, 2151, 2140>, 0,
    <2152, 2140, 2141>, 0,
    <2158, 2157, 2153>, 0,
    <2158, 2153, 2155>, 0,
    <2158, 2155, 2154>, 0,
    <2158, 2154, 2156>, 0,
    <2158, 2156, 2029>, 0,
    <2158, 2029, 2142>, 0,
    <2158, 2142, 2140>, 0,
    <2158, 2140, 2157>, 0,
    <2162, 2161, 2153>, 0,
    <2162, 2153, 2157>, 0,
    <2162, 2157, 2140>, 0,
    <2162, 2140, 2151>, 0,
    <2162, 2151, 2149>, 0,
    <2162, 2149, 2160>, 0,
    <2162, 2160, 2159>, 0,
    <2162, 2159, 2161>, 0,
    <2166, 2155, 2153>, 0,
    <2166, 2153, 2161>, 0,
    <2166, 2161, 2159>, 0,
    <2166, 2159, 2164>, 0,
    <2166, 2164, 2163>, 0,
    <2166, 2163, 2165>, 0,
    <2166, 2165, 2154>, 0,
    <2166, 2154, 2155>, 0,
    <2172, 2171, 2167>, 0,
    <2172, 2167, 2169>, 0,
    <2172, 2169, 2168>, 0,
    <2172, 2168, 2170>, 0,
    <2172, 2170, 2163>, 0,
    <2172, 2163, 2164>, 0,
    <2172, 2164, 2159>, 0,
    <2172, 2159, 2171>, 0,
    <2176, 2175, 2167>, 0,
    <2176, 2167, 2171>, 0,
    <2176, 2171, 2159>, 0,
    <2176, 2159, 2160>, 0,
    <2176, 2160, 2149>, 0,
    <2176, 2149, 2174>, 0,
    <2176, 2174, 2173>, 0,
    <2176, 2173, 2175>, 0,
    <2180, 2169, 2167>, 0,
    <2180, 2167, 2175>, 0,
    <2180, 2175, 2173>, 0,
    <2180, 2173, 2178>, 0,
    <2180, 2178, 2177>, 0,
    <2180, 2177, 2179>, 0,
    <2180, 2179, 2168>, 0,
    <2180, 2168, 2169>, 0,
    <2189, 2188, 2181>, 0,
    <2189, 2181, 2185>, 0,
    <2189, 2185, 2182>, 0,
    <2189, 2182, 2186>, 0,
    <2189, 2186, 2183>, 0,
    <2189, 2183, 2187>, 0,
    <2189, 2187, 2184>, 0,
    <2189, 2184, 2188>, 0,
    <2192, 2191, 2181>, 0,
    <2192, 2181, 2188>, 0,
    <2192, 2188, 2184>, 0,
    <2192, 2184, 2190>, 0,
    <2192, 2190, 2097>, 0,
    <2192, 2097, 2098>, 0,
    <2192, 2098, 2092>, 0,
    <2192, 2092, 2191>, 0,
    <2194, 2185, 2181>, 0,
    <2194, 2181, 2191>, 0,
    <2194, 2191, 2092>, 0,
    <2194, 2092, 2094>, 0,
    <2194, 2094, 2091>, 0,
    <2194, 2091, 2193>, 0,
    <2194, 2193, 2182>, 0,
    <2194, 2182, 2185>, 0,
    <2203, 2202, 2195>, 0,
    <2203, 2195, 2199>, 0,
    <2203, 2199, 2196>, 0,
    <2203, 2196, 2200>, 0,
    <2203, 2200, 2197>, 0,
    <2203, 2197, 2201>, 0,
    <2203, 2201, 2198>, 0,
    <2203, 2198, 2202>, 0,
    <2206, 2205, 2195>, 0,
    <2206, 2195, 2202>, 0,
    <2206, 2202, 2198>, 0,
    <2206, 2198, 2204>, 0,
    <2206, 2204, 2183>, 0,
    <2206, 2183, 2186>, 0,
    <2206, 2186, 2182>, 0,
    <2206, 2182, 2205>, 0,
    <2208, 2199, 2195>, 0,
    <2208, 2195, 2205>, 0,
    <2208, 2205, 2182>, 0,
    <2208, 2182, 2193>, 0,
    <2208, 2193, 2091>, 0,
    <2208, 2091, 2207>, 0,
    <2208, 2207, 2196>, 0,
    <2208, 2196, 2199>, 0,
    <2216, 2215, 2209>, 0,
    <2216, 2209, 2212>, 0,
    <2216, 2212, 2210>, 0,
    <2216, 2210, 2213>, 0,
    <2216, 2213, 2197>, 0,
    <2216, 2197, 2214>, 0,
    <2216, 2214, 2211>, 0,
    <2216, 2211, 2215>, 0,
    <2222, 2221, 2209>, 0,
    <2222, 2209, 2215>, 0,
    <2222, 2215, 2211>, 0,
    <2222, 2211, 2219>, 0,
    <2222, 2219, 2217>, 0,
    <2222, 2217, 2220>, 0,
    <2222, 2220, 2218>, 0,
    <2222, 2218, 2221>, 0,
    <2225, 2212, 2209>, 0,
    <2225, 2209, 2221>, 0,
    <2225, 2221, 2218>, 0,
    <2225, 2218, 2223>, 0,
    <2225, 2223, 2097>, 0,
    <2225, 2097, 2224>, 0,
    <2225, 2224, 2210>, 0,
    <2225, 2210, 2212>, 0,
    <2234, 2233, 2226>, 0,
    <2234, 2226, 2230>, 0,
    <2234, 2230, 2227>, 0,
    <2234, 2227, 2231>, 0,
    <2234, 2231, 2228>, 0,
    <2234, 2228, 2232>, 0,
    <2234, 2232, 2229>, 0,
    <2234, 2229, 2233>, 0,
    <2237, 2236, 2226>, 0,
    <2237, 2226, 2233>, 0,
    <2237, 2233, 2229>, 0,
    <2237, 2229, 2235>, 0,
    <2237, 2235, 2177>, 0,
    <2237, 2177, 2178>, 0,
    <2237, 2178, 2173>, 0,
    <2237, 2173, 2236>, 0,
    <2239, 2230, 2226>, 0,
    <2239, 2226, 2236>, 0,
    <2239, 2236, 2173>, 0,
    <2239, 2173, 2174>, 0,
    <2239, 2174, 2149>, 0,
    <2239, 2149, 2238>, 0,
    <2239, 2238, 2227>, 0,
    <2239, 2227, 2230>, 0,
    <2245, 2244, 2240>, 0,
    <2245, 2240, 2242>, 0,
    <2245, 2242, 2241>, 0,
    <2245, 2241, 2243>, 0,
    <2245, 2243, 2217>, 0,
    <2245, 2217, 2219>, 0,
    <2245, 2219, 2211>, 0,
    <2245, 2211, 2244>, 0,
    <2249, 2248, 2240>, 0,
    <2249, 2240, 2244>, 0,
    <2249, 2244, 2211>, 0,
    <2249, 2211, 2214>, 0,
    <2249, 2214, 2197>, 0,
    <2249, 2197, 2247>, 0,
    <2249, 2247, 2246>, 0,
    <2249, 2246, 2248>, 0,
    <2253, 2242, 2240>, 0,
    <2253, 2240, 2248>, 0,
    <2253, 2248, 2246>, 0,
    <2253, 2246, 2251>, 0,
    <2253, 2251, 2250>, 0,
    <2253, 2250, 2252>, 0,
    <2253, 2252, 2241>, 0,
    <2253, 2241, 2242>, 0,
    <2259, 2258, 2254>, 0,
    <2259, 2254, 2256>, 0,
    <2259, 2256, 2255>, 0,
    <2259, 2255, 2257>, 0,
    <2259, 2257, 2217>, 0,
    <2259, 2217, 2243>, 0,
    <2259, 2243, 2241>, 0,
    <2259, 2241, 2258>, 0,
    <2263, 2262, 2254>, 0,
    <2263, 2254, 2258>, 0,
    <2263, 2258, 2241>, 0,
    <2263, 2241, 2252>, 0,
    <2263, 2252, 2250>, 0,
    <2263, 2250, 2261>, 0,
    <2263, 2261, 2260>, 0,
    <2263, 2260, 2262>, 0,
    <2267, 2256, 2254>, 0,
    <2267, 2254, 2262>, 0,
    <2267, 2262, 2260>, 0,
    <2267, 2260, 2265>, 0,
    <2267, 2265, 2264>, 0,
    <2267, 2264, 2266>, 0,
    <2267, 2266, 2255>, 0,
    <2267, 2255, 2256>, 0,
    <2276, 2275, 2268>, 0,
    <2276, 2268, 2272>, 0,
    <2276, 2272, 2269>, 0,
    <2276, 2269, 2273>, 0,
    <2276, 2273, 2270>, 0,
    <2276, 2270, 2274>, 0,
    <2276, 2274, 2271>, 0,
    <2276, 2271, 2275>, 0,
    <2282, 2281, 2268>, 0,
    <2282, 2268, 2275>, 0,
    <2282, 2275, 2271>, 0,
    <2282, 2271, 2279>, 0,
    <2282, 2279, 2277>, 0,
    <2282, 2277, 2280>, 0,
    <2282, 2280, 2278>, 0,
    <2282, 2278, 2281>, 0,
    <2285, 2272, 2268>, 0,
    <2285, 2268, 2281>, 0,
    <2285, 2281, 2278>, 0,
    <2285, 2278, 2283>, 0,
    <2285, 2283, 2117>, 0,
    <2285, 2117, 2284>, 0,
    <2285, 2284, 2269>, 0,
    <2285, 2269, 2272>, 0,
    <2291, 2290, 2286>, 0,
    <2291, 2286, 2288>, 0,
    <2291, 2288, 2287>, 0,
    <2291, 2287, 2289>, 0,
    <2291, 2289, 2270>, 0,
    <2291, 2270, 2273>, 0,
    <2291, 2273, 2269>, 0,
    <2291, 2269, 2290>, 0,
    <2293, 2292, 2286>, 0,
    <2293, 2286, 2290>, 0,
    <2293, 2290, 2269>, 0,
    <2293, 2269, 2284>, 0,
    <2293, 2284, 2117>, 0,
    <2293, 2117, 2134>, 0,
    <2293, 2134, 2128>, 0,
    <2293, 2128, 2292>, 0,
    <2295, 2288, 2286>, 0,
    <2295, 2286, 2292>, 0,
    <2295, 2292, 2128>, 0,
    <2295, 2128, 2131>, 0,
    <2295, 2131, 2127>, 0,
    <2295, 2127, 2294>, 0,
    <2295, 2294, 2287>, 0,
    <2295, 2287, 2288>, 0,
    <2304, 2303, 2296>, 0,
    <2304, 2296, 2300>, 0,
    <2304, 2300, 2297>, 0,
    <2304, 2297, 2301>, 0,
    <2304, 2301, 2298>, 0,
    <2304, 2298, 2302>, 0,
    <2304, 2302, 2299>, 0,
    <2304, 2299, 2303>, 0,
    <2307, 2306, 2296>, 0,
    <2307, 2296, 2303>, 0,
    <2307, 2303, 2299>, 0,
    <2307, 2299, 2305>, 0,
    <2307, 2305, 2064>, 0,
    <2307, 2064, 2066>, 0,
    <2307, 2066, 2058>, 0,
    <2307, 2058, 2306>, 0,
    <2309, 2300, 2296>, 0,
    <2309, 2296, 2306>, 0,
    <2309, 2306, 2058>, 0,
    <2309, 2058, 2061>, 0,
    <2309, 2061, 2057>, 0,
    <2309, 2057, 2308>, 0,
    <2309, 2308, 2297>, 0,
    <2309, 2297, 2300>, 0,
    <2318, 2317, 2310>, 0,
    <2318, 2310, 2314>, 0,
    <2318, 2314, 2311>, 0,
    <2318, 2311, 2315>, 0,
    <2318, 2315, 2312>, 0,
    <2318, 2312, 2316>, 0,
    <2318, 2316, 2313>, 0,
    <2318, 2313, 2317>, 0,
    <2323, 2322, 2310>, 0,
    <2323, 2310, 2317>, 0,
    <2323, 2317, 2313>, 0,
    <2323, 2313, 2320>, 0,
    <2323, 2320, 2064>, 0,
    <2323, 2064, 2321>, 0,
    <2323, 2321, 2319>, 0,
    <2323, 2319, 2322>, 0,
    <2327, 2314, 2310>, 0,
    <2327, 2310, 2322>, 0,
    <2327, 2322, 2319>, 0,
    <2327, 2319, 2325>, 0,
    <2327, 2325, 2324>, 0,
    <2327, 2324, 2326>, 0,
    <2327, 2326, 2311>, 0,
    <2327, 2311, 2314>, 0,
    <2333, 2332, 2328>, 0,
    <2333, 2328, 2330>, 0,
    <2333, 2330, 2299>, 0,
    <2333, 2299, 2302>, 0,
    <2333, 2302, 2298>, 0,
    <2333, 2298, 2331>, 0,
    <2333, 2331, 2329>, 0,
    <2333, 2329, 2332>, 0,
    <2338, 2337, 2328>, 0,
    <2338, 2328, 2332>, 0,
    <2338, 2332, 2329>, 0,
    <2338, 2329, 2335>, 0,
    <2338, 2335, 2312>, 0,
    <2338, 2312, 2336>, 0,
    <2338, 2336, 2334>, 0,
    <2338, 2334, 2337>, 0,
    <2340, 2330, 2328>, 0,
    <2340, 2328, 2337>, 0,
    <2340, 2337, 2334>, 0,
    <2340, 2334, 2339>, 0,
    <2340, 2339, 2064>, 0,
    <2340, 2064, 2305>, 0,
    <2340, 2305, 2299>, 0,
    <2340, 2299, 2330>, 0,
    <2349, 2348, 2341>, 0,
    <2349, 2341, 2345>, 0,
    <2349, 2345, 2342>, 0,
    <2349, 2342, 2346>, 0,
    <2349, 2346, 2343>, 0,
    <2349, 2343, 2347>, 0,
    <2349, 2347, 2344>, 0,
    <2349, 2344, 2348>, 0,
    <2352, 2351, 2341>, 0,
    <2352, 2341, 2348>, 0,
    <2352, 2348, 2344>, 0,
    <2352, 2344, 2350>, 0,
    <2352, 2350, 2312>, 0,
    <2352, 2312, 2335>, 0,
    <2352, 2335, 2329>, 0,
    <2352, 2329, 2351>, 0,
    <2354, 2345, 2341>, 0,
    <2354, 2341, 2351>, 0,
    <2354, 2351, 2329>, 0,
    <2354, 2329, 2331>, 0,
    <2354, 2331, 2298>, 0,
    <2354, 2298, 2353>, 0,
    <2354, 2353, 2342>, 0,
    <2354, 2342, 2345>, 0,
    <2363, 2362, 2355>, 0,
    <2363, 2355, 2359>, 0,
    <2363, 2359, 2356>, 0,
    <2363, 2356, 2360>, 0,
    <2363, 2360, 2357>, 0,
    <2363, 2357, 2361>, 0,
    <2363, 2361, 2358>, 0,
    <2363, 2358, 2362>, 0,
    <2368, 2367, 2355>, 0,
    <2368, 2355, 2362>, 0,
    <2368, 2362, 2358>, 0,
    <2368, 2358, 2365>, 0,
    <2368, 2365, 2228>, 0,
    <2368, 2228, 2366>, 0,
    <2368, 2366, 2364>, 0,
    <2368, 2364, 2367>, 0,
    <2372, 2359, 2355>, 0,
    <2372, 2355, 2367>, 0,
    <2372, 2367, 2364>, 0,
    <2372, 2364, 2370>, 0,
    <2372, 2370, 2369>, 0,
    <2372, 2369, 2371>, 0,
    <2372, 2371, 2356>, 0,
    <2372, 2356, 2359>, 0,
    <2376, 2375, 2373>, 0,
    <2376, 2373, 2374>, 0,
    <2376, 2374, 2364>, 0,
    <2376, 2364, 2366>, 0,
    <2376, 2366, 2228>, 0,
    <2376, 2228, 2231>, 0,
    <2376, 2231, 2227>, 0,
    <2376, 2227, 2375>, 0,
    <2380, 2379, 2373>, 0,
    <2380, 2373, 2375>, 0,
    <2380, 2375, 2227>, 0,
    <2380, 2227, 2238>, 0,
    <2380, 2238, 2149>, 0,
    <2380, 2149, 2378>, 0,
    <2380, 2378, 2377>, 0,
    <2380, 2377, 2379>, 0,
    <2382, 2374, 2373>, 0,
    <2382, 2373, 2379>, 0,
    <2382, 2379, 2377>, 0,
    <2382, 2377, 2381>, 0,
    <2382, 2381, 2369>, 0,
    <2382, 2369, 2370>, 0,
    <2382, 2370, 2364>, 0,
    <2382, 2364, 2374>, 0,
    <2388, 2387, 2383>, 0,
    <2388, 2383, 2385>, 0,
    <2388, 2385, 2384>, 0,
    <2388, 2384, 2386>, 0,
    <2388, 2386, 2357>, 0,
    <2388, 2357, 2360>, 0,
    <2388, 2360, 2356>, 0,
    <2388, 2356, 2387>, 0,
    <2392, 2391, 2383>, 0,
    <2392, 2383, 2387>, 0,
    <2392, 2387, 2356>, 0,
    <2392, 2356, 2371>, 0,
    <2392, 2371, 2369>, 0,
    <2392, 2369, 2390>, 0,
    <2392, 2390, 2389>, 0,
    <2392, 2389, 2391>, 0,
    <2396, 2385, 2383>, 0,
    <2396, 2383, 2391>, 0,
    <2396, 2391, 2389>, 0,
    <2396, 2389, 2394>, 0,
    <2396, 2394, 2393>, 0,
    <2396, 2393, 2395>, 0,
    <2396, 2395, 2384>, 0,
    <2396, 2384, 2385>, 0,
    <2405, 2404, 2397>, 0,
    <2405, 2397, 2401>, 0,
    <2405, 2401, 2398>, 0,
    <2405, 2398, 2402>, 0,
    <2405, 2402, 2399>, 0,
    <2405, 2399, 2403>, 0,
    <2405, 2403, 2400>, 0,
    <2405, 2400, 2404>, 0,
    <2408, 2407, 2397>, 0,
    <2408, 2397, 2404>, 0,
    <2408, 2404, 2400>, 0,
    <2408, 2400, 2406>, 0,
    <2408, 2406, 2277>, 0,
    <2408, 2277, 2279>, 0,
    <2408, 2279, 2271>, 0,
    <2408, 2271, 2407>, 0,
    <2410, 2401, 2397>, 0,
    <2410, 2397, 2407>, 0,
    <2410, 2407, 2271>, 0,
    <2410, 2271, 2274>, 0,
    <2410, 2274, 2270>, 0,
    <2410, 2270, 2409>, 0,
    <2410, 2409, 2398>, 0,
    <2410, 2398, 2401>, 0,
    <2419, 2418, 2411>, 0,
    <2419, 2411, 2415>, 0,
    <2419, 2415, 2412>, 0,
    <2419, 2412, 2416>, 0,
    <2419, 2416, 2413>, 0,
    <2419, 2413, 2417>, 0,
    <2419, 2417, 2414>, 0,
    <2419, 2414, 2418>, 0,
    <2422, 2421, 2411>, 0,
    <2422, 2411, 2418>, 0,
    <2422, 2418, 2414>, 0,
    <2422, 2414, 2420>, 0,
    <2422, 2420, 2264>, 0,
    <2422, 2264, 2265>, 0,
    <2422, 2265, 2260>, 0,
    <2422, 2260, 2421>, 0,
    <2424, 2415, 2411>, 0,
    <2424, 2411, 2421>, 0,
    <2424, 2421, 2260>, 0,
    <2424, 2260, 2261>, 0,
    <2424, 2261, 2250>, 0,
    <2424, 2250, 2423>, 0,
    <2424, 2423, 2412>, 0,
    <2424, 2412, 2415>, 0,
    <2430, 2429, 2425>, 0,
    <2430, 2425, 2427>, 0,
    <2430, 2427, 2400>, 0,
    <2430, 2400, 2403>, 0,
    <2430, 2403, 2399>, 0,
    <2430, 2399, 2428>, 0,
    <2430, 2428, 2426>, 0,
    <2430, 2426, 2429>, 0,
    <2436, 2435, 2425>, 0,
    <2436, 2425, 2429>, 0,
    <2436, 2429, 2426>, 0,
    <2436, 2426, 2433>, 0,
    <2436, 2433, 2431>, 0,
    <2436, 2431, 2434>, 0,
    <2436, 2434, 2432>, 0,
    <2436, 2432, 2435>, 0,
    <2438, 2427, 2425>, 0,
    <2438, 2425, 2435>, 0,
    <2438, 2435, 2432>, 0,
    <2438, 2432, 2437>, 0,
    <2438, 2437, 2277>, 0,
    <2438, 2277, 2406>, 0,
    <2438, 2406, 2400>, 0,
    <2438, 2400, 2427>, 0,
    <2444, 2443, 2439>, 0,
    <2444, 2439, 2441>, 0,
    <2444, 2441, 2432>, 0,
    <2444, 2432, 2434>, 0,
    <2444, 2434, 2431>, 0,
    <2444, 2431, 2442>, 0,
    <2444, 2442, 2440>, 0,
    <2444, 2440, 2443>, 0,
    <2450, 2449, 2439>, 0,
    <2450, 2439, 2443>, 0,
    <2450, 2443, 2440>, 0,
    <2450, 2440, 2447>, 0,
    <2450, 2447, 2445>, 0,
    <2450, 2445, 2448>, 0,
    <2450, 2448, 2446>, 0,
    <2450, 2446, 2449>, 0,
    <2452, 2441, 2439>, 0,
    <2452, 2439, 2449>, 0,
    <2452, 2449, 2446>, 0,
    <2452, 2446, 2451>, 0,
    <2452, 2451, 2277>, 0,
    <2452, 2277, 2437>, 0,
    <2452, 2437, 2432>, 0,
    <2452, 2432, 2441>, 0,
    <2458, 2457, 2453>, 0,
    <2458, 2453, 2455>, 0,
    <2458, 2455, 2414>, 0,
    <2458, 2414, 2417>, 0,
    <2458, 2417, 2413>, 0,
    <2458, 2413, 2456>, 0,
    <2458, 2456, 2454>, 0,
    <2458, 2454, 2457>, 0,
    <2464, 2463, 2453>, 0,
    <2464, 2453, 2457>, 0,
    <2464, 2457, 2454>, 0,
    <2464, 2454, 2461>, 0,
    <2464, 2461, 2459>, 0,
    <2464, 2459, 2462>, 0,
    <2464, 2462, 2460>, 0,
    <2464, 2460, 2463>, 0,
    <2466, 2455, 2453>, 0,
    <2466, 2453, 2463>, 0,
    <2466, 2463, 2460>, 0,
    <2466, 2460, 2465>, 0,
    <2466, 2465, 2264>, 0,
    <2466, 2264, 2420>, 0,
    <2466, 2420, 2414>, 0,
    <2466, 2414, 2455>, 0,
    <2475, 2474, 2467>, 0,
    <2475, 2467, 2471>, 0,
    <2475, 2471, 2468>, 0,
    <2475, 2468, 2472>, 0,
    <2475, 2472, 2469>, 0,
    <2475, 2469, 2473>, 0,
    <2475, 2473, 2470>, 0,
    <2475, 2470, 2474>, 0,
    <2478, 2477, 2467>, 0,
    <2478, 2467, 2474>, 0,
    <2478, 2474, 2470>, 0,
    <2478, 2470, 2476>, 0,
    <2478, 2476, 2393>, 0,
    <2478, 2393, 2394>, 0,
    <2478, 2394, 2389>, 0,
    <2478, 2389, 2477>, 0,
    <2480, 2471, 2467>, 0,
    <2480, 2467, 2477>, 0,
    <2480, 2477, 2389>, 0,
    <2480, 2389, 2390>, 0,
    <2480, 2390, 2369>, 0,
    <2480, 2369, 2479>, 0,
    <2480, 2479, 2468>, 0,
    <2480, 2468, 2471>, 0,
    <2489, 2488, 2481>, 0,
    <2489, 2481, 2485>, 0,
    <2489, 2485, 2482>, 0,
    <2489, 2482, 2486>, 0,
    <2489, 2486, 2483>, 0,
    <2489, 2483, 2487>, 0,
    <2489, 2487, 2484>, 0,
    <2489, 2484, 2488>, 0,
    <2494, 2493, 2481>, 0,
    <2494, 2481, 2488>, 0,
    <2494, 2488, 2484>, 0,
    <2494, 2484, 2491>, 0,
    <2494, 2491, 2459>, 0,
    <2494, 2459, 2492>, 0,
    <2494, 2492, 2490>, 0,
    <2494, 2490, 2493>, 0,
    <2498, 2485, 2481>, 0,
    <2498, 2481, 2493>, 0,
    <2498, 2493, 2490>, 0,
    <2498, 2490, 2496>, 0,
    <2498, 2496, 2495>, 0,
    <2498, 2495, 2497>, 0,
    <2498, 2497, 2482>, 0,
    <2498, 2482, 2485>, 0,
    <2502, 2501, 2499>, 0,
    <2502, 2499, 2500>, 0,
    <2502, 2500, 2490>, 0,
    <2502, 2490, 2492>, 0,
    <2502, 2492, 2459>, 0,
    <2502, 2459, 2461>, 0,
    <2502, 2461, 2454>, 0,
    <2502, 2454, 2501>, 0,
    <2506, 2505, 2499>, 0,
    <2506, 2499, 2501>, 0,
    <2506, 2501, 2454>, 0,
    <2506, 2454, 2456>, 0,
    <2506, 2456, 2413>, 0,
    <2506, 2413, 2504>, 0,
    <2506, 2504, 2503>, 0,
    <2506, 2503, 2505>, 0,
    <2508, 2500, 2499>, 0,
    <2508, 2499, 2505>, 0,
    <2508, 2505, 2503>, 0,
    <2508, 2503, 2507>, 0,
    <2508, 2507, 2495>, 0,
    <2508, 2495, 2496>, 0,
    <2508, 2496, 2490>, 0,
    <2508, 2490, 2500>, 0,
    <2514, 2513, 2509>, 0,
    <2514, 2509, 2511>, 0,
    <2514, 2511, 2510>, 0,
    <2514, 2510, 2512>, 0,
    <2514, 2512, 2445>, 0,
    <2514, 2445, 2447>, 0,
    <2514, 2447, 2440>, 0,
    <2514, 2440, 2513>, 0,
    <2518, 2517, 2509>, 0,
    <2518, 2509, 2513>, 0,
    <2518, 2513, 2440>, 0,
    <2518, 2440, 2442>, 0,
    <2518, 2442, 2431>, 0,
    <2518, 2431, 2516>, 0,
    <2518, 2516, 2515>, 0,
    <2518, 2515, 2517>, 0,
    <2522, 2511, 2509>, 0,
    <2522, 2509, 2517>, 0,
    <2522, 2517, 2515>, 0,
    <2522, 2515, 2520>, 0,
    <2522, 2520, 2519>, 0,
    <2522, 2519, 2521>, 0,
    <2522, 2521, 2510>, 0,
    <2522, 2510, 2511>, 0,
    <2531, 2530, 2523>, 0,
    <2531, 2523, 2527>, 0,
    <2531, 2527, 2524>, 0,
    <2531, 2524, 2528>, 0,
    <2531, 2528, 2525>, 0,
    <2531, 2525, 2529>, 0,
    <2531, 2529, 2526>, 0,
    <2531, 2526, 2530>, 0,
    <2534, 2533, 2523>, 0,
    <2534, 2523, 2530>, 0,
    <2534, 2530, 2526>, 0,
    <2534, 2526, 2532>, 0,
    <2534, 2532, 2519>, 0,
    <2534, 2519, 2520>, 0,
    <2534, 2520, 2515>, 0,
    <2534, 2515, 2533>, 0,
    <2536, 2527, 2523>, 0,
    <2536, 2523, 2533>, 0,
    <2536, 2533, 2515>, 0,
    <2536, 2515, 2516>, 0,
    <2536, 2516, 2431>, 0,
    <2536, 2431, 2535>, 0,
    <2536, 2535, 2524>, 0,
    <2536, 2524, 2527>, 0,
    <2542, 2541, 2537>, 0,
    <2542, 2537, 2539>, 0,
    <2542, 2539, 2538>, 0,
    <2542, 2538, 2540>, 0,
    <2542, 2540, 2483>, 0,
    <2542, 2483, 2486>, 0,
    <2542, 2486, 2482>, 0,
    <2542, 2482, 2541>, 0,
    <2546, 2545, 2537>, 0,
    <2546, 2537, 2541>, 0,
    <2546, 2541, 2482>, 0,
    <2546, 2482, 2497>, 0,
    <2546, 2497, 2495>, 0,
    <2546, 2495, 2544>, 0,
    <2546, 2544, 2543>, 0,
    <2546, 2543, 2545>, 0,
    <2550, 2539, 2537>, 0,
    <2550, 2537, 2545>, 0,
    <2550, 2545, 2543>, 0,
    <2550, 2543, 2548>, 0,
    <2550, 2548, 2547>, 0,
    <2550, 2547, 2549>, 0,
    <2550, 2549, 2538>, 0,
    <2550, 2538, 2539>, 0,
    <2559, 2558, 2551>, 0,
    <2559, 2551, 2555>, 0,
    <2559, 2555, 2552>, 0,
    <2559, 2552, 2556>, 0,
    <2559, 2556, 2553>, 0,
    <2559, 2553, 2557>, 0,
    <2559, 2557, 2554>, 0,
    <2559, 2554, 2558>, 0,
    <2564, 2563, 2551>, 0,
    <2564, 2551, 2558>, 0,
    <2564, 2558, 2554>, 0,
    <2564, 2554, 2561>, 0,
    <2564, 2561, 2312>, 0,
    <2564, 2312, 2562>, 0,
    <2564, 2562, 2560>, 0,
    <2564, 2560, 2563>, 0,
    <2568, 2555, 2551>, 0,
    <2568, 2551, 2563>, 0,
    <2568, 2563, 2560>, 0,
    <2568, 2560, 2566>, 0,
    <2568, 2566, 2565>, 0,
    <2568, 2565, 2567>, 0,
    <2568, 2567, 2552>, 0,
    <2568, 2552, 2555>, 0,
    <2577, 2576, 2569>, 0,
    <2577, 2569, 2573>, 0,
    <2577, 2573, 2570>, 0,
    <2577, 2570, 2574>, 0,
    <2577, 2574, 2571>, 0,
    <2577, 2571, 2575>, 0,
    <2577, 2575, 2572>, 0,
    <2577, 2572, 2576>, 0,
    <2580, 2579, 2569>, 0,
    <2580, 2569, 2576>, 0,
    <2580, 2576, 2572>, 0,
    <2580, 2572, 2578>, 0,
    <2580, 2578, 2312>, 0,
    <2580, 2312, 2350>, 0,
    <2580, 2350, 2344>, 0,
    <2580, 2344, 2579>, 0,
    <2582, 2573, 2569>, 0,
    <2582, 2569, 2579>, 0,
    <2582, 2579, 2344>, 0,
    <2582, 2344, 2347>, 0,
    <2582, 2347, 2343>, 0,
    <2582, 2343, 2581>, 0,
    <2582, 2581, 2570>, 0,
    <2582, 2570, 2573>, 0,
    <2588, 2587, 2583>, 0,
    <2588, 2583, 2585>, 0,
    <2588, 2585, 2572>, 0,
    <2588, 2572, 2575>, 0,
    <2588, 2575, 2571>, 0,
    <2588, 2571, 2586>, 0,
    <2588, 2586, 2584>, 0,
    <2588, 2584, 2587>, 0,
    <2593, 2592, 2583>, 0,
    <2593, 2583, 2587>, 0,
    <2593, 2587, 2584>, 0,
    <2593, 2584, 2590>, 0,
    <2593, 2590, 2553>, 0,
    <2593, 2553, 2591>, 0,
    <2593, 2591, 2589>, 0,
    <2593, 2589, 2592>, 0,
    <2595, 2585, 2583>, 0,
    <2595, 2583, 2592>, 0,
    <2595, 2592, 2589>, 0,
    <2595, 2589, 2594>, 0,
    <2595, 2594, 2312>, 0,
    <2595, 2312, 2578>, 0,
    <2595, 2578, 2572>, 0,
    <2595, 2572, 2585>, 0,
    <2604, 2603, 2596>, 0,
    <2604, 2596, 2600>, 0,
    <2604, 2600, 2597>, 0,
    <2604, 2597, 2601>, 0,
    <2604, 2601, 2598>, 0,
    <2604, 2598, 2602>, 0,
    <2604, 2602, 2599>, 0,
    <2604, 2599, 2603>, 0,
    <2607, 2606, 2596>, 0,
    <2607, 2596, 2603>, 0,
    <2607, 2603, 2599>, 0,
    <2607, 2599, 2605>, 0,
    <2607, 2605, 2553>, 0,
    <2607, 2553, 2590>, 0,
    <2607, 2590, 2584>, 0,
    <2607, 2584, 2606>, 0,
    <2609, 2600, 2596>, 0,
    <2609, 2596, 2606>, 0,
    <2609, 2606, 2584>, 0,
    <2609, 2584, 2586>, 0,
    <2609, 2586, 2571>, 0,
    <2609, 2571, 2608>, 0,
    <2609, 2608, 2597>, 0,
    <2609, 2597, 2600>, 0,
    <2617, 2616, 2610>, 0,
    <2617, 2610, 2613>, 0,
    <2617, 2613, 2611>, 0,
    <2617, 2611, 2614>, 0,
    <2617, 2614, 2469>, 0,
    <2617, 2469, 2615>, 0,
    <2617, 2615, 2612>, 0,
    <2617, 2612, 2616>, 0,
    <2623, 2622, 2610>, 0,
    <2623, 2610, 2616>, 0,
    <2623, 2616, 2612>, 0,
    <2623, 2612, 2620>, 0,
    <2623, 2620, 2618>, 0,
    <2623, 2618, 2621>, 0,
    <2623, 2621, 2619>, 0,
    <2623, 2619, 2622>, 0,
    <2627, 2613, 2610>, 0,
    <2627, 2610, 2622>, 0,
    <2627, 2622, 2619>, 0,
    <2627, 2619, 2625>, 0,
    <2627, 2625, 2624>, 0,
    <2627, 2624, 2626>, 0,
    <2627, 2626, 2611>, 0,
    <2627, 2611, 2613>, 0,
    <2631, 2630, 2628>, 0,
    <2631, 2628, 2629>, 0,
    <2631, 2629, 2612>, 0,
    <2631, 2612, 2615>, 0,
    <2631, 2615, 2469>, 0,
    <2631, 2469, 2472>, 0,
    <2631, 2472, 2468>, 0,
    <2631, 2468, 2630>, 0,
    <2635, 2634, 2628>, 0,
    <2635, 2628, 2630>, 0,
    <2635, 2630, 2468>, 0,
    <2635, 2468, 2479>, 0,
    <2635, 2479, 2369>, 0,
    <2635, 2369, 2633>, 0,
    <2635, 2633, 2632>, 0,
    <2635, 2632, 2634>, 0,
    <2637, 2629, 2628>, 0,
    <2637, 2628, 2634>, 0,
    <2637, 2634, 2632>, 0,
    <2637, 2632, 2636>, 0,
    <2637, 2636, 2618>, 0,
    <2637, 2618, 2620>, 0,
    <2637, 2620, 2612>, 0,
    <2637, 2612, 2629>, 0,
    <2643, 2642, 2638>, 0,
    <2643, 2638, 2640>, 0,
    <2643, 2640, 2639>, 0,
    <2643, 2639, 2641>, 0,
    <2643, 2641, 2624>, 0,
    <2643, 2624, 2625>, 0,
    <2643, 2625, 2619>, 0,
    <2643, 2619, 2642>, 0,
    <2647, 2646, 2638>, 0,
    <2647, 2638, 2642>, 0,
    <2647, 2642, 2619>, 0,
    <2647, 2619, 2621>, 0,
    <2647, 2621, 2618>, 0,
    <2647, 2618, 2645>, 0,
    <2647, 2645, 2644>, 0,
    <2647, 2644, 2646>, 0,
    <2651, 2640, 2638>, 0,
    <2651, 2638, 2646>, 0,
    <2651, 2646, 2644>, 0,
    <2651, 2644, 2649>, 0,
    <2651, 2649, 2648>, 0,
    <2651, 2648, 2650>, 0,
    <2651, 2650, 2639>, 0,
    <2651, 2639, 2640>, 0,
    <2660, 2659, 2652>, 0,
    <2660, 2652, 2656>, 0,
    <2660, 2656, 2653>, 0,
    <2660, 2653, 2657>, 0,
    <2660, 2657, 2654>, 0,
    <2660, 2654, 2658>, 0,
    <2660, 2658, 2655>, 0,
    <2660, 2655, 2659>, 0,
    <2663, 2662, 2652>, 0,
    <2663, 2652, 2659>, 0,
    <2663, 2659, 2655>, 0,
    <2663, 2655, 2661>, 0,
    <2663, 2661, 2547>, 0,
    <2663, 2547, 2548>, 0,
    <2663, 2548, 2543>, 0,
    <2663, 2543, 2662>, 0,
    <2665, 2656, 2652>, 0,
    <2665, 2652, 2662>, 0,
    <2665, 2662, 2543>, 0,
    <2665, 2543, 2544>, 0,
    <2665, 2544, 2495>, 0,
    <2665, 2495, 2664>, 0,
    <2665, 2664, 2653>, 0,
    <2665, 2653, 2656>, 0,
    <2674, 2673, 2666>, 0,
    <2674, 2666, 2670>, 0,
    <2674, 2670, 2667>, 0,
    <2674, 2667, 2671>, 0,
    <2674, 2671, 2668>, 0,
    <2674, 2668, 2672>, 0,
    <2674, 2672, 2669>, 0,
    <2674, 2669, 2673>, 0,
    <2677, 2676, 2666>, 0,
    <2677, 2666, 2673>, 0,
    <2677, 2673, 2669>, 0,
    <2677, 2669, 2675>, 0,
    <2677, 2675, 2654>, 0,
    <2677, 2654, 2657>, 0,
    <2677, 2657, 2653>, 0,
    <2677, 2653, 2676>, 0,
    <2679, 2670, 2666>, 0,
    <2679, 2666, 2676>, 0,
    <2679, 2676, 2653>, 0,
    <2679, 2653, 2664>, 0,
    <2679, 2664, 2495>, 0,
    <2679, 2495, 2678>, 0,
    <2679, 2678, 2667>, 0,
    <2679, 2667, 2670>, 0,
    <2687, 2686, 2680>, 0,
    <2687, 2680, 2683>, 0,
    <2687, 2683, 2681>, 0,
    <2687, 2681, 2684>, 0,
    <2687, 2684, 2668>, 0,
    <2687, 2668, 2685>, 0,
    <2687, 2685, 2682>, 0,
    <2687, 2682, 2686>, 0,
    <2693, 2692, 2680>, 0,
    <2693, 2680, 2686>, 0,
    <2693, 2686, 2682>, 0,
    <2693, 2682, 2690>, 0,
    <2693, 2690, 2688>, 0,
    <2693, 2688, 2691>, 0,
    <2693, 2691, 2689>, 0,
    <2693, 2689, 2692>, 0,
    <2696, 2683, 2680>, 0,
    <2696, 2680, 2692>, 0,
    <2696, 2692, 2689>, 0,
    <2696, 2689, 2694>, 0,
    <2696, 2694, 2547>, 0,
    <2696, 2547, 2695>, 0,
    <2696, 2695, 2681>, 0,
    <2696, 2681, 2683>, 0,
    <2705, 2704, 2697>, 0,
    <2705, 2697, 2701>, 0,
    <2705, 2701, 2698>, 0,
    <2705, 2698, 2702>, 0,
    <2705, 2702, 2699>, 0,
    <2705, 2699, 2703>, 0,
    <2705, 2703, 2700>, 0,
    <2705, 2700, 2704>, 0,
    <2711, 2710, 2697>, 0,
    <2711, 2697, 2704>, 0,
    <2711, 2704, 2700>, 0,
    <2711, 2700, 2708>, 0,
    <2711, 2708, 2706>, 0,
    <2711, 2706, 2709>, 0,
    <2711, 2709, 2707>, 0,
    <2711, 2707, 2710>, 0,
    <2714, 2701, 2697>, 0,
    <2714, 2697, 2710>, 0,
    <2714, 2710, 2707>, 0,
    <2714, 2707, 2712>, 0,
    <2714, 2712, 2519>, 0,
    <2714, 2519, 2713>, 0,
    <2714, 2713, 2698>, 0,
    <2714, 2698, 2701>, 0,
    <2720, 2719, 2715>, 0,
    <2720, 2715, 2717>, 0,
    <2720, 2717, 2716>, 0,
    <2720, 2716, 2718>, 0,
    <2720, 2718, 2699>, 0,
    <2720, 2699, 2702>, 0,
    <2720, 2702, 2698>, 0,
    <2720, 2698, 2719>, 0,
    <2722, 2721, 2715>, 0,
    <2722, 2715, 2719>, 0,
    <2722, 2719, 2698>, 0,
    <2722, 2698, 2713>, 0,
    <2722, 2713, 2519>, 0,
    <2722, 2519, 2532>, 0,
    <2722, 2532, 2526>, 0,
    <2722, 2526, 2721>, 0,
    <2724, 2717, 2715>, 0,
    <2724, 2715, 2721>, 0,
    <2724, 2721, 2526>, 0,
    <2724, 2526, 2529>, 0,
    <2724, 2529, 2525>, 0,
    <2724, 2525, 2723>, 0,
    <2724, 2723, 2716>, 0,
    <2724, 2716, 2717>, 0,
    <2733, 2732, 2725>, 0,
    <2733, 2725, 2729>, 0,
    <2733, 2729, 2726>, 0,
    <2733, 2726, 2730>, 0,
    <2733, 2730, 2727>, 0,
    <2733, 2727, 2731>, 0,
    <2733, 2731, 2728>, 0,
    <2733, 2728, 2732>, 0,
    <2736, 2735, 2725>, 0,
    <2736, 2725, 2732>, 0,
    <2736, 2732, 2728>, 0,
    <2736, 2728, 2734>, 0,
    <2736, 2734, 2648>, 0,
    <2736, 2648, 2649>, 0,
    <2736, 2649, 2644>, 0,
    <2736, 2644, 2735>, 0,
    <2738, 2729, 2725>, 0,
    <2738, 2725, 2735>, 0,
    <2738, 2735, 2644>, 0,
    <2738, 2644, 2645>, 0,
    <2738, 2645, 2618>, 0,
    <2738, 2618, 2737>, 0,
    <2738, 2737, 2726>, 0,
    <2738, 2726, 2729>, 0,
    <2747, 2746, 2739>, 0,
    <2747, 2739, 2743>, 0,
    <2747, 2743, 2740>, 0,
    <2747, 2740, 2744>, 0,
    <2747, 2744, 2741>, 0,
    <2747, 2741, 2745>, 0,
    <2747, 2745, 2742>, 0,
    <2747, 2742, 2746>, 0,
    <2752, 2751, 2739>, 0,
    <2752, 2739, 2746>, 0,
    <2752, 2746, 2742>, 0,
    <2752, 2742, 2749>, 0,
    <2752, 2749, 2688>, 0,
    <2752, 2688, 2750>, 0,
    <2752, 2750, 2748>, 0,
    <2752, 2748, 2751>, 0,
    <2756, 2743, 2739>, 0,
    <2756, 2739, 2751>, 0,
    <2756, 2751, 2748>, 0,
    <2756, 2748, 2754>, 0,
    <2756, 2754, 2753>, 0,
    <2756, 2753, 2755>, 0,
    <2756, 2755, 2740>, 0,
    <2756, 2740, 2743>, 0,
    <2760, 2759, 2757>, 0,
    <2760, 2757, 2758>, 0,
    <2760, 2758, 2748>, 0,
    <2760, 2748, 2750>, 0,
    <2760, 2750, 2688>, 0,
    <2760, 2688, 2690>, 0,
    <2760, 2690, 2682>, 0,
    <2760, 2682, 2759>, 0,
    <2764, 2763, 2757>, 0,
    <2764, 2757, 2759>, 0,
    <2764, 2759, 2682>, 0,
    <2764, 2682, 2685>, 0,
    <2764, 2685, 2668>, 0,
    <2764, 2668, 2762>, 0,
    <2764, 2762, 2761>, 0,
    <2764, 2761, 2763>, 0,
    <2766, 2758, 2757>, 0,
    <2766, 2757, 2763>, 0,
    <2766, 2763, 2761>, 0,
    <2766, 2761, 2765>, 0,
    <2766, 2765, 2753>, 0,
    <2766, 2753, 2754>, 0,
    <2766, 2754, 2748>, 0,
    <2766, 2748, 2758>, 0,
    <2772, 2771, 2767>, 0,
    <2772, 2767, 2769>, 0,
    <2772, 2769, 2768>, 0,
    <2772, 2768, 2770>, 0,
    <2772, 2770, 2706>, 0,
    <2772, 2706, 2708>, 0,
    <2772, 2708, 2700>, 0,
    <2772, 2700, 2771>, 0,
    <2776, 2775, 2767>, 0,
    <2776, 2767, 2771>, 0,
    <2776, 2771, 2700>, 0,
    <2776, 2700, 2703>, 0,
    <2776, 2703, 2699>, 0,
    <2776, 2699, 2774>, 0,
    <2776, 2774, 2773>, 0,
    <2776, 2773, 2775>, 0,
    <2780, 2769, 2767>, 0,
    <2780, 2767, 2775>, 0,
    <2780, 2775, 2773>, 0,
    <2780, 2773, 2778>, 0,
    <2780, 2778, 2777>, 0,
    <2780, 2777, 2779>, 0,
    <2780, 2779, 2768>, 0,
    <2780, 2768, 2769>, 0,
    <2786, 2785, 2781>, 0,
    <2786, 2781, 2783>, 0,
    <2786, 2783, 2782>, 0,
    <2786, 2782, 2784>, 0,
    <2786, 2784, 2741>, 0,
    <2786, 2741, 2744>, 0,
    <2786, 2744, 2740>, 0,
    <2786, 2740, 2785>, 0,
    <2790, 2789, 2781>, 0,
    <2790, 2781, 2785>, 0,
    <2790, 2785, 2740>, 0,
    <2790, 2740, 2755>, 0,
    <2790, 2755, 2753>, 0,
    <2790, 2753, 2788>, 0,
    <2790, 2788, 2787>, 0,
    <2790, 2787, 2789>, 0,
    <2794, 2783, 2781>, 0,
    <2794, 2781, 2789>, 0,
    <2794, 2789, 2787>, 0,
    <2794, 2787, 2792>, 0,
    <2794, 2792, 2791>, 0,
    <2794, 2791, 2793>, 0,
    <2794, 2793, 2782>, 0,
    <2794, 2782, 2783>, 0,
    <2803, 2802, 2795>, 0,
    <2803, 2795, 2799>, 0,
    <2803, 2799, 2796>, 0,
    <2803, 2796, 2800>, 0,
    <2803, 2800, 2797>, 0,
    <2803, 2797, 2801>, 0,
    <2803, 2801, 2798>, 0,
    <2803, 2798, 2802>, 0,
    <2806, 2805, 2795>, 0,
    <2806, 2795, 2802>, 0,
    <2806, 2802, 2798>, 0,
    <2806, 2798, 2804>, 0,
    <2806, 2804, 2777>, 0,
    <2806, 2777, 2778>, 0,
    <2806, 2778, 2773>, 0,
    <2806, 2773, 2805>, 0,
    <2808, 2799, 2795>, 0,
    <2808, 2795, 2805>, 0,
    <2808, 2805, 2773>, 0,
    <2808, 2773, 2774>, 0,
    <2808, 2774, 2699>, 0,
    <2808, 2699, 2807>, 0,
    <2808, 2807, 2796>, 0,
    <2808, 2796, 2799>, 0,
    <2817, 2816, 2809>, 0,
    <2817, 2809, 2813>, 0,
    <2817, 2813, 2810>, 0,
    <2817, 2810, 2814>, 0,
    <2817, 2814, 2811>, 0,
    <2817, 2811, 2815>, 0,
    <2817, 2815, 2812>, 0,
    <2817, 2812, 2816>, 0,
    <2822, 2821, 2809>, 0,
    <2822, 2809, 2816>, 0,
    <2822, 2816, 2812>, 0,
    <2822, 2812, 2819>, 0,
    <2822, 2819, 2553>, 0,
    <2822, 2553, 2820>, 0,
    <2822, 2820, 2818>, 0,
    <2822, 2818, 2821>, 0,
    <2826, 2813, 2809>, 0,
    <2826, 2809, 2821>, 0,
    <2826, 2821, 2818>, 0,
    <2826, 2818, 2824>, 0,
    <2826, 2824, 2823>, 0,
    <2826, 2823, 2825>, 0,
    <2826, 2825, 2810>, 0,
    <2826, 2810, 2813>, 0,
    <2835, 2834, 2827>, 0,
    <2835, 2827, 2831>, 0,
    <2835, 2831, 2828>, 0,
    <2835, 2828, 2832>, 0,
    <2835, 2832, 2829>, 0,
    <2835, 2829, 2833>, 0,
    <2835, 2833, 2830>, 0,
    <2835, 2830, 2834>, 0,
    <2838, 2837, 2827>, 0,
    <2838, 2827, 2834>, 0,
    <2838, 2834, 2830>, 0,
    <2838, 2830, 2836>, 0,
    <2838, 2836, 2791>, 0,
    <2838, 2791, 2792>, 0,
    <2838, 2792, 2787>, 0,
    <2838, 2787, 2837>, 0,
    <2840, 2831, 2827>, 0,
    <2840, 2827, 2837>, 0,
    <2840, 2837, 2787>, 0,
    <2840, 2787, 2788>, 0,
    <2840, 2788, 2753>, 0,
    <2840, 2753, 2839>, 0,
    <2840, 2839, 2828>, 0,
    <2840, 2828, 2831>, 0,
    <2849, 2848, 2841>, 0,
    <2849, 2841, 2845>, 0,
    <2849, 2845, 2842>, 0,
    <2849, 2842, 2846>, 0,
    <2849, 2846, 2843>, 0,
    <2849, 2843, 2847>, 0,
    <2849, 2847, 2844>, 0,
    <2849, 2844, 2848>, 0,
    <2852, 2851, 2841>, 0,
    <2852, 2841, 2848>, 0,
    <2852, 2848, 2844>, 0,
    <2852, 2844, 2850>, 0,
    <2852, 2850, 2553>, 0,
    <2852, 2553, 2605>, 0,
    <2852, 2605, 2599>, 0,
    <2852, 2599, 2851>, 0,
    <2854, 2845, 2841>, 0,
    <2854, 2841, 2851>, 0,
    <2854, 2851, 2599>, 0,
    <2854, 2599, 2602>, 0,
    <2854, 2602, 2598>, 0,
    <2854, 2598, 2853>, 0,
    <2854, 2853, 2842>, 0,
    <2854, 2842, 2845>, 0,
    <2860, 2859, 2855>, 0,
    <2860, 2855, 2857>, 0,
    <2860, 2857, 2844>, 0,
    <2860, 2844, 2847>, 0,
    <2860, 2847, 2843>, 0,
    <2860, 2843, 2858>, 0,
    <2860, 2858, 2856>, 0,
    <2860, 2856, 2859>, 0,
    <2865, 2864, 2855>, 0,
    <2865, 2855, 2859>, 0,
    <2865, 2859, 2856>, 0,
    <2865, 2856, 2862>, 0,
    <2865, 2862, 2811>, 0,
    <2865, 2811, 2863>, 0,
    <2865, 2863, 2861>, 0,
    <2865, 2861, 2864>, 0,
    <2867, 2857, 2855>, 0,
    <2867, 2855, 2864>, 0,
    <2867, 2864, 2861>, 0,
    <2867, 2861, 2866>, 0,
    <2867, 2866, 2553>, 0,
    <2867, 2553, 2850>, 0,
    <2867, 2850, 2844>, 0,
    <2867, 2844, 2857>, 0,
    <2876, 2875, 2868>, 0,
    <2876, 2868, 2872>, 0,
    <2876, 2872, 2869>, 0,
    <2876, 2869, 2873>, 0,
    <2876, 2873, 2870>, 0,
    <2876, 2870, 2874>, 0,
    <2876, 2874, 2871>, 0,
    <2876, 2871, 2875>, 0,
    <2879, 2878, 2868>, 0,
    <2879, 2868, 2875>, 0,
    <2879, 2875, 2871>, 0,
    <2879, 2871, 2877>, 0,
    <2879, 2877, 2811>, 0,
    <2879, 2811, 2862>, 0,
    <2879, 2862, 2856>, 0,
    <2879, 2856, 2878>, 0,
    <2881, 2872, 2868>, 0,
    <2881, 2868, 2878>, 0,
    <2881, 2878, 2856>, 0,
    <2881, 2856, 2858>, 0,
    <2881, 2858, 2843>, 0,
    <2881, 2843, 2880>, 0,
    <2881, 2880, 2869>, 0,
    <2881, 2869, 2872>, 0,
    <2890, 2889, 2882>, 0,
    <2890, 2882, 2886>, 0,
    <2890, 2886, 2883>, 0,
    <2890, 2883, 2887>, 0,
    <2890, 2887, 2884>, 0,
    <2890, 2884, 2888>, 0,
    <2890, 2888, 2885>, 0,
    <2890, 2885, 2889>, 0,
    <2895, 2894, 2882>, 0,
    <2895, 2882, 2889>, 0,
    <2895, 2889, 2885>, 0,
    <2895, 2885, 2892>, 0,
    <2895, 2892, 2727>, 0,
    <2895, 2727, 2893>, 0,
    <2895, 2893, 2891>, 0,
    <2895, 2891, 2894>, 0,
    <2899, 2886, 2882>, 0,
    <2899, 2882, 2894>, 0,
    <2899, 2894, 2891>, 0,
    <2899, 2891, 2897>, 0,
    <2899, 2897, 2896>, 0,
    <2899, 2896, 2898>, 0,
    <2899, 2898, 2883>, 0,
    <2899, 2883, 2886>, 0,
    <2903, 2902, 2900>, 0,
    <2903, 2900, 2901>, 0,
    <2903, 2901, 2891>, 0,
    <2903, 2891, 2893>, 0,
    <2903, 2893, 2727>, 0,
    <2903, 2727, 2730>, 0,
    <2903, 2730, 2726>, 0,
    <2903, 2726, 2902>, 0,
    <2907, 2906, 2900>, 0,
    <2907, 2900, 2902>, 0,
    <2907, 2902, 2726>, 0,
    <2907, 2726, 2737>, 0,
    <2907, 2737, 2618>, 0,
    <2907, 2618, 2905>, 0,
    <2907, 2905, 2904>, 0,
    <2907, 2904, 2906>, 0,
    <2909, 2901, 2900>, 0,
    <2909, 2900, 2906>, 0,
    <2909, 2906, 2904>, 0,
    <2909, 2904, 2908>, 0,
    <2909, 2908, 2896>, 0,
    <2909, 2896, 2897>, 0,
    <2909, 2897, 2891>, 0,
    <2909, 2891, 2901>, 0,
    <2915, 2914, 2910>, 0,
    <2915, 2910, 2912>, 0,
    <2915, 2912, 2911>, 0,
    <2915, 2911, 2913>, 0,
    <2915, 2913, 2884>, 0,
    <2915, 2884, 2887>, 0,
    <2915, 2887, 2883>, 0,
    <2915, 2883, 2914>, 0,
    <2919, 2918, 2910>, 0,
    <2919, 2910, 2914>, 0,
    <2919, 2914, 2883>, 0,
    <2919, 2883, 2898>, 0,
    <2919, 2898, 2896>, 0,
    <2919, 2896, 2917>, 0,
    <2919, 2917, 2916>, 0,
    <2919, 2916, 2918>, 0,
    <2923, 2912, 2910>, 0,
    <2923, 2910, 2918>, 0,
    <2923, 2918, 2916>, 0,
    <2923, 2916, 2921>, 0,
    <2923, 2921, 2920>, 0,
    <2923, 2920, 2922>, 0,
    <2923, 2922, 2911>, 0,
    <2923, 2911, 2912>, 0,
    <2932, 2931, 2924>, 0,
    <2932, 2924, 2928>, 0,
    <2932, 2928, 2925>, 0,
    <2932, 2925, 2929>, 0,
    <2932, 2929, 2926>, 0,
    <2932, 2926, 2930>, 0,
    <2932, 2930, 2927>, 0,
    <2932, 2927, 2931>, 0,
    <2935, 2934, 2924>, 0,
    <2935, 2924, 2931>, 0,
    <2935, 2931, 2927>, 0,
    <2935, 2927, 2933>, 0,
    <2935, 2933, 2777>, 0,
    <2935, 2777, 2804>, 0,
    <2935, 2804, 2798>, 0,
    <2935, 2798, 2934>, 0,
    <2937, 2928, 2924>, 0,
    <2937, 2924, 2934>, 0,
    <2937, 2934, 2798>, 0,
    <2937, 2798, 2801>, 0,
    <2937, 2801, 2797>, 0,
    <2937, 2797, 2936>, 0,
    <2937, 2936, 2925>, 0,
    <2937, 2925, 2928>, 0,
    <2946, 2945, 2938>, 0,
    <2946, 2938, 2942>, 0,
    <2946, 2942, 2939>, 0,
    <2946, 2939, 2943>, 0,
    <2946, 2943, 2940>, 0,
    <2946, 2940, 2944>, 0,
    <2946, 2944, 2941>, 0,
    <2946, 2941, 2945>, 0,
    <2949, 2948, 2938>, 0,
    <2949, 2938, 2945>, 0,
    <2949, 2945, 2941>, 0,
    <2949, 2941, 2947>, 0,
    <2949, 2947, 2829>, 0,
    <2949, 2829, 2832>, 0,
    <2949, 2832, 2828>, 0,
    <2949, 2828, 2948>, 0,
    <2951, 2942, 2938>, 0,
    <2951, 2938, 2948>, 0,
    <2951, 2948, 2828>, 0,
    <2951, 2828, 2839>, 0,
    <2951, 2839, 2753>, 0,
    <2951, 2753, 2950>, 0,
    <2951, 2950, 2939>, 0,
    <2951, 2939, 2942>, 0,
    <2957, 2956, 2952>, 0,
    <2957, 2952, 2954>, 0,
    <2957, 2954, 2927>, 0,
    <2957, 2927, 2930>, 0,
    <2957, 2930, 2926>, 0,
    <2957, 2926, 2955>, 0,
    <2957, 2955, 2953>, 0,
    <2957, 2953, 2956>, 0,
    <2963, 2962, 2952>, 0,
    <2963, 2952, 2956>, 0,
    <2963, 2956, 2953>, 0,
    <2963, 2953, 2960>, 0,
    <2963, 2960, 2958>, 0,
    <2963, 2958, 2961>, 0,
    <2963, 2961, 2959>, 0,
    <2963, 2959, 2962>, 0,
    <2965, 2954, 2952>, 0,
    <2965, 2952, 2962>, 0,
    <2965, 2962, 2959>, 0,
    <2965, 2959, 2964>, 0,
    <2965, 2964, 2777>, 0,
    <2965, 2777, 2933>, 0,
    <2965, 2933, 2927>, 0,
    <2965, 2927, 2954>, 0,
    <2971, 2970, 2966>, 0,
    <2971, 2966, 2968>, 0,
    <2971, 2968, 2959>, 0,
    <2971, 2959, 2961>, 0,
    <2971, 2961, 2958>, 0,
    <2971, 2958, 2969>, 0,
    <2971, 2969, 2967>, 0,
    <2971, 2967, 2970>, 0,
    <2977, 2976, 2966>, 0,
    <2977, 2966, 2970>, 0,
    <2977, 2970, 2967>, 0,
    <2977, 2967, 2974>, 0,
    <2977, 2974, 2972>, 0,
    <2977, 2972, 2975>, 0,
    <2977, 2975, 2973>, 0,
    <2977, 2973, 2976>, 0,
    <2979, 2968, 2966>, 0,
    <2979, 2966, 2976>, 0,
    <2979, 2976, 2973>, 0,
    <2979, 2973, 2978>, 0,
    <2979, 2978, 2777>, 0,
    <2979, 2777, 2964>, 0,
    <2979, 2964, 2959>, 0,
    <2979, 2959, 2968>, 0,
    <2987, 2986, 2980>, 0,
    <2987, 2980, 2983>, 0,
    <2987, 2983, 2981>, 0,
    <2987, 2981, 2984>, 0,
    <2987, 2984, 2940>, 0,
    <2987, 2940, 2985>, 0,
    <2987, 2985, 2982>, 0,
    <2987, 2982, 2986>, 0,
    <2993, 2992, 2980>, 0,
    <2993, 2980, 2986>, 0,
    <2993, 2986, 2982>, 0,
    <2993, 2982, 2990>, 0,
    <2993, 2990, 2988>, 0,
    <2993, 2988, 2991>, 0,
    <2993, 2991, 2989>, 0,
    <2993, 2989, 2992>, 0,
    <2996, 2983, 2980>, 0,
    <2996, 2980, 2992>, 0,
    <2996, 2992, 2989>, 0,
    <2996, 2989, 2994>, 0,
    <2996, 2994, 2791>, 0,
    <2996, 2791, 2995>, 0,
    <2996, 2995, 2981>, 0,
    <2996, 2981, 2983>, 0,
    <3002, 3001, 2997>, 0,
    <3002, 2997, 2999>, 0,
    <3002, 2999, 2998>, 0,
    <3002, 2998, 3000>, 0,
    <3002, 3000, 2988>, 0,
    <3002, 2988, 2990>, 0,
    <3002, 2990, 2982>, 0,
    <3002, 2982, 3001>, 0,
    <3006, 3005, 2997>, 0,
    <3006, 2997, 3001>, 0,
    <3006, 3001, 2982>, 0,
    <3006, 2982, 2985>, 0,
    <3006, 2985, 2940>, 0,
    <3006, 2940, 3004>, 0,
    <3006, 3004, 3003>, 0,
    <3006, 3003, 3005>, 0,
    <3010, 2999, 2997>, 0,
    <3010, 2997, 3005>, 0,
    <3010, 3005, 3003>, 0,
    <3010, 3003, 3008>, 0,
    <3010, 3008, 3007>, 0,
    <3010, 3007, 3009>, 0,
    <3010, 3009, 2998>, 0,
    <3010, 2998, 2999>, 0,
    <3019, 3018, 3011>, 0,
    <3019, 3011, 3015>, 0,
    <3019, 3015, 3012>, 0,
    <3019, 3012, 3016>, 0,
    <3019, 3016, 3013>, 0,
    <3019, 3013, 3017>, 0,
    <3019, 3017, 3014>, 0,
    <3019, 3014, 3018>, 0,
    <3025, 3024, 3011>, 0,
    <3025, 3011, 3018>, 0,
    <3025, 3018, 3014>, 0,
    <3025, 3014, 3022>, 0,
    <3025, 3022, 3020>, 0,
    <3025, 3020, 3023>, 0,
    <3025, 3023, 3021>, 0,
    <3025, 3021, 3024>, 0,
    <3028, 3015, 3011>, 0,
    <3028, 3011, 3024>, 0,
    <3028, 3024, 3021>, 0,
    <3028, 3021, 3026>, 0,
    <3028, 3026, 2958>, 0,
    <3028, 2958, 3027>, 0,
    <3028, 3027, 3012>, 0,
    <3028, 3012, 3015>, 0,
    <3034, 3033, 3029>, 0,
    <3034, 3029, 3031>, 0,
    <3034, 3031, 3030>, 0,
    <3034, 3030, 3032>, 0,
    <3034, 3032, 2972>, 0,
    <3034, 2972, 2974>, 0,
    <3034, 2974, 2967>, 0,
    <3034, 2967, 3033>, 0,
    <3036, 3035, 3029>, 0,
    <3036, 3029, 3033>, 0,
    <3036, 3033, 2967>, 0,
    <3036, 2967, 2969>, 0,
    <3036, 2969, 2958>, 0,
    <3036, 2958, 3026>, 0,
    <3036, 3026, 3021>, 0,
    <3036, 3021, 3035>, 0,
    <3038, 3031, 3029>, 0,
    <3038, 3029, 3035>, 0,
    <3038, 3035, 3021>, 0,
    <3038, 3021, 3023>, 0,
    <3038, 3023, 3020>, 0,
    <3038, 3020, 3037>, 0,
    <3038, 3037, 3030>, 0,
    <3038, 3030, 3031>, 0,
    <3044, 3043, 3039>, 0,
    <3044, 3039, 3041>, 0,
    <3044, 3041, 3040>, 0,
    <3044, 3040, 3042>, 0,
    <3044, 3042, 2988>, 0,
    <3044, 2988, 3000>, 0,
    <3044, 3000, 2998>, 0,
    <3044, 2998, 3043>, 0,
    <3048, 3047, 3039>, 0,
    <3048, 3039, 3043>, 0,
    <3048, 3043, 2998>, 0,
    <3048, 2998, 3009>, 0,
    <3048, 3009, 3007>, 0,
    <3048, 3007, 3046>, 0,
    <3048, 3046, 3045>, 0,
    <3048, 3045, 3047>, 0,
    <3052, 3041, 3039>, 0,
    <3052, 3039, 3047>, 0,
    <3052, 3047, 3045>, 0,
    <3052, 3045, 3050>, 0,
    <3052, 3050, 3049>, 0,
    <3052, 3049, 3051>, 0,
    <3052, 3051, 3040>, 0,
    <3052, 3040, 3041>, 0,
    <3061, 3060, 3053>, 0,
    <3061, 3053, 3057>, 0,
    <3061, 3057, 3054>, 0,
    <3061, 3054, 3058>, 0,
    <3061, 3058, 3055>, 0,
    <3061, 3055, 3059>, 0,
    <3061, 3059, 3056>, 0,
    <3061, 3056, 3060>, 0,
    <3064, 3063, 3053>, 0,
    <3064, 3053, 3060>, 0,
    <3064, 3060, 3056>, 0,
    <3064, 3056, 3062>, 0,
    <3064, 3062, 3020>, 0,
    <3064, 3020, 3022>, 0,
    <3064, 3022, 3014>, 0,
    <3064, 3014, 3063>, 0,
    <3066, 3057, 3053>, 0,
    <3066, 3053, 3063>, 0,
    <3066, 3063, 3014>, 0,
    <3066, 3014, 3017>, 0,
    <3066, 3017, 3013>, 0,
    <3066, 3013, 3065>, 0,
    <3066, 3065, 3054>, 0,
    <3066, 3054, 3057>, 0,
    <3075, 3074, 3067>, 0,
    <3075, 3067, 3071>, 0,
    <3075, 3071, 3068>, 0,
    <3075, 3068, 3072>, 0,
    <3075, 3072, 3069>, 0,
    <3075, 3069, 3073>, 0,
    <3075, 3073, 3070>, 0,
    <3075, 3070, 3074>, 0,
    <3080, 3079, 3067>, 0,
    <3080, 3067, 3074>, 0,
    <3080, 3074, 3070>, 0,
    <3080, 3070, 3077>, 0,
    <3080, 3077, 2811>, 0,
    <3080, 2811, 3078>, 0,
    <3080, 3078, 3076>, 0,
    <3080, 3076, 3079>, 0,
    <3084, 3071, 3067>, 0,
    <3084, 3067, 3079>, 0,
    <3084, 3079, 3076>, 0,
    <3084, 3076, 3082>, 0,
    <3084, 3082, 3081>, 0,
    <3084, 3081, 3083>, 0,
    <3084, 3083, 3068>, 0,
    <3084, 3068, 3071>, 0,
    <3093, 3092, 3085>, 0,
    <3093, 3085, 3089>, 0,
    <3093, 3089, 3086>, 0,
    <3093, 3086, 3090>, 0,
    <3093, 3090, 3087>, 0,
    <3093, 3087, 3091>, 0,
    <3093, 3091, 3088>, 0,
    <3093, 3088, 3092>, 0,
    <3096, 3095, 3085>, 0,
    <3096, 3085, 3092>, 0,
    <3096, 3092, 3088>, 0,
    <3096, 3088, 3094>, 0,
    <3096, 3094, 2811>, 0,
    <3096, 2811, 2877>, 0,
    <3096, 2877, 2871>, 0,
    <3096, 2871, 3095>, 0,
    <3098, 3089, 3085>, 0,
    <3098, 3085, 3095>, 0,
    <3098, 3095, 2871>, 0,
    <3098, 2871, 2874>, 0,
    <3098, 2874, 2870>, 0,
    <3098, 2870, 3097>, 0,
    <3098, 3097, 3086>, 0,
    <3098, 3086, 3089>, 0,
    <3104, 3103, 3099>, 0,
    <3104, 3099, 3101>, 0,
    <3104, 3101, 3088>, 0,
    <3104, 3088, 3091>, 0,
    <3104, 3091, 3087>, 0,
    <3104, 3087, 3102>, 0,
    <3104, 3102, 3100>, 0,
    <3104, 3100, 3103>, 0,
    <3109, 3108, 3099>, 0,
    <3109, 3099, 3103>, 0,
    <3109, 3103, 3100>, 0,
    <3109, 3100, 3106>, 0,
    <3109, 3106, 3069>, 0,
    <3109, 3069, 3107>, 0,
    <3109, 3107, 3105>, 0,
    <3109, 3105, 3108>, 0,
    <3111, 3101, 3099>, 0,
    <3111, 3099, 3108>, 0,
    <3111, 3108, 3105>, 0,
    <3111, 3105, 3110>, 0,
    <3111, 3110, 2811>, 0,
    <3111, 2811, 3094>, 0,
    <3111, 3094, 3088>, 0,
    <3111, 3088, 3101>, 0,
    <3120, 3119, 3112>, 0,
    <3120, 3112, 3116>, 0,
    <3120, 3116, 3113>, 0,
    <3120, 3113, 3117>, 0,
    <3120, 3117, 3114>, 0,
    <3120, 3114, 3118>, 0,
    <3120, 3118, 3115>, 0,
    <3120, 3115, 3119>, 0,
    <3123, 3122, 3112>, 0,
    <3123, 3112, 3119>, 0,
    <3123, 3119, 3115>, 0,
    <3123, 3115, 3121>, 0,
    <3123, 3121, 3069>, 0,
    <3123, 3069, 3106>, 0,
    <3123, 3106, 3100>, 0,
    <3123, 3100, 3122>, 0,
    <3125, 3116, 3112>, 0,
    <3125, 3112, 3122>, 0,
    <3125, 3122, 3100>, 0,
    <3125, 3100, 3102>, 0,
    <3125, 3102, 3087>, 0,
    <3125, 3087, 3124>, 0,
    <3125, 3124, 3113>, 0,
    <3125, 3113, 3116>, 0,
    <3133, 3132, 3126>, 0,
    <3133, 3126, 3129>, 0,
    <3133, 3129, 3127>, 0,
    <3133, 3127, 3130>, 0,
    <3133, 3130, 2920>, 0,
    <3133, 2920, 3131>, 0,
    <3133, 3131, 3128>, 0,
    <3133, 3128, 3132>, 0,
    <3139, 3138, 3126>, 0,
    <3139, 3126, 3132>, 0,
    <3139, 3132, 3128>, 0,
    <3139, 3128, 3136>, 0,
    <3139, 3136, 3134>, 0,
    <3139, 3134, 3137>, 0,
    <3139, 3137, 3135>, 0,
    <3139, 3135, 3138>, 0,
    <3143, 3129, 3126>, 0,
    <3143, 3126, 3138>, 0,
    <3143, 3138, 3135>, 0,
    <3143, 3135, 3141>, 0,
    <3143, 3141, 3140>, 0,
    <3143, 3140, 3142>, 0,
    <3143, 3142, 3127>, 0,
    <3143, 3127, 3129>, 0,
    <3147, 3146, 3144>, 0,
    <3147, 3144, 3145>, 0,
    <3147, 3145, 3128>, 0,
    <3147, 3128, 3131>, 0,
    <3147, 3131, 2920>, 0,
    <3147, 2920, 2921>, 0,
    <3147, 2921, 2916>, 0,
    <3147, 2916, 3146>, 0,
    <3151, 3150, 3144>, 0,
    <3151, 3144, 3146>, 0,
    <3151, 3146, 2916>, 0,
    <3151, 2916, 2917>, 0,
    <3151, 2917, 2896>, 0,
    <3151, 2896, 3149>, 0,
    <3151, 3149, 3148>, 0,
    <3151, 3148, 3150>, 0,
    <3153, 3145, 3144>, 0,
    <3153, 3144, 3150>, 0,
    <3153, 3150, 3148>, 0,
    <3153, 3148, 3152>, 0,
    <3153, 3152, 3134>, 0,
    <3153, 3134, 3136>, 0,
    <3153, 3136, 3128>, 0,
    <3153, 3128, 3145>, 0,
    <3159, 3158, 3154>, 0,
    <3159, 3154, 3156>, 0,
    <3159, 3156, 3155>, 0,
    <3159, 3155, 3157>, 0,
    <3159, 3157, 3140>, 0,
    <3159, 3140, 3141>, 0,
    <3159, 3141, 3135>, 0,
    <3159, 3135, 3158>, 0,
    <3163, 3162, 3154>, 0,
    <3163, 3154, 3158>, 0,
    <3163, 3158, 3135>, 0,
    <3163, 3135, 3137>, 0,
    <3163, 3137, 3134>, 0,
    <3163, 3134, 3161>, 0,
    <3163, 3161, 3160>, 0,
    <3163, 3160, 3162>, 0,
    <3167, 3156, 3154>, 0,
    <3167, 3154, 3162>, 0,
    <3167, 3162, 3160>, 0,
    <3167, 3160, 3165>, 0,
    <3167, 3165, 3164>, 0,
    <3167, 3164, 3166>, 0,
    <3167, 3166, 3155>, 0,
    <3167, 3155, 3156>, 0,
    <3176, 3175, 3168>, 0,
    <3176, 3168, 3172>, 0,
    <3176, 3172, 3169>, 0,
    <3176, 3169, 3173>, 0,
    <3176, 3173, 3170>, 0,
    <3176, 3170, 3174>, 0,
    <3176, 3174, 3171>, 0,
    <3176, 3171, 3175>, 0,
    <3179, 3178, 3168>, 0,
    <3179, 3168, 3175>, 0,
    <3179, 3175, 3171>, 0,
    <3179, 3171, 3177>, 0,
    <3179, 3177, 3049>, 0,
    <3179, 3049, 3050>, 0,
    <3179, 3050, 3045>, 0,
    <3179, 3045, 3178>, 0,
    <3181, 3172, 3168>, 0,
    <3181, 3168, 3178>, 0,
    <3181, 3178, 3045>, 0,
    <3181, 3045, 3046>, 0,
    <3181, 3046, 3007>, 0,
    <3181, 3007, 3180>, 0,
    <3181, 3180, 3169>, 0,
    <3181, 3169, 3172>, 0,
    <3187, 3186, 3182>, 0,
    <3187, 3182, 3184>, 0,
    <3187, 3184, 3171>, 0,
    <3187, 3171, 3174>, 0,
    <3187, 3174, 3170>, 0,
    <3187, 3170, 3185>, 0,
    <3187, 3185, 3183>, 0,
    <3187, 3183, 3186>, 0,
    <3193, 3192, 3182>, 0,
    <3193, 3182, 3186>, 0,
    <3193, 3186, 3183>, 0,
    <3193, 3183, 3190>, 0,
    <3193, 3190, 3188>, 0,
    <3193, 3188, 3191>, 0,
    <3193, 3191, 3189>, 0,
    <3193, 3189, 3192>, 0,
    <3195, 3184, 3182>, 0,
    <3195, 3182, 3192>, 0,
    <3195, 3192, 3189>, 0,
    <3195, 3189, 3194>, 0,
    <3195, 3194, 3049>, 0,
    <3195, 3049, 3177>, 0,
    <3195, 3177, 3171>, 0,
    <3195, 3171, 3184>, 0,
    <3204, 3203, 3196>, 0,
    <3204, 3196, 3200>, 0,
    <3204, 3200, 3197>, 0,
    <3204, 3197, 3201>, 0,
    <3204, 3201, 3198>, 0,
    <3204, 3198, 3202>, 0,
    <3204, 3202, 3199>, 0,
    <3204, 3199, 3203>, 0,
    <3210, 3209, 3196>, 0,
    <3210, 3196, 3203>, 0,
    <3210, 3203, 3199>, 0,
    <3210, 3199, 3207>, 0,
    <3210, 3207, 3205>, 0,
    <3210, 3205, 3208>, 0,
    <3210, 3208, 3206>, 0,
    <3210, 3206, 3209>, 0,
    <3213, 3200, 3196>, 0,
    <3213, 3196, 3209>, 0,
    <3213, 3209, 3206>, 0,
    <3213, 3206, 3211>, 0,
    <3213, 3211, 3020>, 0,
    <3213, 3020, 3212>, 0,
    <3213, 3212, 3197>, 0,
    <3213, 3197, 3200>, 0,
    <3219, 3218, 3214>, 0,
    <3219, 3214, 3216>, 0,
    <3219, 3216, 3215>, 0,
    <3219, 3215, 3217>, 0,
    <3219, 3217, 3198>, 0,
    <3219, 3198, 3201>, 0,
    <3219, 3201, 3197>, 0,
    <3219, 3197, 3218>, 0,
    <3221, 3220, 3214>, 0,
    <3221, 3214, 3218>, 0,
    <3221, 3218, 3197>, 0,
    <3221, 3197, 3212>, 0,
    <3221, 3212, 3020>, 0,
    <3221, 3020, 3062>, 0,
    <3221, 3062, 3056>, 0,
    <3221, 3056, 3220>, 0,
    <3223, 3216, 3214>, 0,
    <3223, 3214, 3220>, 0,
    <3223, 3220, 3056>, 0,
    <3223, 3056, 3059>, 0,
    <3223, 3059, 3055>, 0,
    <3223, 3055, 3222>, 0,
    <3223, 3222, 3215>, 0,
    <3223, 3215, 3216>, 0,
    <3232, 3231, 3224>, 0,
    <3232, 3224, 3228>, 0,
    <3232, 3228, 3225>, 0,
    <3232, 3225, 3229>, 0,
    <3232, 3229, 3226>, 0,
    <3232, 3226, 3230>, 0,
    <3232, 3230, 3227>, 0,
    <3232, 3227, 3231>, 0,
    <3237, 3236, 3224>, 0,
    <3237, 3224, 3231>, 0,
    <3237, 3231, 3227>, 0,
    <3237, 3227, 3234>, 0,
    <3237, 3234, 3188>, 0,
    <3237, 3188, 3235>, 0,
    <3237, 3235, 3233>, 0,
    <3237, 3233, 3236>, 0,
    <3241, 3228, 3224>, 0,
    <3241, 3224, 3236>, 0,
    <3241, 3236, 3233>, 0,
    <3241, 3233, 3239>, 0,
    <3241, 3239, 3238>, 0,
    <3241, 3238, 3240>, 0,
    <3241, 3240, 3225>, 0,
    <3241, 3225, 3228>, 0,
    <3245, 3244, 3242>, 0,
    <3245, 3242, 3243>, 0,
    <3245, 3243, 3233>, 0,
    <3245, 3233, 3235>, 0,
    <3245, 3235, 3188>, 0,
    <3245, 3188, 3190>, 0,
    <3245, 3190, 3183>, 0,
    <3245, 3183, 3244>, 0,
    <3249, 3248, 3242>, 0,
    <3249, 3242, 3244>, 0,
    <3249, 3244, 3183>, 0,
    <3249, 3183, 3185>, 0,
    <3249, 3185, 3170>, 0,
    <3249, 3170, 3247>, 0,
    <3249, 3247, 3246>, 0,
    <3249, 3246, 3248>, 0,
    <3251, 3243, 3242>, 0,
    <3251, 3242, 3248>, 0,
    <3251, 3248, 3246>, 0,
    <3251, 3246, 3250>, 0,
    <3251, 3250, 3238>, 0,
    <3251, 3238, 3239>, 0,
    <3251, 3239, 3233>, 0,
    <3251, 3233, 3243>, 0,
    <3257, 3256, 3252>, 0,
    <3257, 3252, 3254>, 0,
    <3257, 3254, 3253>, 0,
    <3257, 3253, 3255>, 0,
    <3257, 3255, 3205>, 0,
    <3257, 3205, 3207>, 0,
    <3257, 3207, 3199>, 0,
    <3257, 3199, 3256>, 0,
    <3261, 3260, 3252>, 0,
    <3261, 3252, 3256>, 0,
    <3261, 3256, 3199>, 0,
    <3261, 3199, 3202>, 0,
    <3261, 3202, 3198>, 0,
    <3261, 3198, 3259>, 0,
    <3261, 3259, 3258>, 0,
    <3261, 3258, 3260>, 0,
    <3265, 3254, 3252>, 0,
    <3265, 3252, 3260>, 0,
    <3265, 3260, 3258>, 0,
    <3265, 3258, 3263>, 0,
    <3265, 3263, 3262>, 0,
    <3265, 3262, 3264>, 0,
    <3265, 3264, 3253>, 0,
    <3265, 3253, 3254>, 0,
    <3271, 3270, 3266>, 0,
    <3271, 3266, 3268>, 0,
    <3271, 3268, 3267>, 0,
    <3271, 3267, 3269>, 0,
    <3271, 3269, 3226>, 0,
    <3271, 3226, 3229>, 0,
    <3271, 3229, 3225>, 0,
    <3271, 3225, 3270>, 0,
    <3275, 3274, 3266>, 0,
    <3275, 3266, 3270>, 0,
    <3275, 3270, 3225>, 0,
    <3275, 3225, 3240>, 0,
    <3275, 3240, 3238>, 0,
    <3275, 3238, 3273>, 0,
    <3275, 3273, 3272>, 0,
    <3275, 3272, 3274>, 0,
    <3279, 3268, 3266>, 0,
    <3279, 3266, 3274>, 0,
    <3279, 3274, 3272>, 0,
    <3279, 3272, 3277>, 0,
    <3279, 3277, 3276>, 0,
    <3279, 3276, 3278>, 0,
    <3279, 3278, 3267>, 0,
    <3279, 3267, 3268>, 0,
    <3288, 3287, 3280>, 0,
    <3288, 3280, 3284>, 0,
    <3288, 3284, 3281>, 0,
    <3288, 3281, 3285>, 0,
    <3288, 3285, 3282>, 0,
    <3288, 3282, 3286>, 0,
    <3288, 3286, 3283>, 0,
    <3288, 3283, 3287>, 0,
    <3291, 3290, 3280>, 0,
    <3291, 3280, 3287>, 0,
    <3291, 3287, 3283>, 0,
    <3291, 3283, 3289>, 0,
    <3291, 3289, 3262>, 0,
    <3291, 3262, 3263>, 0,
    <3291, 3263, 3258>, 0,
    <3291, 3258, 3290>, 0,
    <3293, 3284, 3280>, 0,
    <3293, 3280, 3290>, 0,
    <3293, 3290, 3258>, 0,
    <3293, 3258, 3259>, 0,
    <3293, 3259, 3198>, 0,
    <3293, 3198, 3292>, 0,
    <3293, 3292, 3281>, 0,
    <3293, 3281, 3284>, 0,
    <3302, 3301, 3294>, 0,
    <3302, 3294, 3298>, 0,
    <3302, 3298, 3295>, 0,
    <3302, 3295, 3299>, 0,
    <3302, 3299, 3296>, 0,
    <3302, 3296, 3300>, 0,
    <3302, 3300, 3297>, 0,
    <3302, 3297, 3301>, 0,
    <3305, 3304, 3294>, 0,
    <3305, 3294, 3301>, 0,
    <3305, 3301, 3297>, 0,
    <3305, 3297, 3303>, 0,
    <3305, 3303, 3276>, 0,
    <3305, 3276, 3277>, 0,
    <3305, 3277, 3272>, 0,
    <3305, 3272, 3304>, 0,
    <3307, 3298, 3294>, 0,
    <3307, 3294, 3304>, 0,
    <3307, 3304, 3272>, 0,
    <3307, 3272, 3273>, 0,
    <3307, 3273, 3238>, 0,
    <3307, 3238, 3306>, 0,
    <3307, 3306, 3295>, 0,
    <3307, 3295, 3298>, 0,
    <3316, 3315, 3308>, 0,
    <3316, 3308, 3312>, 0,
    <3316, 3312, 3309>, 0,
    <3316, 3309, 3313>, 0,
    <3316, 3313, 3310>, 0,
    <3316, 3310, 3314>, 0,
    <3316, 3314, 3311>, 0,
    <3316, 3311, 3315>, 0,
    <3319, 3318, 3308>, 0,
    <3319, 3308, 3315>, 0,
    <3319, 3315, 3311>, 0,
    <3319, 3311, 3317>, 0,
    <3319, 3317, 3164>, 0,
    <3319, 3164, 3165>, 0,
    <3319, 3165, 3160>, 0,
    <3319, 3160, 3318>, 0,
    <3321, 3312, 3308>, 0,
    <3321, 3308, 3318>, 0,
    <3321, 3318, 3160>, 0,
    <3321, 3160, 3161>, 0,
    <3321, 3161, 3134>, 0,
    <3321, 3134, 3320>, 0,
    <3321, 3320, 3309>, 0,
    <3321, 3309, 3312>, 0,
    <3330, 3329, 3322>, 0,
    <3330, 3322, 3326>, 0,
    <3330, 3326, 3323>, 0,
    <3330, 3323, 3327>, 0,
    <3330, 3327, 3324>, 0,
    <3330, 3324, 3328>, 0,
    <3330, 3328, 3325>, 0,
    <3330, 3325, 3329>, 0,
    <3333, 3332, 3322>, 0,
    <3333, 3322, 3329>, 0,
    <3333, 3329, 3325>, 0,
    <3333, 3325, 3331>, 0,
    <3333, 3331, 3262>, 0,
    <3333, 3262, 3289>, 0,
    <3333, 3289, 3283>, 0,
    <3333, 3283, 3332>, 0,
    <3335, 3326, 3322>, 0,
    <3335, 3322, 3332>, 0,
    <3335, 3332, 3283>, 0,
    <3335, 3283, 3286>, 0,
    <3335, 3286, 3282>, 0,
    <3335, 3282, 3334>, 0,
    <3335, 3334, 3323>, 0,
    <3335, 3323, 3326>, 0,
    <3344, 3343, 3336>, 0,
    <3344, 3336, 3340>, 0,
    <3344, 3340, 3337>, 0,
    <3344, 3337, 3341>, 0,
    <3344, 3341, 3338>, 0,
    <3344, 3338, 3342>, 0,
    <3344, 3342, 3339>, 0,
    <3344, 3339, 3343>, 0,
    <3347, 3346, 3336>, 0,
    <3347, 3336, 3343>, 0,
    <3347, 3343, 3339>, 0,
    <3347, 3339, 3345>, 0,
    <3347, 3345, 3069>, 0,
    <3347, 3069, 3121>, 0,
    <3347, 3121, 3115>, 0,
    <3347, 3115, 3346>, 0,
    <3349, 3340, 3336>, 0,
    <3349, 3336, 3346>, 0,
    <3349, 3346, 3115>, 0,
    <3349, 3115, 3118>, 0,
    <3349, 3118, 3114>, 0,
    <3349, 3114, 3348>, 0,
    <3349, 3348, 3337>, 0,
    <3349, 3337, 3340>, 0,
    <3358, 3357, 3350>, 0,
    <3358, 3350, 3354>, 0,
    <3358, 3354, 3351>, 0,
    <3358, 3351, 3355>, 0,
    <3358, 3355, 3352>, 0,
    <3358, 3352, 3356>, 0,
    <3358, 3356, 3353>, 0,
    <3358, 3353, 3357>, 0,
    <3361, 3360, 3350>, 0,
    <3361, 3350, 3357>, 0,
    <3361, 3357, 3353>, 0,
    <3361, 3353, 3359>, 0,
    <3361, 3359, 3296>, 0,
    <3361, 3296, 3299>, 0,
    <3361, 3299, 3295>, 0,
    <3361, 3295, 3360>, 0,
    <3363, 3354, 3350>, 0,
    <3363, 3350, 3360>, 0,
    <3363, 3360, 3295>, 0,
    <3363, 3295, 3306>, 0,
    <3363, 3306, 3238>, 0,
    <3363, 3238, 3362>, 0,
    <3363, 3362, 3351>, 0,
    <3363, 3351, 3354>, 0,
    <3369, 3368, 3364>, 0,
    <3369, 3364, 3366>, 0,
    <3369, 3366, 3339>, 0,
    <3369, 3339, 3342>, 0,
    <3369, 3342, 3338>, 0,
    <3369, 3338, 3367>, 0,
    <3369, 3367, 3365>, 0,
    <3369, 3365, 3368>, 0,
    <3375, 3374, 3364>, 0,
    <3375, 3364, 3368>, 0,
    <3375, 3368, 3365>, 0,
    <3375, 3365, 3372>, 0,
    <3375, 3372, 3370>, 0,
    <3375, 3370, 3373>, 0,
    <3375, 3373, 3371>, 0,
    <3375, 3371, 3374>, 0,
    <3377, 3366, 3364>, 0,
    <3377, 3364, 3374>, 0,
    <3377, 3374, 3371>, 0,
    <3377, 3371, 3376>, 0,
    <3377, 3376, 3069>, 0,
    <3377, 3069, 3345>, 0,
    <3377, 3345, 3339>, 0,
    <3377, 3339, 3366>, 0,
    <3386, 3385, 3378>, 0,
    <3386, 3378, 3382>, 0,
    <3386, 3382, 3379>, 0,
    <3386, 3379, 3383>, 0,
    <3386, 3383, 3380>, 0,
    <3386, 3380, 3384>, 0,
    <3386, 3384, 3381>, 0,
    <3386, 3381, 3385>, 0,
    <3389, 3388, 3378>, 0,
    <3389, 3378, 3385>, 0,
    <3389, 3385, 3381>, 0,
    <3389, 3381, 3387>, 0,
    <3389, 3387, 3370>, 0,
    <3389, 3370, 3372>, 0,
    <3389, 3372, 3365>, 0,
    <3389, 3365, 3388>, 0,
    <3391, 3382, 3378>, 0,
    <3391, 3378, 3388>, 0,
    <3391, 3388, 3365>, 0,
    <3391, 3365, 3367>, 0,
    <3391, 3367, 3338>, 0,
    <3391, 3338, 3390>, 0,
    <3391, 3390, 3379>, 0,
    <3391, 3379, 3382>, 0,
    <3400, 3399, 3392>, 0,
    <3400, 3392, 3396>, 0,
    <3400, 3396, 3393>, 0,
    <3400, 3393, 3397>, 0,
    <3400, 3397, 3394>, 0,
    <3400, 3394, 3398>, 0,
    <3400, 3398, 3395>, 0,
    <3400, 3395, 3399>, 0,
    <3405, 3404, 3392>, 0,
    <3405, 3392, 3399>, 0,
    <3405, 3399, 3395>, 0,
    <3405, 3395, 3402>, 0,
    <3405, 3402, 3310>, 0,
    <3405, 3310, 3403>, 0,
    <3405, 3403, 3401>, 0,
    <3405, 3401, 3404>, 0,
    <3409, 3396, 3392>, 0,
    <3409, 3392, 3404>, 0,
    <3409, 3404, 3401>, 0,
    <3409, 3401, 3407>, 0,
    <3409, 3407, 3406>, 0,
    <3409, 3406, 3408>, 0,
    <3409, 3408, 3393>, 0,
    <3409, 3393, 3396>, 0,
    <3413, 3412, 3410>, 0,
    <3413, 3410, 3411>, 0,
    <3413, 3411, 3401>, 0,
    <3413, 3401, 3403>, 0,
    <3413, 3403, 3310>, 0,
    <3413, 3310, 3313>, 0,
    <3413, 3313, 3309>, 0,
    <3413, 3309, 3412>, 0,
    <3417, 3416, 3410>, 0,
    <3417, 3410, 3412>, 0,
    <3417, 3412, 3309>, 0,
    <3417, 3309, 3320>, 0,
    <3417, 3320, 3134>, 0,
    <3417, 3134, 3415>, 0,
    <3417, 3415, 3414>, 0,
    <3417, 3414, 3416>, 0,
    <3419, 3411, 3410>, 0,
    <3419, 3410, 3416>, 0,
    <3419, 3416, 3414>, 0,
    <3419, 3414, 3418>, 0,
    <3419, 3418, 3406>, 0,
    <3419, 3406, 3407>, 0,
    <3419, 3407, 3401>, 0,
    <3419, 3401, 3411>, 0,
    <3425, 3424, 3420>, 0,
    <3425, 3420, 3422>, 0,
    <3425, 3422, 3421>, 0,
    <3425, 3421, 3423>, 0,
    <3425, 3423, 3394>, 0,
    <3425, 3394, 3397>, 0,
    <3425, 3397, 3393>, 0,
    <3425, 3393, 3424>, 0,
    <3429, 3428, 3420>, 0,
    <3429, 3420, 3424>, 0,
    <3429, 3424, 3393>, 0,
    <3429, 3393, 3408>, 0,
    <3429, 3408, 3406>, 0,
    <3429, 3406, 3427>, 0,
    <3429, 3427, 3426>, 0,
    <3429, 3426, 3428>, 0,
    <3433, 3422, 3420>, 0,
    <3433, 3420, 3428>, 0,
    <3433, 3428, 3426>, 0,
    <3433, 3426, 3431>, 0,
    <3433, 3431, 3430>, 0,
    <3433, 3430, 3432>, 0,
    <3433, 3432, 3421>, 0,
    <3433, 3421, 3422>, 0,
    <3441, 3440, 3434>, 0,
    <3441, 3434, 3437>, 0,
    <3441, 3437, 3435>, 0,
    <3441, 3435, 3438>, 0,
    <3441, 3438, 3352>, 0,
    <3441, 3352, 3439>, 0,
    <3441, 3439, 3436>, 0,
    <3441, 3436, 3440>, 0,
    <3447, 3446, 3434>, 0,
    <3447, 3434, 3440>, 0,
    <3447, 3440, 3436>, 0,
    <3447, 3436, 3444>, 0,
    <3447, 3444, 3442>, 0,
    <3447, 3442, 3445>, 0,
    <3447, 3445, 3443>, 0,
    <3447, 3443, 3446>, 0,
    <3450, 3437, 3434>, 0,
    <3450, 3434, 3446>, 0,
    <3450, 3446, 3443>, 0,
    <3450, 3443, 3448>, 0,
    <3450, 3448, 3276>, 0,
    <3450, 3276, 3449>, 0,
    <3450, 3449, 3435>, 0,
    <3450, 3435, 3437>, 0,
    <3456, 3455, 3451>, 0,
    <3456, 3451, 3453>, 0,
    <3456, 3453, 3325>, 0,
    <3456, 3325, 3328>, 0,
    <3456, 3328, 3324>, 0,
    <3456, 3324, 3454>, 0,
    <3456, 3454, 3452>, 0,
    <3456, 3452, 3455>, 0,
    <3462, 3461, 3451>, 0,
    <3462, 3451, 3455>, 0,
    <3462, 3455, 3452>, 0,
    <3462, 3452, 3459>, 0,
    <3462, 3459, 3457>, 0,
    <3462, 3457, 3460>, 0,
    <3462, 3460, 3458>, 0,
    <3462, 3458, 3461>, 0,
    <3464, 3453, 3451>, 0,
    <3464, 3451, 3461>, 0,
    <3464, 3461, 3458>, 0,
    <3464, 3458, 3463>, 0,
    <3464, 3463, 3262>, 0,
    <3464, 3262, 3331>, 0,
    <3464, 3331, 3325>, 0,
    <3464, 3325, 3453>, 0,
    <3470, 3469, 3465>, 0,
    <3470, 3465, 3467>, 0,
    <3470, 3467, 3458>, 0,
    <3470, 3458, 3460>, 0,
    <3470, 3460, 3457>, 0,
    <3470, 3457, 3468>, 0,
    <3470, 3468, 3466>, 0,
    <3470, 3466, 3469>, 0,
    <3476, 3475, 3465>, 0,
    <3476, 3465, 3469>, 0,
    <3476, 3469, 3466>, 0,
    <3476, 3466, 3473>, 0,
    <3476, 3473, 3471>, 0,
    <3476, 3471, 3474>, 0,
    <3476, 3474, 3472>, 0,
    <3476, 3472, 3475>, 0,
    <3478, 3467, 3465>, 0,
    <3478, 3465, 3475>, 0,
    <3478, 3475, 3472>, 0,
    <3478, 3472, 3477>, 0,
    <3478, 3477, 3262>, 0,
    <3478, 3262, 3463>, 0,
    <3478, 3463, 3458>, 0,
    <3478, 3458, 3467>, 0,
    <3487, 3486, 3479>, 0,
    <3487, 3479, 3483>, 0,
    <3487, 3483, 3480>, 0,
    <3487, 3480, 3484>, 0,
    <3487, 3484, 3481>, 0,
    <3487, 3481, 3485>, 0,
    <3487, 3485, 3482>, 0,
    <3487, 3482, 3486>, 0,
    <3492, 3491, 3479>, 0,
    <3492, 3479, 3486>, 0,
    <3492, 3486, 3482>, 0,
    <3492, 3482, 3489>, 0,
    <3492, 3489, 3442>, 0,
    <3492, 3442, 3490>, 0,
    <3492, 3490, 3488>, 0,
    <3492, 3488, 3491>, 0,
    <3496, 3483, 3479>, 0,
    <3496, 3479, 3491>, 0,
    <3496, 3491, 3488>, 0,
    <3496, 3488, 3494>, 0,
    <3496, 3494, 3493>, 0,
    <3496, 3493, 3495>, 0,
    <3496, 3495, 3480>, 0,
    <3496, 3480, 3483>, 0,
    <3500, 3499, 3497>, 0,
    <3500, 3497, 3498>, 0,
    <3500, 3498, 3488>, 0,
    <3500, 3488, 3490>, 0,
    <3500, 3490, 3442>, 0,
    <3500, 3442, 3444>, 0,
    <3500, 3444, 3436>, 0,
    <3500, 3436, 3499>, 0,
    <3504, 3503, 3497>, 0,
    <3504, 3497, 3499>, 0,
    <3504, 3499, 3436>, 0,
    <3504, 3436, 3439>, 0,
    <3504, 3439, 3352>, 0,
    <3504, 3352, 3502>, 0,
    <3504, 3502, 3501>, 0,
    <3504, 3501, 3503>, 0,
    <3506, 3498, 3497>, 0,
    <3506, 3497, 3503>, 0,
    <3506, 3503, 3501>, 0,
    <3506, 3501, 3505>, 0,
    <3506, 3505, 3493>, 0,
    <3506, 3493, 3494>, 0,
    <3506, 3494, 3488>, 0,
    <3506, 3488, 3498>, 0,
    <3515, 3514, 3507>, 0,
    <3515, 3507, 3511>, 0,
    <3515, 3511, 3508>, 0,
    <3515, 3508, 3512>, 0,
    <3515, 3512, 3509>, 0,
    <3515, 3509, 3513>, 0,
    <3515, 3513, 3510>, 0,
    <3515, 3510, 3514>, 0,
    <3521, 3520, 3507>, 0,
    <3521, 3507, 3514>, 0,
    <3521, 3514, 3510>, 0,
    <3521, 3510, 3518>, 0,
    <3521, 3518, 3516>, 0,
    <3521, 3516, 3519>, 0,
    <3521, 3519, 3517>, 0,
    <3521, 3517, 3520>, 0,
    <3524, 3511, 3507>, 0,
    <3524, 3507, 3520>, 0,
    <3524, 3520, 3517>, 0,
    <3524, 3517, 3522>, 0,
    <3524, 3522, 3457>, 0,
    <3524, 3457, 3523>, 0,
    <3524, 3523, 3508>, 0,
    <3524, 3508, 3511>, 0,
    <3530, 3529, 3525>, 0,
    <3530, 3525, 3527>, 0,
    <3530, 3527, 3526>, 0,
    <3530, 3526, 3528>, 0,
    <3530, 3528, 3471>, 0,
    <3530, 3471, 3473>, 0,
    <3530, 3473, 3466>, 0,
    <3530, 3466, 3529>, 0,
    <3532, 3531, 3525>, 0,
    <3532, 3525, 3529>, 0,
    <3532, 3529, 3466>, 0,
    <3532, 3466, 3468>, 0,
    <3532, 3468, 3457>, 0,
    <3532, 3457, 3522>, 0,
    <3532, 3522, 3517>, 0,
    <3532, 3517, 3531>, 0,
    <3534, 3527, 3525>, 0,
    <3534, 3525, 3531>, 0,
    <3534, 3531, 3517>, 0,
    <3534, 3517, 3519>, 0,
    <3534, 3519, 3516>, 0,
    <3534, 3516, 3533>, 0,
    <3534, 3533, 3526>, 0,
    <3534, 3526, 3527>, 0,
    <3540, 3539, 3535>, 0,
    <3540, 3535, 3537>, 0,
    <3540, 3537, 3536>, 0,
    <3540, 3536, 3538>, 0,
    <3540, 3538, 3481>, 0,
    <3540, 3481, 3484>, 0,
    <3540, 3484, 3480>, 0,
    <3540, 3480, 3539>, 0,
    <3544, 3543, 3535>, 0,
    <3544, 3535, 3539>, 0,
    <3544, 3539, 3480>, 0,
    <3544, 3480, 3495>, 0,
    <3544, 3495, 3493>, 0,
    <3544, 3493, 3542>, 0,
    <3544, 3542, 3541>, 0,
    <3544, 3541, 3543>, 0,
    <3548, 3537, 3535>, 0,
    <3548, 3535, 3543>, 0,
    <3548, 3543, 3541>, 0,
    <3548, 3541, 3546>, 0,
    <3548, 3546, 3545>, 0,
    <3548, 3545, 3547>, 0,
    <3548, 3547, 3536>, 0,
    <3548, 3536, 3537>, 0,
    <3557, 3556, 3549>, 0,
    <3557, 3549, 3553>, 0,
    <3557, 3553, 3550>, 0,
    <3557, 3550, 3554>, 0,
    <3557, 3554, 3551>, 0,
    <3557, 3551, 3555>, 0,
    <3557, 3555, 3552>, 0,
    <3557, 3552, 3556>, 0,
    <3560, 3559, 3549>, 0,
    <3560, 3549, 3556>, 0,
    <3560, 3556, 3552>, 0,
    <3560, 3552, 3558>, 0,
    <3560, 3558, 3516>, 0,
    <3560, 3516, 3518>, 0,
    <3560, 3518, 3510>, 0,
    <3560, 3510, 3559>, 0,
    <3562, 3553, 3549>, 0,
    <3562, 3549, 3559>, 0,
    <3562, 3559, 3510>, 0,
    <3562, 3510, 3513>, 0,
    <3562, 3513, 3509>, 0,
    <3562, 3509, 3561>, 0,
    <3562, 3561, 3550>, 0,
    <3562, 3550, 3553>, 0,
    <3571, 3570, 3563>, 0,
    <3571, 3563, 3567>, 0,
    <3571, 3567, 3564>, 0,
    <3571, 3564, 3568>, 0,
    <3571, 3568, 3565>, 0,
    <3571, 3565, 3569>, 0,
    <3571, 3569, 3566>, 0,
    <3571, 3566, 3570>, 0,
    <3574, 3573, 3563>, 0,
    <3574, 3563, 3570>, 0,
    <3574, 3570, 3566>, 0,
    <3574, 3566, 3572>, 0,
    <3574, 3572, 3545>, 0,
    <3574, 3545, 3546>, 0,
    <3574, 3546, 3541>, 0,
    <3574, 3541, 3573>, 0,
    <3576, 3567, 3563>, 0,
    <3576, 3563, 3573>, 0,
    <3576, 3573, 3541>, 0,
    <3576, 3541, 3542>, 0,
    <3576, 3542, 3493>, 0,
    <3576, 3493, 3575>, 0,
    <3576, 3575, 3564>, 0,
    <3576, 3564, 3567>, 0,
    <3585, 3584, 3577>, 0,
    <3585, 3577, 3581>, 0,
    <3585, 3581, 3578>, 0,
    <3585, 3578, 3582>, 0,
    <3585, 3582, 3579>, 0,
    <3585, 3579, 3583>, 0,
    <3585, 3583, 3580>, 0,
    <3585, 3580, 3584>, 0,
    <3588, 3587, 3577>, 0,
    <3588, 3577, 3584>, 0,
    <3588, 3584, 3580>, 0,
    <3588, 3580, 3586>, 0,
    <3588, 3586, 3516>, 0,
    <3588, 3516, 3558>, 0,
    <3588, 3558, 3552>, 0,
    <3588, 3552, 3587>, 0,
    <3590, 3581, 3577>, 0,
    <3590, 3577, 3587>, 0,
    <3590, 3587, 3552>, 0,
    <3590, 3552, 3555>, 0,
    <3590, 3555, 3551>, 0,
    <3590, 3551, 3589>, 0,
    <3590, 3589, 3578>, 0,
    <3590, 3578, 3581>, 0,
    <3599, 3598, 3591>, 0,
    <3599, 3591, 3595>, 0,
    <3599, 3595, 3592>, 0,
    <3599, 3592, 3596>, 0,
    <3599, 3596, 3593>, 0,
    <3599, 3593, 3597>, 0,
    <3599, 3597, 3594>, 0,
    <3599, 3594, 3598>, 0,
    <3602, 3601, 3591>, 0,
    <3602, 3591, 3598>, 0,
    <3602, 3598, 3594>, 0,
    <3602, 3594, 3600>, 0,
    <3602, 3600, 3430>, 0,
    <3602, 3430, 3431>, 0,
    <3602, 3431, 3426>, 0,
    <3602, 3426, 3601>, 0,
    <3604, 3595, 3591>, 0,
    <3604, 3591, 3601>, 0,
    <3604, 3601, 3426>, 0,
    <3604, 3426, 3427>, 0,
    <3604, 3427, 3406>, 0,
    <3604, 3406, 3603>, 0,
    <3604, 3603, 3592>, 0,
    <3604, 3592, 3595>, 0,
    <3613, 3612, 3605>, 0,
    <3613, 3605, 3609>, 0,
    <3613, 3609, 3606>, 0,
    <3613, 3606, 3610>, 0,
    <3613, 3610, 3607>, 0,
    <3613, 3607, 3611>, 0,
    <3613, 3611, 3608>, 0,
    <3613, 3608, 3612>, 0,
    <3619, 3618, 3605>, 0,
    <3619, 3605, 3612>, 0,
    <3619, 3612, 3608>, 0,
    <3619, 3608, 3616>, 0,
    <3619, 3616, 3614>, 0,
    <3619, 3614, 3617>, 0,
    <3619, 3617, 3615>, 0,
    <3619, 3615, 3618>, 0,
    <3622, 3609, 3605>, 0,
    <3622, 3605, 3618>, 0,
    <3622, 3618, 3615>, 0,
    <3622, 3615, 3620>, 0,
    <3622, 3620, 3516>, 0,
    <3622, 3516, 3621>, 0,
    <3622, 3621, 3606>, 0,
    <3622, 3606, 3609>, 0,
    <3628, 3627, 3623>, 0,
    <3628, 3623, 3625>, 0,
    <3628, 3625, 3580>, 0,
    <3628, 3580, 3583>, 0,
    <3628, 3583, 3579>, 0,
    <3628, 3579, 3626>, 0,
    <3628, 3626, 3624>, 0,
    <3628, 3624, 3627>, 0,
    <3631, 3630, 3623>, 0,
    <3631, 3623, 3627>, 0,
    <3631, 3627, 3624>, 0,
    <3631, 3624, 3629>, 0,
    <3631, 3629, 3607>, 0,
    <3631, 3607, 3610>, 0,
    <3631, 3610, 3606>, 0,
    <3631, 3606, 3630>, 0,
    <3632, 3625, 3623>, 0,
    <3632, 3623, 3630>, 0,
    <3632, 3630, 3606>, 0,
    <3632, 3606, 3621>, 0,
    <3632, 3621, 3516>, 0,
    <3632, 3516, 3586>, 0,
    <3632, 3586, 3580>, 0,
    <3632, 3580, 3625>, 0,
    <3638, 3637, 3633>, 0,
    <3638, 3633, 3635>, 0,
    <3638, 3635, 3634>, 0,
    <3638, 3634, 3636>, 0,
    <3638, 3636, 3565>, 0,
    <3638, 3565, 3568>, 0,
    <3638, 3568, 3564>, 0,
    <3638, 3564, 3637>, 0,
    <3642, 3641, 3633>, 0,
    <3642, 3633, 3637>, 0,
    <3642, 3637, 3564>, 0,
    <3642, 3564, 3575>, 0,
    <3642, 3575, 3493>, 0,
    <3642, 3493, 3640>, 0,
    <3642, 3640, 3639>, 0,
    <3642, 3639, 3641>, 0,
    <3646, 3635, 3633>, 0,
    <3646, 3633, 3641>, 0,
    <3646, 3641, 3639>, 0,
    <3646, 3639, 3644>, 0,
    <3646, 3644, 3643>, 0,
    <3646, 3643, 3645>, 0,
    <3646, 3645, 3634>, 0,
    <3646, 3634, 3635>, 0,
    <3652, 3651, 3647>, 0,
    <3652, 3647, 3649>, 0,
    <3652, 3649, 3648>, 0,
    <3652, 3648, 3650>, 0,
    <3652, 3650, 3614>, 0,
    <3652, 3614, 3616>, 0,
    <3652, 3616, 3608>, 0,
    <3652, 3608, 3651>, 0,
    <3656, 3655, 3647>, 0,
    <3656, 3647, 3651>, 0,
    <3656, 3651, 3608>, 0,
    <3656, 3608, 3611>, 0,
    <3656, 3611, 3607>, 0,
    <3656, 3607, 3654>, 0,
    <3656, 3654, 3653>, 0,
    <3656, 3653, 3655>, 0,
    <3660, 3649, 3647>, 0,
    <3660, 3647, 3655>, 0,
    <3660, 3655, 3653>, 0,
    <3660, 3653, 3658>, 0,
    <3660, 3658, 3657>, 0,
    <3660, 3657, 3659>, 0,
    <3660, 3659, 3648>, 0,
    <3660, 3648, 3649>, 0,
    <3669, 3668, 3661>, 0,
    <3669, 3661, 3665>, 0,
    <3669, 3665, 3662>, 0,
    <3669, 3662, 3666>, 0,
    <3669, 3666, 3663>, 0,
    <3669, 3663, 3667>, 0,
    <3669, 3667, 3664>, 0,
    <3669, 3664, 3668>, 0,
    <3672, 3671, 3661>, 0,
    <3672, 3661, 3668>, 0,
    <3672, 3668, 3664>, 0,
    <3672, 3664, 3670>, 0,
    <3672, 3670, 3370>, 0,
    <3672, 3370, 3387>, 0,
    <3672, 3387, 3381>, 0,
    <3672, 3381, 3671>, 0,
    <3674, 3665, 3661>, 0,
    <3674, 3661, 3671>, 0,
    <3674, 3671, 3381>, 0,
    <3674, 3381, 3384>, 0,
    <3674, 3384, 3380>, 0,
    <3674, 3380, 3673>, 0,
    <3674, 3673, 3662>, 0,
    <3674, 3662, 3665>, 0,
    <3680, 3679, 3675>, 0,
    <3680, 3675, 3677>, 0,
    <3680, 3677, 3664>, 0,
    <3680, 3664, 3667>, 0,
    <3680, 3667, 3663>, 0,
    <3680, 3663, 3678>, 0,
    <3680, 3678, 3676>, 0,
    <3680, 3676, 3679>, 0,
    <3686, 3685, 3675>, 0,
    <3686, 3675, 3679>, 0,
    <3686, 3679, 3676>, 0,
    <3686, 3676, 3683>, 0,
    <3686, 3683, 3681>, 0,
    <3686, 3681, 3684>, 0,
    <3686, 3684, 3682>, 0,
    <3686, 3682, 3685>, 0,
    <3688, 3677, 3675>, 0,
    <3688, 3675, 3685>, 0,
    <3688, 3685, 3682>, 0,
    <3688, 3682, 3687>, 0,
    <3688, 3687, 3370>, 0,
    <3688, 3370, 3670>, 0,
    <3688, 3670, 3664>, 0,
    <3688, 3664, 3677>, 0,
    <3697, 3696, 3689>, 0,
    <3697, 3689, 3693>, 0,
    <3697, 3693, 3690>, 0,
    <3697, 3690, 3694>, 0,
    <3697, 3694, 3691>, 0,
    <3697, 3691, 3695>, 0,
    <3697, 3695, 3692>, 0,
    <3697, 3692, 3696>, 0,
    <3700, 3699, 3689>, 0,
    <3700, 3689, 3696>, 0,
    <3700, 3696, 3692>, 0,
    <3700, 3692, 3698>, 0,
    <3700, 3698, 3681>, 0,
    <3700, 3681, 3683>, 0,
    <3700, 3683, 3676>, 0,
    <3700, 3676, 3699>, 0,
    <3702, 3693, 3689>, 0,
    <3702, 3689, 3699>, 0,
    <3702, 3699, 3676>, 0,
    <3702, 3676, 3678>, 0,
    <3702, 3678, 3663>, 0,
    <3702, 3663, 3701>, 0,
    <3702, 3701, 3690>, 0,
    <3702, 3690, 3693>, 0,
    <3711, 3710, 3703>, 0,
    <3711, 3703, 3707>, 0,
    <3711, 3707, 3704>, 0,
    <3711, 3704, 3708>, 0,
    <3711, 3708, 3705>, 0,
    <3711, 3705, 3709>, 0,
    <3711, 3709, 3706>, 0,
    <3711, 3706, 3710>, 0,
    <3716, 3715, 3703>, 0,
    <3716, 3703, 3710>, 0,
    <3716, 3710, 3706>, 0,
    <3716, 3706, 3713>, 0,
    <3716, 3713, 3593>, 0,
    <3716, 3593, 3714>, 0,
    <3716, 3714, 3712>, 0,
    <3716, 3712, 3715>, 0,
    <3720, 3707, 3703>, 0,
    <3720, 3703, 3715>, 0,
    <3720, 3715, 3712>, 0,
    <3720, 3712, 3718>, 0,
    <3720, 3718, 3717>, 0,
    <3720, 3717, 3719>, 0,
    <3720, 3719, 3704>, 0,
    <3720, 3704, 3707>, 0,
    <3724, 3723, 3721>, 0,
    <3724, 3721, 3722>, 0,
    <3724, 3722, 3712>, 0,
    <3724, 3712, 3714>, 0,
    <3724, 3714, 3593>, 0,
    <3724, 3593, 3596>, 0,
    <3724, 3596, 3592>, 0,
    <3724, 3592, 3723>, 0,
    <3728, 3727, 3721>, 0,
    <3728, 3721, 3723>, 0,
    <3728, 3723, 3592>, 0,
    <3728, 3592, 3603>, 0,
    <3728, 3603, 3406>, 0,
    <3728, 3406, 3726>, 0,
    <3728, 3726, 3725>, 0,
    <3728, 3725, 3727>, 0,
    <3730, 3722, 3721>, 0,
    <3730, 3721, 3727>, 0,
    <3730, 3727, 3725>, 0,
    <3730, 3725, 3729>, 0,
    <3730, 3729, 3717>, 0,
    <3730, 3717, 3718>, 0,
    <3730, 3718, 3712>, 0,
    <3730, 3712, 3722>, 0,
    <3736, 3735, 3731>, 0,
    <3736, 3731, 3733>, 0,
    <3736, 3733, 3732>, 0,
    <3736, 3732, 3734>, 0,
    <3736, 3734, 3705>, 0,
    <3736, 3705, 3708>, 0,
    <3736, 3708, 3704>, 0,
    <3736, 3704, 3735>, 0,
    <3740, 3739, 3731>, 0,
    <3740, 3731, 3735>, 0,
    <3740, 3735, 3704>, 0,
    <3740, 3704, 3719>, 0,
    <3740, 3719, 3717>, 0,
    <3740, 3717, 3738>, 0,
    <3740, 3738, 3737>, 0,
    <3740, 3737, 3739>, 0,
    <3744, 3733, 3731>, 0,
    <3744, 3731, 3739>, 0,
    <3744, 3739, 3737>, 0,
    <3744, 3737, 3742>, 0,
    <3744, 3742, 3741>, 0,
    <3744, 3741, 3743>, 0,
    <3744, 3743, 3732>, 0,
    <3744, 3732, 3733>, 0,
    <3752, 3751, 3745>, 0,
    <3752, 3745, 3748>, 0,
    <3752, 3748, 3746>, 0,
    <3752, 3746, 3749>, 0,
    <3752, 3749, 3545>, 0,
    <3752, 3545, 3750>, 0,
    <3752, 3750, 3747>, 0,
    <3752, 3747, 3751>, 0,
    <3757, 3756, 3745>, 0,
    <3757, 3745, 3751>, 0,
    <3757, 3751, 3747>, 0,
    <3757, 3747, 3754>, 0,
    <3757, 3754, 3643>, 0,
    <3757, 3643, 3755>, 0,
    <3757, 3755, 3753>, 0,
    <3757, 3753, 3756>, 0,
    <3761, 3748, 3745>, 0,
    <3761, 3745, 3756>, 0,
    <3761, 3756, 3753>, 0,
    <3761, 3753, 3759>, 0,
    <3761, 3759, 3758>, 0,
    <3761, 3758, 3760>, 0,
    <3761, 3760, 3746>, 0,
    <3761, 3746, 3748>, 0,
    <3770, 3769, 3762>, 0,
    <3770, 3762, 3766>, 0,
    <3770, 3766, 3763>, 0,
    <3770, 3763, 3767>, 0,
    <3770, 3767, 3764>, 0,
    <3770, 3764, 3768>, 0,
    <3770, 3768, 3765>, 0,
    <3770, 3765, 3769>, 0,
    <3773, 3772, 3762>, 0,
    <3773, 3762, 3769>, 0,
    <3773, 3769, 3765>, 0,
    <3773, 3765, 3771>, 0,
    <3773, 3771, 3657>, 0,
    <3773, 3657, 3658>, 0,
    <3773, 3658, 3653>, 0,
    <3773, 3653, 3772>, 0,
    <3775, 3766, 3762>, 0,
    <3775, 3762, 3772>, 0,
    <3775, 3772, 3653>, 0,
    <3775, 3653, 3654>, 0,
    <3775, 3654, 3607>, 0,
    <3775, 3607, 3774>, 0,
    <3775, 3774, 3763>, 0,
    <3775, 3763, 3766>, 0,
    <3784, 3783, 3776>, 0,
    <3784, 3776, 3780>, 0,
    <3784, 3780, 3777>, 0,
    <3784, 3777, 3781>, 0,
    <3784, 3781, 3778>, 0,
    <3784, 3778, 3782>, 0,
    <3784, 3782, 3779>, 0,
    <3784, 3779, 3783>, 0,
    <3787, 3786, 3776>, 0,
    <3787, 3776, 3783>, 0,
    <3787, 3783, 3779>, 0,
    <3787, 3779, 3785>, 0,
    <3787, 3785, 3758>, 0,
    <3787, 3758, 3759>, 0,
    <3787, 3759, 3753>, 0,
    <3787, 3753, 3786>, 0,
    <3789, 3780, 3776>, 0,
    <3789, 3776, 3786>, 0,
    <3789, 3786, 3753>, 0,
    <3789, 3753, 3755>, 0,
    <3789, 3755, 3643>, 0,
    <3789, 3643, 3788>, 0,
    <3789, 3788, 3777>, 0,
    <3789, 3777, 3780>, 0,
    <3798, 3797, 3790>, 0,
    <3798, 3790, 3794>, 0,
    <3798, 3794, 3791>, 0,
    <3798, 3791, 3795>, 0,
    <3798, 3795, 3792>, 0,
    <3798, 3792, 3796>, 0,
    <3798, 3796, 3793>, 0,
    <3798, 3793, 3797>, 0,
    <3801, 3800, 3790>, 0,
    <3801, 3790, 3797>, 0,
    <3801, 3797, 3793>, 0,
    <3801, 3793, 3799>, 0,
    <3801, 3799, 3657>, 0,
    <3801, 3657, 3771>, 0,
    <3801, 3771, 3765>, 0,
    <3801, 3765, 3800>, 0,
    <3803, 3794, 3790>, 0,
    <3803, 3790, 3800>, 0,
    <3803, 3800, 3765>, 0,
    <3803, 3765, 3768>, 0,
    <3803, 3768, 3764>, 0,
    <3803, 3764, 3802>, 0,
    <3803, 3802, 3791>, 0,
    <3803, 3791, 3794>, 0,
    <3812, 3811, 3804>, 0,
    <3812, 3804, 3808>, 0,
    <3812, 3808, 3805>, 0,
    <3812, 3805, 3809>, 0,
    <3812, 3809, 3806>, 0,
    <3812, 3806, 3810>, 0,
    <3812, 3810, 3807>, 0,
    <3812, 3807, 3811>, 0,
    <3815, 3814, 3804>, 0,
    <3815, 3804, 3811>, 0,
    <3815, 3811, 3807>, 0,
    <3815, 3807, 3813>, 0,
    <3815, 3813, 3778>, 0,
    <3815, 3778, 3781>, 0,
    <3815, 3781, 3777>, 0,
    <3815, 3777, 3814>, 0,
    <3817, 3808, 3804>, 0,
    <3817, 3804, 3814>, 0,
    <3817, 3814, 3777>, 0,
    <3817, 3777, 3788>, 0,
    <3817, 3788, 3643>, 0,
    <3817, 3643, 3816>, 0,
    <3817, 3816, 3805>, 0,
    <3817, 3805, 3808>, 0,
    <3823, 3822, 3818>, 0,
    <3823, 3818, 3820>, 0,
    <3823, 3820, 3793>, 0,
    <3823, 3793, 3796>, 0,
    <3823, 3796, 3792>, 0,
    <3823, 3792, 3821>, 0,
    <3823, 3821, 3819>, 0,
    <3823, 3819, 3822>, 0,
    <3829, 3828, 3818>, 0,
    <3829, 3818, 3822>, 0,
    <3829, 3822, 3819>, 0,
    <3829, 3819, 3826>, 0,
    <3829, 3826, 3824>, 0,
    <3829, 3824, 3827>, 0,
    <3829, 3827, 3825>, 0,
    <3829, 3825, 3828>, 0,
    <3831, 3820, 3818>, 0,
    <3831, 3818, 3828>, 0,
    <3831, 3828, 3825>, 0,
    <3831, 3825, 3830>, 0,
    <3831, 3830, 3657>, 0,
    <3831, 3657, 3799>, 0,
    <3831, 3799, 3793>, 0,
    <3831, 3793, 3820>, 0,
    <3837, 3836, 3832>, 0,
    <3837, 3832, 3834>, 0,
    <3837, 3834, 3825>, 0,
    <3837, 3825, 3827>, 0,
    <3837, 3827, 3824>, 0,
    <3837, 3824, 3835>, 0,
    <3837, 3835, 3833>, 0,
    <3837, 3833, 3836>, 0,
    <3843, 3842, 3832>, 0,
    <3843, 3832, 3836>, 0,
    <3843, 3836, 3833>, 0,
    <3843, 3833, 3840>, 0,
    <3843, 3840, 3838>, 0,
    <3843, 3838, 3841>, 0,
    <3843, 3841, 3839>, 0,
    <3843, 3839, 3842>, 0,
    <3845, 3834, 3832>, 0,
    <3845, 3832, 3842>, 0,
    <3845, 3842, 3839>, 0,
    <3845, 3839, 3844>, 0,
    <3845, 3844, 3657>, 0,
    <3845, 3657, 3830>, 0,
    <3845, 3830, 3825>, 0,
    <3845, 3825, 3834>, 0,
    <3853, 3852, 3846>, 0,
    <3853, 3846, 3849>, 0,
    <3853, 3849, 3847>, 0,
    <3853, 3847, 3850>, 0,
    <3853, 3850, 3806>, 0,
    <3853, 3806, 3851>, 0,
    <3853, 3851, 3848>, 0,
    <3853, 3848, 3852>, 0,
    <3859, 3858, 3846>, 0,
    <3859, 3846, 3852>, 0,
    <3859, 3852, 3848>, 0,
    <3859, 3848, 3856>, 0,
    <3859, 3856, 3854>, 0,
    <3859, 3854, 3857>, 0,
    <3859, 3857, 3855>, 0,
    <3859, 3855, 3858>, 0,
    <3862, 3849, 3846>, 0,
    <3862, 3846, 3858>, 0,
    <3862, 3858, 3855>, 0,
    <3862, 3855, 3860>, 0,
    <3862, 3860, 3758>, 0,
    <3862, 3758, 3861>, 0,
    <3862, 3861, 3847>, 0,
    <3862, 3847, 3849>, 0,
    <3868, 3867, 3863>, 0,
    <3868, 3863, 3865>, 0,
    <3868, 3865, 3864>, 0,
    <3868, 3864, 3866>, 0,
    <3868, 3866, 3854>, 0,
    <3868, 3854, 3856>, 0,
    <3868, 3856, 3848>, 0,
    <3868, 3848, 3867>, 0,
    <3872, 3871, 3863>, 0,
    <3872, 3863, 3867>, 0,
    <3872, 3867, 3848>, 0,
    <3872, 3848, 3851>, 0,
    <3872, 3851, 3806>, 0,
    <3872, 3806, 3870>, 0,
    <3872, 3870, 3869>, 0,
    <3872, 3869, 3871>, 0,
    <3876, 3865, 3863>, 0,
    <3876, 3863, 3871>, 0,
    <3876, 3871, 3869>, 0,
    <3876, 3869, 3874>, 0,
    <3876, 3874, 3873>, 0,
    <3876, 3873, 3875>, 0,
    <3876, 3875, 3864>, 0,
    <3876, 3864, 3865>, 0,
    <3882, 3881, 3877>, 0,
    <3882, 3877, 3879>, 0,
    <3882, 3879, 3878>, 0,
    <3882, 3878, 3880>, 0,
    <3882, 3880, 3838>, 0,
    <3882, 3838, 3840>, 0,
    <3882, 3840, 3833>, 0,
    <3882, 3833, 3881>, 0,
    <3886, 3885, 3877>, 0,
    <3886, 3877, 3881>, 0,
    <3886, 3881, 3833>, 0,
    <3886, 3833, 3835>, 0,
    <3886, 3835, 3824>, 0,
    <3886, 3824, 3884>, 0,
    <3886, 3884, 3883>, 0,
    <3886, 3883, 3885>, 0,
    <3890, 3879, 3877>, 0,
    <3890, 3877, 3885>, 0,
    <3890, 3885, 3883>, 0,
    <3890, 3883, 3888>, 0,
    <3890, 3888, 3887>, 0,
    <3890, 3887, 3889>, 0,
    <3890, 3889, 3878>, 0,
    <3890, 3878, 3879>, 0,
    <3896, 3895, 3891>, 0,
    <3896, 3891, 3893>, 0,
    <3896, 3893, 3892>, 0,
    <3896, 3892, 3894>, 0,
    <3896, 3894, 3854>, 0,
    <3896, 3854, 3866>, 0,
    <3896, 3866, 3864>, 0,
    <3896, 3864, 3895>, 0,
    <3900, 3899, 3891>, 0,
    <3900, 3891, 3895>, 0,
    <3900, 3895, 3864>, 0,
    <3900, 3864, 3875>, 0,
    <3900, 3875, 3873>, 0,
    <3900, 3873, 3898>, 0,
    <3900, 3898, 3897>, 0,
    <3900, 3897, 3899>, 0,
    <3904, 3893, 3891>, 0,
    <3904, 3891, 3899>, 0,
    <3904, 3899, 3897>, 0,
    <3904, 3897, 3902>, 0,
    <3904, 3902, 3901>, 0,
    <3904, 3901, 3903>, 0,
    <3904, 3903, 3892>, 0,
    <3904, 3892, 3893>, 0,
    <3913, 3912, 3905>, 0,
    <3913, 3905, 3909>, 0,
    <3913, 3909, 3906>, 0,
    <3913, 3906, 3910>, 0,
    <3913, 3910, 3907>, 0,
    <3913, 3907, 3911>, 0,
    <3913, 3911, 3908>, 0,
    <3913, 3908, 3912>, 0,
    <3916, 3915, 3905>, 0,
    <3916, 3905, 3912>, 0,
    <3916, 3912, 3908>, 0,
    <3916, 3908, 3914>, 0,
    <3916, 3914, 3887>, 0,
    <3916, 3887, 3888>, 0,
    <3916, 3888, 3883>, 0,
    <3916, 3883, 3915>, 0,
    <3918, 3909, 3905>, 0,
    <3918, 3905, 3915>, 0,
    <3918, 3915, 3883>, 0,
    <3918, 3883, 3884>, 0,
    <3918, 3884, 3824>, 0,
    <3918, 3824, 3917>, 0,
    <3918, 3917, 3906>, 0,
    <3918, 3906, 3909>, 0,
    <3924, 3923, 3919>, 0,
    <3924, 3919, 3921>, 0,
    <3924, 3921, 3920>, 0,
    <3924, 3920, 3922>, 0,
    <3924, 3922, 3901>, 0,
    <3924, 3901, 3902>, 0,
    <3924, 3902, 3897>, 0,
    <3924, 3897, 3923>, 0,
    <3928, 3927, 3919>, 0,
    <3928, 3919, 3923>, 0,
    <3928, 3923, 3897>, 0,
    <3928, 3897, 3898>, 0,
    <3928, 3898, 3873>, 0,
    <3928, 3873, 3926>, 0,
    <3928, 3926, 3925>, 0,
    <3928, 3925, 3927>, 0,
    <3932, 3921, 3919>, 0,
    <3932, 3919, 3927>, 0,
    <3932, 3927, 3925>, 0,
    <3932, 3925, 3930>, 0,
    <3932, 3930, 3929>, 0,
    <3932, 3929, 3931>, 0,
    <3932, 3931, 3920>, 0,
    <3932, 3920, 3921>, 0,
    <3941, 3940, 3933>, 0,
    <3941, 3933, 3937>, 0,
    <3941, 3937, 3934>, 0,
    <3941, 3934, 3938>, 0,
    <3941, 3938, 3935>, 0,
    <3941, 3935, 3939>, 0,
    <3941, 3939, 3936>, 0,
    <3941, 3936, 3940>, 0,
    <3944, 3943, 3933>, 0,
    <3944, 3933, 3940>, 0,
    <3944, 3940, 3936>, 0,
    <3944, 3936, 3942>, 0,
    <3944, 3942, 3887>, 0,
    <3944, 3887, 3914>, 0,
    <3944, 3914, 3908>, 0,
    <3944, 3908, 3943>, 0,
    <3946, 3937, 3933>, 0,
    <3946, 3933, 3943>, 0,
    <3946, 3943, 3908>, 0,
    <3946, 3908, 3911>, 0,
    <3946, 3911, 3907>, 0,
    <3946, 3907, 3945>, 0,
    <3946, 3945, 3934>, 0,
    <3946, 3934, 3937>, 0,
    <3955, 3954, 3947>, 0,
    <3955, 3947, 3951>, 0,
    <3955, 3951, 3948>, 0,
    <3955, 3948, 3952>, 0,
    <3955, 3952, 3949>, 0,
    <3955, 3949, 3953>, 0,
    <3955, 3953, 3950>, 0,
    <3955, 3950, 3954>, 0,
    <3958, 3957, 3947>, 0,
    <3958, 3947, 3954>, 0,
    <3958, 3954, 3950>, 0,
    <3958, 3950, 3956>, 0,
    <3958, 3956, 3741>, 0,
    <3958, 3741, 3742>, 0,
    <3958, 3742, 3737>, 0,
    <3958, 3737, 3957>, 0,
    <3960, 3951, 3947>, 0,
    <3960, 3947, 3957>, 0,
    <3960, 3957, 3737>, 0,
    <3960, 3737, 3738>, 0,
    <3960, 3738, 3717>, 0,
    <3960, 3717, 3959>, 0,
    <3960, 3959, 3948>, 0,
    <3960, 3948, 3951>, 0,
    <3969, 3968, 3961>, 0,
    <3969, 3961, 3965>, 0,
    <3969, 3965, 3962>, 0,
    <3969, 3962, 3966>, 0,
    <3969, 3966, 3963>, 0,
    <3969, 3963, 3967>, 0,
    <3969, 3967, 3964>, 0,
    <3969, 3964, 3968>, 0,
    <3974, 3973, 3961>, 0,
    <3974, 3961, 3968>, 0,
    <3974, 3968, 3964>, 0,
    <3974, 3964, 3971>, 0,
    <3974, 3971, 3929>, 0,
    <3974, 3929, 3972>, 0,
    <3974, 3972, 3970>, 0,
    <3974, 3970, 3973>, 0,
    <3977, 3965, 3961>, 0,
    <3977, 3961, 3973>, 0,
    <3977, 3973, 3970>, 0,
    <3977, 3970, 3975>, 0,
    <3977, 3975, 3887>, 0,
    <3977, 3887, 3976>, 0,
    <3977, 3976, 3962>, 0,
    <3977, 3962, 3965>, 0,
    <3986, 3985, 3978>, 0,
    <3986, 3978, 3982>, 0,
    <3986, 3982, 3979>, 0,
    <3986, 3979, 3983>, 0,
    <3986, 3983, 3980>, 0,
    <3986, 3980, 3984>, 0,
    <3986, 3984, 3981>, 0,
    <3986, 3981, 3985>, 0,
    <3992, 3991, 3978>, 0,
    <3992, 3978, 3985>, 0,
    <3992, 3985, 3981>, 0,
    <3992, 3981, 3989>, 0,
    <3992, 3989, 3987>, 0,
    <3992, 3987, 3990>, 0,
    <3992, 3990, 3988>, 0,
    <3992, 3988, 3991>, 0,
    <3995, 3982, 3978>, 0,
    <3995, 3978, 3991>, 0,
    <3995, 3991, 3988>, 0,
    <3995, 3988, 3993>, 0,
    <3995, 3993, 3681>, 0,
    <3995, 3681, 3994>, 0,
    <3995, 3994, 3979>, 0,
    <3995, 3979, 3982>, 0,
    <4001, 4000, 3996>, 0,
    <4001, 3996, 3998>, 0,
    <4001, 3998, 3997>, 0,
    <4001, 3997, 3999>, 0,
    <4001, 3999, 3901>, 0,
    <4001, 3901, 3922>, 0,
    <4001, 3922, 3920>, 0,
    <4001, 3920, 4000>, 0,
    <4005, 4004, 3996>, 0,
    <4005, 3996, 4000>, 0,
    <4005, 4000, 3920>, 0,
    <4005, 3920, 3931>, 0,
    <4005, 3931, 3929>, 0,
    <4005, 3929, 4003>, 0,
    <4005, 4003, 4002>, 0,
    <4005, 4002, 4004>, 0,
    <4009, 3998, 3996>, 0,
    <4009, 3996, 4004>, 0,
    <4009, 4004, 4002>, 0,
    <4009, 4002, 4007>, 0,
    <4009, 4007, 4006>, 0,
    <4009, 4006, 4008>, 0,
    <4009, 4008, 3997>, 0,
    <4009, 3997, 3998>, 0,
    <4015, 4014, 4010>, 0,
    <4015, 4010, 4012>, 0,
    <4015, 4012, 3964>, 0,
    <4015, 3964, 3967>, 0,
    <4015, 3967, 3963>, 0,
    <4015, 3963, 4013>, 0,
    <4015, 4013, 4011>, 0,
    <4015, 4011, 4014>, 0,
    <4018, 4017, 4010>, 0,
    <4018, 4010, 4014>, 0,
    <4018, 4014, 4011>, 0,
    <4018, 4011, 4016>, 0,
    <4018, 4016, 4006>, 0,
    <4018, 4006, 4007>, 0,
    <4018, 4007, 4002>, 0,
    <4018, 4002, 4017>, 0,
    <4019, 4012, 4010>, 0,
    <4019, 4010, 4017>, 0,
    <4019, 4017, 4002>, 0,
    <4019, 4002, 4003>, 0,
    <4019, 4003, 3929>, 0,
    <4019, 3929, 3971>, 0,
    <4019, 3971, 3964>, 0,
    <4019, 3964, 4012>, 0,
    <4025, 4024, 4020>, 0,
    <4025, 4020, 4022>, 0,
    <4025, 4022, 3936>, 0,
    <4025, 3936, 3939>, 0,
    <4025, 3939, 3935>, 0,
    <4025, 3935, 4023>, 0,
    <4025, 4023, 4021>, 0,
    <4025, 4021, 4024>, 0,
    <4030, 4029, 4020>, 0,
    <4030, 4020, 4024>, 0,
    <4030, 4024, 4021>, 0,
    <4030, 4021, 4027>, 0,
    <4030, 4027, 4006>, 0,
    <4030, 4006, 4028>, 0,
    <4030, 4028, 4026>, 0,
    <4030, 4026, 4029>, 0,
    <4032, 4022, 4020>, 0,
    <4032, 4020, 4029>, 0,
    <4032, 4029, 4026>, 0,
    <4032, 4026, 4031>, 0,
    <4032, 4031, 3887>, 0,
    <4032, 3887, 3942>, 0,
    <4032, 3942, 3936>, 0,
    <4032, 3936, 4022>, 0,
    <4041, 4040, 4033>, 0,
    <4041, 4033, 4037>, 0,
    <4041, 4037, 4034>, 0,
    <4041, 4034, 4038>, 0,
    <4041, 4038, 4035>, 0,
    <4041, 4035, 4039>, 0,
    <4041, 4039, 4036>, 0,
    <4041, 4036, 4040>, 0,
    <4044, 4043, 4033>, 0,
    <4044, 4033, 4040>, 0,
    <4044, 4040, 4036>, 0,
    <4044, 4036, 4042>, 0,
    <4044, 4042, 3681>, 0,
    <4044, 3681, 3698>, 0,
    <4044, 3698, 3692>, 0,
    <4044, 3692, 4043>, 0,
    <4046, 4037, 4033>, 0,
    <4046, 4033, 4043>, 0,
    <4046, 4043, 3692>, 0,
    <4046, 3692, 3695>, 0,
    <4046, 3695, 3691>, 0,
    <4046, 3691, 4045>, 0,
    <4046, 4045, 4034>, 0,
    <4046, 4034, 4037>, 0,
    <4052, 4051, 4047>, 0,
    <4052, 4047, 4049>, 0,
    <4052, 4049, 4036>, 0,
    <4052, 4036, 4039>, 0,
    <4052, 4039, 4035>, 0,
    <4052, 4035, 4050>, 0,
    <4052, 4050, 4048>, 0,
    <4052, 4048, 4051>, 0,
    <4057, 4056, 4047>, 0,
    <4057, 4047, 4051>, 0,
    <4057, 4051, 4048>, 0,
    <4057, 4048, 4054>, 0,
    <4057, 4054, 3987>, 0,
    <4057, 3987, 4055>, 0,
    <4057, 4055, 4053>, 0,
    <4057, 4053, 4056>, 0,
    <4059, 4049, 4047>, 0,
    <4059, 4047, 4056>, 0,
    <4059, 4056, 4053>, 0,
    <4059, 4053, 4058>, 0,
    <4059, 4058, 3681>, 0,
    <4059, 3681, 4042>, 0,
    <4059, 4042, 4036>, 0,
    <4059, 4036, 4049>, 0,
    <4068, 4067, 4060>, 0,
    <4068, 4060, 4064>, 0,
    <4068, 4064, 4061>, 0,
    <4068, 4061, 4065>, 0,
    <4068, 4065, 4062>, 0,
    <4068, 4062, 4066>, 0,
    <4068, 4066, 4063>, 0,
    <4068, 4063, 4067>, 0,
    <4071, 4070, 4060>, 0,
    <4071, 4060, 4067>, 0,
    <4071, 4067, 4063>, 0,
    <4071, 4063, 4069>, 0,
    <4071, 4069, 3987>, 0,
    <4071, 3987, 4054>, 0,
    <4071, 4054, 4048>, 0,
    <4071, 4048, 4070>, 0,
    <4073, 4064, 4060>, 0,
    <4073, 4060, 4070>, 0,
    <4073, 4070, 4048>, 0,
    <4073, 4048, 4050>, 0,
    <4073, 4050, 4035>, 0,
    <4073, 4035, 4072>, 0,
    <4073, 4072, 4061>, 0,
    <4073, 4061, 4064>, 0,
    <4081, 4080, 4074>, 0,
    <4081, 4074, 4077>, 0,
    <4081, 4077, 4075>, 0,
    <4081, 4075, 4078>, 0,
    <4081, 4078, 3949>, 0,
    <4081, 3949, 4079>, 0,
    <4081, 4079, 4076>, 0,
    <4081, 4076, 4080>, 0,
    <4087, 4086, 4074>, 0,
    <4087, 4074, 4080>, 0,
    <4087, 4080, 4076>, 0,
    <4087, 4076, 4084>, 0,
    <4087, 4084, 4082>, 0,
    <4087, 4082, 4085>, 0,
    <4087, 4085, 4083>, 0,
    <4087, 4083, 4086>, 0,
    <4091, 4077, 4074>, 0,
    <4091, 4074, 4086>, 0,
    <4091, 4086, 4083>, 0,
    <4091, 4083, 4089>, 0,
    <4091, 4089, 4088>, 0,
    <4091, 4088, 4090>, 0,
    <4091, 4090, 4075>, 0,
    <4091, 4075, 4077>, 0,
    <4099, 4098, 4092>, 0,
    <4099, 4092, 4095>, 0,
    <4099, 4095, 4093>, 0,
    <4099, 4093, 4096>, 0,
    <4099, 4096, 3717>, 0,
    <4099, 3717, 4097>, 0,
    <4099, 4097, 4094>, 0,
    <4099, 4094, 4098>, 0,
    <4104, 4103, 4092>, 0,
    <4104, 4092, 4098>, 0,
    <4104, 4098, 4094>, 0,
    <4104, 4094, 4101>, 0,
    <4104, 4101, 4082>, 0,
    <4104, 4082, 4102>, 0,
    <4104, 4102, 4100>, 0,
    <4104, 4100, 4103>, 0,
    <4108, 4095, 4092>, 0,
    <4108, 4092, 4103>, 0,
    <4108, 4103, 4100>, 0,
    <4108, 4100, 4106>, 0,
    <4108, 4106, 4105>, 0,
    <4108, 4105, 4107>, 0,
    <4108, 4107, 4093>, 0,
    <4108, 4093, 4095>, 0,
    <4112, 4111, 4109>, 0,
    <4112, 4109, 4110>, 0,
    <4112, 4110, 4076>, 0,
    <4112, 4076, 4079>, 0,
    <4112, 4079, 3949>, 0,
    <4112, 3949, 3952>, 0,
    <4112, 3952, 3948>, 0,
    <4112, 3948, 4111>, 0,
    <4116, 4115, 4109>, 0,
    <4116, 4109, 4111>, 0,
    <4116, 4111, 3948>, 0,
    <4116, 3948, 3959>, 0,
    <4116, 3959, 3717>, 0,
    <4116, 3717, 4114>, 0,
    <4116, 4114, 4113>, 0,
    <4116, 4113, 4115>, 0,
    <4118, 4110, 4109>, 0,
    <4118, 4109, 4115>, 0,
    <4118, 4115, 4113>, 0,
    <4118, 4113, 4117>, 0,
    <4118, 4117, 4082>, 0,
    <4118, 4082, 4084>, 0,
    <4118, 4084, 4076>, 0,
    <4118, 4076, 4110>, 0,
    <4124, 4123, 4119>, 0,
    <4124, 4119, 4121>, 0,
    <4124, 4121, 4120>, 0,
    <4124, 4120, 4122>, 0,
    <4124, 4122, 4088>, 0,
    <4124, 4088, 4089>, 0,
    <4124, 4089, 4083>, 0,
    <4124, 4083, 4123>, 0,
    <4128, 4127, 4119>, 0,
    <4128, 4119, 4123>, 0,
    <4128, 4123, 4083>, 0,
    <4128, 4083, 4085>, 0,
    <4128, 4085, 4082>, 0,
    <4128, 4082, 4126>, 0,
    <4128, 4126, 4125>, 0,
    <4128, 4125, 4127>, 0,
    <4132, 4121, 4119>, 0,
    <4132, 4119, 4127>, 0,
    <4132, 4127, 4125>, 0,
    <4132, 4125, 4130>, 0,
    <4132, 4130, 4129>, 0,
    <4132, 4129, 4131>, 0,
    <4132, 4131, 4120>, 0,
    <4132, 4120, 4121>, 0,
    <4141, 4140, 4133>, 0,
    <4141, 4133, 4137>, 0,
    <4141, 4137, 4134>, 0,
    <4141, 4134, 4138>, 0,
    <4141, 4138, 4135>, 0,
    <4141, 4135, 4139>, 0,
    <4141, 4139, 4136>, 0,
    <4141, 4136, 4140>, 0,
    <4147, 4146, 4133>, 0,
    <4147, 4133, 4140>, 0,
    <4147, 4140, 4136>, 0,
    <4147, 4136, 4144>, 0,
    <4147, 4144, 4142>, 0,
    <4147, 4142, 4145>, 0,
    <4147, 4145, 4143>, 0,
    <4147, 4143, 4146>, 0,
    <4150, 4137, 4133>, 0,
    <4150, 4133, 4146>, 0,
    <4150, 4146, 4143>, 0,
    <4150, 4143, 4148>, 0,
    <4150, 4148, 3987>, 0,
    <4150, 3987, 4149>, 0,
    <4150, 4149, 4134>, 0,
    <4150, 4134, 4137>, 0,
    <4159, 4158, 4151>, 0,
    <4159, 4151, 4155>, 0,
    <4159, 4155, 4152>, 0,
    <4159, 4152, 4156>, 0,
    <4159, 4156, 4153>, 0,
    <4159, 4153, 4157>, 0,
    <4159, 4157, 4154>, 0,
    <4159, 4154, 4158>, 0,
    <4162, 4161, 4151>, 0,
    <4162, 4151, 4158>, 0,
    <4162, 4158, 4154>, 0,
    <4162, 4154, 4160>, 0,
    <4162, 4160, 4129>, 0,
    <4162, 4129, 4130>, 0,
    <4162, 4130, 4125>, 0,
    <4162, 4125, 4161>, 0,
    <4164, 4155, 4151>, 0,
    <4164, 4151, 4161>, 0,
    <4164, 4161, 4125>, 0,
    <4164, 4125, 4126>, 0,
    <4164, 4126, 4082>, 0,
    <4164, 4082, 4163>, 0,
    <4164, 4163, 4152>, 0,
    <4164, 4152, 4155>, 0,
    <4173, 4172, 4165>, 0,
    <4173, 4165, 4169>, 0,
    <4173, 4169, 4166>, 0,
    <4173, 4166, 4170>, 0,
    <4173, 4170, 4167>, 0,
    <4173, 4167, 4171>, 0,
    <4173, 4171, 4168>, 0,
    <4173, 4168, 4172>, 0,
    <4176, 4175, 4165>, 0,
    <4176, 4165, 4172>, 0,
    <4176, 4172, 4168>, 0,
    <4176, 4168, 4174>, 0,
    <4176, 4174, 3987>, 0,
    <4176, 3987, 4069>, 0,
    <4176, 4069, 4063>, 0,
    <4176, 4063, 4175>, 0,
    <4178, 4169, 4165>, 0,
    <4178, 4165, 4175>, 0,
    <4178, 4175, 4063>, 0,
    <4178, 4063, 4066>, 0,
    <4178, 4066, 4062>, 0,
    <4178, 4062, 4177>, 0,
    <4178, 4177, 4166>, 0,
    <4178, 4166, 4169>, 0,
    <4184, 4183, 4179>, 0,
    <4184, 4179, 4181>, 0,
    <4184, 4181, 4168>, 0,
    <4184, 4168, 4171>, 0,
    <4184, 4171, 4167>, 0,
    <4184, 4167, 4182>, 0,
    <4184, 4182, 4180>, 0,
    <4184, 4180, 4183>, 0,
    <4189, 4188, 4179>, 0,
    <4189, 4179, 4183>, 0,
    <4189, 4183, 4180>, 0,
    <4189, 4180, 4186>, 0,
    <4189, 4186, 4142>, 0,
    <4189, 4142, 4187>, 0,
    <4189, 4187, 4185>, 0,
    <4189, 4185, 4188>, 0,
    <4191, 4181, 4179>, 0,
    <4191, 4179, 4188>, 0,
    <4191, 4188, 4185>, 0,
    <4191, 4185, 4190>, 0,
    <4191, 4190, 3987>, 0,
    <4191, 3987, 4174>, 0,
    <4191, 4174, 4168>, 0,
    <4191, 4168, 4181>, 0,
    <4200, 4199, 4192>, 0,
    <4200, 4192, 4196>, 0,
    <4200, 4196, 4193>, 0,
    <4200, 4193, 4197>, 0,
    <4200, 4197, 4194>, 0,
    <4200, 4194, 4198>, 0,
    <4200, 4198, 4195>, 0,
    <4200, 4195, 4199>, 0,
    <4203, 4202, 4192>, 0,
    <4203, 4192, 4199>, 0,
    <4203, 4199, 4195>, 0,
    <4203, 4195, 4201>, 0,
    <4203, 4201, 4142>, 0,
    <4203, 4142, 4186>, 0,
    <4203, 4186, 4180>, 0,
    <4203, 4180, 4202>, 0,
    <4205, 4196, 4192>, 0,
    <4205, 4192, 4202>, 0,
    <4205, 4202, 4180>, 0,
    <4205, 4180, 4182>, 0,
    <4205, 4182, 4167>, 0,
    <4205, 4167, 4204>, 0,
    <4205, 4204, 4193>, 0,
    <4205, 4193, 4196>, 0,
    <4214, 4213, 4206>, 0,
    <4214, 4206, 4210>, 0,
    <4214, 4210, 4207>, 0,
    <4214, 4207, 4211>, 0,
    <4214, 4211, 4208>, 0,
    <4214, 4208, 4212>, 0,
    <4214, 4212, 4209>, 0,
    <4214, 4209, 4213>, 0,
    <4219, 4218, 4206>, 0,
    <4219, 4206, 4213>, 0,
    <4219, 4213, 4209>, 0,
    <4219, 4209, 4216>, 0,
    <4219, 4216, 4153>, 0,
    <4219, 4153, 4217>, 0,
    <4219, 4217, 4215>, 0,
    <4219, 4215, 4218>, 0,
    <4223, 4210, 4206>, 0,
    <4223, 4206, 4218>, 0,
    <4223, 4218, 4215>, 0,
    <4223, 4215, 4221>, 0,
    <4223, 4221, 4220>, 0,
    <4223, 4220, 4222>, 0,
    <4223, 4222, 4207>, 0,
    <4223, 4207, 4210>, 0,
    <4231, 4230, 4224>, 0,
    <4231, 4224, 4227>, 0,
    <4231, 4227, 4225>, 0,
    <4231, 4225, 4228>, 0,
    <4231, 4228, 4082>, 0,
    <4231, 4082, 4229>, 0,
    <4231, 4229, 4226>, 0,
    <4231, 4226, 4230>, 0,
    <4236, 4235, 4224>, 0,
    <4236, 4224, 4230>, 0,
    <4236, 4230, 4226>, 0,
    <4236, 4226, 4233>, 0,
    <4236, 4233, 4220>, 0,
    <4236, 4220, 4234>, 0,
    <4236, 4234, 4232>, 0,
    <4236, 4232, 4235>, 0,
    <4240, 4227, 4224>, 0,
    <4240, 4224, 4235>, 0,
    <4240, 4235, 4232>, 0,
    <4240, 4232, 4238>, 0,
    <4240, 4238, 4237>, 0,
    <4240, 4237, 4239>, 0,
    <4240, 4239, 4225>, 0,
    <4240, 4225, 4227>, 0,
    <4244, 4243, 4241>, 0,
    <4244, 4241, 4242>, 0,
    <4244, 4242, 4215>, 0,
    <4244, 4215, 4217>, 0,
    <4244, 4217, 4153>, 0,
    <4244, 4153, 4156>, 0,
    <4244, 4156, 4152>, 0,
    <4244, 4152, 4243>, 0,
    <4248, 4247, 4241>, 0,
    <4248, 4241, 4243>, 0,
    <4248, 4243, 4152>, 0,
    <4248, 4152, 4163>, 0,
    <4248, 4163, 4082>, 0,
    <4248, 4082, 4246>, 0,
    <4248, 4246, 4245>, 0,
    <4248, 4245, 4247>, 0,
    <4250, 4242, 4241>, 0,
    <4250, 4241, 4247>, 0,
    <4250, 4247, 4245>, 0,
    <4250, 4245, 4249>, 0,
    <4250, 4249, 4220>, 0,
    <4250, 4220, 4221>, 0,
    <4250, 4221, 4215>, 0,
    <4250, 4215, 4242>, 0,
    <4256, 4255, 4251>, 0,
    <4256, 4251, 4253>, 0,
    <4256, 4253, 4252>, 0,
    <4256, 4252, 4254>, 0,
    <4256, 4254, 4208>, 0,
    <4256, 4208, 4211>, 0,
    <4256, 4211, 4207>, 0,
    <4256, 4207, 4255>, 0,
    <4260, 4259, 4251>, 0,
    <4260, 4251, 4255>, 0,
    <4260, 4255, 4207>, 0,
    <4260, 4207, 4222>, 0,
    <4260, 4222, 4220>, 0,
    <4260, 4220, 4258>, 0,
    <4260, 4258, 4257>, 0,
    <4260, 4257, 4259>, 0,
    <4264, 4253, 4251>, 0,
    <4264, 4251, 4259>, 0,
    <4264, 4259, 4257>, 0,
    <4264, 4257, 4262>, 0,
    <4264, 4262, 4261>, 0,
    <4264, 4261, 4263>, 0,
    <4264, 4263, 4252>, 0,
    <4264, 4252, 4253>, 0,
    <4273, 4272, 4265>, 0,
    <4273, 4265, 4269>, 0,
    <4273, 4269, 4266>, 0,
    <4273, 4266, 4270>, 0,
    <4273, 4270, 4267>, 0,
    <4273, 4267, 4271>, 0,
    <4273, 4271, 4268>, 0,
    <4273, 4268, 4272>, 0,
    <4276, 4275, 4265>, 0,
    <4276, 4265, 4272>, 0,
    <4276, 4272, 4268>, 0,
    <4276, 4268, 4274>, 0,
    <4276, 4274, 4142>, 0,
    <4276, 4142, 4201>, 0,
    <4276, 4201, 4195>, 0,
    <4276, 4195, 4275>, 0,
    <4278, 4269, 4265>, 0,
    <4278, 4265, 4275>, 0,
    <4278, 4275, 4195>, 0,
    <4278, 4195, 4198>, 0,
    <4278, 4198, 4194>, 0,
    <4278, 4194, 4277>, 0,
    <4278, 4277, 4266>, 0,
    <4278, 4266, 4269>, 0,
    <4284, 4283, 4279>, 0,
    <4284, 4279, 4281>, 0,
    <4284, 4281, 4268>, 0,
    <4284, 4268, 4271>, 0,
    <4284, 4271, 4267>, 0,
    <4284, 4267, 4282>, 0,
    <4284, 4282, 4280>, 0,
    <4284, 4280, 4283>, 0,
    <4290, 4289, 4279>, 0,
    <4290, 4279, 4283>, 0,
    <4290, 4283, 4280>, 0,
    <4290, 4280, 4287>, 0,
    <4290, 4287, 4285>, 0,
    <4290, 4285, 4288>, 0,
    <4290, 4288, 4286>, 0,
    <4290, 4286, 4289>, 0,
    <4292, 4281, 4279>, 0,
    <4292, 4279, 4289>, 0,
    <4292, 4289, 4286>, 0,
    <4292, 4286, 4291>, 0,
    <4292, 4291, 4142>, 0,
    <4292, 4142, 4274>, 0,
    <4292, 4274, 4268>, 0,
    <4292, 4268, 4281>, 0,
    <4301, 4300, 4293>, 0,
    <4301, 4293, 4297>, 0,
    <4301, 4297, 4294>, 0,
    <4301, 4294, 4298>, 0,
    <4301, 4298, 4295>, 0,
    <4301, 4295, 4299>, 0,
    <4301, 4299, 4296>, 0,
    <4301, 4296, 4300>, 0,
    <4304, 4303, 4293>, 0,
    <4304, 4293, 4300>, 0,
    <4304, 4300, 4296>, 0,
    <4304, 4296, 4302>, 0,
    <4304, 4302, 4285>, 0,
    <4304, 4285, 4287>, 0,
    <4304, 4287, 4280>, 0,
    <4304, 4280, 4303>, 0,
    <4306, 4297, 4293>, 0,
    <4306, 4293, 4303>, 0,
    <4306, 4303, 4280>, 0,
    <4306, 4280, 4282>, 0,
    <4306, 4282, 4267>, 0,
    <4306, 4267, 4305>, 0,
    <4306, 4305, 4294>, 0,
    <4306, 4294, 4297>, 0,
    <4314, 4313, 4307>, 0,
    <4314, 4307, 4310>, 0,
    <4314, 4310, 4308>, 0,
    <4314, 4308, 4311>, 0,
    <4314, 4311, 4261>, 0,
    <4314, 4261, 4312>, 0,
    <4314, 4312, 4309>, 0,
    <4314, 4309, 4313>, 0,
    <4317, 4316, 4307>, 0,
    <4317, 4307, 4313>, 0,
    <4317, 4313, 4309>, 0,
    <4317, 4309, 4315>, 0,
    <4317, 4315, 4285>, 0,
    <4317, 4285, 4302>, 0,
    <4317, 4302, 4296>, 0,
    <4317, 4296, 4316>, 0,
    <4319, 4310, 4307>, 0,
    <4319, 4307, 4316>, 0,
    <4319, 4316, 4296>, 0,
    <4319, 4296, 4299>, 0,
    <4319, 4299, 4295>, 0,
    <4319, 4295, 4318>, 0,
    <4319, 4318, 4308>, 0,
    <4319, 4308, 4310>, 0,
    <4327, 4326, 4320>, 0,
    <4327, 4320, 4323>, 0,
    <4327, 4323, 4321>, 0,
    <4327, 4321, 4324>, 0,
    <4327, 4324, 4220>, 0,
    <4327, 4220, 4325>, 0,
    <4327, 4325, 4322>, 0,
    <4327, 4322, 4326>, 0,
    <4332, 4331, 4320>, 0,
    <4332, 4320, 4326>, 0,
    <4332, 4326, 4322>, 0,
    <4332, 4322, 4329>, 0,
    <4332, 4329, 4285>, 0,
    <4332, 4285, 4330>, 0,
    <4332, 4330, 4328>, 0,
    <4332, 4328, 4331>, 0,
    <4336, 4323, 4320>, 0,
    <4336, 4320, 4331>, 0,
    <4336, 4331, 4328>, 0,
    <4336, 4328, 4334>, 0,
    <4336, 4334, 4333>, 0,
    <4336, 4333, 4335>, 0,
    <4336, 4335, 4321>, 0,
    <4336, 4321, 4323>, 0,
    <4340, 4339, 4337>, 0,
    <4340, 4337, 4338>, 0,
    <4340, 4338, 4309>, 0,
    <4340, 4309, 4312>, 0,
    <4340, 4312, 4261>, 0,
    <4340, 4261, 4262>, 0,
    <4340, 4262, 4257>, 0,
    <4340, 4257, 4339>, 0,
    <4344, 4343, 4337>, 0,
    <4344, 4337, 4339>, 0,
    <4344, 4339, 4257>, 0,
    <4344, 4257, 4258>, 0,
    <4344, 4258, 4220>, 0,
    <4344, 4220, 4342>, 0,
    <4344, 4342, 4341>, 0,
    <4344, 4341, 4343>, 0,
    <4346, 4338, 4337>, 0,
    <4346, 4337, 4343>, 0,
    <4346, 4343, 4341>, 0,
    <4346, 4341, 4345>, 0,
    <4346, 4345, 4285>, 0,
    <4346, 4285, 4315>, 0,
    <4346, 4315, 4309>, 0,
    <4346, 4309, 4338>, 0,
    <4355, 4354, 4347>, 0,
    <4355, 4347, 4351>, 0,
    <4355, 4351, 4348>, 0,
    <4355, 4348, 4352>, 0,
    <4355, 4352, 4349>, 0,
    <4355, 4349, 4353>, 0,
    <4355, 4353, 4350>, 0,
    <4355, 4350, 4354>, 0,
    <4360, 4359, 4347>, 0,
    <4360, 4347, 4354>, 0,
    <4360, 4354, 4350>, 0,
    <4360, 4350, 4357>, 0,
    <4360, 4357, 2>, 0,
    <4360, 2, 4358>, 0,
    <4360, 4358, 4356>, 0,
    <4360, 4356, 4359>, 0,
    <4364, 4351, 4347>, 0,
    <4364, 4347, 4359>, 0,
    <4364, 4359, 4356>, 0,
    <4364, 4356, 4362>, 0,
    <4364, 4362, 4361>, 0,
    <4364, 4361, 4363>, 0,
    <4364, 4363, 4348>, 0,
    <4364, 4348, 4351>, 0,
    <4373, 4372, 4365>, 0,
    <4373, 4365, 4369>, 0,
    <4373, 4369, 4366>, 0,
    <4373, 4366, 4370>, 0,
    <4373, 4370, 4367>, 0,
    <4373, 4367, 4371>, 0,
    <4373, 4371, 4368>, 0,
    <4373, 4368, 4372>, 0,
    <4376, 4375, 4365>, 0,
    <4376, 4365, 4372>, 0,
    <4376, 4372, 4368>, 0,
    <4376, 4368, 4374>, 0,
    <4376, 4374, 4361>, 0,
    <4376, 4361, 4362>, 0,
    <4376, 4362, 4356>, 0,
    <4376, 4356, 4375>, 0,
    <4378, 4369, 4365>, 0,
    <4378, 4365, 4375>, 0,
    <4378, 4375, 4356>, 0,
    <4378, 4356, 4358>, 0,
    <4378, 4358, 2>, 0,
    <4378, 2, 4377>, 0,
    <4378, 4377, 4366>, 0,
    <4378, 4366, 4369>, 0,
    <4387, 4386, 4379>, 0,
    <4387, 4379, 4383>, 0,
    <4387, 4383, 4380>, 0,
    <4387, 4380, 4384>, 0,
    <4387, 4384, 4381>, 0,
    <4387, 4381, 4385>, 0,
    <4387, 4385, 4382>, 0,
    <4387, 4382, 4386>, 0,
    <4393, 4392, 4379>, 0,
    <4393, 4379, 4386>, 0,
    <4393, 4386, 4382>, 0,
    <4393, 4382, 4390>, 0,
    <4393, 4390, 4388>, 0,
    <4393, 4388, 4391>, 0,
    <4393, 4391, 4389>, 0,
    <4393, 4389, 4392>, 0,
    <4396, 4383, 4379>, 0,
    <4396, 4379, 4392>, 0,
    <4396, 4392, 4389>, 0,
    <4396, 4389, 4394>, 0,
    <4396, 4394, 49>, 0,
    <4396, 49, 4395>, 0,
    <4396, 4395, 4380>, 0,
    <4396, 4380, 4383>, 0,
    <4402, 4401, 4397>, 0,
    <4402, 4397, 4399>, 0,
    <4402, 4399, 4382>, 0,
    <4402, 4382, 4385>, 0,
    <4402, 4385, 4381>, 0,
    <4402, 4381, 4400>, 0,
    <4402, 4400, 4398>, 0,
    <4402, 4398, 4401>, 0,
    <4407, 4406, 4397>, 0,
    <4407, 4397, 4401>, 0,
    <4407, 4401, 4398>, 0,
    <4407, 4398, 4404>, 0,
    <4407, 4404, 4349>, 0,
    <4407, 4349, 4405>, 0,
    <4407, 4405, 4403>, 0,
    <4407, 4403, 4406>, 0,
    <4409, 4399, 4397>, 0,
    <4409, 4397, 4406>, 0,
    <4409, 4406, 4403>, 0,
    <4409, 4403, 4408>, 0,
    <4409, 4408, 4388>, 0,
    <4409, 4388, 4390>, 0,
    <4409, 4390, 4382>, 0,
    <4409, 4382, 4399>, 0,
    <4413, 4412, 4410>, 0,
    <4413, 4410, 4411>, 0,
    <4413, 4411, 4403>, 0,
    <4413, 4403, 4405>, 0,
    <4413, 4405, 4349>, 0,
    <4413, 4349, 4352>, 0,
    <4413, 4352, 4348>, 0,
    <4413, 4348, 4412>, 0,
    <4417, 4416, 4410>, 0,
    <4417, 4410, 4412>, 0,
    <4417, 4412, 4348>, 0,
    <4417, 4348, 4363>, 0,
    <4417, 4363, 4361>, 0,
    <4417, 4361, 4415>, 0,
    <4417, 4415, 4414>, 0,
    <4417, 4414, 4416>, 0,
    <4419, 4411, 4410>, 0,
    <4419, 4410, 4416>, 0,
    <4419, 4416, 4414>, 0,
    <4419, 4414, 4418>, 0,
    <4419, 4418, 4388>, 0,
    <4419, 4388, 4408>, 0,
    <4419, 4408, 4403>, 0,
    <4419, 4403, 4411>, 0,
    <4425, 4424, 4420>, 0,
    <4425, 4420, 4422>, 0,
    <4425, 4422, 4368>, 0,
    <4425, 4368, 4371>, 0,
    <4425, 4371, 4367>, 0,
    <4425, 4367, 4423>, 0,
    <4425, 4423, 4421>, 0,
    <4425, 4421, 4424>, 0,
    <4431, 4430, 4420>, 0,
    <4431, 4420, 4424>, 0,
    <4431, 4424, 4421>, 0,
    <4431, 4421, 4428>, 0,
    <4431, 4428, 4426>, 0,
    <4431, 4426, 4429>, 0,
    <4431, 4429, 4427>, 0,
    <4431, 4427, 4430>, 0,
    <4433, 4422, 4420>, 0,
    <4433, 4420, 4430>, 0,
    <4433, 4430, 4427>, 0,
    <4433, 4427, 4432>, 0,
    <4433, 4432, 4361>, 0,
    <4433, 4361, 4374>, 0,
    <4433, 4374, 4368>, 0,
    <4433, 4368, 4422>, 0,
    <4439, 4438, 4434>, 0,
    <4439, 4434, 4436>, 0,
    <4439, 4436, 4421>, 0,
    <4439, 4421, 4423>, 0,
    <4439, 4423, 4367>, 0,
    <4439, 4367, 4437>, 0,
    <4439, 4437, 4435>, 0,
    <4439, 4435, 4438>, 0,
    <4445, 4444, 4434>, 0,
    <4445, 4434, 4438>, 0,
    <4445, 4438, 4435>, 0,
    <4445, 4435, 4442>, 0,
    <4445, 4442, 4440>, 0,
    <4445, 4440, 4443>, 0,
    <4445, 4443, 4441>, 0,
    <4445, 4441, 4444>, 0,
    <4447, 4436, 4434>, 0,
    <4447, 4434, 4444>, 0,
    <4447, 4444, 4441>, 0,
    <4447, 4441, 4446>, 0,
    <4447, 4446, 4426>, 0,
    <4447, 4426, 4428>, 0,
    <4447, 4428, 4421>, 0,
    <4447, 4421, 4436>, 0,
    <4453, 4452, 4448>, 0,
    <4453, 4448, 4450>, 0,
    <4453, 4450, 4441>, 0,
    <4453, 4441, 4443>, 0,
    <4453, 4443, 4440>, 0,
    <4453, 4440, 4451>, 0,
    <4453, 4451, 4449>, 0,
    <4453, 4449, 4452>, 0,
    <4458, 4457, 4448>, 0,
    <4458, 4448, 4452>, 0,
    <4458, 4452, 4449>, 0,
    <4458, 4449, 4455>, 0,
    <4458, 4455, 91>, 0,
    <4458, 91, 4456>, 0,
    <4458, 4456, 4454>, 0,
    <4458, 4454, 4457>, 0,
    <4460, 4450, 4448>, 0,
    <4460, 4448, 4457>, 0,
    <4460, 4457, 4454>, 0,
    <4460, 4454, 4459>, 0,
    <4460, 4459, 4426>, 0,
    <4460, 4426, 4446>, 0,
    <4460, 4446, 4441>, 0,
    <4460, 4441, 4450>, 0,
    <4466, 4465, 4461>, 0,
    <4466, 4461, 4463>, 0,
    <4466, 4463, 4427>, 0,
    <4466, 4427, 4429>, 0,
    <4466, 4429, 4426>, 0,
    <4466, 4426, 4464>, 0,
    <4466, 4464, 4462>, 0,
    <4466, 4462, 4465>, 0,
    <4472, 4471, 4461>, 0,
    <4472, 4461, 4465>, 0,
    <4472, 4465, 4462>, 0,
    <4472, 4462, 4469>, 0,
    <4472, 4469, 4467>, 0,
    <4472, 4467, 4470>, 0,
    <4472, 4470, 4468>, 0,
    <4472, 4468, 4471>, 0,
    <4474, 4463, 4461>, 0,
    <4474, 4461, 4471>, 0,
    <4474, 4471, 4468>, 0,
    <4474, 4468, 4473>, 0,
    <4474, 4473, 4361>, 0,
    <4474, 4361, 4432>, 0,
    <4474, 4432, 4427>, 0,
    <4474, 4427, 4463>, 0,
    <4483, 4482, 4475>, 0,
    <4483, 4475, 4479>, 0,
    <4483, 4479, 4476>, 0,
    <4483, 4476, 4480>, 0,
    <4483, 4480, 4477>, 0,
    <4483, 4477, 4481>, 0,
    <4483, 4481, 4478>, 0,
    <4483, 4478, 4482>, 0,
    <4488, 4487, 4475>, 0,
    <4488, 4475, 4482>, 0,
    <4488, 4482, 4478>, 0,
    <4488, 4478, 4485>, 0,
    <4488, 4485, 9>, 0,
    <4488, 9, 4486>, 0,
    <4488, 4486, 4484>, 0,
    <4488, 4484, 4487>, 0,
    <4492, 4479, 4475>, 0,
    <4492, 4475, 4487>, 0,
    <4492, 4487, 4484>, 0,
    <4492, 4484, 4490>, 0,
    <4492, 4490, 4489>, 0,
    <4492, 4489, 4491>, 0,
    <4492, 4491, 4476>, 0,
    <4492, 4476, 4479>, 0,
    <4500, 4499, 4493>, 0,
    <4500, 4493, 4496>, 0,
    <4500, 4496, 4494>, 0,
    <4500, 4494, 4497>, 0,
    <4500, 4497, 85>, 0,
    <4500, 85, 4498>, 0,
    <4500, 4498, 4495>, 0,
    <4500, 4495, 4499>, 0,
    <4503, 4502, 4493>, 0,
    <4503, 4493, 4499>, 0,
    <4503, 4499, 4495>, 0,
    <4503, 4495, 4501>, 0,
    <4503, 4501, 4477>, 0,
    <4503, 4477, 4480>, 0,
    <4503, 4480, 4476>, 0,
    <4503, 4476, 4502>, 0,
    <4505, 4496, 4493>, 0,
    <4505, 4493, 4502>, 0,
    <4505, 4502, 4476>, 0,
    <4505, 4476, 4491>, 0,
    <4505, 4491, 4489>, 0,
    <4505, 4489, 4504>, 0,
    <4505, 4504, 4494>, 0,
    <4505, 4494, 4496>, 0,
    <4514, 4513, 4506>, 0,
    <4514, 4506, 4510>, 0,
    <4514, 4510, 4507>, 0,
    <4514, 4507, 4511>, 0,
    <4514, 4511, 4508>, 0,
    <4514, 4508, 4512>, 0,
    <4514, 4512, 4509>, 0,
    <4514, 4509, 4513>, 0,
    <4517, 4516, 4506>, 0,
    <4517, 4506, 4513>, 0,
    <4517, 4513, 4509>, 0,
    <4517, 4509, 4515>, 0,
    <4517, 4515, 49>, 0,
    <4517, 49, 4394>, 0,
    <4517, 4394, 4389>, 0,
    <4517, 4389, 4516>, 0,
    <4519, 4510, 4506>, 0,
    <4519, 4506, 4516>, 0,
    <4519, 4516, 4389>, 0,
    <4519, 4389, 4391>, 0,
    <4519, 4391, 4388>, 0,
    <4519, 4388, 4518>, 0,
    <4519, 4518, 4507>, 0,
    <4519, 4507, 4510>, 0,
    <4525, 4524, 4520>, 0,
    <4525, 4520, 4522>, 0,
    <4525, 4522, 4414>, 0,
    <4525, 4414, 4415>, 0,
    <4525, 4415, 4361>, 0,
    <4525, 4361, 4523>, 0,
    <4525, 4523, 4521>, 0,
    <4525, 4521, 4524>, 0,
    <4531, 4530, 4520>, 0,
    <4531, 4520, 4524>, 0,
    <4531, 4524, 4521>, 0,
    <4531, 4521, 4528>, 0,
    <4531, 4528, 4526>, 0,
    <4531, 4526, 4529>, 0,
    <4531, 4529, 4527>, 0,
    <4531, 4527, 4530>, 0,
    <4533, 4522, 4520>, 0,
    <4533, 4520, 4530>, 0,
    <4533, 4530, 4527>, 0,
    <4533, 4527, 4532>, 0,
    <4533, 4532, 4388>, 0,
    <4533, 4388, 4418>, 0,
    <4533, 4418, 4414>, 0,
    <4533, 4414, 4522>, 0,
    <4537, 4536, 4534>, 0,
    <4537, 4534, 4535>, 0,
    <4537, 4535, 4521>, 0,
    <4537, 4521, 4523>, 0,
    <4537, 4523, 4361>, 0,
    <4537, 4361, 4473>, 0,
    <4537, 4473, 4468>, 0,
    <4537, 4468, 4536>, 0,
    <4541, 4540, 4534>, 0,
    <4541, 4534, 4536>, 0,
    <4541, 4536, 4468>, 0,
    <4541, 4468, 4470>, 0,
    <4541, 4470, 4467>, 0,
    <4541, 4467, 4539>, 0,
    <4541, 4539, 4538>, 0,
    <4541, 4538, 4540>, 0,
    <4543, 4535, 4534>, 0,
    <4543, 4534, 4540>, 0,
    <4543, 4540, 4538>, 0,
    <4543, 4538, 4542>, 0,
    <4543, 4542, 4526>, 0,
    <4543, 4526, 4528>, 0,
    <4543, 4528, 4521>, 0,
    <4543, 4521, 4535>, 0,
    <4552, 4551, 4544>, 0,
    <4552, 4544, 4548>, 0,
    <4552, 4548, 4545>, 0,
    <4552, 4545, 4549>, 0,
    <4552, 4549, 4546>, 0,
    <4552, 4546, 4550>, 0,
    <4552, 4550, 4547>, 0,
    <4552, 4547, 4551>, 0,
    <4558, 4557, 4544>, 0,
    <4558, 4544, 4551>, 0,
    <4558, 4551, 4547>, 0,
    <4558, 4547, 4555>, 0,
    <4558, 4555, 4553>, 0,
    <4558, 4553, 4556>, 0,
    <4558, 4556, 4554>, 0,
    <4558, 4554, 4557>, 0,
    <4561, 4548, 4544>, 0,
    <4561, 4544, 4557>, 0,
    <4561, 4557, 4554>, 0,
    <4561, 4554, 4559>, 0,
    <4561, 4559, 4467>, 0,
    <4561, 4467, 4560>, 0,
    <4561, 4560, 4545>, 0,
    <4561, 4545, 4548>, 0,
    <4567, 4566, 4562>, 0,
    <4567, 4562, 4564>, 0,
    <4567, 4564, 4462>, 0,
    <4567, 4462, 4464>, 0,
    <4567, 4464, 4426>, 0,
    <4567, 4426, 4565>, 0,
    <4567, 4565, 4563>, 0,
    <4567, 4563, 4566>, 0,
    <4570, 4569, 4562>, 0,
    <4570, 4562, 4566>, 0,
    <4570, 4566, 4563>, 0,
    <4570, 4563, 4568>, 0,
    <4570, 4568, 4546>, 0,
    <4570, 4546, 4549>, 0,
    <4570, 4549, 4545>, 0,
    <4570, 4545, 4569>, 0,
    <4571, 4564, 4562>, 0,
    <4571, 4562, 4569>, 0,
    <4571, 4569, 4545>, 0,
    <4571, 4545, 4560>, 0,
    <4571, 4560, 4467>, 0,
    <4571, 4467, 4469>, 0,
    <4571, 4469, 4462>, 0,
    <4571, 4462, 4564>, 0,
    <4580, 4579, 4572>, 0,
    <4580, 4572, 4576>, 0,
    <4580, 4576, 4573>, 0,
    <4580, 4573, 4577>, 0,
    <4580, 4577, 4574>, 0,
    <4580, 4574, 4578>, 0,
    <4580, 4578, 4575>, 0,
    <4580, 4575, 4579>, 0,
    <4583, 4582, 4572>, 0,
    <4583, 4572, 4579>, 0,
    <4583, 4579, 4575>, 0,
    <4583, 4575, 4581>, 0,
    <4583, 4581, 4426>, 0,
    <4583, 4426, 4459>, 0,
    <4583, 4459, 4454>, 0,
    <4583, 4454, 4582>, 0,
    <4585, 4576, 4572>, 0,
    <4585, 4572, 4582>, 0,
    <4585, 4582, 4454>, 0,
    <4585, 4454, 4456>, 0,
    <4585, 4456, 91>, 0,
    <4585, 91, 4584>, 0,
    <4585, 4584, 4573>, 0,
    <4585, 4573, 4576>, 0,
    <4593, 4592, 4586>, 0,
    <4593, 4586, 4589>, 0,
    <4593, 4589, 4587>, 0,
    <4593, 4587, 4590>, 0,
    <4593, 4590, 119>, 0,
    <4593, 119, 4591>, 0,
    <4593, 4591, 4588>, 0,
    <4593, 4588, 4592>, 0,
    <4598, 4597, 4586>, 0,
    <4598, 4586, 4592>, 0,
    <4598, 4592, 4588>, 0,
    <4598, 4588, 4595>, 0,
    <4598, 4595, 56>, 0,
    <4598, 56, 4596>, 0,
    <4598, 4596, 4594>, 0,
    <4598, 4594, 4597>, 0,
    <4602, 4589, 4586>, 0,
    <4602, 4586, 4597>, 0,
    <4602, 4597, 4594>, 0,
    <4602, 4594, 4600>, 0,
    <4602, 4600, 4599>, 0,
    <4602, 4599, 4601>, 0,
    <4602, 4601, 4587>, 0,
    <4602, 4587, 4589>, 0,
    <4610, 4609, 4603>, 0,
    <4610, 4603, 4606>, 0,
    <4610, 4606, 4604>, 0,
    <4610, 4604, 4607>, 0,
    <4610, 4607, 9>, 0,
    <4610, 9, 4608>, 0,
    <4610, 4608, 4605>, 0,
    <4610, 4605, 4609>, 0,
    <4613, 4612, 4603>, 0,
    <4613, 4603, 4609>, 0,
    <4613, 4609, 4605>, 0,
    <4613, 4605, 4611>, 0,
    <4613, 4611, 119>, 0,
    <4613, 119, 4590>, 0,
    <4613, 4590, 4587>, 0,
    <4613, 4587, 4612>, 0,
    <4615, 4606, 4603>, 0,
    <4615, 4603, 4612>, 0,
    <4615, 4612, 4587>, 0,
    <4615, 4587, 4601>, 0,
    <4615, 4601, 4599>, 0,
    <4615, 4599, 4614>, 0,
    <4615, 4614, 4604>, 0,
    <4615, 4604, 4606>, 0,
    <4619, 4618, 4616>, 0,
    <4619, 4616, 4617>, 0,
    <4619, 4617, 4484>, 0,
    <4619, 4484, 4486>, 0,
    <4619, 4486, 9>, 0,
    <4619, 9, 4607>, 0,
    <4619, 4607, 4604>, 0,
    <4619, 4604, 4618>, 0,
    <4623, 4622, 4616>, 0,
    <4623, 4616, 4618>, 0,
    <4623, 4618, 4604>, 0,
    <4623, 4604, 4614>, 0,
    <4623, 4614, 4599>, 0,
    <4623, 4599, 4621>, 0,
    <4623, 4621, 4620>, 0,
    <4623, 4620, 4622>, 0,
    <4625, 4617, 4616>, 0,
    <4625, 4616, 4622>, 0,
    <4625, 4622, 4620>, 0,
    <4625, 4620, 4624>, 0,
    <4625, 4624, 4489>, 0,
    <4625, 4489, 4490>, 0,
    <4625, 4490, 4484>, 0,
    <4625, 4484, 4617>, 0,
    <4631, 4630, 4626>, 0,
    <4631, 4626, 4628>, 0,
    <4631, 4628, 4627>, 0,
    <4631, 4627, 4629>, 0,
    <4631, 4629, 85>, 0,
    <4631, 85, 4497>, 0,
    <4631, 4497, 4494>, 0,
    <4631, 4494, 4630>, 0,
    <4635, 4634, 4626>, 0,
    <4635, 4626, 4630>, 0,
    <4635, 4630, 4494>, 0,
    <4635, 4494, 4504>, 0,
    <4635, 4504, 4489>, 0,
    <4635, 4489, 4633>, 0,
    <4635, 4633, 4632>, 0,
    <4635, 4632, 4634>, 0,
    <4639, 4628, 4626>, 0,
    <4639, 4626, 4634>, 0,
    <4639, 4634, 4632>, 0,
    <4639, 4632, 4637>, 0,
    <4639, 4637, 4636>, 0,
    <4639, 4636, 4638>, 0,
    <4639, 4638, 4627>, 0,
    <4639, 4627, 4628>, 0,
    <4645, 4644, 4640>, 0,
    <4645, 4640, 4642>, 0,
    <4645, 4642, 4641>, 0,
    <4645, 4641, 4643>, 0,
    <4645, 4643, 4636>, 0,
    <4645, 4636, 4637>, 0,
    <4645, 4637, 4632>, 0,
    <4645, 4632, 4644>, 0,
    <4649, 4648, 4640>, 0,
    <4649, 4640, 4644>, 0,
    <4649, 4644, 4632>, 0,
    <4649, 4632, 4633>, 0,
    <4649, 4633, 4489>, 0,
    <4649, 4489, 4647>, 0,
    <4649, 4647, 4646>, 0,
    <4649, 4646, 4648>, 0,
    <4653, 4642, 4640>, 0,
    <4653, 4640, 4648>, 0,
    <4653, 4648, 4646>, 0,
    <4653, 4646, 4651>, 0,
    <4653, 4651, 4650>, 0,
    <4653, 4650, 4652>, 0,
    <4653, 4652, 4641>, 0,
    <4653, 4641, 4642>, 0,
    <4659, 4658, 4654>, 0,
    <4659, 4654, 4656>, 0,
    <4659, 4656, 4538>, 0,
    <4659, 4538, 4539>, 0,
    <4659, 4539, 4467>, 0,
    <4659, 4467, 4657>, 0,
    <4659, 4657, 4655>, 0,
    <4659, 4655, 4658>, 0,
    <4665, 4664, 4654>, 0,
    <4665, 4654, 4658>, 0,
    <4665, 4658, 4655>, 0,
    <4665, 4655, 4662>, 0,
    <4665, 4662, 4660>, 0,
    <4665, 4660, 4663>, 0,
    <4665, 4663, 4661>, 0,
    <4665, 4661, 4664>, 0,
    <4667, 4656, 4654>, 0,
    <4667, 4654, 4664>, 0,
    <4667, 4664, 4661>, 0,
    <4667, 4661, 4666>, 0,
    <4667, 4666, 4526>, 0,
    <4667, 4526, 4542>, 0,
    <4667, 4542, 4538>, 0,
    <4667, 4538, 4656>, 0,
    <4671, 4670, 4668>, 0,
    <4671, 4668, 4669>, 0,
    <4671, 4669, 4655>, 0,
    <4671, 4655, 4657>, 0,
    <4671, 4657, 4467>, 0,
    <4671, 4467, 4559>, 0,
    <4671, 4559, 4554>, 0,
    <4671, 4554, 4670>, 0,
    <4675, 4674, 4668>, 0,
    <4675, 4668, 4670>, 0,
    <4675, 4670, 4554>, 0,
    <4675, 4554, 4556>, 0,
    <4675, 4556, 4553>, 0,
    <4675, 4553, 4673>, 0,
    <4675, 4673, 4672>, 0,
    <4675, 4672, 4674>, 0,
    <4677, 4669, 4668>, 0,
    <4677, 4668, 4674>, 0,
    <4677, 4674, 4672>, 0,
    <4677, 4672, 4676>, 0,
    <4677, 4676, 4660>, 0,
    <4677, 4660, 4662>, 0,
    <4677, 4662, 4655>, 0,
    <4677, 4655, 4669>, 0,
    <4686, 4685, 4678>, 0,
    <4686, 4678, 4682>, 0,
    <4686, 4682, 4679>, 0,
    <4686, 4679, 4683>, 0,
    <4686, 4683, 4680>, 0,
    <4686, 4680, 4684>, 0,
    <4686, 4684, 4681>, 0,
    <4686, 4681, 4685>, 0,
    <4692, 4691, 4678>, 0,
    <4692, 4678, 4685>, 0,
    <4692, 4685, 4681>, 0,
    <4692, 4681, 4689>, 0,
    <4692, 4689, 4687>, 0,
    <4692, 4687, 4690>, 0,
    <4692, 4690, 4688>, 0,
    <4692, 4688, 4691>, 0,
    <4695, 4682, 4678>, 0,
    <4695, 4678, 4691>, 0,
    <4695, 4691, 4688>, 0,
    <4695, 4688, 4693>, 0,
    <4695, 4693, 4553>, 0,
    <4695, 4553, 4694>, 0,
    <4695, 4694, 4679>, 0,
    <4695, 4679, 4682>, 0,
    <4701, 4700, 4696>, 0,
    <4701, 4696, 4698>, 0,
    <4701, 4698, 4547>, 0,
    <4701, 4547, 4550>, 0,
    <4701, 4550, 4546>, 0,
    <4701, 4546, 4699>, 0,
    <4701, 4699, 4697>, 0,
    <4701, 4697, 4700>, 0,
    <4704, 4703, 4696>, 0,
    <4704, 4696, 4700>, 0,
    <4704, 4700, 4697>, 0,
    <4704, 4697, 4702>, 0,
    <4704, 4702, 4680>, 0,
    <4704, 4680, 4683>, 0,
    <4704, 4683, 4679>, 0,
    <4704, 4679, 4703>, 0,
    <4705, 4698, 4696>, 0,
    <4705, 4696, 4703>, 0,
    <4705, 4703, 4679>, 0,
    <4705, 4679, 4694>, 0,
    <4705, 4694, 4553>, 0,
    <4705, 4553, 4555>, 0,
    <4705, 4555, 4547>, 0,
    <4705, 4547, 4698>, 0,
    <4711, 4710, 4706>, 0,
    <4711, 4706, 4708>, 0,
    <4711, 4708, 4707>, 0,
    <4711, 4707, 4709>, 0,
    <4711, 4709, 4489>, 0,
    <4711, 4489, 4624>, 0,
    <4711, 4624, 4620>, 0,
    <4711, 4620, 4710>, 0,
    <4715, 4714, 4706>, 0,
    <4715, 4706, 4710>, 0,
    <4715, 4710, 4620>, 0,
    <4715, 4620, 4621>, 0,
    <4715, 4621, 4599>, 0,
    <4715, 4599, 4713>, 0,
    <4715, 4713, 4712>, 0,
    <4715, 4712, 4714>, 0,
    <4719, 4708, 4706>, 0,
    <4719, 4706, 4714>, 0,
    <4719, 4714, 4712>, 0,
    <4719, 4712, 4717>, 0,
    <4719, 4717, 4716>, 0,
    <4719, 4716, 4718>, 0,
    <4719, 4718, 4707>, 0,
    <4719, 4707, 4708>, 0,
    <4723, 4722, 4720>, 0,
    <4723, 4720, 4721>, 0,
    <4723, 4721, 4646>, 0,
    <4723, 4646, 4647>, 0,
    <4723, 4647, 4489>, 0,
    <4723, 4489, 4709>, 0,
    <4723, 4709, 4707>, 0,
    <4723, 4707, 4722>, 0,
    <4727, 4726, 4720>, 0,
    <4727, 4720, 4722>, 0,
    <4727, 4722, 4707>, 0,
    <4727, 4707, 4718>, 0,
    <4727, 4718, 4716>, 0,
    <4727, 4716, 4725>, 0,
    <4727, 4725, 4724>, 0,
    <4727, 4724, 4726>, 0,
    <4729, 4721, 4720>, 0,
    <4729, 4720, 4726>, 0,
    <4729, 4726, 4724>, 0,
    <4729, 4724, 4728>, 0,
    <4729, 4728, 4650>, 0,
    <4729, 4650, 4651>, 0,
    <4729, 4651, 4646>, 0,
    <4729, 4646, 4721>, 0,
    <4738, 4737, 4730>, 0,
    <4738, 4730, 4734>, 0,
    <4738, 4734, 4731>, 0,
    <4738, 4731, 4735>, 0,
    <4738, 4735, 4732>, 0,
    <4738, 4732, 4736>, 0,
    <4738, 4736, 4733>, 0,
    <4738, 4733, 4737>, 0,
    <4743, 4742, 4730>, 0,
    <4743, 4730, 4737>, 0,
    <4743, 4737, 4733>, 0,
    <4743, 4733, 4740>, 0,
    <4743, 4740, 4650>, 0,
    <4743, 4650, 4741>, 0,
    <4743, 4741, 4739>, 0,
    <4743, 4739, 4742>, 0,
    <4747, 4734, 4730>, 0,
    <4747, 4730, 4742>, 0,
    <4747, 4742, 4739>, 0,
    <4747, 4739, 4745>, 0,
    <4747, 4745, 4744>, 0,
    <4747, 4744, 4746>, 0,
    <4747, 4746, 4731>, 0,
    <4747, 4731, 4734>, 0,
    <4753, 4752, 4748>, 0,
    <4753, 4748, 4750>, 0,
    <4753, 4750, 4749>, 0,
    <4753, 4749, 4751>, 0,
    <4753, 4751, 4636>, 0,
    <4753, 4636, 4643>, 0,
    <4753, 4643, 4641>, 0,
    <4753, 4641, 4752>, 0,
    <4755, 4754, 4748>, 0,
    <4755, 4748, 4752>, 0,
    <4755, 4752, 4641>, 0,
    <4755, 4641, 4652>, 0,
    <4755, 4652, 4650>, 0,
    <4755, 4650, 4740>, 0,
    <4755, 4740, 4733>, 0,
    <4755, 4733, 4754>, 0,
    <4757, 4750, 4748>, 0,
    <4757, 4748, 4754>, 0,
    <4757, 4754, 4733>, 0,
    <4757, 4733, 4736>, 0,
    <4757, 4736, 4732>, 0,
    <4757, 4732, 4756>, 0,
    <4757, 4756, 4749>, 0,
    <4757, 4749, 4750>, 0,
    <4766, 4765, 4758>, 0,
    <4766, 4758, 4762>, 0,
    <4766, 4762, 4759>, 0,
    <4766, 4759, 4763>, 0,
    <4766, 4763, 4760>, 0,
    <4766, 4760, 4764>, 0,
    <4766, 4764, 4761>, 0,
    <4766, 4761, 4765>, 0,
    <4769, 4768, 4758>, 0,
    <4769, 4758, 4765>, 0,
    <4769, 4765, 4761>, 0,
    <4769, 4761, 4767>, 0,
    <4769, 4767, 85>, 0,
    <4769, 85, 4629>, 0,
    <4769, 4629, 4627>, 0,
    <4769, 4627, 4768>, 0,
    <4771, 4762, 4758>, 0,
    <4771, 4758, 4768>, 0,
    <4771, 4768, 4627>, 0,
    <4771, 4627, 4638>, 0,
    <4771, 4638, 4636>, 0,
    <4771, 4636, 4770>, 0,
    <4771, 4770, 4759>, 0,
    <4771, 4759, 4762>, 0,
    <4777, 4776, 4772>, 0,
    <4777, 4772, 4774>, 0,
    <4777, 4774, 4672>, 0,
    <4777, 4672, 4673>, 0,
    <4777, 4673, 4553>, 0,
    <4777, 4553, 4775>, 0,
    <4777, 4775, 4773>, 0,
    <4777, 4773, 4776>, 0,
    <4783, 4782, 4772>, 0,
    <4783, 4772, 4776>, 0,
    <4783, 4776, 4773>, 0,
    <4783, 4773, 4780>, 0,
    <4783, 4780, 4778>, 0,
    <4783, 4778, 4781>, 0,
    <4783, 4781, 4779>, 0,
    <4783, 4779, 4782>, 0,
    <4785, 4774, 4772>, 0,
    <4785, 4772, 4782>, 0,
    <4785, 4782, 4779>, 0,
    <4785, 4779, 4784>, 0,
    <4785, 4784, 4660>, 0,
    <4785, 4660, 4676>, 0,
    <4785, 4676, 4672>, 0,
    <4785, 4672, 4774>, 0,
    <4789, 4788, 4786>, 0,
    <4789, 4786, 4787>, 0,
    <4789, 4787, 4773>, 0,
    <4789, 4773, 4775>, 0,
    <4789, 4775, 4553>, 0,
    <4789, 4553, 4693>, 0,
    <4789, 4693, 4688>, 0,
    <4789, 4688, 4788>, 0,
    <4793, 4792, 4786>, 0,
    <4793, 4786, 4788>, 0,
    <4793, 4788, 4688>, 0,
    <4793, 4688, 4690>, 0,
    <4793, 4690, 4687>, 0,
    <4793, 4687, 4791>, 0,
    <4793, 4791, 4790>, 0,
    <4793, 4790, 4792>, 0,
    <4795, 4787, 4786>, 0,
    <4795, 4786, 4792>, 0,
    <4795, 4792, 4790>, 0,
    <4795, 4790, 4794>, 0,
    <4795, 4794, 4778>, 0,
    <4795, 4778, 4780>, 0,
    <4795, 4780, 4773>, 0,
    <4795, 4773, 4787>, 0,
    <4804, 4803, 4796>, 0,
    <4804, 4796, 4800>, 0,
    <4804, 4800, 4797>, 0,
    <4804, 4797, 4801>, 0,
    <4804, 4801, 4798>, 0,
    <4804, 4798, 4802>, 0,
    <4804, 4802, 4799>, 0,
    <4804, 4799, 4803>, 0,
    <4810, 4809, 4796>, 0,
    <4810, 4796, 4803>, 0,
    <4810, 4803, 4799>, 0,
    <4810, 4799, 4807>, 0,
    <4810, 4807, 4805>, 0,
    <4810, 4805, 4808>, 0,
    <4810, 4808, 4806>, 0,
    <4810, 4806, 4809>, 0,
    <4813, 4800, 4796>, 0,
    <4813, 4796, 4809>, 0,
    <4813, 4809, 4806>, 0,
    <4813, 4806, 4811>, 0,
    <4813, 4811, 4687>, 0,
    <4813, 4687, 4812>, 0,
    <4813, 4812, 4797>, 0,
    <4813, 4797, 4800>, 0,
    <4819, 4818, 4814>, 0,
    <4819, 4814, 4816>, 0,
    <4819, 4816, 4681>, 0,
    <4819, 4681, 4684>, 0,
    <4819, 4684, 4680>, 0,
    <4819, 4680, 4817>, 0,
    <4819, 4817, 4815>, 0,
    <4819, 4815, 4818>, 0,
    <4822, 4821, 4814>, 0,
    <4822, 4814, 4818>, 0,
    <4822, 4818, 4815>, 0,
    <4822, 4815, 4820>, 0,
    <4822, 4820, 4798>, 0,
    <4822, 4798, 4801>, 0,
    <4822, 4801, 4797>, 0,
    <4822, 4797, 4821>, 0,
    <4823, 4816, 4814>, 0,
    <4823, 4814, 4821>, 0,
    <4823, 4821, 4797>, 0,
    <4823, 4797, 4812>, 0,
    <4823, 4812, 4687>, 0,
    <4823, 4687, 4689>, 0,
    <4823, 4689, 4681>, 0,
    <4823, 4681, 4816>, 0,
    <4832, 4831, 4824>, 0,
    <4832, 4824, 4828>, 0,
    <4832, 4828, 4825>, 0,
    <4832, 4825, 4829>, 0,
    <4832, 4829, 4826>, 0,
    <4832, 4826, 4830>, 0,
    <4832, 4830, 4827>, 0,
    <4832, 4827, 4831>, 0,
    <4838, 4837, 4824>, 0,
    <4838, 4824, 4831>, 0,
    <4838, 4831, 4827>, 0,
    <4838, 4827, 4835>, 0,
    <4838, 4835, 4833>, 0,
    <4838, 4833, 4836>, 0,
    <4838, 4836, 4834>, 0,
    <4838, 4834, 4837>, 0,
    <4841, 4828, 4824>, 0,
    <4841, 4824, 4837>, 0,
    <4841, 4837, 4834>, 0,
    <4841, 4834, 4839>, 0,
    <4841, 4839, 180>, 0,
    <4841, 180, 4840>, 0,
    <4841, 4840, 4825>, 0,
    <4841, 4825, 4828>, 0,
    <4847, 4846, 4842>, 0,
    <4847, 4842, 4844>, 0,
    <4847, 4844, 4827>, 0,
    <4847, 4827, 4830>, 0,
    <4847, 4830, 4826>, 0,
    <4847, 4826, 4845>, 0,
    <4847, 4845, 4843>, 0,
    <4847, 4843, 4846>, 0,
    <4852, 4851, 4842>, 0,
    <4852, 4842, 4846>, 0,
    <4852, 4846, 4843>, 0,
    <4852, 4843, 4849>, 0,
    <4852, 4849, 4508>, 0,
    <4852, 4508, 4850>, 0,
    <4852, 4850, 4848>, 0,
    <4852, 4848, 4851>, 0,
    <4854, 4844, 4842>, 0,
    <4854, 4842, 4851>, 0,
    <4854, 4851, 4848>, 0,
    <4854, 4848, 4853>, 0,
    <4854, 4853, 4833>, 0,
    <4854, 4833, 4835>, 0,
    <4854, 4835, 4827>, 0,
    <4854, 4827, 4844>, 0,
    <4858, 4857, 4855>, 0,
    <4858, 4855, 4856>, 0,
    <4858, 4856, 4848>, 0,
    <4858, 4848, 4850>, 0,
    <4858, 4850, 4508>, 0,
    <4858, 4508, 4511>, 0,
    <4858, 4511, 4507>, 0,
    <4858, 4507, 4857>, 0,
    <4862, 4861, 4855>, 0,
    <4862, 4855, 4857>, 0,
    <4862, 4857, 4507>, 0,
    <4862, 4507, 4518>, 0,
    <4862, 4518, 4388>, 0,
    <4862, 4388, 4860>, 0,
    <4862, 4860, 4859>, 0,
    <4862, 4859, 4861>, 0,
    <4864, 4856, 4855>, 0,
    <4864, 4855, 4861>, 0,
    <4864, 4861, 4859>, 0,
    <4864, 4859, 4863>, 0,
    <4864, 4863, 4833>, 0,
    <4864, 4833, 4853>, 0,
    <4864, 4853, 4848>, 0,
    <4864, 4848, 4856>, 0,
    <4870, 4869, 4865>, 0,
    <4870, 4865, 4867>, 0,
    <4870, 4867, 4575>, 0,
    <4870, 4575, 4578>, 0,
    <4870, 4578, 4574>, 0,
    <4870, 4574, 4868>, 0,
    <4870, 4868, 4866>, 0,
    <4870, 4866, 4869>, 0,
    <4876, 4875, 4865>, 0,
    <4876, 4865, 4869>, 0,
    <4876, 4869, 4866>, 0,
    <4876, 4866, 4873>, 0,
    <4876, 4873, 4871>, 0,
    <4876, 4871, 4874>, 0,
    <4876, 4874, 4872>, 0,
    <4876, 4872, 4875>, 0,
    <4878, 4867, 4865>, 0,
    <4878, 4865, 4875>, 0,
    <4878, 4875, 4872>, 0,
    <4878, 4872, 4877>, 0,
    <4878, 4877, 4426>, 0,
    <4878, 4426, 4581>, 0,
    <4878, 4581, 4575>, 0,
    <4878, 4575, 4867>, 0,
    <4884, 4883, 4879>, 0,
    <4884, 4879, 4881>, 0,
    <4884, 4881, 4866>, 0,
    <4884, 4866, 4868>, 0,
    <4884, 4868, 4574>, 0,
    <4884, 4574, 4882>, 0,
    <4884, 4882, 4880>, 0,
    <4884, 4880, 4883>, 0,
    <4890, 4889, 4879>, 0,
    <4890, 4879, 4883>, 0,
    <4890, 4883, 4880>, 0,
    <4890, 4880, 4887>, 0,
    <4890, 4887, 4885>, 0,
    <4890, 4885, 4888>, 0,
    <4890, 4888, 4886>, 0,
    <4890, 4886, 4889>, 0,
    <4892, 4881, 4879>, 0,
    <4892, 4879, 4889>, 0,
    <4892, 4889, 4886>, 0,
    <4892, 4886, 4891>, 0,
    <4892, 4891, 4871>, 0,
    <4892, 4871, 4873>, 0,
    <4892, 4873, 4866>, 0,
    <4892, 4866, 4881>, 0,
    <4898, 4897, 4893>, 0,
    <4898, 4893, 4895>, 0,
    <4898, 4895, 4872>, 0,
    <4898, 4872, 4874>, 0,
    <4898, 4874, 4871>, 0,
    <4898, 4871, 4896>, 0,
    <4898, 4896, 4894>, 0,
    <4898, 4894, 4897>, 0,
    <4901, 4900, 4893>, 0,
    <4901, 4893, 4897>, 0,
    <4901, 4897, 4894>, 0,
    <4901, 4894, 4899>, 0,
    <4901, 4899, 4546>, 0,
    <4901, 4546, 4568>, 0,
    <4901, 4568, 4563>, 0,
    <4901, 4563, 4900>, 0,
    <4902, 4895, 4893>, 0,
    <4902, 4893, 4900>, 0,
    <4902, 4900, 4563>, 0,
    <4902, 4563, 4565>, 0,
    <4902, 4565, 4426>, 0,
    <4902, 4426, 4877>, 0,
    <4902, 4877, 4872>, 0,
    <4902, 4872, 4895>, 0,
    <4908, 4907, 4903>, 0,
    <4908, 4903, 4905>, 0,
    <4908, 4905, 4886>, 0,
    <4908, 4886, 4888>, 0,
    <4908, 4888, 4885>, 0,
    <4908, 4885, 4906>, 0,
    <4908, 4906, 4904>, 0,
    <4908, 4904, 4907>, 0,
    <4913, 4912, 4903>, 0,
    <4913, 4903, 4907>, 0,
    <4913, 4907, 4904>, 0,
    <4913, 4904, 4910>, 0,
    <4913, 4910, 230>, 0,
    <4913, 230, 4911>, 0,
    <4913, 4911, 4909>, 0,
    <4913, 4909, 4912>, 0,
    <4915, 4905, 4903>, 0,
    <4915, 4903, 4912>, 0,
    <4915, 4912, 4909>, 0,
    <4915, 4909, 4914>, 0,
    <4915, 4914, 4871>, 0,
    <4915, 4871, 4891>, 0,
    <4915, 4891, 4886>, 0,
    <4915, 4886, 4905>, 0,
    <4921, 4920, 4916>, 0,
    <4921, 4916, 4918>, 0,
    <4921, 4918, 4917>, 0,
    <4921, 4917, 4919>, 0,
    <4921, 4919, 4650>, 0,
    <4921, 4650, 4728>, 0,
    <4921, 4728, 4724>, 0,
    <4921, 4724, 4920>, 0,
    <4925, 4924, 4916>, 0,
    <4925, 4916, 4920>, 0,
    <4925, 4920, 4724>, 0,
    <4925, 4724, 4725>, 0,
    <4925, 4725, 4716>, 0,
    <4925, 4716, 4923>, 0,
    <4925, 4923, 4922>, 0,
    <4925, 4922, 4924>, 0,
    <4929, 4918, 4916>, 0,
    <4929, 4916, 4924>, 0,
    <4929, 4924, 4922>, 0,
    <4929, 4922, 4927>, 0,
    <4929, 4927, 4926>, 0,
    <4929, 4926, 4928>, 0,
    <4929, 4928, 4917>, 0,
    <4929, 4917, 4918>, 0,
    <4933, 4932, 4930>, 0,
    <4933, 4930, 4931>, 0,
    <4933, 4931, 4739>, 0,
    <4933, 4739, 4741>, 0,
    <4933, 4741, 4650>, 0,
    <4933, 4650, 4919>, 0,
    <4933, 4919, 4917>, 0,
    <4933, 4917, 4932>, 0,
    <4937, 4936, 4930>, 0,
    <4937, 4930, 4932>, 0,
    <4937, 4932, 4917>, 0,
    <4937, 4917, 4928>, 0,
    <4937, 4928, 4926>, 0,
    <4937, 4926, 4935>, 0,
    <4937, 4935, 4934>, 0,
    <4937, 4934, 4936>, 0,
    <4939, 4931, 4930>, 0,
    <4939, 4930, 4936>, 0,
    <4939, 4936, 4934>, 0,
    <4939, 4934, 4938>, 0,
    <4939, 4938, 4744>, 0,
    <4939, 4744, 4745>, 0,
    <4939, 4745, 4739>, 0,
    <4939, 4739, 4931>, 0,
    <4948, 4947, 4940>, 0,
    <4948, 4940, 4944>, 0,
    <4948, 4944, 4941>, 0,
    <4948, 4941, 4945>, 0,
    <4948, 4945, 4942>, 0,
    <4948, 4942, 4946>, 0,
    <4948, 4946, 4943>, 0,
    <4948, 4943, 4947>, 0,
    <4953, 4952, 4940>, 0,
    <4953, 4940, 4947>, 0,
    <4953, 4947, 4943>, 0,
    <4953, 4943, 4950>, 0,
    <4953, 4950, 4744>, 0,
    <4953, 4744, 4951>, 0,
    <4953, 4951, 4949>, 0,
    <4953, 4949, 4952>, 0,
    <4957, 4944, 4940>, 0,
    <4957, 4940, 4952>, 0,
    <4957, 4952, 4949>, 0,
    <4957, 4949, 4955>, 0,
    <4957, 4955, 4954>, 0,
    <4957, 4954, 4956>, 0,
    <4957, 4956, 4941>, 0,
    <4957, 4941, 4944>, 0,
    <4963, 4962, 4958>, 0,
    <4963, 4958, 4960>, 0,
    <4963, 4960, 4959>, 0,
    <4963, 4959, 4961>, 0,
    <4963, 4961, 4732>, 0,
    <4963, 4732, 4735>, 0,
    <4963, 4735, 4731>, 0,
    <4963, 4731, 4962>, 0,
    <4965, 4964, 4958>, 0,
    <4965, 4958, 4962>, 0,
    <4965, 4962, 4731>, 0,
    <4965, 4731, 4746>, 0,
    <4965, 4746, 4744>, 0,
    <4965, 4744, 4950>, 0,
    <4965, 4950, 4943>, 0,
    <4965, 4943, 4964>, 0,
    <4967, 4960, 4958>, 0,
    <4967, 4958, 4964>, 0,
    <4967, 4964, 4943>, 0,
    <4967, 4943, 4946>, 0,
    <4967, 4946, 4942>, 0,
    <4967, 4942, 4966>, 0,
    <4967, 4966, 4959>, 0,
    <4967, 4959, 4960>, 0,
    <4973, 4972, 4968>, 0,
    <4973, 4968, 4970>, 0,
    <4973, 4970, 4790>, 0,
    <4973, 4790, 4791>, 0,
    <4973, 4791, 4687>, 0,
    <4973, 4687, 4971>, 0,
    <4973, 4971, 4969>, 0,
    <4973, 4969, 4972>, 0,
    <4979, 4978, 4968>, 0,
    <4979, 4968, 4972>, 0,
    <4979, 4972, 4969>, 0,
    <4979, 4969, 4976>, 0,
    <4979, 4976, 4974>, 0,
    <4979, 4974, 4977>, 0,
    <4979, 4977, 4975>, 0,
    <4979, 4975, 4978>, 0,
    <4981, 4970, 4968>, 0,
    <4981, 4968, 4978>, 0,
    <4981, 4978, 4975>, 0,
    <4981, 4975, 4980>, 0,
    <4981, 4980, 4778>, 0,
    <4981, 4778, 4794>, 0,
    <4981, 4794, 4790>, 0,
    <4981, 4790, 4970>, 0,
    <4985, 4984, 4982>, 0,
    <4985, 4982, 4983>, 0,
    <4985, 4983, 4969>, 0,
    <4985, 4969, 4971>, 0,
    <4985, 4971, 4687>, 0,
    <4985, 4687, 4811>, 0,
    <4985, 4811, 4806>, 0,
    <4985, 4806, 4984>, 0,
    <4989, 4988, 4982>, 0,
    <4989, 4982, 4984>, 0,
    <4989, 4984, 4806>, 0,
    <4989, 4806, 4808>, 0,
    <4989, 4808, 4805>, 0,
    <4989, 4805, 4987>, 0,
    <4989, 4987, 4986>, 0,
    <4989, 4986, 4988>, 0,
    <4991, 4983, 4982>, 0,
    <4991, 4982, 4988>, 0,
    <4991, 4988, 4986>, 0,
    <4991, 4986, 4990>, 0,
    <4991, 4990, 4974>, 0,
    <4991, 4974, 4976>, 0,
    <4991, 4976, 4969>, 0,
    <4991, 4969, 4983>, 0,
    <5000, 4999, 4992>, 0,
    <5000, 4992, 4996>, 0,
    <5000, 4996, 4993>, 0,
    <5000, 4993, 4997>, 0,
    <5000, 4997, 4994>, 0,
    <5000, 4994, 4998>, 0,
    <5000, 4998, 4995>, 0,
    <5000, 4995, 4999>, 0,
    <5006, 5005, 4992>, 0,
    <5006, 4992, 4999>, 0,
    <5006, 4999, 4995>, 0,
    <5006, 4995, 5003>, 0,
    <5006, 5003, 5001>, 0,
    <5006, 5001, 5004>, 0,
    <5006, 5004, 5002>, 0,
    <5006, 5002, 5005>, 0,
    <5009, 4996, 4992>, 0,
    <5009, 4992, 5005>, 0,
    <5009, 5005, 5002>, 0,
    <5009, 5002, 5007>, 0,
    <5009, 5007, 4805>, 0,
    <5009, 4805, 5008>, 0,
    <5009, 5008, 4993>, 0,
    <5009, 4993, 4996>, 0,
    <5015, 5014, 5010>, 0,
    <5015, 5010, 5012>, 0,
    <5015, 5012, 4799>, 0,
    <5015, 4799, 4802>, 0,
    <5015, 4802, 4798>, 0,
    <5015, 4798, 5013>, 0,
    <5015, 5013, 5011>, 0,
    <5015, 5011, 5014>, 0,
    <5018, 5017, 5010>, 0,
    <5018, 5010, 5014>, 0,
    <5018, 5014, 5011>, 0,
    <5018, 5011, 5016>, 0,
    <5018, 5016, 4994>, 0,
    <5018, 4994, 4997>, 0,
    <5018, 4997, 4993>, 0,
    <5018, 4993, 5017>, 0,
    <5019, 5012, 5010>, 0,
    <5019, 5010, 5017>, 0,
    <5019, 5017, 4993>, 0,
    <5019, 4993, 5008>, 0,
    <5019, 5008, 4805>, 0,
    <5019, 4805, 4807>, 0,
    <5019, 4807, 4799>, 0,
    <5019, 4799, 5012>, 0,
    <5027, 5026, 5020>, 0,
    <5027, 5020, 5023>, 0,
    <5027, 5023, 5021>, 0,
    <5027, 5021, 5024>, 0,
    <5027, 5024, 216>, 0,
    <5027, 216, 5025>, 0,
    <5027, 5025, 5022>, 0,
    <5027, 5022, 5026>, 0,
    <5030, 5029, 5020>, 0,
    <5030, 5020, 5026>, 0,
    <5030, 5026, 5022>, 0,
    <5030, 5022, 5028>, 0,
    <5030, 5028, 4760>, 0,
    <5030, 4760, 4763>, 0,
    <5030, 4763, 4759>, 0,
    <5030, 4759, 5029>, 0,
    <5032, 5023, 5020>, 0,
    <5032, 5020, 5029>, 0,
    <5032, 5029, 4759>, 0,
    <5032, 4759, 4770>, 0,
    <5032, 4770, 4636>, 0,
    <5032, 4636, 5031>, 0,
    <5032, 5031, 5021>, 0,
    <5032, 5021, 5023>, 0,
    <5038, 5037, 5033>, 0,
    <5038, 5033, 5035>, 0,
    <5038, 5035, 4986>, 0,
    <5038, 4986, 4987>, 0,
    <5038, 4987, 4805>, 0,
    <5038, 4805, 5036>, 0,
    <5038, 5036, 5034>, 0,
    <5038, 5034, 5037>, 0,
    <5044, 5043, 5033>, 0,
    <5044, 5033, 5037>, 0,
    <5044, 5037, 5034>, 0,
    <5044, 5034, 5041>, 0,
    <5044, 5041, 5039>, 0,
    <5044, 5039, 5042>, 0,
    <5044, 5042, 5040>, 0,
    <5044, 5040, 5043>, 0,
    <5046, 5035, 5033>, 0,
    <5046, 5033, 5043>, 0,
    <5046, 5043, 5040>, 0,
    <5046, 5040, 5045>, 0,
    <5046, 5045, 4974>, 0,
    <5046, 4974, 4990>, 0,
    <5046, 4990, 4986>, 0,
    <5046, 4986, 5035>, 0,
    <5050, 5049, 5047>, 0,
    <5050, 5047, 5048>, 0,
    <5050, 5048, 5034>, 0,
    <5050, 5034, 5036>, 0,
    <5050, 5036, 4805>, 0,
    <5050, 4805, 5007>, 0,
    <5050, 5007, 5002>, 0,
    <5050, 5002, 5049>, 0,
    <5054, 5053, 5047>, 0,
    <5054, 5047, 5049>, 0,
    <5054, 5049, 5002>, 0,
    <5054, 5002, 5004>, 0,
    <5054, 5004, 5001>, 0,
    <5054, 5001, 5052>, 0,
    <5054, 5052, 5051>, 0,
    <5054, 5051, 5053>, 0,
    <5056, 5048, 5047>, 0,
    <5056, 5047, 5053>, 0,
    <5056, 5053, 5051>, 0,
    <5056, 5051, 5055>, 0,
    <5056, 5055, 5039>, 0,
    <5056, 5039, 5041>, 0,
    <5056, 5041, 5034>, 0,
    <5056, 5034, 5048>, 0,
    <5065, 5064, 5057>, 0,
    <5065, 5057, 5061>, 0,
    <5065, 5061, 5058>, 0,
    <5065, 5058, 5062>, 0,
    <5065, 5062, 5059>, 0,
    <5065, 5059, 5063>, 0,
    <5065, 5063, 5060>, 0,
    <5065, 5060, 5064>, 0,
    <5071, 5070, 5057>, 0,
    <5071, 5057, 5064>, 0,
    <5071, 5064, 5060>, 0,
    <5071, 5060, 5068>, 0,
    <5071, 5068, 5066>, 0,
    <5071, 5066, 5069>, 0,
    <5071, 5069, 5067>, 0,
    <5071, 5067, 5070>, 0,
    <5074, 5061, 5057>, 0,
    <5074, 5057, 5070>, 0,
    <5074, 5070, 5067>, 0,
    <5074, 5067, 5072>, 0,
    <5074, 5072, 5001>, 0,
    <5074, 5001, 5073>, 0,
    <5074, 5073, 5058>, 0,
    <5074, 5058, 5061>, 0,
    <5080, 5079, 5075>, 0,
    <5080, 5075, 5077>, 0,
    <5080, 5077, 4995>, 0,
    <5080, 4995, 4998>, 0,
    <5080, 4998, 4994>, 0,
    <5080, 4994, 5078>, 0,
    <5080, 5078, 5076>, 0,
    <5080, 5076, 5079>, 0,
    <5083, 5082, 5075>, 0,
    <5083, 5075, 5079>, 0,
    <5083, 5079, 5076>, 0,
    <5083, 5076, 5081>, 0,
    <5083, 5081, 5059>, 0,
    <5083, 5059, 5062>, 0,
    <5083, 5062, 5058>, 0,
    <5083, 5058, 5082>, 0,
    <5084, 5077, 5075>, 0,
    <5084, 5075, 5082>, 0,
    <5084, 5082, 5058>, 0,
    <5084, 5058, 5073>, 0,
    <5084, 5073, 5001>, 0,
    <5084, 5001, 5003>, 0,
    <5084, 5003, 4995>, 0,
    <5084, 4995, 5077>, 0,
    <5090, 5089, 5085>, 0,
    <5090, 5085, 5087>, 0,
    <5090, 5087, 5086>, 0,
    <5090, 5086, 5088>, 0,
    <5090, 5088, 4744>, 0,
    <5090, 4744, 4938>, 0,
    <5090, 4938, 4934>, 0,
    <5090, 4934, 5089>, 0,
    <5094, 5093, 5085>, 0,
    <5094, 5085, 5089>, 0,
    <5094, 5089, 4934>, 0,
    <5094, 4934, 4935>, 0,
    <5094, 4935, 4926>, 0,
    <5094, 4926, 5092>, 0,
    <5094, 5092, 5091>, 0,
    <5094, 5091, 5093>, 0,
    <5098, 5087, 5085>, 0,
    <5098, 5085, 5093>, 0,
    <5098, 5093, 5091>, 0,
    <5098, 5091, 5096>, 0,
    <5098, 5096, 5095>, 0,
    <5098, 5095, 5097>, 0,
    <5098, 5097, 5086>, 0,
    <5098, 5086, 5087>, 0,
    <5102, 5101, 5099>, 0,
    <5102, 5099, 5100>, 0,
    <5102, 5100, 4949>, 0,
    <5102, 4949, 4951>, 0,
    <5102, 4951, 4744>, 0,
    <5102, 4744, 5088>, 0,
    <5102, 5088, 5086>, 0,
    <5102, 5086, 5101>, 0,
    <5106, 5105, 5099>, 0,
    <5106, 5099, 5101>, 0,
    <5106, 5101, 5086>, 0,
    <5106, 5086, 5097>, 0,
    <5106, 5097, 5095>, 0,
    <5106, 5095, 5104>, 0,
    <5106, 5104, 5103>, 0,
    <5106, 5103, 5105>, 0,
    <5108, 5100, 5099>, 0,
    <5108, 5099, 5105>, 0,
    <5108, 5105, 5103>, 0,
    <5108, 5103, 5107>, 0,
    <5108, 5107, 4954>, 0,
    <5108, 4954, 4955>, 0,
    <5108, 4955, 4949>, 0,
    <5108, 4949, 5100>, 0,
    <5117, 5116, 5109>, 0,
    <5117, 5109, 5113>, 0,
    <5117, 5113, 5110>, 0,
    <5117, 5110, 5114>, 0,
    <5117, 5114, 5111>, 0,
    <5117, 5111, 5115>, 0,
    <5117, 5115, 5112>, 0,
    <5117, 5112, 5116>, 0,
    <5122, 5121, 5109>, 0,
    <5122, 5109, 5116>, 0,
    <5122, 5116, 5112>, 0,
    <5122, 5112, 5119>, 0,
    <5122, 5119, 4954>, 0,
    <5122, 4954, 5120>, 0,
    <5122, 5120, 5118>, 0,
    <5122, 5118, 5121>, 0,
    <5126, 5113, 5109>, 0,
    <5126, 5109, 5121>, 0,
    <5126, 5121, 5118>, 0,
    <5126, 5118, 5124>, 0,
    <5126, 5124, 5123>, 0,
    <5126, 5123, 5125>, 0,
    <5126, 5125, 5110>, 0,
    <5126, 5110, 5113>, 0,
    <5132, 5131, 5127>, 0,
    <5132, 5127, 5129>, 0,
    <5132, 5129, 5128>, 0,
    <5132, 5128, 5130>, 0,
    <5132, 5130, 4942>, 0,
    <5132, 4942, 4945>, 0,
    <5132, 4945, 4941>, 0,
    <5132, 4941, 5131>, 0,
    <5134, 5133, 5127>, 0,
    <5134, 5127, 5131>, 0,
    <5134, 5131, 4941>, 0,
    <5134, 4941, 4956>, 0,
    <5134, 4956, 4954>, 0,
    <5134, 4954, 5119>, 0,
    <5134, 5119, 5112>, 0,
    <5134, 5112, 5133>, 0,
    <5136, 5129, 5127>, 0,
    <5136, 5127, 5133>, 0,
    <5136, 5133, 5112>, 0,
    <5136, 5112, 5115>, 0,
    <5136, 5115, 5111>, 0,
    <5136, 5111, 5135>, 0,
    <5136, 5135, 5128>, 0,
    <5136, 5128, 5129>, 0,
    <5142, 5141, 5137>, 0,
    <5142, 5137, 5139>, 0,
    <5142, 5139, 4859>, 0,
    <5142, 4859, 4860>, 0,
    <5142, 4860, 4388>, 0,
    <5142, 4388, 5140>, 0,
    <5142, 5140, 5138>, 0,
    <5142, 5138, 5141>, 0,
    <5148, 5147, 5137>, 0,
    <5148, 5137, 5141>, 0,
    <5148, 5141, 5138>, 0,
    <5148, 5138, 5145>, 0,
    <5148, 5145, 5143>, 0,
    <5148, 5143, 5146>, 0,
    <5148, 5146, 5144>, 0,
    <5148, 5144, 5147>, 0,
    <5150, 5139, 5137>, 0,
    <5150, 5137, 5147>, 0,
    <5150, 5147, 5144>, 0,
    <5150, 5144, 5149>, 0,
    <5150, 5149, 4833>, 0,
    <5150, 4833, 4863>, 0,
    <5150, 4863, 4859>, 0,
    <5150, 4859, 5139>, 0,
    <5154, 5153, 5151>, 0,
    <5154, 5151, 5152>, 0,
    <5154, 5152, 5138>, 0,
    <5154, 5138, 5140>, 0,
    <5154, 5140, 4388>, 0,
    <5154, 4388, 4532>, 0,
    <5154, 4532, 4527>, 0,
    <5154, 4527, 5153>, 0,
    <5158, 5157, 5151>, 0,
    <5158, 5151, 5153>, 0,
    <5158, 5153, 4527>, 0,
    <5158, 4527, 4529>, 0,
    <5158, 4529, 4526>, 0,
    <5158, 4526, 5156>, 0,
    <5158, 5156, 5155>, 0,
    <5158, 5155, 5157>, 0,
    <5160, 5152, 5151>, 0,
    <5160, 5151, 5157>, 0,
    <5160, 5157, 5155>, 0,
    <5160, 5155, 5159>, 0,
    <5160, 5159, 5143>, 0,
    <5160, 5143, 5145>, 0,
    <5160, 5145, 5138>, 0,
    <5160, 5138, 5152>, 0,
    <5169, 5168, 5161>, 0,
    <5169, 5161, 5165>, 0,
    <5169, 5165, 5162>, 0,
    <5169, 5162, 5166>, 0,
    <5169, 5166, 5163>, 0,
    <5169, 5163, 5167>, 0,
    <5169, 5167, 5164>, 0,
    <5169, 5164, 5168>, 0,
    <5172, 5171, 5161>, 0,
    <5172, 5161, 5168>, 0,
    <5172, 5168, 5164>, 0,
    <5172, 5164, 5170>, 0,
    <5172, 5170, 4680>, 0,
    <5172, 4680, 4702>, 0,
    <5172, 4702, 4697>, 0,
    <5172, 4697, 5171>, 0,
    <5174, 5165, 5161>, 0,
    <5174, 5161, 5171>, 0,
    <5174, 5171, 4697>, 0,
    <5174, 4697, 4699>, 0,
    <5174, 4699, 4546>, 0,
    <5174, 4546, 5173>, 0,
    <5174, 5173, 5162>, 0,
    <5174, 5162, 5165>, 0,
    <5180, 5179, 5175>, 0,
    <5180, 5175, 5177>, 0,
    <5180, 5177, 4894>, 0,
    <5180, 4894, 4896>, 0,
    <5180, 4896, 4871>, 0,
    <5180, 4871, 5178>, 0,
    <5180, 5178, 5176>, 0,
    <5180, 5176, 5179>, 0,
    <5183, 5182, 5175>, 0,
    <5183, 5175, 5179>, 0,
    <5183, 5179, 5176>, 0,
    <5183, 5176, 5181>, 0,
    <5183, 5181, 5163>, 0,
    <5183, 5163, 5166>, 0,
    <5183, 5166, 5162>, 0,
    <5183, 5162, 5182>, 0,
    <5184, 5177, 5175>, 0,
    <5184, 5175, 5182>, 0,
    <5184, 5182, 5162>, 0,
    <5184, 5162, 5173>, 0,
    <5184, 5173, 4546>, 0,
    <5184, 4546, 4899>, 0,
    <5184, 4899, 4894>, 0,
    <5184, 4894, 5177>, 0,
    <5190, 5189, 5185>, 0,
    <5190, 5185, 5187>, 0,
    <5190, 5187, 5051>, 0,
    <5190, 5051, 5052>, 0,
    <5190, 5052, 5001>, 0,
    <5190, 5001, 5188>, 0,
    <5190, 5188, 5186>, 0,
    <5190, 5186, 5189>, 0,
    <5196, 5195, 5185>, 0,
    <5196, 5185, 5189>, 0,
    <5196, 5189, 5186>, 0,
    <5196, 5186, 5193>, 0,
    <5196, 5193, 5191>, 0,
    <5196, 5191, 5194>, 0,
    <5196, 5194, 5192>, 0,
    <5196, 5192, 5195>, 0,
    <5198, 5187, 5185>, 0,
    <5198, 5185, 5195>, 0,
    <5198, 5195, 5192>, 0,
    <5198, 5192, 5197>, 0,
    <5198, 5197, 5039>, 0,
    <5198, 5039, 5055>, 0,
    <5198, 5055, 5051>, 0,
    <5198, 5051, 5187>, 0,
    <5202, 5201, 5199>, 0,
    <5202, 5199, 5200>, 0,
    <5202, 5200, 5186>, 0,
    <5202, 5186, 5188>, 0,
    <5202, 5188, 5001>, 0,
    <5202, 5001, 5072>, 0,
    <5202, 5072, 5067>, 0,
    <5202, 5067, 5201>, 0,
    <5206, 5205, 5199>, 0,
    <5206, 5199, 5201>, 0,
    <5206, 5201, 5067>, 0,
    <5206, 5067, 5069>, 0,
    <5206, 5069, 5066>, 0,
    <5206, 5066, 5204>, 0,
    <5206, 5204, 5203>, 0,
    <5206, 5203, 5205>, 0,
    <5208, 5200, 5199>, 0,
    <5208, 5199, 5205>, 0,
    <5208, 5205, 5203>, 0,
    <5208, 5203, 5207>, 0,
    <5208, 5207, 5191>, 0,
    <5208, 5191, 5193>, 0,
    <5208, 5193, 5186>, 0,
    <5208, 5186, 5200>, 0,
    <5217, 5216, 5209>, 0,
    <5217, 5209, 5213>, 0,
    <5217, 5213, 5210>, 0,
    <5217, 5210, 5214>, 0,
    <5217, 5214, 5211>, 0,
    <5217, 5211, 5215>, 0,
    <5217, 5215, 5212>, 0,
    <5217, 5212, 5216>, 0,
    <5222, 5221, 5209>, 0,
    <5222, 5209, 5216>, 0,
    <5222, 5216, 5212>, 0,
    <5222, 5212, 5219>, 0,
    <5222, 5219, 274>, 0,
    <5222, 274, 5220>, 0,
    <5222, 5220, 5218>, 0,
    <5222, 5218, 5221>, 0,
    <5225, 5213, 5209>, 0,
    <5225, 5209, 5221>, 0,
    <5225, 5221, 5218>, 0,
    <5225, 5218, 5223>, 0,
    <5225, 5223, 5066>, 0,
    <5225, 5066, 5224>, 0,
    <5225, 5224, 5210>, 0,
    <5225, 5210, 5213>, 0,
    <5231, 5230, 5226>, 0,
    <5231, 5226, 5228>, 0,
    <5231, 5228, 5060>, 0,
    <5231, 5060, 5063>, 0,
    <5231, 5063, 5059>, 0,
    <5231, 5059, 5229>, 0,
    <5231, 5229, 5227>, 0,
    <5231, 5227, 5230>, 0,
    <5234, 5233, 5226>, 0,
    <5234, 5226, 5230>, 0,
    <5234, 5230, 5227>, 0,
    <5234, 5227, 5232>, 0,
    <5234, 5232, 5211>, 0,
    <5234, 5211, 5214>, 0,
    <5234, 5214, 5210>, 0,
    <5234, 5210, 5233>, 0,
    <5235, 5228, 5226>, 0,
    <5235, 5226, 5233>, 0,
    <5235, 5233, 5210>, 0,
    <5235, 5210, 5224>, 0,
    <5235, 5224, 5066>, 0,
    <5235, 5066, 5068>, 0,
    <5235, 5068, 5060>, 0,
    <5235, 5060, 5228>, 0,
    <5241, 5240, 5236>, 0,
    <5241, 5236, 5238>, 0,
    <5241, 5238, 5203>, 0,
    <5241, 5203, 5204>, 0,
    <5241, 5204, 5066>, 0,
    <5241, 5066, 5239>, 0,
    <5241, 5239, 5237>, 0,
    <5241, 5237, 5240>, 0,
    <5246, 5245, 5236>, 0,
    <5246, 5236, 5240>, 0,
    <5246, 5240, 5237>, 0,
    <5246, 5237, 5243>, 0,
    <5246, 5243, 354>, 0,
    <5246, 354, 5244>, 0,
    <5246, 5244, 5242>, 0,
    <5246, 5242, 5245>, 0,
    <5248, 5238, 5236>, 0,
    <5248, 5236, 5245>, 0,
    <5248, 5245, 5242>, 0,
    <5248, 5242, 5247>, 0,
    <5248, 5247, 5191>, 0,
    <5248, 5191, 5207>, 0,
    <5248, 5207, 5203>, 0,
    <5248, 5203, 5238>, 0,
    <5252, 5251, 5249>, 0,
    <5252, 5249, 5250>, 0,
    <5252, 5250, 5237>, 0,
    <5252, 5237, 5239>, 0,
    <5252, 5239, 5066>, 0,
    <5252, 5066, 5223>, 0,
    <5252, 5223, 5218>, 0,
    <5252, 5218, 5251>, 0,
    <5256, 5255, 5249>, 0,
    <5256, 5249, 5251>, 0,
    <5256, 5251, 5218>, 0,
    <5256, 5218, 5220>, 0,
    <5256, 5220, 274>, 0,
    <5256, 274, 5254>, 0,
    <5256, 5254, 5253>, 0,
    <5256, 5253, 5255>, 0,
    <5258, 5250, 5249>, 0,
    <5258, 5249, 5255>, 0,
    <5258, 5255, 5253>, 0,
    <5258, 5253, 5257>, 0,
    <5258, 5257, 354>, 0,
    <5258, 354, 5243>, 0,
    <5258, 5243, 5237>, 0,
    <5258, 5237, 5250>, 0,
    <5264, 5263, 5259>, 0,
    <5264, 5259, 5261>, 0,
    <5264, 5261, 5212>, 0,
    <5264, 5212, 5215>, 0,
    <5264, 5215, 5211>, 0,
    <5264, 5211, 5262>, 0,
    <5264, 5262, 5260>, 0,
    <5264, 5260, 5263>, 0,
    <5269, 5268, 5259>, 0,
    <5269, 5259, 5263>, 0,
    <5269, 5263, 5260>, 0,
    <5269, 5260, 5266>, 0,
    <5269, 5266, 384>, 0,
    <5269, 384, 5267>, 0,
    <5269, 5267, 5265>, 0,
    <5269, 5265, 5268>, 0,
    <5271, 5261, 5259>, 0,
    <5271, 5259, 5268>, 0,
    <5271, 5268, 5265>, 0,
    <5271, 5265, 5270>, 0,
    <5271, 5270, 274>, 0,
    <5271, 274, 5219>, 0,
    <5271, 5219, 5212>, 0,
    <5271, 5212, 5261>, 0,
    <5279, 5278, 5272>, 0,
    <5279, 5272, 5275>, 0,
    <5279, 5275, 5273>, 0,
    <5279, 5273, 5276>, 0,
    <5279, 5276, 261>, 0,
    <5279, 261, 5277>, 0,
    <5279, 5277, 5274>, 0,
    <5279, 5274, 5278>, 0,
    <5284, 5283, 5272>, 0,
    <5284, 5272, 5278>, 0,
    <5284, 5278, 5274>, 0,
    <5284, 5274, 5281>, 0,
    <5284, 5281, 187>, 0,
    <5284, 187, 5282>, 0,
    <5284, 5282, 5280>, 0,
    <5284, 5280, 5283>, 0,
    <5288, 5275, 5272>, 0,
    <5288, 5272, 5283>, 0,
    <5288, 5283, 5280>, 0,
    <5288, 5280, 5286>, 0,
    <5288, 5286, 5285>, 0,
    <5288, 5285, 5287>, 0,
    <5288, 5287, 5273>, 0,
    <5288, 5273, 5275>, 0,
    <5296, 5295, 5289>, 0,
    <5296, 5289, 5292>, 0,
    <5296, 5292, 5290>, 0,
    <5296, 5290, 5293>, 0,
    <5296, 5293, 56>, 0,
    <5296, 56, 5294>, 0,
    <5296, 5294, 5291>, 0,
    <5296, 5291, 5295>, 0,
    <5299, 5298, 5289>, 0,
    <5299, 5289, 5295>, 0,
    <5299, 5295, 5291>, 0,
    <5299, 5291, 5297>, 0,
    <5299, 5297, 261>, 0,
    <5299, 261, 5276>, 0,
    <5299, 5276, 5273>, 0,
    <5299, 5273, 5298>, 0,
    <5301, 5292, 5289>, 0,
    <5301, 5289, 5298>, 0,
    <5301, 5298, 5273>, 0,
    <5301, 5273, 5287>, 0,
    <5301, 5287, 5285>, 0,
    <5301, 5285, 5300>, 0,
    <5301, 5300, 5290>, 0,
    <5301, 5290, 5292>, 0,
    <5305, 5304, 5302>, 0,
    <5305, 5302, 5303>, 0,
    <5305, 5303, 4594>, 0,
    <5305, 4594, 4596>, 0,
    <5305, 4596, 56>, 0,
    <5305, 56, 5293>, 0,
    <5305, 5293, 5290>, 0,
    <5305, 5290, 5304>, 0,
    <5309, 5308, 5302>, 0,
    <5309, 5302, 5304>, 0,
    <5309, 5304, 5290>, 0,
    <5309, 5290, 5300>, 0,
    <5309, 5300, 5285>, 0,
    <5309, 5285, 5307>, 0,
    <5309, 5307, 5306>, 0,
    <5309, 5306, 5308>, 0,
    <5311, 5303, 5302>, 0,
    <5311, 5302, 5308>, 0,
    <5311, 5308, 5306>, 0,
    <5311, 5306, 5310>, 0,
    <5311, 5310, 4599>, 0,
    <5311, 4599, 4600>, 0,
    <5311, 4600, 4594>, 0,
    <5311, 4594, 5303>, 0,
    <5320, 5319, 5312>, 0,
    <5320, 5312, 5316>, 0,
    <5320, 5316, 5313>, 0,
    <5320, 5313, 5317>, 0,
    <5320, 5317, 5314>, 0,
    <5320, 5314, 5318>, 0,
    <5320, 5318, 5315>, 0,
    <5320, 5315, 5319>, 0,
    <5323, 5322, 5312>, 0,
    <5323, 5312, 5319>, 0,
    <5323, 5319, 5315>, 0,
    <5323, 5315, 5321>, 0,
    <5323, 5321, 4636>, 0,
    <5323, 4636, 4751>, 0,
    <5323, 4751, 4749>, 0,
    <5323, 4749, 5322>, 0,
    <5325, 5316, 5312>, 0,
    <5325, 5312, 5322>, 0,
    <5325, 5322, 4749>, 0,
    <5325, 4749, 4756>, 0,
    <5325, 4756, 4732>, 0,
    <5325, 4732, 5324>, 0,
    <5325, 5324, 5313>, 0,
    <5325, 5313, 5316>, 0,
    <5331, 5330, 5326>, 0,
    <5331, 5326, 5328>, 0,
    <5331, 5328, 5327>, 0,
    <5331, 5327, 5329>, 0,
    <5331, 5329, 216>, 0,
    <5331, 216, 5024>, 0,
    <5331, 5024, 5021>, 0,
    <5331, 5021, 5330>, 0,
    <5333, 5332, 5326>, 0,
    <5333, 5326, 5330>, 0,
    <5333, 5330, 5021>, 0,
    <5333, 5021, 5031>, 0,
    <5333, 5031, 4636>, 0,
    <5333, 4636, 5321>, 0,
    <5333, 5321, 5315>, 0,
    <5333, 5315, 5332>, 0,
    <5335, 5328, 5326>, 0,
    <5335, 5326, 5332>, 0,
    <5335, 5332, 5315>, 0,
    <5335, 5315, 5318>, 0,
    <5335, 5318, 5314>, 0,
    <5335, 5314, 5334>, 0,
    <5335, 5334, 5327>, 0,
    <5335, 5327, 5328>, 0,
    <5341, 5340, 5336>, 0,
    <5341, 5336, 5338>, 0,
    <5341, 5338, 5337>, 0,
    <5341, 5337, 5339>, 0,
    <5341, 5339, 4954>, 0,
    <5341, 4954, 5107>, 0,
    <5341, 5107, 5103>, 0,
    <5341, 5103, 5340>, 0,
    <5345, 5344, 5336>, 0,
    <5345, 5336, 5340>, 0,
    <5345, 5340, 5103>, 0,
    <5345, 5103, 5104>, 0,
    <5345, 5104, 5095>, 0,
    <5345, 5095, 5343>, 0,
    <5345, 5343, 5342>, 0,
    <5345, 5342, 5344>, 0,
    <5349, 5338, 5336>, 0,
    <5349, 5336, 5344>, 0,
    <5349, 5344, 5342>, 0,
    <5349, 5342, 5347>, 0,
    <5349, 5347, 5346>, 0,
    <5349, 5346, 5348>, 0,
    <5349, 5348, 5337>, 0,
    <5349, 5337, 5338>, 0,
    <5353, 5352, 5350>, 0,
    <5353, 5350, 5351>, 0,
    <5353, 5351, 5118>, 0,
    <5353, 5118, 5120>, 0,
    <5353, 5120, 4954>, 0,
    <5353, 4954, 5339>, 0,
    <5353, 5339, 5337>, 0,
    <5353, 5337, 5352>, 0,
    <5357, 5356, 5350>, 0,
    <5357, 5350, 5352>, 0,
    <5357, 5352, 5337>, 0,
    <5357, 5337, 5348>, 0,
    <5357, 5348, 5346>, 0,
    <5357, 5346, 5355>, 0,
    <5357, 5355, 5354>, 0,
    <5357, 5354, 5356>, 0,
    <5359, 5351, 5350>, 0,
    <5359, 5350, 5356>, 0,
    <5359, 5356, 5354>, 0,
    <5359, 5354, 5358>, 0,
    <5359, 5358, 5123>, 0,
    <5359, 5123, 5124>, 0,
    <5359, 5124, 5118>, 0,
    <5359, 5118, 5351>, 0,
    <5368, 5367, 5360>, 0,
    <5368, 5360, 5364>, 0,
    <5368, 5364, 5361>, 0,
    <5368, 5361, 5365>, 0,
    <5368, 5365, 5362>, 0,
    <5368, 5362, 5366>, 0,
    <5368, 5366, 5363>, 0,
    <5368, 5363, 5367>, 0,
    <5373, 5372, 5360>, 0,
    <5373, 5360, 5367>, 0,
    <5373, 5367, 5363>, 0,
    <5373, 5363, 5370>, 0,
    <5373, 5370, 5123>, 0,
    <5373, 5123, 5371>, 0,
    <5373, 5371, 5369>, 0,
    <5373, 5369, 5372>, 0,
    <5377, 5364, 5360>, 0,
    <5377, 5360, 5372>, 0,
    <5377, 5372, 5369>, 0,
    <5377, 5369, 5375>, 0,
    <5377, 5375, 5374>, 0,
    <5377, 5374, 5376>, 0,
    <5377, 5376, 5361>, 0,
    <5377, 5361, 5364>, 0,
    <5383, 5382, 5378>, 0,
    <5383, 5378, 5380>, 0,
    <5383, 5380, 5379>, 0,
    <5383, 5379, 5381>, 0,
    <5383, 5381, 5111>, 0,
    <5383, 5111, 5114>, 0,
    <5383, 5114, 5110>, 0,
    <5383, 5110, 5382>, 0,
    <5385, 5384, 5378>, 0,
    <5385, 5378, 5382>, 0,
    <5385, 5382, 5110>, 0,
    <5385, 5110, 5125>, 0,
    <5385, 5125, 5123>, 0,
    <5385, 5123, 5370>, 0,
    <5385, 5370, 5363>, 0,
    <5385, 5363, 5384>, 0,
    <5387, 5380, 5378>, 0,
    <5387, 5378, 5384>, 0,
    <5387, 5384, 5363>, 0,
    <5387, 5363, 5366>, 0,
    <5387, 5366, 5362>, 0,
    <5387, 5362, 5386>, 0,
    <5387, 5386, 5379>, 0,
    <5387, 5379, 5380>, 0,
    <5396, 5395, 5388>, 0,
    <5396, 5388, 5392>, 0,
    <5396, 5392, 5389>, 0,
    <5396, 5389, 5393>, 0,
    <5396, 5393, 5390>, 0,
    <5396, 5390, 5394>, 0,
    <5396, 5394, 5391>, 0,
    <5396, 5391, 5395>, 0,
    <5399, 5398, 5388>, 0,
    <5399, 5388, 5395>, 0,
    <5399, 5395, 5391>, 0,
    <5399, 5391, 5397>, 0,
    <5399, 5397, 180>, 0,
    <5399, 180, 4839>, 0,
    <5399, 4839, 4834>, 0,
    <5399, 4834, 5398>, 0,
    <5401, 5392, 5388>, 0,
    <5401, 5388, 5398>, 0,
    <5401, 5398, 4834>, 0,
    <5401, 4834, 4836>, 0,
    <5401, 4836, 4833>, 0,
    <5401, 4833, 5400>, 0,
    <5401, 5400, 5389>, 0,
    <5401, 5389, 5392>, 0,
    <5407, 5406, 5402>, 0,
    <5407, 5402, 5404>, 0,
    <5407, 5404, 5403>, 0,
    <5407, 5403, 5405>, 0,
    <5407, 5405, 5123>, 0,
    <5407, 5123, 5358>, 0,
    <5407, 5358, 5354>, 0,
    <5407, 5354, 5406>, 0,
    <5411, 5410, 5402>, 0,
    <5411, 5402, 5406>, 0,
    <5411, 5406, 5354>, 0,
    <5411, 5354, 5355>, 0,
    <5411, 5355, 5346>, 0,
    <5411, 5346, 5409>, 0,
    <5411, 5409, 5408>, 0,
    <5411, 5408, 5410>, 0,
    <5415, 5404, 5402>, 0,
    <5415, 5402, 5410>, 0,
    <5415, 5410, 5408>, 0,
    <5415, 5408, 5413>, 0,
    <5415, 5413, 5412>, 0,
    <5415, 5412, 5414>, 0,
    <5415, 5414, 5403>, 0,
    <5415, 5403, 5404>, 0,
    <5419, 5418, 5416>, 0,
    <5419, 5416, 5417>, 0,
    <5419, 5417, 5369>, 0,
    <5419, 5369, 5371>, 0,
    <5419, 5371, 5123>, 0,
    <5419, 5123, 5405>, 0,
    <5419, 5405, 5403>, 0,
    <5419, 5403, 5418>, 0,
    <5423, 5422, 5416>, 0,
    <5423, 5416, 5418>, 0,
    <5423, 5418, 5403>, 0,
    <5423, 5403, 5414>, 0,
    <5423, 5414, 5412>, 0,
    <5423, 5412, 5421>, 0,
    <5423, 5421, 5420>, 0,
    <5423, 5420, 5422>, 0,
    <5425, 5417, 5416>, 0,
    <5425, 5416, 5422>, 0,
    <5425, 5422, 5420>, 0,
    <5425, 5420, 5424>, 0,
    <5425, 5424, 5374>, 0,
    <5425, 5374, 5375>, 0,
    <5425, 5375, 5369>, 0,
    <5425, 5369, 5417>, 0,
    <5434, 5433, 5426>, 0,
    <5434, 5426, 5430>, 0,
    <5434, 5430, 5427>, 0,
    <5434, 5427, 5431>, 0,
    <5434, 5431, 5428>, 0,
    <5434, 5428, 5432>, 0,
    <5434, 5432, 5429>, 0,
    <5434, 5429, 5433>, 0,
    <5439, 5438, 5426>, 0,
    <5439, 5426, 5433>, 0,
    <5439, 5433, 5429>, 0,
    <5439, 5429, 5436>, 0,
    <5439, 5436, 5374>, 0,
    <5439, 5374, 5437>, 0,
    <5439, 5437, 5435>, 0,
    <5439, 5435, 5438>, 0,
    <5442, 5430, 5426>, 0,
    <5442, 5426, 5438>, 0,
    <5442, 5438, 5435>, 0,
    <5442, 5435, 5440>, 0,
    <5442, 5440, 280>, 0,
    <5442, 280, 5441>, 0,
    <5442, 5441, 5427>, 0,
    <5442, 5427, 5430>, 0,
    <5448, 5447, 5443>, 0,
    <5448, 5443, 5445>, 0,
    <5448, 5445, 5444>, 0,
    <5448, 5444, 5446>, 0,
    <5448, 5446, 5362>, 0,
    <5448, 5362, 5365>, 0,
    <5448, 5365, 5361>, 0,
    <5448, 5361, 5447>, 0,
    <5450, 5449, 5443>, 0,
    <5450, 5443, 5447>, 0,
    <5450, 5447, 5361>, 0,
    <5450, 5361, 5376>, 0,
    <5450, 5376, 5374>, 0,
    <5450, 5374, 5436>, 0,
    <5450, 5436, 5429>, 0,
    <5450, 5429, 5449>, 0,
    <5452, 5445, 5443>, 0,
    <5452, 5443, 5449>, 0,
    <5452, 5449, 5429>, 0,
    <5452, 5429, 5432>, 0,
    <5452, 5432, 5428>, 0,
    <5452, 5428, 5451>, 0,
    <5452, 5451, 5444>, 0,
    <5452, 5444, 5445>, 0,
    <5458, 5457, 5453>, 0,
    <5458, 5453, 5455>, 0,
    <5458, 5455, 5155>, 0,
    <5458, 5155, 5156>, 0,
    <5458, 5156, 4526>, 0,
    <5458, 4526, 5456>, 0,
    <5458, 5456, 5454>, 0,
    <5458, 5454, 5457>, 0,
    <5464, 5463, 5453>, 0,
    <5464, 5453, 5457>, 0,
    <5464, 5457, 5454>, 0,
    <5464, 5454, 5461>, 0,
    <5464, 5461, 5459>, 0,
    <5464, 5459, 5462>, 0,
    <5464, 5462, 5460>, 0,
    <5464, 5460, 5463>, 0,
    <5466, 5455, 5453>, 0,
    <5466, 5453, 5463>, 0,
    <5466, 5463, 5460>, 0,
    <5466, 5460, 5465>, 0,
    <5466, 5465, 5143>, 0,
    <5466, 5143, 5159>, 0,
    <5466, 5159, 5155>, 0,
    <5466, 5155, 5455>, 0,
    <5470, 5469, 5467>, 0,
    <5470, 5467, 5468>, 0,
    <5470, 5468, 5454>, 0,
    <5470, 5454, 5456>, 0,
    <5470, 5456, 4526>, 0,
    <5470, 4526, 4666>, 0,
    <5470, 4666, 4661>, 0,
    <5470, 4661, 5469>, 0,
    <5474, 5473, 5467>, 0,
    <5474, 5467, 5469>, 0,
    <5474, 5469, 4661>, 0,
    <5474, 4661, 4663>, 0,
    <5474, 4663, 4660>, 0,
    <5474, 4660, 5472>, 0,
    <5474, 5472, 5471>, 0,
    <5474, 5471, 5473>, 0,
    <5476, 5468, 5467>, 0,
    <5476, 5467, 5473>, 0,
    <5476, 5473, 5471>, 0,
    <5476, 5471, 5475>, 0,
    <5476, 5475, 5459>, 0,
    <5476, 5459, 5461>, 0,
    <5476, 5461, 5454>, 0,
    <5476, 5454, 5468>, 0,
    <5485, 5484, 5477>, 0,
    <5485, 5477, 5481>, 0,
    <5485, 5481, 5478>, 0,
    <5485, 5478, 5482>, 0,
    <5485, 5482, 5479>, 0,
    <5485, 5479, 5483>, 0,
    <5485, 5483, 5480>, 0,
    <5485, 5480, 5484>, 0,
    <5488, 5487, 5477>, 0,
    <5488, 5477, 5484>, 0,
    <5488, 5484, 5480>, 0,
    <5488, 5480, 5486>, 0,
    <5488, 5486, 4798>, 0,
    <5488, 4798, 4820>, 0,
    <5488, 4820, 4815>, 0,
    <5488, 4815, 5487>, 0,
    <5490, 5481, 5477>, 0,
    <5490, 5477, 5487>, 0,
    <5490, 5487, 4815>, 0,
    <5490, 4815, 4817>, 0,
    <5490, 4817, 4680>, 0,
    <5490, 4680, 5489>, 0,
    <5490, 5489, 5478>, 0,
    <5490, 5478, 5481>, 0,
    <5496, 5495, 5491>, 0,
    <5496, 5491, 5493>, 0,
    <5496, 5493, 5164>, 0,
    <5496, 5164, 5167>, 0,
    <5496, 5167, 5163>, 0,
    <5496, 5163, 5494>, 0,
    <5496, 5494, 5492>, 0,
    <5496, 5492, 5495>, 0,
    <5499, 5498, 5491>, 0,
    <5499, 5491, 5495>, 0,
    <5499, 5495, 5492>, 0,
    <5499, 5492, 5497>, 0,
    <5499, 5497, 5479>, 0,
    <5499, 5479, 5482>, 0,
    <5499, 5482, 5478>, 0,
    <5499, 5478, 5498>, 0,
    <5500, 5493, 5491>, 0,
    <5500, 5491, 5498>, 0,
    <5500, 5498, 5478>, 0,
    <5500, 5478, 5489>, 0,
    <5500, 5489, 4680>, 0,
    <5500, 4680, 5170>, 0,
    <5500, 5170, 5164>, 0,
    <5500, 5164, 5493>, 0,
    <5506, 5505, 5501>, 0,
    <5506, 5501, 5503>, 0,
    <5506, 5503, 5502>, 0,
    <5506, 5502, 5504>, 0,
    <5506, 5504, 5374>, 0,
    <5506, 5374, 5424>, 0,
    <5506, 5424, 5420>, 0,
    <5506, 5420, 5505>, 0,
    <5510, 5509, 5501>, 0,
    <5510, 5501, 5505>, 0,
    <5510, 5505, 5420>, 0,
    <5510, 5420, 5421>, 0,
    <5510, 5421, 5412>, 0,
    <5510, 5412, 5508>, 0,
    <5510, 5508, 5507>, 0,
    <5510, 5507, 5509>, 0,
    <5513, 5503, 5501>, 0,
    <5513, 5501, 5509>, 0,
    <5513, 5509, 5507>, 0,
    <5513, 5507, 5511>, 0,
    <5513, 5511, 348>, 0,
    <5513, 348, 5512>, 0,
    <5513, 5512, 5502>, 0,
    <5513, 5502, 5503>, 0,
    <5517, 5516, 5514>, 0,
    <5517, 5514, 5515>, 0,
    <5517, 5515, 5435>, 0,
    <5517, 5435, 5437>, 0,
    <5517, 5437, 5374>, 0,
    <5517, 5374, 5504>, 0,
    <5517, 5504, 5502>, 0,
    <5517, 5502, 5516>, 0,
    <5521, 5520, 5514>, 0,
    <5521, 5514, 5516>, 0,
    <5521, 5516, 5502>, 0,
    <5521, 5502, 5512>, 0,
    <5521, 5512, 348>, 0,
    <5521, 348, 5519>, 0,
    <5521, 5519, 5518>, 0,
    <5521, 5518, 5520>, 0,
    <5523, 5515, 5514>, 0,
    <5523, 5514, 5520>, 0,
    <5523, 5520, 5518>, 0,
    <5523, 5518, 5522>, 0,
    <5523, 5522, 280>, 0,
    <5523, 280, 5440>, 0,
    <5523, 5440, 5435>, 0,
    <5523, 5435, 5515>, 0,
    <5529, 5528, 5524>, 0,
    <5529, 5524, 5526>, 0,
    <5529, 5526, 5525>, 0,
    <5529, 5525, 5527>, 0,
    <5529, 5527, 5428>, 0,
    <5529, 5428, 5431>, 0,
    <5529, 5431, 5427>, 0,
    <5529, 5427, 5528>, 0,
    <5531, 5530, 5524>, 0,
    <5531, 5524, 5528>, 0,
    <5531, 5528, 5427>, 0,
    <5531, 5427, 5441>, 0,
    <5531, 5441, 280>, 0,
    <5531, 280, 380>, 0,
    <5531, 380, 375>, 0,
    <5531, 375, 5530>, 0,
    <5533, 5526, 5524>, 0,
    <5533, 5524, 5530>, 0,
    <5533, 5530, 375>, 0,
    <5533, 375, 377>, 0,
    <5533, 377, 374>, 0,
    <5533, 374, 5532>, 0,
    <5533, 5532, 5525>, 0,
    <5533, 5525, 5526>, 0,
    <5542, 5541, 5534>, 0,
    <5542, 5534, 5538>, 0,
    <5542, 5538, 5535>, 0,
    <5542, 5535, 5539>, 0,
    <5542, 5539, 5536>, 0,
    <5542, 5536, 5540>, 0,
    <5542, 5540, 5537>, 0,
    <5542, 5537, 5541>, 0,
    <5545, 5544, 5534>, 0,
    <5545, 5534, 5541>, 0,
    <5545, 5541, 5537>, 0,
    <5545, 5537, 5543>, 0,
    <5545, 5543, 4871>, 0,
    <5545, 4871, 4914>, 0,
    <5545, 4914, 4909>, 0,
    <5545, 4909, 5544>, 0,
    <5547, 5538, 5534>, 0,
    <5547, 5534, 5544>, 0,
    <5547, 5544, 4909>, 0,
    <5547, 4909, 4911>, 0,
    <5547, 4911, 230>, 0,
    <5547, 230, 5546>, 0,
    <5547, 5546, 5535>, 0,
    <5547, 5535, 5538>, 0,
    <5553, 5552, 5548>, 0,
    <5553, 5548, 5550>, 0,
    <5553, 5550, 5549>, 0,
    <5553, 5549, 5551>, 0,
    <5553, 5551, 4599>, 0,
    <5553, 4599, 5310>, 0,
    <5553, 5310, 5306>, 0,
    <5553, 5306, 5552>, 0,
    <5557, 5556, 5548>, 0,
    <5557, 5548, 5552>, 0,
    <5557, 5552, 5306>, 0,
    <5557, 5306, 5307>, 0,
    <5557, 5307, 5285>, 0,
    <5557, 5285, 5555>, 0,
    <5557, 5555, 5554>, 0,
    <5557, 5554, 5556>, 0,
    <5561, 5550, 5548>, 0,
    <5561, 5548, 5556>, 0,
    <5561, 5556, 5554>, 0,
    <5561, 5554, 5559>, 0,
    <5561, 5559, 5558>, 0,
    <5561, 5558, 5560>, 0,
    <5561, 5560, 5549>, 0,
    <5561, 5549, 5550>, 0,
    <5565, 5564, 5562>, 0,
    <5565, 5562, 5563>, 0,
    <5565, 5563, 4712>, 0,
    <5565, 4712, 4713>, 0,
    <5565, 4713, 4599>, 0,
    <5565, 4599, 5551>, 0,
    <5565, 5551, 5549>, 0,
    <5565, 5549, 5564>, 0,
    <5569, 5568, 5562>, 0,
    <5569, 5562, 5564>, 0,
    <5569, 5564, 5549>, 0,
    <5569, 5549, 5560>, 0,
    <5569, 5560, 5558>, 0,
    <5569, 5558, 5567>, 0,
    <5569, 5567, 5566>, 0,
    <5569, 5566, 5568>, 0,
    <5571, 5563, 5562>, 0,
    <5571, 5562, 5568>, 0,
    <5571, 5568, 5566>, 0,
    <5571, 5566, 5570>, 0,
    <5571, 5570, 4716>, 0,
    <5571, 4716, 4717>, 0,
    <5571, 4717, 4712>, 0,
    <5571, 4712, 5563>, 0,
    <5580, 5579, 5572>, 0,
    <5580, 5572, 5576>, 0,
    <5580, 5576, 5573>, 0,
    <5580, 5573, 5577>, 0,
    <5580, 5577, 5574>, 0,
    <5580, 5574, 5578>, 0,
    <5580, 5578, 5575>, 0,
    <5580, 5575, 5579>, 0,
    <5583, 5582, 5572>, 0,
    <5583, 5572, 5579>, 0,
    <5583, 5579, 5575>, 0,
    <5583, 5575, 5581>, 0,
    <5583, 5581, 4732>, 0,
    <5583, 4732, 4961>, 0,
    <5583, 4961, 4959>, 0,
    <5583, 4959, 5582>, 0,
    <5585, 5576, 5572>, 0,
    <5585, 5572, 5582>, 0,
    <5585, 5582, 4959>, 0,
    <5585, 4959, 4966>, 0,
    <5585, 4966, 4942>, 0,
    <5585, 4942, 5584>, 0,
    <5585, 5584, 5573>, 0,
    <5585, 5573, 5576>, 0,
    <5591, 5590, 5586>, 0,
    <5591, 5586, 5588>, 0,
    <5591, 5588, 5587>, 0,
    <5591, 5587, 5589>, 0,
    <5591, 5589, 5314>, 0,
    <5591, 5314, 5317>, 0,
    <5591, 5317, 5313>, 0,
    <5591, 5313, 5590>, 0,
    <5593, 5592, 5586>, 0,
    <5593, 5586, 5590>, 0,
    <5593, 5590, 5313>, 0,
    <5593, 5313, 5324>, 0,
    <5593, 5324, 4732>, 0,
    <5593, 4732, 5581>, 0,
    <5593, 5581, 5575>, 0,
    <5593, 5575, 5592>, 0,
    <5595, 5588, 5586>, 0,
    <5595, 5586, 5592>, 0,
    <5595, 5592, 5575>, 0,
    <5595, 5575, 5578>, 0,
    <5595, 5578, 5574>, 0,
    <5595, 5574, 5594>, 0,
    <5595, 5594, 5587>, 0,
    <5595, 5587, 5588>, 0,
    <5601, 5600, 5596>, 0,
    <5601, 5596, 5598>, 0,
    <5601, 5598, 5471>, 0,
    <5601, 5471, 5472>, 0,
    <5601, 5472, 4660>, 0,
    <5601, 4660, 5599>, 0,
    <5601, 5599, 5597>, 0,
    <5601, 5597, 5600>, 0,
    <5607, 5606, 5596>, 0,
    <5607, 5596, 5600>, 0,
    <5607, 5600, 5597>, 0,
    <5607, 5597, 5604>, 0,
    <5607, 5604, 5602>, 0,
    <5607, 5602, 5605>, 0,
    <5607, 5605, 5603>, 0,
    <5607, 5603, 5606>, 0,
    <5609, 5598, 5596>, 0,
    <5609, 5596, 5606>, 0,
    <5609, 5606, 5603>, 0,
    <5609, 5603, 5608>, 0,
    <5609, 5608, 5459>, 0,
    <5609, 5459, 5475>, 0,
    <5609, 5475, 5471>, 0,
    <5609, 5471, 5598>, 0,
    <5613, 5612, 5610>, 0,
    <5613, 5610, 5611>, 0,
    <5613, 5611, 5597>, 0,
    <5613, 5597, 5599>, 0,
    <5613, 5599, 4660>, 0,
    <5613, 4660, 4784>, 0,
    <5613, 4784, 4779>, 0,
    <5613, 4779, 5612>, 0,
    <5617, 5616, 5610>, 0,
    <5617, 5610, 5612>, 0,
    <5617, 5612, 4779>, 0,
    <5617, 4779, 4781>, 0,
    <5617, 4781, 4778>, 0,
    <5617, 4778, 5615>, 0,
    <5617, 5615, 5614>, 0,
    <5617, 5614, 5616>, 0,
    <5619, 5611, 5610>, 0,
    <5619, 5610, 5616>, 0,
    <5619, 5616, 5614>, 0,
    <5619, 5614, 5618>, 0,
    <5619, 5618, 5602>, 0,
    <5619, 5602, 5604>, 0,
    <5619, 5604, 5597>, 0,
    <5619, 5597, 5611>, 0,
    <5628, 5627, 5620>, 0,
    <5628, 5620, 5624>, 0,
    <5628, 5624, 5621>, 0,
    <5628, 5621, 5625>, 0,
    <5628, 5625, 5622>, 0,
    <5628, 5622, 5626>, 0,
    <5628, 5626, 5623>, 0,
    <5628, 5623, 5627>, 0,
    <5631, 5630, 5620>, 0,
    <5631, 5620, 5627>, 0,
    <5631, 5627, 5623>, 0,
    <5631, 5623, 5629>, 0,
    <5631, 5629, 4994>, 0,
    <5631, 4994, 5016>, 0,
    <5631, 5016, 5011>, 0,
    <5631, 5011, 5630>, 0,
    <5633, 5624, 5620>, 0,
    <5633, 5620, 5630>, 0,
    <5633, 5630, 5011>, 0,
    <5633, 5011, 5013>, 0,
    <5633, 5013, 4798>, 0,
    <5633, 4798, 5632>, 0,
    <5633, 5632, 5621>, 0,
    <5633, 5621, 5624>, 0,
    <5639, 5638, 5634>, 0,
    <5639, 5634, 5636>, 0,
    <5639, 5636, 5480>, 0,
    <5639, 5480, 5483>, 0,
    <5639, 5483, 5479>, 0,
    <5639, 5479, 5637>, 0,
    <5639, 5637, 5635>, 0,
    <5639, 5635, 5638>, 0,
    <5642, 5641, 5634>, 0,
    <5642, 5634, 5638>, 0,
    <5642, 5638, 5635>, 0,
    <5642, 5635, 5640>, 0,
    <5642, 5640, 5622>, 0,
    <5642, 5622, 5625>, 0,
    <5642, 5625, 5621>, 0,
    <5642, 5621, 5641>, 0,
    <5643, 5636, 5634>, 0,
    <5643, 5634, 5641>, 0,
    <5643, 5641, 5621>, 0,
    <5643, 5621, 5632>, 0,
    <5643, 5632, 4798>, 0,
    <5643, 4798, 5486>, 0,
    <5643, 5486, 5480>, 0,
    <5643, 5480, 5636>, 0,
    <5649, 5648, 5644>, 0,
    <5649, 5644, 5646>, 0,
    <5649, 5646, 5645>, 0,
    <5649, 5645, 5647>, 0,
    <5649, 5647, 4716>, 0,
    <5649, 4716, 5570>, 0,
    <5649, 5570, 5566>, 0,
    <5649, 5566, 5648>, 0,
    <5653, 5652, 5644>, 0,
    <5653, 5644, 5648>, 0,
    <5653, 5648, 5566>, 0,
    <5653, 5566, 5567>, 0,
    <5653, 5567, 5558>, 0,
    <5653, 5558, 5651>, 0,
    <5653, 5651, 5650>, 0,
    <5653, 5650, 5652>, 0,
    <5657, 5646, 5644>, 0,
    <5657, 5644, 5652>, 0,
    <5657, 5652, 5650>, 0,
    <5657, 5650, 5655>, 0,
    <5657, 5655, 5654>, 0,
    <5657, 5654, 5656>, 0,
    <5657, 5656, 5645>, 0,
    <5657, 5645, 5646>, 0,
    <5661, 5660, 5658>, 0,
    <5661, 5658, 5659>, 0,
    <5661, 5659, 4922>, 0,
    <5661, 4922, 4923>, 0,
    <5661, 4923, 4716>, 0,
    <5661, 4716, 5647>, 0,
    <5661, 5647, 5645>, 0,
    <5661, 5645, 5660>, 0,
    <5665, 5664, 5658>, 0,
    <5665, 5658, 5660>, 0,
    <5665, 5660, 5645>, 0,
    <5665, 5645, 5656>, 0,
    <5665, 5656, 5654>, 0,
    <5665, 5654, 5663>, 0,
    <5665, 5663, 5662>, 0,
    <5665, 5662, 5664>, 0,
    <5667, 5659, 5658>, 0,
    <5667, 5658, 5664>, 0,
    <5667, 5664, 5662>, 0,
    <5667, 5662, 5666>, 0,
    <5667, 5666, 4926>, 0,
    <5667, 4926, 4927>, 0,
    <5667, 4927, 4922>, 0,
    <5667, 4922, 5659>, 0,
    <5676, 5675, 5668>, 0,
    <5676, 5668, 5672>, 0,
    <5676, 5672, 5669>, 0,
    <5676, 5669, 5673>, 0,
    <5676, 5673, 5670>, 0,
    <5676, 5670, 5674>, 0,
    <5676, 5674, 5671>, 0,
    <5676, 5671, 5675>, 0,
    <5679, 5678, 5668>, 0,
    <5679, 5668, 5675>, 0,
    <5679, 5675, 5671>, 0,
    <5679, 5671, 5677>, 0,
    <5679, 5677, 4942>, 0,
    <5679, 4942, 5130>, 0,
    <5679, 5130, 5128>, 0,
    <5679, 5128, 5678>, 0,
    <5681, 5672, 5668>, 0,
    <5681, 5668, 5678>, 0,
    <5681, 5678, 5128>, 0,
    <5681, 5128, 5135>, 0,
    <5681, 5135, 5111>, 0,
    <5681, 5111, 5680>, 0,
    <5681, 5680, 5669>, 0,
    <5681, 5669, 5672>, 0,
    <5687, 5686, 5682>, 0,
    <5687, 5682, 5684>, 0,
    <5687, 5684, 5683>, 0,
    <5687, 5683, 5685>, 0,
    <5687, 5685, 5574>, 0,
    <5687, 5574, 5577>, 0,
    <5687, 5577, 5573>, 0,
    <5687, 5573, 5686>, 0,
    <5689, 5688, 5682>, 0,
    <5689, 5682, 5686>, 0,
    <5689, 5686, 5573>, 0,
    <5689, 5573, 5584>, 0,
    <5689, 5584, 4942>, 0,
    <5689, 4942, 5677>, 0,
    <5689, 5677, 5671>, 0,
    <5689, 5671, 5688>, 0,
    <5691, 5684, 5682>, 0,
    <5691, 5682, 5688>, 0,
    <5691, 5688, 5671>, 0,
    <5691, 5671, 5674>, 0,
    <5691, 5674, 5670>, 0,
    <5691, 5670, 5690>, 0,
    <5691, 5690, 5683>, 0,
    <5691, 5683, 5684>, 0,
    <5697, 5696, 5692>, 0,
    <5697, 5692, 5694>, 0,
    <5697, 5694, 5614>, 0,
    <5697, 5614, 5615>, 0,
    <5697, 5615, 4778>, 0,
    <5697, 4778, 5695>, 0,
    <5697, 5695, 5693>, 0,
    <5697, 5693, 5696>, 0,
    <5703, 5702, 5692>, 0,
    <5703, 5692, 5696>, 0,
    <5703, 5696, 5693>, 0,
    <5703, 5693, 5700>, 0,
    <5703, 5700, 5698>, 0,
    <5703, 5698, 5701>, 0,
    <5703, 5701, 5699>, 0,
    <5703, 5699, 5702>, 0,
    <5705, 5694, 5692>, 0,
    <5705, 5692, 5702>, 0,
    <5705, 5702, 5699>, 0,
    <5705, 5699, 5704>, 0,
    <5705, 5704, 5602>, 0,
    <5705, 5602, 5618>, 0,
    <5705, 5618, 5614>, 0,
    <5705, 5614, 5694>, 0,
    <5709, 5708, 5706>, 0,
    <5709, 5706, 5707>, 0,
    <5709, 5707, 5693>, 0,
    <5709, 5693, 5695>, 0,
    <5709, 5695, 4778>, 0,
    <5709, 4778, 4980>, 0,
    <5709, 4980, 4975>, 0,
    <5709, 4975, 5708>, 0,
    <5713, 5712, 5706>, 0,
    <5713, 5706, 5708>, 0,
    <5713, 5708, 4975>, 0,
    <5713, 4975, 4977>, 0,
    <5713, 4977, 4974>, 0,
    <5713, 4974, 5711>, 0,
    <5713, 5711, 5710>, 0,
    <5713, 5710, 5712>, 0,
    <5715, 5707, 5706>, 0,
    <5715, 5706, 5712>, 0,
    <5715, 5712, 5710>, 0,
    <5715, 5710, 5714>, 0,
    <5715, 5714, 5698>, 0,
    <5715, 5698, 5700>, 0,
    <5715, 5700, 5693>, 0,
    <5715, 5693, 5707>, 0,
    <5724, 5723, 5716>, 0,
    <5724, 5716, 5720>, 0,
    <5724, 5720, 5717>, 0,
    <5724, 5717, 5721>, 0,
    <5724, 5721, 5718>, 0,
    <5724, 5718, 5722>, 0,
    <5724, 5722, 5719>, 0,
    <5724, 5719, 5723>, 0,
    <5727, 5726, 5716>, 0,
    <5727, 5716, 5723>, 0,
    <5727, 5723, 5719>, 0,
    <5727, 5719, 5725>, 0,
    <5727, 5725, 5059>, 0,
    <5727, 5059, 5081>, 0,
    <5727, 5081, 5076>, 0,
    <5727, 5076, 5726>, 0,
    <5729, 5720, 5716>, 0,
    <5729, 5716, 5726>, 0,
    <5729, 5726, 5076>, 0,
    <5729, 5076, 5078>, 0,
    <5729, 5078, 4994>, 0,
    <5729, 4994, 5728>, 0,
    <5729, 5728, 5717>, 0,
    <5729, 5717, 5720>, 0,
    <5735, 5734, 5730>, 0,
    <5735, 5730, 5732>, 0,
    <5735, 5732, 5623>, 0,
    <5735, 5623, 5626>, 0,
    <5735, 5626, 5622>, 0,
    <5735, 5622, 5733>, 0,
    <5735, 5733, 5731>, 0,
    <5735, 5731, 5734>, 0,
    <5738, 5737, 5730>, 0,
    <5738, 5730, 5734>, 0,
    <5738, 5734, 5731>, 0,
    <5738, 5731, 5736>, 0,
    <5738, 5736, 5718>, 0,
    <5738, 5718, 5721>, 0,
    <5738, 5721, 5717>, 0,
    <5738, 5717, 5737>, 0,
    <5739, 5732, 5730>, 0,
    <5739, 5730, 5737>, 0,
    <5739, 5737, 5717>, 0,
    <5739, 5717, 5728>, 0,
    <5739, 5728, 4994>, 0,
    <5739, 4994, 5629>, 0,
    <5739, 5629, 5623>, 0,
    <5739, 5623, 5732>, 0,
    <5748, 5747, 5740>, 0,
    <5748, 5740, 5744>, 0,
    <5748, 5744, 5741>, 0,
    <5748, 5741, 5745>, 0,
    <5748, 5745, 5742>, 0,
    <5748, 5742, 5746>, 0,
    <5748, 5746, 5743>, 0,
    <5748, 5743, 5747>, 0,
    <5751, 5750, 5740>, 0,
    <5751, 5740, 5747>, 0,
    <5751, 5747, 5743>, 0,
    <5751, 5743, 5749>, 0,
    <5751, 5749, 216>, 0,
    <5751, 216, 5329>, 0,
    <5751, 5329, 5327>, 0,
    <5751, 5327, 5750>, 0,
    <5753, 5744, 5740>, 0,
    <5753, 5740, 5750>, 0,
    <5753, 5750, 5327>, 0,
    <5753, 5327, 5334>, 0,
    <5753, 5334, 5314>, 0,
    <5753, 5314, 5752>, 0,
    <5753, 5752, 5741>, 0,
    <5753, 5741, 5744>, 0,
    <5759, 5758, 5754>, 0,
    <5759, 5754, 5756>, 0,
    <5759, 5756, 5710>, 0,
    <5759, 5710, 5711>, 0,
    <5759, 5711, 4974>, 0,
    <5759, 4974, 5757>, 0,
    <5759, 5757, 5755>, 0,
    <5759, 5755, 5758>, 0,
    <5765, 5764, 5754>, 0,
    <5765, 5754, 5758>, 0,
    <5765, 5758, 5755>, 0,
    <5765, 5755, 5762>, 0,
    <5765, 5762, 5760>, 0,
    <5765, 5760, 5763>, 0,
    <5765, 5763, 5761>, 0,
    <5765, 5761, 5764>, 0,
    <5767, 5756, 5754>, 0,
    <5767, 5754, 5764>, 0,
    <5767, 5764, 5761>, 0,
    <5767, 5761, 5766>, 0,
    <5767, 5766, 5698>, 0,
    <5767, 5698, 5714>, 0,
    <5767, 5714, 5710>, 0,
    <5767, 5710, 5756>, 0,
    <5771, 5770, 5768>, 0,
    <5771, 5768, 5769>, 0,
    <5771, 5769, 5755>, 0,
    <5771, 5755, 5757>, 0,
    <5771, 5757, 4974>, 0,
    <5771, 4974, 5045>, 0,
    <5771, 5045, 5040>, 0,
    <5771, 5040, 5770>, 0,
    <5775, 5774, 5768>, 0,
    <5775, 5768, 5770>, 0,
    <5775, 5770, 5040>, 0,
    <5775, 5040, 5042>, 0,
    <5775, 5042, 5039>, 0,
    <5775, 5039, 5773>, 0,
    <5775, 5773, 5772>, 0,
    <5775, 5772, 5774>, 0,
    <5777, 5769, 5768>, 0,
    <5777, 5768, 5774>, 0,
    <5777, 5774, 5772>, 0,
    <5777, 5772, 5776>, 0,
    <5777, 5776, 5760>, 0,
    <5777, 5760, 5762>, 0,
    <5777, 5762, 5755>, 0,
    <5777, 5755, 5769>, 0,
    <5786, 5785, 5778>, 0,
    <5786, 5778, 5782>, 0,
    <5786, 5782, 5779>, 0,
    <5786, 5779, 5783>, 0,
    <5786, 5783, 5780>, 0,
    <5786, 5780, 5784>, 0,
    <5786, 5784, 5781>, 0,
    <5786, 5781, 5785>, 0,
    <5789, 5788, 5778>, 0,
    <5789, 5778, 5785>, 0,
    <5789, 5785, 5781>, 0,
    <5789, 5781, 5787>, 0,
    <5789, 5787, 5211>, 0,
    <5789, 5211, 5232>, 0,
    <5789, 5232, 5227>, 0,
    <5789, 5227, 5788>, 0,
    <5791, 5782, 5778>, 0,
    <5791, 5778, 5788>, 0,
    <5791, 5788, 5227>, 0,
    <5791, 5227, 5229>, 0,
    <5791, 5229, 5059>, 0,
    <5791, 5059, 5790>, 0,
    <5791, 5790, 5779>, 0,
    <5791, 5779, 5782>, 0,
    <5797, 5796, 5792>, 0,
    <5797, 5792, 5794>, 0,
    <5797, 5794, 5719>, 0,
    <5797, 5719, 5722>, 0,
    <5797, 5722, 5718>, 0,
    <5797, 5718, 5795>, 0,
    <5797, 5795, 5793>, 0,
    <5797, 5793, 5796>, 0,
    <5800, 5799, 5792>, 0,
    <5800, 5792, 5796>, 0,
    <5800, 5796, 5793>, 0,
    <5800, 5793, 5798>, 0,
    <5800, 5798, 5780>, 0,
    <5800, 5780, 5783>, 0,
    <5800, 5783, 5779>, 0,
    <5800, 5779, 5799>, 0,
    <5801, 5794, 5792>, 0,
    <5801, 5792, 5799>, 0,
    <5801, 5799, 5779>, 0,
    <5801, 5779, 5790>, 0,
    <5801, 5790, 5059>, 0,
    <5801, 5059, 5725>, 0,
    <5801, 5725, 5719>, 0,
    <5801, 5719, 5794>, 0,
    <5807, 5806, 5802>, 0,
    <5807, 5802, 5804>, 0,
    <5807, 5804, 5803>, 0,
    <5807, 5803, 5805>, 0,
    <5807, 5805, 4926>, 0,
    <5807, 4926, 5666>, 0,
    <5807, 5666, 5662>, 0,
    <5807, 5662, 5806>, 0,
    <5811, 5810, 5802>, 0,
    <5811, 5802, 5806>, 0,
    <5811, 5806, 5662>, 0,
    <5811, 5662, 5663>, 0,
    <5811, 5663, 5654>, 0,
    <5811, 5654, 5809>, 0,
    <5811, 5809, 5808>, 0,
    <5811, 5808, 5810>, 0,
    <5815, 5804, 5802>, 0,
    <5815, 5802, 5810>, 0,
    <5815, 5810, 5808>, 0,
    <5815, 5808, 5813>, 0,
    <5815, 5813, 5812>, 0,
    <5815, 5812, 5814>, 0,
    <5815, 5814, 5803>, 0,
    <5815, 5803, 5804>, 0,
    <5819, 5818, 5816>, 0,
    <5819, 5816, 5817>, 0,
    <5819, 5817, 5091>, 0,
    <5819, 5091, 5092>, 0,
    <5819, 5092, 4926>, 0,
    <5819, 4926, 5805>, 0,
    <5819, 5805, 5803>, 0,
    <5819, 5803, 5818>, 0,
    <5823, 5822, 5816>, 0,
    <5823, 5816, 5818>, 0,
    <5823, 5818, 5803>, 0,
    <5823, 5803, 5814>, 0,
    <5823, 5814, 5812>, 0,
    <5823, 5812, 5821>, 0,
    <5823, 5821, 5820>, 0,
    <5823, 5820, 5822>, 0,
    <5825, 5817, 5816>, 0,
    <5825, 5816, 5822>, 0,
    <5825, 5822, 5820>, 0,
    <5825, 5820, 5824>, 0,
    <5825, 5824, 5095>, 0,
    <5825, 5095, 5096>, 0,
    <5825, 5096, 5091>, 0,
    <5825, 5091, 5817>, 0,
    <5834, 5833, 5826>, 0,
    <5834, 5826, 5830>, 0,
    <5834, 5830, 5827>, 0,
    <5834, 5827, 5831>, 0,
    <5834, 5831, 5828>, 0,
    <5834, 5828, 5832>, 0,
    <5834, 5832, 5829>, 0,
    <5834, 5829, 5833>, 0,
    <5837, 5836, 5826>, 0,
    <5837, 5826, 5833>, 0,
    <5837, 5833, 5829>, 0,
    <5837, 5829, 5835>, 0,
    <5837, 5835, 5111>, 0,
    <5837, 5111, 5381>, 0,
    <5837, 5381, 5379>, 0,
    <5837, 5379, 5836>, 0,
    <5839, 5830, 5826>, 0,
    <5839, 5826, 5836>, 0,
    <5839, 5836, 5379>, 0,
    <5839, 5379, 5386>, 0,
    <5839, 5386, 5362>, 0,
    <5839, 5362, 5838>, 0,
    <5839, 5838, 5827>, 0,
    <5839, 5827, 5830>, 0,
    <5845, 5844, 5840>, 0,
    <5845, 5840, 5842>, 0,
    <5845, 5842, 5841>, 0,
    <5845, 5841, 5843>, 0,
    <5845, 5843, 5670>, 0,
    <5845, 5670, 5673>, 0,
    <5845, 5673, 5669>, 0,
    <5845, 5669, 5844>, 0,
    <5847, 5846, 5840>, 0,
    <5847, 5840, 5844>, 0,
    <5847, 5844, 5669>, 0,
    <5847, 5669, 5680>, 0,
    <5847, 5680, 5111>, 0,
    <5847, 5111, 5835>, 0,
    <5847, 5835, 5829>, 0,
    <5847, 5829, 5846>, 0,
    <5849, 5842, 5840>, 0,
    <5849, 5840, 5846>, 0,
    <5849, 5846, 5829>, 0,
    <5849, 5829, 5832>, 0,
    <5849, 5832, 5828>, 0,
    <5849, 5828, 5848>, 0,
    <5849, 5848, 5841>, 0,
    <5849, 5841, 5842>, 0,
    <5855, 5854, 5850>, 0,
    <5855, 5850, 5852>, 0,
    <5855, 5852, 5772>, 0,
    <5855, 5772, 5773>, 0,
    <5855, 5773, 5039>, 0,
    <5855, 5039, 5853>, 0,
    <5855, 5853, 5851>, 0,
    <5855, 5851, 5854>, 0,
    <5861, 5860, 5850>, 0,
    <5861, 5850, 5854>, 0,
    <5861, 5854, 5851>, 0,
    <5861, 5851, 5858>, 0,
    <5861, 5858, 5856>, 0,
    <5861, 5856, 5859>, 0,
    <5861, 5859, 5857>, 0,
    <5861, 5857, 5860>, 0,
    <5863, 5852, 5850>, 0,
    <5863, 5850, 5860>, 0,
    <5863, 5860, 5857>, 0,
    <5863, 5857, 5862>, 0,
    <5863, 5862, 5760>, 0,
    <5863, 5760, 5776>, 0,
    <5863, 5776, 5772>, 0,
    <5863, 5772, 5852>, 0,
    <5867, 5866, 5864>, 0,
    <5867, 5864, 5865>, 0,
    <5867, 5865, 5851>, 0,
    <5867, 5851, 5853>, 0,
    <5867, 5853, 5039>, 0,
    <5867, 5039, 5197>, 0,
    <5867, 5197, 5192>, 0,
    <5867, 5192, 5866>, 0,
    <5871, 5870, 5864>, 0,
    <5871, 5864, 5866>, 0,
    <5871, 5866, 5192>, 0,
    <5871, 5192, 5194>, 0,
    <5871, 5194, 5191>, 0,
    <5871, 5191, 5869>, 0,
    <5871, 5869, 5868>, 0,
    <5871, 5868, 5870>, 0,
    <5873, 5865, 5864>, 0,
    <5873, 5864, 5870>, 0,
    <5873, 5870, 5868>, 0,
    <5873, 5868, 5872>, 0,
    <5873, 5872, 5856>, 0,
    <5873, 5856, 5858>, 0,
    <5873, 5858, 5851>, 0,
    <5873, 5851, 5865>, 0,
    <5882, 5881, 5874>, 0,
    <5882, 5874, 5878>, 0,
    <5882, 5878, 5875>, 0,
    <5882, 5875, 5879>, 0,
    <5882, 5879, 5876>, 0,
    <5882, 5876, 5880>, 0,
    <5882, 5880, 5877>, 0,
    <5882, 5877, 5881>, 0,
    <5885, 5884, 5874>, 0,
    <5885, 5874, 5881>, 0,
    <5885, 5881, 5877>, 0,
    <5885, 5877, 5883>, 0,
    <5885, 5883, 384>, 0,
    <5885, 384, 5266>, 0,
    <5885, 5266, 5260>, 0,
    <5885, 5260, 5884>, 0,
    <5887, 5878, 5874>, 0,
    <5887, 5874, 5884>, 0,
    <5887, 5884, 5260>, 0,
    <5887, 5260, 5262>, 0,
    <5887, 5262, 5211>, 0,
    <5887, 5211, 5886>, 0,
    <5887, 5886, 5875>, 0,
    <5887, 5875, 5878>, 0,
    <5893, 5892, 5888>, 0,
    <5893, 5888, 5890>, 0,
    <5893, 5890, 5781>, 0,
    <5893, 5781, 5784>, 0,
    <5893, 5784, 5780>, 0,
    <5893, 5780, 5891>, 0,
    <5893, 5891, 5889>, 0,
    <5893, 5889, 5892>, 0,
    <5896, 5895, 5888>, 0,
    <5896, 5888, 5892>, 0,
    <5896, 5892, 5889>, 0,
    <5896, 5889, 5894>, 0,
    <5896, 5894, 5876>, 0,
    <5896, 5876, 5879>, 0,
    <5896, 5879, 5875>, 0,
    <5896, 5875, 5895>, 0,
    <5897, 5890, 5888>, 0,
    <5897, 5888, 5895>, 0,
    <5897, 5895, 5875>, 0,
    <5897, 5875, 5886>, 0,
    <5897, 5886, 5211>, 0,
    <5897, 5211, 5787>, 0,
    <5897, 5787, 5781>, 0,
    <5897, 5781, 5890>, 0,
    <5903, 5902, 5898>, 0,
    <5903, 5898, 5900>, 0,
    <5903, 5900, 5868>, 0,
    <5903, 5868, 5869>, 0,
    <5903, 5869, 5191>, 0,
    <5903, 5191, 5901>, 0,
    <5903, 5901, 5899>, 0,
    <5903, 5899, 5902>, 0,
    <5908, 5907, 5898>, 0,
    <5908, 5898, 5902>, 0,
    <5908, 5902, 5899>, 0,
    <5908, 5899, 5905>, 0,
    <5908, 5905, 565>, 0,
    <5908, 565, 5906>, 0,
    <5908, 5906, 5904>, 0,
    <5908, 5904, 5907>, 0,
    <5910, 5900, 5898>, 0,
    <5910, 5898, 5907>, 0,
    <5910, 5907, 5904>, 0,
    <5910, 5904, 5909>, 0,
    <5910, 5909, 5856>, 0,
    <5910, 5856, 5872>, 0,
    <5910, 5872, 5868>, 0,
    <5910, 5868, 5900>, 0,
    <5914, 5913, 5911>, 0,
    <5914, 5911, 5912>, 0,
    <5914, 5912, 5899>, 0,
    <5914, 5899, 5901>, 0,
    <5914, 5901, 5191>, 0,
    <5914, 5191, 5247>, 0,
    <5914, 5247, 5242>, 0,
    <5914, 5242, 5913>, 0,
    <5918, 5917, 5911>, 0,
    <5918, 5911, 5913>, 0,
    <5918, 5913, 5242>, 0,
    <5918, 5242, 5244>, 0,
    <5918, 5244, 354>, 0,
    <5918, 354, 5916>, 0,
    <5918, 5916, 5915>, 0,
    <5918, 5915, 5917>, 0,
    <5920, 5912, 5911>, 0,
    <5920, 5911, 5917>, 0,
    <5920, 5917, 5915>, 0,
    <5920, 5915, 5919>, 0,
    <5920, 5919, 565>, 0,
    <5920, 565, 5905>, 0,
    <5920, 5905, 5899>, 0,
    <5920, 5899, 5912>, 0,
    <5926, 5925, 5921>, 0,
    <5926, 5921, 5923>, 0,
    <5926, 5923, 5877>, 0,
    <5926, 5877, 5880>, 0,
    <5926, 5880, 5876>, 0,
    <5926, 5876, 5924>, 0,
    <5926, 5924, 5922>, 0,
    <5926, 5922, 5925>, 0,
    <5931, 5930, 5921>, 0,
    <5931, 5921, 5925>, 0,
    <5931, 5925, 5922>, 0,
    <5931, 5922, 5928>, 0,
    <5931, 5928, 622>, 0,
    <5931, 622, 5929>, 0,
    <5931, 5929, 5927>, 0,
    <5931, 5927, 5930>, 0,
    <5933, 5923, 5921>, 0,
    <5933, 5921, 5930>, 0,
    <5933, 5930, 5927>, 0,
    <5933, 5927, 5932>, 0,
    <5933, 5932, 384>, 0,
    <5933, 384, 5883>, 0,
    <5933, 5883, 5877>, 0,
    <5933, 5877, 5923>, 0,
    <5939, 5938, 5934>, 0,
    <5939, 5934, 5936>, 0,
    <5939, 5936, 5935>, 0,
    <5939, 5935, 5937>, 0,
    <5939, 5937, 5095>, 0,
    <5939, 5095, 5824>, 0,
    <5939, 5824, 5820>, 0,
    <5939, 5820, 5938>, 0,
    <5943, 5942, 5934>, 0,
    <5943, 5934, 5938>, 0,
    <5943, 5938, 5820>, 0,
    <5943, 5820, 5821>, 0,
    <5943, 5821, 5812>, 0,
    <5943, 5812, 5941>, 0,
    <5943, 5941, 5940>, 0,
    <5943, 5940, 5942>, 0,
    <5947, 5936, 5934>, 0,
    <5947, 5934, 5942>, 0,
    <5947, 5942, 5940>, 0,
    <5947, 5940, 5945>, 0,
    <5947, 5945, 5944>, 0,
    <5947, 5944, 5946>, 0,
    <5947, 5946, 5935>, 0,
    <5947, 5935, 5936>, 0,
    <5951, 5950, 5948>, 0,
    <5951, 5948, 5949>, 0,
    <5951, 5949, 5342>, 0,
    <5951, 5342, 5343>, 0,
    <5951, 5343, 5095>, 0,
    <5951, 5095, 5937>, 0,
    <5951, 5937, 5935>, 0,
    <5951, 5935, 5950>, 0,
    <5955, 5954, 5948>, 0,
    <5955, 5948, 5950>, 0,
    <5955, 5950, 5935>, 0,
    <5955, 5935, 5946>, 0,
    <5955, 5946, 5944>, 0,
    <5955, 5944, 5953>, 0,
    <5955, 5953, 5952>, 0,
    <5955, 5952, 5954>, 0,
    <5957, 5949, 5948>, 0,
    <5957, 5948, 5954>, 0,
    <5957, 5954, 5952>, 0,
    <5957, 5952, 5956>, 0,
    <5957, 5956, 5346>, 0,
    <5957, 5346, 5347>, 0,
    <5957, 5347, 5342>, 0,
    <5957, 5342, 5949>, 0,
    <5966, 5965, 5958>, 0,
    <5966, 5958, 5962>, 0,
    <5966, 5962, 5959>, 0,
    <5966, 5959, 5963>, 0,
    <5966, 5963, 5960>, 0,
    <5966, 5960, 5964>, 0,
    <5966, 5964, 5961>, 0,
    <5966, 5961, 5965>, 0,
    <5969, 5968, 5958>, 0,
    <5969, 5958, 5965>, 0,
    <5969, 5965, 5961>, 0,
    <5969, 5961, 5967>, 0,
    <5969, 5967, 5362>, 0,
    <5969, 5362, 5446>, 0,
    <5969, 5446, 5444>, 0,
    <5969, 5444, 5968>, 0,
    <5971, 5962, 5958>, 0,
    <5971, 5958, 5968>, 0,
    <5971, 5968, 5444>, 0,
    <5971, 5444, 5451>, 0,
    <5971, 5451, 5428>, 0,
    <5971, 5428, 5970>, 0,
    <5971, 5970, 5959>, 0,
    <5971, 5959, 5962>, 0,
    <5977, 5976, 5972>, 0,
    <5977, 5972, 5974>, 0,
    <5977, 5974, 5973>, 0,
    <5977, 5973, 5975>, 0,
    <5977, 5975, 5828>, 0,
    <5977, 5828, 5831>, 0,
    <5977, 5831, 5827>, 0,
    <5977, 5827, 5976>, 0,
    <5979, 5978, 5972>, 0,
    <5979, 5972, 5976>, 0,
    <5979, 5976, 5827>, 0,
    <5979, 5827, 5838>, 0,
    <5979, 5838, 5362>, 0,
    <5979, 5362, 5967>, 0,
    <5979, 5967, 5961>, 0,
    <5979, 5961, 5978>, 0,
    <5981, 5974, 5972>, 0,
    <5981, 5972, 5978>, 0,
    <5981, 5978, 5961>, 0,
    <5981, 5961, 5964>, 0,
    <5981, 5964, 5960>, 0,
    <5981, 5960, 5980>, 0,
    <5981, 5980, 5973>, 0,
    <5981, 5973, 5974>, 0,
    <5987, 5986, 5982>, 0,
    <5987, 5982, 5984>, 0,
    <5987, 5984, 5983>, 0,
    <5987, 5983, 5985>, 0,
    <5987, 5985, 5346>, 0,
    <5987, 5346, 5956>, 0,
    <5987, 5956, 5952>, 0,
    <5987, 5952, 5986>, 0,
    <5991, 5990, 5982>, 0,
    <5991, 5982, 5986>, 0,
    <5991, 5986, 5952>, 0,
    <5991, 5952, 5953>, 0,
    <5991, 5953, 5944>, 0,
    <5991, 5944, 5989>, 0,
    <5991, 5989, 5988>, 0,
    <5991, 5988, 5990>, 0,
    <5995, 5984, 5982>, 0,
    <5995, 5982, 5990>, 0,
    <5995, 5990, 5988>, 0,
    <5995, 5988, 5993>, 0,
    <5995, 5993, 5992>, 0,
    <5995, 5992, 5994>, 0,
    <5995, 5994, 5983>, 0,
    <5995, 5983, 5984>, 0,
    <5999, 5998, 5996>, 0,
    <5999, 5996, 5997>, 0,
    <5999, 5997, 5408>, 0,
    <5999, 5408, 5409>, 0,
    <5999, 5409, 5346>, 0,
    <5999, 5346, 5985>, 0,
    <5999, 5985, 5983>, 0,
    <5999, 5983, 5998>, 0,
    <6003, 6002, 5996>, 0,
    <6003, 5996, 5998>, 0,
    <6003, 5998, 5983>, 0,
    <6003, 5983, 5994>, 0,
    <6003, 5994, 5992>, 0,
    <6003, 5992, 6001>, 0,
    <6003, 6001, 6000>, 0,
    <6003, 6000, 6002>, 0,
    <6005, 5997, 5996>, 0,
    <6005, 5996, 6002>, 0,
    <6005, 6002, 6000>, 0,
    <6005, 6000, 6004>, 0,
    <6005, 6004, 5412>, 0,
    <6005, 5412, 5413>, 0,
    <6005, 5413, 5408>, 0,
    <6005, 5408, 5997>, 0,
    <6014, 6013, 6006>, 0,
    <6014, 6006, 6010>, 0,
    <6014, 6010, 6007>, 0,
    <6014, 6007, 6011>, 0,
    <6014, 6011, 6008>, 0,
    <6014, 6008, 6012>, 0,
    <6014, 6012, 6009>, 0,
    <6014, 6009, 6013>, 0,
    <6017, 6016, 6006>, 0,
    <6017, 6006, 6013>, 0,
    <6017, 6013, 6009>, 0,
    <6017, 6009, 6015>, 0,
    <6017, 6015, 5428>, 0,
    <6017, 5428, 5527>, 0,
    <6017, 5527, 5525>, 0,
    <6017, 5525, 6016>, 0,
    <6019, 6010, 6006>, 0,
    <6019, 6006, 6016>, 0,
    <6019, 6016, 5525>, 0,
    <6019, 5525, 5532>, 0,
    <6019, 5532, 374>, 0,
    <6019, 374, 6018>, 0,
    <6019, 6018, 6007>, 0,
    <6019, 6007, 6010>, 0,
    <6025, 6024, 6020>, 0,
    <6025, 6020, 6022>, 0,
    <6025, 6022, 6021>, 0,
    <6025, 6021, 6023>, 0,
    <6025, 6023, 5960>, 0,
    <6025, 5960, 5963>, 0,
    <6025, 5963, 5959>, 0,
    <6025, 5959, 6024>, 0,
    <6027, 6026, 6020>, 0,
    <6027, 6020, 6024>, 0,
    <6027, 6024, 5959>, 0,
    <6027, 5959, 5970>, 0,
    <6027, 5970, 5428>, 0,
    <6027, 5428, 6015>, 0,
    <6027, 6015, 6009>, 0,
    <6027, 6009, 6026>, 0,
    <6029, 6022, 6020>, 0,
    <6029, 6020, 6026>, 0,
    <6029, 6026, 6009>, 0,
    <6029, 6009, 6012>, 0,
    <6029, 6012, 6008>, 0,
    <6029, 6008, 6028>, 0,
    <6029, 6028, 6021>, 0,
    <6029, 6021, 6022>, 0,
    <6035, 6034, 6030>, 0,
    <6035, 6030, 6032>, 0,
    <6035, 6032, 6031>, 0,
    <6035, 6031, 6033>, 0,
    <6035, 6033, 5412>, 0,
    <6035, 5412, 6004>, 0,
    <6035, 6004, 6000>, 0,
    <6035, 6000, 6034>, 0,
    <6039, 6038, 6030>, 0,
    <6039, 6030, 6034>, 0,
    <6039, 6034, 6000>, 0,
    <6039, 6000, 6001>, 0,
    <6039, 6001, 5992>, 0,
    <6039, 5992, 6037>, 0,
    <6039, 6037, 6036>, 0,
    <6039, 6036, 6038>, 0,
    <6042, 6032, 6030>, 0,
    <6042, 6030, 6038>, 0,
    <6042, 6038, 6036>, 0,
    <6042, 6036, 6040>, 0,
    <6042, 6040, 559>, 0,
    <6042, 559, 6041>, 0,
    <6042, 6041, 6031>, 0,
    <6042, 6031, 6032>, 0,
    <6046, 6045, 6043>, 0,
    <6046, 6043, 6044>, 0,
    <6046, 6044, 5507>, 0,
    <6046, 5507, 5508>, 0,
    <6046, 5508, 5412>, 0,
    <6046, 5412, 6033>, 0,
    <6046, 6033, 6031>, 0,
    <6046, 6031, 6045>, 0,
    <6048, 6047, 6043>, 0,
    <6048, 6043, 6045>, 0,
    <6048, 6045, 6031>, 0,
    <6048, 6031, 6041>, 0,
    <6048, 6041, 559>, 0,
    <6048, 559, 590>, 0,
    <6048, 590, 586>, 0,
    <6048, 586, 6047>, 0,
    <6049, 6044, 6043>, 0,
    <6049, 6043, 6047>, 0,
    <6049, 6047, 586>, 0,
    <6049, 586, 587>, 0,
    <6049, 587, 348>, 0,
    <6049, 348, 5511>, 0,
    <6049, 5511, 5507>, 0,
    <6049, 5507, 6044>, 0,
    <6055, 6054, 6050>, 0,
    <6055, 6050, 6052>, 0,
    <6055, 6052, 6051>, 0,
    <6055, 6051, 6053>, 0,
    <6055, 6053, 6008>, 0,
    <6055, 6008, 6011>, 0,
    <6055, 6011, 6007>, 0,
    <6055, 6007, 6054>, 0,
    <6057, 6056, 6050>, 0,
    <6057, 6050, 6054>, 0,
    <6057, 6054, 6007>, 0,
    <6057, 6007, 6018>, 0,
    <6057, 6018, 374>, 0,
    <6057, 374, 618>, 0,
    <6057, 618, 614>, 0,
    <6057, 614, 6056>, 0,
    <6059, 6052, 6050>, 0,
    <6059, 6050, 6056>, 0,
    <6059, 6056, 614>, 0,
    <6059, 614, 615>, 0,
    <6059, 615, 601>, 0,
    <6059, 601, 6058>, 0,
    <6059, 6058, 6051>, 0,
    <6059, 6051, 6052>, 0,
    <6068, 6067, 6060>, 0,
    <6068, 6060, 6064>, 0,
    <6068, 6064, 6061>, 0,
    <6068, 6061, 6065>, 0,
    <6068, 6065, 6062>, 0,
    <6068, 6062, 6066>, 0,
    <6068, 6066, 6063>, 0,
    <6068, 6063, 6067>, 0,
    <6074, 6073, 6060>, 0,
    <6074, 6060, 6067>, 0,
    <6074, 6067, 6063>, 0,
    <6074, 6063, 6071>, 0,
    <6074, 6071, 6069>, 0,
    <6074, 6069, 6072>, 0,
    <6074, 6072, 6070>, 0,
    <6074, 6070, 6073>, 0,
    <6077, 6064, 6060>, 0,
    <6077, 6060, 6073>, 0,
    <6077, 6073, 6070>, 0,
    <6077, 6070, 6075>, 0,
    <6077, 6075, 482>, 0,
    <6077, 482, 6076>, 0,
    <6077, 6076, 6061>, 0,
    <6077, 6061, 6064>, 0,
    <6083, 6082, 6078>, 0,
    <6083, 6078, 6080>, 0,
    <6083, 6080, 6063>, 0,
    <6083, 6063, 6066>, 0,
    <6083, 6066, 6062>, 0,
    <6083, 6062, 6081>, 0,
    <6083, 6081, 6079>, 0,
    <6083, 6079, 6082>, 0,
    <6088, 6087, 6078>, 0,
    <6088, 6078, 6082>, 0,
    <6088, 6082, 6079>, 0,
    <6088, 6079, 6085>, 0,
    <6088, 6085, 5390>, 0,
    <6088, 5390, 6086>, 0,
    <6088, 6086, 6084>, 0,
    <6088, 6084, 6087>, 0,
    <6090, 6080, 6078>, 0,
    <6090, 6078, 6087>, 0,
    <6090, 6087, 6084>, 0,
    <6090, 6084, 6089>, 0,
    <6090, 6089, 6069>, 0,
    <6090, 6069, 6071>, 0,
    <6090, 6071, 6063>, 0,
    <6090, 6063, 6080>, 0,
    <6094, 6093, 6091>, 0,
    <6094, 6091, 6092>, 0,
    <6094, 6092, 6084>, 0,
    <6094, 6084, 6086>, 0,
    <6094, 6086, 5390>, 0,
    <6094, 5390, 5393>, 0,
    <6094, 5393, 5389>, 0,
    <6094, 5389, 6093>, 0,
    <6098, 6097, 6091>, 0,
    <6098, 6091, 6093>, 0,
    <6098, 6093, 5389>, 0,
    <6098, 5389, 5400>, 0,
    <6098, 5400, 4833>, 0,
    <6098, 4833, 6096>, 0,
    <6098, 6096, 6095>, 0,
    <6098, 6095, 6097>, 0,
    <6100, 6092, 6091>, 0,
    <6100, 6091, 6097>, 0,
    <6100, 6097, 6095>, 0,
    <6100, 6095, 6099>, 0,
    <6100, 6099, 6069>, 0,
    <6100, 6069, 6089>, 0,
    <6100, 6089, 6084>, 0,
    <6100, 6084, 6092>, 0,
    <6106, 6105, 6101>, 0,
    <6106, 6101, 6103>, 0,
    <6106, 6103, 5537>, 0,
    <6106, 5537, 5540>, 0,
    <6106, 5540, 5536>, 0,
    <6106, 5536, 6104>, 0,
    <6106, 6104, 6102>, 0,
    <6106, 6102, 6105>, 0,
    <6112, 6111, 6101>, 0,
    <6112, 6101, 6105>, 0,
    <6112, 6105, 6102>, 0,
    <6112, 6102, 6109>, 0,
    <6112, 6109, 6107>, 0,
    <6112, 6107, 6110>, 0,
    <6112, 6110, 6108>, 0,
    <6112, 6108, 6111>, 0,
    <6114, 6103, 6101>, 0,
    <6114, 6101, 6111>, 0,
    <6114, 6111, 6108>, 0,
    <6114, 6108, 6113>, 0,
    <6114, 6113, 4871>, 0,
    <6114, 4871, 5543>, 0,
    <6114, 5543, 5537>, 0,
    <6114, 5537, 6103>, 0,
    <6120, 6119, 6115>, 0,
    <6120, 6115, 6117>, 0,
    <6120, 6117, 6102>, 0,
    <6120, 6102, 6104>, 0,
    <6120, 6104, 5536>, 0,
    <6120, 5536, 6118>, 0,
    <6120, 6118, 6116>, 0,
    <6120, 6116, 6119>, 0,
    <6126, 6125, 6115>, 0,
    <6126, 6115, 6119>, 0,
    <6126, 6119, 6116>, 0,
    <6126, 6116, 6123>, 0,
    <6126, 6123, 6121>, 0,
    <6126, 6121, 6124>, 0,
    <6126, 6124, 6122>, 0,
    <6126, 6122, 6125>, 0,
    <6128, 6117, 6115>, 0,
    <6128, 6115, 6125>, 0,
    <6128, 6125, 6122>, 0,
    <6128, 6122, 6127>, 0,
    <6128, 6127, 6107>, 0,
    <6128, 6107, 6109>, 0,
    <6128, 6109, 6102>, 0,
    <6128, 6102, 6117>, 0,
    <6134, 6133, 6129>, 0,
    <6134, 6129, 6131>, 0,
    <6134, 6131, 6108>, 0,
    <6134, 6108, 6110>, 0,
    <6134, 6110, 6107>, 0,
    <6134, 6107, 6132>, 0,
    <6134, 6132, 6130>, 0,
    <6134, 6130, 6133>, 0,
    <6137, 6136, 6129>, 0,
    <6137, 6129, 6133>, 0,
    <6137, 6133, 6130>, 0,
    <6137, 6130, 6135>, 0,
    <6137, 6135, 5163>, 0,
    <6137, 5163, 5181>, 0,
    <6137, 5181, 5176>, 0,
    <6137, 5176, 6136>, 0,
    <6138, 6131, 6129>, 0,
    <6138, 6129, 6136>, 0,
    <6138, 6136, 5176>, 0,
    <6138, 5176, 5178>, 0,
    <6138, 5178, 4871>, 0,
    <6138, 4871, 6113>, 0,
    <6138, 6113, 6108>, 0,
    <6138, 6108, 6131>, 0,
    <6144, 6143, 6139>, 0,
    <6144, 6139, 6141>, 0,
    <6144, 6141, 6122>, 0,
    <6144, 6122, 6124>, 0,
    <6144, 6124, 6121>, 0,
    <6144, 6121, 6142>, 0,
    <6144, 6142, 6140>, 0,
    <6144, 6140, 6143>, 0,
    <6149, 6148, 6139>, 0,
    <6149, 6139, 6143>, 0,
    <6149, 6143, 6140>, 0,
    <6149, 6140, 6146>, 0,
    <6149, 6146, 524>, 0,
    <6149, 524, 6147>, 0,
    <6149, 6147, 6145>, 0,
    <6149, 6145, 6148>, 0,
    <6151, 6141, 6139>, 0,
    <6151, 6139, 6148>, 0,
    <6151, 6148, 6145>, 0,
    <6151, 6145, 6150>, 0,
    <6151, 6150, 6107>, 0,
    <6151, 6107, 6127>, 0,
    <6151, 6127, 6122>, 0,
    <6151, 6122, 6141>, 0,
    <6159, 6158, 6152>, 0,
    <6159, 6152, 6155>, 0,
    <6159, 6155, 6153>, 0,
    <6159, 6153, 6156>, 0,
    <6159, 6156, 518>, 0,
    <6159, 518, 6157>, 0,
    <6159, 6157, 6154>, 0,
    <6159, 6154, 6158>, 0,
    <6162, 6161, 6152>, 0,
    <6162, 6152, 6158>, 0,
    <6162, 6158, 6154>, 0,
    <6162, 6154, 6160>, 0,
    <6162, 6160, 5742>, 0,
    <6162, 5742, 5745>, 0,
    <6162, 5745, 5741>, 0,
    <6162, 5741, 6161>, 0,
    <6164, 6155, 6152>, 0,
    <6164, 6152, 6161>, 0,
    <6164, 6161, 5741>, 0,
    <6164, 5741, 5752>, 0,
    <6164, 5752, 5314>, 0,
    <6164, 5314, 6163>, 0,
    <6164, 6163, 6153>, 0,
    <6164, 6153, 6155>, 0,
    <6170, 6169, 6165>, 0,
    <6170, 6165, 6167>, 0,
    <6170, 6167, 6095>, 0,
    <6170, 6095, 6096>, 0,
    <6170, 6096, 4833>, 0,
    <6170, 4833, 6168>, 0,
    <6170, 6168, 6166>, 0,
    <6170, 6166, 6169>, 0,
    <6176, 6175, 6165>, 0,
    <6176, 6165, 6169>, 0,
    <6176, 6169, 6166>, 0,
    <6176, 6166, 6173>, 0,
    <6176, 6173, 6171>, 0,
    <6176, 6171, 6174>, 0,
    <6176, 6174, 6172>, 0,
    <6176, 6172, 6175>, 0,
    <6178, 6167, 6165>, 0,
    <6178, 6165, 6175>, 0,
    <6178, 6175, 6172>, 0,
    <6178, 6172, 6177>, 0,
    <6178, 6177, 6069>, 0,
    <6178, 6069, 6099>, 0,
    <6178, 6099, 6095>, 0,
    <6178, 6095, 6167>, 0,
    <6182, 6181, 6179>, 0,
    <6182, 6179, 6180>, 0,
    <6182, 6180, 6166>, 0,
    <6182, 6166, 6168>, 0,
    <6182, 6168, 4833>, 0,
    <6182, 4833, 5149>, 0,
    <6182, 5149, 5144>, 0,
    <6182, 5144, 6181>, 0,
    <6186, 6185, 6179>, 0,
    <6186, 6179, 6181>, 0,
    <6186, 6181, 5144>, 0,
    <6186, 5144, 5146>, 0,
    <6186, 5146, 5143>, 0,
    <6186, 5143, 6184>, 0,
    <6186, 6184, 6183>, 0,
    <6186, 6183, 6185>, 0,
    <6188, 6180, 6179>, 0,
    <6188, 6179, 6185>, 0,
    <6188, 6185, 6183>, 0,
    <6188, 6183, 6187>, 0,
    <6188, 6187, 6171>, 0,
    <6188, 6171, 6173>, 0,
    <6188, 6173, 6166>, 0,
    <6188, 6166, 6180>, 0,
    <6197, 6196, 6189>, 0,
    <6197, 6189, 6193>, 0,
    <6197, 6193, 6190>, 0,
    <6197, 6190, 6194>, 0,
    <6197, 6194, 6191>, 0,
    <6197, 6191, 6195>, 0,
    <6197, 6195, 6192>, 0,
    <6197, 6192, 6196>, 0,
    <6200, 6199, 6189>, 0,
    <6200, 6189, 6196>, 0,
    <6200, 6196, 6192>, 0,
    <6200, 6192, 6198>, 0,
    <6200, 6198, 5479>, 0,
    <6200, 5479, 5497>, 0,
    <6200, 5497, 5492>, 0,
    <6200, 5492, 6199>, 0,
    <6202, 6193, 6189>, 0,
    <6202, 6189, 6199>, 0,
    <6202, 6199, 5492>, 0,
    <6202, 5492, 5494>, 0,
    <6202, 5494, 5163>, 0,
    <6202, 5163, 6201>, 0,
    <6202, 6201, 6190>, 0,
    <6202, 6190, 6193>, 0,
    <6208, 6207, 6203>, 0,
    <6208, 6203, 6205>, 0,
    <6208, 6205, 6130>, 0,
    <6208, 6130, 6132>, 0,
    <6208, 6132, 6107>, 0,
    <6208, 6107, 6206>, 0,
    <6208, 6206, 6204>, 0,
    <6208, 6204, 6207>, 0,
    <6211, 6210, 6203>, 0,
    <6211, 6203, 6207>, 0,
    <6211, 6207, 6204>, 0,
    <6211, 6204, 6209>, 0,
    <6211, 6209, 6191>, 0,
    <6211, 6191, 6194>, 0,
    <6211, 6194, 6190>, 0,
    <6211, 6190, 6210>, 0,
    <6212, 6205, 6203>, 0,
    <6212, 6203, 6210>, 0,
    <6212, 6210, 6190>, 0,
    <6212, 6190, 6201>, 0,
    <6212, 6201, 5163>, 0,
    <6212, 5163, 6135>, 0,
    <6212, 6135, 6130>, 0,
    <6212, 6130, 6205>, 0,
    <6220, 6219, 6213>, 0,
    <6220, 6213, 6216>, 0,
    <6220, 6216, 6214>, 0,
    <6220, 6214, 6217>, 0,
    <6220, 6217, 647>, 0,
    <6220, 647, 6218>, 0,
    <6220, 6218, 6215>, 0,
    <6220, 6215, 6219>, 0,
    <6225, 6224, 6213>, 0,
    <6225, 6213, 6219>, 0,
    <6225, 6219, 6215>, 0,
    <6225, 6215, 6222>, 0,
    <6225, 6222, 489>, 0,
    <6225, 489, 6223>, 0,
    <6225, 6223, 6221>, 0,
    <6225, 6221, 6224>, 0,
    <6229, 6216, 6213>, 0,
    <6229, 6213, 6224>, 0,
    <6229, 6224, 6221>, 0,
    <6229, 6221, 6227>, 0,
    <6229, 6227, 6226>, 0,
    <6229, 6226, 6228>, 0,
    <6229, 6228, 6214>, 0,
    <6229, 6214, 6216>, 0,
    <6237, 6236, 6230>, 0,
    <6237, 6230, 6233>, 0,
    <6237, 6233, 6231>, 0,
    <6237, 6231, 6234>, 0,
    <6237, 6234, 187>, 0,
    <6237, 187, 6235>, 0,
    <6237, 6235, 6232>, 0,
    <6237, 6232, 6236>, 0,
    <6240, 6239, 6230>, 0,
    <6240, 6230, 6236>, 0,
    <6240, 6236, 6232>, 0,
    <6240, 6232, 6238>, 0,
    <6240, 6238, 647>, 0,
    <6240, 647, 6217>, 0,
    <6240, 6217, 6214>, 0,
    <6240, 6214, 6239>, 0,
    <6242, 6233, 6230>, 0,
    <6242, 6230, 6239>, 0,
    <6242, 6239, 6214>, 0,
    <6242, 6214, 6228>, 0,
    <6242, 6228, 6226>, 0,
    <6242, 6226, 6241>, 0,
    <6242, 6241, 6231>, 0,
    <6242, 6231, 6233>, 0,
    <6246, 6245, 6243>, 0,
    <6246, 6243, 6244>, 0,
    <6246, 6244, 5280>, 0,
    <6246, 5280, 5282>, 0,
    <6246, 5282, 187>, 0,
    <6246, 187, 6234>, 0,
    <6246, 6234, 6231>, 0,
    <6246, 6231, 6245>, 0,
    <6250, 6249, 6243>, 0,
    <6250, 6243, 6245>, 0,
    <6250, 6245, 6231>, 0,
    <6250, 6231, 6241>, 0,
    <6250, 6241, 6226>, 0,
    <6250, 6226, 6248>, 0,
    <6250, 6248, 6247>, 0,
    <6250, 6247, 6249>, 0,
    <6252, 6244, 6243>, 0,
    <6252, 6243, 6249>, 0,
    <6252, 6249, 6247>, 0,
    <6252, 6247, 6251>, 0,
    <6252, 6251, 5285>, 0,
    <6252, 5285, 5286>, 0,
    <6252, 5286, 5280>, 0,
    <6252, 5280, 6244>, 0,
    <6261, 6260, 6253>, 0,
    <6261, 6253, 6257>, 0,
    <6261, 6257, 6254>, 0,
    <6261, 6254, 6258>, 0,
    <6261, 6258, 6255>, 0,
    <6261, 6255, 6259>, 0,
    <6261, 6259, 6256>, 0,
    <6261, 6256, 6260>, 0,
    <6264, 6263, 6253>, 0,
    <6264, 6253, 6260>, 0,
    <6264, 6260, 6256>, 0,
    <6264, 6256, 6262>, 0,
    <6264, 6262, 5314>, 0,
    <6264, 5314, 5589>, 0,
    <6264, 5589, 5587>, 0,
    <6264, 5587, 6263>, 0,
    <6266, 6257, 6253>, 0,
    <6266, 6253, 6263>, 0,
    <6266, 6263, 5587>, 0,
    <6266, 5587, 5594>, 0,
    <6266, 5594, 5574>, 0,
    <6266, 5574, 6265>, 0,
    <6266, 6265, 6254>, 0,
    <6266, 6254, 6257>, 0,
    <6272, 6271, 6267>, 0,
    <6272, 6267, 6269>, 0,
    <6272, 6269, 6268>, 0,
    <6272, 6268, 6270>, 0,
    <6272, 6270, 518>, 0,
    <6272, 518, 6156>, 0,
    <6272, 6156, 6153>, 0,
    <6272, 6153, 6271>, 0,
    <6274, 6273, 6267>, 0,
    <6274, 6267, 6271>, 0,
    <6274, 6271, 6153>, 0,
    <6274, 6153, 6163>, 0,
    <6274, 6163, 5314>, 0,
    <6274, 5314, 6262>, 0,
    <6274, 6262, 6256>, 0,
    <6274, 6256, 6273>, 0,
    <6276, 6269, 6267>, 0,
    <6276, 6267, 6273>, 0,
    <6276, 6273, 6256>, 0,
    <6276, 6256, 6259>, 0,
    <6276, 6259, 6255>, 0,
    <6276, 6255, 6275>, 0,
    <6276, 6275, 6268>, 0,
    <6276, 6268, 6269>, 0,
    <6282, 6281, 6277>, 0,
    <6282, 6277, 6279>, 0,
    <6282, 6279, 6183>, 0,
    <6282, 6183, 6184>, 0,
    <6282, 6184, 5143>, 0,
    <6282, 5143, 6280>, 0,
    <6282, 6280, 6278>, 0,
    <6282, 6278, 6281>, 0,
    <6288, 6287, 6277>, 0,
    <6288, 6277, 6281>, 0,
    <6288, 6281, 6278>, 0,
    <6288, 6278, 6285>, 0,
    <6288, 6285, 6283>, 0,
    <6288, 6283, 6286>, 0,
    <6288, 6286, 6284>, 0,
    <6288, 6284, 6287>, 0,
    <6290, 6279, 6277>, 0,
    <6290, 6277, 6287>, 0,
    <6290, 6287, 6284>, 0,
    <6290, 6284, 6289>, 0,
    <6290, 6289, 6171>, 0,
    <6290, 6171, 6187>, 0,
    <6290, 6187, 6183>, 0,
    <6290, 6183, 6279>, 0,
    <6294, 6293, 6291>, 0,
    <6294, 6291, 6292>, 0,
    <6294, 6292, 6278>, 0,
    <6294, 6278, 6280>, 0,
    <6294, 6280, 5143>, 0,
    <6294, 5143, 5465>, 0,
    <6294, 5465, 5460>, 0,
    <6294, 5460, 6293>, 0,
    <6298, 6297, 6291>, 0,
    <6298, 6291, 6293>, 0,
    <6298, 6293, 5460>, 0,
    <6298, 5460, 5462>, 0,
    <6298, 5462, 5459>, 0,
    <6298, 5459, 6296>, 0,
    <6298, 6296, 6295>, 0,
    <6298, 6295, 6297>, 0,
    <6300, 6292, 6291>, 0,
    <6300, 6291, 6297>, 0,
    <6300, 6297, 6295>, 0,
    <6300, 6295, 6299>, 0,
    <6300, 6299, 6283>, 0,
    <6300, 6283, 6285>, 0,
    <6300, 6285, 6278>, 0,
    <6300, 6278, 6292>, 0,
    <6309, 6308, 6301>, 0,
    <6309, 6301, 6305>, 0,
    <6309, 6305, 6302>, 0,
    <6309, 6302, 6306>, 0,
    <6309, 6306, 6303>, 0,
    <6309, 6303, 6307>, 0,
    <6309, 6307, 6304>, 0,
    <6309, 6304, 6308>, 0,
    <6312, 6311, 6301>, 0,
    <6312, 6301, 6308>, 0,
    <6312, 6308, 6304>, 0,
    <6312, 6304, 6310>, 0,
    <6312, 6310, 5622>, 0,
    <6312, 5622, 5640>, 0,
    <6312, 5640, 5635>, 0,
    <6312, 5635, 6311>, 0,
    <6314, 6305, 6301>, 0,
    <6314, 6301, 6311>, 0,
    <6314, 6311, 5635>, 0,
    <6314, 5635, 5637>, 0,
    <6314, 5637, 5479>, 0,
    <6314, 5479, 6313>, 0,
    <6314, 6313, 6302>, 0,
    <6314, 6302, 6305>, 0,
    <6320, 6319, 6315>, 0,
    <6320, 6315, 6317>, 0,
    <6320, 6317, 6192>, 0,
    <6320, 6192, 6195>, 0,
    <6320, 6195, 6191>, 0,
    <6320, 6191, 6318>, 0,
    <6320, 6318, 6316>, 0,
    <6320, 6316, 6319>, 0,
    <6323, 6322, 6315>, 0,
    <6323, 6315, 6319>, 0,
    <6323, 6319, 6316>, 0,
    <6323, 6316, 6321>, 0,
    <6323, 6321, 6303>, 0,
    <6323, 6303, 6306>, 0,
    <6323, 6306, 6302>, 0,
    <6323, 6302, 6322>, 0,
    <6324, 6317, 6315>, 0,
    <6324, 6315, 6322>, 0,
    <6324, 6322, 6302>, 0,
    <6324, 6302, 6313>, 0,
    <6324, 6313, 5479>, 0,
    <6324, 5479, 6198>, 0,
    <6324, 6198, 6192>, 0,
    <6324, 6192, 6317>, 0,
    <6330, 6329, 6325>, 0,
    <6330, 6325, 6327>, 0,
    <6330, 6327, 6326>, 0,
    <6330, 6326, 6328>, 0,
    <6330, 6328, 5285>, 0,
    <6330, 5285, 6251>, 0,
    <6330, 6251, 6247>, 0,
    <6330, 6247, 6329>, 0,
    <6334, 6333, 6325>, 0,
    <6334, 6325, 6329>, 0,
    <6334, 6329, 6247>, 0,
    <6334, 6247, 6248>, 0,
    <6334, 6248, 6226>, 0,
    <6334, 6226, 6332>, 0,
    <6334, 6332, 6331>, 0,
    <6334, 6331, 6333>, 0,
    <6338, 6327, 6325>, 0,
    <6338, 6325, 6333>, 0,
    <6338, 6333, 6331>, 0,
    <6338, 6331, 6336>, 0,
    <6338, 6336, 6335>, 0,
    <6338, 6335, 6337>, 0,
    <6338, 6337, 6326>, 0,
    <6338, 6326, 6327>, 0,
    <6342, 6341, 6339>, 0,
    <6342, 6339, 6340>, 0,
    <6342, 6340, 5554>, 0,
    <6342, 5554, 5555>, 0,
    <6342, 5555, 5285>, 0,
    <6342, 5285, 6328>, 0,
    <6342, 6328, 6326>, 0,
    <6342, 6326, 6341>, 0,
    <6346, 6345, 6339>, 0,
    <6346, 6339, 6341>, 0,
    <6346, 6341, 6326>, 0,
    <6346, 6326, 6337>, 0,
    <6346, 6337, 6335>, 0,
    <6346, 6335, 6344>, 0,
    <6346, 6344, 6343>, 0,
    <6346, 6343, 6345>, 0,
    <6348, 6340, 6339>, 0,
    <6348, 6339, 6345>, 0,
    <6348, 6345, 6343>, 0,
    <6348, 6343, 6347>, 0,
    <6348, 6347, 5558>, 0,
    <6348, 5558, 5559>, 0,
    <6348, 5559, 5554>, 0,
    <6348, 5554, 6340>, 0,
    <6357, 6356, 6349>, 0,
    <6357, 6349, 6353>, 0,
    <6357, 6353, 6350>, 0,
    <6357, 6350, 6354>, 0,
    <6357, 6354, 6351>, 0,
    <6357, 6351, 6355>, 0,
    <6357, 6355, 6352>, 0,
    <6357, 6352, 6356>, 0,
    <6360, 6359, 6349>, 0,
    <6360, 6349, 6356>, 0,
    <6360, 6356, 6352>, 0,
    <6360, 6352, 6358>, 0,
    <6360, 6358, 5574>, 0,
    <6360, 5574, 5685>, 0,
    <6360, 5685, 5683>, 0,
    <6360, 5683, 6359>, 0,
    <6362, 6353, 6349>, 0,
    <6362, 6349, 6359>, 0,
    <6362, 6359, 5683>, 0,
    <6362, 5683, 5690>, 0,
    <6362, 5690, 5670>, 0,
    <6362, 5670, 6361>, 0,
    <6362, 6361, 6350>, 0,
    <6362, 6350, 6353>, 0,
    <6368, 6367, 6363>, 0,
    <6368, 6363, 6365>, 0,
    <6368, 6365, 6364>, 0,
    <6368, 6364, 6366>, 0,
    <6368, 6366, 6255>, 0,
    <6368, 6255, 6258>, 0,
    <6368, 6258, 6254>, 0,
    <6368, 6254, 6367>, 0,
    <6370, 6369, 6363>, 0,
    <6370, 6363, 6367>, 0,
    <6370, 6367, 6254>, 0,
    <6370, 6254, 6265>, 0,
    <6370, 6265, 5574>, 0,
    <6370, 5574, 6358>, 0,
    <6370, 6358, 6352>, 0,
    <6370, 6352, 6369>, 0,
    <6372, 6365, 6363>, 0,
    <6372, 6363, 6369>, 0,
    <6372, 6369, 6352>, 0,
    <6372, 6352, 6355>, 0,
    <6372, 6355, 6351>, 0,
    <6372, 6351, 6371>, 0,
    <6372, 6371, 6364>, 0,
    <6372, 6364, 6365>, 0,
    <6378, 6377, 6373>, 0,
    <6378, 6373, 6375>, 0,
    <6378, 6375, 6295>, 0,
    <6378, 6295, 6296>, 0,
    <6378, 6296, 5459>, 0,
    <6378, 5459, 6376>, 0,
    <6378, 6376, 6374>, 0,
    <6378, 6374, 6377>, 0,
    <6384, 6383, 6373>, 0,
    <6384, 6373, 6377>, 0,
    <6384, 6377, 6374>, 0,
    <6384, 6374, 6381>, 0,
    <6384, 6381, 6379>, 0,
    <6384, 6379, 6382>, 0,
    <6384, 6382, 6380>, 0,
    <6384, 6380, 6383>, 0,
    <6386, 6375, 6373>, 0,
    <6386, 6373, 6383>, 0,
    <6386, 6383, 6380>, 0,
    <6386, 6380, 6385>, 0,
    <6386, 6385, 6283>, 0,
    <6386, 6283, 6299>, 0,
    <6386, 6299, 6295>, 0,
    <6386, 6295, 6375>, 0,
    <6390, 6389, 6387>, 0,
    <6390, 6387, 6388>, 0,
    <6390, 6388, 6374>, 0,
    <6390, 6374, 6376>, 0,
    <6390, 6376, 5459>, 0,
    <6390, 5459, 5608>, 0,
    <6390, 5608, 5603>, 0,
    <6390, 5603, 6389>, 0,
    <6394, 6393, 6387>, 0,
    <6394, 6387, 6389>, 0,
    <6394, 6389, 5603>, 0,
    <6394, 5603, 5605>, 0,
    <6394, 5605, 5602>, 0,
    <6394, 5602, 6392>, 0,
    <6394, 6392, 6391>, 0,
    <6394, 6391, 6393>, 0,
    <6396, 6388, 6387>, 0,
    <6396, 6387, 6393>, 0,
    <6396, 6393, 6391>, 0,
    <6396, 6391, 6395>, 0,
    <6396, 6395, 6379>, 0,
    <6396, 6379, 6381>, 0,
    <6396, 6381, 6374>, 0,
    <6396, 6374, 6388>, 0,
    <6405, 6404, 6397>, 0,
    <6405, 6397, 6401>, 0,
    <6405, 6401, 6398>, 0,
    <6405, 6398, 6402>, 0,
    <6405, 6402, 6399>, 0,
    <6405, 6399, 6403>, 0,
    <6405, 6403, 6400>, 0,
    <6405, 6400, 6404>, 0,
    <6408, 6407, 6397>, 0,
    <6408, 6397, 6404>, 0,
    <6408, 6404, 6400>, 0,
    <6408, 6400, 6406>, 0,
    <6408, 6406, 5718>, 0,
    <6408, 5718, 5736>, 0,
    <6408, 5736, 5731>, 0,
    <6408, 5731, 6407>, 0,
    <6410, 6401, 6397>, 0,
    <6410, 6397, 6407>, 0,
    <6410, 6407, 5731>, 0,
    <6410, 5731, 5733>, 0,
    <6410, 5733, 5622>, 0,
    <6410, 5622, 6409>, 0,
    <6410, 6409, 6398>, 0,
    <6410, 6398, 6401>, 0,
    <6416, 6415, 6411>, 0,
    <6416, 6411, 6413>, 0,
    <6416, 6413, 6304>, 0,
    <6416, 6304, 6307>, 0,
    <6416, 6307, 6303>, 0,
    <6416, 6303, 6414>, 0,
    <6416, 6414, 6412>, 0,
    <6416, 6412, 6415>, 0,
    <6419, 6418, 6411>, 0,
    <6419, 6411, 6415>, 0,
    <6419, 6415, 6412>, 0,
    <6419, 6412, 6417>, 0,
    <6419, 6417, 6399>, 0,
    <6419, 6399, 6402>, 0,
    <6419, 6402, 6398>, 0,
    <6419, 6398, 6418>, 0,
    <6420, 6413, 6411>, 0,
    <6420, 6411, 6418>, 0,
    <6420, 6418, 6398>, 0,
    <6420, 6398, 6409>, 0,
    <6420, 6409, 5622>, 0,
    <6420, 5622, 6310>, 0,
    <6420, 6310, 6304>, 0,
    <6420, 6304, 6413>, 0,
    <6429, 6428, 6421>, 0,
    <6429, 6421, 6425>, 0,
    <6429, 6425, 6422>, 0,
    <6429, 6422, 6426>, 0,
    <6429, 6426, 6423>, 0,
    <6429, 6423, 6427>, 0,
    <6429, 6427, 6424>, 0,
    <6429, 6424, 6428>, 0,
    <6432, 6431, 6421>, 0,
    <6432, 6421, 6428>, 0,
    <6432, 6428, 6424>, 0,
    <6432, 6424, 6430>, 0,
    <6432, 6430, 482>, 0,
    <6432, 482, 6075>, 0,
    <6432, 6075, 6070>, 0,
    <6432, 6070, 6431>, 0,
    <6434, 6425, 6421>, 0,
    <6434, 6421, 6431>, 0,
    <6434, 6431, 6070>, 0,
    <6434, 6070, 6072>, 0,
    <6434, 6072, 6069>, 0,
    <6434, 6069, 6433>, 0,
    <6434, 6433, 6422>, 0,
    <6434, 6422, 6425>, 0,
    <6440, 6439, 6435>, 0,
    <6440, 6435, 6437>, 0,
    <6440, 6437, 6436>, 0,
    <6440, 6436, 6438>, 0,
    <6440, 6438, 5558>, 0,
    <6440, 5558, 6347>, 0,
    <6440, 6347, 6343>, 0,
    <6440, 6343, 6439>, 0,
    <6444, 6443, 6435>, 0,
    <6444, 6435, 6439>, 0,
    <6444, 6439, 6343>, 0,
    <6444, 6343, 6344>, 0,
    <6444, 6344, 6335>, 0,
    <6444, 6335, 6442>, 0,
    <6444, 6442, 6441>, 0,
    <6444, 6441, 6443>, 0,
    <6448, 6437, 6435>, 0,
    <6448, 6435, 6443>, 0,
    <6448, 6443, 6441>, 0,
    <6448, 6441, 6446>, 0,
    <6448, 6446, 6445>, 0,
    <6448, 6445, 6447>, 0,
    <6448, 6447, 6436>, 0,
    <6448, 6436, 6437>, 0,
    <6452, 6451, 6449>, 0,
    <6452, 6449, 6450>, 0,
    <6452, 6450, 5650>, 0,
    <6452, 5650, 5651>, 0,
    <6452, 5651, 5558>, 0,
    <6452, 5558, 6438>, 0,
    <6452, 6438, 6436>, 0,
    <6452, 6436, 6451>, 0,
    <6456, 6455, 6449>, 0,
    <6456, 6449, 6451>, 0,
    <6456, 6451, 6436>, 0,
    <6456, 6436, 6447>, 0,
    <6456, 6447, 6445>, 0,
    <6456, 6445, 6454>, 0,
    <6456, 6454, 6453>, 0,
    <6456, 6453, 6455>, 0,
    <6458, 6450, 6449>, 0,
    <6458, 6449, 6455>, 0,
    <6458, 6455, 6453>, 0,
    <6458, 6453, 6457>, 0,
    <6458, 6457, 5654>, 0,
    <6458, 5654, 5655>, 0,
    <6458, 5655, 5650>, 0,
    <6458, 5650, 6450>, 0,
    <6467, 6466, 6459>, 0,
    <6467, 6459, 6463>, 0,
    <6467, 6463, 6460>, 0,
    <6467, 6460, 6464>, 0,
    <6467, 6464, 6461>, 0,
    <6467, 6461, 6465>, 0,
    <6467, 6465, 6462>, 0,
    <6467, 6462, 6466>, 0,
    <6470, 6469, 6459>, 0,
    <6470, 6459, 6466>, 0,
    <6470, 6466, 6462>, 0,
    <6470, 6462, 6468>, 0,
    <6470, 6468, 5670>, 0,
    <6470, 5670, 5843>, 0,
    <6470, 5843, 5841>, 0,
    <6470, 5841, 6469>, 0,
    <6472, 6463, 6459>, 0,
    <6472, 6459, 6469>, 0,
    <6472, 6469, 5841>, 0,
    <6472, 5841, 5848>, 0,
    <6472, 5848, 5828>, 0,
    <6472, 5828, 6471>, 0,
    <6472, 6471, 6460>, 0,
    <6472, 6460, 6463>, 0,
    <6478, 6477, 6473>, 0,
    <6478, 6473, 6475>, 0,
    <6478, 6475, 6474>, 0,
    <6478, 6474, 6476>, 0,
    <6478, 6476, 6351>, 0,
    <6478, 6351, 6354>, 0,
    <6478, 6354, 6350>, 0,
    <6478, 6350, 6477>, 0,
    <6480, 6479, 6473>, 0,
    <6480, 6473, 6477>, 0,
    <6480, 6477, 6350>, 0,
    <6480, 6350, 6361>, 0,
    <6480, 6361, 5670>, 0,
    <6480, 5670, 6468>, 0,
    <6480, 6468, 6462>, 0,
    <6480, 6462, 6479>, 0,
    <6482, 6475, 6473>, 0,
    <6482, 6473, 6479>, 0,
    <6482, 6479, 6462>, 0,
    <6482, 6462, 6465>, 0,
    <6482, 6465, 6461>, 0,
    <6482, 6461, 6481>, 0,
    <6482, 6481, 6474>, 0,
    <6482, 6474, 6475>, 0,
    <6488, 6487, 6483>, 0,
    <6488, 6483, 6485>, 0,
    <6488, 6485, 6391>, 0,
    <6488, 6391, 6392>, 0,
    <6488, 6392, 5602>, 0,
    <6488, 5602, 6486>, 0,
    <6488, 6486, 6484>, 0,
    <6488, 6484, 6487>, 0,
    <6494, 6493, 6483>, 0,
    <6494, 6483, 6487>, 0,
    <6494, 6487, 6484>, 0,
    <6494, 6484, 6491>, 0,
    <6494, 6491, 6489>, 0,
    <6494, 6489, 6492>, 0,
    <6494, 6492, 6490>, 0,
    <6494, 6490, 6493>, 0,
    <6496, 6485, 6483>, 0,
    <6496, 6483, 6493>, 0,
    <6496, 6493, 6490>, 0,
    <6496, 6490, 6495>, 0,
    <6496, 6495, 6379>, 0,
    <6496, 6379, 6395>, 0,
    <6496, 6395, 6391>, 0,
    <6496, 6391, 6485>, 0,
    <6500, 6499, 6497>, 0,
    <6500, 6497, 6498>, 0,
    <6500, 6498, 6484>, 0,
    <6500, 6484, 6486>, 0,
    <6500, 6486, 5602>, 0,
    <6500, 5602, 5704>, 0,
    <6500, 5704, 5699>, 0,
    <6500, 5699, 6499>, 0,
    <6504, 6503, 6497>, 0,
    <6504, 6497, 6499>, 0,
    <6504, 6499, 5699>, 0,
    <6504, 5699, 5701>, 0,
    <6504, 5701, 5698>, 0,
    <6504, 5698, 6502>, 0,
    <6504, 6502, 6501>, 0,
    <6504, 6501, 6503>, 0,
    <6506, 6498, 6497>, 0,
    <6506, 6497, 6503>, 0,
    <6506, 6503, 6501>, 0,
    <6506, 6501, 6505>, 0,
    <6506, 6505, 6489>, 0,
    <6506, 6489, 6491>, 0,
    <6506, 6491, 6484>, 0,
    <6506, 6484, 6498>, 0,
    <6515, 6514, 6507>, 0,
    <6515, 6507, 6511>, 0,
    <6515, 6511, 6508>, 0,
    <6515, 6508, 6512>, 0,
    <6515, 6512, 6509>, 0,
    <6515, 6509, 6513>, 0,
    <6515, 6513, 6510>, 0,
    <6515, 6510, 6514>, 0,
    <6518, 6517, 6507>, 0,
    <6518, 6507, 6514>, 0,
    <6518, 6514, 6510>, 0,
    <6518, 6510, 6516>, 0,
    <6518, 6516, 5780>, 0,
    <6518, 5780, 5798>, 0,
    <6518, 5798, 5793>, 0,
    <6518, 5793, 6517>, 0,
    <6520, 6511, 6507>, 0,
    <6520, 6507, 6517>, 0,
    <6520, 6517, 5793>, 0,
    <6520, 5793, 5795>, 0,
    <6520, 5795, 5718>, 0,
    <6520, 5718, 6519>, 0,
    <6520, 6519, 6508>, 0,
    <6520, 6508, 6511>, 0,
    <6526, 6525, 6521>, 0,
    <6526, 6521, 6523>, 0,
    <6526, 6523, 6400>, 0,
    <6526, 6400, 6403>, 0,
    <6526, 6403, 6399>, 0,
    <6526, 6399, 6524>, 0,
    <6526, 6524, 6522>, 0,
    <6526, 6522, 6525>, 0,
    <6529, 6528, 6521>, 0,
    <6529, 6521, 6525>, 0,
    <6529, 6525, 6522>, 0,
    <6529, 6522, 6527>, 0,
    <6529, 6527, 6509>, 0,
    <6529, 6509, 6512>, 0,
    <6529, 6512, 6508>, 0,
    <6529, 6508, 6528>, 0,
    <6530, 6523, 6521>, 0,
    <6530, 6521, 6528>, 0,
    <6530, 6528, 6508>, 0,
    <6530, 6508, 6519>, 0,
    <6530, 6519, 5718>, 0,
    <6530, 5718, 6406>, 0,
    <6530, 6406, 6400>, 0,
    <6530, 6400, 6523>, 0,
    <6539, 6538, 6531>, 0,
    <6539, 6531, 6535>, 0,
    <6539, 6535, 6532>, 0,
    <6539, 6532, 6536>, 0,
    <6539, 6536, 6533>, 0,
    <6539, 6533, 6537>, 0,
    <6539, 6537, 6534>, 0,
    <6539, 6534, 6538>, 0,
    <6542, 6541, 6531>, 0,
    <6542, 6531, 6538>, 0,
    <6542, 6538, 6534>, 0,
    <6542, 6534, 6540>, 0,
    <6542, 6540, 6107>, 0,
    <6542, 6107, 6150>, 0,
    <6542, 6150, 6145>, 0,
    <6542, 6145, 6541>, 0,
    <6544, 6535, 6531>, 0,
    <6544, 6531, 6541>, 0,
    <6544, 6541, 6145>, 0,
    <6544, 6145, 6147>, 0,
    <6544, 6147, 524>, 0,
    <6544, 524, 6543>, 0,
    <6544, 6543, 6532>, 0,
    <6544, 6532, 6535>, 0,
    <6550, 6549, 6545>, 0,
    <6550, 6545, 6547>, 0,
    <6550, 6547, 6501>, 0,
    <6550, 6501, 6502>, 0,
    <6550, 6502, 5698>, 0,
    <6550, 5698, 6548>, 0,
    <6550, 6548, 6546>, 0,
    <6550, 6546, 6549>, 0,
    <6556, 6555, 6545>, 0,
    <6556, 6545, 6549>, 0,
    <6556, 6549, 6546>, 0,
    <6556, 6546, 6553>, 0,
    <6556, 6553, 6551>, 0,
    <6556, 6551, 6554>, 0,
    <6556, 6554, 6552>, 0,
    <6556, 6552, 6555>, 0,
    <6558, 6547, 6545>, 0,
    <6558, 6545, 6555>, 0,
    <6558, 6555, 6552>, 0,
    <6558, 6552, 6557>, 0,
    <6558, 6557, 6489>, 0,
    <6558, 6489, 6505>, 0,
    <6558, 6505, 6501>, 0,
    <6558, 6501, 6547>, 0,
    <6562, 6561, 6559>, 0,
    <6562, 6559, 6560>, 0,
    <6562, 6560, 6546>, 0,
    <6562, 6546, 6548>, 0,
    <6562, 6548, 5698>, 0,
    <6562, 5698, 5766>, 0,
    <6562, 5766, 5761>, 0,
    <6562, 5761, 6561>, 0,
    <6566, 6565, 6559>, 0,
    <6566, 6559, 6561>, 0,
    <6566, 6561, 5761>, 0,
    <6566, 5761, 5763>, 0,
    <6566, 5763, 5760>, 0,
    <6566, 5760, 6564>, 0,
    <6566, 6564, 6563>, 0,
    <6566, 6563, 6565>, 0,
    <6568, 6560, 6559>, 0,
    <6568, 6559, 6565>, 0,
    <6568, 6565, 6563>, 0,
    <6568, 6563, 6567>, 0,
    <6568, 6567, 6551>, 0,
    <6568, 6551, 6553>, 0,
    <6568, 6553, 6546>, 0,
    <6568, 6546, 6560>, 0,
    <6577, 6576, 6569>, 0,
    <6577, 6569, 6573>, 0,
    <6577, 6573, 6570>, 0,
    <6577, 6570, 6574>, 0,
    <6577, 6574, 6571>, 0,
    <6577, 6571, 6575>, 0,
    <6577, 6575, 6572>, 0,
    <6577, 6572, 6576>, 0,
    <6580, 6579, 6569>, 0,
    <6580, 6569, 6576>, 0,
    <6580, 6576, 6572>, 0,
    <6580, 6572, 6578>, 0,
    <6580, 6578, 5876>, 0,
    <6580, 5876, 5894>, 0,
    <6580, 5894, 5889>, 0,
    <6580, 5889, 6579>, 0,
    <6582, 6573, 6569>, 0,
    <6582, 6569, 6579>, 0,
    <6582, 6579, 5889>, 0,
    <6582, 5889, 5891>, 0,
    <6582, 5891, 5780>, 0,
    <6582, 5780, 6581>, 0,
    <6582, 6581, 6570>, 0,
    <6582, 6570, 6573>, 0,
    <6588, 6587, 6583>, 0,
    <6588, 6583, 6585>, 0,
    <6588, 6585, 6510>, 0,
    <6588, 6510, 6513>, 0,
    <6588, 6513, 6509>, 0,
    <6588, 6509, 6586>, 0,
    <6588, 6586, 6584>, 0,
    <6588, 6584, 6587>, 0,
    <6591, 6590, 6583>, 0,
    <6591, 6583, 6587>, 0,
    <6591, 6587, 6584>, 0,
    <6591, 6584, 6589>, 0,
    <6591, 6589, 6571>, 0,
    <6591, 6571, 6574>, 0,
    <6591, 6574, 6570>, 0,
    <6591, 6570, 6590>, 0,
    <6592, 6585, 6583>, 0,
    <6592, 6583, 6590>, 0,
    <6592, 6590, 6570>, 0,
    <6592, 6570, 6581>, 0,
    <6592, 6581, 5780>, 0,
    <6592, 5780, 6516>, 0,
    <6592, 6516, 6510>, 0,
    <6592, 6510, 6585>, 0,
    <6598, 6597, 6593>, 0,
    <6598, 6593, 6595>, 0,
    <6598, 6595, 6594>, 0,
    <6598, 6594, 6596>, 0,
    <6598, 6596, 5654>, 0,
    <6598, 5654, 6457>, 0,
    <6598, 6457, 6453>, 0,
    <6598, 6453, 6597>, 0,
    <6602, 6601, 6593>, 0,
    <6602, 6593, 6597>, 0,
    <6602, 6597, 6453>, 0,
    <6602, 6453, 6454>, 0,
    <6602, 6454, 6445>, 0,
    <6602, 6445, 6600>, 0,
    <6602, 6600, 6599>, 0,
    <6602, 6599, 6601>, 0,
    <6606, 6595, 6593>, 0,
    <6606, 6593, 6601>, 0,
    <6606, 6601, 6599>, 0,
    <6606, 6599, 6604>, 0,
    <6606, 6604, 6603>, 0,
    <6606, 6603, 6605>, 0,
    <6606, 6605, 6594>, 0,
    <6606, 6594, 6595>, 0,
    <6610, 6609, 6607>, 0,
    <6610, 6607, 6608>, 0,
    <6610, 6608, 5808>, 0,
    <6610, 5808, 5809>, 0,
    <6610, 5809, 5654>, 0,
    <6610, 5654, 6596>, 0,
    <6610, 6596, 6594>, 0,
    <6610, 6594, 6609>, 0,
    <6614, 6613, 6607>, 0,
    <6614, 6607, 6609>, 0,
    <6614, 6609, 6594>, 0,
    <6614, 6594, 6605>, 0,
    <6614, 6605, 6603>, 0,
    <6614, 6603, 6612>, 0,
    <6614, 6612, 6611>, 0,
    <6614, 6611, 6613>, 0,
    <6616, 6608, 6607>, 0,
    <6616, 6607, 6613>, 0,
    <6616, 6613, 6611>, 0,
    <6616, 6611, 6615>, 0,
    <6616, 6615, 5812>, 0,
    <6616, 5812, 5813>, 0,
    <6616, 5813, 5808>, 0,
    <6616, 5808, 6608>, 0,
    <6625, 6624, 6617>, 0,
    <6625, 6617, 6621>, 0,
    <6625, 6621, 6618>, 0,
    <6625, 6618, 6622>, 0,
    <6625, 6622, 6619>, 0,
    <6625, 6619, 6623>, 0,
    <6625, 6623, 6620>, 0,
    <6625, 6620, 6624>, 0,
    <6628, 6627, 6617>, 0,
    <6628, 6617, 6624>, 0,
    <6628, 6624, 6620>, 0,
    <6628, 6620, 6626>, 0,
    <6628, 6626, 5828>, 0,
    <6628, 5828, 5975>, 0,
    <6628, 5975, 5973>, 0,
    <6628, 5973, 6627>, 0,
    <6630, 6621, 6617>, 0,
    <6630, 6617, 6627>, 0,
    <6630, 6627, 5973>, 0,
    <6630, 5973, 5980>, 0,
    <6630, 5980, 5960>, 0,
    <6630, 5960, 6629>, 0,
    <6630, 6629, 6618>, 0,
    <6630, 6618, 6621>, 0,
    <6636, 6635, 6631>, 0,
    <6636, 6631, 6633>, 0,
    <6636, 6633, 6632>, 0,
    <6636, 6632, 6634>, 0,
    <6636, 6634, 6461>, 0,
    <6636, 6461, 6464>, 0,
    <6636, 6464, 6460>, 0,
    <6636, 6460, 6635>, 0,
    <6638, 6637, 6631>, 0,
    <6638, 6631, 6635>, 0,
    <6638, 6635, 6460>, 0,
    <6638, 6460, 6471>, 0,
    <6638, 6471, 5828>, 0,
    <6638, 5828, 6626>, 0,
    <6638, 6626, 6620>, 0,
    <6638, 6620, 6637>, 0,
    <6640, 6633, 6631>, 0,
    <6640, 6631, 6637>, 0,
    <6640, 6637, 6620>, 0,
    <6640, 6620, 6623>, 0,
    <6640, 6623, 6619>, 0,
    <6640, 6619, 6639>, 0,
    <6640, 6639, 6632>, 0,
    <6640, 6632, 6633>, 0,
    <6646, 6645, 6641>, 0,
    <6646, 6641, 6643>, 0,
    <6646, 6643, 6563>, 0,
    <6646, 6563, 6564>, 0,
    <6646, 6564, 5760>, 0,
    <6646, 5760, 6644>, 0,
    <6646, 6644, 6642>, 0,
    <6646, 6642, 6645>, 0,
    <6652, 6651, 6641>, 0,
    <6652, 6641, 6645>, 0,
    <6652, 6645, 6642>, 0,
    <6652, 6642, 6649>, 0,
    <6652, 6649, 6647>, 0,
    <6652, 6647, 6650>, 0,
    <6652, 6650, 6648>, 0,
    <6652, 6648, 6651>, 0,
    <6654, 6643, 6641>, 0,
    <6654, 6641, 6651>, 0,
    <6654, 6651, 6648>, 0,
    <6654, 6648, 6653>, 0,
    <6654, 6653, 6551>, 0,
    <6654, 6551, 6567>, 0,
    <6654, 6567, 6563>, 0,
    <6654, 6563, 6643>, 0,
    <6658, 6657, 6655>, 0,
    <6658, 6655, 6656>, 0,
    <6658, 6656, 6642>, 0,
    <6658, 6642, 6644>, 0,
    <6658, 6644, 5760>, 0,
    <6658, 5760, 5862>, 0,
    <6658, 5862, 5857>, 0,
    <6658, 5857, 6657>, 0,
    <6662, 6661, 6655>, 0,
    <6662, 6655, 6657>, 0,
    <6662, 6657, 5857>, 0,
    <6662, 5857, 5859>, 0,
    <6662, 5859, 5856>, 0,
    <6662, 5856, 6660>, 0,
    <6662, 6660, 6659>, 0,
    <6662, 6659, 6661>, 0,
    <6664, 6656, 6655>, 0,
    <6664, 6655, 6661>, 0,
    <6664, 6661, 6659>, 0,
    <6664, 6659, 6663>, 0,
    <6664, 6663, 6647>, 0,
    <6664, 6647, 6649>, 0,
    <6664, 6649, 6642>, 0,
    <6664, 6642, 6656>, 0,
    <6673, 6672, 6665>, 0,
    <6673, 6665, 6669>, 0,
    <6673, 6669, 6666>, 0,
    <6673, 6666, 6670>, 0,
    <6673, 6670, 6667>, 0,
    <6673, 6667, 6671>, 0,
    <6673, 6671, 6668>, 0,
    <6673, 6668, 6672>, 0,
    <6676, 6675, 6665>, 0,
    <6676, 6665, 6672>, 0,
    <6676, 6672, 6668>, 0,
    <6676, 6668, 6674>, 0,
    <6676, 6674, 622>, 0,
    <6676, 622, 5928>, 0,
    <6676, 5928, 5922>, 0,
    <6676, 5922, 6675>, 0,
    <6678, 6669, 6665>, 0,
    <6678, 6665, 6675>, 0,
    <6678, 6675, 5922>, 0,
    <6678, 5922, 5924>, 0,
    <6678, 5924, 5876>, 0,
    <6678, 5876, 6677>, 0,
    <6678, 6677, 6666>, 0,
    <6678, 6666, 6669>, 0,
    <6684, 6683, 6679>, 0,
    <6684, 6679, 6681>, 0,
    <6684, 6681, 6572>, 0,
    <6684, 6572, 6575>, 0,
    <6684, 6575, 6571>, 0,
    <6684, 6571, 6682>, 0,
    <6684, 6682, 6680>, 0,
    <6684, 6680, 6683>, 0,
    <6687, 6686, 6679>, 0,
    <6687, 6679, 6683>, 0,
    <6687, 6683, 6680>, 0,
    <6687, 6680, 6685>, 0,
    <6687, 6685, 6667>, 0,
    <6687, 6667, 6670>, 0,
    <6687, 6670, 6666>, 0,
    <6687, 6666, 6686>, 0,
    <6688, 6681, 6679>, 0,
    <6688, 6679, 6686>, 0,
    <6688, 6686, 6666>, 0,
    <6688, 6666, 6677>, 0,
    <6688, 6677, 5876>, 0,
    <6688, 5876, 6578>, 0,
    <6688, 6578, 6572>, 0,
    <6688, 6572, 6681>, 0,
    <6694, 6693, 6689>, 0,
    <6694, 6689, 6691>, 0,
    <6694, 6691, 6659>, 0,
    <6694, 6659, 6660>, 0,
    <6694, 6660, 5856>, 0,
    <6694, 5856, 6692>, 0,
    <6694, 6692, 6690>, 0,
    <6694, 6690, 6693>, 0,
    <6699, 6698, 6689>, 0,
    <6699, 6689, 6693>, 0,
    <6699, 6693, 6690>, 0,
    <6699, 6690, 6696>, 0,
    <6699, 6696, 722>, 0,
    <6699, 722, 6697>, 0,
    <6699, 6697, 6695>, 0,
    <6699, 6695, 6698>, 0,
    <6701, 6691, 6689>, 0,
    <6701, 6689, 6698>, 0,
    <6701, 6698, 6695>, 0,
    <6701, 6695, 6700>, 0,
    <6701, 6700, 6647>, 0,
    <6701, 6647, 6663>, 0,
    <6701, 6663, 6659>, 0,
    <6701, 6659, 6691>, 0,
    <6705, 6704, 6702>, 0,
    <6705, 6702, 6703>, 0,
    <6705, 6703, 6690>, 0,
    <6705, 6690, 6692>, 0,
    <6705, 6692, 5856>, 0,
    <6705, 5856, 5909>, 0,
    <6705, 5909, 5904>, 0,
    <6705, 5904, 6704>, 0,
    <6709, 6708, 6702>, 0,
    <6709, 6702, 6704>, 0,
    <6709, 6704, 5904>, 0,
    <6709, 5904, 5906>, 0,
    <6709, 5906, 565>, 0,
    <6709, 565, 6707>, 0,
    <6709, 6707, 6706>, 0,
    <6709, 6706, 6708>, 0,
    <6711, 6703, 6702>, 0,
    <6711, 6702, 6708>, 0,
    <6711, 6708, 6706>, 0,
    <6711, 6706, 6710>, 0,
    <6711, 6710, 722>, 0,
    <6711, 722, 6696>, 0,
    <6711, 6696, 6690>, 0,
    <6711, 6690, 6703>, 0,
    <6717, 6716, 6712>, 0,
    <6717, 6712, 6714>, 0,
    <6717, 6714, 6668>, 0,
    <6717, 6668, 6671>, 0,
    <6717, 6671, 6667>, 0,
    <6717, 6667, 6715>, 0,
    <6717, 6715, 6713>, 0,
    <6717, 6713, 6716>, 0,
    <6722, 6721, 6712>, 0,
    <6722, 6712, 6716>, 0,
    <6722, 6716, 6713>, 0,
    <6722, 6713, 6719>, 0,
    <6722, 6719, 779>, 0,
    <6722, 779, 6720>, 0,
    <6722, 6720, 6718>, 0,
    <6722, 6718, 6721>, 0,
    <6724, 6714, 6712>, 0,
    <6724, 6712, 6721>, 0,
    <6724, 6721, 6718>, 0,
    <6724, 6718, 6723>, 0,
    <6724, 6723, 622>, 0,
    <6724, 622, 6674>, 0,
    <6724, 6674, 6668>, 0,
    <6724, 6668, 6714>, 0,
    <6730, 6729, 6725>, 0,
    <6730, 6725, 6727>, 0,
    <6730, 6727, 6726>, 0,
    <6730, 6726, 6728>, 0,
    <6730, 6728, 5812>, 0,
    <6730, 5812, 6615>, 0,
    <6730, 6615, 6611>, 0,
    <6730, 6611, 6729>, 0,
    <6734, 6733, 6725>, 0,
    <6734, 6725, 6729>, 0,
    <6734, 6729, 6611>, 0,
    <6734, 6611, 6612>, 0,
    <6734, 6612, 6603>, 0,
    <6734, 6603, 6732>, 0,
    <6734, 6732, 6731>, 0,
    <6734, 6731, 6733>, 0,
    <6738, 6727, 6725>, 0,
    <6738, 6725, 6733>, 0,
    <6738, 6733, 6731>, 0,
    <6738, 6731, 6736>, 0,
    <6738, 6736, 6735>, 0,
    <6738, 6735, 6737>, 0,
    <6738, 6737, 6726>, 0,
    <6738, 6726, 6727>, 0,
    <6742, 6741, 6739>, 0,
    <6742, 6739, 6740>, 0,
    <6742, 6740, 5940>, 0,
    <6742, 5940, 5941>, 0,
    <6742, 5941, 5812>, 0,
    <6742, 5812, 6728>, 0,
    <6742, 6728, 6726>, 0,
    <6742, 6726, 6741>, 0,
    <6746, 6745, 6739>, 0,
    <6746, 6739, 6741>, 0,
    <6746, 6741, 6726>, 0,
    <6746, 6726, 6737>, 0,
    <6746, 6737, 6735>, 0,
    <6746, 6735, 6744>, 0,
    <6746, 6744, 6743>, 0,
    <6746, 6743, 6745>, 0,
    <6748, 6740, 6739>, 0,
    <6748, 6739, 6745>, 0,
    <6748, 6745, 6743>, 0,
    <6748, 6743, 6747>, 0,
    <6748, 6747, 5944>, 0,
    <6748, 5944, 5945>, 0,
    <6748, 5945, 5940>, 0,
    <6748, 5940, 6740>, 0,
    <6757, 6756, 6749>, 0,
    <6757, 6749, 6753>, 0,
    <6757, 6753, 6750>, 0,
    <6757, 6750, 6754>, 0,
    <6757, 6754, 6751>, 0,
    <6757, 6751, 6755>, 0,
    <6757, 6755, 6752>, 0,
    <6757, 6752, 6756>, 0,
    <6760, 6759, 6749>, 0,
    <6760, 6749, 6756>, 0,
    <6760, 6756, 6752>, 0,
    <6760, 6752, 6758>, 0,
    <6760, 6758, 5960>, 0,
    <6760, 5960, 6023>, 0,
    <6760, 6023, 6021>, 0,
    <6760, 6021, 6759>, 0,
    <6762, 6753, 6749>, 0,
    <6762, 6749, 6759>, 0,
    <6762, 6759, 6021>, 0,
    <6762, 6021, 6028>, 0,
    <6762, 6028, 6008>, 0,
    <6762, 6008, 6761>, 0,
    <6762, 6761, 6750>, 0,
    <6762, 6750, 6753>, 0,
    <6768, 6767, 6763>, 0,
    <6768, 6763, 6765>, 0,
    <6768, 6765, 6764>, 0,
    <6768, 6764, 6766>, 0,
    <6768, 6766, 6619>, 0,
    <6768, 6619, 6622>, 0,
    <6768, 6622, 6618>, 0,
    <6768, 6618, 6767>, 0,
    <6770, 6769, 6763>, 0,
    <6770, 6763, 6767>, 0,
    <6770, 6767, 6618>, 0,
    <6770, 6618, 6629>, 0,
    <6770, 6629, 5960>, 0,
    <6770, 5960, 6758>, 0,
    <6770, 6758, 6752>, 0,
    <6770, 6752, 6769>, 0,
    <6772, 6765, 6763>, 0,
    <6772, 6763, 6769>, 0,
    <6772, 6769, 6752>, 0,
    <6772, 6752, 6755>, 0,
    <6772, 6755, 6751>, 0,
    <6772, 6751, 6771>, 0,
    <6772, 6771, 6764>, 0,
    <6772, 6764, 6765>, 0,
    <6778, 6777, 6773>, 0,
    <6778, 6773, 6775>, 0,
    <6778, 6775, 6774>, 0,
    <6778, 6774, 6776>, 0,
    <6778, 6776, 5944>, 0,
    <6778, 5944, 6747>, 0,
    <6778, 6747, 6743>, 0,
    <6778, 6743, 6777>, 0,
    <6782, 6781, 6773>, 0,
    <6782, 6773, 6777>, 0,
    <6782, 6777, 6743>, 0,
    <6782, 6743, 6744>, 0,
    <6782, 6744, 6735>, 0,
    <6782, 6735, 6780>, 0,
    <6782, 6780, 6779>, 0,
    <6782, 6779, 6781>, 0,
    <6786, 6775, 6773>, 0,
    <6786, 6773, 6781>, 0,
    <6786, 6781, 6779>, 0,
    <6786, 6779, 6784>, 0,
    <6786, 6784, 6783>, 0,
    <6786, 6783, 6785>, 0,
    <6786, 6785, 6774>, 0,
    <6786, 6774, 6775>, 0,
    <6790, 6789, 6787>, 0,
    <6790, 6787, 6788>, 0,
    <6790, 6788, 5988>, 0,
    <6790, 5988, 5989>, 0,
    <6790, 5989, 5944>, 0,
    <6790, 5944, 6776>, 0,
    <6790, 6776, 6774>, 0,
    <6790, 6774, 6789>, 0,
    <6794, 6793, 6787>, 0,
    <6794, 6787, 6789>, 0,
    <6794, 6789, 6774>, 0,
    <6794, 6774, 6785>, 0,
    <6794, 6785, 6783>, 0,
    <6794, 6783, 6792>, 0,
    <6794, 6792, 6791>, 0,
    <6794, 6791, 6793>, 0,
    <6796, 6788, 6787>, 0,
    <6796, 6787, 6793>, 0,
    <6796, 6793, 6791>, 0,
    <6796, 6791, 6795>, 0,
    <6796, 6795, 5992>, 0,
    <6796, 5992, 5993>, 0,
    <6796, 5993, 5988>, 0,
    <6796, 5988, 6788>, 0,
    <6805, 6804, 6797>, 0,
    <6805, 6797, 6801>, 0,
    <6805, 6801, 6798>, 0,
    <6805, 6798, 6802>, 0,
    <6805, 6802, 6799>, 0,
    <6805, 6799, 6803>, 0,
    <6805, 6803, 6800>, 0,
    <6805, 6800, 6804>, 0,
    <6808, 6807, 6797>, 0,
    <6808, 6797, 6804>, 0,
    <6808, 6804, 6800>, 0,
    <6808, 6800, 6806>, 0,
    <6808, 6806, 6008>, 0,
    <6808, 6008, 6053>, 0,
    <6808, 6053, 6051>, 0,
    <6808, 6051, 6807>, 0,
    <6810, 6801, 6797>, 0,
    <6810, 6797, 6807>, 0,
    <6810, 6807, 6051>, 0,
    <6810, 6051, 6058>, 0,
    <6810, 6058, 601>, 0,
    <6810, 601, 6809>, 0,
    <6810, 6809, 6798>, 0,
    <6810, 6798, 6801>, 0,
    <6816, 6815, 6811>, 0,
    <6816, 6811, 6813>, 0,
    <6816, 6813, 6812>, 0,
    <6816, 6812, 6814>, 0,
    <6816, 6814, 6751>, 0,
    <6816, 6751, 6754>, 0,
    <6816, 6754, 6750>, 0,
    <6816, 6750, 6815>, 0,
    <6818, 6817, 6811>, 0,
    <6818, 6811, 6815>, 0,
    <6818, 6815, 6750>, 0,
    <6818, 6750, 6761>, 0,
    <6818, 6761, 6008>, 0,
    <6818, 6008, 6806>, 0,
    <6818, 6806, 6800>, 0,
    <6818, 6800, 6817>, 0,
    <6820, 6813, 6811>, 0,
    <6820, 6811, 6817>, 0,
    <6820, 6817, 6800>, 0,
    <6820, 6800, 6803>, 0,
    <6820, 6803, 6799>, 0,
    <6820, 6799, 6819>, 0,
    <6820, 6819, 6812>, 0,
    <6820, 6812, 6813>, 0,
    <6826, 6825, 6821>, 0,
    <6826, 6821, 6823>, 0,
    <6826, 6823, 6822>, 0,
    <6826, 6822, 6824>, 0,
    <6826, 6824, 5992>, 0,
    <6826, 5992, 6795>, 0,
    <6826, 6795, 6791>, 0,
    <6826, 6791, 6825>, 0,
    <6830, 6829, 6821>, 0,
    <6830, 6821, 6825>, 0,
    <6830, 6825, 6791>, 0,
    <6830, 6791, 6792>, 0,
    <6830, 6792, 6783>, 0,
    <6830, 6783, 6828>, 0,
    <6830, 6828, 6827>, 0,
    <6830, 6827, 6829>, 0,
    <6833, 6823, 6821>, 0,
    <6833, 6821, 6829>, 0,
    <6833, 6829, 6827>, 0,
    <6833, 6827, 6831>, 0,
    <6833, 6831, 716>, 0,
    <6833, 716, 6832>, 0,
    <6833, 6832, 6822>, 0,
    <6833, 6822, 6823>, 0,
    <6837, 6836, 6834>, 0,
    <6837, 6834, 6835>, 0,
    <6837, 6835, 6036>, 0,
    <6837, 6036, 6037>, 0,
    <6837, 6037, 5992>, 0,
    <6837, 5992, 6824>, 0,
    <6837, 6824, 6822>, 0,
    <6837, 6822, 6836>, 0,
    <6839, 6838, 6834>, 0,
    <6839, 6834, 6836>, 0,
    <6839, 6836, 6822>, 0,
    <6839, 6822, 6832>, 0,
    <6839, 6832, 716>, 0,
    <6839, 716, 747>, 0,
    <6839, 747, 743>, 0,
    <6839, 743, 6838>, 0,
    <6840, 6835, 6834>, 0,
    <6840, 6834, 6838>, 0,
    <6840, 6838, 743>, 0,
    <6840, 743, 744>, 0,
    <6840, 744, 559>, 0,
    <6840, 559, 6040>, 0,
    <6840, 6040, 6036>, 0,
    <6840, 6036, 6835>, 0,
    <6846, 6845, 6841>, 0,
    <6846, 6841, 6843>, 0,
    <6846, 6843, 6842>, 0,
    <6846, 6842, 6844>, 0,
    <6846, 6844, 6799>, 0,
    <6846, 6799, 6802>, 0,
    <6846, 6802, 6798>, 0,
    <6846, 6798, 6845>, 0,
    <6848, 6847, 6841>, 0,
    <6848, 6841, 6845>, 0,
    <6848, 6845, 6798>, 0,
    <6848, 6798, 6809>, 0,
    <6848, 6809, 601>, 0,
    <6848, 601, 775>, 0,
    <6848, 775, 771>, 0,
    <6848, 771, 6847>, 0,
    <6850, 6843, 6841>, 0,
    <6850, 6841, 6847>, 0,
    <6850, 6847, 771>, 0,
    <6850, 771, 772>, 0,
    <6850, 772, 758>, 0,
    <6850, 758, 6849>, 0,
    <6850, 6849, 6842>, 0,
    <6850, 6842, 6843>, 0,
    <6859, 6858, 6851>, 0,
    <6859, 6851, 6855>, 0,
    <6859, 6855, 6852>, 0,
    <6859, 6852, 6856>, 0,
    <6859, 6856, 6853>, 0,
    <6859, 6853, 6857>, 0,
    <6859, 6857, 6854>, 0,
    <6859, 6854, 6858>, 0,
    <6862, 6861, 6851>, 0,
    <6862, 6851, 6858>, 0,
    <6862, 6858, 6854>, 0,
    <6862, 6854, 6860>, 0,
    <6862, 6860, 518>, 0,
    <6862, 518, 6270>, 0,
    <6862, 6270, 6268>, 0,
    <6862, 6268, 6861>, 0,
    <6864, 6855, 6851>, 0,
    <6864, 6851, 6861>, 0,
    <6864, 6861, 6268>, 0,
    <6864, 6268, 6275>, 0,
    <6864, 6275, 6255>, 0,
    <6864, 6255, 6863>, 0,
    <6864, 6863, 6852>, 0,
    <6864, 6852, 6855>, 0,
    <6873, 6872, 6865>, 0,
    <6873, 6865, 6869>, 0,
    <6873, 6869, 6866>, 0,
    <6873, 6866, 6870>, 0,
    <6873, 6870, 6867>, 0,
    <6873, 6867, 6871>, 0,
    <6873, 6871, 6868>, 0,
    <6873, 6868, 6872>, 0,
    <6879, 6878, 6865>, 0,
    <6879, 6865, 6872>, 0,
    <6879, 6872, 6868>, 0,
    <6879, 6868, 6876>, 0,
    <6879, 6876, 6874>, 0,
    <6879, 6874, 6877>, 0,
    <6879, 6877, 6875>, 0,
    <6879, 6875, 6878>, 0,
    <6882, 6869, 6865>, 0,
    <6882, 6865, 6878>, 0,
    <6882, 6878, 6875>, 0,
    <6882, 6875, 6880>, 0,
    <6882, 6880, 835>, 0,
    <6882, 835, 6881>, 0,
    <6882, 6881, 6866>, 0,
    <6882, 6866, 6869>, 0,
    <6888, 6887, 6883>, 0,
    <6888, 6883, 6885>, 0,
    <6888, 6885, 6868>, 0,
    <6888, 6868, 6871>, 0,
    <6888, 6871, 6867>, 0,
    <6888, 6867, 6886>, 0,
    <6888, 6886, 6884>, 0,
    <6888, 6884, 6887>, 0,
    <6893, 6892, 6883>, 0,
    <6893, 6883, 6887>, 0,
    <6893, 6887, 6884>, 0,
    <6893, 6884, 6890>, 0,
    <6893, 6890, 6423>, 0,
    <6893, 6423, 6891>, 0,
    <6893, 6891, 6889>, 0,
    <6893, 6889, 6892>, 0,
    <6895, 6885, 6883>, 0,
    <6895, 6883, 6892>, 0,
    <6895, 6892, 6889>, 0,
    <6895, 6889, 6894>, 0,
    <6895, 6894, 6874>, 0,
    <6895, 6874, 6876>, 0,
    <6895, 6876, 6868>, 0,
    <6895, 6868, 6885>, 0,
    <6899, 6898, 6896>, 0,
    <6899, 6896, 6897>, 0,
    <6899, 6897, 6889>, 0,
    <6899, 6889, 6891>, 0,
    <6899, 6891, 6423>, 0,
    <6899, 6423, 6426>, 0,
    <6899, 6426, 6422>, 0,
    <6899, 6422, 6898>, 0,
    <6903, 6902, 6896>, 0,
    <6903, 6896, 6898>, 0,
    <6903, 6898, 6422>, 0,
    <6903, 6422, 6433>, 0,
    <6903, 6433, 6069>, 0,
    <6903, 6069, 6901>, 0,
    <6903, 6901, 6900>, 0,
    <6903, 6900, 6902>, 0,
    <6905, 6897, 6896>, 0,
    <6905, 6896, 6902>, 0,
    <6905, 6902, 6900>, 0,
    <6905, 6900, 6904>, 0,
    <6905, 6904, 6874>, 0,
    <6905, 6874, 6894>, 0,
    <6905, 6894, 6889>, 0,
    <6905, 6889, 6897>, 0,
    <6911, 6910, 6906>, 0,
    <6911, 6906, 6908>, 0,
    <6911, 6908, 6534>, 0,
    <6911, 6534, 6537>, 0,
    <6911, 6537, 6533>, 0,
    <6911, 6533, 6909>, 0,
    <6911, 6909, 6907>, 0,
    <6911, 6907, 6910>, 0,
    <6917, 6916, 6906>, 0,
    <6917, 6906, 6910>, 0,
    <6917, 6910, 6907>, 0,
    <6917, 6907, 6914>, 0,
    <6917, 6914, 6912>, 0,
    <6917, 6912, 6915>, 0,
    <6917, 6915, 6913>, 0,
    <6917, 6913, 6916>, 0,
    <6919, 6908, 6906>, 0,
    <6919, 6906, 6916>, 0,
    <6919, 6916, 6913>, 0,
    <6919, 6913, 6918>, 0,
    <6919, 6918, 6107>, 0,
    <6919, 6107, 6540>, 0,
    <6919, 6540, 6534>, 0,
    <6919, 6534, 6908>, 0,
    <6925, 6924, 6920>, 0,
    <6925, 6920, 6922>, 0,
    <6925, 6922, 6913>, 0,
    <6925, 6913, 6915>, 0,
    <6925, 6915, 6912>, 0,
    <6925, 6912, 6923>, 0,
    <6925, 6923, 6921>, 0,
    <6925, 6921, 6924>, 0,
    <6928, 6927, 6920>, 0,
    <6928, 6920, 6924>, 0,
    <6928, 6924, 6921>, 0,
    <6928, 6921, 6926>, 0,
    <6928, 6926, 6191>, 0,
    <6928, 6191, 6209>, 0,
    <6928, 6209, 6204>, 0,
    <6928, 6204, 6927>, 0,
    <6929, 6922, 6920>, 0,
    <6929, 6920, 6927>, 0,
    <6929, 6927, 6204>, 0,
    <6929, 6204, 6206>, 0,
    <6929, 6206, 6107>, 0,
    <6929, 6107, 6918>, 0,
    <6929, 6918, 6913>, 0,
    <6929, 6913, 6922>, 0,
    <6935, 6934, 6930>, 0,
    <6935, 6930, 6932>, 0,
    <6935, 6932, 6907>, 0,
    <6935, 6907, 6909>, 0,
    <6935, 6909, 6533>, 0,
    <6935, 6533, 6933>, 0,
    <6935, 6933, 6931>, 0,
    <6935, 6931, 6934>, 0,
    <6940, 6939, 6930>, 0,
    <6940, 6930, 6934>, 0,
    <6940, 6934, 6931>, 0,
    <6940, 6931, 6937>, 0,
    <6940, 6937, 885>, 0,
    <6940, 885, 6938>, 0,
    <6940, 6938, 6936>, 0,
    <6940, 6936, 6939>, 0,
    <6942, 6932, 6930>, 0,
    <6942, 6930, 6939>, 0,
    <6942, 6939, 6936>, 0,
    <6942, 6936, 6941>, 0,
    <6942, 6941, 6912>, 0,
    <6942, 6912, 6914>, 0,
    <6942, 6914, 6907>, 0,
    <6942, 6907, 6932>, 0,
    <6950, 6949, 6943>, 0,
    <6950, 6943, 6946>, 0,
    <6950, 6946, 6944>, 0,
    <6950, 6944, 6947>, 0,
    <6950, 6947, 871>, 0,
    <6950, 871, 6948>, 0,
    <6950, 6948, 6945>, 0,
    <6950, 6945, 6949>, 0,
    <6953, 6952, 6943>, 0,
    <6953, 6943, 6949>, 0,
    <6953, 6949, 6945>, 0,
    <6953, 6945, 6951>, 0,
    <6953, 6951, 6853>, 0,
    <6953, 6853, 6856>, 0,
    <6953, 6856, 6852>, 0,
    <6953, 6852, 6952>, 0,
    <6955, 6946, 6943>, 0,
    <6955, 6943, 6952>, 0,
    <6955, 6952, 6852>, 0,
    <6955, 6852, 6863>, 0,
    <6955, 6863, 6255>, 0,
    <6955, 6255, 6954>, 0,
    <6955, 6954, 6944>, 0,
    <6955, 6944, 6946>, 0,
    <6961, 6960, 6956>, 0,
    <6961, 6956, 6958>, 0,
    <6961, 6958, 6900>, 0,
    <6961, 6900, 6901>, 0,
    <6961, 6901, 6069>, 0,
    <6961, 6069, 6959>, 0,
    <6961, 6959, 6957>, 0,
    <6961, 6957, 6960>, 0,
    <6967, 6966, 6956>, 0,
    <6967, 6956, 6960>, 0,
    <6967, 6960, 6957>, 0,
    <6967, 6957, 6964>, 0,
    <6967, 6964, 6962>, 0,
    <6967, 6962, 6965>, 0,
    <6967, 6965, 6963>, 0,
    <6967, 6963, 6966>, 0,
    <6969, 6958, 6956>, 0,
    <6969, 6956, 6966>, 0,
    <6969, 6966, 6963>, 0,
    <6969, 6963, 6968>, 0,
    <6969, 6968, 6874>, 0,
    <6969, 6874, 6904>, 0,
    <6969, 6904, 6900>, 0,
    <6969, 6900, 6958>, 0,
    <6973, 6972, 6970>, 0,
    <6973, 6970, 6971>, 0,
    <6973, 6971, 6957>, 0,
    <6973, 6957, 6959>, 0,
    <6973, 6959, 6069>, 0,
    <6973, 6069, 6177>, 0,
    <6973, 6177, 6172>, 0,
    <6973, 6172, 6972>, 0,
    <6977, 6976, 6970>, 0,
    <6977, 6970, 6972>, 0,
    <6977, 6972, 6172>, 0,
    <6977, 6172, 6174>, 0,
    <6977, 6174, 6171>, 0,
    <6977, 6171, 6975>, 0,
    <6977, 6975, 6974>, 0,
    <6977, 6974, 6976>, 0,
    <6979, 6971, 6970>, 0,
    <6979, 6970, 6976>, 0,
    <6979, 6976, 6974>, 0,
    <6979, 6974, 6978>, 0,
    <6979, 6978, 6962>, 0,
    <6979, 6962, 6964>, 0,
    <6979, 6964, 6957>, 0,
    <6979, 6957, 6971>, 0,
    <6988, 6987, 6980>, 0,
    <6988, 6980, 6984>, 0,
    <6988, 6984, 6981>, 0,
    <6988, 6981, 6985>, 0,
    <6988, 6985, 6982>, 0,
    <6988, 6982, 6986>, 0,
    <6988, 6986, 6983>, 0,
    <6988, 6983, 6987>, 0,
    <6991, 6990, 6980>, 0,
    <6991, 6980, 6987>, 0,
    <6991, 6987, 6983>, 0,
    <6991, 6983, 6989>, 0,
    <6991, 6989, 6303>, 0,
    <6991, 6303, 6321>, 0,
    <6991, 6321, 6316>, 0,
    <6991, 6316, 6990>, 0,
    <6993, 6984, 6980>, 0,
    <6993, 6980, 6990>, 0,
    <6993, 6990, 6316>, 0,
    <6993, 6316, 6318>, 0,
    <6993, 6318, 6191>, 0,
    <6993, 6191, 6992>, 0,
    <6993, 6992, 6981>, 0,
    <6993, 6981, 6984>, 0,
    <6999, 6998, 6994>, 0,
    <6999, 6994, 6996>, 0,
    <6999, 6996, 6921>, 0,
    <6999, 6921, 6923>, 0,
    <6999, 6923, 6912>, 0,
    <6999, 6912, 6997>, 0,
    <6999, 6997, 6995>, 0,
    <6999, 6995, 6998>, 0,
    <7002, 7001, 6994>, 0,
    <7002, 6994, 6998>, 0,
    <7002, 6998, 6995>, 0,
    <7002, 6995, 7000>, 0,
    <7002, 7000, 6982>, 0,
    <7002, 6982, 6985>, 0,
    <7002, 6985, 6981>, 0,
    <7002, 6981, 7001>, 0,
    <7003, 6996, 6994>, 0,
    <7003, 6994, 7001>, 0,
    <7003, 7001, 6981>, 0,
    <7003, 6981, 6992>, 0,
    <7003, 6992, 6191>, 0,
    <7003, 6191, 6926>, 0,
    <7003, 6926, 6921>, 0,
    <7003, 6921, 6996>, 0,
    <7012, 7011, 7004>, 0,
    <7012, 7004, 7008>, 0,
    <7012, 7008, 7005>, 0,
    <7012, 7005, 7009>, 0,
    <7012, 7009, 7006>, 0,
    <7012, 7006, 7010>, 0,
    <7012, 7010, 7007>, 0,
    <7012, 7007, 7011>, 0,
    <7017, 7016, 7004>, 0,
    <7017, 7004, 7011>, 0,
    <7017, 7011, 7007>, 0,
    <7017, 7007, 7014>, 0,
    <7017, 7014, 842>, 0,
    <7017, 842, 7015>, 0,
    <7017, 7015, 7013>, 0,
    <7017, 7013, 7016>, 0,
    <7021, 7008, 7004>, 0,
    <7021, 7004, 7016>, 0,
    <7021, 7016, 7013>, 0,
    <7021, 7013, 7019>, 0,
    <7021, 7019, 7018>, 0,
    <7021, 7018, 7020>, 0,
    <7021, 7020, 7005>, 0,
    <7021, 7005, 7008>, 0,
    <7029, 7028, 7022>, 0,
    <7029, 7022, 7025>, 0,
    <7029, 7025, 7023>, 0,
    <7029, 7023, 7026>, 0,
    <7029, 7026, 489>, 0,
    <7029, 489, 7027>, 0,
    <7029, 7027, 7024>, 0,
    <7029, 7024, 7028>, 0,
    <7032, 7031, 7022>, 0,
    <7032, 7022, 7028>, 0,
    <7032, 7028, 7024>, 0,
    <7032, 7024, 7030>, 0,
    <7032, 7030, 7006>, 0,
    <7032, 7006, 7009>, 0,
    <7032, 7009, 7005>, 0,
    <7032, 7005, 7031>, 0,
    <7034, 7025, 7022>, 0,
    <7034, 7022, 7031>, 0,
    <7034, 7031, 7005>, 0,
    <7034, 7005, 7020>, 0,
    <7034, 7020, 7018>, 0,
    <7034, 7018, 7033>, 0,
    <7034, 7033, 7023>, 0,
    <7034, 7023, 7025>, 0,
    <7038, 7037, 7035>, 0,
    <7038, 7035, 7036>, 0,
    <7038, 7036, 6221>, 0,
    <7038, 6221, 6223>, 0,
    <7038, 6223, 489>, 0,
    <7038, 489, 7026>, 0,
    <7038, 7026, 7023>, 0,
    <7038, 7023, 7037>, 0,
    <7042, 7041, 7035>, 0,
    <7042, 7035, 7037>, 0,
    <7042, 7037, 7023>, 0,
    <7042, 7023, 7033>, 0,
    <7042, 7033, 7018>, 0,
    <7042, 7018, 7040>, 0,
    <7042, 7040, 7039>, 0,
    <7042, 7039, 7041>, 0,
    <7044, 7036, 7035>, 0,
    <7044, 7035, 7041>, 0,
    <7044, 7041, 7039>, 0,
    <7044, 7039, 7043>, 0,
    <7044, 7043, 6226>, 0,
    <7044, 6226, 6227>, 0,
    <7044, 6227, 6221>, 0,
    <7044, 6221, 7036>, 0,
    <7053, 7052, 7045>, 0,
    <7053, 7045, 7049>, 0,
    <7053, 7049, 7046>, 0,
    <7053, 7046, 7050>, 0,
    <7053, 7050, 7047>, 0,
    <7053, 7047, 7051>, 0,
    <7053, 7051, 7048>, 0,
    <7053, 7048, 7052>, 0,
    <7056, 7055, 7045>, 0,
    <7056, 7045, 7052>, 0,
    <7056, 7052, 7048>, 0,
    <7056, 7048, 7054>, 0,
    <7056, 7054, 6255>, 0,
    <7056, 6255, 6366>, 0,
    <7056, 6366, 6364>, 0,
    <7056, 6364, 7055>, 0,
    <7058, 7049, 7045>, 0,
    <7058, 7045, 7055>, 0,
    <7058, 7055, 6364>, 0,
    <7058, 6364, 6371>, 0,
    <7058, 6371, 6351>, 0,
    <7058, 6351, 7057>, 0,
    <7058, 7057, 7046>, 0,
    <7058, 7046, 7049>, 0,
    <7064, 7063, 7059>, 0,
    <7064, 7059, 7061>, 0,
    <7064, 7061, 7060>, 0,
    <7064, 7060, 7062>, 0,
    <7064, 7062, 871>, 0,
    <7064, 871, 6947>, 0,
    <7064, 6947, 6944>, 0,
    <7064, 6944, 7063>, 0,
    <7066, 7065, 7059>, 0,
    <7066, 7059, 7063>, 0,
    <7066, 7063, 6944>, 0,
    <7066, 6944, 6954>, 0,
    <7066, 6954, 6255>, 0,
    <7066, 6255, 7054>, 0,
    <7066, 7054, 7048>, 0,
    <7066, 7048, 7065>, 0,
    <7068, 7061, 7059>, 0,
    <7068, 7059, 7065>, 0,
    <7068, 7065, 7048>, 0,
    <7068, 7048, 7051>, 0,
    <7068, 7051, 7047>, 0,
    <7068, 7047, 7067>, 0,
    <7068, 7067, 7060>, 0,
    <7068, 7060, 7061>, 0,
    <7074, 7073, 7069>, 0,
    <7074, 7069, 7071>, 0,
    <7074, 7071, 6974>, 0,
    <7074, 6974, 6975>, 0,
    <7074, 6975, 6171>, 0,
    <7074, 6171, 7072>, 0,
    <7074, 7072, 7070>, 0,
    <7074, 7070, 7073>, 0,
    <7080, 7079, 7069>, 0,
    <7080, 7069, 7073>, 0,
    <7080, 7073, 7070>, 0,
    <7080, 7070, 7077>, 0,
    <7080, 7077, 7075>, 0,
    <7080, 7075, 7078>, 0,
    <7080, 7078, 7076>, 0,
    <7080, 7076, 7079>, 0,
    <7082, 7071, 7069>, 0,
    <7082, 7069, 7079>, 0,
    <7082, 7079, 7076>, 0,
    <7082, 7076, 7081>, 0,
    <7082, 7081, 6962>, 0,
    <7082, 6962, 6978>, 0,
    <7082, 6978, 6974>, 0,
    <7082, 6974, 7071>, 0,
    <7086, 7085, 7083>, 0,
    <7086, 7083, 7084>, 0,
    <7086, 7084, 7070>, 0,
    <7086, 7070, 7072>, 0,
    <7086, 7072, 6171>, 0,
    <7086, 6171, 6289>, 0,
    <7086, 6289, 6284>, 0,
    <7086, 6284, 7085>, 0,
    <7090, 7089, 7083>, 0,
    <7090, 7083, 7085>, 0,
    <7090, 7085, 6284>, 0,
    <7090, 6284, 6286>, 0,
    <7090, 6286, 6283>, 0,
    <7090, 6283, 7088>, 0,
    <7090, 7088, 7087>, 0,
    <7090, 7087, 7089>, 0,
    <7092, 7084, 7083>, 0,
    <7092, 7083, 7089>, 0,
    <7092, 7089, 7087>, 0,
    <7092, 7087, 7091>, 0,
    <7092, 7091, 7075>, 0,
    <7092, 7075, 7077>, 0,
    <7092, 7077, 7070>, 0,
    <7092, 7070, 7084>, 0,
    <7101, 7100, 7093>, 0,
    <7101, 7093, 7097>, 0,
    <7101, 7097, 7094>, 0,
    <7101, 7094, 7098>, 0,
    <7101, 7098, 7095>, 0,
    <7101, 7095, 7099>, 0,
    <7101, 7099, 7096>, 0,
    <7101, 7096, 7100>, 0,
    <7104, 7103, 7093>, 0,
    <7104, 7093, 7100>, 0,
    <7104, 7100, 7096>, 0,
    <7104, 7096, 7102>, 0,
    <7104, 7102, 6399>, 0,
    <7104, 6399, 6417>, 0,
    <7104, 6417, 6412>, 0,
    <7104, 6412, 7103>, 0,
    <7106, 7097, 7093>, 0,
    <7106, 7093, 7103>, 0,
    <7106, 7103, 6412>, 0,
    <7106, 6412, 6414>, 0,
    <7106, 6414, 6303>, 0,
    <7106, 6303, 7105>, 0,
    <7106, 7105, 7094>, 0,
    <7106, 7094, 7097>, 0,
    <7112, 7111, 7107>, 0,
    <7112, 7107, 7109>, 0,
    <7112, 7109, 6983>, 0,
    <7112, 6983, 6986>, 0,
    <7112, 6986, 6982>, 0,
    <7112, 6982, 7110>, 0,
    <7112, 7110, 7108>, 0,
    <7112, 7108, 7111>, 0,
    <7115, 7114, 7107>, 0,
    <7115, 7107, 7111>, 0,
    <7115, 7111, 7108>, 0,
    <7115, 7108, 7113>, 0,
    <7115, 7113, 7095>, 0,
    <7115, 7095, 7098>, 0,
    <7115, 7098, 7094>, 0,
    <7115, 7094, 7114>, 0,
    <7116, 7109, 7107>, 0,
    <7116, 7107, 7114>, 0,
    <7116, 7114, 7094>, 0,
    <7116, 7094, 7105>, 0,
    <7116, 7105, 6303>, 0,
    <7116, 6303, 6989>, 0,
    <7116, 6989, 6983>, 0,
    <7116, 6983, 7109>, 0,
    <7122, 7121, 7117>, 0,
    <7122, 7117, 7119>, 0,
    <7122, 7119, 7118>, 0,
    <7122, 7118, 7120>, 0,
    <7122, 7120, 6226>, 0,
    <7122, 6226, 7043>, 0,
    <7122, 7043, 7039>, 0,
    <7122, 7039, 7121>, 0,
    <7126, 7125, 7117>, 0,
    <7126, 7117, 7121>, 0,
    <7126, 7121, 7039>, 0,
    <7126, 7039, 7040>, 0,
    <7126, 7040, 7018>, 0,
    <7126, 7018, 7124>, 0,
    <7126, 7124, 7123>, 0,
    <7126, 7123, 7125>, 0,
    <7130, 7119, 7117>, 0,
    <7130, 7117, 7125>, 0,
    <7130, 7125, 7123>, 0,
    <7130, 7123, 7128>, 0,
    <7130, 7128, 7127>, 0,
    <7130, 7127, 7129>, 0,
    <7130, 7129, 7118>, 0,
    <7130, 7118, 7119>, 0,
    <7134, 7133, 7131>, 0,
    <7134, 7131, 7132>, 0,
    <7134, 7132, 6331>, 0,
    <7134, 6331, 6332>, 0,
    <7134, 6332, 6226>, 0,
    <7134, 6226, 7120>, 0,
    <7134, 7120, 7118>, 0,
    <7134, 7118, 7133>, 0,
    <7138, 7137, 7131>, 0,
    <7138, 7131, 7133>, 0,
    <7138, 7133, 7118>, 0,
    <7138, 7118, 7129>, 0,
    <7138, 7129, 7127>, 0,
    <7138, 7127, 7136>, 0,
    <7138, 7136, 7135>, 0,
    <7138, 7135, 7137>, 0,
    <7140, 7132, 7131>, 0,
    <7140, 7131, 7137>, 0,
    <7140, 7137, 7135>, 0,
    <7140, 7135, 7139>, 0,
    <7140, 7139, 6335>, 0,
    <7140, 6335, 6336>, 0,
    <7140, 6336, 6331>, 0,
    <7140, 6331, 7132>, 0,
    <7149, 7148, 7141>, 0,
    <7149, 7141, 7145>, 0,
    <7149, 7145, 7142>, 0,
    <7149, 7142, 7146>, 0,
    <7149, 7146, 7143>, 0,
    <7149, 7143, 7147>, 0,
    <7149, 7147, 7144>, 0,
    <7149, 7144, 7148>, 0,
    <7152, 7151, 7141>, 0,
    <7152, 7141, 7148>, 0,
    <7152, 7148, 7144>, 0,
    <7152, 7144, 7150>, 0,
    <7152, 7150, 6351>, 0,
    <7152, 6351, 6476>, 0,
    <7152, 6476, 6474>, 0,
    <7152, 6474, 7151>, 0,
    <7154, 7145, 7141>, 0,
    <7154, 7141, 7151>, 0,
    <7154, 7151, 6474>, 0,
    <7154, 6474, 6481>, 0,
    <7154, 6481, 6461>, 0,
    <7154, 6461, 7153>, 0,
    <7154, 7153, 7142>, 0,
    <7154, 7142, 7145>, 0,
    <7160, 7159, 7155>, 0,
    <7160, 7155, 7157>, 0,
    <7160, 7157, 7156>, 0,
    <7160, 7156, 7158>, 0,
    <7160, 7158, 7047>, 0,
    <7160, 7047, 7050>, 0,
    <7160, 7050, 7046>, 0,
    <7160, 7046, 7159>, 0,
    <7162, 7161, 7155>, 0,
    <7162, 7155, 7159>, 0,
    <7162, 7159, 7046>, 0,
    <7162, 7046, 7057>, 0,
    <7162, 7057, 6351>, 0,
    <7162, 6351, 7150>, 0,
    <7162, 7150, 7144>, 0,
    <7162, 7144, 7161>, 0,
    <7164, 7157, 7155>, 0,
    <7164, 7155, 7161>, 0,
    <7164, 7161, 7144>, 0,
    <7164, 7144, 7147>, 0,
    <7164, 7147, 7143>, 0,
    <7164, 7143, 7163>, 0,
    <7164, 7163, 7156>, 0,
    <7164, 7156, 7157>, 0,
    <7170, 7169, 7165>, 0,
    <7170, 7165, 7167>, 0,
    <7170, 7167, 7087>, 0,
    <7170, 7087, 7088>, 0,
    <7170, 7088, 6283>, 0,
    <7170, 6283, 7168>, 0,
    <7170, 7168, 7166>, 0,
    <7170, 7166, 7169>, 0,
    <7176, 7175, 7165>, 0,
    <7176, 7165, 7169>, 0,
    <7176, 7169, 7166>, 0,
    <7176, 7166, 7173>, 0,
    <7176, 7173, 7171>, 0,
    <7176, 7171, 7174>, 0,
    <7176, 7174, 7172>, 0,
    <7176, 7172, 7175>, 0,
    <7178, 7167, 7165>, 0,
    <7178, 7165, 7175>, 0,
    <7178, 7175, 7172>, 0,
    <7178, 7172, 7177>, 0,
    <7178, 7177, 7075>, 0,
    <7178, 7075, 7091>, 0,
    <7178, 7091, 7087>, 0,
    <7178, 7087, 7167>, 0,
    <7182, 7181, 7179>, 0,
    <7182, 7179, 7180>, 0,
    <7182, 7180, 7166>, 0,
    <7182, 7166, 7168>, 0,
    <7182, 7168, 6283>, 0,
    <7182, 6283, 6385>, 0,
    <7182, 6385, 6380>, 0,
    <7182, 6380, 7181>, 0,
    <7186, 7185, 7179>, 0,
    <7186, 7179, 7181>, 0,
    <7186, 7181, 6380>, 0,
    <7186, 6380, 6382>, 0,
    <7186, 6382, 6379>, 0,
    <7186, 6379, 7184>, 0,
    <7186, 7184, 7183>, 0,
    <7186, 7183, 7185>, 0,
    <7188, 7180, 7179>, 0,
    <7188, 7179, 7185>, 0,
    <7188, 7185, 7183>, 0,
    <7188, 7183, 7187>, 0,
    <7188, 7187, 7171>, 0,
    <7188, 7171, 7173>, 0,
    <7188, 7173, 7166>, 0,
    <7188, 7166, 7180>, 0,
    <7197, 7196, 7189>, 0,
    <7197, 7189, 7193>, 0,
    <7197, 7193, 7190>, 0,
    <7197, 7190, 7194>, 0,
    <7197, 7194, 7191>, 0,
    <7197, 7191, 7195>, 0,
    <7197, 7195, 7192>, 0,
    <7197, 7192, 7196>, 0,
    <7200, 7199, 7189>, 0,
    <7200, 7189, 7196>, 0,
    <7200, 7196, 7192>, 0,
    <7200, 7192, 7198>, 0,
    <7200, 7198, 6509>, 0,
    <7200, 6509, 6527>, 0,
    <7200, 6527, 6522>, 0,
    <7200, 6522, 7199>, 0,
    <7202, 7193, 7189>, 0,
    <7202, 7189, 7199>, 0,
    <7202, 7199, 6522>, 0,
    <7202, 6522, 6524>, 0,
    <7202, 6524, 6399>, 0,
    <7202, 6399, 7201>, 0,
    <7202, 7201, 7190>, 0,
    <7202, 7190, 7193>, 0,
    <7208, 7207, 7203>, 0,
    <7208, 7203, 7205>, 0,
    <7208, 7205, 7096>, 0,
    <7208, 7096, 7099>, 0,
    <7208, 7099, 7095>, 0,
    <7208, 7095, 7206>, 0,
    <7208, 7206, 7204>, 0,
    <7208, 7204, 7207>, 0,
    <7211, 7210, 7203>, 0,
    <7211, 7203, 7207>, 0,
    <7211, 7207, 7204>, 0,
    <7211, 7204, 7209>, 0,
    <7211, 7209, 7191>, 0,
    <7211, 7191, 7194>, 0,
    <7211, 7194, 7190>, 0,
    <7211, 7190, 7210>, 0,
    <7212, 7205, 7203>, 0,
    <7212, 7203, 7210>, 0,
    <7212, 7210, 7190>, 0,
    <7212, 7190, 7201>, 0,
    <7212, 7201, 6399>, 0,
    <7212, 6399, 7102>, 0,
    <7212, 7102, 7096>, 0,
    <7212, 7096, 7205>, 0,
    <7218, 7217, 7213>, 0,
    <7218, 7213, 7215>, 0,
    <7218, 7215, 7214>, 0,
    <7218, 7214, 7216>, 0,
    <7218, 7216, 6335>, 0,
    <7218, 6335, 7139>, 0,
    <7218, 7139, 7135>, 0,
    <7218, 7135, 7217>, 0,
    <7222, 7221, 7213>, 0,
    <7222, 7213, 7217>, 0,
    <7222, 7217, 7135>, 0,
    <7222, 7135, 7136>, 0,
    <7222, 7136, 7127>, 0,
    <7222, 7127, 7220>, 0,
    <7222, 7220, 7219>, 0,
    <7222, 7219, 7221>, 0,
    <7226, 7215, 7213>, 0,
    <7226, 7213, 7221>, 0,
    <7226, 7221, 7219>, 0,
    <7226, 7219, 7224>, 0,
    <7226, 7224, 7223>, 0,
    <7226, 7223, 7225>, 0,
    <7226, 7225, 7214>, 0,
    <7226, 7214, 7215>, 0,
    <7230, 7229, 7227>, 0,
    <7230, 7227, 7228>, 0,
    <7230, 7228, 6441>, 0,
    <7230, 6441, 6442>, 0,
    <7230, 6442, 6335>, 0,
    <7230, 6335, 7216>, 0,
    <7230, 7216, 7214>, 0,
    <7230, 7214, 7229>, 0,
    <7234, 7233, 7227>, 0,
    <7234, 7227, 7229>, 0,
    <7234, 7229, 7214>, 0,
    <7234, 7214, 7225>, 0,
    <7234, 7225, 7223>, 0,
    <7234, 7223, 7232>, 0,
    <7234, 7232, 7231>, 0,
    <7234, 7231, 7233>, 0,
    <7236, 7228, 7227>, 0,
    <7236, 7227, 7233>, 0,
    <7236, 7233, 7231>, 0,
    <7236, 7231, 7235>, 0,
    <7236, 7235, 6445>, 0,
    <7236, 6445, 6446>, 0,
    <7236, 6446, 6441>, 0,
    <7236, 6441, 7228>, 0,
    <7245, 7244, 7237>, 0,
    <7245, 7237, 7241>, 0,
    <7245, 7241, 7238>, 0,
    <7245, 7238, 7242>, 0,
    <7245, 7242, 7239>, 0,
    <7245, 7239, 7243>, 0,
    <7245, 7243, 7240>, 0,
    <7245, 7240, 7244>, 0,
    <7248, 7247, 7237>, 0,
    <7248, 7237, 7244>, 0,
    <7248, 7244, 7240>, 0,
    <7248, 7240, 7246>, 0,
    <7248, 7246, 6461>, 0,
    <7248, 6461, 6634>, 0,
    <7248, 6634, 6632>, 0,
    <7248, 6632, 7247>, 0,
    <7250, 7241, 7237>, 0,
    <7250, 7237, 7247>, 0,
    <7250, 7247, 6632>, 0,
    <7250, 6632, 6639>, 0,
    <7250, 6639, 6619>, 0,
    <7250, 6619, 7249>, 0,
    <7250, 7249, 7238>, 0,
    <7250, 7238, 7241>, 0,
    <7256, 7255, 7251>, 0,
    <7256, 7251, 7253>, 0,
    <7256, 7253, 7252>, 0,
    <7256, 7252, 7254>, 0,
    <7256, 7254, 7143>, 0,
    <7256, 7143, 7146>, 0,
    <7256, 7146, 7142>, 0,
    <7256, 7142, 7255>, 0,
    <7258, 7257, 7251>, 0,
    <7258, 7251, 7255>, 0,
    <7258, 7255, 7142>, 0,
    <7258, 7142, 7153>, 0,
    <7258, 7153, 6461>, 0,
    <7258, 6461, 7246>, 0,
    <7258, 7246, 7240>, 0,
    <7258, 7240, 7257>, 0,
    <7260, 7253, 7251>, 0,
    <7260, 7251, 7257>, 0,
    <7260, 7257, 7240>, 0,
    <7260, 7240, 7243>, 0,
    <7260, 7243, 7239>, 0,
    <7260, 7239, 7259>, 0,
    <7260, 7259, 7252>, 0,
    <7260, 7252, 7253>, 0,
    <7266, 7265, 7261>, 0,
    <7266, 7261, 7263>, 0,
    <7266, 7263, 7183>, 0,
    <7266, 7183, 7184>, 0,
    <7266, 7184, 6379>, 0,
    <7266, 6379, 7264>, 0,
    <7266, 7264, 7262>, 0,
    <7266, 7262, 7265>, 0,
    <7272, 7271, 7261>, 0,
    <7272, 7261, 7265>, 0,
    <7272, 7265, 7262>, 0,
    <7272, 7262, 7269>, 0,
    <7272, 7269, 7267>, 0,
    <7272, 7267, 7270>, 0,
    <7272, 7270, 7268>, 0,
    <7272, 7268, 7271>, 0,
    <7274, 7263, 7261>, 0,
    <7274, 7261, 7271>, 0,
    <7274, 7271, 7268>, 0,
    <7274, 7268, 7273>, 0,
    <7274, 7273, 7171>, 0,
    <7274, 7171, 7187>, 0,
    <7274, 7187, 7183>, 0,
    <7274, 7183, 7263>, 0,
    <7278, 7277, 7275>, 0,
    <7278, 7275, 7276>, 0,
    <7278, 7276, 7262>, 0,
    <7278, 7262, 7264>, 0,
    <7278, 7264, 6379>, 0,
    <7278, 6379, 6495>, 0,
    <7278, 6495, 6490>, 0,
    <7278, 6490, 7277>, 0,
    <7282, 7281, 7275>, 0,
    <7282, 7275, 7277>, 0,
    <7282, 7277, 6490>, 0,
    <7282, 6490, 6492>, 0,
    <7282, 6492, 6489>, 0,
    <7282, 6489, 7280>, 0,
    <7282, 7280, 7279>, 0,
    <7282, 7279, 7281>, 0,
    <7284, 7276, 7275>, 0,
    <7284, 7275, 7281>, 0,
    <7284, 7281, 7279>, 0,
    <7284, 7279, 7283>, 0,
    <7284, 7283, 7267>, 0,
    <7284, 7267, 7269>, 0,
    <7284, 7269, 7262>, 0,
    <7284, 7262, 7276>, 0,
    <7293, 7292, 7285>, 0,
    <7293, 7285, 7289>, 0,
    <7293, 7289, 7286>, 0,
    <7293, 7286, 7290>, 0,
    <7293, 7290, 7287>, 0,
    <7293, 7287, 7291>, 0,
    <7293, 7291, 7288>, 0,
    <7293, 7288, 7292>, 0,
    <7296, 7295, 7285>, 0,
    <7296, 7285, 7292>, 0,
    <7296, 7292, 7288>, 0,
    <7296, 7288, 7294>, 0,
    <7296, 7294, 6571>, 0,
    <7296, 6571, 6589>, 0,
    <7296, 6589, 6584>, 0,
    <7296, 6584, 7295>, 0,
    <7298, 7289, 7285>, 0,
    <7298, 7285, 7295>, 0,
    <7298, 7295, 6584>, 0,
    <7298, 6584, 6586>, 0,
    <7298, 6586, 6509>, 0,
    <7298, 6509, 7297>, 0,
    <7298, 7297, 7286>, 0,
    <7298, 7286, 7289>, 0,
    <7304, 7303, 7299>, 0,
    <7304, 7299, 7301>, 0,
    <7304, 7301, 7192>, 0,
    <7304, 7192, 7195>, 0,
    <7304, 7195, 7191>, 0,
    <7304, 7191, 7302>, 0,
    <7304, 7302, 7300>, 0,
    <7304, 7300, 7303>, 0,
    <7307, 7306, 7299>, 0,
    <7307, 7299, 7303>, 0,
    <7307, 7303, 7300>, 0,
    <7307, 7300, 7305>, 0,
    <7307, 7305, 7287>, 0,
    <7307, 7287, 7290>, 0,
    <7307, 7290, 7286>, 0,
    <7307, 7286, 7306>, 0,
    <7308, 7301, 7299>, 0,
    <7308, 7299, 7306>, 0,
    <7308, 7306, 7286>, 0,
    <7308, 7286, 7297>, 0,
    <7308, 7297, 6509>, 0,
    <7308, 6509, 7198>, 0,
    <7308, 7198, 7192>, 0,
    <7308, 7192, 7301>, 0,
    <7314, 7313, 7309>, 0,
    <7314, 7309, 7311>, 0,
    <7314, 7311, 7279>, 0,
    <7314, 7279, 7280>, 0,
    <7314, 7280, 6489>, 0,
    <7314, 6489, 7312>, 0,
    <7314, 7312, 7310>, 0,
    <7314, 7310, 7313>, 0,
    <7320, 7319, 7309>, 0,
    <7320, 7309, 7313>, 0,
    <7320, 7313, 7310>, 0,
    <7320, 7310, 7317>, 0,
    <7320, 7317, 7315>, 0,
    <7320, 7315, 7318>, 0,
    <7320, 7318, 7316>, 0,
    <7320, 7316, 7319>, 0,
    <7322, 7311, 7309>, 0,
    <7322, 7309, 7319>, 0,
    <7322, 7319, 7316>, 0,
    <7322, 7316, 7321>, 0,
    <7322, 7321, 7267>, 0,
    <7322, 7267, 7283>, 0,
    <7322, 7283, 7279>, 0,
    <7322, 7279, 7311>, 0,
    <7326, 7325, 7323>, 0,
    <7326, 7323, 7324>, 0,
    <7326, 7324, 7310>, 0,
    <7326, 7310, 7312>, 0,
    <7326, 7312, 6489>, 0,
    <7326, 6489, 6557>, 0,
    <7326, 6557, 6552>, 0,
    <7326, 6552, 7325>, 0,
    <7330, 7329, 7323>, 0,
    <7330, 7323, 7325>, 0,
    <7330, 7325, 6552>, 0,
    <7330, 6552, 6554>, 0,
    <7330, 6554, 6551>, 0,
    <7330, 6551, 7328>, 0,
    <7330, 7328, 7327>, 0,
    <7330, 7327, 7329>, 0,
    <7332, 7324, 7323>, 0,
    <7332, 7323, 7329>, 0,
    <7332, 7329, 7327>, 0,
    <7332, 7327, 7331>, 0,
    <7332, 7331, 7315>, 0,
    <7332, 7315, 7317>, 0,
    <7332, 7317, 7310>, 0,
    <7332, 7310, 7324>, 0,
    <7341, 7340, 7333>, 0,
    <7341, 7333, 7337>, 0,
    <7341, 7337, 7334>, 0,
    <7341, 7334, 7338>, 0,
    <7341, 7338, 7335>, 0,
    <7341, 7335, 7339>, 0,
    <7341, 7339, 7336>, 0,
    <7341, 7336, 7340>, 0,
    <7344, 7343, 7333>, 0,
    <7344, 7333, 7340>, 0,
    <7344, 7340, 7336>, 0,
    <7344, 7336, 7342>, 0,
    <7344, 7342, 6667>, 0,
    <7344, 6667, 6685>, 0,
    <7344, 6685, 6680>, 0,
    <7344, 6680, 7343>, 0,
    <7346, 7337, 7333>, 0,
    <7346, 7333, 7343>, 0,
    <7346, 7343, 6680>, 0,
    <7346, 6680, 6682>, 0,
    <7346, 6682, 6571>, 0,
    <7346, 6571, 7345>, 0,
    <7346, 7345, 7334>, 0,
    <7346, 7334, 7337>, 0,
    <7352, 7351, 7347>, 0,
    <7352, 7347, 7349>, 0,
    <7352, 7349, 7288>, 0,
    <7352, 7288, 7291>, 0,
    <7352, 7291, 7287>, 0,
    <7352, 7287, 7350>, 0,
    <7352, 7350, 7348>, 0,
    <7352, 7348, 7351>, 0,
    <7355, 7354, 7347>, 0,
    <7355, 7347, 7351>, 0,
    <7355, 7351, 7348>, 0,
    <7355, 7348, 7353>, 0,
    <7355, 7353, 7335>, 0,
    <7355, 7335, 7338>, 0,
    <7355, 7338, 7334>, 0,
    <7355, 7334, 7354>, 0,
    <7356, 7349, 7347>, 0,
    <7356, 7347, 7354>, 0,
    <7356, 7354, 7334>, 0,
    <7356, 7334, 7345>, 0,
    <7356, 7345, 6571>, 0,
    <7356, 6571, 7294>, 0,
    <7356, 7294, 7288>, 0,
    <7356, 7288, 7349>, 0,
    <7362, 7361, 7357>, 0,
    <7362, 7357, 7359>, 0,
    <7362, 7359, 7358>, 0,
    <7362, 7358, 7360>, 0,
    <7362, 7360, 6445>, 0,
    <7362, 6445, 7235>, 0,
    <7362, 7235, 7231>, 0,
    <7362, 7231, 7361>, 0,
    <7366, 7365, 7357>, 0,
    <7366, 7357, 7361>, 0,
    <7366, 7361, 7231>, 0,
    <7366, 7231, 7232>, 0,
    <7366, 7232, 7223>, 0,
    <7366, 7223, 7364>, 0,
    <7366, 7364, 7363>, 0,
    <7366, 7363, 7365>, 0,
    <7370, 7359, 7357>, 0,
    <7370, 7357, 7365>, 0,
    <7370, 7365, 7363>, 0,
    <7370, 7363, 7368>, 0,
    <7370, 7368, 7367>, 0,
    <7370, 7367, 7369>, 0,
    <7370, 7369, 7358>, 0,
    <7370, 7358, 7359>, 0,
    <7374, 7373, 7371>, 0,
    <7374, 7371, 7372>, 0,
    <7374, 7372, 6599>, 0,
    <7374, 6599, 6600>, 0,
    <7374, 6600, 6445>, 0,
    <7374, 6445, 7360>, 0,
    <7374, 7360, 7358>, 0,
    <7374, 7358, 7373>, 0,
    <7378, 7377, 7371>, 0,
    <7378, 7371, 7373>, 0,
    <7378, 7373, 7358>, 0,
    <7378, 7358, 7369>, 0,
    <7378, 7369, 7367>, 0,
    <7378, 7367, 7376>, 0,
    <7378, 7376, 7375>, 0,
    <7378, 7375, 7377>, 0,
    <7380, 7372, 7371>, 0,
    <7380, 7371, 7377>, 0,
    <7380, 7377, 7375>, 0,
    <7380, 7375, 7379>, 0,
    <7380, 7379, 6603>, 0,
    <7380, 6603, 6604>, 0,
    <7380, 6604, 6599>, 0,
    <7380, 6599, 7372>, 0,
    <7389, 7388, 7381>, 0,
    <7389, 7381, 7385>, 0,
    <7389, 7385, 7382>, 0,
    <7389, 7382, 7386>, 0,
    <7389, 7386, 7383>, 0,
    <7389, 7383, 7387>, 0,
    <7389, 7387, 7384>, 0,
    <7389, 7384, 7388>, 0,
    <7392, 7391, 7381>, 0,
    <7392, 7381, 7388>, 0,
    <7392, 7388, 7384>, 0,
    <7392, 7384, 7390>, 0,
    <7392, 7390, 6619>, 0,
    <7392, 6619, 6766>, 0,
    <7392, 6766, 6764>, 0,
    <7392, 6764, 7391>, 0,
    <7394, 7385, 7381>, 0,
    <7394, 7381, 7391>, 0,
    <7394, 7391, 6764>, 0,
    <7394, 6764, 6771>, 0,
    <7394, 6771, 6751>, 0,
    <7394, 6751, 7393>, 0,
    <7394, 7393, 7382>, 0,
    <7394, 7382, 7385>, 0,
    <7400, 7399, 7395>, 0,
    <7400, 7395, 7397>, 0,
    <7400, 7397, 7396>, 0,
    <7400, 7396, 7398>, 0,
    <7400, 7398, 7239>, 0,
    <7400, 7239, 7242>, 0,
    <7400, 7242, 7238>, 0,
    <7400, 7238, 7399>, 0,
    <7402, 7401, 7395>, 0,
    <7402, 7395, 7399>, 0,
    <7402, 7399, 7238>, 0,
    <7402, 7238, 7249>, 0,
    <7402, 7249, 6619>, 0,
    <7402, 6619, 7390>, 0,
    <7402, 7390, 7384>, 0,
    <7402, 7384, 7401>, 0,
    <7404, 7397, 7395>, 0,
    <7404, 7395, 7401>, 0,
    <7404, 7401, 7384>, 0,
    <7404, 7384, 7387>, 0,
    <7404, 7387, 7383>, 0,
    <7404, 7383, 7403>, 0,
    <7404, 7403, 7396>, 0,
    <7404, 7396, 7397>, 0,
    <7410, 7409, 7405>, 0,
    <7410, 7405, 7407>, 0,
    <7410, 7407, 7327>, 0,
    <7410, 7327, 7328>, 0,
    <7410, 7328, 6551>, 0,
    <7410, 6551, 7408>, 0,
    <7410, 7408, 7406>, 0,
    <7410, 7406, 7409>, 0,
    <7416, 7415, 7405>, 0,
    <7416, 7405, 7409>, 0,
    <7416, 7409, 7406>, 0,
    <7416, 7406, 7413>, 0,
    <7416, 7413, 7411>, 0,
    <7416, 7411, 7414>, 0,
    <7416, 7414, 7412>, 0,
    <7416, 7412, 7415>, 0,
    <7418, 7407, 7405>, 0,
    <7418, 7405, 7415>, 0,
    <7418, 7415, 7412>, 0,
    <7418, 7412, 7417>, 0,
    <7418, 7417, 7315>, 0,
    <7418, 7315, 7331>, 0,
    <7418, 7331, 7327>, 0,
    <7418, 7327, 7407>, 0,
    <7422, 7421, 7419>, 0,
    <7422, 7419, 7420>, 0,
    <7422, 7420, 7406>, 0,
    <7422, 7406, 7408>, 0,
    <7422, 7408, 6551>, 0,
    <7422, 6551, 6653>, 0,
    <7422, 6653, 6648>, 0,
    <7422, 6648, 7421>, 0,
    <7426, 7425, 7419>, 0,
    <7426, 7419, 7421>, 0,
    <7426, 7421, 6648>, 0,
    <7426, 6648, 6650>, 0,
    <7426, 6650, 6647>, 0,
    <7426, 6647, 7424>, 0,
    <7426, 7424, 7423>, 0,
    <7426, 7423, 7425>, 0,
    <7428, 7420, 7419>, 0,
    <7428, 7419, 7425>, 0,
    <7428, 7425, 7423>, 0,
    <7428, 7423, 7427>, 0,
    <7428, 7427, 7411>, 0,
    <7428, 7411, 7413>, 0,
    <7428, 7413, 7406>, 0,
    <7428, 7406, 7420>, 0,
    <7437, 7436, 7429>, 0,
    <7437, 7429, 7433>, 0,
    <7437, 7433, 7430>, 0,
    <7437, 7430, 7434>, 0,
    <7437, 7434, 7431>, 0,
    <7437, 7431, 7435>, 0,
    <7437, 7435, 7432>, 0,
    <7437, 7432, 7436>, 0,
    <7440, 7439, 7429>, 0,
    <7440, 7429, 7436>, 0,
    <7440, 7436, 7432>, 0,
    <7440, 7432, 7438>, 0,
    <7440, 7438, 779>, 0,
    <7440, 779, 6719>, 0,
    <7440, 6719, 6713>, 0,
    <7440, 6713, 7439>, 0,
    <7442, 7433, 7429>, 0,
    <7442, 7429, 7439>, 0,
    <7442, 7439, 6713>, 0,
    <7442, 6713, 6715>, 0,
    <7442, 6715, 6667>, 0,
    <7442, 6667, 7441>, 0,
    <7442, 7441, 7430>, 0,
    <7442, 7430, 7433>, 0,
    <7448, 7447, 7443>, 0,
    <7448, 7443, 7445>, 0,
    <7448, 7445, 7336>, 0,
    <7448, 7336, 7339>, 0,
    <7448, 7339, 7335>, 0,
    <7448, 7335, 7446>, 0,
    <7448, 7446, 7444>, 0,
    <7448, 7444, 7447>, 0,
    <7451, 7450, 7443>, 0,
    <7451, 7443, 7447>, 0,
    <7451, 7447, 7444>, 0,
    <7451, 7444, 7449>, 0,
    <7451, 7449, 7431>, 0,
    <7451, 7431, 7434>, 0,
    <7451, 7434, 7430>, 0,
    <7451, 7430, 7450>, 0,
    <7452, 7445, 7443>, 0,
    <7452, 7443, 7450>, 0,
    <7452, 7450, 7430>, 0,
    <7452, 7430, 7441>, 0,
    <7452, 7441, 6667>, 0,
    <7452, 6667, 7342>, 0,
    <7452, 7342, 7336>, 0,
    <7452, 7336, 7445>, 0,
    <7461, 7460, 7453>, 0,
    <7461, 7453, 7457>, 0,
    <7461, 7457, 7454>, 0,
    <7461, 7454, 7458>, 0,
    <7461, 7458, 7455>, 0,
    <7461, 7455, 7459>, 0,
    <7461, 7459, 7456>, 0,
    <7461, 7456, 7460>, 0,
    <7464, 7463, 7453>, 0,
    <7464, 7453, 7460>, 0,
    <7464, 7460, 7456>, 0,
    <7464, 7456, 7462>, 0,
    <7464, 7462, 835>, 0,
    <7464, 835, 6880>, 0,
    <7464, 6880, 6875>, 0,
    <7464, 6875, 7463>, 0,
    <7466, 7457, 7453>, 0,
    <7466, 7453, 7463>, 0,
    <7466, 7463, 6875>, 0,
    <7466, 6875, 6877>, 0,
    <7466, 6877, 6874>, 0,
    <7466, 6874, 7465>, 0,
    <7466, 7465, 7454>, 0,
    <7466, 7454, 7457>, 0,
    <7472, 7471, 7467>, 0,
    <7472, 7467, 7469>, 0,
    <7472, 7469, 7423>, 0,
    <7472, 7423, 7424>, 0,
    <7472, 7424, 6647>, 0,
    <7472, 6647, 7470>, 0,
    <7472, 7470, 7468>, 0,
    <7472, 7468, 7471>, 0,
    <7477, 7476, 7467>, 0,
    <7477, 7467, 7471>, 0,
    <7477, 7471, 7468>, 0,
    <7477, 7468, 7474>, 0,
    <7477, 7474, 946>, 0,
    <7477, 946, 7475>, 0,
    <7477, 7475, 7473>, 0,
    <7477, 7473, 7476>, 0,
    <7479, 7469, 7467>, 0,
    <7479, 7467, 7476>, 0,
    <7479, 7476, 7473>, 0,
    <7479, 7473, 7478>, 0,
    <7479, 7478, 7411>, 0,
    <7479, 7411, 7427>, 0,
    <7479, 7427, 7423>, 0,
    <7479, 7423, 7469>, 0,
    <7483, 7482, 7480>, 0,
    <7483, 7480, 7481>, 0,
    <7483, 7481, 7468>, 0,
    <7483, 7468, 7470>, 0,
    <7483, 7470, 6647>, 0,
    <7483, 6647, 6700>, 0,
    <7483, 6700, 6695>, 0,
    <7483, 6695, 7482>, 0,
    <7487, 7486, 7480>, 0,
    <7487, 7480, 7482>, 0,
    <7487, 7482, 6695>, 0,
    <7487, 6695, 6697>, 0,
    <7487, 6697, 722>, 0,
    <7487, 722, 7485>, 0,
    <7487, 7485, 7484>, 0,
    <7487, 7484, 7486>, 0,
    <7489, 7481, 7480>, 0,
    <7489, 7480, 7486>, 0,
    <7489, 7486, 7484>, 0,
    <7489, 7484, 7488>, 0,
    <7489, 7488, 946>, 0,
    <7489, 946, 7474>, 0,
    <7489, 7474, 7468>, 0,
    <7489, 7468, 7481>, 0,
    <7495, 7494, 7490>, 0,
    <7495, 7490, 7492>, 0,
    <7495, 7492, 7432>, 0,
    <7495, 7432, 7435>, 0,
    <7495, 7435, 7431>, 0,
    <7495, 7431, 7493>, 0,
    <7495, 7493, 7491>, 0,
    <7495, 7491, 7494>, 0,
    <7500, 7499, 7490>, 0,
    <7500, 7490, 7494>, 0,
    <7500, 7494, 7491>, 0,
    <7500, 7491, 7497>, 0,
    <7500, 7497, 1003>, 0,
    <7500, 1003, 7498>, 0,
    <7500, 7498, 7496>, 0,
    <7500, 7496, 7499>, 0,
    <7502, 7492, 7490>, 0,
    <7502, 7490, 7499>, 0,
    <7502, 7499, 7496>, 0,
    <7502, 7496, 7501>, 0,
    <7502, 7501, 779>, 0,
    <7502, 779, 7438>, 0,
    <7502, 7438, 7432>, 0,
    <7502, 7432, 7492>, 0,
    <7508, 7507, 7503>, 0,
    <7508, 7503, 7505>, 0,
    <7508, 7505, 7504>, 0,
    <7508, 7504, 7506>, 0,
    <7508, 7506, 6603>, 0,
    <7508, 6603, 7379>, 0,
    <7508, 7379, 7375>, 0,
    <7508, 7375, 7507>, 0,
    <7512, 7511, 7503>, 0,
    <7512, 7503, 7507>, 0,
    <7512, 7507, 7375>, 0,
    <7512, 7375, 7376>, 0,
    <7512, 7376, 7367>, 0,
    <7512, 7367, 7510>, 0,
    <7512, 7510, 7509>, 0,
    <7512, 7509, 7511>, 0,
    <7516, 7505, 7503>, 0,
    <7516, 7503, 7511>, 0,
    <7516, 7511, 7509>, 0,
    <7516, 7509, 7514>, 0,
    <7516, 7514, 7513>, 0,
    <7516, 7513, 7515>, 0,
    <7516, 7515, 7504>, 0,
    <7516, 7504, 7505>, 0,
    <7520, 7519, 7517>, 0,
    <7520, 7517, 7518>, 0,
    <7520, 7518, 6731>, 0,
    <7520, 6731, 6732>, 0,
    <7520, 6732, 6603>, 0,
    <7520, 6603, 7506>, 0,
    <7520, 7506, 7504>, 0,
    <7520, 7504, 7519>, 0,
    <7524, 7523, 7517>, 0,
    <7524, 7517, 7519>, 0,
    <7524, 7519, 7504>, 0,
    <7524, 7504, 7515>, 0,
    <7524, 7515, 7513>, 0,
    <7524, 7513, 7522>, 0,
    <7524, 7522, 7521>, 0,
    <7524, 7521, 7523>, 0,
    <7526, 7518, 7517>, 0,
    <7526, 7517, 7523>, 0,
    <7526, 7523, 7521>, 0,
    <7526, 7521, 7525>, 0,
    <7526, 7525, 6735>, 0,
    <7526, 6735, 6736>, 0,
    <7526, 6736, 6731>, 0,
    <7526, 6731, 7518>, 0,
    <7535, 7534, 7527>, 0,
    <7535, 7527, 7531>, 0,
    <7535, 7531, 7528>, 0,
    <7535, 7528, 7532>, 0,
    <7535, 7532, 7529>, 0,
    <7535, 7529, 7533>, 0,
    <7535, 7533, 7530>, 0,
    <7535, 7530, 7534>, 0,
    <7538, 7537, 7527>, 0,
    <7538, 7527, 7534>, 0,
    <7538, 7534, 7530>, 0,
    <7538, 7530, 7536>, 0,
    <7538, 7536, 6751>, 0,
    <7538, 6751, 6814>, 0,
    <7538, 6814, 6812>, 0,
    <7538, 6812, 7537>, 0,
    <7540, 7531, 7527>, 0,
    <7540, 7527, 7537>, 0,
    <7540, 7537, 6812>, 0,
    <7540, 6812, 6819>, 0,
    <7540, 6819, 6799>, 0,
    <7540, 6799, 7539>, 0,
    <7540, 7539, 7528>, 0,
    <7540, 7528, 7531>, 0,
    <7546, 7545, 7541>, 0,
    <7546, 7541, 7543>, 0,
    <7546, 7543, 7542>, 0,
    <7546, 7542, 7544>, 0,
    <7546, 7544, 7383>, 0,
    <7546, 7383, 7386>, 0,
    <7546, 7386, 7382>, 0,
    <7546, 7382, 7545>, 0,
    <7548, 7547, 7541>, 0,
    <7548, 7541, 7545>, 0,
    <7548, 7545, 7382>, 0,
    <7548, 7382, 7393>, 0,
    <7548, 7393, 6751>, 0,
    <7548, 6751, 7536>, 0,
    <7548, 7536, 7530>, 0,
    <7548, 7530, 7547>, 0,
    <7550, 7543, 7541>, 0,
    <7550, 7541, 7547>, 0,
    <7550, 7547, 7530>, 0,
    <7550, 7530, 7533>, 0,
    <7550, 7533, 7529>, 0,
    <7550, 7529, 7549>, 0,
    <7550, 7549, 7542>, 0,
    <7550, 7542, 7543>, 0,
    <7556, 7555, 7551>, 0,
    <7556, 7551, 7553>, 0,
    <7556, 7553, 7552>, 0,
    <7556, 7552, 7554>, 0,
    <7556, 7554, 6735>, 0,
    <7556, 6735, 7525>, 0,
    <7556, 7525, 7521>, 0,
    <7556, 7521, 7555>, 0,
    <7560, 7559, 7551>, 0,
    <7560, 7551, 7555>, 0,
    <7560, 7555, 7521>, 0,
    <7560, 7521, 7522>, 0,
    <7560, 7522, 7513>, 0,
    <7560, 7513, 7558>, 0,
    <7560, 7558, 7557>, 0,
    <7560, 7557, 7559>, 0,
    <7564, 7553, 7551>, 0,
    <7564, 7551, 7559>, 0,
    <7564, 7559, 7557>, 0,
    <7564, 7557, 7562>, 0,
    <7564, 7562, 7561>, 0,
    <7564, 7561, 7563>, 0,
    <7564, 7563, 7552>, 0,
    <7564, 7552, 7553>, 0,
    <7568, 7567, 7565>, 0,
    <7568, 7565, 7566>, 0,
    <7568, 7566, 6779>, 0,
    <7568, 6779, 6780>, 0,
    <7568, 6780, 6735>, 0,
    <7568, 6735, 7554>, 0,
    <7568, 7554, 7552>, 0,
    <7568, 7552, 7567>, 0,
    <7572, 7571, 7565>, 0,
    <7572, 7565, 7567>, 0,
    <7572, 7567, 7552>, 0,
    <7572, 7552, 7563>, 0,
    <7572, 7563, 7561>, 0,
    <7572, 7561, 7570>, 0,
    <7572, 7570, 7569>, 0,
    <7572, 7569, 7571>, 0,
    <7574, 7566, 7565>, 0,
    <7574, 7565, 7571>, 0,
    <7574, 7571, 7569>, 0,
    <7574, 7569, 7573>, 0,
    <7574, 7573, 6783>, 0,
    <7574, 6783, 6784>, 0,
    <7574, 6784, 6779>, 0,
    <7574, 6779, 7566>, 0,
    <7583, 7582, 7575>, 0,
    <7583, 7575, 7579>, 0,
    <7583, 7579, 7576>, 0,
    <7583, 7576, 7580>, 0,
    <7583, 7580, 7577>, 0,
    <7583, 7577, 7581>, 0,
    <7583, 7581, 7578>, 0,
    <7583, 7578, 7582>, 0,
    <7586, 7585, 7575>, 0,
    <7586, 7575, 7582>, 0,
    <7586, 7582, 7578>, 0,
    <7586, 7578, 7584>, 0,
    <7586, 7584, 6799>, 0,
    <7586, 6799, 6844>, 0,
    <7586, 6844, 6842>, 0,
    <7586, 6842, 7585>, 0,
    <7588, 7579, 7575>, 0,
    <7588, 7575, 7585>, 0,
    <7588, 7585, 6842>, 0,
    <7588, 6842, 6849>, 0,
    <7588, 6849, 758>, 0,
    <7588, 758, 7587>, 0,
    <7588, 7587, 7576>, 0,
    <7588, 7576, 7579>, 0,
    <7594, 7593, 7589>, 0,
    <7594, 7589, 7591>, 0,
    <7594, 7591, 7590>, 0,
    <7594, 7590, 7592>, 0,
    <7594, 7592, 7529>, 0,
    <7594, 7529, 7532>, 0,
    <7594, 7532, 7528>, 0,
    <7594, 7528, 7593>, 0,
    <7596, 7595, 7589>, 0,
    <7596, 7589, 7593>, 0,
    <7596, 7593, 7528>, 0,
    <7596, 7528, 7539>, 0,
    <7596, 7539, 6799>, 0,
    <7596, 6799, 7584>, 0,
    <7596, 7584, 7578>, 0,
    <7596, 7578, 7595>, 0,
    <7598, 7591, 7589>, 0,
    <7598, 7589, 7595>, 0,
    <7598, 7595, 7578>, 0,
    <7598, 7578, 7581>, 0,
    <7598, 7581, 7577>, 0,
    <7598, 7577, 7597>, 0,
    <7598, 7597, 7590>, 0,
    <7598, 7590, 7591>, 0,
    <7604, 7603, 7599>, 0,
    <7604, 7599, 7601>, 0,
    <7604, 7601, 7600>, 0,
    <7604, 7600, 7602>, 0,
    <7604, 7602, 6783>, 0,
    <7604, 6783, 7573>, 0,
    <7604, 7573, 7569>, 0,
    <7604, 7569, 7603>, 0,
    <7608, 7607, 7599>, 0,
    <7608, 7599, 7603>, 0,
    <7608, 7603, 7569>, 0,
    <7608, 7569, 7570>, 0,
    <7608, 7570, 7561>, 0,
    <7608, 7561, 7606>, 0,
    <7608, 7606, 7605>, 0,
    <7608, 7605, 7607>, 0,
    <7611, 7601, 7599>, 0,
    <7611, 7599, 7607>, 0,
    <7611, 7607, 7605>, 0,
    <7611, 7605, 7609>, 0,
    <7611, 7609, 940>, 0,
    <7611, 940, 7610>, 0,
    <7611, 7610, 7600>, 0,
    <7611, 7600, 7601>, 0,
    <7615, 7614, 7612>, 0,
    <7615, 7612, 7613>, 0,
    <7615, 7613, 6827>, 0,
    <7615, 6827, 6828>, 0,
    <7615, 6828, 6783>, 0,
    <7615, 6783, 7602>, 0,
    <7615, 7602, 7600>, 0,
    <7615, 7600, 7614>, 0,
    <7617, 7616, 7612>, 0,
    <7617, 7612, 7614>, 0,
    <7617, 7614, 7600>, 0,
    <7617, 7600, 7610>, 0,
    <7617, 7610, 940>, 0,
    <7617, 940, 971>, 0,
    <7617, 971, 967>, 0,
    <7617, 967, 7616>, 0,
    <7618, 7613, 7612>, 0,
    <7618, 7612, 7616>, 0,
    <7618, 7616, 967>, 0,
    <7618, 967, 968>, 0,
    <7618, 968, 716>, 0,
    <7618, 716, 6831>, 0,
    <7618, 6831, 6827>, 0,
    <7618, 6827, 7613>, 0,
    <7624, 7623, 7619>, 0,
    <7624, 7619, 7621>, 0,
    <7624, 7621, 7620>, 0,
    <7624, 7620, 7622>, 0,
    <7624, 7622, 7577>, 0,
    <7624, 7577, 7580>, 0,
    <7624, 7580, 7576>, 0,
    <7624, 7576, 7623>, 0,
    <7626, 7625, 7619>, 0,
    <7626, 7619, 7623>, 0,
    <7626, 7623, 7576>, 0,
    <7626, 7576, 7587>, 0,
    <7626, 7587, 758>, 0,
    <7626, 758, 999>, 0,
    <7626, 999, 995>, 0,
    <7626, 995, 7625>, 0,
    <7628, 7621, 7619>, 0,
    <7628, 7619, 7625>, 0,
    <7628, 7625, 995>, 0,
    <7628, 995, 996>, 0,
    <7628, 996, 982>, 0,
    <7628, 982, 7627>, 0,
    <7628, 7627, 7620>, 0,
    <7628, 7620, 7621>, 0,
    <7637, 7636, 7629>, 0,
    <7637, 7629, 7633>, 0,
    <7637, 7633, 7630>, 0,
    <7637, 7630, 7634>, 0,
    <7637, 7634, 7631>, 0,
    <7637, 7631, 7635>, 0,
    <7637, 7635, 7632>, 0,
    <7637, 7632, 7636>, 0,
    <7640, 7639, 7629>, 0,
    <7640, 7629, 7636>, 0,
    <7640, 7636, 7632>, 0,
    <7640, 7632, 7638>, 0,
    <7640, 7638, 6912>, 0,
    <7640, 6912, 6941>, 0,
    <7640, 6941, 6936>, 0,
    <7640, 6936, 7639>, 0,
    <7642, 7633, 7629>, 0,
    <7642, 7629, 7639>, 0,
    <7642, 7639, 6936>, 0,
    <7642, 6936, 6938>, 0,
    <7642, 6938, 885>, 0,
    <7642, 885, 7641>, 0,
    <7642, 7641, 7630>, 0,
    <7642, 7630, 7633>, 0,
    <7651, 7650, 7643>, 0,
    <7651, 7643, 7647>, 0,
    <7651, 7647, 7644>, 0,
    <7651, 7644, 7648>, 0,
    <7651, 7648, 7645>, 0,
    <7651, 7645, 7649>, 0,
    <7651, 7649, 7646>, 0,
    <7651, 7646, 7650>, 0,
    <7654, 7653, 7643>, 0,
    <7654, 7643, 7650>, 0,
    <7654, 7650, 7646>, 0,
    <7654, 7646, 7652>, 0,
    <7654, 7652, 871>, 0,
    <7654, 871, 7062>, 0,
    <7654, 7062, 7060>, 0,
    <7654, 7060, 7653>, 0,
    <7656, 7647, 7643>, 0,
    <7656, 7643, 7653>, 0,
    <7656, 7653, 7060>, 0,
    <7656, 7060, 7067>, 0,
    <7656, 7067, 7047>, 0,
    <7656, 7047, 7655>, 0,
    <7656, 7655, 7644>, 0,
    <7656, 7644, 7647>, 0,
    <7664, 7663, 7657>, 0,
    <7664, 7657, 7660>, 0,
    <7664, 7660, 7658>, 0,
    <7664, 7658, 7661>, 0,
    <7664, 7661, 7455>, 0,
    <7664, 7455, 7662>, 0,
    <7664, 7662, 7659>, 0,
    <7664, 7659, 7663>, 0,
    <7670, 7669, 7657>, 0,
    <7670, 7657, 7663>, 0,
    <7670, 7663, 7659>, 0,
    <7670, 7659, 7667>, 0,
    <7670, 7667, 7665>, 0,
    <7670, 7665, 7668>, 0,
    <7670, 7668, 7666>, 0,
    <7670, 7666, 7669>, 0,
    <7673, 7660, 7657>, 0,
    <7673, 7657, 7669>, 0,
    <7673, 7669, 7666>, 0,
    <7673, 7666, 7671>, 0,
    <7673, 7671, 1045>, 0,
    <7673, 1045, 7672>, 0,
    <7673, 7672, 7658>, 0,
    <7673, 7658, 7660>, 0,
    <7677, 7676, 7674>, 0,
    <7677, 7674, 7675>, 0,
    <7677, 7675, 7659>, 0,
    <7677, 7659, 7662>, 0,
    <7677, 7662, 7455>, 0,
    <7677, 7455, 7458>, 0,
    <7677, 7458, 7454>, 0,
    <7677, 7454, 7676>, 0,
    <7681, 7680, 7674>, 0,
    <7681, 7674, 7676>, 0,
    <7681, 7676, 7454>, 0,
    <7681, 7454, 7465>, 0,
    <7681, 7465, 6874>, 0,
    <7681, 6874, 7679>, 0,
    <7681, 7679, 7678>, 0,
    <7681, 7678, 7680>, 0,
    <7683, 7675, 7674>, 0,
    <7683, 7674, 7680>, 0,
    <7683, 7680, 7678>, 0,
    <7683, 7678, 7682>, 0,
    <7683, 7682, 7665>, 0,
    <7683, 7665, 7667>, 0,
    <7683, 7667, 7659>, 0,
    <7683, 7659, 7675>, 0,
    <7689, 7688, 7684>, 0,
    <7689, 7684, 7686>, 0,
    <7689, 7686, 7632>, 0,
    <7689, 7632, 7635>, 0,
    <7689, 7635, 7631>, 0,
    <7689, 7631, 7687>, 0,
    <7689, 7687, 7685>, 0,
    <7689, 7685, 7688>, 0,
    <7695, 7694, 7684>, 0,
    <7695, 7684, 7688>, 0,
    <7695, 7688, 7685>, 0,
    <7695, 7685, 7692>, 0,
    <7695, 7692, 7690>, 0,
    <7695, 7690, 7693>, 0,
    <7695, 7693, 7691>, 0,
    <7695, 7691, 7694>, 0,
    <7697, 7686, 7684>, 0,
    <7697, 7684, 7694>, 0,
    <7697, 7694, 7691>, 0,
    <7697, 7691, 7696>, 0,
    <7697, 7696, 6912>, 0,
    <7697, 6912, 7638>, 0,
    <7697, 7638, 7632>, 0,
    <7697, 7632, 7686>, 0,
    <7703, 7702, 7698>, 0,
    <7703, 7698, 7700>, 0,
    <7703, 7700, 7691>, 0,
    <7703, 7691, 7693>, 0,
    <7703, 7693, 7690>, 0,
    <7703, 7690, 7701>, 0,
    <7703, 7701, 7699>, 0,
    <7703, 7699, 7702>, 0,
    <7706, 7705, 7698>, 0,
    <7706, 7698, 7702>, 0,
    <7706, 7702, 7699>, 0,
    <7706, 7699, 7704>, 0,
    <7706, 7704, 6982>, 0,
    <7706, 6982, 7000>, 0,
    <7706, 7000, 6995>, 0,
    <7706, 6995, 7705>, 0,
    <7707, 7700, 7698>, 0,
    <7707, 7698, 7705>, 0,
    <7707, 7705, 6995>, 0,
    <7707, 6995, 6997>, 0,
    <7707, 6997, 6912>, 0,
    <7707, 6912, 7696>, 0,
    <7707, 7696, 7691>, 0,
    <7707, 7691, 7700>, 0,
    <7713, 7712, 7708>, 0,
    <7713, 7708, 7710>, 0,
    <7713, 7710, 7685>, 0,
    <7713, 7685, 7687>, 0,
    <7713, 7687, 7631>, 0,
    <7713, 7631, 7711>, 0,
    <7713, 7711, 7709>, 0,
    <7713, 7709, 7712>, 0,
    <7718, 7717, 7708>, 0,
    <7718, 7708, 7712>, 0,
    <7718, 7712, 7709>, 0,
    <7718, 7709, 7715>, 0,
    <7718, 7715, 1087>, 0,
    <7718, 1087, 7716>, 0,
    <7718, 7716, 7714>, 0,
    <7718, 7714, 7717>, 0,
    <7720, 7710, 7708>, 0,
    <7720, 7708, 7717>, 0,
    <7720, 7717, 7714>, 0,
    <7720, 7714, 7719>, 0,
    <7720, 7719, 7690>, 0,
    <7720, 7690, 7692>, 0,
    <7720, 7692, 7685>, 0,
    <7720, 7685, 7710>, 0,
    <7728, 7727, 7721>, 0,
    <7728, 7721, 7724>, 0,
    <7728, 7724, 7722>, 0,
    <7728, 7722, 7725>, 0,
    <7728, 7725, 1081>, 0,
    <7728, 1081, 7726>, 0,
    <7728, 7726, 7723>, 0,
    <7728, 7723, 7727>, 0,
    <7731, 7730, 7721>, 0,
    <7731, 7721, 7727>, 0,
    <7731, 7727, 7723>, 0,
    <7731, 7723, 7729>, 0,
    <7731, 7729, 7645>, 0,
    <7731, 7645, 7648>, 0,
    <7731, 7648, 7644>, 0,
    <7731, 7644, 7730>, 0,
    <7733, 7724, 7721>, 0,
    <7733, 7721, 7730>, 0,
    <7733, 7730, 7644>, 0,
    <7733, 7644, 7655>, 0,
    <7733, 7655, 7047>, 0,
    <7733, 7047, 7732>, 0,
    <7733, 7732, 7722>, 0,
    <7733, 7722, 7724>, 0,
    <7739, 7738, 7734>, 0,
    <7739, 7734, 7736>, 0,
    <7739, 7736, 7678>, 0,
    <7739, 7678, 7679>, 0,
    <7739, 7679, 6874>, 0,
    <7739, 6874, 7737>, 0,
    <7739, 7737, 7735>, 0,
    <7739, 7735, 7738>, 0,
    <7745, 7744, 7734>, 0,
    <7745, 7734, 7738>, 0,
    <7745, 7738, 7735>, 0,
    <7745, 7735, 7742>, 0,
    <7745, 7742, 7740>, 0,
    <7745, 7740, 7743>, 0,
    <7745, 7743, 7741>, 0,
    <7745, 7741, 7744>, 0,
    <7747, 7736, 7734>, 0,
    <7747, 7734, 7744>, 0,
    <7747, 7744, 7741>, 0,
    <7747, 7741, 7746>, 0,
    <7747, 7746, 7665>, 0,
    <7747, 7665, 7682>, 0,
    <7747, 7682, 7678>, 0,
    <7747, 7678, 7736>, 0,
    <7751, 7750, 7748>, 0,
    <7751, 7748, 7749>, 0,
    <7751, 7749, 7735>, 0,
    <7751, 7735, 7737>, 0,
    <7751, 7737, 6874>, 0,
    <7751, 6874, 6968>, 0,
    <7751, 6968, 6963>, 0,
    <7751, 6963, 7750>, 0,
    <7755, 7754, 7748>, 0,
    <7755, 7748, 7750>, 0,
    <7755, 7750, 6963>, 0,
    <7755, 6963, 6965>, 0,
    <7755, 6965, 6962>, 0,
    <7755, 6962, 7753>, 0,
    <7755, 7753, 7752>, 0,
    <7755, 7752, 7754>, 0,
    <7757, 7749, 7748>, 0,
    <7757, 7748, 7754>, 0,
    <7757, 7754, 7752>, 0,
    <7757, 7752, 7756>, 0,
    <7757, 7756, 7740>, 0,
    <7757, 7740, 7742>, 0,
    <7757, 7742, 7735>, 0,
    <7757, 7735, 7749>, 0,
    <7766, 7765, 7758>, 0,
    <7766, 7758, 7762>, 0,
    <7766, 7762, 7759>, 0,
    <7766, 7759, 7763>, 0,
    <7766, 7763, 7760>, 0,
    <7766, 7760, 7764>, 0,
    <7766, 7764, 7761>, 0,
    <7766, 7761, 7765>, 0,
    <7769, 7768, 7758>, 0,
    <7769, 7758, 7765>, 0,
    <7769, 7765, 7761>, 0,
    <7769, 7761, 7767>, 0,
    <7769, 7767, 7095>, 0,
    <7769, 7095, 7113>, 0,
    <7769, 7113, 7108>, 0,
    <7769, 7108, 7768>, 0,
    <7771, 7762, 7758>, 0,
    <7771, 7758, 7768>, 0,
    <7771, 7768, 7108>, 0,
    <7771, 7108, 7110>, 0,
    <7771, 7110, 6982>, 0,
    <7771, 6982, 7770>, 0,
    <7771, 7770, 7759>, 0,
    <7771, 7759, 7762>, 0,
    <7777, 7776, 7772>, 0,
    <7777, 7772, 7774>, 0,
    <7777, 7774, 7699>, 0,
    <7777, 7699, 7701>, 0,
    <7777, 7701, 7690>, 0,
    <7777, 7690, 7775>, 0,
    <7777, 7775, 7773>, 0,
    <7777, 7773, 7776>, 0,
    <7780, 7779, 7772>, 0,
    <7780, 7772, 7776>, 0,
    <7780, 7776, 7773>, 0,
    <7780, 7773, 7778>, 0,
    <7780, 7778, 7760>, 0,
    <7780, 7760, 7763>, 0,
    <7780, 7763, 7759>, 0,
    <7780, 7759, 7779>, 0,
    <7781, 7774, 7772>, 0,
    <7781, 7772, 7779>, 0,
    <7781, 7779, 7759>, 0,
    <7781, 7759, 7770>, 0,
    <7781, 7770, 6982>, 0,
    <7781, 6982, 7704>, 0,
    <7781, 7704, 7699>, 0,
    <7781, 7699, 7774>, 0,
    <7790, 7789, 7782>, 0,
    <7790, 7782, 7786>, 0,
    <7790, 7786, 7783>, 0,
    <7790, 7783, 7787>, 0,
    <7790, 7787, 7784>, 0,
    <7790, 7784, 7788>, 0,
    <7790, 7788, 7785>, 0,
    <7790, 7785, 7789>, 0,
    <7795, 7794, 7782>, 0,
    <7795, 7782, 7789>, 0,
    <7795, 7789, 7785>, 0,
    <7795, 7785, 7792>, 0,
    <7795, 7792, 1052>, 0,
    <7795, 1052, 7793>, 0,
    <7795, 7793, 7791>, 0,
    <7795, 7791, 7794>, 0,
    <7799, 7786, 7782>, 0,
    <7799, 7782, 7794>, 0,
    <7799, 7794, 7791>, 0,
    <7799, 7791, 7797>, 0,
    <7799, 7797, 7796>, 0,
    <7799, 7796, 7798>, 0,
    <7799, 7798, 7783>, 0,
    <7799, 7783, 7786>, 0,
    <7807, 7806, 7800>, 0,
    <7807, 7800, 7803>, 0,
    <7807, 7803, 7801>, 0,
    <7807, 7801, 7804>, 0,
    <7807, 7804, 842>, 0,
    <7807, 842, 7805>, 0,
    <7807, 7805, 7802>, 0,
    <7807, 7802, 7806>, 0,
    <7810, 7809, 7800>, 0,
    <7810, 7800, 7806>, 0,
    <7810, 7806, 7802>, 0,
    <7810, 7802, 7808>, 0,
    <7810, 7808, 7784>, 0,
    <7810, 7784, 7787>, 0,
    <7810, 7787, 7783>, 0,
    <7810, 7783, 7809>, 0,
    <7812, 7803, 7800>, 0,
    <7812, 7800, 7809>, 0,
    <7812, 7809, 7783>, 0,
    <7812, 7783, 7798>, 0,
    <7812, 7798, 7796>, 0,
    <7812, 7796, 7811>, 0,
    <7812, 7811, 7801>, 0,
    <7812, 7801, 7803>, 0,
    <7816, 7815, 7813>, 0,
    <7816, 7813, 7814>, 0,
    <7816, 7814, 7013>, 0,
    <7816, 7013, 7015>, 0,
    <7816, 7015, 842>, 0,
    <7816, 842, 7804>, 0,
    <7816, 7804, 7801>, 0,
    <7816, 7801, 7815>, 0,
    <7820, 7819, 7813>, 0,
    <7820, 7813, 7815>, 0,
    <7820, 7815, 7801>, 0,
    <7820, 7801, 7811>, 0,
    <7820, 7811, 7796>, 0,
    <7820, 7796, 7818>, 0,
    <7820, 7818, 7817>, 0,
    <7820, 7817, 7819>, 0,
    <7822, 7814, 7813>, 0,
    <7822, 7813, 7819>, 0,
    <7822, 7819, 7817>, 0,
    <7822, 7817, 7821>, 0,
    <7822, 7821, 7018>, 0,
    <7822, 7018, 7019>, 0,
    <7822, 7019, 7013>, 0,
    <7822, 7013, 7814>, 0,
    <7831, 7830, 7823>, 0,
    <7831, 7823, 7827>, 0,
    <7831, 7827, 7824>, 0,
    <7831, 7824, 7828>, 0,
    <7831, 7828, 7825>, 0,
    <7831, 7825, 7829>, 0,
    <7831, 7829, 7826>, 0,
    <7831, 7826, 7830>, 0,
    <7834, 7833, 7823>, 0,
    <7834, 7823, 7830>, 0,
    <7834, 7830, 7826>, 0,
    <7834, 7826, 7832>, 0,
    <7834, 7832, 7047>, 0,
    <7834, 7047, 7158>, 0,
    <7834, 7158, 7156>, 0,
    <7834, 7156, 7833>, 0,
    <7836, 7827, 7823>, 0,
    <7836, 7823, 7833>, 0,
    <7836, 7833, 7156>, 0,
    <7836, 7156, 7163>, 0,
    <7836, 7163, 7143>, 0,
    <7836, 7143, 7835>, 0,
    <7836, 7835, 7824>, 0,
    <7836, 7824, 7827>, 0,
    <7842, 7841, 7837>, 0,
    <7842, 7837, 7839>, 0,
    <7842, 7839, 7838>, 0,
    <7842, 7838, 7840>, 0,
    <7842, 7840, 1081>, 0,
    <7842, 1081, 7725>, 0,
    <7842, 7725, 7722>, 0,
    <7842, 7722, 7841>, 0,
    <7844, 7843, 7837>, 0,
    <7844, 7837, 7841>, 0,
    <7844, 7841, 7722>, 0,
    <7844, 7722, 7732>, 0,
    <7844, 7732, 7047>, 0,
    <7844, 7047, 7832>, 0,
    <7844, 7832, 7826>, 0,
    <7844, 7826, 7843>, 0,
    <7846, 7839, 7837>, 0,
    <7846, 7837, 7843>, 0,
    <7846, 7843, 7826>, 0,
    <7846, 7826, 7829>, 0,
    <7846, 7829, 7825>, 0,
    <7846, 7825, 7845>, 0,
    <7846, 7845, 7838>, 0,
    <7846, 7838, 7839>, 0,
    <7852, 7851, 7847>, 0,
    <7852, 7847, 7849>, 0,
    <7852, 7849, 7752>, 0,
    <7852, 7752, 7753>, 0,
    <7852, 7753, 6962>, 0,
    <7852, 6962, 7850>, 0,
    <7852, 7850, 7848>, 0,
    <7852, 7848, 7851>, 0,
    <7858, 7857, 7847>, 0,
    <7858, 7847, 7851>, 0,
    <7858, 7851, 7848>, 0,
    <7858, 7848, 7855>, 0,
    <7858, 7855, 7853>, 0,
    <7858, 7853, 7856>, 0,
    <7858, 7856, 7854>, 0,
    <7858, 7854, 7857>, 0,
    <7860, 7849, 7847>, 0,
    <7860, 7847, 7857>, 0,
    <7860, 7857, 7854>, 0,
    <7860, 7854, 7859>, 0,
    <7860, 7859, 7740>, 0,
    <7860, 7740, 7756>, 0,
    <7860, 7756, 7752>, 0,
    <7860, 7752, 7849>, 0,
    <7864, 7863, 7861>, 0,
    <7864, 7861, 7862>, 0,
    <7864, 7862, 7848>, 0,
    <7864, 7848, 7850>, 0,
    <7864, 7850, 6962>, 0,
    <7864, 6962, 7081>, 0,
    <7864, 7081, 7076>, 0,
    <7864, 7076, 7863>, 0,
    <7868, 7867, 7861>, 0,
    <7868, 7861, 7863>, 0,
    <7868, 7863, 7076>, 0,
    <7868, 7076, 7078>, 0,
    <7868, 7078, 7075>, 0,
    <7868, 7075, 7866>, 0,
    <7868, 7866, 7865>, 0,
    <7868, 7865, 7867>, 0,
    <7870, 7862, 7861>, 0,
    <7870, 7861, 7867>, 0,
    <7870, 7867, 7865>, 0,
    <7870, 7865, 7869>, 0,
    <7870, 7869, 7853>, 0,
    <7870, 7853, 7855>, 0,
    <7870, 7855, 7848>, 0,
    <7870, 7848, 7862>, 0,
    <7879, 7878, 7871>, 0,
    <7879, 7871, 7875>, 0,
    <7879, 7875, 7872>, 0,
    <7879, 7872, 7876>, 0,
    <7879, 7876, 7873>, 0,
    <7879, 7873, 7877>, 0,
    <7879, 7877, 7874>, 0,
    <7879, 7874, 7878>, 0,
    <7882, 7881, 7871>, 0,
    <7882, 7871, 7878>, 0,
    <7882, 7878, 7874>, 0,
    <7882, 7874, 7880>, 0,
    <7882, 7880, 7191>, 0,
    <7882, 7191, 7209>, 0,
    <7882, 7209, 7204>, 0,
    <7882, 7204, 7881>, 0,
    <7884, 7875, 7871>, 0,
    <7884, 7871, 7881>, 0,
    <7884, 7881, 7204>, 0,
    <7884, 7204, 7206>, 0,
    <7884, 7206, 7095>, 0,
    <7884, 7095, 7883>, 0,
    <7884, 7883, 7872>, 0,
    <7884, 7872, 7875>, 0,
    <7890, 7889, 7885>, 0,
    <7890, 7885, 7887>, 0,
    <7890, 7887, 7761>, 0,
    <7890, 7761, 7764>, 0,
    <7890, 7764, 7760>, 0,
    <7890, 7760, 7888>, 0,
    <7890, 7888, 7886>, 0,
    <7890, 7886, 7889>, 0,
    <7893, 7892, 7885>, 0,
    <7893, 7885, 7889>, 0,
    <7893, 7889, 7886>, 0,
    <7893, 7886, 7891>, 0,
    <7893, 7891, 7873>, 0,
    <7893, 7873, 7876>, 0,
    <7893, 7876, 7872>, 0,
    <7893, 7872, 7892>, 0,
    <7894, 7887, 7885>, 0,
    <7894, 7885, 7892>, 0,
    <7894, 7892, 7872>, 0,
    <7894, 7872, 7883>, 0,
    <7894, 7883, 7095>, 0,
    <7894, 7095, 7767>, 0,
    <7894, 7767, 7761>, 0,
    <7894, 7761, 7887>, 0,
    <7900, 7899, 7895>, 0,
    <7900, 7895, 7897>, 0,
    <7900, 7897, 7896>, 0,
    <7900, 7896, 7898>, 0,
    <7900, 7898, 7018>, 0,
    <7900, 7018, 7821>, 0,
    <7900, 7821, 7817>, 0,
    <7900, 7817, 7899>, 0,
    <7904, 7903, 7895>, 0,
    <7904, 7895, 7899>, 0,
    <7904, 7899, 7817>, 0,
    <7904, 7817, 7818>, 0,
    <7904, 7818, 7796>, 0,
    <7904, 7796, 7902>, 0,
    <7904, 7902, 7901>, 0,
    <7904, 7901, 7903>, 0,
    <7908, 7897, 7895>, 0,
    <7908, 7895, 7903>, 0,
    <7908, 7903, 7901>, 0,
    <7908, 7901, 7906>, 0,
    <7908, 7906, 7905>, 0,
    <7908, 7905, 7907>, 0,
    <7908, 7907, 7896>, 0,
    <7908, 7896, 7897>, 0,
    <7912, 7911, 7909>, 0,
    <7912, 7909, 7910>, 0,
    <7912, 7910, 7123>, 0,
    <7912, 7123, 7124>, 0,
    <7912, 7124, 7018>, 0,
    <7912, 7018, 7898>, 0,
    <7912, 7898, 7896>, 0,
    <7912, 7896, 7911>, 0,
    <7916, 7915, 7909>, 0,
    <7916, 7909, 7911>, 0,
    <7916, 7911, 7896>, 0,
    <7916, 7896, 7907>, 0,
    <7916, 7907, 7905>, 0,
    <7916, 7905, 7914>, 0,
    <7916, 7914, 7913>, 0,
    <7916, 7913, 7915>, 0,
    <7918, 7910, 7909>, 0,
    <7918, 7909, 7915>, 0,
    <7918, 7915, 7913>, 0,
    <7918, 7913, 7917>, 0,
    <7918, 7917, 7127>, 0,
    <7918, 7127, 7128>, 0,
    <7918, 7128, 7123>, 0,
    <7918, 7123, 7910>, 0,
    <7927, 7926, 7919>, 0,
    <7927, 7919, 7923>, 0,
    <7927, 7923, 7920>, 0,
    <7927, 7920, 7924>, 0,
    <7927, 7924, 7921>, 0,
    <7927, 7921, 7925>, 0,
    <7927, 7925, 7922>, 0,
    <7927, 7922, 7926>, 0,
    <7930, 7929, 7919>, 0,
    <7930, 7919, 7926>, 0,
    <7930, 7926, 7922>, 0,
    <7930, 7922, 7928>, 0,
    <7930, 7928, 7143>, 0,
    <7930, 7143, 7254>, 0,
    <7930, 7254, 7252>, 0,
    <7930, 7252, 7929>, 0,
    <7932, 7923, 7919>, 0,
    <7932, 7919, 7929>, 0,
    <7932, 7929, 7252>, 0,
    <7932, 7252, 7259>, 0,
    <7932, 7259, 7239>, 0,
    <7932, 7239, 7931>, 0,
    <7932, 7931, 7920>, 0,
    <7932, 7920, 7923>, 0,
    <7938, 7937, 7933>, 0,
    <7938, 7933, 7935>, 0,
    <7938, 7935, 7934>, 0,
    <7938, 7934, 7936>, 0,
    <7938, 7936, 7825>, 0,
    <7938, 7825, 7828>, 0,
    <7938, 7828, 7824>, 0,
    <7938, 7824, 7937>, 0,
    <7940, 7939, 7933>, 0,
    <7940, 7933, 7937>, 0,
    <7940, 7937, 7824>, 0,
    <7940, 7824, 7835>, 0,
    <7940, 7835, 7143>, 0,
    <7940, 7143, 7928>, 0,
    <7940, 7928, 7922>, 0,
    <7940, 7922, 7939>, 0,
    <7942, 7935, 7933>, 0,
    <7942, 7933, 7939>, 0,
    <7942, 7939, 7922>, 0,
    <7942, 7922, 7925>, 0,
    <7942, 7925, 7921>, 0,
    <7942, 7921, 7941>, 0,
    <7942, 7941, 7934>, 0,
    <7942, 7934, 7935>, 0,
    <7948, 7947, 7943>, 0,
    <7948, 7943, 7945>, 0,
    <7948, 7945, 7865>, 0,
    <7948, 7865, 7866>, 0,
    <7948, 7866, 7075>, 0,
    <7948, 7075, 7946>, 0,
    <7948, 7946, 7944>, 0,
    <7948, 7944, 7947>, 0,
    <7954, 7953, 7943>, 0,
    <7954, 7943, 7947>, 0,
    <7954, 7947, 7944>, 0,
    <7954, 7944, 7951>, 0,
    <7954, 7951, 7949>, 0,
    <7954, 7949, 7952>, 0,
    <7954, 7952, 7950>, 0,
    <7954, 7950, 7953>, 0,
    <7956, 7945, 7943>, 0,
    <7956, 7943, 7953>, 0,
    <7956, 7953, 7950>, 0,
    <7956, 7950, 7955>, 0,
    <7956, 7955, 7853>, 0,
    <7956, 7853, 7869>, 0,
    <7956, 7869, 7865>, 0,
    <7956, 7865, 7945>, 0,
    <7960, 7959, 7957>, 0,
    <7960, 7957, 7958>, 0,
    <7960, 7958, 7944>, 0,
    <7960, 7944, 7946>, 0,
    <7960, 7946, 7075>, 0,
    <7960, 7075, 7177>, 0,
    <7960, 7177, 7172>, 0,
    <7960, 7172, 7959>, 0,
    <7964, 7963, 7957>, 0,
    <7964, 7957, 7959>, 0,
    <7964, 7959, 7172>, 0,
    <7964, 7172, 7174>, 0,
    <7964, 7174, 7171>, 0,
    <7964, 7171, 7962>, 0,
    <7964, 7962, 7961>, 0,
    <7964, 7961, 7963>, 0,
    <7966, 7958, 7957>, 0,
    <7966, 7957, 7963>, 0,
    <7966, 7963, 7961>, 0,
    <7966, 7961, 7965>, 0,
    <7966, 7965, 7949>, 0,
    <7966, 7949, 7951>, 0,
    <7966, 7951, 7944>, 0,
    <7966, 7944, 7958>, 0,
    <7975, 7974, 7967>, 0,
    <7975, 7967, 7971>, 0,
    <7975, 7971, 7968>, 0,
    <7975, 7968, 7972>, 0,
    <7975, 7972, 7969>, 0,
    <7975, 7969, 7973>, 0,
    <7975, 7973, 7970>, 0,
    <7975, 7970, 7974>, 0,
    <7978, 7977, 7967>, 0,
    <7978, 7967, 7974>, 0,
    <7978, 7974, 7970>, 0,
    <7978, 7970, 7976>, 0,
    <7978, 7976, 7287>, 0,
    <7978, 7287, 7305>, 0,
    <7978, 7305, 7300>, 0,
    <7978, 7300, 7977>, 0,
    <7980, 7971, 7967>, 0,
    <7980, 7967, 7977>, 0,
    <7980, 7977, 7300>, 0,
    <7980, 7300, 7302>, 0,
    <7980, 7302, 7191>, 0,
    <7980, 7191, 7979>, 0,
    <7980, 7979, 7968>, 0,
    <7980, 7968, 7971>, 0,
    <7986, 7985, 7981>, 0,
    <7986, 7981, 7983>, 0,
    <7986, 7983, 7874>, 0,
    <7986, 7874, 7877>, 0,
    <7986, 7877, 7873>, 0,
    <7986, 7873, 7984>, 0,
    <7986, 7984, 7982>, 0,
    <7986, 7982, 7985>, 0,
    <7989, 7988, 7981>, 0,
    <7989, 7981, 7985>, 0,
    <7989, 7985, 7982>, 0,
    <7989, 7982, 7987>, 0,
    <7989, 7987, 7969>, 0,
    <7989, 7969, 7972>, 0,
    <7989, 7972, 7968>, 0,
    <7989, 7968, 7988>, 0,
    <7990, 7983, 7981>, 0,
    <7990, 7981, 7988>, 0,
    <7990, 7988, 7968>, 0,
    <7990, 7968, 7979>, 0,
    <7990, 7979, 7191>, 0,
    <7990, 7191, 7880>, 0,
    <7990, 7880, 7874>, 0,
    <7990, 7874, 7983>, 0,
    <7996, 7995, 7991>, 0,
    <7996, 7991, 7993>, 0,
    <7996, 7993, 7992>, 0,
    <7996, 7992, 7994>, 0,
    <7996, 7994, 7127>, 0,
    <7996, 7127, 7917>, 0,
    <7996, 7917, 7913>, 0,
    <7996, 7913, 7995>, 0,
    <8000, 7999, 7991>, 0,
    <8000, 7991, 7995>, 0,
    <8000, 7995, 7913>, 0,
    <8000, 7913, 7914>, 0,
    <8000, 7914, 7905>, 0,
    <8000, 7905, 7998>, 0,
    <8000, 7998, 7997>, 0,
    <8000, 7997, 7999>, 0,
    <8004, 7993, 7991>, 0,
    <8004, 7991, 7999>, 0,
    <8004, 7999, 7997>, 0,
    <8004, 7997, 8002>, 0,
    <8004, 8002, 8001>, 0,
    <8004, 8001, 8003>, 0,
    <8004, 8003, 7992>, 0,
    <8004, 7992, 7993>, 0,
    <8008, 8007, 8005>, 0,
    <8008, 8005, 8006>, 0,
    <8008, 8006, 7219>, 0,
    <8008, 7219, 7220>, 0,
    <8008, 7220, 7127>, 0,
    <8008, 7127, 7994>, 0,
    <8008, 7994, 7992>, 0,
    <8008, 7992, 8007>, 0,
    <8012, 8011, 8005>, 0,
    <8012, 8005, 8007>, 0,
    <8012, 8007, 7992>, 0,
    <8012, 7992, 8003>, 0,
    <8012, 8003, 8001>, 0,
    <8012, 8001, 8010>, 0,
    <8012, 8010, 8009>, 0,
    <8012, 8009, 8011>, 0,
    <8014, 8006, 8005>, 0,
    <8014, 8005, 8011>, 0,
    <8014, 8011, 8009>, 0,
    <8014, 8009, 8013>, 0,
    <8014, 8013, 7223>, 0,
    <8014, 7223, 7224>, 0,
    <8014, 7224, 7219>, 0,
    <8014, 7219, 8006>, 0,
    <8023, 8022, 8015>, 0,
    <8023, 8015, 8019>, 0,
    <8023, 8019, 8016>, 0,
    <8023, 8016, 8020>, 0,
    <8023, 8020, 8017>, 0,
    <8023, 8017, 8021>, 0,
    <8023, 8021, 8018>, 0,
    <8023, 8018, 8022>, 0,
    <8026, 8025, 8015>, 0,
    <8026, 8015, 8022>, 0,
    <8026, 8022, 8018>, 0,
    <8026, 8018, 8024>, 0,
    <8026, 8024, 7239>, 0,
    <8026, 7239, 7398>, 0,
    <8026, 7398, 7396>, 0,
    <8026, 7396, 8025>, 0,
    <8028, 8019, 8015>, 0,
    <8028, 8015, 8025>, 0,
    <8028, 8025, 7396>, 0,
    <8028, 7396, 7403>, 0,
    <8028, 7403, 7383>, 0,
    <8028, 7383, 8027>, 0,
    <8028, 8027, 8016>, 0,
    <8028, 8016, 8019>, 0,
    <8034, 8033, 8029>, 0,
    <8034, 8029, 8031>, 0,
    <8034, 8031, 8030>, 0,
    <8034, 8030, 8032>, 0,
    <8034, 8032, 7921>, 0,
    <8034, 7921, 7924>, 0,
    <8034, 7924, 7920>, 0,
    <8034, 7920, 8033>, 0,
    <8036, 8035, 8029>, 0,
    <8036, 8029, 8033>, 0,
    <8036, 8033, 7920>, 0,
    <8036, 7920, 7931>, 0,
    <8036, 7931, 7239>, 0,
    <8036, 7239, 8024>, 0,
    <8036, 8024, 8018>, 0,
    <8036, 8018, 8035>, 0,
    <8038, 8031, 8029>, 0,
    <8038, 8029, 8035>, 0,
    <8038, 8035, 8018>, 0,
    <8038, 8018, 8021>, 0,
    <8038, 8021, 8017>, 0,
    <8038, 8017, 8037>, 0,
    <8038, 8037, 8030>, 0,
    <8038, 8030, 8031>, 0,
    <8044, 8043, 8039>, 0,
    <8044, 8039, 8041>, 0,
    <8044, 8041, 7961>, 0,
    <8044, 7961, 7962>, 0,
    <8044, 7962, 7171>, 0,
    <8044, 7171, 8042>, 0,
    <8044, 8042, 8040>, 0,
    <8044, 8040, 8043>, 0,
    <8050, 8049, 8039>, 0,
    <8050, 8039, 8043>, 0,
    <8050, 8043, 8040>, 0,
    <8050, 8040, 8047>, 0,
    <8050, 8047, 8045>, 0,
    <8050, 8045, 8048>, 0,
    <8050, 8048, 8046>, 0,
    <8050, 8046, 8049>, 0,
    <8052, 8041, 8039>, 0,
    <8052, 8039, 8049>, 0,
    <8052, 8049, 8046>, 0,
    <8052, 8046, 8051>, 0,
    <8052, 8051, 7949>, 0,
    <8052, 7949, 7965>, 0,
    <8052, 7965, 7961>, 0,
    <8052, 7961, 8041>, 0,
    <8056, 8055, 8053>, 0,
    <8056, 8053, 8054>, 0,
    <8056, 8054, 8040>, 0,
    <8056, 8040, 8042>, 0,
    <8056, 8042, 7171>, 0,
    <8056, 7171, 7273>, 0,
    <8056, 7273, 7268>, 0,
    <8056, 7268, 8055>, 0,
    <8060, 8059, 8053>, 0,
    <8060, 8053, 8055>, 0,
    <8060, 8055, 7268>, 0,
    <8060, 7268, 7270>, 0,
    <8060, 7270, 7267>, 0,
    <8060, 7267, 8058>, 0,
    <8060, 8058, 8057>, 0,
    <8060, 8057, 8059>, 0,
    <8062, 8054, 8053>, 0,
    <8062, 8053, 8059>, 0,
    <8062, 8059, 8057>, 0,
    <8062, 8057, 8061>, 0,
    <8062, 8061, 8045>, 0,
    <8062, 8045, 8047>, 0,
    <8062, 8047, 8040>, 0,
    <8062, 8040, 8054>, 0,
    <8071, 8070, 8063>, 0,
    <8071, 8063, 8067>, 0,
    <8071, 8067, 8064>, 0,
    <8071, 8064, 8068>, 0,
    <8071, 8068, 8065>, 0,
    <8071, 8065, 8069>, 0,
    <8071, 8069, 8066>, 0,
    <8071, 8066, 8070>, 0,
    <8074, 8073, 8063>, 0,
    <8074, 8063, 8070>, 0,
    <8074, 8070, 8066>, 0,
    <8074, 8066, 8072>, 0,
    <8074, 8072, 7335>, 0,
    <8074, 7335, 7353>, 0,
    <8074, 7353, 7348>, 0,
    <8074, 7348, 8073>, 0,
    <8076, 8067, 8063>, 0,
    <8076, 8063, 8073>, 0,
    <8076, 8073, 7348>, 0,
    <8076, 7348, 7350>, 0,
    <8076, 7350, 7287>, 0,
    <8076, 7287, 8075>, 0,
    <8076, 8075, 8064>, 0,
    <8076, 8064, 8067>, 0,
    <8082, 8081, 8077>, 0,
    <8082, 8077, 8079>, 0,
    <8082, 8079, 7970>, 0,
    <8082, 7970, 7973>, 0,
    <8082, 7973, 7969>, 0,
    <8082, 7969, 8080>, 0,
    <8082, 8080, 8078>, 0,
    <8082, 8078, 8081>, 0,
    <8085, 8084, 8077>, 0,
    <8085, 8077, 8081>, 0,
    <8085, 8081, 8078>, 0,
    <8085, 8078, 8083>, 0,
    <8085, 8083, 8065>, 0,
    <8085, 8065, 8068>, 0,
    <8085, 8068, 8064>, 0,
    <8085, 8064, 8084>, 0,
    <8086, 8079, 8077>, 0,
    <8086, 8077, 8084>, 0,
    <8086, 8084, 8064>, 0,
    <8086, 8064, 8075>, 0,
    <8086, 8075, 7287>, 0,
    <8086, 7287, 7976>, 0,
    <8086, 7976, 7970>, 0,
    <8086, 7970, 8079>, 0,
    <8092, 8091, 8087>, 0,
    <8092, 8087, 8089>, 0,
    <8092, 8089, 8057>, 0,
    <8092, 8057, 8058>, 0,
    <8092, 8058, 7267>, 0,
    <8092, 7267, 8090>, 0,
    <8092, 8090, 8088>, 0,
    <8092, 8088, 8091>, 0,
    <8098, 8097, 8087>, 0,
    <8098, 8087, 8091>, 0,
    <8098, 8091, 8088>, 0,
    <8098, 8088, 8095>, 0,
    <8098, 8095, 8093>, 0,
    <8098, 8093, 8096>, 0,
    <8098, 8096, 8094>, 0,
    <8098, 8094, 8097>, 0,
    <8100, 8089, 8087>, 0,
    <8100, 8087, 8097>, 0,
    <8100, 8097, 8094>, 0,
    <8100, 8094, 8099>, 0,
    <8100, 8099, 8045>, 0,
    <8100, 8045, 8061>, 0,
    <8100, 8061, 8057>, 0,
    <8100, 8057, 8089>, 0,
    <8104, 8103, 8101>, 0,
    <8104, 8101, 8102>, 0,
    <8104, 8102, 8088>, 0,
    <8104, 8088, 8090>, 0,
    <8104, 8090, 7267>, 0,
    <8104, 7267, 7321>, 0,
    <8104, 7321, 7316>, 0,
    <8104, 7316, 8103>, 0,
    <8108, 8107, 8101>, 0,
    <8108, 8101, 8103>, 0,
    <8108, 8103, 7316>, 0,
    <8108, 7316, 7318>, 0,
    <8108, 7318, 7315>, 0,
    <8108, 7315, 8106>, 0,
    <8108, 8106, 8105>, 0,
    <8108, 8105, 8107>, 0,
    <8110, 8102, 8101>, 0,
    <8110, 8101, 8107>, 0,
    <8110, 8107, 8105>, 0,
    <8110, 8105, 8109>, 0,
    <8110, 8109, 8093>, 0,
    <8110, 8093, 8095>, 0,
    <8110, 8095, 8088>, 0,
    <8110, 8088, 8102>, 0,
    <8119, 8118, 8111>, 0,
    <8119, 8111, 8115>, 0,
    <8119, 8115, 8112>, 0,
    <8119, 8112, 8116>, 0,
    <8119, 8116, 8113>, 0,
    <8119, 8113, 8117>, 0,
    <8119, 8117, 8114>, 0,
    <8119, 8114, 8118>, 0,
    <8122, 8121, 8111>, 0,
    <8122, 8111, 8118>, 0,
    <8122, 8118, 8114>, 0,
    <8122, 8114, 8120>, 0,
    <8122, 8120, 7431>, 0,
    <8122, 7431, 7449>, 0,
    <8122, 7449, 7444>, 0,
    <8122, 7444, 8121>, 0,
    <8124, 8115, 8111>, 0,
    <8124, 8111, 8121>, 0,
    <8124, 8121, 7444>, 0,
    <8124, 7444, 7446>, 0,
    <8124, 7446, 7335>, 0,
    <8124, 7335, 8123>, 0,
    <8124, 8123, 8112>, 0,
    <8124, 8112, 8115>, 0,
    <8130, 8129, 8125>, 0,
    <8130, 8125, 8127>, 0,
    <8130, 8127, 8066>, 0,
    <8130, 8066, 8069>, 0,
    <8130, 8069, 8065>, 0,
    <8130, 8065, 8128>, 0,
    <8130, 8128, 8126>, 0,
    <8130, 8126, 8129>, 0,
    <8133, 8132, 8125>, 0,
    <8133, 8125, 8129>, 0,
    <8133, 8129, 8126>, 0,
    <8133, 8126, 8131>, 0,
    <8133, 8131, 8113>, 0,
    <8133, 8113, 8116>, 0,
    <8133, 8116, 8112>, 0,
    <8133, 8112, 8132>, 0,
    <8134, 8127, 8125>, 0,
    <8134, 8125, 8132>, 0,
    <8134, 8132, 8112>, 0,
    <8134, 8112, 8123>, 0,
    <8134, 8123, 7335>, 0,
    <8134, 7335, 8072>, 0,
    <8134, 8072, 8066>, 0,
    <8134, 8066, 8127>, 0,
    <8140, 8139, 8135>, 0,
    <8140, 8135, 8137>, 0,
    <8140, 8137, 8136>, 0,
    <8140, 8136, 8138>, 0,
    <8140, 8138, 7223>, 0,
    <8140, 7223, 8013>, 0,
    <8140, 8013, 8009>, 0,
    <8140, 8009, 8139>, 0,
    <8144, 8143, 8135>, 0,
    <8144, 8135, 8139>, 0,
    <8144, 8139, 8009>, 0,
    <8144, 8009, 8010>, 0,
    <8144, 8010, 8001>, 0,
    <8144, 8001, 8142>, 0,
    <8144, 8142, 8141>, 0,
    <8144, 8141, 8143>, 0,
    <8148, 8137, 8135>, 0,
    <8148, 8135, 8143>, 0,
    <8148, 8143, 8141>, 0,
    <8148, 8141, 8146>, 0,
    <8148, 8146, 8145>, 0,
    <8148, 8145, 8147>, 0,
    <8148, 8147, 8136>, 0,
    <8148, 8136, 8137>, 0,
    <8152, 8151, 8149>, 0,
    <8152, 8149, 8150>, 0,
    <8152, 8150, 7363>, 0,
    <8152, 7363, 7364>, 0,
    <8152, 7364, 7223>, 0,
    <8152, 7223, 8138>, 0,
    <8152, 8138, 8136>, 0,
    <8152, 8136, 8151>, 0,
    <8156, 8155, 8149>, 0,
    <8156, 8149, 8151>, 0,
    <8156, 8151, 8136>, 0,
    <8156, 8136, 8147>, 0,
    <8156, 8147, 8145>, 0,
    <8156, 8145, 8154>, 0,
    <8156, 8154, 8153>, 0,
    <8156, 8153, 8155>, 0,
    <8158, 8150, 8149>, 0,
    <8158, 8149, 8155>, 0,
    <8158, 8155, 8153>, 0,
    <8158, 8153, 8157>, 0,
    <8158, 8157, 7367>, 0,
    <8158, 7367, 7368>, 0,
    <8158, 7368, 7363>, 0,
    <8158, 7363, 8150>, 0,
    <8167, 8166, 8159>, 0,
    <8167, 8159, 8163>, 0,
    <8167, 8163, 8160>, 0,
    <8167, 8160, 8164>, 0,
    <8167, 8164, 8161>, 0,
    <8167, 8161, 8165>, 0,
    <8167, 8165, 8162>, 0,
    <8167, 8162, 8166>, 0,
    <8170, 8169, 8159>, 0,
    <8170, 8159, 8166>, 0,
    <8170, 8166, 8162>, 0,
    <8170, 8162, 8168>, 0,
    <8170, 8168, 7383>, 0,
    <8170, 7383, 7544>, 0,
    <8170, 7544, 7542>, 0,
    <8170, 7542, 8169>, 0,
    <8172, 8163, 8159>, 0,
    <8172, 8159, 8169>, 0,
    <8172, 8169, 7542>, 0,
    <8172, 7542, 7549>, 0,
    <8172, 7549, 7529>, 0,
    <8172, 7529, 8171>, 0,
    <8172, 8171, 8160>, 0,
    <8172, 8160, 8163>, 0,
    <8178, 8177, 8173>, 0,
    <8178, 8173, 8175>, 0,
    <8178, 8175, 8174>, 0,
    <8178, 8174, 8176>, 0,
    <8178, 8176, 8017>, 0,
    <8178, 8017, 8020>, 0,
    <8178, 8020, 8016>, 0,
    <8178, 8016, 8177>, 0,
    <8180, 8179, 8173>, 0,
    <8180, 8173, 8177>, 0,
    <8180, 8177, 8016>, 0,
    <8180, 8016, 8027>, 0,
    <8180, 8027, 7383>, 0,
    <8180, 7383, 8168>, 0,
    <8180, 8168, 8162>, 0,
    <8180, 8162, 8179>, 0,
    <8182, 8175, 8173>, 0,
    <8182, 8173, 8179>, 0,
    <8182, 8179, 8162>, 0,
    <8182, 8162, 8165>, 0,
    <8182, 8165, 8161>, 0,
    <8182, 8161, 8181>, 0,
    <8182, 8181, 8174>, 0,
    <8182, 8174, 8175>, 0,
    <8188, 8187, 8183>, 0,
    <8188, 8183, 8185>, 0,
    <8188, 8185, 8105>, 0,
    <8188, 8105, 8106>, 0,
    <8188, 8106, 7315>, 0,
    <8188, 7315, 8186>, 0,
    <8188, 8186, 8184>, 0,
    <8188, 8184, 8187>, 0,
    <8194, 8193, 8183>, 0,
    <8194, 8183, 8187>, 0,
    <8194, 8187, 8184>, 0,
    <8194, 8184, 8191>, 0,
    <8194, 8191, 8189>, 0,
    <8194, 8189, 8192>, 0,
    <8194, 8192, 8190>, 0,
    <8194, 8190, 8193>, 0,
    <8196, 8185, 8183>, 0,
    <8196, 8183, 8193>, 0,
    <8196, 8193, 8190>, 0,
    <8196, 8190, 8195>, 0,
    <8196, 8195, 8093>, 0,
    <8196, 8093, 8109>, 0,
    <8196, 8109, 8105>, 0,
    <8196, 8105, 8185>, 0,
    <8200, 8199, 8197>, 0,
    <8200, 8197, 8198>, 0,
    <8200, 8198, 8184>, 0,
    <8200, 8184, 8186>, 0,
    <8200, 8186, 7315>, 0,
    <8200, 7315, 7417>, 0,
    <8200, 7417, 7412>, 0,
    <8200, 7412, 8199>, 0,
    <8204, 8203, 8197>, 0,
    <8204, 8197, 8199>, 0,
    <8204, 8199, 7412>, 0,
    <8204, 7412, 7414>, 0,
    <8204, 7414, 7411>, 0,
    <8204, 7411, 8202>, 0,
    <8204, 8202, 8201>, 0,
    <8204, 8201, 8203>, 0,
    <8206, 8198, 8197>, 0,
    <8206, 8197, 8203>, 0,
    <8206, 8203, 8201>, 0,
    <8206, 8201, 8205>, 0,
    <8206, 8205, 8189>, 0,
    <8206, 8189, 8191>, 0,
    <8206, 8191, 8184>, 0,
    <8206, 8184, 8198>, 0,
    <8215, 8214, 8207>, 0,
    <8215, 8207, 8211>, 0,
    <8215, 8211, 8208>, 0,
    <8215, 8208, 8212>, 0,
    <8215, 8212, 8209>, 0,
    <8215, 8209, 8213>, 0,
    <8215, 8213, 8210>, 0,
    <8215, 8210, 8214>, 0,
    <8218, 8217, 8207>, 0,
    <8218, 8207, 8214>, 0,
    <8218, 8214, 8210>, 0,
    <8218, 8210, 8216>, 0,
    <8218, 8216, 1003>, 0,
    <8218, 1003, 7497>, 0,
    <8218, 7497, 7491>, 0,
    <8218, 7491, 8217>, 0,
    <8220, 8211, 8207>, 0,
    <8220, 8207, 8217>, 0,
    <8220, 8217, 7491>, 0,
    <8220, 7491, 7493>, 0,
    <8220, 7493, 7431>, 0,
    <8220, 7431, 8219>, 0,
    <8220, 8219, 8208>, 0,
    <8220, 8208, 8211>, 0,
    <8226, 8225, 8221>, 0,
    <8226, 8221, 8223>, 0,
    <8226, 8223, 8114>, 0,
    <8226, 8114, 8117>, 0,
    <8226, 8117, 8113>, 0,
    <8226, 8113, 8224>, 0,
    <8226, 8224, 8222>, 0,
    <8226, 8222, 8225>, 0,
    <8229, 8228, 8221>, 0,
    <8229, 8221, 8225>, 0,
    <8229, 8225, 8222>, 0,
    <8229, 8222, 8227>, 0,
    <8229, 8227, 8209>, 0,
    <8229, 8209, 8212>, 0,
    <8229, 8212, 8208>, 0,
    <8229, 8208, 8228>, 0,
    <8230, 8223, 8221>, 0,
    <8230, 8221, 8228>, 0,
    <8230, 8228, 8208>, 0,
    <8230, 8208, 8219>, 0,
    <8230, 8219, 7431>, 0,
    <8230, 7431, 8120>, 0,
    <8230, 8120, 8114>, 0,
    <8230, 8114, 8223>, 0,
    <8236, 8235, 8231>, 0,
    <8236, 8231, 8233>, 0,
    <8236, 8233, 8201>, 0,
    <8236, 8201, 8202>, 0,
    <8236, 8202, 7411>, 0,
    <8236, 7411, 8234>, 0,
    <8236, 8234, 8232>, 0,
    <8236, 8232, 8235>, 0,
    <8241, 8240, 8231>, 0,
    <8241, 8231, 8235>, 0,
    <8241, 8235, 8232>, 0,
    <8241, 8232, 8238>, 0,
    <8241, 8238, 1156>, 0,
    <8241, 1156, 8239>, 0,
    <8241, 8239, 8237>, 0,
    <8241, 8237, 8240>, 0,
    <8243, 8233, 8231>, 0,
    <8243, 8231, 8240>, 0,
    <8243, 8240, 8237>, 0,
    <8243, 8237, 8242>, 0,
    <8243, 8242, 8189>, 0,
    <8243, 8189, 8205>, 0,
    <8243, 8205, 8201>, 0,
    <8243, 8201, 8233>, 0,
    <8247, 8246, 8244>, 0,
    <8247, 8244, 8245>, 0,
    <8247, 8245, 8232>, 0,
    <8247, 8232, 8234>, 0,
    <8247, 8234, 7411>, 0,
    <8247, 7411, 7478>, 0,
    <8247, 7478, 7473>, 0,
    <8247, 7473, 8246>, 0,
    <8251, 8250, 8244>, 0,
    <8251, 8244, 8246>, 0,
    <8251, 8246, 7473>, 0,
    <8251, 7473, 7475>, 0,
    <8251, 7475, 946>, 0,
    <8251, 946, 8249>, 0,
    <8251, 8249, 8248>, 0,
    <8251, 8248, 8250>, 0,
    <8253, 8245, 8244>, 0,
    <8253, 8244, 8250>, 0,
    <8253, 8250, 8248>, 0,
    <8253, 8248, 8252>, 0,
    <8253, 8252, 1156>, 0,
    <8253, 1156, 8238>, 0,
    <8253, 8238, 8232>, 0,
    <8253, 8232, 8245>, 0,
    <8259, 8258, 8254>, 0,
    <8259, 8254, 8256>, 0,
    <8259, 8256, 8210>, 0,
    <8259, 8210, 8213>, 0,
    <8259, 8213, 8209>, 0,
    <8259, 8209, 8257>, 0,
    <8259, 8257, 8255>, 0,
    <8259, 8255, 8258>, 0,
    <8264, 8263, 8254>, 0,
    <8264, 8254, 8258>, 0,
    <8264, 8258, 8255>, 0,
    <8264, 8255, 8261>, 0,
    <8264, 8261, 1213>, 0,
    <8264, 1213, 8262>, 0,
    <8264, 8262, 8260>, 0,
    <8264, 8260, 8263>, 0,
    <8266, 8256, 8254>, 0,
    <8266, 8254, 8263>, 0,
    <8266, 8263, 8260>, 0,
    <8266, 8260, 8265>, 0,
    <8266, 8265, 1003>, 0,
    <8266, 1003, 8216>, 0,
    <8266, 8216, 8210>, 0,
    <8266, 8210, 8256>, 0,
    <8272, 8271, 8267>, 0,
    <8272, 8267, 8269>, 0,
    <8272, 8269, 8268>, 0,
    <8272, 8268, 8270>, 0,
    <8272, 8270, 7367>, 0,
    <8272, 7367, 8157>, 0,
    <8272, 8157, 8153>, 0,
    <8272, 8153, 8271>, 0,
    <8276, 8275, 8267>, 0,
    <8276, 8267, 8271>, 0,
    <8276, 8271, 8153>, 0,
    <8276, 8153, 8154>, 0,
    <8276, 8154, 8145>, 0,
    <8276, 8145, 8274>, 0,
    <8276, 8274, 8273>, 0,
    <8276, 8273, 8275>, 0,
    <8280, 8269, 8267>, 0,
    <8280, 8267, 8275>, 0,
    <8280, 8275, 8273>, 0,
    <8280, 8273, 8278>, 0,
    <8280, 8278, 8277>, 0,
    <8280, 8277, 8279>, 0,
    <8280, 8279, 8268>, 0,
    <8280, 8268, 8269>, 0,
    <8284, 8283, 8281>, 0,
    <8284, 8281, 8282>, 0,
    <8284, 8282, 7509>, 0,
    <8284, 7509, 7510>, 0,
    <8284, 7510, 7367>, 0,
    <8284, 7367, 8270>, 0,
    <8284, 8270, 8268>, 0,
    <8284, 8268, 8283>, 0,
    <8288, 8287, 8281>, 0,
    <8288, 8281, 8283>, 0,
    <8288, 8283, 8268>, 0,
    <8288, 8268, 8279>, 0,
    <8288, 8279, 8277>, 0,
    <8288, 8277, 8286>, 0,
    <8288, 8286, 8285>, 0,
    <8288, 8285, 8287>, 0,
    <8290, 8282, 8281>, 0,
    <8290, 8281, 8287>, 0,
    <8290, 8287, 8285>, 0,
    <8290, 8285, 8289>, 0,
    <8290, 8289, 7513>, 0,
    <8290, 7513, 7514>, 0,
    <8290, 7514, 7509>, 0,
    <8290, 7509, 8282>, 0,
    <8299, 8298, 8291>, 0,
    <8299, 8291, 8295>, 0,
    <8299, 8295, 8292>, 0,
    <8299, 8292, 8296>, 0,
    <8299, 8296, 8293>, 0,
    <8299, 8293, 8297>, 0,
    <8299, 8297, 8294>, 0,
    <8299, 8294, 8298>, 0,
    <8302, 8301, 8291>, 0,
    <8302, 8291, 8298>, 0,
    <8302, 8298, 8294>, 0,
    <8302, 8294, 8300>, 0,
    <8302, 8300, 7529>, 0,
    <8302, 7529, 7592>, 0,
    <8302, 7592, 7590>, 0,
    <8302, 7590, 8301>, 0,
    <8304, 8295, 8291>, 0,
    <8304, 8291, 8301>, 0,
    <8304, 8301, 7590>, 0,
    <8304, 7590, 7597>, 0,
    <8304, 7597, 7577>, 0,
    <8304, 7577, 8303>, 0,
    <8304, 8303, 8292>, 0,
    <8304, 8292, 8295>, 0,
    <8310, 8309, 8305>, 0,
    <8310, 8305, 8307>, 0,
    <8310, 8307, 8306>, 0,
    <8310, 8306, 8308>, 0,
    <8310, 8308, 8161>, 0,
    <8310, 8161, 8164>, 0,
    <8310, 8164, 8160>, 0,
    <8310, 8160, 8309>, 0,
    <8312, 8311, 8305>, 0,
    <8312, 8305, 8309>, 0,
    <8312, 8309, 8160>, 0,
    <8312, 8160, 8171>, 0,
    <8312, 8171, 7529>, 0,
    <8312, 7529, 8300>, 0,
    <8312, 8300, 8294>, 0,
    <8312, 8294, 8311>, 0,
    <8314, 8307, 8305>, 0,
    <8314, 8305, 8311>, 0,
    <8314, 8311, 8294>, 0,
    <8314, 8294, 8297>, 0,
    <8314, 8297, 8293>, 0,
    <8314, 8293, 8313>, 0,
    <8314, 8313, 8306>, 0,
    <8314, 8306, 8307>, 0,
    <8320, 8319, 8315>, 0,
    <8320, 8315, 8317>, 0,
    <8320, 8317, 8316>, 0,
    <8320, 8316, 8318>, 0,
    <8320, 8318, 7513>, 0,
    <8320, 7513, 8289>, 0,
    <8320, 8289, 8285>, 0,
    <8320, 8285, 8319>, 0,
    <8324, 8323, 8315>, 0,
    <8324, 8315, 8319>, 0,
    <8324, 8319, 8285>, 0,
    <8324, 8285, 8286>, 0,
    <8324, 8286, 8277>, 0,
    <8324, 8277, 8322>, 0,
    <8324, 8322, 8321>, 0,
    <8324, 8321, 8323>, 0,
    <8328, 8317, 8315>, 0,
    <8328, 8315, 8323>, 0,
    <8328, 8323, 8321>, 0,
    <8328, 8321, 8326>, 0,
    <8328, 8326, 8325>, 0,
    <8328, 8325, 8327>, 0,
    <8328, 8327, 8316>, 0,
    <8328, 8316, 8317>, 0,
    <8332, 8331, 8329>, 0,
    <8332, 8329, 8330>, 0,
    <8332, 8330, 7557>, 0,
    <8332, 7557, 7558>, 0,
    <8332, 7558, 7513>, 0,
    <8332, 7513, 8318>, 0,
    <8332, 8318, 8316>, 0,
    <8332, 8316, 8331>, 0,
    <8336, 8335, 8329>, 0,
    <8336, 8329, 8331>, 0,
    <8336, 8331, 8316>, 0,
    <8336, 8316, 8327>, 0,
    <8336, 8327, 8325>, 0,
    <8336, 8325, 8334>, 0,
    <8336, 8334, 8333>, 0,
    <8336, 8333, 8335>, 0,
    <8338, 8330, 8329>, 0,
    <8338, 8329, 8335>, 0,
    <8338, 8335, 8333>, 0,
    <8338, 8333, 8337>, 0,
    <8338, 8337, 7561>, 0,
    <8338, 7561, 7562>, 0,
    <8338, 7562, 7557>, 0,
    <8338, 7557, 8330>, 0,
    <8347, 8346, 8339>, 0,
    <8347, 8339, 8343>, 0,
    <8347, 8343, 8340>, 0,
    <8347, 8340, 8344>, 0,
    <8347, 8344, 8341>, 0,
    <8347, 8341, 8345>, 0,
    <8347, 8345, 8342>, 0,
    <8347, 8342, 8346>, 0,
    <8350, 8349, 8339>, 0,
    <8350, 8339, 8346>, 0,
    <8350, 8346, 8342>, 0,
    <8350, 8342, 8348>, 0,
    <8350, 8348, 7577>, 0,
    <8350, 7577, 7622>, 0,
    <8350, 7622, 7620>, 0,
    <8350, 7620, 8349>, 0,
    <8352, 8343, 8339>, 0,
    <8352, 8339, 8349>, 0,
    <8352, 8349, 7620>, 0,
    <8352, 7620, 7627>, 0,
    <8352, 7627, 982>, 0,
    <8352, 982, 8351>, 0,
    <8352, 8351, 8340>, 0,
    <8352, 8340, 8343>, 0,
    <8358, 8357, 8353>, 0,
    <8358, 8353, 8355>, 0,
    <8358, 8355, 8354>, 0,
    <8358, 8354, 8356>, 0,
    <8358, 8356, 8293>, 0,
    <8358, 8293, 8296>, 0,
    <8358, 8296, 8292>, 0,
    <8358, 8292, 8357>, 0,
    <8360, 8359, 8353>, 0,
    <8360, 8353, 8357>, 0,
    <8360, 8357, 8292>, 0,
    <8360, 8292, 8303>, 0,
    <8360, 8303, 7577>, 0,
    <8360, 7577, 8348>, 0,
    <8360, 8348, 8342>, 0,
    <8360, 8342, 8359>, 0,
    <8362, 8355, 8353>, 0,
    <8362, 8353, 8359>, 0,
    <8362, 8359, 8342>, 0,
    <8362, 8342, 8345>, 0,
    <8362, 8345, 8341>, 0,
    <8362, 8341, 8361>, 0,
    <8362, 8361, 8354>, 0,
    <8362, 8354, 8355>, 0,
    <8368, 8367, 8363>, 0,
    <8368, 8363, 8365>, 0,
    <8368, 8365, 8364>, 0,
    <8368, 8364, 8366>, 0,
    <8368, 8366, 7561>, 0,
    <8368, 7561, 8337>, 0,
    <8368, 8337, 8333>, 0,
    <8368, 8333, 8367>, 0,
    <8372, 8371, 8363>, 0,
    <8372, 8363, 8367>, 0,
    <8372, 8367, 8333>, 0,
    <8372, 8333, 8334>, 0,
    <8372, 8334, 8325>, 0,
    <8372, 8325, 8370>, 0,
    <8372, 8370, 8369>, 0,
    <8372, 8369, 8371>, 0,
    <8375, 8365, 8363>, 0,
    <8375, 8363, 8371>, 0,
    <8375, 8371, 8369>, 0,
    <8375, 8369, 8373>, 0,
    <8375, 8373, 1150>, 0,
    <8375, 1150, 8374>, 0,
    <8375, 8374, 8364>, 0,
    <8375, 8364, 8365>, 0,
    <8379, 8378, 8376>, 0,
    <8379, 8376, 8377>, 0,
    <8379, 8377, 7605>, 0,
    <8379, 7605, 7606>, 0,
    <8379, 7606, 7561>, 0,
    <8379, 7561, 8366>, 0,
    <8379, 8366, 8364>, 0,
    <8379, 8364, 8378>, 0,
    <8381, 8380, 8376>, 0,
    <8381, 8376, 8378>, 0,
    <8381, 8378, 8364>, 0,
    <8381, 8364, 8374>, 0,
    <8381, 8374, 1150>, 0,
    <8381, 1150, 1181>, 0,
    <8381, 1181, 1177>, 0,
    <8381, 1177, 8380>, 0,
    <8382, 8377, 8376>, 0,
    <8382, 8376, 8380>, 0,
    <8382, 8380, 1177>, 0,
    <8382, 1177, 1178>, 0,
    <8382, 1178, 940>, 0,
    <8382, 940, 7609>, 0,
    <8382, 7609, 7605>, 0,
    <8382, 7605, 8377>, 0,
    <8388, 8387, 8383>, 0,
    <8388, 8383, 8385>, 0,
    <8388, 8385, 8384>, 0,
    <8388, 8384, 8386>, 0,
    <8388, 8386, 8341>, 0,
    <8388, 8341, 8344>, 0,
    <8388, 8344, 8340>, 0,
    <8388, 8340, 8387>, 0,
    <8390, 8389, 8383>, 0,
    <8390, 8383, 8387>, 0,
    <8390, 8387, 8340>, 0,
    <8390, 8340, 8351>, 0,
    <8390, 8351, 982>, 0,
    <8390, 982, 1209>, 0,
    <8390, 1209, 1205>, 0,
    <8390, 1205, 8389>, 0,
    <8392, 8385, 8383>, 0,
    <8392, 8383, 8389>, 0,
    <8392, 8389, 1205>, 0,
    <8392, 1205, 1206>, 0,
    <8392, 1206, 1192>, 0,
    <8392, 1192, 8391>, 0,
    <8392, 8391, 8384>, 0,
    <8392, 8384, 8385>, 0,
    <8401, 8400, 8393>, 0,
    <8401, 8393, 8397>, 0,
    <8401, 8397, 8394>, 0,
    <8401, 8394, 8398>, 0,
    <8401, 8398, 8395>, 0,
    <8401, 8395, 8399>, 0,
    <8401, 8399, 8396>, 0,
    <8401, 8396, 8400>, 0,
    <8404, 8403, 8393>, 0,
    <8404, 8393, 8400>, 0,
    <8404, 8400, 8396>, 0,
    <8404, 8396, 8402>, 0,
    <8404, 8402, 1045>, 0,
    <8404, 1045, 7671>, 0,
    <8404, 7671, 7666>, 0,
    <8404, 7666, 8403>, 0,
    <8406, 8397, 8393>, 0,
    <8406, 8393, 8403>, 0,
    <8406, 8403, 7666>, 0,
    <8406, 7666, 7668>, 0,
    <8406, 7668, 7665>, 0,
    <8406, 7665, 8405>, 0,
    <8406, 8405, 8394>, 0,
    <8406, 8394, 8397>, 0,
    <8415, 8414, 8407>, 0,
    <8415, 8407, 8411>, 0,
    <8415, 8411, 8408>, 0,
    <8415, 8408, 8412>, 0,
    <8415, 8412, 8409>, 0,
    <8415, 8409, 8413>, 0,
    <8415, 8413, 8410>, 0,
    <8415, 8410, 8414>, 0,
    <8418, 8417, 8407>, 0,
    <8418, 8407, 8414>, 0,
    <8418, 8414, 8410>, 0,
    <8418, 8410, 8416>, 0,
    <8418, 8416, 7690>, 0,
    <8418, 7690, 7719>, 0,
    <8418, 7719, 7714>, 0,
    <8418, 7714, 8417>, 0,
    <8420, 8411, 8407>, 0,
    <8420, 8407, 8417>, 0,
    <8420, 8417, 7714>, 0,
    <8420, 7714, 7716>, 0,
    <8420, 7716, 1087>, 0,
    <8420, 1087, 8419>, 0,
    <8420, 8419, 8408>, 0,
    <8420, 8408, 8411>, 0,
    <8428, 8427, 8421>, 0,
    <8428, 8421, 8424>, 0,
    <8428, 8424, 8422>, 0,
    <8428, 8422, 8425>, 0,
    <8428, 8425, 1351>, 0,
    <8428, 1351, 8426>, 0,
    <8428, 8426, 8423>, 0,
    <8428, 8423, 8427>, 0,
    <8431, 8430, 8421>, 0,
    <8431, 8421, 8427>, 0,
    <8431, 8427, 8423>, 0,
    <8431, 8423, 8429>, 0,
    <8431, 8429, 1081>, 0,
    <8431, 1081, 7840>, 0,
    <8431, 7840, 7838>, 0,
    <8431, 7838, 8430>, 0,
    <8433, 8424, 8421>, 0,
    <8433, 8421, 8430>, 0,
    <8433, 8430, 7838>, 0,
    <8433, 7838, 7845>, 0,
    <8433, 7845, 7825>, 0,
    <8433, 7825, 8432>, 0,
    <8433, 8432, 8422>, 0,
    <8433, 8422, 8424>, 0,
    <8442, 8441, 8434>, 0,
    <8442, 8434, 8438>, 0,
    <8442, 8438, 8435>, 0,
    <8442, 8435, 8439>, 0,
    <8442, 8439, 8436>, 0,
    <8442, 8436, 8440>, 0,
    <8442, 8440, 8437>, 0,
    <8442, 8437, 8441>, 0,
    <8448, 8447, 8434>, 0,
    <8448, 8434, 8441>, 0,
    <8448, 8441, 8437>, 0,
    <8448, 8437, 8445>, 0,
    <8448, 8445, 8443>, 0,
    <8448, 8443, 8446>, 0,
    <8448, 8446, 8444>, 0,
    <8448, 8444, 8447>, 0,
    <8451, 8438, 8434>, 0,
    <8451, 8434, 8447>, 0,
    <8451, 8447, 8444>, 0,
    <8451, 8444, 8449>, 0,
    <8451, 8449, 1311>, 0,
    <8451, 1311, 8450>, 0,
    <8451, 8450, 8435>, 0,
    <8451, 8435, 8438>, 0,
    <8457, 8456, 8452>, 0,
    <8457, 8452, 8454>, 0,
    <8457, 8454, 8437>, 0,
    <8457, 8437, 8440>, 0,
    <8457, 8440, 8436>, 0,
    <8457, 8436, 8455>, 0,
    <8457, 8455, 8453>, 0,
    <8457, 8453, 8456>, 0,
    <8462, 8461, 8452>, 0,
    <8462, 8452, 8456>, 0,
    <8462, 8456, 8453>, 0,
    <8462, 8453, 8459>, 0,
    <8462, 8459, 8395>, 0,
    <8462, 8395, 8460>, 0,
    <8462, 8460, 8458>, 0,
    <8462, 8458, 8461>, 0,
    <8464, 8454, 8452>, 0,
    <8464, 8452, 8461>, 0,
    <8464, 8461, 8458>, 0,
    <8464, 8458, 8463>, 0,
    <8464, 8463, 8443>, 0,
    <8464, 8443, 8445>, 0,
    <8464, 8445, 8437>, 0,
    <8464, 8437, 8454>, 0,
    <8468, 8467, 8465>, 0,
    <8468, 8465, 8466>, 0,
    <8468, 8466, 8458>, 0,
    <8468, 8458, 8460>, 0,
    <8468, 8460, 8395>, 0,
    <8468, 8395, 8398>, 0,
    <8468, 8398, 8394>, 0,
    <8468, 8394, 8467>, 0,
    <8472, 8471, 8465>, 0,
    <8472, 8465, 8467>, 0,
    <8472, 8467, 8394>, 0,
    <8472, 8394, 8405>, 0,
    <8472, 8405, 7665>, 0,
    <8472, 7665, 8470>, 0,
    <8472, 8470, 8469>, 0,
    <8472, 8469, 8471>, 0,
    <8474, 8466, 8465>, 0,
    <8474, 8465, 8471>, 0,
    <8474, 8471, 8469>, 0,
    <8474, 8469, 8473>, 0,
    <8474, 8473, 8443>, 0,
    <8474, 8443, 8463>, 0,
    <8474, 8463, 8458>, 0,
    <8474, 8458, 8466>, 0,
    <8480, 8479, 8475>, 0,
    <8480, 8475, 8477>, 0,
    <8480, 8477, 8410>, 0,
    <8480, 8410, 8413>, 0,
    <8480, 8413, 8409>, 0,
    <8480, 8409, 8478>, 0,
    <8480, 8478, 8476>, 0,
    <8480, 8476, 8479>, 0,
    <8486, 8485, 8475>, 0,
    <8486, 8475, 8479>, 0,
    <8486, 8479, 8476>, 0,
    <8486, 8476, 8483>, 0,
    <8486, 8483, 8481>, 0,
    <8486, 8481, 8484>, 0,
    <8486, 8484, 8482>, 0,
    <8486, 8482, 8485>, 0,
    <8488, 8477, 8475>, 0,
    <8488, 8475, 8485>, 0,
    <8488, 8485, 8482>, 0,
    <8488, 8482, 8487>, 0,
    <8488, 8487, 7690>, 0,
    <8488, 7690, 8416>, 0,
    <8488, 8416, 8410>, 0,
    <8488, 8410, 8477>, 0,
    <8494, 8493, 8489>, 0,
    <8494, 8489, 8491>, 0,
    <8494, 8491, 8476>, 0,
    <8494, 8476, 8478>, 0,
    <8494, 8478, 8409>, 0,
    <8494, 8409, 8492>, 0,
    <8494, 8492, 8490>, 0,
    <8494, 8490, 8493>, 0,
    <8500, 8499, 8489>, 0,
    <8500, 8489, 8493>, 0,
    <8500, 8493, 8490>, 0,
    <8500, 8490, 8497>, 0,
    <8500, 8497, 8495>, 0,
    <8500, 8495, 8498>, 0,
    <8500, 8498, 8496>, 0,
    <8500, 8496, 8499>, 0,
    <8502, 8491, 8489>, 0,
    <8502, 8489, 8499>, 0,
    <8502, 8499, 8496>, 0,
    <8502, 8496, 8501>, 0,
    <8502, 8501, 8481>, 0,
    <8502, 8481, 8483>, 0,
    <8502, 8483, 8476>, 0,
    <8502, 8476, 8491>, 0,
    <8508, 8507, 8503>, 0,
    <8508, 8503, 8505>, 0,
    <8508, 8505, 8482>, 0,
    <8508, 8482, 8484>, 0,
    <8508, 8484, 8481>, 0,
    <8508, 8481, 8506>, 0,
    <8508, 8506, 8504>, 0,
    <8508, 8504, 8507>, 0,
    <8511, 8510, 8503>, 0,
    <8511, 8503, 8507>, 0,
    <8511, 8507, 8504>, 0,
    <8511, 8504, 8509>, 0,
    <8511, 8509, 7760>, 0,
    <8511, 7760, 7778>, 0,
    <8511, 7778, 7773>, 0,
    <8511, 7773, 8510>, 0,
    <8512, 8505, 8503>, 0,
    <8512, 8503, 8510>, 0,
    <8512, 8510, 7773>, 0,
    <8512, 7773, 7775>, 0,
    <8512, 7775, 7690>, 0,
    <8512, 7690, 8487>, 0,
    <8512, 8487, 8482>, 0,
    <8512, 8482, 8505>, 0,
    <8518, 8517, 8513>, 0,
    <8518, 8513, 8515>, 0,
    <8518, 8515, 8496>, 0,
    <8518, 8496, 8498>, 0,
    <8518, 8498, 8495>, 0,
    <8518, 8495, 8516>, 0,
    <8518, 8516, 8514>, 0,
    <8518, 8514, 8517>, 0,
    <8523, 8522, 8513>, 0,
    <8523, 8513, 8517>, 0,
    <8523, 8517, 8514>, 0,
    <8523, 8514, 8520>, 0,
    <8523, 8520, 1370>, 0,
    <8523, 1370, 8521>, 0,
    <8523, 8521, 8519>, 0,
    <8523, 8519, 8522>, 0,
    <8525, 8515, 8513>, 0,
    <8525, 8513, 8522>, 0,
    <8525, 8522, 8519>, 0,
    <8525, 8519, 8524>, 0,
    <8525, 8524, 8481>, 0,
    <8525, 8481, 8501>, 0,
    <8525, 8501, 8496>, 0,
    <8525, 8496, 8515>, 0,
    <8533, 8532, 8526>, 0,
    <8533, 8526, 8529>, 0,
    <8533, 8529, 8527>, 0,
    <8533, 8527, 8530>, 0,
    <8533, 8530, 1345>, 0,
    <8533, 1345, 8531>, 0,
    <8533, 8531, 8528>, 0,
    <8533, 8528, 8532>, 0,
    <8536, 8535, 8526>, 0,
    <8536, 8526, 8532>, 0,
    <8536, 8532, 8528>, 0,
    <8536, 8528, 8534>, 0,
    <8536, 8534, 1351>, 0,
    <8536, 1351, 8425>, 0,
    <8536, 8425, 8422>, 0,
    <8536, 8422, 8535>, 0,
    <8538, 8529, 8526>, 0,
    <8538, 8526, 8535>, 0,
    <8538, 8535, 8422>, 0,
    <8538, 8422, 8432>, 0,
    <8538, 8432, 7825>, 0,
    <8538, 7825, 8537>, 0,
    <8538, 8537, 8527>, 0,
    <8538, 8527, 8529>, 0,
    <8544, 8543, 8539>, 0,
    <8544, 8539, 8541>, 0,
    <8544, 8541, 8469>, 0,
    <8544, 8469, 8470>, 0,
    <8544, 8470, 7665>, 0,
    <8544, 7665, 8542>, 0,
    <8544, 8542, 8540>, 0,
    <8544, 8540, 8543>, 0,
    <8550, 8549, 8539>, 0,
    <8550, 8539, 8543>, 0,
    <8550, 8543, 8540>, 0,
    <8550, 8540, 8547>, 0,
    <8550, 8547, 8545>, 0,
    <8550, 8545, 8548>, 0,
    <8550, 8548, 8546>, 0,
    <8550, 8546, 8549>, 0,
    <8552, 8541, 8539>, 0,
    <8552, 8539, 8549>, 0,
    <8552, 8549, 8546>, 0,
    <8552, 8546, 8551>, 0,
    <8552, 8551, 8443>, 0,
    <8552, 8443, 8473>, 0,
    <8552, 8473, 8469>, 0,
    <8552, 8469, 8541>, 0,
    <8556, 8555, 8553>, 0,
    <8556, 8553, 8554>, 0,
    <8556, 8554, 8540>, 0,
    <8556, 8540, 8542>, 0,
    <8556, 8542, 7665>, 0,
    <8556, 7665, 7746>, 0,
    <8556, 7746, 7741>, 0,
    <8556, 7741, 8555>, 0,
    <8560, 8559, 8553>, 0,
    <8560, 8553, 8555>, 0,
    <8560, 8555, 7741>, 0,
    <8560, 7741, 7743>, 0,
    <8560, 7743, 7740>, 0,
    <8560, 7740, 8558>, 0,
    <8560, 8558, 8557>, 0,
    <8560, 8557, 8559>, 0,
    <8562, 8554, 8553>, 0,
    <8562, 8553, 8559>, 0,
    <8562, 8559, 8557>, 0,
    <8562, 8557, 8561>, 0,
    <8562, 8561, 8545>, 0,
    <8562, 8545, 8547>, 0,
    <8562, 8547, 8540>, 0,
    <8562, 8540, 8554>, 0,
    <8571, 8570, 8563>, 0,
    <8571, 8563, 8567>, 0,
    <8571, 8567, 8564>, 0,
    <8571, 8564, 8568>, 0,
    <8571, 8568, 8565>, 0,
    <8571, 8565, 8569>, 0,
    <8571, 8569, 8566>, 0,
    <8571, 8566, 8570>, 0,
    <8574, 8573, 8563>, 0,
    <8574, 8563, 8570>, 0,
    <8574, 8570, 8566>, 0,
    <8574, 8566, 8572>, 0,
    <8574, 8572, 7873>, 0,
    <8574, 7873, 7891>, 0,
    <8574, 7891, 7886>, 0,
    <8574, 7886, 8573>, 0,
    <8576, 8567, 8563>, 0,
    <8576, 8563, 8573>, 0,
    <8576, 8573, 7886>, 0,
    <8576, 7886, 7888>, 0,
    <8576, 7888, 7760>, 0,
    <8576, 7760, 8575>, 0,
    <8576, 8575, 8564>, 0,
    <8576, 8564, 8567>, 0,
    <8582, 8581, 8577>, 0,
    <8582, 8577, 8579>, 0,
    <8582, 8579, 8504>, 0,
    <8582, 8504, 8506>, 0,
    <8582, 8506, 8481>, 0,
    <8582, 8481, 8580>, 0,
    <8582, 8580, 8578>, 0,
    <8582, 8578, 8581>, 0,
    <8585, 8584, 8577>, 0,
    <8585, 8577, 8581>, 0,
    <8585, 8581, 8578>, 0,
    <8585, 8578, 8583>, 0,
    <8585, 8583, 8565>, 0,
    <8585, 8565, 8568>, 0,
    <8585, 8568, 8564>, 0,
    <8585, 8564, 8584>, 0,
    <8586, 8579, 8577>, 0,
    <8586, 8577, 8584>, 0,
    <8586, 8584, 8564>, 0,
    <8586, 8564, 8575>, 0,
    <8586, 8575, 7760>, 0,
    <8586, 7760, 8509>, 0,
    <8586, 8509, 8504>, 0,
    <8586, 8504, 8579>, 0,
    <8594, 8593, 8587>, 0,
    <8594, 8587, 8590>, 0,
    <8594, 8590, 8588>, 0,
    <8594, 8588, 8591>, 0,
    <8594, 8591, 1398>, 0,
    <8594, 1398, 8592>, 0,
    <8594, 8592, 8589>, 0,
    <8594, 8589, 8593>, 0,
    <8599, 8598, 8587>, 0,
    <8599, 8587, 8593>, 0,
    <8599, 8593, 8589>, 0,
    <8599, 8589, 8596>, 0,
    <8599, 8596, 1318>, 0,
    <8599, 1318, 8597>, 0,
    <8599, 8597, 8595>, 0,
    <8599, 8595, 8598>, 0,
    <8603, 8590, 8587>, 0,
    <8603, 8587, 8598>, 0,
    <8603, 8598, 8595>, 0,
    <8603, 8595, 8601>, 0,
    <8603, 8601, 8600>, 0,
    <8603, 8600, 8602>, 0,
    <8603, 8602, 8588>, 0,
    <8603, 8588, 8590>, 0,
    <8611, 8610, 8604>, 0,
    <8611, 8604, 8607>, 0,
    <8611, 8607, 8605>, 0,
    <8611, 8605, 8608>, 0,
    <8611, 8608, 1052>, 0,
    <8611, 1052, 8609>, 0,
    <8611, 8609, 8606>, 0,
    <8611, 8606, 8610>, 0,
    <8614, 8613, 8604>, 0,
    <8614, 8604, 8610>, 0,
    <8614, 8610, 8606>, 0,
    <8614, 8606, 8612>, 0,
    <8614, 8612, 1398>, 0,
    <8614, 1398, 8591>, 0,
    <8614, 8591, 8588>, 0,
    <8614, 8588, 8613>, 0,
    <8616, 8607, 8604>, 0,
    <8616, 8604, 8613>, 0,
    <8616, 8613, 8588>, 0,
    <8616, 8588, 8602>, 0,
    <8616, 8602, 8600>, 0,
    <8616, 8600, 8615>, 0,
    <8616, 8615, 8605>, 0,
    <8616, 8605, 8607>, 0,
    <8620, 8619, 8617>, 0,
    <8620, 8617, 8618>, 0,
    <8620, 8618, 7791>, 0,
    <8620, 7791, 7793>, 0,
    <8620, 7793, 1052>, 0,
    <8620, 1052, 8608>, 0,
    <8620, 8608, 8605>, 0,
    <8620, 8605, 8619>, 0,
    <8624, 8623, 8617>, 0,
    <8624, 8617, 8619>, 0,
    <8624, 8619, 8605>, 0,
    <8624, 8605, 8615>, 0,
    <8624, 8615, 8600>, 0,
    <8624, 8600, 8622>, 0,
    <8624, 8622, 8621>, 0,
    <8624, 8621, 8623>, 0,
    <8626, 8618, 8617>, 0,
    <8626, 8617, 8623>, 0,
    <8626, 8623, 8621>, 0,
    <8626, 8621, 8625>, 0,
    <8626, 8625, 7796>, 0,
    <8626, 7796, 7797>, 0,
    <8626, 7797, 7791>, 0,
    <8626, 7791, 8618>, 0,
    <8635, 8634, 8627>, 0,
    <8635, 8627, 8631>, 0,
    <8635, 8631, 8628>, 0,
    <8635, 8628, 8632>, 0,
    <8635, 8632, 8629>, 0,
    <8635, 8629, 8633>, 0,
    <8635, 8633, 8630>, 0,
    <8635, 8630, 8634>, 0,
    <8638, 8637, 8627>, 0,
    <8638, 8627, 8634>, 0,
    <8638, 8634, 8630>, 0,
    <8638, 8630, 8636>, 0,
    <8638, 8636, 7825>, 0,
    <8638, 7825, 7936>, 0,
    <8638, 7936, 7934>, 0,
    <8638, 7934, 8637>, 0,
    <8640, 8631, 8627>, 0,
    <8640, 8627, 8637>, 0,
    <8640, 8637, 7934>, 0,
    <8640, 7934, 7941>, 0,
    <8640, 7941, 7921>, 0,
    <8640, 7921, 8639>, 0,
    <8640, 8639, 8628>, 0,
    <8640, 8628, 8631>, 0,
    <8646, 8645, 8641>, 0,
    <8646, 8641, 8643>, 0,
    <8646, 8643, 8642>, 0,
    <8646, 8642, 8644>, 0,
    <8646, 8644, 1345>, 0,
    <8646, 1345, 8530>, 0,
    <8646, 8530, 8527>, 0,
    <8646, 8527, 8645>, 0,
    <8648, 8647, 8641>, 0,
    <8648, 8641, 8645>, 0,
    <8648, 8645, 8527>, 0,
    <8648, 8527, 8537>, 0,
    <8648, 8537, 7825>, 0,
    <8648, 7825, 8636>, 0,
    <8648, 8636, 8630>, 0,
    <8648, 8630, 8647>, 0,
    <8650, 8643, 8641>, 0,
    <8650, 8641, 8647>, 0,
    <8650, 8647, 8630>, 0,
    <8650, 8630, 8633>, 0,
    <8650, 8633, 8629>, 0,
    <8650, 8629, 8649>, 0,
    <8650, 8649, 8642>, 0,
    <8650, 8642, 8643>, 0,
    <8656, 8655, 8651>, 0,
    <8656, 8651, 8653>, 0,
    <8656, 8653, 8557>, 0,
    <8656, 8557, 8558>, 0,
    <8656, 8558, 7740>, 0,
    <8656, 7740, 8654>, 0,
    <8656, 8654, 8652>, 0,
    <8656, 8652, 8655>, 0,
    <8662, 8661, 8651>, 0,
    <8662, 8651, 8655>, 0,
    <8662, 8655, 8652>, 0,
    <8662, 8652, 8659>, 0,
    <8662, 8659, 8657>, 0,
    <8662, 8657, 8660>, 0,
    <8662, 8660, 8658>, 0,
    <8662, 8658, 8661>, 0,
    <8664, 8653, 8651>, 0,
    <8664, 8651, 8661>, 0,
    <8664, 8661, 8658>, 0,
    <8664, 8658, 8663>, 0,
    <8664, 8663, 8545>, 0,
    <8664, 8545, 8561>, 0,
    <8664, 8561, 8557>, 0,
    <8664, 8557, 8653>, 0,
    <8668, 8667, 8665>, 0,
    <8668, 8665, 8666>, 0,
    <8668, 8666, 8652>, 0,
    <8668, 8652, 8654>, 0,
    <8668, 8654, 7740>, 0,
    <8668, 7740, 7859>, 0,
    <8668, 7859, 7854>, 0,
    <8668, 7854, 8667>, 0,
    <8672, 8671, 8665>, 0,
    <8672, 8665, 8667>, 0,
    <8672, 8667, 7854>, 0,
    <8672, 7854, 7856>, 0,
    <8672, 7856, 7853>, 0,
    <8672, 7853, 8670>, 0,
    <8672, 8670, 8669>, 0,
    <8672, 8669, 8671>, 0,
    <8674, 8666, 8665>, 0,
    <8674, 8665, 8671>, 0,
    <8674, 8671, 8669>, 0,
    <8674, 8669, 8673>, 0,
    <8674, 8673, 8657>, 0,
    <8674, 8657, 8659>, 0,
    <8674, 8659, 8652>, 0,
    <8674, 8652, 8666>, 0,
    <8683, 8682, 8675>, 0,
    <8683, 8675, 8679>, 0,
    <8683, 8679, 8676>, 0,
    <8683, 8676, 8680>, 0,
    <8683, 8680, 8677>, 0,
    <8683, 8677, 8681>, 0,
    <8683, 8681, 8678>, 0,
    <8683, 8678, 8682>, 0,
    <8686, 8685, 8675>, 0,
    <8686, 8675, 8682>, 0,
    <8686, 8682, 8678>, 0,
    <8686, 8678, 8684>, 0,
    <8686, 8684, 7969>, 0,
    <8686, 7969, 7987>, 0,
    <8686, 7987, 7982>, 0,
    <8686, 7982, 8685>, 0,
    <8688, 8679, 8675>, 0,
    <8688, 8675, 8685>, 0,
    <8688, 8685, 7982>, 0,
    <8688, 7982, 7984>, 0,
    <8688, 7984, 7873>, 0,
    <8688, 7873, 8687>, 0,
    <8688, 8687, 8676>, 0,
    <8688, 8676, 8679>, 0,
    <8694, 8693, 8689>, 0,
    <8694, 8689, 8691>, 0,
    <8694, 8691, 8566>, 0,
    <8694, 8566, 8569>, 0,
    <8694, 8569, 8565>, 0,
    <8694, 8565, 8692>, 0,
    <8694, 8692, 8690>, 0,
    <8694, 8690, 8693>, 0,
    <8697, 8696, 8689>, 0,
    <8697, 8689, 8693>, 0,
    <8697, 8693, 8690>, 0,
    <8697, 8690, 8695>, 0,
    <8697, 8695, 8677>, 0,
    <8697, 8677, 8680>, 0,
    <8697, 8680, 8676>, 0,
    <8697, 8676, 8696>, 0,
    <8698, 8691, 8689>, 0,
    <8698, 8689, 8696>, 0,
    <8698, 8696, 8676>, 0,
    <8698, 8676, 8687>, 0,
    <8698, 8687, 7873>, 0,
    <8698, 7873, 8572>, 0,
    <8698, 8572, 8566>, 0,
    <8698, 8566, 8691>, 0,
    <8704, 8703, 8699>, 0,
    <8704, 8699, 8701>, 0,
    <8704, 8701, 8700>, 0,
    <8704, 8700, 8702>, 0,
    <8704, 8702, 7796>, 0,
    <8704, 7796, 8625>, 0,
    <8704, 8625, 8621>, 0,
    <8704, 8621, 8703>, 0,
    <8708, 8707, 8699>, 0,
    <8708, 8699, 8703>, 0,
    <8708, 8703, 8621>, 0,
    <8708, 8621, 8622>, 0,
    <8708, 8622, 8600>, 0,
    <8708, 8600, 8706>, 0,
    <8708, 8706, 8705>, 0,
    <8708, 8705, 8707>, 0,
    <8712, 8701, 8699>, 0,
    <8712, 8699, 8707>, 0,
    <8712, 8707, 8705>, 0,
    <8712, 8705, 8710>, 0,
    <8712, 8710, 8709>, 0,
    <8712, 8709, 8711>, 0,
    <8712, 8711, 8700>, 0,
    <8712, 8700, 8701>, 0,
    <8716, 8715, 8713>, 0,
    <8716, 8713, 8714>, 0,
    <8716, 8714, 7901>, 0,
    <8716, 7901, 7902>, 0,
    <8716, 7902, 7796>, 0,
    <8716, 7796, 8702>, 0,
    <8716, 8702, 8700>, 0,
    <8716, 8700, 8715>, 0,
    <8720, 8719, 8713>, 0,
    <8720, 8713, 8715>, 0,
    <8720, 8715, 8700>, 0,
    <8720, 8700, 8711>, 0,
    <8720, 8711, 8709>, 0,
    <8720, 8709, 8718>, 0,
    <8720, 8718, 8717>, 0,
    <8720, 8717, 8719>, 0,
    <8722, 8714, 8713>, 0,
    <8722, 8713, 8719>, 0,
    <8722, 8719, 8717>, 0,
    <8722, 8717, 8721>, 0,
    <8722, 8721, 7905>, 0,
    <8722, 7905, 7906>, 0,
    <8722, 7906, 7901>, 0,
    <8722, 7901, 8714>, 0,
    <8731, 8730, 8723>, 0,
    <8731, 8723, 8727>, 0,
    <8731, 8727, 8724>, 0,
    <8731, 8724, 8728>, 0,
    <8731, 8728, 8725>, 0,
    <8731, 8725, 8729>, 0,
    <8731, 8729, 8726>, 0,
    <8731, 8726, 8730>, 0,
    <8734, 8733, 8723>, 0,
    <8734, 8723, 8730>, 0,
    <8734, 8730, 8726>, 0,
    <8734, 8726, 8732>, 0,
    <8734, 8732, 7921>, 0,
    <8734, 7921, 8032>, 0,
    <8734, 8032, 8030>, 0,
    <8734, 8030, 8733>, 0,
    <8736, 8727, 8723>, 0,
    <8736, 8723, 8733>, 0,
    <8736, 8733, 8030>, 0,
    <8736, 8030, 8037>, 0,
    <8736, 8037, 8017>, 0,
    <8736, 8017, 8735>, 0,
    <8736, 8735, 8724>, 0,
    <8736, 8724, 8727>, 0,
    <8742, 8741, 8737>, 0,
    <8742, 8737, 8739>, 0,
    <8742, 8739, 8738>, 0,
    <8742, 8738, 8740>, 0,
    <8742, 8740, 8629>, 0,
    <8742, 8629, 8632>, 0,
    <8742, 8632, 8628>, 0,
    <8742, 8628, 8741>, 0,
    <8744, 8743, 8737>, 0,
    <8744, 8737, 8741>, 0,
    <8744, 8741, 8628>, 0,
    <8744, 8628, 8639>, 0,
    <8744, 8639, 7921>, 0,
    <8744, 7921, 8732>, 0,
    <8744, 8732, 8726>, 0,
    <8744, 8726, 8743>, 0,
    <8746, 8739, 8737>, 0,
    <8746, 8737, 8743>, 0,
    <8746, 8743, 8726>, 0,
    <8746, 8726, 8729>, 0,
    <8746, 8729, 8725>, 0,
    <8746, 8725, 8745>, 0,
    <8746, 8745, 8738>, 0,
    <8746, 8738, 8739>, 0,
    <8752, 8751, 8747>, 0,
    <8752, 8747, 8749>, 0,
    <8752, 8749, 8669>, 0,
    <8752, 8669, 8670>, 0,
    <8752, 8670, 7853>, 0,
    <8752, 7853, 8750>, 0,
    <8752, 8750, 8748>, 0,
    <8752, 8748, 8751>, 0,
    <8758, 8757, 8747>, 0,
    <8758, 8747, 8751>, 0,
    <8758, 8751, 8748>, 0,
    <8758, 8748, 8755>, 0,
    <8758, 8755, 8753>, 0,
    <8758, 8753, 8756>, 0,
    <8758, 8756, 8754>, 0,
    <8758, 8754, 8757>, 0,
    <8760, 8749, 8747>, 0,
    <8760, 8747, 8757>, 0,
    <8760, 8757, 8754>, 0,
    <8760, 8754, 8759>, 0,
    <8760, 8759, 8657>, 0,
    <8760, 8657, 8673>, 0,
    <8760, 8673, 8669>, 0,
    <8760, 8669, 8749>, 0,
    <8764, 8763, 8761>, 0,
    <8764, 8761, 8762>, 0,
    <8764, 8762, 8748>, 0,
    <8764, 8748, 8750>, 0,
    <8764, 8750, 7853>, 0,
    <8764, 7853, 7955>, 0,
    <8764, 7955, 7950>, 0,
    <8764, 7950, 8763>, 0,
    <8768, 8767, 8761>, 0,
    <8768, 8761, 8763>, 0,
    <8768, 8763, 7950>, 0,
    <8768, 7950, 7952>, 0,
    <8768, 7952, 7949>, 0,
    <8768, 7949, 8766>, 0,
    <8768, 8766, 8765>, 0,
    <8768, 8765, 8767>, 0,
    <8770, 8762, 8761>, 0,
    <8770, 8761, 8767>, 0,
    <8770, 8767, 8765>, 0,
    <8770, 8765, 8769>, 0,
    <8770, 8769, 8753>, 0,
    <8770, 8753, 8755>, 0,
    <8770, 8755, 8748>, 0,
    <8770, 8748, 8762>, 0,
    <8779, 8778, 8771>, 0,
    <8779, 8771, 8775>, 0,
    <8779, 8775, 8772>, 0,
    <8779, 8772, 8776>, 0,
    <8779, 8776, 8773>, 0,
    <8779, 8773, 8777>, 0,
    <8779, 8777, 8774>, 0,
    <8779, 8774, 8778>, 0,
    <8782, 8781, 8771>, 0,
    <8782, 8771, 8778>, 0,
    <8782, 8778, 8774>, 0,
    <8782, 8774, 8780>, 0,
    <8782, 8780, 8065>, 0,
    <8782, 8065, 8083>, 0,
    <8782, 8083, 8078>, 0,
    <8782, 8078, 8781>, 0,
    <8784, 8775, 8771>, 0,
    <8784, 8771, 8781>, 0,
    <8784, 8781, 8078>, 0,
    <8784, 8078, 8080>, 0,
    <8784, 8080, 7969>, 0,
    <8784, 7969, 8783>, 0,
    <8784, 8783, 8772>, 0,
    <8784, 8772, 8775>, 0,
    <8790, 8789, 8785>, 0,
    <8790, 8785, 8787>, 0,
    <8790, 8787, 8678>, 0,
    <8790, 8678, 8681>, 0,
    <8790, 8681, 8677>, 0,
    <8790, 8677, 8788>, 0,
    <8790, 8788, 8786>, 0,
    <8790, 8786, 8789>, 0,
    <8793, 8792, 8785>, 0,
    <8793, 8785, 8789>, 0,
    <8793, 8789, 8786>, 0,
    <8793, 8786, 8791>, 0,
    <8793, 8791, 8773>, 0,
    <8793, 8773, 8776>, 0,
    <8793, 8776, 8772>, 0,
    <8793, 8772, 8792>, 0,
    <8794, 8787, 8785>, 0,
    <8794, 8785, 8792>, 0,
    <8794, 8792, 8772>, 0,
    <8794, 8772, 8783>, 0,
    <8794, 8783, 7969>, 0,
    <8794, 7969, 8684>, 0,
    <8794, 8684, 8678>, 0,
    <8794, 8678, 8787>, 0,
    <8800, 8799, 8795>, 0,
    <8800, 8795, 8797>, 0,
    <8800, 8797, 8796>, 0,
    <8800, 8796, 8798>, 0,
    <8800, 8798, 7905>, 0,
    <8800, 7905, 8721>, 0,
    <8800, 8721, 8717>, 0,
    <8800, 8717, 8799>, 0,
    <8804, 8803, 8795>, 0,
    <8804, 8795, 8799>, 0,
    <8804, 8799, 8717>, 0,
    <8804, 8717, 8718>, 0,
    <8804, 8718, 8709>, 0,
    <8804, 8709, 8802>, 0,
    <8804, 8802, 8801>, 0,
    <8804, 8801, 8803>, 0,
    <8808, 8797, 8795>, 0,
    <8808, 8795, 8803>, 0,
    <8808, 8803, 8801>, 0,
    <8808, 8801, 8806>, 0,
    <8808, 8806, 8805>, 0,
    <8808, 8805, 8807>, 0,
    <8808, 8807, 8796>, 0,
    <8808, 8796, 8797>, 0,
    <8812, 8811, 8809>, 0,
    <8812, 8809, 8810>, 0,
    <8812, 8810, 7997>, 0,
    <8812, 7997, 7998>, 0,
    <8812, 7998, 7905>, 0,
    <8812, 7905, 8798>, 0,
    <8812, 8798, 8796>, 0,
    <8812, 8796, 8811>, 0,
    <8816, 8815, 8809>, 0,
    <8816, 8809, 8811>, 0,
    <8816, 8811, 8796>, 0,
    <8816, 8796, 8807>, 0,
    <8816, 8807, 8805>, 0,
    <8816, 8805, 8814>, 0,
    <8816, 8814, 8813>, 0,
    <8816, 8813, 8815>, 0,
    <8818, 8810, 8809>, 0,
    <8818, 8809, 8815>, 0,
    <8818, 8815, 8813>, 0,
    <8818, 8813, 8817>, 0,
    <8818, 8817, 8001>, 0,
    <8818, 8001, 8002>, 0,
    <8818, 8002, 7997>, 0,
    <8818, 7997, 8810>, 0,
    <8827, 8826, 8819>, 0,
    <8827, 8819, 8823>, 0,
    <8827, 8823, 8820>, 0,
    <8827, 8820, 8824>, 0,
    <8827, 8824, 8821>, 0,
    <8827, 8821, 8825>, 0,
    <8827, 8825, 8822>, 0,
    <8827, 8822, 8826>, 0,
    <8830, 8829, 8819>, 0,
    <8830, 8819, 8826>, 0,
    <8830, 8826, 8822>, 0,
    <8830, 8822, 8828>, 0,
    <8830, 8828, 8017>, 0,
    <8830, 8017, 8176>, 0,
    <8830, 8176, 8174>, 0,
    <8830, 8174, 8829>, 0,
    <8832, 8823, 8819>, 0,
    <8832, 8819, 8829>, 0,
    <8832, 8829, 8174>, 0,
    <8832, 8174, 8181>, 0,
    <8832, 8181, 8161>, 0,
    <8832, 8161, 8831>, 0,
    <8832, 8831, 8820>, 0,
    <8832, 8820, 8823>, 0,
    <8838, 8837, 8833>, 0,
    <8838, 8833, 8835>, 0,
    <8838, 8835, 8834>, 0,
    <8838, 8834, 8836>, 0,
    <8838, 8836, 8725>, 0,
    <8838, 8725, 8728>, 0,
    <8838, 8728, 8724>, 0,
    <8838, 8724, 8837>, 0,
    <8840, 8839, 8833>, 0,
    <8840, 8833, 8837>, 0,
    <8840, 8837, 8724>, 0,
    <8840, 8724, 8735>, 0,
    <8840, 8735, 8017>, 0,
    <8840, 8017, 8828>, 0,
    <8840, 8828, 8822>, 0,
    <8840, 8822, 8839>, 0,
    <8842, 8835, 8833>, 0,
    <8842, 8833, 8839>, 0,
    <8842, 8839, 8822>, 0,
    <8842, 8822, 8825>, 0,
    <8842, 8825, 8821>, 0,
    <8842, 8821, 8841>, 0,
    <8842, 8841, 8834>, 0,
    <8842, 8834, 8835>, 0,
    <8848, 8847, 8843>, 0,
    <8848, 8843, 8845>, 0,
    <8848, 8845, 8765>, 0,
    <8848, 8765, 8766>, 0,
    <8848, 8766, 7949>, 0,
    <8848, 7949, 8846>, 0,
    <8848, 8846, 8844>, 0,
    <8848, 8844, 8847>, 0,
    <8854, 8853, 8843>, 0,
    <8854, 8843, 8847>, 0,
    <8854, 8847, 8844>, 0,
    <8854, 8844, 8851>, 0,
    <8854, 8851, 8849>, 0,
    <8854, 8849, 8852>, 0,
    <8854, 8852, 8850>, 0,
    <8854, 8850, 8853>, 0,
    <8856, 8845, 8843>, 0,
    <8856, 8843, 8853>, 0,
    <8856, 8853, 8850>, 0,
    <8856, 8850, 8855>, 0,
    <8856, 8855, 8753>, 0,
    <8856, 8753, 8769>, 0,
    <8856, 8769, 8765>, 0,
    <8856, 8765, 8845>, 0,
    <8860, 8859, 8857>, 0,
    <8860, 8857, 8858>, 0,
    <8860, 8858, 8844>, 0,
    <8860, 8844, 8846>, 0,
    <8860, 8846, 7949>, 0,
    <8860, 7949, 8051>, 0,
    <8860, 8051, 8046>, 0,
    <8860, 8046, 8859>, 0,
    <8864, 8863, 8857>, 0,
    <8864, 8857, 8859>, 0,
    <8864, 8859, 8046>, 0,
    <8864, 8046, 8048>, 0,
    <8864, 8048, 8045>, 0,
    <8864, 8045, 8862>, 0,
    <8864, 8862, 8861>, 0,
    <8864, 8861, 8863>, 0,
    <8866, 8858, 8857>, 0,
    <8866, 8857, 8863>, 0,
    <8866, 8863, 8861>, 0,
    <8866, 8861, 8865>, 0,
    <8866, 8865, 8849>, 0,
    <8866, 8849, 8851>, 0,
    <8866, 8851, 8844>, 0,
    <8866, 8844, 8858>, 0,
    <8875, 8874, 8867>, 0,
    <8875, 8867, 8871>, 0,
    <8875, 8871, 8868>, 0,
    <8875, 8868, 8872>, 0,
    <8875, 8872, 8869>, 0,
    <8875, 8869, 8873>, 0,
    <8875, 8873, 8870>, 0,
    <8875, 8870, 8874>, 0,
    <8878, 8877, 8867>, 0,
    <8878, 8867, 8874>, 0,
    <8878, 8874, 8870>, 0,
    <8878, 8870, 8876>, 0,
    <8878, 8876, 8113>, 0,
    <8878, 8113, 8131>, 0,
    <8878, 8131, 8126>, 0,
    <8878, 8126, 8877>, 0,
    <8880, 8871, 8867>, 0,
    <8880, 8867, 8877>, 0,
    <8880, 8877, 8126>, 0,
    <8880, 8126, 8128>, 0,
    <8880, 8128, 8065>, 0,
    <8880, 8065, 8879>, 0,
    <8880, 8879, 8868>, 0,
    <8880, 8868, 8871>, 0,
    <8886, 8885, 8881>, 0,
    <8886, 8881, 8883>, 0,
    <8886, 8883, 8774>, 0,
    <8886, 8774, 8777>, 0,
    <8886, 8777, 8773>, 0,
    <8886, 8773, 8884>, 0,
    <8886, 8884, 8882>, 0,
    <8886, 8882, 8885>, 0,
    <8889, 8888, 8881>, 0,
    <8889, 8881, 8885>, 0,
    <8889, 8885, 8882>, 0,
    <8889, 8882, 8887>, 0,
    <8889, 8887, 8869>, 0,
    <8889, 8869, 8872>, 0,
    <8889, 8872, 8868>, 0,
    <8889, 8868, 8888>, 0,
    <8890, 8883, 8881>, 0,
    <8890, 8881, 8888>, 0,
    <8890, 8888, 8868>, 0,
    <8890, 8868, 8879>, 0,
    <8890, 8879, 8065>, 0,
    <8890, 8065, 8780>, 0,
    <8890, 8780, 8774>, 0,
    <8890, 8774, 8883>, 0,
    <8896, 8895, 8891>, 0,
    <8896, 8891, 8893>, 0,
    <8896, 8893, 8861>, 0,
    <8896, 8861, 8862>, 0,
    <8896, 8862, 8045>, 0,
    <8896, 8045, 8894>, 0,
    <8896, 8894, 8892>, 0,
    <8896, 8892, 8895>, 0,
    <8902, 8901, 8891>, 0,
    <8902, 8891, 8895>, 0,
    <8902, 8895, 8892>, 0,
    <8902, 8892, 8899>, 0,
    <8902, 8899, 8897>, 0,
    <8902, 8897, 8900>, 0,
    <8902, 8900, 8898>, 0,
    <8902, 8898, 8901>, 0,
    <8904, 8893, 8891>, 0,
    <8904, 8891, 8901>, 0,
    <8904, 8901, 8898>, 0,
    <8904, 8898, 8903>, 0,
    <8904, 8903, 8849>, 0,
    <8904, 8849, 8865>, 0,
    <8904, 8865, 8861>, 0,
    <8904, 8861, 8893>, 0,
    <8908, 8907, 8905>, 0,
    <8908, 8905, 8906>, 0,
    <8908, 8906, 8892>, 0,
    <8908, 8892, 8894>, 0,
    <8908, 8894, 8045>, 0,
    <8908, 8045, 8099>, 0,
    <8908, 8099, 8094>, 0,
    <8908, 8094, 8907>, 0,
    <8912, 8911, 8905>, 0,
    <8912, 8905, 8907>, 0,
    <8912, 8907, 8094>, 0,
    <8912, 8094, 8096>, 0,
    <8912, 8096, 8093>, 0,
    <8912, 8093, 8910>, 0,
    <8912, 8910, 8909>, 0,
    <8912, 8909, 8911>, 0,
    <8914, 8906, 8905>, 0,
    <8914, 8905, 8911>, 0,
    <8914, 8911, 8909>, 0,
    <8914, 8909, 8913>, 0,
    <8914, 8913, 8897>, 0,
    <8914, 8897, 8899>, 0,
    <8914, 8899, 8892>, 0,
    <8914, 8892, 8906>, 0,
    <8923, 8922, 8915>, 0,
    <8923, 8915, 8919>, 0,
    <8923, 8919, 8916>, 0,
    <8923, 8916, 8920>, 0,
    <8923, 8920, 8917>, 0,
    <8923, 8917, 8921>, 0,
    <8923, 8921, 8918>, 0,
    <8923, 8918, 8922>, 0,
    <8926, 8925, 8915>, 0,
    <8926, 8915, 8922>, 0,
    <8926, 8922, 8918>, 0,
    <8926, 8918, 8924>, 0,
    <8926, 8924, 8209>, 0,
    <8926, 8209, 8227>, 0,
    <8926, 8227, 8222>, 0,
    <8926, 8222, 8925>, 0,
    <8928, 8919, 8915>, 0,
    <8928, 8915, 8925>, 0,
    <8928, 8925, 8222>, 0,
    <8928, 8222, 8224>, 0,
    <8928, 8224, 8113>, 0,
    <8928, 8113, 8927>, 0,
    <8928, 8927, 8916>, 0,
    <8928, 8916, 8919>, 0,
    <8934, 8933, 8929>, 0,
    <8934, 8929, 8931>, 0,
    <8934, 8931, 8870>, 0,
    <8934, 8870, 8873>, 0,
    <8934, 8873, 8869>, 0,
    <8934, 8869, 8932>, 0,
    <8934, 8932, 8930>, 0,
    <8934, 8930, 8933>, 0,
    <8937, 8936, 8929>, 0,
    <8937, 8929, 8933>, 0,
    <8937, 8933, 8930>, 0,
    <8937, 8930, 8935>, 0,
    <8937, 8935, 8917>, 0,
    <8937, 8917, 8920>, 0,
    <8937, 8920, 8916>, 0,
    <8937, 8916, 8936>, 0,
    <8938, 8931, 8929>, 0,
    <8938, 8929, 8936>, 0,
    <8938, 8936, 8916>, 0,
    <8938, 8916, 8927>, 0,
    <8938, 8927, 8113>, 0,
    <8938, 8113, 8876>, 0,
    <8938, 8876, 8870>, 0,
    <8938, 8870, 8931>, 0,
    <8944, 8943, 8939>, 0,
    <8944, 8939, 8941>, 0,
    <8944, 8941, 8940>, 0,
    <8944, 8940, 8942>, 0,
    <8944, 8942, 8001>, 0,
    <8944, 8001, 8817>, 0,
    <8944, 8817, 8813>, 0,
    <8944, 8813, 8943>, 0,
    <8948, 8947, 8939>, 0,
    <8948, 8939, 8943>, 0,
    <8948, 8943, 8813>, 0,
    <8948, 8813, 8814>, 0,
    <8948, 8814, 8805>, 0,
    <8948, 8805, 8946>, 0,
    <8948, 8946, 8945>, 0,
    <8948, 8945, 8947>, 0,
    <8952, 8941, 8939>, 0,
    <8952, 8939, 8947>, 0,
    <8952, 8947, 8945>, 0,
    <8952, 8945, 8950>, 0,
    <8952, 8950, 8949>, 0,
    <8952, 8949, 8951>, 0,
    <8952, 8951, 8940>, 0,
    <8952, 8940, 8941>, 0,
    <8956, 8955, 8953>, 0,
    <8956, 8953, 8954>, 0,
    <8956, 8954, 8141>, 0,
    <8956, 8141, 8142>, 0,
    <8956, 8142, 8001>, 0,
    <8956, 8001, 8942>, 0,
    <8956, 8942, 8940>, 0,
    <8956, 8940, 8955>, 0,
    <8960, 8959, 8953>, 0,
    <8960, 8953, 8955>, 0,
    <8960, 8955, 8940>, 0,
    <8960, 8940, 8951>, 0,
    <8960, 8951, 8949>, 0,
    <8960, 8949, 8958>, 0,
    <8960, 8958, 8957>, 0,
    <8960, 8957, 8959>, 0,
    <8962, 8954, 8953>, 0,
    <8962, 8953, 8959>, 0,
    <8962, 8959, 8957>, 0,
    <8962, 8957, 8961>, 0,
    <8962, 8961, 8145>, 0,
    <8962, 8145, 8146>, 0,
    <8962, 8146, 8141>, 0,
    <8962, 8141, 8954>, 0,
    <8971, 8970, 8963>, 0,
    <8971, 8963, 8967>, 0,
    <8971, 8967, 8964>, 0,
    <8971, 8964, 8968>, 0,
    <8971, 8968, 8965>, 0,
    <8971, 8965, 8969>, 0,
    <8971, 8969, 8966>, 0,
    <8971, 8966, 8970>, 0,
    <8974, 8973, 8963>, 0,
    <8974, 8963, 8970>, 0,
    <8974, 8970, 8966>, 0,
    <8974, 8966, 8972>, 0,
    <8974, 8972, 8161>, 0,
    <8974, 8161, 8308>, 0,
    <8974, 8308, 8306>, 0,
    <8974, 8306, 8973>, 0,
    <8976, 8967, 8963>, 0,
    <8976, 8963, 8973>, 0,
    <8976, 8973, 8306>, 0,
    <8976, 8306, 8313>, 0,
    <8976, 8313, 8293>, 0,
    <8976, 8293, 8975>, 0,
    <8976, 8975, 8964>, 0,
    <8976, 8964, 8967>, 0,
    <8982, 8981, 8977>, 0,
    <8982, 8977, 8979>, 0,
    <8982, 8979, 8978>, 0,
    <8982, 8978, 8980>, 0,
    <8982, 8980, 8821>, 0,
    <8982, 8821, 8824>, 0,
    <8982, 8824, 8820>, 0,
    <8982, 8820, 8981>, 0,
    <8984, 8983, 8977>, 0,
    <8984, 8977, 8981>, 0,
    <8984, 8981, 8820>, 0,
    <8984, 8820, 8831>, 0,
    <8984, 8831, 8161>, 0,
    <8984, 8161, 8972>, 0,
    <8984, 8972, 8966>, 0,
    <8984, 8966, 8983>, 0,
    <8986, 8979, 8977>, 0,
    <8986, 8977, 8983>, 0,
    <8986, 8983, 8966>, 0,
    <8986, 8966, 8969>, 0,
    <8986, 8969, 8965>, 0,
    <8986, 8965, 8985>, 0,
    <8986, 8985, 8978>, 0,
    <8986, 8978, 8979>, 0,
    <8992, 8991, 8987>, 0,
    <8992, 8987, 8989>, 0,
    <8992, 8989, 8909>, 0,
    <8992, 8909, 8910>, 0,
    <8992, 8910, 8093>, 0,
    <8992, 8093, 8990>, 0,
    <8992, 8990, 8988>, 0,
    <8992, 8988, 8991>, 0,
    <8998, 8997, 8987>, 0,
    <8998, 8987, 8991>, 0,
    <8998, 8991, 8988>, 0,
    <8998, 8988, 8995>, 0,
    <8998, 8995, 8993>, 0,
    <8998, 8993, 8996>, 0,
    <8998, 8996, 8994>, 0,
    <8998, 8994, 8997>, 0,
    <9000, 8989, 8987>, 0,
    <9000, 8987, 8997>, 0,
    <9000, 8997, 8994>, 0,
    <9000, 8994, 8999>, 0,
    <9000, 8999, 8897>, 0,
    <9000, 8897, 8913>, 0,
    <9000, 8913, 8909>, 0,
    <9000, 8909, 8989>, 0,
    <9004, 9003, 9001>, 0,
    <9004, 9001, 9002>, 0,
    <9004, 9002, 8988>, 0,
    <9004, 8988, 8990>, 0,
    <9004, 8990, 8093>, 0,
    <9004, 8093, 8195>, 0,
    <9004, 8195, 8190>, 0,
    <9004, 8190, 9003>, 0,
    <9008, 9007, 9001>, 0,
    <9008, 9001, 9003>, 0,
    <9008, 9003, 8190>, 0,
    <9008, 8190, 8192>, 0,
    <9008, 8192, 8189>, 0,
    <9008, 8189, 9006>, 0,
    <9008, 9006, 9005>, 0,
    <9008, 9005, 9007>, 0,
    <9010, 9002, 9001>, 0,
    <9010, 9001, 9007>, 0,
    <9010, 9007, 9005>, 0,
    <9010, 9005, 9009>, 0,
    <9010, 9009, 8993>, 0,
    <9010, 8993, 8995>, 0,
    <9010, 8995, 8988>, 0,
    <9010, 8988, 9002>, 0,
    <9019, 9018, 9011>, 0,
    <9019, 9011, 9015>, 0,
    <9019, 9015, 9012>, 0,
    <9019, 9012, 9016>, 0,
    <9019, 9016, 9013>, 0,
    <9019, 9013, 9017>, 0,
    <9019, 9017, 9014>, 0,
    <9019, 9014, 9018>, 0,
    <9022, 9021, 9011>, 0,
    <9022, 9011, 9018>, 0,
    <9022, 9018, 9014>, 0,
    <9022, 9014, 9020>, 0,
    <9022, 9020, 1213>, 0,
    <9022, 1213, 8261>, 0,
    <9022, 8261, 8255>, 0,
    <9022, 8255, 9021>, 0,
    <9024, 9015, 9011>, 0,
    <9024, 9011, 9021>, 0,
    <9024, 9021, 8255>, 0,
    <9024, 8255, 8257>, 0,
    <9024, 8257, 8209>, 0,
    <9024, 8209, 9023>, 0,
    <9024, 9023, 9012>, 0,
    <9024, 9012, 9015>, 0,
    <9030, 9029, 9025>, 0,
    <9030, 9025, 9027>, 0,
    <9030, 9027, 8918>, 0,
    <9030, 8918, 8921>, 0,
    <9030, 8921, 8917>, 0,
    <9030, 8917, 9028>, 0,
    <9030, 9028, 9026>, 0,
    <9030, 9026, 9029>, 0,
    <9033, 9032, 9025>, 0,
    <9033, 9025, 9029>, 0,
    <9033, 9029, 9026>, 0,
    <9033, 9026, 9031>, 0,
    <9033, 9031, 9013>, 0,
    <9033, 9013, 9016>, 0,
    <9033, 9016, 9012>, 0,
    <9033, 9012, 9032>, 0,
    <9034, 9027, 9025>, 0,
    <9034, 9025, 9032>, 0,
    <9034, 9032, 9012>, 0,
    <9034, 9012, 9023>, 0,
    <9034, 9023, 8209>, 0,
    <9034, 8209, 8924>, 0,
    <9034, 8924, 8918>, 0,
    <9034, 8918, 9027>, 0,
    <9040, 9039, 9035>, 0,
    <9040, 9035, 9037>, 0,
    <9040, 9037, 9005>, 0,
    <9040, 9005, 9006>, 0,
    <9040, 9006, 8189>, 0,
    <9040, 8189, 9038>, 0,
    <9040, 9038, 9036>, 0,
    <9040, 9036, 9039>, 0,
    <9045, 9044, 9035>, 0,
    <9045, 9035, 9039>, 0,
    <9045, 9039, 9036>, 0,
    <9045, 9036, 9042>, 0,
    <9045, 9042, 1428>, 0,
    <9045, 1428, 9043>, 0,
    <9045, 9043, 9041>, 0,
    <9045, 9041, 9044>, 0,
    <9047, 9037, 9035>, 0,
    <9047, 9035, 9044>, 0,
    <9047, 9044, 9041>, 0,
    <9047, 9041, 9046>, 0,
    <9047, 9046, 8993>, 0,
    <9047, 8993, 9009>, 0,
    <9047, 9009, 9005>, 0,
    <9047, 9005, 9037>, 0,
    <9051, 9050, 9048>, 0,
    <9051, 9048, 9049>, 0,
    <9051, 9049, 9036>, 0,
    <9051, 9036, 9038>, 0,
    <9051, 9038, 8189>, 0,
    <9051, 8189, 8242>, 0,
    <9051, 8242, 8237>, 0,
    <9051, 8237, 9050>, 0,
    <9055, 9054, 9048>, 0,
    <9055, 9048, 9050>, 0,
    <9055, 9050, 8237>, 0,
    <9055, 8237, 8239>, 0,
    <9055, 8239, 1156>, 0,
    <9055, 1156, 9053>, 0,
    <9055, 9053, 9052>, 0,
    <9055, 9052, 9054>, 0,
    <9057, 9049, 9048>, 0,
    <9057, 9048, 9054>, 0,
    <9057, 9054, 9052>, 0,
    <9057, 9052, 9056>, 0,
    <9057, 9056, 1428>, 0,
    <9057, 1428, 9042>, 0,
    <9057, 9042, 9036>, 0,
    <9057, 9036, 9049>, 0,
    <9063, 9062, 9058>, 0,
    <9063, 9058, 9060>, 0,
    <9063, 9060, 9014>, 0,
    <9063, 9014, 9017>, 0,
    <9063, 9017, 9013>, 0,
    <9063, 9013, 9061>, 0,
    <9063, 9061, 9059>, 0,
    <9063, 9059, 9062>, 0,
    <9068, 9067, 9058>, 0,
    <9068, 9058, 9062>, 0,
    <9068, 9062, 9059>, 0,
    <9068, 9059, 9065>, 0,
    <9068, 9065, 1485>, 0,
    <9068, 1485, 9066>, 0,
    <9068, 9066, 9064>, 0,
    <9068, 9064, 9067>, 0,
    <9070, 9060, 9058>, 0,
    <9070, 9058, 9067>, 0,
    <9070, 9067, 9064>, 0,
    <9070, 9064, 9069>, 0,
    <9070, 9069, 1213>, 0,
    <9070, 1213, 9020>, 0,
    <9070, 9020, 9014>, 0,
    <9070, 9014, 9060>, 0,
    <9076, 9075, 9071>, 0,
    <9076, 9071, 9073>, 0,
    <9076, 9073, 9072>, 0,
    <9076, 9072, 9074>, 0,
    <9076, 9074, 8145>, 0,
    <9076, 8145, 8961>, 0,
    <9076, 8961, 8957>, 0,
    <9076, 8957, 9075>, 0,
    <9080, 9079, 9071>, 0,
    <9080, 9071, 9075>, 0,
    <9080, 9075, 8957>, 0,
    <9080, 8957, 8958>, 0,
    <9080, 8958, 8949>, 0,
    <9080, 8949, 9078>, 0,
    <9080, 9078, 9077>, 0,
    <9080, 9077, 9079>, 0,
    <9084, 9073, 9071>, 0,
    <9084, 9071, 9079>, 0,
    <9084, 9079, 9077>, 0,
    <9084, 9077, 9082>, 0,
    <9084, 9082, 9081>, 0,
    <9084, 9081, 9083>, 0,
    <9084, 9083, 9072>, 0,
    <9084, 9072, 9073>, 0,
    <9088, 9087, 9085>, 0,
    <9088, 9085, 9086>, 0,
    <9088, 9086, 8273>, 0,
    <9088, 8273, 8274>, 0,
    <9088, 8274, 8145>, 0,
    <9088, 8145, 9074>, 0,
    <9088, 9074, 9072>, 0,
    <9088, 9072, 9087>, 0,
    <9092, 9091, 9085>, 0,
    <9092, 9085, 9087>, 0,
    <9092, 9087, 9072>, 0,
    <9092, 9072, 9083>, 0,
    <9092, 9083, 9081>, 0,
    <9092, 9081, 9090>, 0,
    <9092, 9090, 9089>, 0,
    <9092, 9089, 9091>, 0,
    <9094, 9086, 9085>, 0,
    <9094, 9085, 9091>, 0,
    <9094, 9091, 9089>, 0,
    <9094, 9089, 9093>, 0,
    <9094, 9093, 8277>, 0,
    <9094, 8277, 8278>, 0,
    <9094, 8278, 8273>, 0,
    <9094, 8273, 9086>, 0,
    <9103, 9102, 9095>, 0,
    <9103, 9095, 9099>, 0,
    <9103, 9099, 9096>, 0,
    <9103, 9096, 9100>, 0,
    <9103, 9100, 9097>, 0,
    <9103, 9097, 9101>, 0,
    <9103, 9101, 9098>, 0,
    <9103, 9098, 9102>, 0,
    <9106, 9105, 9095>, 0,
    <9106, 9095, 9102>, 0,
    <9106, 9102, 9098>, 0,
    <9106, 9098, 9104>, 0,
    <9106, 9104, 8293>, 0,
    <9106, 8293, 8356>, 0,
    <9106, 8356, 8354>, 0,
    <9106, 8354, 9105>, 0,
    <9108, 9099, 9095>, 0,
    <9108, 9095, 9105>, 0,
    <9108, 9105, 8354>, 0,
    <9108, 8354, 8361>, 0,
    <9108, 8361, 8341>, 0,
    <9108, 8341, 9107>, 0,
    <9108, 9107, 9096>, 0,
    <9108, 9096, 9099>, 0,
    <9114, 9113, 9109>, 0,
    <9114, 9109, 9111>, 0,
    <9114, 9111, 9110>, 0,
    <9114, 9110, 9112>, 0,
    <9114, 9112, 8965>, 0,
    <9114, 8965, 8968>, 0,
    <9114, 8968, 8964>, 0,
    <9114, 8964, 9113>, 0,
    <9116, 9115, 9109>, 0,
    <9116, 9109, 9113>, 0,
    <9116, 9113, 8964>, 0,
    <9116, 8964, 8975>, 0,
    <9116, 8975, 8293>, 0,
    <9116, 8293, 9104>, 0,
    <9116, 9104, 9098>, 0,
    <9116, 9098, 9115>, 0,
    <9118, 9111, 9109>, 0,
    <9118, 9109, 9115>, 0,
    <9118, 9115, 9098>, 0,
    <9118, 9098, 9101>, 0,
    <9118, 9101, 9097>, 0,
    <9118, 9097, 9117>, 0,
    <9118, 9117, 9110>, 0,
    <9118, 9110, 9111>, 0,
    <9124, 9123, 9119>, 0,
    <9124, 9119, 9121>, 0,
    <9124, 9121, 9120>, 0,
    <9124, 9120, 9122>, 0,
    <9124, 9122, 8277>, 0,
    <9124, 8277, 9093>, 0,
    <9124, 9093, 9089>, 0,
    <9124, 9089, 9123>, 0,
    <9128, 9127, 9119>, 0,
    <9128, 9119, 9123>, 0,
    <9128, 9123, 9089>, 0,
    <9128, 9089, 9090>, 0,
    <9128, 9090, 9081>, 0,
    <9128, 9081, 9126>, 0,
    <9128, 9126, 9125>, 0,
    <9128, 9125, 9127>, 0,
    <9132, 9121, 9119>, 0,
    <9132, 9119, 9127>, 0,
    <9132, 9127, 9125>, 0,
    <9132, 9125, 9130>, 0,
    <9132, 9130, 9129>, 0,
    <9132, 9129, 9131>, 0,
    <9132, 9131, 9120>, 0,
    <9132, 9120, 9121>, 0,
    <9136, 9135, 9133>, 0,
    <9136, 9133, 9134>, 0,
    <9136, 9134, 8321>, 0,
    <9136, 8321, 8322>, 0,
    <9136, 8322, 8277>, 0,
    <9136, 8277, 9122>, 0,
    <9136, 9122, 9120>, 0,
    <9136, 9120, 9135>, 0,
    <9140, 9139, 9133>, 0,
    <9140, 9133, 9135>, 0,
    <9140, 9135, 9120>, 0,
    <9140, 9120, 9131>, 0,
    <9140, 9131, 9129>, 0,
    <9140, 9129, 9138>, 0,
    <9140, 9138, 9137>, 0,
    <9140, 9137, 9139>, 0,
    <9142, 9134, 9133>, 0,
    <9142, 9133, 9139>, 0,
    <9142, 9139, 9137>, 0,
    <9142, 9137, 9141>, 0,
    <9142, 9141, 8325>, 0,
    <9142, 8325, 8326>, 0,
    <9142, 8326, 8321>, 0,
    <9142, 8321, 9134>, 0,
    <9151, 9150, 9143>, 0,
    <9151, 9143, 9147>, 0,
    <9151, 9147, 9144>, 0,
    <9151, 9144, 9148>, 0,
    <9151, 9148, 9145>, 0,
    <9151, 9145, 9149>, 0,
    <9151, 9149, 9146>, 0,
    <9151, 9146, 9150>, 0,
    <9154, 9153, 9143>, 0,
    <9154, 9143, 9150>, 0,
    <9154, 9150, 9146>, 0,
    <9154, 9146, 9152>, 0,
    <9154, 9152, 8341>, 0,
    <9154, 8341, 8386>, 0,
    <9154, 8386, 8384>, 0,
    <9154, 8384, 9153>, 0,
    <9156, 9147, 9143>, 0,
    <9156, 9143, 9153>, 0,
    <9156, 9153, 8384>, 0,
    <9156, 8384, 8391>, 0,
    <9156, 8391, 1192>, 0,
    <9156, 1192, 9155>, 0,
    <9156, 9155, 9144>, 0,
    <9156, 9144, 9147>, 0,
    <9162, 9161, 9157>, 0,
    <9162, 9157, 9159>, 0,
    <9162, 9159, 9158>, 0,
    <9162, 9158, 9160>, 0,
    <9162, 9160, 9097>, 0,
    <9162, 9097, 9100>, 0,
    <9162, 9100, 9096>, 0,
    <9162, 9096, 9161>, 0,
    <9164, 9163, 9157>, 0,
    <9164, 9157, 9161>, 0,
    <9164, 9161, 9096>, 0,
    <9164, 9096, 9107>, 0,
    <9164, 9107, 8341>, 0,
    <9164, 8341, 9152>, 0,
    <9164, 9152, 9146>, 0,
    <9164, 9146, 9163>, 0,
    <9166, 9159, 9157>, 0,
    <9166, 9157, 9163>, 0,
    <9166, 9163, 9146>, 0,
    <9166, 9146, 9149>, 0,
    <9166, 9149, 9145>, 0,
    <9166, 9145, 9165>, 0,
    <9166, 9165, 9158>, 0,
    <9166, 9158, 9159>, 0,
    <9172, 9171, 9167>, 0,
    <9172, 9167, 9169>, 0,
    <9172, 9169, 9168>, 0,
    <9172, 9168, 9170>, 0,
    <9172, 9170, 8325>, 0,
    <9172, 8325, 9141>, 0,
    <9172, 9141, 9137>, 0,
    <9172, 9137, 9171>, 0,
    <9176, 9175, 9167>, 0,
    <9176, 9167, 9171>, 0,
    <9176, 9171, 9137>, 0,
    <9176, 9137, 9138>, 0,
    <9176, 9138, 9129>, 0,
    <9176, 9129, 9174>, 0,
    <9176, 9174, 9173>, 0,
    <9176, 9173, 9175>, 0,
    <9179, 9169, 9167>, 0,
    <9179, 9167, 9175>, 0,
    <9179, 9175, 9173>, 0,
    <9179, 9173, 9177>, 0,
    <9179, 9177, 1422>, 0,
    <9179, 1422, 9178>, 0,
    <9179, 9178, 9168>, 0,
    <9179, 9168, 9169>, 0,
    <9183, 9182, 9180>, 0,
    <9183, 9180, 9181>, 0,
    <9183, 9181, 8369>, 0,
    <9183, 8369, 8370>, 0,
    <9183, 8370, 8325>, 0,
    <9183, 8325, 9170>, 0,
    <9183, 9170, 9168>, 0,
    <9183, 9168, 9182>, 0,
    <9185, 9184, 9180>, 0,
    <9185, 9180, 9182>, 0,
    <9185, 9182, 9168>, 0,
    <9185, 9168, 9178>, 0,
    <9185, 9178, 1422>, 0,
    <9185, 1422, 1453>, 0,
    <9185, 1453, 1449>, 0,
    <9185, 1449, 9184>, 0,
    <9186, 9181, 9180>, 0,
    <9186, 9180, 9184>, 0,
    <9186, 9184, 1449>, 0,
    <9186, 1449, 1450>, 0,
    <9186, 1450, 1150>, 0,
    <9186, 1150, 8373>, 0,
    <9186, 8373, 8369>, 0,
    <9186, 8369, 9181>, 0,
    <9192, 9191, 9187>, 0,
    <9192, 9187, 9189>, 0,
    <9192, 9189, 9188>, 0,
    <9192, 9188, 9190>, 0,
    <9192, 9190, 9145>, 0,
    <9192, 9145, 9148>, 0,
    <9192, 9148, 9144>, 0,
    <9192, 9144, 9191>, 0,
    <9194, 9193, 9187>, 0,
    <9194, 9187, 9191>, 0,
    <9194, 9191, 9144>, 0,
    <9194, 9144, 9155>, 0,
    <9194, 9155, 1192>, 0,
    <9194, 1192, 1481>, 0,
    <9194, 1481, 1477>, 0,
    <9194, 1477, 9193>, 0,
    <9196, 9189, 9187>, 0,
    <9196, 9187, 9193>, 0,
    <9196, 9193, 1477>, 0,
    <9196, 1477, 1478>, 0,
    <9196, 1478, 1464>, 0,
    <9196, 1464, 9195>, 0,
    <9196, 9195, 9188>, 0,
    <9196, 9188, 9189>, 0,
    <9205, 9204, 9197>, 0,
    <9205, 9197, 9201>, 0,
    <9205, 9201, 9198>, 0,
    <9205, 9198, 9202>, 0,
    <9205, 9202, 9199>, 0,
    <9205, 9199, 9203>, 0,
    <9205, 9203, 9200>, 0,
    <9205, 9200, 9204>, 0,
    <9208, 9207, 9197>, 0,
    <9208, 9197, 9204>, 0,
    <9208, 9204, 9200>, 0,
    <9208, 9200, 9206>, 0,
    <9208, 9206, 1311>, 0,
    <9208, 1311, 8449>, 0,
    <9208, 8449, 8444>, 0,
    <9208, 8444, 9207>, 0,
    <9210, 9201, 9197>, 0,
    <9210, 9197, 9207>, 0,
    <9210, 9207, 8444>, 0,
    <9210, 8444, 8446>, 0,
    <9210, 8446, 8443>, 0,
    <9210, 8443, 9209>, 0,
    <9210, 9209, 9198>, 0,
    <9210, 9198, 9201>, 0,
    <9219, 9218, 9211>, 0,
    <9219, 9211, 9215>, 0,
    <9219, 9215, 9212>, 0,
    <9219, 9212, 9216>, 0,
    <9219, 9216, 9213>, 0,
    <9219, 9213, 9217>, 0,
    <9219, 9217, 9214>, 0,
    <9219, 9214, 9218>, 0,
    <9222, 9221, 9211>, 0,
    <9222, 9211, 9218>, 0,
    <9222, 9218, 9214>, 0,
    <9222, 9214, 9220>, 0,
    <9222, 9220, 8481>, 0,
    <9222, 8481, 8524>, 0,
    <9222, 8524, 8519>, 0,
    <9222, 8519, 9221>, 0,
    <9224, 9215, 9211>, 0,
    <9224, 9211, 9221>, 0,
    <9224, 9221, 8519>, 0,
    <9224, 8519, 8521>, 0,
    <9224, 8521, 1370>, 0,
    <9224, 1370, 9223>, 0,
    <9224, 9223, 9212>, 0,
    <9224, 9212, 9215>, 0,
    <9232, 9231, 9225>, 0,
    <9232, 9225, 9228>, 0,
    <9232, 9228, 9226>, 0,
    <9232, 9226, 9229>, 0,
    <9232, 9229, 1609>, 0,
    <9232, 1609, 9230>, 0,
    <9232, 9230, 9227>, 0,
    <9232, 9227, 9231>, 0,
    <9235, 9234, 9225>, 0,
    <9235, 9225, 9231>, 0,
    <9235, 9231, 9227>, 0,
    <9235, 9227, 9233>, 0,
    <9235, 9233, 1345>, 0,
    <9235, 1345, 8644>, 0,
    <9235, 8644, 8642>, 0,
    <9235, 8642, 9234>, 0,
    <9237, 9228, 9225>, 0,
    <9237, 9225, 9234>, 0,
    <9237, 9234, 8642>, 0,
    <9237, 8642, 8649>, 0,
    <9237, 8649, 8629>, 0,
    <9237, 8629, 9236>, 0,
    <9237, 9236, 9226>, 0,
    <9237, 9226, 9228>, 0,
    <9246, 9245, 9238>, 0,
    <9246, 9238, 9242>, 0,
    <9246, 9242, 9239>, 0,
    <9246, 9239, 9243>, 0,
    <9246, 9243, 9240>, 0,
    <9246, 9240, 9244>, 0,
    <9246, 9244, 9241>, 0,
    <9246, 9241, 9245>, 0,
    <9252, 9251, 9238>, 0,
    <9252, 9238, 9245>, 0,
    <9252, 9245, 9241>, 0,
    <9252, 9241, 9249>, 0,
    <9252, 9249, 9247>, 0,
    <9252, 9247, 9250>, 0,
    <9252, 9250, 9248>, 0,
    <9252, 9248, 9251>, 0,
    <9255, 9242, 9238>, 0,
    <9255, 9238, 9251>, 0,
    <9255, 9251, 9248>, 0,
    <9255, 9248, 9253>, 0,
    <9255, 9253, 1569>, 0,
    <9255, 1569, 9254>, 0,
    <9255, 9254, 9239>, 0,
    <9255, 9239, 9242>, 0,
    <9261, 9260, 9256>, 0,
    <9261, 9256, 9258>, 0,
    <9261, 9258, 9241>, 0,
    <9261, 9241, 9244>, 0,
    <9261, 9244, 9240>, 0,
    <9261, 9240, 9259>, 0,
    <9261, 9259, 9257>, 0,
    <9261, 9257, 9260>, 0,
    <9266, 9265, 9256>, 0,
    <9266, 9256, 9260>, 0,
    <9266, 9260, 9257>, 0,
    <9266, 9257, 9263>, 0,
    <9266, 9263, 9199>, 0,
    <9266, 9199, 9264>, 0,
    <9266, 9264, 9262>, 0,
    <9266, 9262, 9265>, 0,
    <9268, 9258, 9256>, 0,
    <9268, 9256, 9265>, 0,
    <9268, 9265, 9262>, 0,
    <9268, 9262, 9267>, 0,
    <9268, 9267, 9247>, 0,
    <9268, 9247, 9249>, 0,
    <9268, 9249, 9241>, 0,
    <9268, 9241, 9258>, 0,
    <9272, 9271, 9269>, 0,
    <9272, 9269, 9270>, 0,
    <9272, 9270, 9262>, 0,
    <9272, 9262, 9264>, 0,
    <9272, 9264, 9199>, 0,
    <9272, 9199, 9202>, 0,
    <9272, 9202, 9198>, 0,
    <9272, 9198, 9271>, 0,
    <9276, 9275, 9269>, 0,
    <9276, 9269, 9271>, 0,
    <9276, 9271, 9198>, 0,
    <9276, 9198, 9209>, 0,
    <9276, 9209, 8443>, 0,
    <9276, 8443, 9274>, 0,
    <9276, 9274, 9273>, 0,
    <9276, 9273, 9275>, 0,
    <9278, 9270, 9269>, 0,
    <9278, 9269, 9275>, 0,
    <9278, 9275, 9273>, 0,
    <9278, 9273, 9277>, 0,
    <9278, 9277, 9247>, 0,
    <9278, 9247, 9267>, 0,
    <9278, 9267, 9262>, 0,
    <9278, 9262, 9270>, 0,
    <9284, 9283, 9279>, 0,
    <9284, 9279, 9281>, 0,
    <9284, 9281, 9214>, 0,
    <9284, 9214, 9217>, 0,
    <9284, 9217, 9213>, 0,
    <9284, 9213, 9282>, 0,
    <9284, 9282, 9280>, 0,
    <9284, 9280, 9283>, 0,
    <9290, 9289, 9279>, 0,
    <9290, 9279, 9283>, 0,
    <9290, 9283, 9280>, 0,
    <9290, 9280, 9287>, 0,
    <9290, 9287, 9285>, 0,
    <9290, 9285, 9288>, 0,
    <9290, 9288, 9286>, 0,
    <9290, 9286, 9289>, 0,
    <9292, 9281, 9279>, 0,
    <9292, 9279, 9289>, 0,
    <9292, 9289, 9286>, 0,
    <9292, 9286, 9291>, 0,
    <9292, 9291, 8481>, 0,
    <9292, 8481, 9220>, 0,
    <9292, 9220, 9214>, 0,
    <9292, 9214, 9281>, 0,
    <9298, 9297, 9293>, 0,
    <9298, 9293, 9295>, 0,
    <9298, 9295, 9286>, 0,
    <9298, 9286, 9288>, 0,
    <9298, 9288, 9285>, 0,
    <9298, 9285, 9296>, 0,
    <9298, 9296, 9294>, 0,
    <9298, 9294, 9297>, 0,
    <9301, 9300, 9293>, 0,
    <9301, 9293, 9297>, 0,
    <9301, 9297, 9294>, 0,
    <9301, 9294, 9299>, 0,
    <9301, 9299, 8565>, 0,
    <9301, 8565, 8583>, 0,
    <9301, 8583, 8578>, 0,
    <9301, 8578, 9300>, 0,
    <9302, 9295, 9293>, 0,
    <9302, 9293, 9300>, 0,
    <9302, 9300, 8578>, 0,
    <9302, 8578, 8580>, 0,
    <9302, 8580, 8481>, 0,
    <9302, 8481, 9291>, 0,
    <9302, 9291, 9286>, 0,
    <9302, 9286, 9295>, 0,
    <9308, 9307, 9303>, 0,
    <9308, 9303, 9305>, 0,
    <9308, 9305, 9280>, 0,
    <9308, 9280, 9282>, 0,
    <9308, 9282, 9213>, 0,
    <9308, 9213, 9306>, 0,
    <9308, 9306, 9304>, 0,
    <9308, 9304, 9307>, 0,
    <9314, 9313, 9303>, 0,
    <9314, 9303, 9307>, 0,
    <9314, 9307, 9304>, 0,
    <9314, 9304, 9311>, 0,
    <9314, 9311, 9309>, 0,
    <9314, 9309, 9312>, 0,
    <9314, 9312, 9310>, 0,
    <9314, 9310, 9313>, 0,
    <9316, 9305, 9303>, 0,
    <9316, 9303, 9313>, 0,
    <9316, 9313, 9310>, 0,
    <9316, 9310, 9315>, 0,
    <9316, 9315, 9285>, 0,
    <9316, 9285, 9287>, 0,
    <9316, 9287, 9280>, 0,
    <9316, 9280, 9305>, 0,
    <9322, 9321, 9317>, 0,
    <9322, 9317, 9319>, 0,
    <9322, 9319, 9310>, 0,
    <9322, 9310, 9312>, 0,
    <9322, 9312, 9309>, 0,
    <9322, 9309, 9320>, 0,
    <9322, 9320, 9318>, 0,
    <9322, 9318, 9321>, 0,
    <9327, 9326, 9317>, 0,
    <9327, 9317, 9321>, 0,
    <9327, 9321, 9318>, 0,
    <9327, 9318, 9324>, 0,
    <9327, 9324, 1636>, 0,
    <9327, 1636, 9325>, 0,
    <9327, 9325, 9323>, 0,
    <9327, 9323, 9326>, 0,
    <9329, 9319, 9317>, 0,
    <9329, 9317, 9326>, 0,
    <9329, 9326, 9323>, 0,
    <9329, 9323, 9328>, 0,
    <9329, 9328, 9285>, 0,
    <9329, 9285, 9315>, 0,
    <9329, 9315, 9310>, 0,
    <9329, 9310, 9319>, 0,
    <9337, 9336, 9330>, 0,
    <9337, 9330, 9333>, 0,
    <9337, 9333, 9331>, 0,
    <9337, 9331, 9334>, 0,
    <9337, 9334, 1603>, 0,
    <9337, 1603, 9335>, 0,
    <9337, 9335, 9332>, 0,
    <9337, 9332, 9336>, 0,
    <9340, 9339, 9330>, 0,
    <9340, 9330, 9336>, 0,
    <9340, 9336, 9332>, 0,
    <9340, 9332, 9338>, 0,
    <9340, 9338, 1609>, 0,
    <9340, 1609, 9229>, 0,
    <9340, 9229, 9226>, 0,
    <9340, 9226, 9339>, 0,
    <9342, 9333, 9330>, 0,
    <9342, 9330, 9339>, 0,
    <9342, 9339, 9226>, 0,
    <9342, 9226, 9236>, 0,
    <9342, 9236, 8629>, 0,
    <9342, 8629, 9341>, 0,
    <9342, 9341, 9331>, 0,
    <9342, 9331, 9333>, 0,
    <9348, 9347, 9343>, 0,
    <9348, 9343, 9345>, 0,
    <9348, 9345, 9273>, 0,
    <9348, 9273, 9274>, 0,
    <9348, 9274, 8443>, 0,
    <9348, 8443, 9346>, 0,
    <9348, 9346, 9344>, 0,
    <9348, 9344, 9347>, 0,
    <9354, 9353, 9343>, 0,
    <9354, 9343, 9347>, 0,
    <9354, 9347, 9344>, 0,
    <9354, 9344, 9351>, 0,
    <9354, 9351, 9349>, 0,
    <9354, 9349, 9352>, 0,
    <9354, 9352, 9350>, 0,
    <9354, 9350, 9353>, 0,
    <9356, 9345, 9343>, 0,
    <9356, 9343, 9353>, 0,
    <9356, 9353, 9350>, 0,
    <9356, 9350, 9355>, 0,
    <9356, 9355, 9247>, 0,
    <9356, 9247, 9277>, 0,
    <9356, 9277, 9273>, 0,
    <9356, 9273, 9345>, 0,
    <9360, 9359, 9357>, 0,
    <9360, 9357, 9358>, 0,
    <9360, 9358, 9344>, 0,
    <9360, 9344, 9346>, 0,
    <9360, 9346, 8443>, 0,
    <9360, 8443, 8551>, 0,
    <9360, 8551, 8546>, 0,
    <9360, 8546, 9359>, 0,
    <9364, 9363, 9357>, 0,
    <9364, 9357, 9359>, 0,
    <9364, 9359, 8546>, 0,
    <9364, 8546, 8548>, 0,
    <9364, 8548, 8545>, 0,
    <9364, 8545, 9362>, 0,
    <9364, 9362, 9361>, 0,
    <9364, 9361, 9363>, 0,
    <9366, 9358, 9357>, 0,
    <9366, 9357, 9363>, 0,
    <9366, 9363, 9361>, 0,
    <9366, 9361, 9365>, 0,
    <9366, 9365, 9349>, 0,
    <9366, 9349, 9351>, 0,
    <9366, 9351, 9344>, 0,
    <9366, 9344, 9358>, 0,
    <9375, 9374, 9367>, 0,
    <9375, 9367, 9371>, 0,
    <9375, 9371, 9368>, 0,
    <9375, 9368, 9372>, 0,
    <9375, 9372, 9369>, 0,
    <9375, 9369, 9373>, 0,
    <9375, 9373, 9370>, 0,
    <9375, 9370, 9374>, 0,
    <9378, 9377, 9367>, 0,
    <9378, 9367, 9374>, 0,
    <9378, 9374, 9370>, 0,
    <9378, 9370, 9376>, 0,
    <9378, 9376, 8677>, 0,
    <9378, 8677, 8695>, 0,
    <9378, 8695, 8690>, 0,
    <9378, 8690, 9377>, 0,
    <9380, 9371, 9367>, 0,
    <9380, 9367, 9377>, 0,
    <9380, 9377, 8690>, 0,
    <9380, 8690, 8692>, 0,
    <9380, 8692, 8565>, 0,
    <9380, 8565, 9379>, 0,
    <9380, 9379, 9368>, 0,
    <9380, 9368, 9371>, 0,
    <9386, 9385, 9381>, 0,
    <9386, 9381, 9383>, 0,
    <9386, 9383, 9294>, 0,
    <9386, 9294, 9296>, 0,
    <9386, 9296, 9285>, 0,
    <9386, 9285, 9384>, 0,
    <9386, 9384, 9382>, 0,
    <9386, 9382, 9385>, 0,
    <9389, 9388, 9381>, 0,
    <9389, 9381, 9385>, 0,
    <9389, 9385, 9382>, 0,
    <9389, 9382, 9387>, 0,
    <9389, 9387, 9369>, 0,
    <9389, 9369, 9372>, 0,
    <9389, 9372, 9368>, 0,
    <9389, 9368, 9388>, 0,
    <9390, 9383, 9381>, 0,
    <9390, 9381, 9388>, 0,
    <9390, 9388, 9368>, 0,
    <9390, 9368, 9379>, 0,
    <9390, 9379, 8565>, 0,
    <9390, 8565, 9299>, 0,
    <9390, 9299, 9294>, 0,
    <9390, 9294, 9383>, 0,
    <9398, 9397, 9391>, 0,
    <9398, 9391, 9394>, 0,
    <9398, 9394, 9392>, 0,
    <9398, 9392, 9395>, 0,
    <9398, 9395, 1656>, 0,
    <9398, 1656, 9396>, 0,
    <9398, 9396, 9393>, 0,
    <9398, 9393, 9397>, 0,
    <9403, 9402, 9391>, 0,
    <9403, 9391, 9397>, 0,
    <9403, 9397, 9393>, 0,
    <9403, 9393, 9400>, 0,
    <9403, 9400, 1576>, 0,
    <9403, 1576, 9401>, 0,
    <9403, 9401, 9399>, 0,
    <9403, 9399, 9402>, 0,
    <9407, 9394, 9391>, 0,
    <9407, 9391, 9402>, 0,
    <9407, 9402, 9399>, 0,
    <9407, 9399, 9405>, 0,
    <9407, 9405, 9404>, 0,
    <9407, 9404, 9406>, 0,
    <9407, 9406, 9392>, 0,
    <9407, 9392, 9394>, 0,
    <9415, 9414, 9408>, 0,
    <9415, 9408, 9411>, 0,
    <9415, 9411, 9409>, 0,
    <9415, 9409, 9412>, 0,
    <9415, 9412, 1318>, 0,
    <9415, 1318, 9413>, 0,
    <9415, 9413, 9410>, 0,
    <9415, 9410, 9414>, 0,
    <9418, 9417, 9408>, 0,
    <9418, 9408, 9414>, 0,
    <9418, 9414, 9410>, 0,
    <9418, 9410, 9416>, 0,
    <9418, 9416, 1656>, 0,
    <9418, 1656, 9395>, 0,
    <9418, 9395, 9392>, 0,
    <9418, 9392, 9417>, 0,
    <9420, 9411, 9408>, 0,
    <9420, 9408, 9417>, 0,
    <9420, 9417, 9392>, 0,
    <9420, 9392, 9406>, 0,
    <9420, 9406, 9404>, 0,
    <9420, 9404, 9419>, 0,
    <9420, 9419, 9409>, 0,
    <9420, 9409, 9411>, 0,
    <9424, 9423, 9421>, 0,
    <9424, 9421, 9422>, 0,
    <9424, 9422, 8595>, 0,
    <9424, 8595, 8597>, 0,
    <9424, 8597, 1318>, 0,
    <9424, 1318, 9412>, 0,
    <9424, 9412, 9409>, 0,
    <9424, 9409, 9423>, 0,
    <9428, 9427, 9421>, 0,
    <9428, 9421, 9423>, 0,
    <9428, 9423, 9409>, 0,
    <9428, 9409, 9419>, 0,
    <9428, 9419, 9404>, 0,
    <9428, 9404, 9426>, 0,
    <9428, 9426, 9425>, 0,
    <9428, 9425, 9427>, 0,
    <9430, 9422, 9421>, 0,
    <9430, 9421, 9427>, 0,
    <9430, 9427, 9425>, 0,
    <9430, 9425, 9429>, 0,
    <9430, 9429, 8600>, 0,
    <9430, 8600, 8601>, 0,
    <9430, 8601, 8595>, 0,
    <9430, 8595, 9422>, 0,
    <9439, 9438, 9431>, 0,
    <9439, 9431, 9435>, 0,
    <9439, 9435, 9432>, 0,
    <9439, 9432, 9436>, 0,
    <9439, 9436, 9433>, 0,
    <9439, 9433, 9437>, 0,
    <9439, 9437, 9434>, 0,
    <9439, 9434, 9438>, 0,
    <9442, 9441, 9431>, 0,
    <9442, 9431, 9438>, 0,
    <9442, 9438, 9434>, 0,
    <9442, 9434, 9440>, 0,
    <9442, 9440, 8629>, 0,
    <9442, 8629, 8740>, 0,
    <9442, 8740, 8738>, 0,
    <9442, 8738, 9441>, 0,
    <9444, 9435, 9431>, 0,
    <9444, 9431, 9441>, 0,
    <9444, 9441, 8738>, 0,
    <9444, 8738, 8745>, 0,
    <9444, 8745, 8725>, 0,
    <9444, 8725, 9443>, 0,
    <9444, 9443, 9432>, 0,
    <9444, 9432, 9435>, 0,
    <9450, 9449, 9445>, 0,
    <9450, 9445, 9447>, 0,
    <9450, 9447, 9446>, 0,
    <9450, 9446, 9448>, 0,
    <9450, 9448, 1603>, 0,
    <9450, 1603, 9334>, 0,
    <9450, 9334, 9331>, 0,
    <9450, 9331, 9449>, 0,
    <9452, 9451, 9445>, 0,
    <9452, 9445, 9449>, 0,
    <9452, 9449, 9331>, 0,
    <9452, 9331, 9341>, 0,
    <9452, 9341, 8629>, 0,
    <9452, 8629, 9440>, 0,
    <9452, 9440, 9434>, 0,
    <9452, 9434, 9451>, 0,
    <9454, 9447, 9445>, 0,
    <9454, 9445, 9451>, 0,
    <9454, 9451, 9434>, 0,
    <9454, 9434, 9437>, 0,
    <9454, 9437, 9433>, 0,
    <9454, 9433, 9453>, 0,
    <9454, 9453, 9446>, 0,
    <9454, 9446, 9447>, 0,
    <9460, 9459, 9455>, 0,
    <9460, 9455, 9457>, 0,
    <9460, 9457, 9361>, 0,
    <9460, 9361, 9362>, 0,
    <9460, 9362, 8545>, 0,
    <9460, 8545, 9458>, 0,
    <9460, 9458, 9456>, 0,
    <9460, 9456, 9459>, 0,
    <9466, 9465, 9455>, 0,
    <9466, 9455, 9459>, 0,
    <9466, 9459, 9456>, 0,
    <9466, 9456, 9463>, 0,
    <9466, 9463, 9461>, 0,
    <9466, 9461, 9464>, 0,
    <9466, 9464, 9462>, 0,
    <9466, 9462, 9465>, 0,
    <9468, 9457, 9455>, 0,
    <9468, 9455, 9465>, 0,
    <9468, 9465, 9462>, 0,
    <9468, 9462, 9467>, 0,
    <9468, 9467, 9349>, 0,
    <9468, 9349, 9365>, 0,
    <9468, 9365, 9361>, 0,
    <9468, 9361, 9457>, 0,
    <9472, 9471, 9469>, 0,
    <9472, 9469, 9470>, 0,
    <9472, 9470, 9456>, 0,
    <9472, 9456, 9458>, 0,
    <9472, 9458, 8545>, 0,
    <9472, 8545, 8663>, 0,
    <9472, 8663, 8658>, 0,
    <9472, 8658, 9471>, 0,
    <9476, 9475, 9469>, 0,
    <9476, 9469, 9471>, 0,
    <9476, 9471, 8658>, 0,
    <9476, 8658, 8660>, 0,
    <9476, 8660, 8657>, 0,
    <9476, 8657, 9474>, 0,
    <9476, 9474, 9473>, 0,
    <9476, 9473, 9475>, 0,
    <9478, 9470, 9469>, 0,
    <9478, 9469, 9475>, 0,
    <9478, 9475, 9473>, 0,
    <9478, 9473, 9477>, 0,
    <9478, 9477, 9461>, 0,
    <9478, 9461, 9463>, 0,
    <9478, 9463, 9456>, 0,
    <9478, 9456, 9470>, 0,
    <9487, 9486, 9479>, 0,
    <9487, 9479, 9483>, 0,
    <9487, 9483, 9480>, 0,
    <9487, 9480, 9484>, 0,
    <9487, 9484, 9481>, 0,
    <9487, 9481, 9485>, 0,
    <9487, 9485, 9482>, 0,
    <9487, 9482, 9486>, 0,
    <9490, 9489, 9479>, 0,
    <9490, 9479, 9486>, 0,
    <9490, 9486, 9482>, 0,
    <9490, 9482, 9488>, 0,
    <9490, 9488, 8773>, 0,
    <9490, 8773, 8791>, 0,
    <9490, 8791, 8786>, 0,
    <9490, 8786, 9489>, 0,
    <9492, 9483, 9479>, 0,
    <9492, 9479, 9489>, 0,
    <9492, 9489, 8786>, 0,
    <9492, 8786, 8788>, 0,
    <9492, 8788, 8677>, 0,
    <9492, 8677, 9491>, 0,
    <9492, 9491, 9480>, 0,
    <9492, 9480, 9483>, 0,
    <9498, 9497, 9493>, 0,
    <9498, 9493, 9495>, 0,
    <9498, 9495, 9370>, 0,
    <9498, 9370, 9373>, 0,
    <9498, 9373, 9369>, 0,
    <9498, 9369, 9496>, 0,
    <9498, 9496, 9494>, 0,
    <9498, 9494, 9497>, 0,
    <9501, 9500, 9493>, 0,
    <9501, 9493, 9497>, 0,
    <9501, 9497, 9494>, 0,
    <9501, 9494, 9499>, 0,
    <9501, 9499, 9481>, 0,
    <9501, 9481, 9484>, 0,
    <9501, 9484, 9480>, 0,
    <9501, 9480, 9500>, 0,
    <9502, 9495, 9493>, 0,
    <9502, 9493, 9500>, 0,
    <9502, 9500, 9480>, 0,
    <9502, 9480, 9491>, 0,
    <9502, 9491, 8677>, 0,
    <9502, 8677, 9376>, 0,
    <9502, 9376, 9370>, 0,
    <9502, 9370, 9495>, 0,
    <9508, 9507, 9503>, 0,
    <9508, 9503, 9505>, 0,
    <9508, 9505, 9504>, 0,
    <9508, 9504, 9506>, 0,
    <9508, 9506, 8600>, 0,
    <9508, 8600, 9429>, 0,
    <9508, 9429, 9425>, 0,
    <9508, 9425, 9507>, 0,
    <9512, 9511, 9503>, 0,
    <9512, 9503, 9507>, 0,
    <9512, 9507, 9425>, 0,
    <9512, 9425, 9426>, 0,
    <9512, 9426, 9404>, 0,
    <9512, 9404, 9510>, 0,
    <9512, 9510, 9509>, 0,
    <9512, 9509, 9511>, 0,
    <9516, 9505, 9503>, 0,
    <9516, 9503, 9511>, 0,
    <9516, 9511, 9509>, 0,
    <9516, 9509, 9514>, 0,
    <9516, 9514, 9513>, 0,
    <9516, 9513, 9515>, 0,
    <9516, 9515, 9504>, 0,
    <9516, 9504, 9505>, 0,
    <9520, 9519, 9517>, 0,
    <9520, 9517, 9518>, 0,
    <9520, 9518, 8705>, 0,
    <9520, 8705, 8706>, 0,
    <9520, 8706, 8600>, 0,
    <9520, 8600, 9506>, 0,
    <9520, 9506, 9504>, 0,
    <9520, 9504, 9519>, 0,
    <9524, 9523, 9517>, 0,
    <9524, 9517, 9519>, 0,
    <9524, 9519, 9504>, 0,
    <9524, 9504, 9515>, 0,
    <9524, 9515, 9513>, 0,
    <9524, 9513, 9522>, 0,
    <9524, 9522, 9521>, 0,
    <9524, 9521, 9523>, 0,
    <9526, 9518, 9517>, 0,
    <9526, 9517, 9523>, 0,
    <9526, 9523, 9521>, 0,
    <9526, 9521, 9525>, 0,
    <9526, 9525, 8709>, 0,
    <9526, 8709, 8710>, 0,
    <9526, 8710, 8705>, 0,
    <9526, 8705, 9518>, 0,
    <9535, 9534, 9527>, 0,
    <9535, 9527, 9531>, 0,
    <9535, 9531, 9528>, 0,
    <9535, 9528, 9532>, 0,
    <9535, 9532, 9529>, 0,
    <9535, 9529, 9533>, 0,
    <9535, 9533, 9530>, 0,
    <9535, 9530, 9534>, 0,
    <9538, 9537, 9527>, 0,
    <9538, 9527, 9534>, 0,
    <9538, 9534, 9530>, 0,
    <9538, 9530, 9536>, 0,
    <9538, 9536, 8725>, 0,
    <9538, 8725, 8836>, 0,
    <9538, 8836, 8834>, 0,
    <9538, 8834, 9537>, 0,
    <9540, 9531, 9527>, 0,
    <9540, 9527, 9537>, 0,
    <9540, 9537, 8834>, 0,
    <9540, 8834, 8841>, 0,
    <9540, 8841, 8821>, 0,
    <9540, 8821, 9539>, 0,
    <9540, 9539, 9528>, 0,
    <9540, 9528, 9531>, 0,
    <9546, 9545, 9541>, 0,
    <9546, 9541, 9543>, 0,
    <9546, 9543, 9542>, 0,
    <9546, 9542, 9544>, 0,
    <9546, 9544, 9433>, 0,
    <9546, 9433, 9436>, 0,
    <9546, 9436, 9432>, 0,
    <9546, 9432, 9545>, 0,
    <9548, 9547, 9541>, 0,
    <9548, 9541, 9545>, 0,
    <9548, 9545, 9432>, 0,
    <9548, 9432, 9443>, 0,
    <9548, 9443, 8725>, 0,
    <9548, 8725, 9536>, 0,
    <9548, 9536, 9530>, 0,
    <9548, 9530, 9547>, 0,
    <9550, 9543, 9541>, 0,
    <9550, 9541, 9547>, 0,
    <9550, 9547, 9530>, 0,
    <9550, 9530, 9533>, 0,
    <9550, 9533, 9529>, 0,
    <9550, 9529, 9549>, 0,
    <9550, 9549, 9542>, 0,
    <9550, 9542, 9543>, 0,
    <9556, 9555, 9551>, 0,
    <9556, 9551, 9553>, 0,
    <9556, 9553, 9473>, 0,
    <9556, 9473, 9474>, 0,
    <9556, 9474, 8657>, 0,
    <9556, 8657, 9554>, 0,
    <9556, 9554, 9552>, 0,
    <9556, 9552, 9555>, 0,
    <9562, 9561, 9551>, 0,
    <9562, 9551, 9555>, 0,
    <9562, 9555, 9552>, 0,
    <9562, 9552, 9559>, 0,
    <9562, 9559, 9557>, 0,
    <9562, 9557, 9560>, 0,
    <9562, 9560, 9558>, 0,
    <9562, 9558, 9561>, 0,
    <9564, 9553, 9551>, 0,
    <9564, 9551, 9561>, 0,
    <9564, 9561, 9558>, 0,
    <9564, 9558, 9563>, 0,
    <9564, 9563, 9461>, 0,
    <9564, 9461, 9477>, 0,
    <9564, 9477, 9473>, 0,
    <9564, 9473, 9553>, 0,
    <9568, 9567, 9565>, 0,
    <9568, 9565, 9566>, 0,
    <9568, 9566, 9552>, 0,
    <9568, 9552, 9554>, 0,
    <9568, 9554, 8657>, 0,
    <9568, 8657, 8759>, 0,
    <9568, 8759, 8754>, 0,
    <9568, 8754, 9567>, 0,
    <9572, 9571, 9565>, 0,
    <9572, 9565, 9567>, 0,
    <9572, 9567, 8754>, 0,
    <9572, 8754, 8756>, 0,
    <9572, 8756, 8753>, 0,
    <9572, 8753, 9570>, 0,
    <9572, 9570, 9569>, 0,
    <9572, 9569, 9571>, 0,
    <9574, 9566, 9565>, 0,
    <9574, 9565, 9571>, 0,
    <9574, 9571, 9569>, 0,
    <9574, 9569, 9573>, 0,
    <9574, 9573, 9557>, 0,
    <9574, 9557, 9559>, 0,
    <9574, 9559, 9552>, 0,
    <9574, 9552, 9566>, 0,
    <9583, 9582, 9575>, 0,
    <9583, 9575, 9579>, 0,
    <9583, 9579, 9576>, 0,
    <9583, 9576, 9580>, 0,
    <9583, 9580, 9577>, 0,
    <9583, 9577, 9581>, 0,
    <9583, 9581, 9578>, 0,
    <9583, 9578, 9582>, 0,
    <9586, 9585, 9575>, 0,
    <9586, 9575, 9582>, 0,
    <9586, 9582, 9578>, 0,
    <9586, 9578, 9584>, 0,
    <9586, 9584, 8869>, 0,
    <9586, 8869, 8887>, 0,
    <9586, 8887, 8882>, 0,
    <9586, 8882, 9585>, 0,
    <9588, 9579, 9575>, 0,
    <9588, 9575, 9585>, 0,
    <9588, 9585, 8882>, 0,
    <9588, 8882, 8884>, 0,
    <9588, 8884, 8773>, 0,
    <9588, 8773, 9587>, 0,
    <9588, 9587, 9576>, 0,
    <9588, 9576, 9579>, 0,
    <9594, 9593, 9589>, 0,
    <9594, 9589, 9591>, 0,
    <9594, 9591, 9482>, 0,
    <9594, 9482, 9485>, 0,
    <9594, 9485, 9481>, 0,
    <9594, 9481, 9592>, 0,
    <9594, 9592, 9590>, 0,
    <9594, 9590, 9593>, 0,
    <9597, 9596, 9589>, 0,
    <9597, 9589, 9593>, 0,
    <9597, 9593, 9590>, 0,
    <9597, 9590, 9595>, 0,
    <9597, 9595, 9577>, 0,
    <9597, 9577, 9580>, 0,
    <9597, 9580, 9576>, 0,
    <9597, 9576, 9596>, 0,
    <9598, 9591, 9589>, 0,
    <9598, 9589, 9596>, 0,
    <9598, 9596, 9576>, 0,
    <9598, 9576, 9587>, 0,
    <9598, 9587, 8773>, 0,
    <9598, 8773, 9488>, 0,
    <9598, 9488, 9482>, 0,
    <9598, 9482, 9591>, 0,
    <9604, 9603, 9599>, 0,
    <9604, 9599, 9601>, 0,
    <9604, 9601, 9600>, 0,
    <9604, 9600, 9602>, 0,
    <9604, 9602, 8709>, 0,
    <9604, 8709, 9525>, 0,
    <9604, 9525, 9521>, 0,
    <9604, 9521, 9603>, 0,
    <9608, 9607, 9599>, 0,
    <9608, 9599, 9603>, 0,
    <9608, 9603, 9521>, 0,
    <9608, 9521, 9522>, 0,
    <9608, 9522, 9513>, 0,
    <9608, 9513, 9606>, 0,
    <9608, 9606, 9605>, 0,
    <9608, 9605, 9607>, 0,
    <9612, 9601, 9599>, 0,
    <9612, 9599, 9607>, 0,
    <9612, 9607, 9605>, 0,
    <9612, 9605, 9610>, 0,
    <9612, 9610, 9609>, 0,
    <9612, 9609, 9611>, 0,
    <9612, 9611, 9600>, 0,
    <9612, 9600, 9601>, 0,
    <9616, 9615, 9613>, 0,
    <9616, 9613, 9614>, 0,
    <9616, 9614, 8801>, 0,
    <9616, 8801, 8802>, 0,
    <9616, 8802, 8709>, 0,
    <9616, 8709, 9602>, 0,
    <9616, 9602, 9600>, 0,
    <9616, 9600, 9615>, 0,
    <9620, 9619, 9613>, 0,
    <9620, 9613, 9615>, 0,
    <9620, 9615, 9600>, 0,
    <9620, 9600, 9611>, 0,
    <9620, 9611, 9609>, 0,
    <9620, 9609, 9618>, 0,
    <9620, 9618, 9617>, 0,
    <9620, 9617, 9619>, 0,
    <9622, 9614, 9613>, 0,
    <9622, 9613, 9619>, 0,
    <9622, 9619, 9617>, 0,
    <9622, 9617, 9621>, 0,
    <9622, 9621, 8805>, 0,
    <9622, 8805, 8806>, 0,
    <9622, 8806, 8801>, 0,
    <9622, 8801, 9614>, 0,
    <9631, 9630, 9623>, 0,
    <9631, 9623, 9627>, 0,
    <9631, 9627, 9624>, 0,
    <9631, 9624, 9628>, 0,
    <9631, 9628, 9625>, 0,
    <9631, 9625, 9629>, 0,
    <9631, 9629, 9626>, 0,
    <9631, 9626, 9630>, 0,
    <9634, 9633, 9623>, 0,
    <9634, 9623, 9630>, 0,
    <9634, 9630, 9626>, 0,
    <9634, 9626, 9632>, 0,
    <9634, 9632, 8821>, 0,
    <9634, 8821, 8980>, 0,
    <9634, 8980, 8978>, 0,
    <9634, 8978, 9633>, 0,
    <9636, 9627, 9623>, 0,
    <9636, 9623, 9633>, 0,
    <9636, 9633, 8978>, 0,
    <9636, 8978, 8985>, 0,
    <9636, 8985, 8965>, 0,
    <9636, 8965, 9635>, 0,
    <9636, 9635, 9624>, 0,
    <9636, 9624, 9627>, 0,
    <9642, 9641, 9637>, 0,
    <9642, 9637, 9639>, 0,
    <9642, 9639, 9638>, 0,
    <9642, 9638, 9640>, 0,
    <9642, 9640, 9529>, 0,
    <9642, 9529, 9532>, 0,
    <9642, 9532, 9528>, 0,
    <9642, 9528, 9641>, 0,
    <9644, 9643, 9637>, 0,
    <9644, 9637, 9641>, 0,
    <9644, 9641, 9528>, 0,
    <9644, 9528, 9539>, 0,
    <9644, 9539, 8821>, 0,
    <9644, 8821, 9632>, 0,
    <9644, 9632, 9626>, 0,
    <9644, 9626, 9643>, 0,
    <9646, 9639, 9637>, 0,
    <9646, 9637, 9643>, 0,
    <9646, 9643, 9626>, 0,
    <9646, 9626, 9629>, 0,
    <9646, 9629, 9625>, 0,
    <9646, 9625, 9645>, 0,
    <9646, 9645, 9638>, 0,
    <9646, 9638, 9639>, 0,
    <9652, 9651, 9647>, 0,
    <9652, 9647, 9649>, 0,
    <9652, 9649, 9569>, 0,
    <9652, 9569, 9570>, 0,
    <9652, 9570, 8753>, 0,
    <9652, 8753, 9650>, 0,
    <9652, 9650, 9648>, 0,
    <9652, 9648, 9651>, 0,
    <9658, 9657, 9647>, 0,
    <9658, 9647, 9651>, 0,
    <9658, 9651, 9648>, 0,
    <9658, 9648, 9655>, 0,
    <9658, 9655, 9653>, 0,
    <9658, 9653, 9656>, 0,
    <9658, 9656, 9654>, 0,
    <9658, 9654, 9657>, 0,
    <9660, 9649, 9647>, 0,
    <9660, 9647, 9657>, 0,
    <9660, 9657, 9654>, 0,
    <9660, 9654, 9659>, 0,
    <9660, 9659, 9557>, 0,
    <9660, 9557, 9573>, 0,
    <9660, 9573, 9569>, 0,
    <9660, 9569, 9649>, 0,
    <9664, 9663, 9661>, 0,
    <9664, 9661, 9662>, 0,
    <9664, 9662, 9648>, 0,
    <9664, 9648, 9650>, 0,
    <9664, 9650, 8753>, 0,
    <9664, 8753, 8855>, 0,
    <9664, 8855, 8850>, 0,
    <9664, 8850, 9663>, 0,
    <9668, 9667, 9661>, 0,
    <9668, 9661, 9663>, 0,
    <9668, 9663, 8850>, 0,
    <9668, 8850, 8852>, 0,
    <9668, 8852, 8849>, 0,
    <9668, 8849, 9666>, 0,
    <9668, 9666, 9665>, 0,
    <9668, 9665, 9667>, 0,
    <9670, 9662, 9661>, 0,
    <9670, 9661, 9667>, 0,
    <9670, 9667, 9665>, 0,
    <9670, 9665, 9669>, 0,
    <9670, 9669, 9653>, 0,
    <9670, 9653, 9655>, 0,
    <9670, 9655, 9648>, 0,
    <9670, 9648, 9662>, 0,
    <9679, 9678, 9671>, 0,
    <9679, 9671, 9675>, 0,
    <9679, 9675, 9672>, 0,
    <9679, 9672, 9676>, 0,
    <9679, 9676, 9673>, 0,
    <9679, 9673, 9677>, 0,
    <9679, 9677, 9674>, 0,
    <9679, 9674, 9678>, 0,
    <9682, 9681, 9671>, 0,
    <9682, 9671, 9678>, 0,
    <9682, 9678, 9674>, 0,
    <9682, 9674, 9680>, 0,
    <9682, 9680, 8917>, 0,
    <9682, 8917, 8935>, 0,
    <9682, 8935, 8930>, 0,
    <9682, 8930, 9681>, 0,
    <9684, 9675, 9671>, 0,
    <9684, 9671, 9681>, 0,
    <9684, 9681, 8930>, 0,
    <9684, 8930, 8932>, 0,
    <9684, 8932, 8869>, 0,
    <9684, 8869, 9683>, 0,
    <9684, 9683, 9672>, 0,
    <9684, 9672, 9675>, 0,
    <9690, 9689, 9685>, 0,
    <9690, 9685, 9687>, 0,
    <9690, 9687, 9578>, 0,
    <9690, 9578, 9581>, 0,
    <9690, 9581, 9577>, 0,
    <9690, 9577, 9688>, 0,
    <9690, 9688, 9686>, 0,
    <9690, 9686, 9689>, 0,
    <9693, 9692, 9685>, 0,
    <9693, 9685, 9689>, 0,
    <9693, 9689, 9686>, 0,
    <9693, 9686, 9691>, 0,
    <9693, 9691, 9673>, 0,
    <9693, 9673, 9676>, 0,
    <9693, 9676, 9672>, 0,
    <9693, 9672, 9692>, 0,
    <9694, 9687, 9685>, 0,
    <9694, 9685, 9692>, 0,
    <9694, 9692, 9672>, 0,
    <9694, 9672, 9683>, 0,
    <9694, 9683, 8869>, 0,
    <9694, 8869, 9584>, 0,
    <9694, 9584, 9578>, 0,
    <9694, 9578, 9687>, 0,
    <9700, 9699, 9695>, 0,
    <9700, 9695, 9697>, 0,
    <9700, 9697, 9665>, 0,
    <9700, 9665, 9666>, 0,
    <9700, 9666, 8849>, 0,
    <9700, 8849, 9698>, 0,
    <9700, 9698, 9696>, 0,
    <9700, 9696, 9699>, 0,
    <9706, 9705, 9695>, 0,
    <9706, 9695, 9699>, 0,
    <9706, 9699, 9696>, 0,
    <9706, 9696, 9703>, 0,
    <9706, 9703, 9701>, 0,
    <9706, 9701, 9704>, 0,
    <9706, 9704, 9702>, 0,
    <9706, 9702, 9705>, 0,
    <9708, 9697, 9695>, 0,
    <9708, 9695, 9705>, 0,
    <9708, 9705, 9702>, 0,
    <9708, 9702, 9707>, 0,
    <9708, 9707, 9653>, 0,
    <9708, 9653, 9669>, 0,
    <9708, 9669, 9665>, 0,
    <9708, 9665, 9697>, 0,
    <9712, 9711, 9709>, 0,
    <9712, 9709, 9710>, 0,
    <9712, 9710, 9696>, 0,
    <9712, 9696, 9698>, 0,
    <9712, 9698, 8849>, 0,
    <9712, 8849, 8903>, 0,
    <9712, 8903, 8898>, 0,
    <9712, 8898, 9711>, 0,
    <9716, 9715, 9709>, 0,
    <9716, 9709, 9711>, 0,
    <9716, 9711, 8898>, 0,
    <9716, 8898, 8900>, 0,
    <9716, 8900, 8897>, 0,
    <9716, 8897, 9714>, 0,
    <9716, 9714, 9713>, 0,
    <9716, 9713, 9715>, 0,
    <9718, 9710, 9709>, 0,
    <9718, 9709, 9715>, 0,
    <9718, 9715, 9713>, 0,
    <9718, 9713, 9717>, 0,
    <9718, 9717, 9701>, 0,
    <9718, 9701, 9703>, 0,
    <9718, 9703, 9696>, 0,
    <9718, 9696, 9710>, 0,
    <9727, 9726, 9719>, 0,
    <9727, 9719, 9723>, 0,
    <9727, 9723, 9720>, 0,
    <9727, 9720, 9724>, 0,
    <9727, 9724, 9721>, 0,
    <9727, 9721, 9725>, 0,
    <9727, 9725, 9722>, 0,
    <9727, 9722, 9726>, 0,
    <9730, 9729, 9719>, 0,
    <9730, 9719, 9726>, 0,
    <9730, 9726, 9722>, 0,
    <9730, 9722, 9728>, 0,
    <9730, 9728, 9013>, 0,
    <9730, 9013, 9031>, 0,
    <9730, 9031, 9026>, 0,
    <9730, 9026, 9729>, 0,
    <9732, 9723, 9719>, 0,
    <9732, 9719, 9729>, 0,
    <9732, 9729, 9026>, 0,
    <9732, 9026, 9028>, 0,
    <9732, 9028, 8917>, 0,
    <9732, 8917, 9731>, 0,
    <9732, 9731, 9720>, 0,
    <9732, 9720, 9723>, 0,
    <9738, 9737, 9733>, 0,
    <9738, 9733, 9735>, 0,
    <9738, 9735, 9674>, 0,
    <9738, 9674, 9677>, 0,
    <9738, 9677, 9673>, 0,
    <9738, 9673, 9736>, 0,
    <9738, 9736, 9734>, 0,
    <9738, 9734, 9737>, 0,
    <9741, 9740, 9733>, 0,
    <9741, 9733, 9737>, 0,
    <9741, 9737, 9734>, 0,
    <9741, 9734, 9739>, 0,
    <9741, 9739, 9721>, 0,
    <9741, 9721, 9724>, 0,
    <9741, 9724, 9720>, 0,
    <9741, 9720, 9740>, 0,
    <9742, 9735, 9733>, 0,
    <9742, 9733, 9740>, 0,
    <9742, 9740, 9720>, 0,
    <9742, 9720, 9731>, 0,
    <9742, 9731, 8917>, 0,
    <9742, 8917, 9680>, 0,
    <9742, 9680, 9674>, 0,
    <9742, 9674, 9735>, 0,
    <9748, 9747, 9743>, 0,
    <9748, 9743, 9745>, 0,
    <9748, 9745, 9744>, 0,
    <9748, 9744, 9746>, 0,
    <9748, 9746, 8805>, 0,
    <9748, 8805, 9621>, 0,
    <9748, 9621, 9617>, 0,
    <9748, 9617, 9747>, 0,
    <9752, 9751, 9743>, 0,
    <9752, 9743, 9747>, 0,
    <9752, 9747, 9617>, 0,
    <9752, 9617, 9618>, 0,
    <9752, 9618, 9609>, 0,
    <9752, 9609, 9750>, 0,
    <9752, 9750, 9749>, 0,
    <9752, 9749, 9751>, 0,
    <9756, 9745, 9743>, 0,
    <9756, 9743, 9751>, 0,
    <9756, 9751, 9749>, 0,
    <9756, 9749, 9754>, 0,
    <9756, 9754, 9753>, 0,
    <9756, 9753, 9755>, 0,
    <9756, 9755, 9744>, 0,
    <9756, 9744, 9745>, 0,
    <9760, 9759, 9757>, 0,
    <9760, 9757, 9758>, 0,
    <9760, 9758, 8945>, 0,
    <9760, 8945, 8946>, 0,
    <9760, 8946, 8805>, 0,
    <9760, 8805, 9746>, 0,
    <9760, 9746, 9744>, 0,
    <9760, 9744, 9759>, 0,
    <9764, 9763, 9757>, 0,
    <9764, 9757, 9759>, 0,
    <9764, 9759, 9744>, 0,
    <9764, 9744, 9755>, 0,
    <9764, 9755, 9753>, 0,
    <9764, 9753, 9762>, 0,
    <9764, 9762, 9761>, 0,
    <9764, 9761, 9763>, 0,
    <9766, 9758, 9757>, 0,
    <9766, 9757, 9763>, 0,
    <9766, 9763, 9761>, 0,
    <9766, 9761, 9765>, 0,
    <9766, 9765, 8949>, 0,
    <9766, 8949, 8950>, 0,
    <9766, 8950, 8945>, 0,
    <9766, 8945, 9758>, 0,
    <9775, 9774, 9767>, 0,
    <9775, 9767, 9771>, 0,
    <9775, 9771, 9768>, 0,
    <9775, 9768, 9772>, 0,
    <9775, 9772, 9769>, 0,
    <9775, 9769, 9773>, 0,
    <9775, 9773, 9770>, 0,
    <9775, 9770, 9774>, 0,
    <9778, 9777, 9767>, 0,
    <9778, 9767, 9774>, 0,
    <9778, 9774, 9770>, 0,
    <9778, 9770, 9776>, 0,
    <9778, 9776, 8965>, 0,
    <9778, 8965, 9112>, 0,
    <9778, 9112, 9110>, 0,
    <9778, 9110, 9777>, 0,
    <9780, 9771, 9767>, 0,
    <9780, 9767, 9777>, 0,
    <9780, 9777, 9110>, 0,
    <9780, 9110, 9117>, 0,
    <9780, 9117, 9097>, 0,
    <9780, 9097, 9779>, 0,
    <9780, 9779, 9768>, 0,
    <9780, 9768, 9771>, 0,
    <9786, 9785, 9781>, 0,
    <9786, 9781, 9783>, 0,
    <9786, 9783, 9782>, 0,
    <9786, 9782, 9784>, 0,
    <9786, 9784, 9625>, 0,
    <9786, 9625, 9628>, 0,
    <9786, 9628, 9624>, 0,
    <9786, 9624, 9785>, 0,
    <9788, 9787, 9781>, 0,
    <9788, 9781, 9785>, 0,
    <9788, 9785, 9624>, 0,
    <9788, 9624, 9635>, 0,
    <9788, 9635, 8965>, 0,
    <9788, 8965, 9776>, 0,
    <9788, 9776, 9770>, 0,
    <9788, 9770, 9787>, 0,
    <9790, 9783, 9781>, 0,
    <9790, 9781, 9787>, 0,
    <9790, 9787, 9770>, 0,
    <9790, 9770, 9773>, 0,
    <9790, 9773, 9769>, 0,
    <9790, 9769, 9789>, 0,
    <9790, 9789, 9782>, 0,
    <9790, 9782, 9783>, 0,
    <9796, 9795, 9791>, 0,
    <9796, 9791, 9793>, 0,
    <9796, 9793, 9713>, 0,
    <9796, 9713, 9714>, 0,
    <9796, 9714, 8897>, 0,
    <9796, 8897, 9794>, 0,
    <9796, 9794, 9792>, 0,
    <9796, 9792, 9795>, 0,
    <9802, 9801, 9791>, 0,
    <9802, 9791, 9795>, 0,
    <9802, 9795, 9792>, 0,
    <9802, 9792, 9799>, 0,
    <9802, 9799, 9797>, 0,
    <9802, 9797, 9800>, 0,
    <9802, 9800, 9798>, 0,
    <9802, 9798, 9801>, 0,
    <9804, 9793, 9791>, 0,
    <9804, 9791, 9801>, 0,
    <9804, 9801, 9798>, 0,
    <9804, 9798, 9803>, 0,
    <9804, 9803, 9701>, 0,
    <9804, 9701, 9717>, 0,
    <9804, 9717, 9713>, 0,
    <9804, 9713, 9793>, 0,
    <9808, 9807, 9805>, 0,
    <9808, 9805, 9806>, 0,
    <9808, 9806, 9792>, 0,
    <9808, 9792, 9794>, 0,
    <9808, 9794, 8897>, 0,
    <9808, 8897, 8999>, 0,
    <9808, 8999, 8994>, 0,
    <9808, 8994, 9807>, 0,
    <9812, 9811, 9805>, 0,
    <9812, 9805, 9807>, 0,
    <9812, 9807, 8994>, 0,
    <9812, 8994, 8996>, 0,
    <9812, 8996, 8993>, 0,
    <9812, 8993, 9810>, 0,
    <9812, 9810, 9809>, 0,
    <9812, 9809, 9811>, 0,
    <9814, 9806, 9805>, 0,
    <9814, 9805, 9811>, 0,
    <9814, 9811, 9809>, 0,
    <9814, 9809, 9813>, 0,
    <9814, 9813, 9797>, 0,
    <9814, 9797, 9799>, 0,
    <9814, 9799, 9792>, 0,
    <9814, 9792, 9806>, 0,
    <9823, 9822, 9815>, 0,
    <9823, 9815, 9819>, 0,
    <9823, 9819, 9816>, 0,
    <9823, 9816, 9820>, 0,
    <9823, 9820, 9817>, 0,
    <9823, 9817, 9821>, 0,
    <9823, 9821, 9818>, 0,
    <9823, 9818, 9822>, 0,
    <9826, 9825, 9815>, 0,
    <9826, 9815, 9822>, 0,
    <9826, 9822, 9818>, 0,
    <9826, 9818, 9824>, 0,
    <9826, 9824, 1485>, 0,
    <9826, 1485, 9065>, 0,
    <9826, 9065, 9059>, 0,
    <9826, 9059, 9825>, 0,
    <9828, 9819, 9815>, 0,
    <9828, 9815, 9825>, 0,
    <9828, 9825, 9059>, 0,
    <9828, 9059, 9061>, 0,
    <9828, 9061, 9013>, 0,
    <9828, 9013, 9827>, 0,
    <9828, 9827, 9816>, 0,
    <9828, 9816, 9819>, 0,
    <9834, 9833, 9829>, 0,
    <9834, 9829, 9831>, 0,
    <9834, 9831, 9722>, 0,
    <9834, 9722, 9725>, 0,
    <9834, 9725, 9721>, 0,
    <9834, 9721, 9832>, 0,
    <9834, 9832, 9830>, 0,
    <9834, 9830, 9833>, 0,
    <9837, 9836, 9829>, 0,
    <9837, 9829, 9833>, 0,
    <9837, 9833, 9830>, 0,
    <9837, 9830, 9835>, 0,
    <9837, 9835, 9817>, 0,
    <9837, 9817, 9820>, 0,
    <9837, 9820, 9816>, 0,
    <9837, 9816, 9836>, 0,
    <9838, 9831, 9829>, 0,
    <9838, 9829, 9836>, 0,
    <9838, 9836, 9816>, 0,
    <9838, 9816, 9827>, 0,
    <9838, 9827, 9013>, 0,
    <9838, 9013, 9728>, 0,
    <9838, 9728, 9722>, 0,
    <9838, 9722, 9831>, 0,
    <9844, 9843, 9839>, 0,
    <9844, 9839, 9841>, 0,
    <9844, 9841, 9809>, 0,
    <9844, 9809, 9810>, 0,
    <9844, 9810, 8993>, 0,
    <9844, 8993, 9842>, 0,
    <9844, 9842, 9840>, 0,
    <9844, 9840, 9843>, 0,
    <9849, 9848, 9839>, 0,
    <9849, 9839, 9843>, 0,
    <9849, 9843, 9840>, 0,
    <9849, 9840, 9846>, 0,
    <9849, 9846, 1699>, 0,
    <9849, 1699, 9847>, 0,
    <9849, 9847, 9845>, 0,
    <9849, 9845, 9848>, 0,
    <9851, 9841, 9839>, 0,
    <9851, 9839, 9848>, 0,
    <9851, 9848, 9845>, 0,
    <9851, 9845, 9850>, 0,
    <9851, 9850, 9797>, 0,
    <9851, 9797, 9813>, 0,
    <9851, 9813, 9809>, 0,
    <9851, 9809, 9841>, 0,
    <9855, 9854, 9852>, 0,
    <9855, 9852, 9853>, 0,
    <9855, 9853, 9840>, 0,
    <9855, 9840, 9842>, 0,
    <9855, 9842, 8993>, 0,
    <9855, 8993, 9046>, 0,
    <9855, 9046, 9041>, 0,
    <9855, 9041, 9854>, 0,
    <9859, 9858, 9852>, 0,
    <9859, 9852, 9854>, 0,
    <9859, 9854, 9041>, 0,
    <9859, 9041, 9043>, 0,
    <9859, 9043, 1428>, 0,
    <9859, 1428, 9857>, 0,
    <9859, 9857, 9856>, 0,
    <9859, 9856, 9858>, 0,
    <9861, 9853, 9852>, 0,
    <9861, 9852, 9858>, 0,
    <9861, 9858, 9856>, 0,
    <9861, 9856, 9860>, 0,
    <9861, 9860, 1699>, 0,
    <9861, 1699, 9846>, 0,
    <9861, 9846, 9840>, 0,
    <9861, 9840, 9853>, 0,
    <9867, 9866, 9862>, 0,
    <9867, 9862, 9864>, 0,
    <9867, 9864, 9818>, 0,
    <9867, 9818, 9821>, 0,
    <9867, 9821, 9817>, 0,
    <9867, 9817, 9865>, 0,
    <9867, 9865, 9863>, 0,
    <9867, 9863, 9866>, 0,
    <9872, 9871, 9862>, 0,
    <9872, 9862, 9866>, 0,
    <9872, 9866, 9863>, 0,
    <9872, 9863, 9869>, 0,
    <9872, 9869, 1677>, 0,
    <9872, 1677, 9870>, 0,
    <9872, 9870, 9868>, 0,
    <9872, 9868, 9871>, 0,
    <9874, 9864, 9862>, 0,
    <9874, 9862, 9871>, 0,
    <9874, 9871, 9868>, 0,
    <9874, 9868, 9873>, 0,
    <9874, 9873, 1485>, 0,
    <9874, 1485, 9824>, 0,
    <9874, 9824, 9818>, 0,
    <9874, 9818, 9864>, 0,
    <9880, 9879, 9875>, 0,
    <9880, 9875, 9877>, 0,
    <9880, 9877, 9876>, 0,
    <9880, 9876, 9878>, 0,
    <9880, 9878, 8949>, 0,
    <9880, 8949, 9765>, 0,
    <9880, 9765, 9761>, 0,
    <9880, 9761, 9879>, 0,
    <9884, 9883, 9875>, 0,
    <9884, 9875, 9879>, 0,
    <9884, 9879, 9761>, 0,
    <9884, 9761, 9762>, 0,
    <9884, 9762, 9753>, 0,
    <9884, 9753, 9882>, 0,
    <9884, 9882, 9881>, 0,
    <9884, 9881, 9883>, 0,
    <9888, 9877, 9875>, 0,
    <9888, 9875, 9883>, 0,
    <9888, 9883, 9881>, 0,
    <9888, 9881, 9886>, 0,
    <9888, 9886, 9885>, 0,
    <9888, 9885, 9887>, 0,
    <9888, 9887, 9876>, 0,
    <9888, 9876, 9877>, 0,
    <9892, 9891, 9889>, 0,
    <9892, 9889, 9890>, 0,
    <9892, 9890, 9077>, 0,
    <9892, 9077, 9078>, 0,
    <9892, 9078, 8949>, 0,
    <9892, 8949, 9878>, 0,
    <9892, 9878, 9876>, 0,
    <9892, 9876, 9891>, 0,
    <9896, 9895, 9889>, 0,
    <9896, 9889, 9891>, 0,
    <9896, 9891, 9876>, 0,
    <9896, 9876, 9887>, 0,
    <9896, 9887, 9885>, 0,
    <9896, 9885, 9894>, 0,
    <9896, 9894, 9893>, 0,
    <9896, 9893, 9895>, 0,
    <9898, 9890, 9889>, 0,
    <9898, 9889, 9895>, 0,
    <9898, 9895, 9893>, 0,
    <9898, 9893, 9897>, 0,
    <9898, 9897, 9081>, 0,
    <9898, 9081, 9082>, 0,
    <9898, 9082, 9077>, 0,
    <9898, 9077, 9890>, 0,
    <9907, 9906, 9899>, 0,
    <9907, 9899, 9903>, 0,
    <9907, 9903, 9900>, 0,
    <9907, 9900, 9904>, 0,
    <9907, 9904, 9901>, 0,
    <9907, 9901, 9905>, 0,
    <9907, 9905, 9902>, 0,
    <9907, 9902, 9906>, 0,
    <9910, 9909, 9899>, 0,
    <9910, 9899, 9906>, 0,
    <9910, 9906, 9902>, 0,
    <9910, 9902, 9908>, 0,
    <9910, 9908, 9097>, 0,
    <9910, 9097, 9160>, 0,
    <9910, 9160, 9158>, 0,
    <9910, 9158, 9909>, 0,
    <9912, 9903, 9899>, 0,
    <9912, 9899, 9909>, 0,
    <9912, 9909, 9158>, 0,
    <9912, 9158, 9165>, 0,
    <9912, 9165, 9145>, 0,
    <9912, 9145, 9911>, 0,
    <9912, 9911, 9900>, 0,
    <9912, 9900, 9903>, 0,
    <9918, 9917, 9913>, 0,
    <9918, 9913, 9915>, 0,
    <9918, 9915, 9914>, 0,
    <9918, 9914, 9916>, 0,
    <9918, 9916, 9769>, 0,
    <9918, 9769, 9772>, 0,
    <9918, 9772, 9768>, 0,
    <9918, 9768, 9917>, 0,
    <9920, 9919, 9913>, 0,
    <9920, 9913, 9917>, 0,
    <9920, 9917, 9768>, 0,
    <9920, 9768, 9779>, 0,
    <9920, 9779, 9097>, 0,
    <9920, 9097, 9908>, 0,
    <9920, 9908, 9902>, 0,
    <9920, 9902, 9919>, 0,
    <9922, 9915, 9913>, 0,
    <9922, 9913, 9919>, 0,
    <9922, 9919, 9902>, 0,
    <9922, 9902, 9905>, 0,
    <9922, 9905, 9901>, 0,
    <9922, 9901, 9921>, 0,
    <9922, 9921, 9914>, 0,
    <9922, 9914, 9915>, 0,
    <9928, 9927, 9923>, 0,
    <9928, 9923, 9925>, 0,
    <9928, 9925, 9924>, 0,
    <9928, 9924, 9926>, 0,
    <9928, 9926, 9081>, 0,
    <9928, 9081, 9897>, 0,
    <9928, 9897, 9893>, 0,
    <9928, 9893, 9927>, 0,
    <9932, 9931, 9923>, 0,
    <9932, 9923, 9927>, 0,
    <9932, 9927, 9893>, 0,
    <9932, 9893, 9894>, 0,
    <9932, 9894, 9885>, 0,
    <9932, 9885, 9930>, 0,
    <9932, 9930, 9929>, 0,
    <9932, 9929, 9931>, 0,
    <9936, 9925, 9923>, 0,
    <9936, 9923, 9931>, 0,
    <9936, 9931, 9929>, 0,
    <9936, 9929, 9934>, 0,
    <9936, 9934, 9933>, 0,
    <9936, 9933, 9935>, 0,
    <9936, 9935, 9924>, 0,
    <9936, 9924, 9925>, 0,
    <9940, 9939, 9937>, 0,
    <9940, 9937, 9938>, 0,
    <9940, 9938, 9125>, 0,
    <9940, 9125, 9126>, 0,
    <9940, 9126, 9081>, 0,
    <9940, 9081, 9926>, 0,
    <9940, 9926, 9924>, 0,
    <9940, 9924, 9939>, 0,
    <9944, 9943, 9937>, 0,
    <9944, 9937, 9939>, 0,
    <9944, 9939, 9924>, 0,
    <9944, 9924, 9935>, 0,
    <9944, 9935, 9933>, 0,
    <9944, 9933, 9942>, 0,
    <9944, 9942, 9941>, 0,
    <9944, 9941, 9943>, 0,
    <9946, 9938, 9937>, 0,
    <9946, 9937, 9943>, 0,
    <9946, 9943, 9941>, 0,
    <9946, 9941, 9945>, 0,
    <9946, 9945, 9129>, 0,
    <9946, 9129, 9130>, 0,
    <9946, 9130, 9125>, 0,
    <9946, 9125, 9938>, 0,
    <9955, 9954, 9947>, 0,
    <9955, 9947, 9951>, 0,
    <9955, 9951, 9948>, 0,
    <9955, 9948, 9952>, 0,
    <9955, 9952, 9949>, 0,
    <9955, 9949, 9953>, 0,
    <9955, 9953, 9950>, 0,
    <9955, 9950, 9954>, 0,
    <9958, 9957, 9947>, 0,
    <9958, 9947, 9954>, 0,
    <9958, 9954, 9950>, 0,
    <9958, 9950, 9956>, 0,
    <9958, 9956, 9145>, 0,
    <9958, 9145, 9190>, 0,
    <9958, 9190, 9188>, 0,
    <9958, 9188, 9957>, 0,
    <9960, 9951, 9947>, 0,
    <9960, 9947, 9957>, 0,
    <9960, 9957, 9188>, 0,
    <9960, 9188, 9195>, 0,
    <9960, 9195, 1464>, 0,
    <9960, 1464, 9959>, 0,
    <9960, 9959, 9948>, 0,
    <9960, 9948, 9951>, 0,
    <9966, 9965, 9961>, 0,
    <9966, 9961, 9963>, 0,
    <9966, 9963, 9962>, 0,
    <9966, 9962, 9964>, 0,
    <9966, 9964, 9901>, 0,
    <9966, 9901, 9904>, 0,
    <9966, 9904, 9900>, 0,
    <9966, 9900, 9965>, 0,
    <9968, 9967, 9961>, 0,
    <9968, 9961, 9965>, 0,
    <9968, 9965, 9900>, 0,
    <9968, 9900, 9911>, 0,
    <9968, 9911, 9145>, 0,
    <9968, 9145, 9956>, 0,
    <9968, 9956, 9950>, 0,
    <9968, 9950, 9967>, 0,
    <9970, 9963, 9961>, 0,
    <9970, 9961, 9967>, 0,
    <9970, 9967, 9950>, 0,
    <9970, 9950, 9953>, 0,
    <9970, 9953, 9949>, 0,
    <9970, 9949, 9969>, 0,
    <9970, 9969, 9962>, 0,
    <9970, 9962, 9963>, 0,
    <9976, 9975, 9971>, 0,
    <9976, 9971, 9973>, 0,
    <9976, 9973, 9972>, 0,
    <9976, 9972, 9974>, 0,
    <9976, 9974, 9129>, 0,
    <9976, 9129, 9945>, 0,
    <9976, 9945, 9941>, 0,
    <9976, 9941, 9975>, 0,
    <9980, 9979, 9971>, 0,
    <9980, 9971, 9975>, 0,
    <9980, 9975, 9941>, 0,
    <9980, 9941, 9942>, 0,
    <9980, 9942, 9933>, 0,
    <9980, 9933, 9978>, 0,
    <9980, 9978, 9977>, 0,
    <9980, 9977, 9979>, 0,
    <9983, 9973, 9971>, 0,
    <9983, 9971, 9979>, 0,
    <9983, 9979, 9977>, 0,
    <9983, 9977, 9981>, 0,
    <9983, 9981, 1693>, 0,
    <9983, 1693, 9982>, 0,
    <9983, 9982, 9972>, 0,
    <9983, 9972, 9973>, 0,
    <9987, 9986, 9984>, 0,
    <9987, 9984, 9985>, 0,
    <9987, 9985, 9173>, 0,
    <9987, 9173, 9174>, 0,
    <9987, 9174, 9129>, 0,
    <9987, 9129, 9974>, 0,
    <9987, 9974, 9972>, 0,
    <9987, 9972, 9986>, 0,
    <9989, 9988, 9984>, 0,
    <9989, 9984, 9986>, 0,
    <9989, 9986, 9972>, 0,
    <9989, 9972, 9982>, 0,
    <9989, 9982, 1693>, 0,
    <9989, 1693, 1711>, 0,
    <9989, 1711, 1707>, 0,
    <9989, 1707, 9988>, 0,
    <9990, 9985, 9984>, 0,
    <9990, 9984, 9988>, 0,
    <9990, 9988, 1707>, 0,
    <9990, 1707, 1708>, 0,
    <9990, 1708, 1422>, 0,
    <9990, 1422, 9177>, 0,
    <9990, 9177, 9173>, 0,
    <9990, 9173, 9985>, 0,
    <9996, 9995, 9991>, 0,
    <9996, 9991, 9993>, 0,
    <9996, 9993, 9992>, 0,
    <9996, 9992, 9994>, 0,
    <9996, 9994, 9949>, 0,
    <9996, 9949, 9952>, 0,
    <9996, 9952, 9948>, 0,
    <9996, 9948, 9995>, 0,
    <9998, 9997, 9991>, 0,
    <9998, 9991, 9995>, 0,
    <9998, 9995, 9948>, 0,
    <9998, 9948, 9959>, 0,
    <9998, 9959, 1464>, 0,
    <9998, 1464, 1725>, 0,
    <9998, 1725, 1720>, 0,
    <9998, 1720, 9997>, 0,
    <10000, 9993, 9991>, 0,
    <10000, 9991, 9997>, 0,
    <10000, 9997, 1720>, 0,
    <10000, 1720, 1722>, 0,
    <10000, 1722, 1719>, 0,
    <10000, 1719, 9999>, 0,
    <10000, 9999, 9992>, 0,
    <10000, 9992, 9993>, 0,
    <10009, 10008, 10001>, 0,
    <10009, 10001, 10005>, 0,
    <10009, 10005, 10002>, 0,
    <10009, 10002, 10006>, 0,
    <10009, 10006, 10003>, 0,
    <10009, 10003, 10007>, 0,
    <10009, 10007, 10004>, 0,
    <10009, 10004, 10008>, 0,
    <10012, 10011, 10001>, 0,
    <10012, 10001, 10008>, 0,
    <10012, 10008, 10004>, 0,
    <10012, 10004, 10010>, 0,
    <10012, 10010, 1569>, 0,
    <10012, 1569, 9253>, 0,
    <10012, 9253, 9248>, 0,
    <10012, 9248, 10011>, 0,
    <10014, 10005, 10001>, 0,
    <10014, 10001, 10011>, 0,
    <10014, 10011, 9248>, 0,
    <10014, 9248, 9250>, 0,
    <10014, 9250, 9247>, 0,
    <10014, 9247, 10013>, 0,
    <10014, 10013, 10002>, 0,
    <10014, 10002, 10005>, 0,
    <10023, 10022, 10015>, 0,
    <10023, 10015, 10019>, 0,
    <10023, 10019, 10016>, 0,
    <10023, 10016, 10020>, 0,
    <10023, 10020, 10017>, 0,
    <10023, 10017, 10021>, 0,
    <10023, 10021, 10018>, 0,
    <10023, 10018, 10022>, 0,
    <10026, 10025, 10015>, 0,
    <10026, 10015, 10022>, 0,
    <10026, 10022, 10018>, 0,
    <10026, 10018, 10024>, 0,
    <10026, 10024, 9285>, 0,
    <10026, 9285, 9328>, 0,
    <10026, 9328, 9323>, 0,
    <10026, 9323, 10025>, 0,
    <10028, 10019, 10015>, 0,
    <10028, 10015, 10025>, 0,
    <10028, 10025, 9323>, 0,
    <10028, 9323, 9325>, 0,
    <10028, 9325, 1636>, 0,
    <10028, 1636, 10027>, 0,
    <10028, 10027, 10016>, 0,
    <10028, 10016, 10019>, 0,
    <10036, 10035, 10029>, 0,
    <10036, 10029, 10032>, 0,
    <10036, 10032, 10030>, 0,
    <10036, 10030, 10033>, 0,
    <10036, 10033, 1853>, 0,
    <10036, 1853, 10034>, 0,
    <10036, 10034, 10031>, 0,
    <10036, 10031, 10035>, 0,
    <10039, 10038, 10029>, 0,
    <10039, 10029, 10035>, 0,
    <10039, 10035, 10031>, 0,
    <10039, 10031, 10037>, 0,
    <10039, 10037, 1603>, 0,
    <10039, 1603, 9448>, 0,
    <10039, 9448, 9446>, 0,
    <10039, 9446, 10038>, 0,
    <10041, 10032, 10029>, 0,
    <10041, 10029, 10038>, 0,
    <10041, 10038, 9446>, 0,
    <10041, 9446, 9453>, 0,
    <10041, 9453, 9433>, 0,
    <10041, 9433, 10040>, 0,
    <10041, 10040, 10030>, 0,
    <10041, 10030, 10032>, 0,
    <10050, 10049, 10042>, 0,
    <10050, 10042, 10046>, 0,
    <10050, 10046, 10043>, 0,
    <10050, 10043, 10047>, 0,
    <10050, 10047, 10044>, 0,
    <10050, 10044, 10048>, 0,
    <10050, 10048, 10045>, 0,
    <10050, 10045, 10049>, 0,
    <10056, 10055, 10042>, 0,
    <10056, 10042, 10049>, 0,
    <10056, 10049, 10045>, 0,
    <10056, 10045, 10053>, 0,
    <10056, 10053, 10051>, 0,
    <10056, 10051, 10054>, 0,
    <10056, 10054, 10052>, 0,
    <10056, 10052, 10055>, 0,
    <10059, 10046, 10042>, 0,
    <10059, 10042, 10055>, 0,
    <10059, 10055, 10052>, 0,
    <10059, 10052, 10057>, 0,
    <10059, 10057, 1813>, 0,
    <10059, 1813, 10058>, 0,
    <10059, 10058, 10043>, 0,
    <10059, 10043, 10046>, 0,
    <10065, 10064, 10060>, 0,
    <10065, 10060, 10062>, 0,
    <10065, 10062, 10045>, 0,
    <10065, 10045, 10048>, 0,
    <10065, 10048, 10044>, 0,
    <10065, 10044, 10063>, 0,
    <10065, 10063, 10061>, 0,
    <10065, 10061, 10064>, 0,
    <10070, 10069, 10060>, 0,
    <10070, 10060, 10064>, 0,
    <10070, 10064, 10061>, 0,
    <10070, 10061, 10067>, 0,
    <10070, 10067, 10003>, 0,
    <10070, 10003, 10068>, 0,
    <10070, 10068, 10066>, 0,
    <10070, 10066, 10069>, 0,
    <10072, 10062, 10060>, 0,
    <10072, 10060, 10069>, 0,
    <10072, 10069, 10066>, 0,
    <10072, 10066, 10071>, 0,
    <10072, 10071, 10051>, 0,
    <10072, 10051, 10053>, 0,
    <10072, 10053, 10045>, 0,
    <10072, 10045, 10062>, 0,
    <10076, 10075, 10073>, 0,
    <10076, 10073, 10074>, 0,
    <10076, 10074, 10066>, 0,
    <10076, 10066, 10068>, 0,
    <10076, 10068, 10003>, 0,
    <10076, 10003, 10006>, 0,
    <10076, 10006, 10002>, 0,
    <10076, 10002, 10075>, 0,
    <10080, 10079, 10073>, 0,
    <10080, 10073, 10075>, 0,
    <10080, 10075, 10002>, 0,
    <10080, 10002, 10013>, 0,
    <10080, 10013, 9247>, 0,
    <10080, 9247, 10078>, 0,
    <10080, 10078, 10077>, 0,
    <10080, 10077, 10079>, 0,
    <10082, 10074, 10073>, 0,
    <10082, 10073, 10079>, 0,
    <10082, 10079, 10077>, 0,
    <10082, 10077, 10081>, 0,
    <10082, 10081, 10051>, 0,
    <10082, 10051, 10071>, 0,
    <10082, 10071, 10066>, 0,
    <10082, 10066, 10074>, 0,
    <10088, 10087, 10083>, 0,
    <10088, 10083, 10085>, 0,
    <10088, 10085, 10018>, 0,
    <10088, 10018, 10021>, 0,
    <10088, 10021, 10017>, 0,
    <10088, 10017, 10086>, 0,
    <10088, 10086, 10084>, 0,
    <10088, 10084, 10087>, 0,
    <10094, 10093, 10083>, 0,
    <10094, 10083, 10087>, 0,
    <10094, 10087, 10084>, 0,
    <10094, 10084, 10091>, 0,
    <10094, 10091, 10089>, 0,
    <10094, 10089, 10092>, 0,
    <10094, 10092, 10090>, 0,
    <10094, 10090, 10093>, 0,
    <10096, 10085, 10083>, 0,
    <10096, 10083, 10093>, 0,
    <10096, 10093, 10090>, 0,
    <10096, 10090, 10095>, 0,
    <10096, 10095, 9285>, 0,
    <10096, 9285, 10024>, 0,
    <10096, 10024, 10018>, 0,
    <10096, 10018, 10085>, 0,
    <10102, 10101, 10097>, 0,
    <10102, 10097, 10099>, 0,
    <10102, 10099, 10090>, 0,
    <10102, 10090, 10092>, 0,
    <10102, 10092, 10089>, 0,
    <10102, 10089, 10100>, 0,
    <10102, 10100, 10098>, 0,
    <10102, 10098, 10101>, 0,
    <10105, 10104, 10097>, 0,
    <10105, 10097, 10101>, 0,
    <10105, 10101, 10098>, 0,
    <10105, 10098, 10103>, 0,
    <10105, 10103, 9369>, 0,
    <10105, 9369, 9387>, 0,
    <10105, 9387, 9382>, 0,
    <10105, 9382, 10104>, 0,
    <10106, 10099, 10097>, 0,
    <10106, 10097, 10104>, 0,
    <10106, 10104, 9382>, 0,
    <10106, 9382, 9384>, 0,
    <10106, 9384, 9285>, 0,
    <10106, 9285, 10095>, 0,
    <10106, 10095, 10090>, 0,
    <10106, 10090, 10099>, 0,
    <10112, 10111, 10107>, 0,
    <10112, 10107, 10109>, 0,
    <10112, 10109, 10084>, 0,
    <10112, 10084, 10086>, 0,
    <10112, 10086, 10017>, 0,
    <10112, 10017, 10110>, 0,
    <10112, 10110, 10108>, 0,
    <10112, 10108, 10111>, 0,
    <10118, 10117, 10107>, 0,
    <10118, 10107, 10111>, 0,
    <10118, 10111, 10108>, 0,
    <10118, 10108, 10115>, 0,
    <10118, 10115, 10113>, 0,
    <10118, 10113, 10116>, 0,
    <10118, 10116, 10114>, 0,
    <10118, 10114, 10117>, 0,
    <10120, 10109, 10107>, 0,
    <10120, 10107, 10117>, 0,
    <10120, 10117, 10114>, 0,
    <10120, 10114, 10119>, 0,
    <10120, 10119, 10089>, 0,
    <10120, 10089, 10091>, 0,
    <10120, 10091, 10084>, 0,
    <10120, 10084, 10109>, 0,
    <10126, 10125, 10121>, 0,
    <10126, 10121, 10123>, 0,
    <10126, 10123, 10114>, 0,
    <10126, 10114, 10116>, 0,
    <10126, 10116, 10113>, 0,
    <10126, 10113, 10124>, 0,
    <10126, 10124, 10122>, 0,
    <10126, 10122, 10125>, 0,
    <10131, 10130, 10121>, 0,
    <10131, 10121, 10125>, 0,
    <10131, 10125, 10122>, 0,
    <10131, 10122, 10128>, 0,
    <10131, 10128, 1872>, 0,
    <10131, 1872, 10129>, 0,
    <10131, 10129, 10127>, 0,
    <10131, 10127, 10130>, 0,
    <10133, 10123, 10121>, 0,
    <10133, 10121, 10130>, 0,
    <10133, 10130, 10127>, 0,
    <10133, 10127, 10132>, 0,
    <10133, 10132, 10089>, 0,
    <10133, 10089, 10119>, 0,
    <10133, 10119, 10114>, 0,
    <10133, 10114, 10123>, 0,
    <10141, 10140, 10134>, 0,
    <10141, 10134, 10137>, 0,
    <10141, 10137, 10135>, 0,
    <10141, 10135, 10138>, 0,
    <10141, 10138, 1847>, 0,
    <10141, 1847, 10139>, 0,
    <10141, 10139, 10136>, 0,
    <10141, 10136, 10140>, 0,
    <10144, 10143, 10134>, 0,
    <10144, 10134, 10140>, 0,
    <10144, 10140, 10136>, 0,
    <10144, 10136, 10142>, 0,
    <10144, 10142, 1853>, 0,
    <10144, 1853, 10033>, 0,
    <10144, 10033, 10030>, 0,
    <10144, 10030, 10143>, 0,
    <10146, 10137, 10134>, 0,
    <10146, 10134, 10143>, 0,
    <10146, 10143, 10030>, 0,
    <10146, 10030, 10040>, 0,
    <10146, 10040, 9433>, 0,
    <10146, 9433, 10145>, 0,
    <10146, 10145, 10135>, 0,
    <10146, 10135, 10137>, 0,
    <10152, 10151, 10147>, 0,
    <10152, 10147, 10149>, 0,
    <10152, 10149, 10077>, 0,
    <10152, 10077, 10078>, 0,
    <10152, 10078, 9247>, 0,
    <10152, 9247, 10150>, 0,
    <10152, 10150, 10148>, 0,
    <10152, 10148, 10151>, 0,
    <10158, 10157, 10147>, 0,
    <10158, 10147, 10151>, 0,
    <10158, 10151, 10148>, 0,
    <10158, 10148, 10155>, 0,
    <10158, 10155, 10153>, 0,
    <10158, 10153, 10156>, 0,
    <10158, 10156, 10154>, 0,
    <10158, 10154, 10157>, 0,
    <10160, 10149, 10147>, 0,
    <10160, 10147, 10157>, 0,
    <10160, 10157, 10154>, 0,
    <10160, 10154, 10159>, 0,
    <10160, 10159, 10051>, 0,
    <10160, 10051, 10081>, 0,
    <10160, 10081, 10077>, 0,
    <10160, 10077, 10149>, 0,
    <10164, 10163, 10161>, 0,
    <10164, 10161, 10162>, 0,
    <10164, 10162, 10148>, 0,
    <10164, 10148, 10150>, 0,
    <10164, 10150, 9247>, 0,
    <10164, 9247, 9355>, 0,
    <10164, 9355, 9350>, 0,
    <10164, 9350, 10163>, 0,
    <10168, 10167, 10161>, 0,
    <10168, 10161, 10163>, 0,
    <10168, 10163, 9350>, 0,
    <10168, 9350, 9352>, 0,
    <10168, 9352, 9349>, 0,
    <10168, 9349, 10166>, 0,
    <10168, 10166, 10165>, 0,
    <10168, 10165, 10167>, 0,
    <10170, 10162, 10161>, 0,
    <10170, 10161, 10167>, 0,
    <10170, 10167, 10165>, 0,
    <10170, 10165, 10169>, 0,
    <10170, 10169, 10153>, 0,
    <10170, 10153, 10155>, 0,
    <10170, 10155, 10148>, 0,
    <10170, 10148, 10162>, 0,
    <10179, 10178, 10171>, 0,
    <10179, 10171, 10175>, 0,
    <10179, 10175, 10172>, 0,
    <10179, 10172, 10176>, 0,
    <10179, 10176, 10173>, 0,
    <10179, 10173, 10177>, 0,
    <10179, 10177, 10174>, 0,
    <10179, 10174, 10178>, 0,
    <10182, 10181, 10171>, 0,
    <10182, 10171, 10178>, 0,
    <10182, 10178, 10174>, 0,
    <10182, 10174, 10180>, 0,
    <10182, 10180, 9481>, 0,
    <10182, 9481, 9499>, 0,
    <10182, 9499, 9494>, 0,
    <10182, 9494, 10181>, 0,
    <10184, 10175, 10171>, 0,
    <10184, 10171, 10181>, 0,
    <10184, 10181, 9494>, 0,
    <10184, 9494, 9496>, 0,
    <10184, 9496, 9369>, 0,
    <10184, 9369, 10183>, 0,
    <10184, 10183, 10172>, 0,
    <10184, 10172, 10175>, 0,
    <10190, 10189, 10185>, 0,
    <10190, 10185, 10187>, 0,
    <10190, 10187, 10098>, 0,
    <10190, 10098, 10100>, 0,
    <10190, 10100, 10089>, 0,
    <10190, 10089, 10188>, 0,
    <10190, 10188, 10186>, 0,
    <10190, 10186, 10189>, 0,
    <10193, 10192, 10185>, 0,
    <10193, 10185, 10189>, 0,
    <10193, 10189, 10186>, 0,
    <10193, 10186, 10191>, 0,
    <10193, 10191, 10173>, 0,
    <10193, 10173, 10176>, 0,
    <10193, 10176, 10172>, 0,
    <10193, 10172, 10192>, 0,
    <10194, 10187, 10185>, 0,
    <10194, 10185, 10192>, 0,
    <10194, 10192, 10172>, 0,
    <10194, 10172, 10183>, 0,
    <10194, 10183, 9369>, 0,
    <10194, 9369, 10103>, 0,
    <10194, 10103, 10098>, 0,
    <10194, 10098, 10187>, 0,
    <10202, 10201, 10195>, 0,
    <10202, 10195, 10198>, 0,
    <10202, 10198, 10196>, 0,
    <10202, 10196, 10199>, 0,
    <10202, 10199, 1886>, 0,
    <10202, 1886, 10200>, 0,
    <10202, 10200, 10197>, 0,
    <10202, 10197, 10201>, 0,
    <10207, 10206, 10195>, 0,
    <10207, 10195, 10201>, 0,
    <10207, 10201, 10197>, 0,
    <10207, 10197, 10204>, 0,
    <10207, 10204, 1820>, 0,
    <10207, 1820, 10205>, 0,
    <10207, 10205, 10203>, 0,
    <10207, 10203, 10206>, 0,
    <10211, 10198, 10195>, 0,
    <10211, 10195, 10206>, 0,
    <10211, 10206, 10203>, 0,
    <10211, 10203, 10209>, 0,
    <10211, 10209, 10208>, 0,
    <10211, 10208, 10210>, 0,
    <10211, 10210, 10196>, 0,
    <10211, 10196, 10198>, 0,
    <10219, 10218, 10212>, 0,
    <10219, 10212, 10215>, 0,
    <10219, 10215, 10213>, 0,
    <10219, 10213, 10216>, 0,
    <10219, 10216, 1576>, 0,
    <10219, 1576, 10217>, 0,
    <10219, 10217, 10214>, 0,
    <10219, 10214, 10218>, 0,
    <10222, 10221, 10212>, 0,
    <10222, 10212, 10218>, 0,
    <10222, 10218, 10214>, 0,
    <10222, 10214, 10220>, 0,
    <10222, 10220, 1886>, 0,
    <10222, 1886, 10199>, 0,
    <10222, 10199, 10196>, 0,
    <10222, 10196, 10221>, 0,
    <10224, 10215, 10212>, 0,
    <10224, 10212, 10221>, 0,
    <10224, 10221, 10196>, 0,
    <10224, 10196, 10210>, 0,
    <10224, 10210, 10208>, 0,
    <10224, 10208, 10223>, 0,
    <10224, 10223, 10213>, 0,
    <10224, 10213, 10215>, 0,
    <10228, 10227, 10225>, 0,
    <10228, 10225, 10226>, 0,
    <10228, 10226, 9399>, 0,
    <10228, 9399, 9401>, 0,
    <10228, 9401, 1576>, 0,
    <10228, 1576, 10216>, 0,
    <10228, 10216, 10213>, 0,
    <10228, 10213, 10227>, 0,
    <10232, 10231, 10225>, 0,
    <10232, 10225, 10227>, 0,
    <10232, 10227, 10213>, 0,
    <10232, 10213, 10223>, 0,
    <10232, 10223, 10208>, 0,
    <10232, 10208, 10230>, 0,
    <10232, 10230, 10229>, 0,
    <10232, 10229, 10231>, 0,
    <10234, 10226, 10225>, 0,
    <10234, 10225, 10231>, 0,
    <10234, 10231, 10229>, 0,
    <10234, 10229, 10233>, 0,
    <10234, 10233, 9404>, 0,
    <10234, 9404, 9405>, 0,
    <10234, 9405, 9399>, 0,
    <10234, 9399, 10226>, 0,
    <10243, 10242, 10235>, 0,
    <10243, 10235, 10239>, 0,
    <10243, 10239, 10236>, 0,
    <10243, 10236, 10240>, 0,
    <10243, 10240, 10237>, 0,
    <10243, 10237, 10241>, 0,
    <10243, 10241, 10238>, 0,
    <10243, 10238, 10242>, 0,
    <10246, 10245, 10235>, 0,
    <10246, 10235, 10242>, 0,
    <10246, 10242, 10238>, 0,
    <10246, 10238, 10244>, 0,
    <10246, 10244, 9433>, 0,
    <10246, 9433, 9544>, 0,
    <10246, 9544, 9542>, 0,
    <10246, 9542, 10245>, 0,
    <10248, 10239, 10235>, 0,
    <10248, 10235, 10245>, 0,
    <10248, 10245, 9542>, 0,
    <10248, 9542, 9549>, 0,
    <10248, 9549, 9529>, 0,
    <10248, 9529, 10247>, 0,
    <10248, 10247, 10236>, 0,
    <10248, 10236, 10239>, 0,
    <10254, 10253, 10249>, 0,
    <10254, 10249, 10251>, 0,
    <10254, 10251, 10250>, 0,
    <10254, 10250, 10252>, 0,
    <10254, 10252, 1847>, 0,
    <10254, 1847, 10138>, 0,
    <10254, 10138, 10135>, 0,
    <10254, 10135, 10253>, 0,
    <10256, 10255, 10249>, 0,
    <10256, 10249, 10253>, 0,
    <10256, 10253, 10135>, 0,
    <10256, 10135, 10145>, 0,
    <10256, 10145, 9433>, 0,
    <10256, 9433, 10244>, 0,
    <10256, 10244, 10238>, 0,
    <10256, 10238, 10255>, 0,
    <10258, 10251, 10249>, 0,
    <10258, 10249, 10255>, 0,
    <10258, 10255, 10238>, 0,
    <10258, 10238, 10241>, 0,
    <10258, 10241, 10237>, 0,
    <10258, 10237, 10257>, 0,
    <10258, 10257, 10250>, 0,
    <10258, 10250, 10251>, 0,
    <10264, 10263, 10259>, 0,
    <10264, 10259, 10261>, 0,
    <10264, 10261, 10165>, 0,
    <10264, 10165, 10166>, 0,
    <10264, 10166, 9349>, 0,
    <10264, 9349, 10262>, 0,
    <10264, 10262, 10260>, 0,
    <10264, 10260, 10263>, 0,
    <10270, 10269, 10259>, 0,
    <10270, 10259, 10263>, 0,
    <10270, 10263, 10260>, 0,
    <10270, 10260, 10267>, 0,
    <10270, 10267, 10265>, 0,
    <10270, 10265, 10268>, 0,
    <10270, 10268, 10266>, 0,
    <10270, 10266, 10269>, 0,
    <10272, 10261, 10259>, 0,
    <10272, 10259, 10269>, 0,
    <10272, 10269, 10266>, 0,
    <10272, 10266, 10271>, 0,
    <10272, 10271, 10153>, 0,
    <10272, 10153, 10169>, 0,
    <10272, 10169, 10165>, 0,
    <10272, 10165, 10261>, 0,
    <10276, 10275, 10273>, 0,
    <10276, 10273, 10274>, 0,
    <10276, 10274, 10260>, 0,
    <10276, 10260, 10262>, 0,
    <10276, 10262, 9349>, 0,
    <10276, 9349, 9467>, 0,
    <10276, 9467, 9462>, 0,
    <10276, 9462, 10275>, 0,
    <10280, 10279, 10273>, 0,
    <10280, 10273, 10275>, 0,
    <10280, 10275, 9462>, 0,
    <10280, 9462, 9464>, 0,
    <10280, 9464, 9461>, 0,
    <10280, 9461, 10278>, 0,
    <10280, 10278, 10277>, 0,
    <10280, 10277, 10279>, 0,
    <10282, 10274, 10273>, 0,
    <10282, 10273, 10279>, 0,
    <10282, 10279, 10277>, 0,
    <10282, 10277, 10281>, 0,
    <10282, 10281, 10265>, 0,
    <10282, 10265, 10267>, 0,
    <10282, 10267, 10260>, 0,
    <10282, 10260, 10274>, 0,
    <10291, 10290, 10283>, 0,
    <10291, 10283, 10287>, 0,
    <10291, 10287, 10284>, 0,
    <10291, 10284, 10288>, 0,
    <10291, 10288, 10285>, 0,
    <10291, 10285, 10289>, 0,
    <10291, 10289, 10286>, 0,
    <10291, 10286, 10290>, 0,
    <10294, 10293, 10283>, 0,
    <10294, 10283, 10290>, 0,
    <10294, 10290, 10286>, 0,
    <10294, 10286, 10292>, 0,
    <10294, 10292, 9577>, 0,
    <10294, 9577, 9595>, 0,
    <10294, 9595, 9590>, 0,
    <10294, 9590, 10293>, 0,
    <10296, 10287, 10283>, 0,
    <10296, 10283, 10293>, 0,
    <10296, 10293, 9590>, 0,
    <10296, 9590, 9592>, 0,
    <10296, 9592, 9481>, 0,
    <10296, 9481, 10295>, 0,
    <10296, 10295, 10284>, 0,
    <10296, 10284, 10287>, 0,
    <10302, 10301, 10297>, 0,
    <10302, 10297, 10299>, 0,
    <10302, 10299, 10174>, 0,
    <10302, 10174, 10177>, 0,
    <10302, 10177, 10173>, 0,
    <10302, 10173, 10300>, 0,
    <10302, 10300, 10298>, 0,
    <10302, 10298, 10301>, 0,
    <10305, 10304, 10297>, 0,
    <10305, 10297, 10301>, 0,
    <10305, 10301, 10298>, 0,
    <10305, 10298, 10303>, 0,
    <10305, 10303, 10285>, 0,
    <10305, 10285, 10288>, 0,
    <10305, 10288, 10284>, 0,
    <10305, 10284, 10304>, 0,
    <10306, 10299, 10297>, 0,
    <10306, 10297, 10304>, 0,
    <10306, 10304, 10284>, 0,
    <10306, 10284, 10295>, 0,
    <10306, 10295, 9481>, 0,
    <10306, 9481, 10180>, 0,
    <10306, 10180, 10174>, 0,
    <10306, 10174, 10299>, 0,
    <10312, 10311, 10307>, 0,
    <10312, 10307, 10309>, 0,
    <10312, 10309, 10308>, 0,
    <10312, 10308, 10310>, 0,
    <10312, 10310, 9404>, 0,
    <10312, 9404, 10233>, 0,
    <10312, 10233, 10229>, 0,
    <10312, 10229, 10311>, 0,
    <10316, 10315, 10307>, 0,
    <10316, 10307, 10311>, 0,
    <10316, 10311, 10229>, 0,
    <10316, 10229, 10230>, 0,
    <10316, 10230, 10208>, 0,
    <10316, 10208, 10314>, 0,
    <10316, 10314, 10313>, 0,
    <10316, 10313, 10315>, 0,
    <10320, 10309, 10307>, 0,
    <10320, 10307, 10315>, 0,
    <10320, 10315, 10313>, 0,
    <10320, 10313, 10318>, 0,
    <10320, 10318, 10317>, 0,
    <10320, 10317, 10319>, 0,
    <10320, 10319, 10308>, 0,
    <10320, 10308, 10309>, 0,
    <10324, 10323, 10321>, 0,
    <10324, 10321, 10322>, 0,
    <10324, 10322, 9509>, 0,
    <10324, 9509, 9510>, 0,
    <10324, 9510, 9404>, 0,
    <10324, 9404, 10310>, 0,
    <10324, 10310, 10308>, 0,
    <10324, 10308, 10323>, 0,
    <10328, 10327, 10321>, 0,
    <10328, 10321, 10323>, 0,
    <10328, 10323, 10308>, 0,
    <10328, 10308, 10319>, 0,
    <10328, 10319, 10317>, 0,
    <10328, 10317, 10326>, 0,
    <10328, 10326, 10325>, 0,
    <10328, 10325, 10327>, 0,
    <10330, 10322, 10321>, 0,
    <10330, 10321, 10327>, 0,
    <10330, 10327, 10325>, 0,
    <10330, 10325, 10329>, 0,
    <10330, 10329, 9513>, 0,
    <10330, 9513, 9514>, 0,
    <10330, 9514, 9509>, 0,
    <10330, 9509, 10322>, 0,
    <10339, 10338, 10331>, 0,
    <10339, 10331, 10335>, 0,
    <10339, 10335, 10332>, 0,
    <10339, 10332, 10336>, 0,
    <10339, 10336, 10333>, 0,
    <10339, 10333, 10337>, 0,
    <10339, 10337, 10334>, 0,
    <10339, 10334, 10338>, 0,
    <10342, 10341, 10331>, 0,
    <10342, 10331, 10338>, 0,
    <10342, 10338, 10334>, 0,
    <10342, 10334, 10340>, 0,
    <10342, 10340, 9529>, 0,
    <10342, 9529, 9640>, 0,
    <10342, 9640, 9638>, 0,
    <10342, 9638, 10341>, 0,
    <10344, 10335, 10331>, 0,
    <10344, 10331, 10341>, 0,
    <10344, 10341, 9638>, 0,
    <10344, 9638, 9645>, 0,
    <10344, 9645, 9625>, 0,
    <10344, 9625, 10343>, 0,
    <10344, 10343, 10332>, 0,
    <10344, 10332, 10335>, 0,
    <10350, 10349, 10345>, 0,
    <10350, 10345, 10347>, 0,
    <10350, 10347, 10346>, 0,
    <10350, 10346, 10348>, 0,
    <10350, 10348, 10237>, 0,
    <10350, 10237, 10240>, 0,
    <10350, 10240, 10236>, 0,
    <10350, 10236, 10349>, 0,
    <10352, 10351, 10345>, 0,
    <10352, 10345, 10349>, 0,
    <10352, 10349, 10236>, 0,
    <10352, 10236, 10247>, 0,
    <10352, 10247, 9529>, 0,
    <10352, 9529, 10340>, 0,
    <10352, 10340, 10334>, 0,
    <10352, 10334, 10351>, 0,
    <10354, 10347, 10345>, 0,
    <10354, 10345, 10351>, 0,
    <10354, 10351, 10334>, 0,
    <10354, 10334, 10337>, 0,
    <10354, 10337, 10333>, 0,
    <10354, 10333, 10353>, 0,
    <10354, 10353, 10346>, 0,
    <10354, 10346, 10347>, 0,
    <10360, 10359, 10355>, 0,
    <10360, 10355, 10357>, 0,
    <10360, 10357, 10277>, 0,
    <10360, 10277, 10278>, 0,
    <10360, 10278, 9461>, 0,
    <10360, 9461, 10358>, 0,
    <10360, 10358, 10356>, 0,
    <10360, 10356, 10359>, 0,
    <10366, 10365, 10355>, 0,
    <10366, 10355, 10359>, 0,
    <10366, 10359, 10356>, 0,
    <10366, 10356, 10363>, 0,
    <10366, 10363, 10361>, 0,
    <10366, 10361, 10364>, 0,
    <10366, 10364, 10362>, 0,
    <10366, 10362, 10365>, 0,
    <10368, 10357, 10355>, 0,
    <10368, 10355, 10365>, 0,
    <10368, 10365, 10362>, 0,
    <10368, 10362, 10367>, 0,
    <10368, 10367, 10265>, 0,
    <10368, 10265, 10281>, 0,
    <10368, 10281, 10277>, 0,
    <10368, 10277, 10357>, 0,
    <10372, 10371, 10369>, 0,
    <10372, 10369, 10370>, 0,
    <10372, 10370, 10356>, 0,
    <10372, 10356, 10358>, 0,
    <10372, 10358, 9461>, 0,
    <10372, 9461, 9563>, 0,
    <10372, 9563, 9558>, 0,
    <10372, 9558, 10371>, 0,
    <10376, 10375, 10369>, 0,
    <10376, 10369, 10371>, 0,
    <10376, 10371, 9558>, 0,
    <10376, 9558, 9560>, 0,
    <10376, 9560, 9557>, 0,
    <10376, 9557, 10374>, 0,
    <10376, 10374, 10373>, 0,
    <10376, 10373, 10375>, 0,
    <10378, 10370, 10369>, 0,
    <10378, 10369, 10375>, 0,
    <10378, 10375, 10373>, 0,
    <10378, 10373, 10377>, 0,
    <10378, 10377, 10361>, 0,
    <10378, 10361, 10363>, 0,
    <10378, 10363, 10356>, 0,
    <10378, 10356, 10370>, 0,
    <10387, 10386, 10379>, 0,
    <10387, 10379, 10383>, 0,
    <10387, 10383, 10380>, 0,
    <10387, 10380, 10384>, 0,
    <10387, 10384, 10381>, 0,
    <10387, 10381, 10385>, 0,
    <10387, 10385, 10382>, 0,
    <10387, 10382, 10386>, 0,
    <10390, 10389, 10379>, 0,
    <10390, 10379, 10386>, 0,
    <10390, 10386, 10382>, 0,
    <10390, 10382, 10388>, 0,
    <10390, 10388, 9673>, 0,
    <10390, 9673, 9691>, 0,
    <10390, 9691, 9686>, 0,
    <10390, 9686, 10389>, 0,
    <10392, 10383, 10379>, 0,
    <10392, 10379, 10389>, 0,
    <10392, 10389, 9686>, 0,
    <10392, 9686, 9688>, 0,
    <10392, 9688, 9577>, 0,
    <10392, 9577, 10391>, 0,
    <10392, 10391, 10380>, 0,
    <10392, 10380, 10383>, 0,
    <10398, 10397, 10393>, 0,
    <10398, 10393, 10395>, 0,
    <10398, 10395, 10286>, 0,
    <10398, 10286, 10289>, 0,
    <10398, 10289, 10285>, 0,
    <10398, 10285, 10396>, 0,
    <10398, 10396, 10394>, 0,
    <10398, 10394, 10397>, 0,
    <10401, 10400, 10393>, 0,
    <10401, 10393, 10397>, 0,
    <10401, 10397, 10394>, 0,
    <10401, 10394, 10399>, 0,
    <10401, 10399, 10381>, 0,
    <10401, 10381, 10384>, 0,
    <10401, 10384, 10380>, 0,
    <10401, 10380, 10400>, 0,
    <10402, 10395, 10393>, 0,
    <10402, 10393, 10400>, 0,
    <10402, 10400, 10380>, 0,
    <10402, 10380, 10391>, 0,
    <10402, 10391, 9577>, 0,
    <10402, 9577, 10292>, 0,
    <10402, 10292, 10286>, 0,
    <10402, 10286, 10395>, 0,
    <10408, 10407, 10403>, 0,
    <10408, 10403, 10405>, 0,
    <10408, 10405, 10404>, 0,
    <10408, 10404, 10406>, 0,
    <10408, 10406, 9513>, 0,
    <10408, 9513, 10329>, 0,
    <10408, 10329, 10325>, 0,
    <10408, 10325, 10407>, 0,
    <10412, 10411, 10403>, 0,
    <10412, 10403, 10407>, 0,
    <10412, 10407, 10325>, 0,
    <10412, 10325, 10326>, 0,
    <10412, 10326, 10317>, 0,
    <10412, 10317, 10410>, 0,
    <10412, 10410, 10409>, 0,
    <10412, 10409, 10411>, 0,
    <10416, 10405, 10403>, 0,
    <10416, 10403, 10411>, 0,
    <10416, 10411, 10409>, 0,
    <10416, 10409, 10414>, 0,
    <10416, 10414, 10413>, 0,
    <10416, 10413, 10415>, 0,
    <10416, 10415, 10404>, 0,
    <10416, 10404, 10405>, 0,
    <10420, 10419, 10417>, 0,
    <10420, 10417, 10418>, 0,
    <10420, 10418, 9605>, 0,
    <10420, 9605, 9606>, 0,
    <10420, 9606, 9513>, 0,
    <10420, 9513, 10406>, 0,
    <10420, 10406, 10404>, 0,
    <10420, 10404, 10419>, 0,
    <10424, 10423, 10417>, 0,
    <10424, 10417, 10419>, 0,
    <10424, 10419, 10404>, 0,
    <10424, 10404, 10415>, 0,
    <10424, 10415, 10413>, 0,
    <10424, 10413, 10422>, 0,
    <10424, 10422, 10421>, 0,
    <10424, 10421, 10423>, 0,
    <10426, 10418, 10417>, 0,
    <10426, 10417, 10423>, 0,
    <10426, 10423, 10421>, 0,
    <10426, 10421, 10425>, 0,
    <10426, 10425, 9609>, 0,
    <10426, 9609, 9610>, 0,
    <10426, 9610, 9605>, 0,
    <10426, 9605, 10418>, 0,
    <10435, 10434, 10427>, 0,
    <10435, 10427, 10431>, 0,
    <10435, 10431, 10428>, 0,
    <10435, 10428, 10432>, 0,
    <10435, 10432, 10429>, 0,
    <10435, 10429, 10433>, 0,
    <10435, 10433, 10430>, 0,
    <10435, 10430, 10434>, 0,
    <10438, 10437, 10427>, 0,
    <10438, 10427, 10434>, 0,
    <10438, 10434, 10430>, 0,
    <10438, 10430, 10436>, 0,
    <10438, 10436, 9625>, 0,
    <10438, 9625, 9784>, 0,
    <10438, 9784, 9782>, 0,
    <10438, 9782, 10437>, 0,
    <10440, 10431, 10427>, 0,
    <10440, 10427, 10437>, 0,
    <10440, 10437, 9782>, 0,
    <10440, 9782, 9789>, 0,
    <10440, 9789, 9769>, 0,
    <10440, 9769, 10439>, 0,
    <10440, 10439, 10428>, 0,
    <10440, 10428, 10431>, 0,
    <10446, 10445, 10441>, 0,
    <10446, 10441, 10443>, 0,
    <10446, 10443, 10442>, 0,
    <10446, 10442, 10444>, 0,
    <10446, 10444, 10333>, 0,
    <10446, 10333, 10336>, 0,
    <10446, 10336, 10332>, 0,
    <10446, 10332, 10445>, 0,
    <10448, 10447, 10441>, 0,
    <10448, 10441, 10445>, 0,
    <10448, 10445, 10332>, 0,
    <10448, 10332, 10343>, 0,
    <10448, 10343, 9625>, 0,
    <10448, 9625, 10436>, 0,
    <10448, 10436, 10430>, 0,
    <10448, 10430, 10447>, 0,
    <10450, 10443, 10441>, 0,
    <10450, 10441, 10447>, 0,
    <10450, 10447, 10430>, 0,
    <10450, 10430, 10433>, 0,
    <10450, 10433, 10429>, 0,
    <10450, 10429, 10449>, 0,
    <10450, 10449, 10442>, 0,
    <10450, 10442, 10443>, 0,
    <10456, 10455, 10451>, 0,
    <10456, 10451, 10453>, 0,
    <10456, 10453, 10373>, 0,
    <10456, 10373, 10374>, 0,
    <10456, 10374, 9557>, 0,
    <10456, 9557, 10454>, 0,
    <10456, 10454, 10452>, 0,
    <10456, 10452, 10455>, 0,
    <10462, 10461, 10451>, 0,
    <10462, 10451, 10455>, 0,
    <10462, 10455, 10452>, 0,
    <10462, 10452, 10459>, 0,
    <10462, 10459, 10457>, 0,
    <10462, 10457, 10460>, 0,
    <10462, 10460, 10458>, 0,
    <10462, 10458, 10461>, 0,
    <10464, 10453, 10451>, 0,
    <10464, 10451, 10461>, 0,
    <10464, 10461, 10458>, 0,
    <10464, 10458, 10463>, 0,
    <10464, 10463, 10361>, 0,
    <10464, 10361, 10377>, 0,
    <10464, 10377, 10373>, 0,
    <10464, 10373, 10453>, 0,
    <10468, 10467, 10465>, 0,
    <10468, 10465, 10466>, 0,
    <10468, 10466, 10452>, 0,
    <10468, 10452, 10454>, 0,
    <10468, 10454, 9557>, 0,
    <10468, 9557, 9659>, 0,
    <10468, 9659, 9654>, 0,
    <10468, 9654, 10467>, 0,
    <10472, 10471, 10465>, 0,
    <10472, 10465, 10467>, 0,
    <10472, 10467, 9654>, 0,
    <10472, 9654, 9656>, 0,
    <10472, 9656, 9653>, 0,
    <10472, 9653, 10470>, 0,
    <10472, 10470, 10469>, 0,
    <10472, 10469, 10471>, 0,
    <10474, 10466, 10465>, 0,
    <10474, 10465, 10471>, 0,
    <10474, 10471, 10469>, 0,
    <10474, 10469, 10473>, 0,
    <10474, 10473, 10457>, 0,
    <10474, 10457, 10459>, 0,
    <10474, 10459, 10452>, 0,
    <10474, 10452, 10466>, 0,
    <10483, 10482, 10475>, 0,
    <10483, 10475, 10479>, 0,
    <10483, 10479, 10476>, 0,
    <10483, 10476, 10480>, 0,
    <10483, 10480, 10477>, 0,
    <10483, 10477, 10481>, 0,
    <10483, 10481, 10478>, 0,
    <10483, 10478, 10482>, 0,
    <10486, 10485, 10475>, 0,
    <10486, 10475, 10482>, 0,
    <10486, 10482, 10478>, 0,
    <10486, 10478, 10484>, 0,
    <10486, 10484, 9721>, 0,
    <10486, 9721, 9739>, 0,
    <10486, 9739, 9734>, 0,
    <10486, 9734, 10485>, 0,
    <10488, 10479, 10475>, 0,
    <10488, 10475, 10485>, 0,
    <10488, 10485, 9734>, 0,
    <10488, 9734, 9736>, 0,
    <10488, 9736, 9673>, 0,
    <10488, 9673, 10487>, 0,
    <10488, 10487, 10476>, 0,
    <10488, 10476, 10479>, 0,
    <10494, 10493, 10489>, 0,
    <10494, 10489, 10491>, 0,
    <10494, 10491, 10382>, 0,
    <10494, 10382, 10385>, 0,
    <10494, 10385, 10381>, 0,
    <10494, 10381, 10492>, 0,
    <10494, 10492, 10490>, 0,
    <10494, 10490, 10493>, 0,
    <10497, 10496, 10489>, 0,
    <10497, 10489, 10493>, 0,
    <10497, 10493, 10490>, 0,
    <10497, 10490, 10495>, 0,
    <10497, 10495, 10477>, 0,
    <10497, 10477, 10480>, 0,
    <10497, 10480, 10476>, 0,
    <10497, 10476, 10496>, 0,
    <10498, 10491, 10489>, 0,
    <10498, 10489, 10496>, 0,
    <10498, 10496, 10476>, 0,
    <10498, 10476, 10487>, 0,
    <10498, 10487, 9673>, 0,
    <10498, 9673, 10388>, 0,
    <10498, 10388, 10382>, 0,
    <10498, 10382, 10491>, 0,
    <10504, 10503, 10499>, 0,
    <10504, 10499, 10501>, 0,
    <10504, 10501, 10469>, 0,
    <10504, 10469, 10470>, 0,
    <10504, 10470, 9653>, 0,
    <10504, 9653, 10502>, 0,
    <10504, 10502, 10500>, 0,
    <10504, 10500, 10503>, 0,
    <10510, 10509, 10499>, 0,
    <10510, 10499, 10503>, 0,
    <10510, 10503, 10500>, 0,
    <10510, 10500, 10507>, 0,
    <10510, 10507, 10505>, 0,
    <10510, 10505, 10508>, 0,
    <10510, 10508, 10506>, 0,
    <10510, 10506, 10509>, 0,
    <10512, 10501, 10499>, 0,
    <10512, 10499, 10509>, 0,
    <10512, 10509, 10506>, 0,
    <10512, 10506, 10511>, 0,
    <10512, 10511, 10457>, 0,
    <10512, 10457, 10473>, 0,
    <10512, 10473, 10469>, 0,
    <10512, 10469, 10501>, 0,
    <10516, 10515, 10513>, 0,
    <10516, 10513, 10514>, 0,
    <10516, 10514, 10500>, 0,
    <10516, 10500, 10502>, 0,
    <10516, 10502, 9653>, 0,
    <10516, 9653, 9707>, 0,
    <10516, 9707, 9702>, 0,
    <10516, 9702, 10515>, 0,
    <10520, 10519, 10513>, 0,
    <10520, 10513, 10515>, 0,
    <10520, 10515, 9702>, 0,
    <10520, 9702, 9704>, 0,
    <10520, 9704, 9701>, 0,
    <10520, 9701, 10518>, 0,
    <10520, 10518, 10517>, 0,
    <10520, 10517, 10519>, 0,
    <10522, 10514, 10513>, 0,
    <10522, 10513, 10519>, 0,
    <10522, 10519, 10517>, 0,
    <10522, 10517, 10521>, 0,
    <10522, 10521, 10505>, 0,
    <10522, 10505, 10507>, 0,
    <10522, 10507, 10500>, 0,
    <10522, 10500, 10514>, 0,
    <10531, 10530, 10523>, 0,
    <10531, 10523, 10527>, 0,
    <10531, 10527, 10524>, 0,
    <10531, 10524, 10528>, 0,
    <10531, 10528, 10525>, 0,
    <10531, 10525, 10529>, 0,
    <10531, 10529, 10526>, 0,
    <10531, 10526, 10530>, 0,
    <10534, 10533, 10523>, 0,
    <10534, 10523, 10530>, 0,
    <10534, 10530, 10526>, 0,
    <10534, 10526, 10532>, 0,
    <10534, 10532, 9817>, 0,
    <10534, 9817, 9835>, 0,
    <10534, 9835, 9830>, 0,
    <10534, 9830, 10533>, 0,
    <10536, 10527, 10523>, 0,
    <10536, 10523, 10533>, 0,
    <10536, 10533, 9830>, 0,
    <10536, 9830, 9832>, 0,
    <10536, 9832, 9721>, 0,
    <10536, 9721, 10535>, 0,
    <10536, 10535, 10524>, 0,
    <10536, 10524, 10527>, 0,
    <10542, 10541, 10537>, 0,
    <10542, 10537, 10539>, 0,
    <10542, 10539, 10478>, 0,
    <10542, 10478, 10481>, 0,
    <10542, 10481, 10477>, 0,
    <10542, 10477, 10540>, 0,
    <10542, 10540, 10538>, 0,
    <10542, 10538, 10541>, 0,
    <10545, 10544, 10537>, 0,
    <10545, 10537, 10541>, 0,
    <10545, 10541, 10538>, 0,
    <10545, 10538, 10543>, 0,
    <10545, 10543, 10525>, 0,
    <10545, 10525, 10528>, 0,
    <10545, 10528, 10524>, 0,
    <10545, 10524, 10544>, 0,
    <10546, 10539, 10537>, 0,
    <10546, 10537, 10544>, 0,
    <10546, 10544, 10524>, 0,
    <10546, 10524, 10535>, 0,
    <10546, 10535, 9721>, 0,
    <10546, 9721, 10484>, 0,
    <10546, 10484, 10478>, 0,
    <10546, 10478, 10539>, 0,
    <10552, 10551, 10547>, 0,
    <10552, 10547, 10549>, 0,
    <10552, 10549, 10548>, 0,
    <10552, 10548, 10550>, 0,
    <10552, 10550, 9609>, 0,
    <10552, 9609, 10425>, 0,
    <10552, 10425, 10421>, 0,
    <10552, 10421, 10551>, 0,
    <10556, 10555, 10547>, 0,
    <10556, 10547, 10551>, 0,
    <10556, 10551, 10421>, 0,
    <10556, 10421, 10422>, 0,
    <10556, 10422, 10413>, 0,
    <10556, 10413, 10554>, 0,
    <10556, 10554, 10553>, 0,
    <10556, 10553, 10555>, 0,
    <10560, 10549, 10547>, 0,
    <10560, 10547, 10555>, 0,
    <10560, 10555, 10553>, 0,
    <10560, 10553, 10558>, 0,
    <10560, 10558, 10557>, 0,
    <10560, 10557, 10559>, 0,
    <10560, 10559, 10548>, 0,
    <10560, 10548, 10549>, 0,
    <10564, 10563, 10561>, 0,
    <10564, 10561, 10562>, 0,
    <10564, 10562, 9749>, 0,
    <10564, 9749, 9750>, 0,
    <10564, 9750, 9609>, 0,
    <10564, 9609, 10550>, 0,
    <10564, 10550, 10548>, 0,
    <10564, 10548, 10563>, 0,
    <10568, 10567, 10561>, 0,
    <10568, 10561, 10563>, 0,
    <10568, 10563, 10548>, 0,
    <10568, 10548, 10559>, 0,
    <10568, 10559, 10557>, 0,
    <10568, 10557, 10566>, 0,
    <10568, 10566, 10565>, 0,
    <10568, 10565, 10567>, 0,
    <10570, 10562, 10561>, 0,
    <10570, 10561, 10567>, 0,
    <10570, 10567, 10565>, 0,
    <10570, 10565, 10569>, 0,
    <10570, 10569, 9753>, 0,
    <10570, 9753, 9754>, 0,
    <10570, 9754, 9749>, 0,
    <10570, 9749, 10562>, 0,
    <10579, 10578, 10571>, 0,
    <10579, 10571, 10575>, 0,
    <10579, 10575, 10572>, 0,
    <10579, 10572, 10576>, 0,
    <10579, 10576, 10573>, 0,
    <10579, 10573, 10577>, 0,
    <10579, 10577, 10574>, 0,
    <10579, 10574, 10578>, 0,
    <10582, 10581, 10571>, 0,
    <10582, 10571, 10578>, 0,
    <10582, 10578, 10574>, 0,
    <10582, 10574, 10580>, 0,
    <10582, 10580, 9769>, 0,
    <10582, 9769, 9916>, 0,
    <10582, 9916, 9914>, 0,
    <10582, 9914, 10581>, 0,
    <10584, 10575, 10571>, 0,
    <10584, 10571, 10581>, 0,
    <10584, 10581, 9914>, 0,
    <10584, 9914, 9921>, 0,
    <10584, 9921, 9901>, 0,
    <10584, 9901, 10583>, 0,
    <10584, 10583, 10572>, 0,
    <10584, 10572, 10575>, 0,
    <10590, 10589, 10585>, 0,
    <10590, 10585, 10587>, 0,
    <10590, 10587, 10586>, 0,
    <10590, 10586, 10588>, 0,
    <10590, 10588, 10429>, 0,
    <10590, 10429, 10432>, 0,
    <10590, 10432, 10428>, 0,
    <10590, 10428, 10589>, 0,
    <10592, 10591, 10585>, 0,
    <10592, 10585, 10589>, 0,
    <10592, 10589, 10428>, 0,
    <10592, 10428, 10439>, 0,
    <10592, 10439, 9769>, 0,
    <10592, 9769, 10580>, 0,
    <10592, 10580, 10574>, 0,
    <10592, 10574, 10591>, 0,
    <10594, 10587, 10585>, 0,
    <10594, 10585, 10591>, 0,
    <10594, 10591, 10574>, 0,
    <10594, 10574, 10577>, 0,
    <10594, 10577, 10573>, 0,
    <10594, 10573, 10593>, 0,
    <10594, 10593, 10586>, 0,
    <10594, 10586, 10587>, 0,
    <10600, 10599, 10595>, 0,
    <10600, 10595, 10597>, 0,
    <10600, 10597, 10517>, 0,
    <10600, 10517, 10518>, 0,
    <10600, 10518, 9701>, 0,
    <10600, 9701, 10598>, 0,
    <10600, 10598, 10596>, 0,
    <10600, 10596, 10599>, 0,
    <10606, 10605, 10595>, 0,
    <10606, 10595, 10599>, 0,
    <10606, 10599, 10596>, 0,
    <10606, 10596, 10603>, 0,
    <10606, 10603, 10601>, 0,
    <10606, 10601, 10604>, 0,
    <10606, 10604, 10602>, 0,
    <10606, 10602, 10605>, 0,
    <10608, 10597, 10595>, 0,
    <10608, 10595, 10605>, 0,
    <10608, 10605, 10602>, 0,
    <10608, 10602, 10607>, 0,
    <10608, 10607, 10505>, 0,
    <10608, 10505, 10521>, 0,
    <10608, 10521, 10517>, 0,
    <10608, 10517, 10597>, 0,
    <10612, 10611, 10609>, 0,
    <10612, 10609, 10610>, 0,
    <10612, 10610, 10596>, 0,
    <10612, 10596, 10598>, 0,
    <10612, 10598, 9701>, 0,
    <10612, 9701, 9803>, 0,
    <10612, 9803, 9798>, 0,
    <10612, 9798, 10611>, 0,
    <10616, 10615, 10609>, 0,
    <10616, 10609, 10611>, 0,
    <10616, 10611, 9798>, 0,
    <10616, 9798, 9800>, 0,
    <10616, 9800, 9797>, 0,
    <10616, 9797, 10614>, 0,
    <10616, 10614, 10613>, 0,
    <10616, 10613, 10615>, 0,
    <10618, 10610, 10609>, 0,
    <10618, 10609, 10615>, 0,
    <10618, 10615, 10613>, 0,
    <10618, 10613, 10617>, 0,
    <10618, 10617, 10601>, 0,
    <10618, 10601, 10603>, 0,
    <10618, 10603, 10596>, 0,
    <10618, 10596, 10610>, 0,
    <10627, 10626, 10619>, 0,
    <10627, 10619, 10623>, 0,
    <10627, 10623, 10620>, 0,
    <10627, 10620, 10624>, 0,
    <10627, 10624, 10621>, 0,
    <10627, 10621, 10625>, 0,
    <10627, 10625, 10622>, 0,
    <10627, 10622, 10626>, 0,
    <10630, 10629, 10619>, 0,
    <10630, 10619, 10626>, 0,
    <10630, 10626, 10622>, 0,
    <10630, 10622, 10628>, 0,
    <10630, 10628, 1677>, 0,
    <10630, 1677, 9869>, 0,
    <10630, 9869, 9863>, 0,
    <10630, 9863, 10629>, 0,
    <10632, 10623, 10619>, 0,
    <10632, 10619, 10629>, 0,
    <10632, 10629, 9863>, 0,
    <10632, 9863, 9865>, 0,
    <10632, 9865, 9817>, 0,
    <10632, 9817, 10631>, 0,
    <10632, 10631, 10620>, 0,
    <10632, 10620, 10623>, 0,
    <10638, 10637, 10633>, 0,
    <10638, 10633, 10635>, 0,
    <10638, 10635, 10526>, 0,
    <10638, 10526, 10529>, 0,
    <10638, 10529, 10525>, 0,
    <10638, 10525, 10636>, 0,
    <10638, 10636, 10634>, 0,
    <10638, 10634, 10637>, 0,
    <10641, 10640, 10633>, 0,
    <10641, 10633, 10637>, 0,
    <10641, 10637, 10634>, 0,
    <10641, 10634, 10639>, 0,
    <10641, 10639, 10621>, 0,
    <10641, 10621, 10624>, 0,
    <10641, 10624, 10620>, 0,
    <10641, 10620, 10640>, 0,
    <10642, 10635, 10633>, 0,
    <10642, 10633, 10640>, 0,
    <10642, 10640, 10620>, 0,
    <10642, 10620, 10631>, 0,
    <10642, 10631, 9817>, 0,
    <10642, 9817, 10532>, 0,
    <10642, 10532, 10526>, 0,
    <10642, 10526, 10635>, 0,
    <10648, 10647, 10643>, 0,
    <10648, 10643, 10645>, 0,
    <10648, 10645, 10613>, 0,
    <10648, 10613, 10614>, 0,
    <10648, 10614, 9797>, 0,
    <10648, 9797, 10646>, 0,
    <10648, 10646, 10644>, 0,
    <10648, 10644, 10647>, 0,
    <10653, 10652, 10643>, 0,
    <10653, 10643, 10647>, 0,
    <10653, 10647, 10644>, 0,
    <10653, 10644, 10650>, 0,
    <10653, 10650, 1930>, 0,
    <10653, 1930, 10651>, 0,
    <10653, 10651, 10649>, 0,
    <10653, 10649, 10652>, 0,
    <10655, 10645, 10643>, 0,
    <10655, 10643, 10652>, 0,
    <10655, 10652, 10649>, 0,
    <10655, 10649, 10654>, 0,
    <10655, 10654, 10601>, 0,
    <10655, 10601, 10617>, 0,
    <10655, 10617, 10613>, 0,
    <10655, 10613, 10645>, 0,
    <10659, 10658, 10656>, 0,
    <10659, 10656, 10657>, 0,
    <10659, 10657, 10644>, 0,
    <10659, 10644, 10646>, 0,
    <10659, 10646, 9797>, 0,
    <10659, 9797, 9850>, 0,
    <10659, 9850, 9845>, 0,
    <10659, 9845, 10658>, 0,
    <10663, 10662, 10656>, 0,
    <10663, 10656, 10658>, 0,
    <10663, 10658, 9845>, 0,
    <10663, 9845, 9847>, 0,
    <10663, 9847, 1699>, 0,
    <10663, 1699, 10661>, 0,
    <10663, 10661, 10660>, 0,
    <10663, 10660, 10662>, 0,
    <10665, 10657, 10656>, 0,
    <10665, 10656, 10662>, 0,
    <10665, 10662, 10660>, 0,
    <10665, 10660, 10664>, 0,
    <10665, 10664, 1930>, 0,
    <10665, 1930, 10650>, 0,
    <10665, 10650, 10644>, 0,
    <10665, 10644, 10657>, 0,
    <10671, 10670, 10666>, 0,
    <10671, 10666, 10668>, 0,
    <10671, 10668, 10622>, 0,
    <10671, 10622, 10625>, 0,
    <10671, 10625, 10621>, 0,
    <10671, 10621, 10669>, 0,
    <10671, 10669, 10667>, 0,
    <10671, 10667, 10670>, 0,
    <10676, 10675, 10666>, 0,
    <10676, 10666, 10670>, 0,
    <10676, 10670, 10667>, 0,
    <10676, 10667, 10673>, 0,
    <10676, 10673, 1987>, 0,
    <10676, 1987, 10674>, 0,
    <10676, 10674, 10672>, 0,
    <10676, 10672, 10675>, 0,
    <10678, 10668, 10666>, 0,
    <10678, 10666, 10675>, 0,
    <10678, 10675, 10672>, 0,
    <10678, 10672, 10677>, 0,
    <10678, 10677, 1677>, 0,
    <10678, 1677, 10628>, 0,
    <10678, 10628, 10622>, 0,
    <10678, 10622, 10668>, 0,
    <10684, 10683, 10679>, 0,
    <10684, 10679, 10681>, 0,
    <10684, 10681, 10680>, 0,
    <10684, 10680, 10682>, 0,
    <10684, 10682, 9753>, 0,
    <10684, 9753, 10569>, 0,
    <10684, 10569, 10565>, 0,
    <10684, 10565, 10683>, 0,
    <10688, 10687, 10679>, 0,
    <10688, 10679, 10683>, 0,
    <10688, 10683, 10565>, 0,
    <10688, 10565, 10566>, 0,
    <10688, 10566, 10557>, 0,
    <10688, 10557, 10686>, 0,
    <10688, 10686, 10685>, 0,
    <10688, 10685, 10687>, 0,
    <10692, 10681, 10679>, 0,
    <10692, 10679, 10687>, 0,
    <10692, 10687, 10685>, 0,
    <10692, 10685, 10690>, 0,
    <10692, 10690, 10689>, 0,
    <10692, 10689, 10691>, 0,
    <10692, 10691, 10680>, 0,
    <10692, 10680, 10681>, 0,
    <10696, 10695, 10693>, 0,
    <10696, 10693, 10694>, 0,
    <10696, 10694, 9881>, 0,
    <10696, 9881, 9882>, 0,
    <10696, 9882, 9753>, 0,
    <10696, 9753, 10682>, 0,
    <10696, 10682, 10680>, 0,
    <10696, 10680, 10695>, 0,
    <10700, 10699, 10693>, 0,
    <10700, 10693, 10695>, 0,
    <10700, 10695, 10680>, 0,
    <10700, 10680, 10691>, 0,
    <10700, 10691, 10689>, 0,
    <10700, 10689, 10698>, 0,
    <10700, 10698, 10697>, 0,
    <10700, 10697, 10699>, 0,
    <10702, 10694, 10693>, 0,
    <10702, 10693, 10699>, 0,
    <10702, 10699, 10697>, 0,
    <10702, 10697, 10701>, 0,
    <10702, 10701, 9885>, 0,
    <10702, 9885, 9886>, 0,
    <10702, 9886, 9881>, 0,
    <10702, 9881, 10694>, 0,
    <10711, 10710, 10703>, 0,
    <10711, 10703, 10707>, 0,
    <10711, 10707, 10704>, 0,
    <10711, 10704, 10708>, 0,
    <10711, 10708, 10705>, 0,
    <10711, 10705, 10709>, 0,
    <10711, 10709, 10706>, 0,
    <10711, 10706, 10710>, 0,
    <10714, 10713, 10703>, 0,
    <10714, 10703, 10710>, 0,
    <10714, 10710, 10706>, 0,
    <10714, 10706, 10712>, 0,
    <10714, 10712, 9901>, 0,
    <10714, 9901, 9964>, 0,
    <10714, 9964, 9962>, 0,
    <10714, 9962, 10713>, 0,
    <10716, 10707, 10703>, 0,
    <10716, 10703, 10713>, 0,
    <10716, 10713, 9962>, 0,
    <10716, 9962, 9969>, 0,
    <10716, 9969, 9949>, 0,
    <10716, 9949, 10715>, 0,
    <10716, 10715, 10704>, 0,
    <10716, 10704, 10707>, 0,
    <10722, 10721, 10717>, 0,
    <10722, 10717, 10719>, 0,
    <10722, 10719, 10718>, 0,
    <10722, 10718, 10720>, 0,
    <10722, 10720, 10573>, 0,
    <10722, 10573, 10576>, 0,
    <10722, 10576, 10572>, 0,
    <10722, 10572, 10721>, 0,
    <10724, 10723, 10717>, 0,
    <10724, 10717, 10721>, 0,
    <10724, 10721, 10572>, 0,
    <10724, 10572, 10583>, 0,
    <10724, 10583, 9901>, 0,
    <10724, 9901, 10712>, 0,
    <10724, 10712, 10706>, 0,
    <10724, 10706, 10723>, 0,
    <10726, 10719, 10717>, 0,
    <10726, 10717, 10723>, 0,
    <10726, 10723, 10706>, 0,
    <10726, 10706, 10709>, 0,
    <10726, 10709, 10705>, 0,
    <10726, 10705, 10725>, 0,
    <10726, 10725, 10718>, 0,
    <10726, 10718, 10719>, 0,
    <10732, 10731, 10727>, 0,
    <10732, 10727, 10729>, 0,
    <10732, 10729, 10728>, 0,
    <10732, 10728, 10730>, 0,
    <10732, 10730, 9885>, 0,
    <10732, 9885, 10701>, 0,
    <10732, 10701, 10697>, 0,
    <10732, 10697, 10731>, 0,
    <10736, 10735, 10727>, 0,
    <10736, 10727, 10731>, 0,
    <10736, 10731, 10697>, 0,
    <10736, 10697, 10698>, 0,
    <10736, 10698, 10689>, 0,
    <10736, 10689, 10734>, 0,
    <10736, 10734, 10733>, 0,
    <10736, 10733, 10735>, 0,
    <10740, 10729, 10727>, 0,
    <10740, 10727, 10735>, 0,
    <10740, 10735, 10733>, 0,
    <10740, 10733, 10738>, 0,
    <10740, 10738, 10737>, 0,
    <10740, 10737, 10739>, 0,
    <10740, 10739, 10728>, 0,
    <10740, 10728, 10729>, 0,
    <10744, 10743, 10741>, 0,
    <10744, 10741, 10742>, 0,
    <10744, 10742, 9929>, 0,
    <10744, 9929, 9930>, 0,
    <10744, 9930, 9885>, 0,
    <10744, 9885, 10730>, 0,
    <10744, 10730, 10728>, 0,
    <10744, 10728, 10743>, 0,
    <10748, 10747, 10741>, 0,
    <10748, 10741, 10743>, 0,
    <10748, 10743, 10728>, 0,
    <10748, 10728, 10739>, 0,
    <10748, 10739, 10737>, 0,
    <10748, 10737, 10746>, 0,
    <10748, 10746, 10745>, 0,
    <10748, 10745, 10747>, 0,
    <10750, 10742, 10741>, 0,
    <10750, 10741, 10747>, 0,
    <10750, 10747, 10745>, 0,
    <10750, 10745, 10749>, 0,
    <10750, 10749, 9933>, 0,
    <10750, 9933, 9934>, 0,
    <10750, 9934, 9929>, 0,
    <10750, 9929, 10742>, 0,
    <10759, 10758, 10751>, 0,
    <10759, 10751, 10755>, 0,
    <10759, 10755, 10752>, 0,
    <10759, 10752, 10756>, 0,
    <10759, 10756, 10753>, 0,
    <10759, 10753, 10757>, 0,
    <10759, 10757, 10754>, 0,
    <10759, 10754, 10758>, 0,
    <10762, 10761, 10751>, 0,
    <10762, 10751, 10758>, 0,
    <10762, 10758, 10754>, 0,
    <10762, 10754, 10760>, 0,
    <10762, 10760, 9949>, 0,
    <10762, 9949, 9994>, 0,
    <10762, 9994, 9992>, 0,
    <10762, 9992, 10761>, 0,
    <10764, 10755, 10751>, 0,
    <10764, 10751, 10761>, 0,
    <10764, 10761, 9992>, 0,
    <10764, 9992, 9999>, 0,
    <10764, 9999, 1719>, 0,
    <10764, 1719, 10763>, 0,
    <10764, 10763, 10752>, 0,
    <10764, 10752, 10755>, 0,
    <10770, 10769, 10765>, 0,
    <10770, 10765, 10767>, 0,
    <10770, 10767, 10766>, 0,
    <10770, 10766, 10768>, 0,
    <10770, 10768, 10705>, 0,
    <10770, 10705, 10708>, 0,
    <10770, 10708, 10704>, 0,
    <10770, 10704, 10769>, 0,
    <10772, 10771, 10765>, 0,
    <10772, 10765, 10769>, 0,
    <10772, 10769, 10704>, 0,
    <10772, 10704, 10715>, 0,
    <10772, 10715, 9949>, 0,
    <10772, 9949, 10760>, 0,
    <10772, 10760, 10754>, 0,
    <10772, 10754, 10771>, 0,
    <10774, 10767, 10765>, 0,
    <10774, 10765, 10771>, 0,
    <10774, 10771, 10754>, 0,
    <10774, 10754, 10757>, 0,
    <10774, 10757, 10753>, 0,
    <10774, 10753, 10773>, 0,
    <10774, 10773, 10766>, 0,
    <10774, 10766, 10767>, 0,
    <10780, 10779, 10775>, 0,
    <10780, 10775, 10777>, 0,
    <10780, 10777, 10776>, 0,
    <10780, 10776, 10778>, 0,
    <10780, 10778, 9933>, 0,
    <10780, 9933, 10749>, 0,
    <10780, 10749, 10745>, 0,
    <10780, 10745, 10779>, 0,
    <10784, 10783, 10775>, 0,
    <10784, 10775, 10779>, 0,
    <10784, 10779, 10745>, 0,
    <10784, 10745, 10746>, 0,
    <10784, 10746, 10737>, 0,
    <10784, 10737, 10782>, 0,
    <10784, 10782, 10781>, 0,
    <10784, 10781, 10783>, 0,
    <10787, 10777, 10775>, 0,
    <10787, 10775, 10783>, 0,
    <10787, 10783, 10781>, 0,
    <10787, 10781, 10785>, 0,
    <10787, 10785, 1924>, 0,
    <10787, 1924, 10786>, 0,
    <10787, 10786, 10776>, 0,
    <10787, 10776, 10777>, 0,
    <10791, 10790, 10788>, 0,
    <10791, 10788, 10789>, 0,
    <10791, 10789, 9977>, 0,
    <10791, 9977, 9978>, 0,
    <10791, 9978, 9933>, 0,
    <10791, 9933, 10778>, 0,
    <10791, 10778, 10776>, 0,
    <10791, 10776, 10790>, 0,
    <10793, 10792, 10788>, 0,
    <10793, 10788, 10790>, 0,
    <10793, 10790, 10776>, 0,
    <10793, 10776, 10786>, 0,
    <10793, 10786, 1924>, 0,
    <10793, 1924, 1955>, 0,
    <10793, 1955, 1951>, 0,
    <10793, 1951, 10792>, 0,
    <10794, 10789, 10788>, 0,
    <10794, 10788, 10792>, 0,
    <10794, 10792, 1951>, 0,
    <10794, 1951, 1952>, 0,
    <10794, 1952, 1693>, 0,
    <10794, 1693, 9981>, 0,
    <10794, 9981, 9977>, 0,
    <10794, 9977, 10789>, 0,
    <10800, 10799, 10795>, 0,
    <10800, 10795, 10797>, 0,
    <10800, 10797, 10796>, 0,
    <10800, 10796, 10798>, 0,
    <10800, 10798, 10753>, 0,
    <10800, 10753, 10756>, 0,
    <10800, 10756, 10752>, 0,
    <10800, 10752, 10799>, 0,
    <10802, 10801, 10795>, 0,
    <10802, 10795, 10799>, 0,
    <10802, 10799, 10752>, 0,
    <10802, 10752, 10763>, 0,
    <10802, 10763, 1719>, 0,
    <10802, 1719, 1969>, 0,
    <10802, 1969, 1964>, 0,
    <10802, 1964, 10801>, 0,
    <10804, 10797, 10795>, 0,
    <10804, 10795, 10801>, 0,
    <10804, 10801, 1964>, 0,
    <10804, 1964, 1966>, 0,
    <10804, 1966, 1963>, 0,
    <10804, 1963, 10803>, 0,
    <10804, 10803, 10796>, 0,
    <10804, 10796, 10797>, 0,
    <10813, 10812, 10805>, 0,
    <10813, 10805, 10809>, 0,
    <10813, 10809, 10806>, 0,
    <10813, 10806, 10810>, 0,
    <10813, 10810, 10807>, 0,
    <10813, 10807, 10811>, 0,
    <10813, 10811, 10808>, 0,
    <10813, 10808, 10812>, 0,
    <10816, 10815, 10805>, 0,
    <10816, 10805, 10812>, 0,
    <10816, 10812, 10808>, 0,
    <10816, 10808, 10814>, 0,
    <10816, 10814, 1813>, 0,
    <10816, 1813, 10057>, 0,
    <10816, 10057, 10052>, 0,
    <10816, 10052, 10815>, 0,
    <10818, 10809, 10805>, 0,
    <10818, 10805, 10815>, 0,
    <10818, 10815, 10052>, 0,
    <10818, 10052, 10054>, 0,
    <10818, 10054, 10051>, 0,
    <10818, 10051, 10817>, 0,
    <10818, 10817, 10806>, 0,
    <10818, 10806, 10809>, 0,
    <10827, 10826, 10819>, 0,
    <10827, 10819, 10823>, 0,
    <10827, 10823, 10820>, 0,
    <10827, 10820, 10824>, 0,
    <10827, 10824, 10821>, 0,
    <10827, 10821, 10825>, 0,
    <10827, 10825, 10822>, 0,
    <10827, 10822, 10826>, 0,
    <10830, 10829, 10819>, 0,
    <10830, 10819, 10826>, 0,
    <10830, 10826, 10822>, 0,
    <10830, 10822, 10828>, 0,
    <10830, 10828, 10089>, 0,
    <10830, 10089, 10132>, 0,
    <10830, 10132, 10127>, 0,
    <10830, 10127, 10829>, 0,
    <10832, 10823, 10819>, 0,
    <10832, 10819, 10829>, 0,
    <10832, 10829, 10127>, 0,
    <10832, 10127, 10129>, 0,
    <10832, 10129, 1872>, 0,
    <10832, 1872, 10831>, 0,
    <10832, 10831, 10820>, 0,
    <10832, 10820, 10823>, 0,
    <10841, 10840, 10833>, 0,
    <10841, 10833, 10837>, 0,
    <10841, 10837, 10834>, 0,
    <10841, 10834, 10838>, 0,
    <10841, 10838, 10835>, 0,
    <10841, 10835, 10839>, 0,
    <10841, 10839, 10836>, 0,
    <10841, 10836, 10840>, 0,
    <10844, 10843, 10833>, 0,
    <10844, 10833, 10840>, 0,
    <10844, 10840, 10836>, 0,
    <10844, 10836, 10842>, 0,
    <10844, 10842, 1847>, 0,
    <10844, 1847, 10252>, 0,
    <10844, 10252, 10250>, 0,
    <10844, 10250, 10843>, 0,
    <10846, 10837, 10833>, 0,
    <10846, 10833, 10843>, 0,
    <10846, 10843, 10250>, 0,
    <10846, 10250, 10257>, 0,
    <10846, 10257, 10237>, 0,
    <10846, 10237, 10845>, 0,
    <10846, 10845, 10834>, 0,
    <10846, 10834, 10837>, 0,
    <10855, 10854, 10847>, 0,
    <10855, 10847, 10851>, 0,
    <10855, 10851, 10848>, 0,
    <10855, 10848, 10852>, 0,
    <10855, 10852, 10849>, 0,
    <10855, 10849, 10853>, 0,
    <10855, 10853, 10850>, 0,
    <10855, 10850, 10854>, 0,
    <10858, 10857, 10847>, 0,
    <10858, 10847, 10854>, 0,
    <10858, 10854, 10850>, 0,
    <10858, 10850, 10856>, 0,
    <10858, 10856, 10173>, 0,
    <10858, 10173, 10191>, 0,
    <10858, 10191, 10186>, 0,
    <10858, 10186, 10857>, 0,
    <10860, 10851, 10847>, 0,
    <10860, 10847, 10857>, 0,
    <10860, 10857, 10186>, 0,
    <10860, 10186, 10188>, 0,
    <10860, 10188, 10089>, 0,
    <10860, 10089, 10859>, 0,
    <10860, 10859, 10848>, 0,
    <10860, 10848, 10851>, 0,
    <10866, 10865, 10861>, 0,
    <10866, 10861, 10863>, 0,
    <10866, 10863, 10822>, 0,
    <10866, 10822, 10825>, 0,
    <10866, 10825, 10821>, 0,
    <10866, 10821, 10864>, 0,
    <10866, 10864, 10862>, 0,
    <10866, 10862, 10865>, 0,
    <10869, 10868, 10861>, 0,
    <10869, 10861, 10865>, 0,
    <10869, 10865, 10862>, 0,
    <10869, 10862, 10867>, 0,
    <10869, 10867, 10849>, 0,
    <10869, 10849, 10852>, 0,
    <10869, 10852, 10848>, 0,
    <10869, 10848, 10868>, 0,
    <10870, 10863, 10861>, 0,
    <10870, 10861, 10868>, 0,
    <10870, 10868, 10848>, 0,
    <10870, 10848, 10859>, 0,
    <10870, 10859, 10089>, 0,
    <10870, 10089, 10828>, 0,
    <10870, 10828, 10822>, 0,
    <10870, 10822, 10863>, 0,
    <10876, 10875, 10871>, 0,
    <10876, 10871, 10873>, 0,
    <10876, 10873, 10862>, 0,
    <10876, 10862, 10864>, 0,
    <10876, 10864, 10821>, 0,
    <10876, 10821, 10874>, 0,
    <10876, 10874, 10872>, 0,
    <10876, 10872, 10875>, 0,
    <10881, 10880, 10871>, 0,
    <10881, 10871, 10875>, 0,
    <10881, 10875, 10872>, 0,
    <10881, 10872, 10878>, 0,
    <10881, 10878, 2163>, 0,
    <10881, 2163, 10879>, 0,
    <10881, 10879, 10877>, 0,
    <10881, 10877, 10880>, 0,
    <10883, 10873, 10871>, 0,
    <10883, 10871, 10880>, 0,
    <10883, 10880, 10877>, 0,
    <10883, 10877, 10882>, 0,
    <10883, 10882, 10849>, 0,
    <10883, 10849, 10867>, 0,
    <10883, 10867, 10862>, 0,
    <10883, 10862, 10873>, 0,
    <10891, 10890, 10884>, 0,
    <10891, 10884, 10887>, 0,
    <10891, 10887, 10885>, 0,
    <10891, 10885, 10888>, 0,
    <10891, 10888, 2149>, 0,
    <10891, 2149, 10889>, 0,
    <10891, 10889, 10886>, 0,
    <10891, 10886, 10890>, 0,
    <10894, 10893, 10884>, 0,
    <10894, 10884, 10890>, 0,
    <10894, 10890, 10886>, 0,
    <10894, 10886, 10892>, 0,
    <10894, 10892, 10835>, 0,
    <10894, 10835, 10838>, 0,
    <10894, 10838, 10834>, 0,
    <10894, 10834, 10893>, 0,
    <10896, 10887, 10884>, 0,
    <10896, 10884, 10893>, 0,
    <10896, 10893, 10834>, 0,
    <10896, 10834, 10845>, 0,
    <10896, 10845, 10237>, 0,
    <10896, 10237, 10895>, 0,
    <10896, 10895, 10885>, 0,
    <10896, 10885, 10887>, 0,
    <10905, 10904, 10897>, 0,
    <10905, 10897, 10901>, 0,
    <10905, 10901, 10898>, 0,
    <10905, 10898, 10902>, 0,
    <10905, 10902, 10899>, 0,
    <10905, 10899, 10903>, 0,
    <10905, 10903, 10900>, 0,
    <10905, 10900, 10904>, 0,
    <10908, 10907, 10897>, 0,
    <10908, 10897, 10904>, 0,
    <10908, 10904, 10900>, 0,
    <10908, 10900, 10906>, 0,
    <10908, 10906, 10285>, 0,
    <10908, 10285, 10303>, 0,
    <10908, 10303, 10298>, 0,
    <10908, 10298, 10907>, 0,
    <10910, 10901, 10897>, 0,
    <10910, 10897, 10907>, 0,
    <10910, 10907, 10298>, 0,
    <10910, 10298, 10300>, 0,
    <10910, 10300, 10173>, 0,
    <10910, 10173, 10909>, 0,
    <10910, 10909, 10898>, 0,
    <10910, 10898, 10901>, 0,
    <10916, 10915, 10911>, 0,
    <10916, 10911, 10913>, 0,
    <10916, 10913, 10850>, 0,
    <10916, 10850, 10853>, 0,
    <10916, 10853, 10849>, 0,
    <10916, 10849, 10914>, 0,
    <10916, 10914, 10912>, 0,
    <10916, 10912, 10915>, 0,
    <10919, 10918, 10911>, 0,
    <10919, 10911, 10915>, 0,
    <10919, 10915, 10912>, 0,
    <10919, 10912, 10917>, 0,
    <10919, 10917, 10899>, 0,
    <10919, 10899, 10902>, 0,
    <10919, 10902, 10898>, 0,
    <10919, 10898, 10918>, 0,
    <10920, 10913, 10911>, 0,
    <10920, 10911, 10918>, 0,
    <10920, 10918, 10898>, 0,
    <10920, 10898, 10909>, 0,
    <10920, 10909, 10173>, 0,
    <10920, 10173, 10856>, 0,
    <10920, 10856, 10850>, 0,
    <10920, 10850, 10913>, 0,
    <10929, 10928, 10921>, 0,
    <10929, 10921, 10925>, 0,
    <10929, 10925, 10922>, 0,
    <10929, 10922, 10926>, 0,
    <10929, 10926, 10923>, 0,
    <10929, 10923, 10927>, 0,
    <10929, 10927, 10924>, 0,
    <10929, 10924, 10928>, 0,
    <10932, 10931, 10921>, 0,
    <10932, 10921, 10928>, 0,
    <10932, 10928, 10924>, 0,
    <10932, 10924, 10930>, 0,
    <10932, 10930, 10237>, 0,
    <10932, 10237, 10348>, 0,
    <10932, 10348, 10346>, 0,
    <10932, 10346, 10931>, 0,
    <10934, 10925, 10921>, 0,
    <10934, 10921, 10931>, 0,
    <10934, 10931, 10346>, 0,
    <10934, 10346, 10353>, 0,
    <10934, 10353, 10333>, 0,
    <10934, 10333, 10933>, 0,
    <10934, 10933, 10922>, 0,
    <10934, 10922, 10925>, 0,
    <10940, 10939, 10935>, 0,
    <10940, 10935, 10937>, 0,
    <10940, 10937, 10936>, 0,
    <10940, 10936, 10938>, 0,
    <10940, 10938, 2149>, 0,
    <10940, 2149, 10888>, 0,
    <10940, 10888, 10885>, 0,
    <10940, 10885, 10939>, 0,
    <10942, 10941, 10935>, 0,
    <10942, 10935, 10939>, 0,
    <10942, 10939, 10885>, 0,
    <10942, 10885, 10895>, 0,
    <10942, 10895, 10237>, 0,
    <10942, 10237, 10930>, 0,
    <10942, 10930, 10924>, 0,
    <10942, 10924, 10941>, 0,
    <10944, 10937, 10935>, 0,
    <10944, 10935, 10941>, 0,
    <10944, 10941, 10924>, 0,
    <10944, 10924, 10927>, 0,
    <10944, 10927, 10923>, 0,
    <10944, 10923, 10943>, 0,
    <10944, 10943, 10936>, 0,
    <10944, 10936, 10937>, 0,
    <10953, 10952, 10945>, 0,
    <10953, 10945, 10949>, 0,
    <10953, 10949, 10946>, 0,
    <10953, 10946, 10950>, 0,
    <10953, 10950, 10947>, 0,
    <10953, 10947, 10951>, 0,
    <10953, 10951, 10948>, 0,
    <10953, 10948, 10952>, 0,
    <10956, 10955, 10945>, 0,
    <10956, 10945, 10952>, 0,
    <10956, 10952, 10948>, 0,
    <10956, 10948, 10954>, 0,
    <10956, 10954, 10381>, 0,
    <10956, 10381, 10399>, 0,
    <10956, 10399, 10394>, 0,
    <10956, 10394, 10955>, 0,
    <10958, 10949, 10945>, 0,
    <10958, 10945, 10955>, 0,
    <10958, 10955, 10394>, 0,
    <10958, 10394, 10396>, 0,
    <10958, 10396, 10285>, 0,
    <10958, 10285, 10957>, 0,
    <10958, 10957, 10946>, 0,
    <10958, 10946, 10949>, 0,
    <10964, 10963, 10959>, 0,
    <10964, 10959, 10961>, 0,
    <10964, 10961, 10900>, 0,
    <10964, 10900, 10903>, 0,
    <10964, 10903, 10899>, 0,
    <10964, 10899, 10962>, 0,
    <10964, 10962, 10960>, 0,
    <10964, 10960, 10963>, 0,
    <10967, 10966, 10959>, 0,
    <10967, 10959, 10963>, 0,
    <10967, 10963, 10960>, 0,
    <10967, 10960, 10965>, 0,
    <10967, 10965, 10947>, 0,
    <10967, 10947, 10950>, 0,
    <10967, 10950, 10946>, 0,
    <10967, 10946, 10966>, 0,
    <10968, 10961, 10959>, 0,
    <10968, 10959, 10966>, 0,
    <10968, 10966, 10946>, 0,
    <10968, 10946, 10957>, 0,
    <10968, 10957, 10285>, 0,
    <10968, 10285, 10906>, 0,
    <10968, 10906, 10900>, 0,
    <10968, 10900, 10961>, 0,
    <10977, 10976, 10969>, 0,
    <10977, 10969, 10973>, 0,
    <10977, 10973, 10970>, 0,
    <10977, 10970, 10974>, 0,
    <10977, 10974, 10971>, 0,
    <10977, 10971, 10975>, 0,
    <10977, 10975, 10972>, 0,
    <10977, 10972, 10976>, 0,
    <10980, 10979, 10969>, 0,
    <10980, 10969, 10976>, 0,
    <10980, 10976, 10972>, 0,
    <10980, 10972, 10978>, 0,
    <10980, 10978, 10333>, 0,
    <10980, 10333, 10444>, 0,
    <10980, 10444, 10442>, 0,
    <10980, 10442, 10979>, 0,
    <10982, 10973, 10969>, 0,
    <10982, 10969, 10979>, 0,
    <10982, 10979, 10442>, 0,
    <10982, 10442, 10449>, 0,
    <10982, 10449, 10429>, 0,
    <10982, 10429, 10981>, 0,
    <10982, 10981, 10970>, 0,
    <10982, 10970, 10973>, 0,
    <10988, 10987, 10983>, 0,
    <10988, 10983, 10985>, 0,
    <10988, 10985, 10984>, 0,
    <10988, 10984, 10986>, 0,
    <10988, 10986, 10923>, 0,
    <10988, 10923, 10926>, 0,
    <10988, 10926, 10922>, 0,
    <10988, 10922, 10987>, 0,
    <10990, 10989, 10983>, 0,
    <10990, 10983, 10987>, 0,
    <10990, 10987, 10922>, 0,
    <10990, 10922, 10933>, 0,
    <10990, 10933, 10333>, 0,
    <10990, 10333, 10978>, 0,
    <10990, 10978, 10972>, 0,
    <10990, 10972, 10989>, 0,
    <10992, 10985, 10983>, 0,
    <10992, 10983, 10989>, 0,
    <10992, 10989, 10972>, 0,
    <10992, 10972, 10975>, 0,
    <10992, 10975, 10971>, 0,
    <10992, 10971, 10991>, 0,
    <10992, 10991, 10984>, 0,
    <10992, 10984, 10985>, 0,
    <11001, 11000, 10993>, 0,
    <11001, 10993, 10997>, 0,
    <11001, 10997, 10994>, 0,
    <11001, 10994, 10998>, 0,
    <11001, 10998, 10995>, 0,
    <11001, 10995, 10999>, 0,
    <11001, 10999, 10996>, 0,
    <11001, 10996, 11000>, 0,
    <11004, 11003, 10993>, 0,
    <11004, 10993, 11000>, 0,
    <11004, 11000, 10996>, 0,
    <11004, 10996, 11002>, 0,
    <11004, 11002, 10477>, 0,
    <11004, 10477, 10495>, 0,
    <11004, 10495, 10490>, 0,
    <11004, 10490, 11003>, 0,
    <11006, 10997, 10993>, 0,
    <11006, 10993, 11003>, 0,
    <11006, 11003, 10490>, 0,
    <11006, 10490, 10492>, 0,
    <11006, 10492, 10381>, 0,
    <11006, 10381, 11005>, 0,
    <11006, 11005, 10994>, 0,
    <11006, 10994, 10997>, 0,
    <11012, 11011, 11007>, 0,
    <11012, 11007, 11009>, 0,
    <11012, 11009, 10948>, 0,
    <11012, 10948, 10951>, 0,
    <11012, 10951, 10947>, 0,
    <11012, 10947, 11010>, 0,
    <11012, 11010, 11008>, 0,
    <11012, 11008, 11011>, 0,
    <11015, 11014, 11007>, 0,
    <11015, 11007, 11011>, 0,
    <11015, 11011, 11008>, 0,
    <11015, 11008, 11013>, 0,
    <11015, 11013, 10995>, 0,
    <11015, 10995, 10998>, 0,
    <11015, 10998, 10994>, 0,
    <11015, 10994, 11014>, 0,
    <11016, 11009, 11007>, 0,
    <11016, 11007, 11014>, 0,
    <11016, 11014, 10994>, 0,
    <11016, 10994, 11005>, 0,
    <11016, 11005, 10381>, 0,
    <11016, 10381, 10954>, 0,
    <11016, 10954, 10948>, 0,
    <11016, 10948, 11009>, 0,
    <11025, 11024, 11017>, 0,
    <11025, 11017, 11021>, 0,
    <11025, 11021, 11018>, 0,
    <11025, 11018, 11022>, 0,
    <11025, 11022, 11019>, 0,
    <11025, 11019, 11023>, 0,
    <11025, 11023, 11020>, 0,
    <11025, 11020, 11024>, 0,
    <11028, 11027, 11017>, 0,
    <11028, 11017, 11024>, 0,
    <11028, 11024, 11020>, 0,
    <11028, 11020, 11026>, 0,
    <11028, 11026, 10429>, 0,
    <11028, 10429, 10588>, 0,
    <11028, 10588, 10586>, 0,
    <11028, 10586, 11027>, 0,
    <11030, 11021, 11017>, 0,
    <11030, 11017, 11027>, 0,
    <11030, 11027, 10586>, 0,
    <11030, 10586, 10593>, 0,
    <11030, 10593, 10573>, 0,
    <11030, 10573, 11029>, 0,
    <11030, 11029, 11018>, 0,
    <11030, 11018, 11021>, 0,
    <11036, 11035, 11031>, 0,
    <11036, 11031, 11033>, 0,
    <11036, 11033, 11032>, 0,
    <11036, 11032, 11034>, 0,
    <11036, 11034, 10971>, 0,
    <11036, 10971, 10974>, 0,
    <11036, 10974, 10970>, 0,
    <11036, 10970, 11035>, 0,
    <11038, 11037, 11031>, 0,
    <11038, 11031, 11035>, 0,
    <11038, 11035, 10970>, 0,
    <11038, 10970, 10981>, 0,
    <11038, 10981, 10429>, 0,
    <11038, 10429, 11026>, 0,
    <11038, 11026, 11020>, 0,
    <11038, 11020, 11037>, 0,
    <11040, 11033, 11031>, 0,
    <11040, 11031, 11037>, 0,
    <11040, 11037, 11020>, 0,
    <11040, 11020, 11023>, 0,
    <11040, 11023, 11019>, 0,
    <11040, 11019, 11039>, 0,
    <11040, 11039, 11032>, 0,
    <11040, 11032, 11033>, 0,
    <11049, 11048, 11041>, 0,
    <11049, 11041, 11045>, 0,
    <11049, 11045, 11042>, 0,
    <11049, 11042, 11046>, 0,
    <11049, 11046, 11043>, 0,
    <11049, 11043, 11047>, 0,
    <11049, 11047, 11044>, 0,
    <11049, 11044, 11048>, 0,
    <11052, 11051, 11041>, 0,
    <11052, 11041, 11048>, 0,
    <11052, 11048, 11044>, 0,
    <11052, 11044, 11050>, 0,
    <11052, 11050, 10525>, 0,
    <11052, 10525, 10543>, 0,
    <11052, 10543, 10538>, 0,
    <11052, 10538, 11051>, 0,
    <11054, 11045, 11041>, 0,
    <11054, 11041, 11051>, 0,
    <11054, 11051, 10538>, 0,
    <11054, 10538, 10540>, 0,
    <11054, 10540, 10477>, 0,
    <11054, 10477, 11053>, 0,
    <11054, 11053, 11042>, 0,
    <11054, 11042, 11045>, 0,
    <11060, 11059, 11055>, 0,
    <11060, 11055, 11057>, 0,
    <11060, 11057, 10996>, 0,
    <11060, 10996, 10999>, 0,
    <11060, 10999, 10995>, 0,
    <11060, 10995, 11058>, 0,
    <11060, 11058, 11056>, 0,
    <11060, 11056, 11059>, 0,
    <11063, 11062, 11055>, 0,
    <11063, 11055, 11059>, 0,
    <11063, 11059, 11056>, 0,
    <11063, 11056, 11061>, 0,
    <11063, 11061, 11043>, 0,
    <11063, 11043, 11046>, 0,
    <11063, 11046, 11042>, 0,
    <11063, 11042, 11062>, 0,
    <11064, 11057, 11055>, 0,
    <11064, 11055, 11062>, 0,
    <11064, 11062, 11042>, 0,
    <11064, 11042, 11053>, 0,
    <11064, 11053, 10477>, 0,
    <11064, 10477, 11002>, 0,
    <11064, 11002, 10996>, 0,
    <11064, 10996, 11057>, 0,
    <11073, 11072, 11065>, 0,
    <11073, 11065, 11069>, 0,
    <11073, 11069, 11066>, 0,
    <11073, 11066, 11070>, 0,
    <11073, 11070, 11067>, 0,
    <11073, 11067, 11071>, 0,
    <11073, 11071, 11068>, 0,
    <11073, 11068, 11072>, 0,
    <11076, 11075, 11065>, 0,
    <11076, 11065, 11072>, 0,
    <11076, 11072, 11068>, 0,
    <11076, 11068, 11074>, 0,
    <11076, 11074, 10621>, 0,
    <11076, 10621, 10639>, 0,
    <11076, 10639, 10634>, 0,
    <11076, 10634, 11075>, 0,
    <11078, 11069, 11065>, 0,
    <11078, 11065, 11075>, 0,
    <11078, 11075, 10634>, 0,
    <11078, 10634, 10636>, 0,
    <11078, 10636, 10525>, 0,
    <11078, 10525, 11077>, 0,
    <11078, 11077, 11066>, 0,
    <11078, 11066, 11069>, 0,
    <11084, 11083, 11079>, 0,
    <11084, 11079, 11081>, 0,
    <11084, 11081, 11044>, 0,
    <11084, 11044, 11047>, 0,
    <11084, 11047, 11043>, 0,
    <11084, 11043, 11082>, 0,
    <11084, 11082, 11080>, 0,
    <11084, 11080, 11083>, 0,
    <11087, 11086, 11079>, 0,
    <11087, 11079, 11083>, 0,
    <11087, 11083, 11080>, 0,
    <11087, 11080, 11085>, 0,
    <11087, 11085, 11067>, 0,
    <11087, 11067, 11070>, 0,
    <11087, 11070, 11066>, 0,
    <11087, 11066, 11086>, 0,
    <11088, 11081, 11079>, 0,
    <11088, 11079, 11086>, 0,
    <11088, 11086, 11066>, 0,
    <11088, 11066, 11077>, 0,
    <11088, 11077, 10525>, 0,
    <11088, 10525, 11050>, 0,
    <11088, 11050, 11044>, 0,
    <11088, 11044, 11081>, 0,
    <11097, 11096, 11089>, 0,
    <11097, 11089, 11093>, 0,
    <11097, 11093, 11090>, 0,
    <11097, 11090, 11094>, 0,
    <11097, 11094, 11091>, 0,
    <11097, 11091, 11095>, 0,
    <11097, 11095, 11092>, 0,
    <11097, 11092, 11096>, 0,
    <11100, 11099, 11089>, 0,
    <11100, 11089, 11096>, 0,
    <11100, 11096, 11092>, 0,
    <11100, 11092, 11098>, 0,
    <11100, 11098, 10573>, 0,
    <11100, 10573, 10720>, 0,
    <11100, 10720, 10718>, 0,
    <11100, 10718, 11099>, 0,
    <11102, 11093, 11089>, 0,
    <11102, 11089, 11099>, 0,
    <11102, 11099, 10718>, 0,
    <11102, 10718, 10725>, 0,
    <11102, 10725, 10705>, 0,
    <11102, 10705, 11101>, 0,
    <11102, 11101, 11090>, 0,
    <11102, 11090, 11093>, 0,
    <11108, 11107, 11103>, 0,
    <11108, 11103, 11105>, 0,
    <11108, 11105, 11104>, 0,
    <11108, 11104, 11106>, 0,
    <11108, 11106, 11019>, 0,
    <11108, 11019, 11022>, 0,
    <11108, 11022, 11018>, 0,
    <11108, 11018, 11107>, 0,
    <11110, 11109, 11103>, 0,
    <11110, 11103, 11107>, 0,
    <11110, 11107, 11018>, 0,
    <11110, 11018, 11029>, 0,
    <11110, 11029, 10573>, 0,
    <11110, 10573, 11098>, 0,
    <11110, 11098, 11092>, 0,
    <11110, 11092, 11109>, 0,
    <11112, 11105, 11103>, 0,
    <11112, 11103, 11109>, 0,
    <11112, 11109, 11092>, 0,
    <11112, 11092, 11095>, 0,
    <11112, 11095, 11091>, 0,
    <11112, 11091, 11111>, 0,
    <11112, 11111, 11104>, 0,
    <11112, 11104, 11105>, 0,
    <11121, 11120, 11113>, 0,
    <11121, 11113, 11117>, 0,
    <11121, 11117, 11114>, 0,
    <11121, 11114, 11118>, 0,
    <11121, 11118, 11115>, 0,
    <11121, 11115, 11119>, 0,
    <11121, 11119, 11116>, 0,
    <11121, 11116, 11120>, 0,
    <11124, 11123, 11113>, 0,
    <11124, 11113, 11120>, 0,
    <11124, 11120, 11116>, 0,
    <11124, 11116, 11122>, 0,
    <11124, 11122, 1987>, 0,
    <11124, 1987, 10673>, 0,
    <11124, 10673, 10667>, 0,
    <11124, 10667, 11123>, 0,
    <11126, 11117, 11113>, 0,
    <11126, 11113, 11123>, 0,
    <11126, 11123, 10667>, 0,
    <11126, 10667, 10669>, 0,
    <11126, 10669, 10621>, 0,
    <11126, 10621, 11125>, 0,
    <11126, 11125, 11114>, 0,
    <11126, 11114, 11117>, 0,
    <11132, 11131, 11127>, 0,
    <11132, 11127, 11129>, 0,
    <11132, 11129, 11068>, 0,
    <11132, 11068, 11071>, 0,
    <11132, 11071, 11067>, 0,
    <11132, 11067, 11130>, 0,
    <11132, 11130, 11128>, 0,
    <11132, 11128, 11131>, 0,
    <11135, 11134, 11127>, 0,
    <11135, 11127, 11131>, 0,
    <11135, 11131, 11128>, 0,
    <11135, 11128, 11133>, 0,
    <11135, 11133, 11115>, 0,
    <11135, 11115, 11118>, 0,
    <11135, 11118, 11114>, 0,
    <11135, 11114, 11134>, 0,
    <11136, 11129, 11127>, 0,
    <11136, 11127, 11134>, 0,
    <11136, 11134, 11114>, 0,
    <11136, 11114, 11125>, 0,
    <11136, 11125, 10621>, 0,
    <11136, 10621, 11074>, 0,
    <11136, 11074, 11068>, 0,
    <11136, 11068, 11129>, 0,
    <11142, 11141, 11137>, 0,
    <11142, 11137, 11139>, 0,
    <11142, 11139, 11116>, 0,
    <11142, 11116, 11119>, 0,
    <11142, 11119, 11115>, 0,
    <11142, 11115, 11140>, 0,
    <11142, 11140, 11138>, 0,
    <11142, 11138, 11141>, 0,
    <11147, 11146, 11137>, 0,
    <11147, 11137, 11141>, 0,
    <11147, 11141, 11138>, 0,
    <11147, 11138, 11144>, 0,
    <11147, 11144, 2127>, 0,
    <11147, 2127, 11145>, 0,
    <11147, 11145, 11143>, 0,
    <11147, 11143, 11146>, 0,
    <11149, 11139, 11137>, 0,
    <11149, 11137, 11146>, 0,
    <11149, 11146, 11143>, 0,
    <11149, 11143, 11148>, 0,
    <11149, 11148, 1987>, 0,
    <11149, 1987, 11122>, 0,
    <11149, 11122, 11116>, 0,
    <11149, 11116, 11139>, 0,
    <11158, 11157, 11150>, 0,
    <11158, 11150, 11154>, 0,
    <11158, 11154, 11151>, 0,
    <11158, 11151, 11155>, 0,
    <11158, 11155, 11152>, 0,
    <11158, 11152, 11156>, 0,
    <11158, 11156, 11153>, 0,
    <11158, 11153, 11157>, 0,
    <11161, 11160, 11150>, 0,
    <11161, 11150, 11157>, 0,
    <11161, 11157, 11153>, 0,
    <11161, 11153, 11159>, 0,
    <11161, 11159, 10705>, 0,
    <11161, 10705, 10768>, 0,
    <11161, 10768, 10766>, 0,
    <11161, 10766, 11160>, 0,
    <11163, 11154, 11150>, 0,
    <11163, 11150, 11160>, 0,
    <11163, 11160, 10766>, 0,
    <11163, 10766, 10773>, 0,
    <11163, 10773, 10753>, 0,
    <11163, 10753, 11162>, 0,
    <11163, 11162, 11151>, 0,
    <11163, 11151, 11154>, 0,
    <11169, 11168, 11164>, 0,
    <11169, 11164, 11166>, 0,
    <11169, 11166, 11165>, 0,
    <11169, 11165, 11167>, 0,
    <11169, 11167, 11091>, 0,
    <11169, 11091, 11094>, 0,
    <11169, 11094, 11090>, 0,
    <11169, 11090, 11168>, 0,
    <11171, 11170, 11164>, 0,
    <11171, 11164, 11168>, 0,
    <11171, 11168, 11090>, 0,
    <11171, 11090, 11101>, 0,
    <11171, 11101, 10705>, 0,
    <11171, 10705, 11159>, 0,
    <11171, 11159, 11153>, 0,
    <11171, 11153, 11170>, 0,
    <11173, 11166, 11164>, 0,
    <11173, 11164, 11170>, 0,
    <11173, 11170, 11153>, 0,
    <11173, 11153, 11156>, 0,
    <11173, 11156, 11152>, 0,
    <11173, 11152, 11172>, 0,
    <11173, 11172, 11165>, 0,
    <11173, 11165, 11166>, 0,
    <11182, 11181, 11174>, 0,
    <11182, 11174, 11178>, 0,
    <11182, 11178, 11175>, 0,
    <11182, 11175, 11179>, 0,
    <11182, 11179, 11176>, 0,
    <11182, 11176, 11180>, 0,
    <11182, 11180, 11177>, 0,
    <11182, 11177, 11181>, 0,
    <11185, 11184, 11174>, 0,
    <11185, 11174, 11181>, 0,
    <11185, 11181, 11177>, 0,
    <11185, 11177, 11183>, 0,
    <11185, 11183, 10753>, 0,
    <11185, 10753, 10798>, 0,
    <11185, 10798, 10796>, 0,
    <11185, 10796, 11184>, 0,
    <11187, 11178, 11174>, 0,
    <11187, 11174, 11184>, 0,
    <11187, 11184, 10796>, 0,
    <11187, 10796, 10803>, 0,
    <11187, 10803, 1963>, 0,
    <11187, 1963, 11186>, 0,
    <11187, 11186, 11175>, 0,
    <11187, 11175, 11178>, 0,
    <11193, 11192, 11188>, 0,
    <11193, 11188, 11190>, 0,
    <11193, 11190, 11189>, 0,
    <11193, 11189, 11191>, 0,
    <11193, 11191, 11152>, 0,
    <11193, 11152, 11155>, 0,
    <11193, 11155, 11151>, 0,
    <11193, 11151, 11192>, 0,
    <11195, 11194, 11188>, 0,
    <11195, 11188, 11192>, 0,
    <11195, 11192, 11151>, 0,
    <11195, 11151, 11162>, 0,
    <11195, 11162, 10753>, 0,
    <11195, 10753, 11183>, 0,
    <11195, 11183, 11177>, 0,
    <11195, 11177, 11194>, 0,
    <11197, 11190, 11188>, 0,
    <11197, 11188, 11194>, 0,
    <11197, 11194, 11177>, 0,
    <11197, 11177, 11180>, 0,
    <11197, 11180, 11176>, 0,
    <11197, 11176, 11196>, 0,
    <11197, 11196, 11189>, 0,
    <11197, 11189, 11190>, 0,
    <11203, 11202, 11198>, 0,
    <11203, 11198, 11200>, 0,
    <11203, 11200, 11199>, 0,
    <11203, 11199, 11201>, 0,
    <11203, 11201, 11176>, 0,
    <11203, 11176, 11179>, 0,
    <11203, 11179, 11175>, 0,
    <11203, 11175, 11202>, 0,
    <11205, 11204, 11198>, 0,
    <11205, 11198, 11202>, 0,
    <11205, 11202, 11175>, 0,
    <11205, 11175, 11186>, 0,
    <11205, 11186, 1963>, 0,
    <11205, 1963, 2123>, 0,
    <11205, 2123, 2118>, 0,
    <11205, 2118, 11204>, 0,
    <11207, 11200, 11198>, 0,
    <11207, 11198, 11204>, 0,
    <11207, 11204, 2118>, 0,
    <11207, 2118, 2120>, 0,
    <11207, 2120, 2117>, 0,
    <11207, 2117, 11206>, 0,
    <11207, 11206, 11199>, 0,
    <11207, 11199, 11200>, 0,
    <11213, 11212, 11208>, 0,
    <11213, 11208, 11210>, 0,
    <11213, 11210, 10781>, 0,
    <11213, 10781, 10782>, 0,
    <11213, 10782, 10737>, 0,
    <11213, 10737, 11211>, 0,
    <11213, 11211, 11209>, 0,
    <11213, 11209, 11212>, 0,
    <11216, 11215, 11208>, 0,
    <11216, 11208, 11212>, 0,
    <11216, 11212, 11209>, 0,
    <11216, 11209, 11214>, 0,
    <11216, 11214, 2091>, 0,
    <11216, 2091, 2109>, 0,
    <11216, 2109, 2105>, 0,
    <11216, 2105, 11215>, 0,
    <11217, 11210, 11208>, 0,
    <11217, 11208, 11215>, 0,
    <11217, 11215, 2105>, 0,
    <11217, 2105, 2106>, 0,
    <11217, 2106, 1924>, 0,
    <11217, 1924, 10785>, 0,
    <11217, 10785, 10781>, 0,
    <11217, 10781, 11210>, 0,
    <11223, 11222, 11218>, 0,
    <11223, 11218, 11220>, 0,
    <11223, 11220, 10733>, 0,
    <11223, 10733, 10734>, 0,
    <11223, 10734, 10689>, 0,
    <11223, 10689, 11221>, 0,
    <11223, 11221, 11219>, 0,
    <11223, 11219, 11222>, 0,
    <11229, 11228, 11218>, 0,
    <11229, 11218, 11222>, 0,
    <11229, 11222, 11219>, 0,
    <11229, 11219, 11226>, 0,
    <11229, 11226, 11224>, 0,
    <11229, 11224, 11227>, 0,
    <11229, 11227, 11225>, 0,
    <11229, 11225, 11228>, 0,
    <11231, 11220, 11218>, 0,
    <11231, 11218, 11228>, 0,
    <11231, 11228, 11225>, 0,
    <11231, 11225, 11230>, 0,
    <11231, 11230, 10737>, 0,
    <11231, 10737, 10738>, 0,
    <11231, 10738, 10733>, 0,
    <11231, 10733, 11220>, 0,
    <11235, 11234, 11232>, 0,
    <11235, 11232, 11233>, 0,
    <11235, 11233, 11209>, 0,
    <11235, 11209, 11211>, 0,
    <11235, 11211, 10737>, 0,
    <11235, 10737, 11230>, 0,
    <11235, 11230, 11225>, 0,
    <11235, 11225, 11234>, 0,
    <11239, 11238, 11232>, 0,
    <11239, 11232, 11234>, 0,
    <11239, 11234, 11225>, 0,
    <11239, 11225, 11227>, 0,
    <11239, 11227, 11224>, 0,
    <11239, 11224, 11237>, 0,
    <11239, 11237, 11236>, 0,
    <11239, 11236, 11238>, 0,
    <11241, 11233, 11232>, 0,
    <11241, 11232, 11238>, 0,
    <11241, 11238, 11236>, 0,
    <11241, 11236, 11240>, 0,
    <11241, 11240, 2091>, 0,
    <11241, 2091, 11214>, 0,
    <11241, 11214, 11209>, 0,
    <11241, 11209, 11233>, 0,
    <11247, 11246, 11242>, 0,
    <11247, 11242, 11244>, 0,
    <11247, 11244, 10685>, 0,
    <11247, 10685, 10686>, 0,
    <11247, 10686, 10557>, 0,
    <11247, 10557, 11245>, 0,
    <11247, 11245, 11243>, 0,
    <11247, 11243, 11246>, 0,
    <11253, 11252, 11242>, 0,
    <11253, 11242, 11246>, 0,
    <11253, 11246, 11243>, 0,
    <11253, 11243, 11250>, 0,
    <11253, 11250, 11248>, 0,
    <11253, 11248, 11251>, 0,
    <11253, 11251, 11249>, 0,
    <11253, 11249, 11252>, 0,
    <11255, 11244, 11242>, 0,
    <11255, 11242, 11252>, 0,
    <11255, 11252, 11249>, 0,
    <11255, 11249, 11254>, 0,
    <11255, 11254, 10689>, 0,
    <11255, 10689, 10690>, 0,
    <11255, 10690, 10685>, 0,
    <11255, 10685, 11244>, 0,
    <11259, 11258, 11256>, 0,
    <11259, 11256, 11257>, 0,
    <11259, 11257, 11219>, 0,
    <11259, 11219, 11221>, 0,
    <11259, 11221, 10689>, 0,
    <11259, 10689, 11254>, 0,
    <11259, 11254, 11249>, 0,
    <11259, 11249, 11258>, 0,
    <11263, 11262, 11256>, 0,
    <11263, 11256, 11258>, 0,
    <11263, 11258, 11249>, 0,
    <11263, 11249, 11251>, 0,
    <11263, 11251, 11248>, 0,
    <11263, 11248, 11261>, 0,
    <11263, 11261, 11260>, 0,
    <11263, 11260, 11262>, 0,
    <11265, 11257, 11256>, 0,
    <11265, 11256, 11262>, 0,
    <11265, 11262, 11260>, 0,
    <11265, 11260, 11264>, 0,
    <11265, 11264, 11224>, 0,
    <11265, 11224, 11226>, 0,
    <11265, 11226, 11219>, 0,
    <11265, 11219, 11257>, 0,
    <11271, 11270, 11266>, 0,
    <11271, 11266, 11268>, 0,
    <11271, 11268, 11267>, 0,
    <11271, 11267, 11269>, 0,
    <11271, 11269, 10601>, 0,
    <11271, 10601, 10654>, 0,
    <11271, 10654, 10649>, 0,
    <11271, 10649, 11270>, 0,
    <11273, 11272, 11266>, 0,
    <11273, 11266, 11270>, 0,
    <11273, 11270, 10649>, 0,
    <11273, 10649, 10651>, 0,
    <11273, 10651, 1930>, 0,
    <11273, 1930, 2087>, 0,
    <11273, 2087, 2084>, 0,
    <11273, 2084, 11272>, 0,
    <11275, 11268, 11266>, 0,
    <11275, 11266, 11272>, 0,
    <11275, 11272, 2084>, 0,
    <11275, 2084, 2099>, 0,
    <11275, 2099, 2097>, 0,
    <11275, 2097, 11274>, 0,
    <11275, 11274, 11267>, 0,
    <11275, 11267, 11268>, 0,
    <11281, 11280, 11276>, 0,
    <11281, 11276, 11278>, 0,
    <11281, 11278, 11277>, 0,
    <11281, 11277, 11279>, 0,
    <11281, 11279, 10505>, 0,
    <11281, 10505, 10607>, 0,
    <11281, 10607, 10602>, 0,
    <11281, 10602, 11280>, 0,
    <11285, 11284, 11276>, 0,
    <11285, 11276, 11280>, 0,
    <11285, 11280, 10602>, 0,
    <11285, 10602, 10604>, 0,
    <11285, 10604, 10601>, 0,
    <11285, 10601, 11283>, 0,
    <11285, 11283, 11282>, 0,
    <11285, 11282, 11284>, 0,
    <11289, 11278, 11276>, 0,
    <11289, 11276, 11284>, 0,
    <11289, 11284, 11282>, 0,
    <11289, 11282, 11287>, 0,
    <11289, 11287, 11286>, 0,
    <11289, 11286, 11288>, 0,
    <11289, 11288, 11277>, 0,
    <11289, 11277, 11278>, 0,
    <11293, 11292, 11290>, 0,
    <11293, 11290, 11291>, 0,
    <11293, 11291, 11282>, 0,
    <11293, 11282, 11283>, 0,
    <11293, 11283, 10601>, 0,
    <11293, 10601, 11269>, 0,
    <11293, 11269, 11267>, 0,
    <11293, 11267, 11292>, 0,
    <11297, 11296, 11290>, 0,
    <11297, 11290, 11292>, 0,
    <11297, 11292, 11267>, 0,
    <11297, 11267, 11274>, 0,
    <11297, 11274, 2097>, 0,
    <11297, 2097, 11295>, 0,
    <11297, 11295, 11294>, 0,
    <11297, 11294, 11296>, 0,
    <11299, 11291, 11290>, 0,
    <11299, 11290, 11296>, 0,
    <11299, 11296, 11294>, 0,
    <11299, 11294, 11298>, 0,
    <11299, 11298, 11286>, 0,
    <11299, 11286, 11287>, 0,
    <11299, 11287, 11282>, 0,
    <11299, 11282, 11291>, 0,
    <11305, 11304, 11300>, 0,
    <11305, 11300, 11302>, 0,
    <11305, 11302, 10553>, 0,
    <11305, 10553, 10554>, 0,
    <11305, 10554, 10413>, 0,
    <11305, 10413, 11303>, 0,
    <11305, 11303, 11301>, 0,
    <11305, 11301, 11304>, 0,
    <11311, 11310, 11300>, 0,
    <11311, 11300, 11304>, 0,
    <11311, 11304, 11301>, 0,
    <11311, 11301, 11308>, 0,
    <11311, 11308, 11306>, 0,
    <11311, 11306, 11309>, 0,
    <11311, 11309, 11307>, 0,
    <11311, 11307, 11310>, 0,
    <11313, 11302, 11300>, 0,
    <11313, 11300, 11310>, 0,
    <11313, 11310, 11307>, 0,
    <11313, 11307, 11312>, 0,
    <11313, 11312, 10557>, 0,
    <11313, 10557, 10558>, 0,
    <11313, 10558, 10553>, 0,
    <11313, 10553, 11302>, 0,
    <11317, 11316, 11314>, 0,
    <11317, 11314, 11315>, 0,
    <11317, 11315, 11243>, 0,
    <11317, 11243, 11245>, 0,
    <11317, 11245, 10557>, 0,
    <11317, 10557, 11312>, 0,
    <11317, 11312, 11307>, 0,
    <11317, 11307, 11316>, 0,
    <11321, 11320, 11314>, 0,
    <11321, 11314, 11316>, 0,
    <11321, 11316, 11307>, 0,
    <11321, 11307, 11309>, 0,
    <11321, 11309, 11306>, 0,
    <11321, 11306, 11319>, 0,
    <11321, 11319, 11318>, 0,
    <11321, 11318, 11320>, 0,
    <11323, 11315, 11314>, 0,
    <11323, 11314, 11320>, 0,
    <11323, 11320, 11318>, 0,
    <11323, 11318, 11322>, 0,
    <11323, 11322, 11248>, 0,
    <11323, 11248, 11250>, 0,
    <11323, 11250, 11243>, 0,
    <11323, 11243, 11315>, 0,
    <11329, 11328, 11324>, 0,
    <11329, 11324, 11326>, 0,
    <11329, 11326, 11325>, 0,
    <11329, 11325, 11327>, 0,
    <11329, 11327, 10457>, 0,
    <11329, 10457, 10511>, 0,
    <11329, 10511, 10506>, 0,
    <11329, 10506, 11328>, 0,
    <11333, 11332, 11324>, 0,
    <11333, 11324, 11328>, 0,
    <11333, 11328, 10506>, 0,
    <11333, 10506, 10508>, 0,
    <11333, 10508, 10505>, 0,
    <11333, 10505, 11331>, 0,
    <11333, 11331, 11330>, 0,
    <11333, 11330, 11332>, 0,
    <11337, 11326, 11324>, 0,
    <11337, 11324, 11332>, 0,
    <11337, 11332, 11330>, 0,
    <11337, 11330, 11335>, 0,
    <11337, 11335, 11334>, 0,
    <11337, 11334, 11336>, 0,
    <11337, 11336, 11325>, 0,
    <11337, 11325, 11326>, 0,
    <11341, 11340, 11338>, 0,
    <11341, 11338, 11339>, 0,
    <11341, 11339, 11330>, 0,
    <11341, 11330, 11331>, 0,
    <11341, 11331, 10505>, 0,
    <11341, 10505, 11279>, 0,
    <11341, 11279, 11277>, 0,
    <11341, 11277, 11340>, 0,
    <11345, 11344, 11338>, 0,
    <11345, 11338, 11340>, 0,
    <11345, 11340, 11277>, 0,
    <11345, 11277, 11288>, 0,
    <11345, 11288, 11286>, 0,
    <11345, 11286, 11343>, 0,
    <11345, 11343, 11342>, 0,
    <11345, 11342, 11344>, 0,
    <11347, 11339, 11338>, 0,
    <11347, 11338, 11344>, 0,
    <11347, 11344, 11342>, 0,
    <11347, 11342, 11346>, 0,
    <11347, 11346, 11334>, 0,
    <11347, 11334, 11335>, 0,
    <11347, 11335, 11330>, 0,
    <11347, 11330, 11339>, 0,
    <11353, 11352, 11348>, 0,
    <11353, 11348, 11350>, 0,
    <11353, 11350, 11349>, 0,
    <11353, 11349, 11351>, 0,
    <11353, 11351, 10361>, 0,
    <11353, 10361, 10463>, 0,
    <11353, 10463, 10458>, 0,
    <11353, 10458, 11352>, 0,
    <11357, 11356, 11348>, 0,
    <11357, 11348, 11352>, 0,
    <11357, 11352, 10458>, 0,
    <11357, 10458, 10460>, 0,
    <11357, 10460, 10457>, 0,
    <11357, 10457, 11355>, 0,
    <11357, 11355, 11354>, 0,
    <11357, 11354, 11356>, 0,
    <11361, 11350, 11348>, 0,
    <11361, 11348, 11356>, 0,
    <11361, 11356, 11354>, 0,
    <11361, 11354, 11359>, 0,
    <11361, 11359, 11358>, 0,
    <11361, 11358, 11360>, 0,
    <11361, 11360, 11349>, 0,
    <11361, 11349, 11350>, 0,
    <11365, 11364, 11362>, 0,
    <11365, 11362, 11363>, 0,
    <11365, 11363, 11354>, 0,
    <11365, 11354, 11355>, 0,
    <11365, 11355, 10457>, 0,
    <11365, 10457, 11327>, 0,
    <11365, 11327, 11325>, 0,
    <11365, 11325, 11364>, 0,
    <11369, 11368, 11362>, 0,
    <11369, 11362, 11364>, 0,
    <11369, 11364, 11325>, 0,
    <11369, 11325, 11336>, 0,
    <11369, 11336, 11334>, 0,
    <11369, 11334, 11367>, 0,
    <11369, 11367, 11366>, 0,
    <11369, 11366, 11368>, 0,
    <11371, 11363, 11362>, 0,
    <11371, 11362, 11368>, 0,
    <11371, 11368, 11366>, 0,
    <11371, 11366, 11370>, 0,
    <11371, 11370, 11358>, 0,
    <11371, 11358, 11359>, 0,
    <11371, 11359, 11354>, 0,
    <11371, 11354, 11363>, 0,
    <11377, 11376, 11372>, 0,
    <11377, 11372, 11374>, 0,
    <11377, 11374, 10409>, 0,
    <11377, 10409, 10410>, 0,
    <11377, 10410, 10317>, 0,
    <11377, 10317, 11375>, 0,
    <11377, 11375, 11373>, 0,
    <11377, 11373, 11376>, 0,
    <11383, 11382, 11372>, 0,
    <11383, 11372, 11376>, 0,
    <11383, 11376, 11373>, 0,
    <11383, 11373, 11380>, 0,
    <11383, 11380, 11378>, 0,
    <11383, 11378, 11381>, 0,
    <11383, 11381, 11379>, 0,
    <11383, 11379, 11382>, 0,
    <11385, 11374, 11372>, 0,
    <11385, 11372, 11382>, 0,
    <11385, 11382, 11379>, 0,
    <11385, 11379, 11384>, 0,
    <11385, 11384, 10413>, 0,
    <11385, 10413, 10414>, 0,
    <11385, 10414, 10409>, 0,
    <11385, 10409, 11374>, 0,
    <11389, 11388, 11386>, 0,
    <11389, 11386, 11387>, 0,
    <11389, 11387, 11301>, 0,
    <11389, 11301, 11303>, 0,
    <11389, 11303, 10413>, 0,
    <11389, 10413, 11384>, 0,
    <11389, 11384, 11379>, 0,
    <11389, 11379, 11388>, 0,
    <11393, 11392, 11386>, 0,
    <11393, 11386, 11388>, 0,
    <11393, 11388, 11379>, 0,
    <11393, 11379, 11381>, 0,
    <11393, 11381, 11378>, 0,
    <11393, 11378, 11391>, 0,
    <11393, 11391, 11390>, 0,
    <11393, 11390, 11392>, 0,
    <11395, 11387, 11386>, 0,
    <11395, 11386, 11392>, 0,
    <11395, 11392, 11390>, 0,
    <11395, 11390, 11394>, 0,
    <11395, 11394, 11306>, 0,
    <11395, 11306, 11308>, 0,
    <11395, 11308, 11301>, 0,
    <11395, 11301, 11387>, 0,
    <11401, 11400, 11396>, 0,
    <11401, 11396, 11398>, 0,
    <11401, 11398, 11397>, 0,
    <11401, 11397, 11399>, 0,
    <11401, 11399, 10265>, 0,
    <11401, 10265, 10367>, 0,
    <11401, 10367, 10362>, 0,
    <11401, 10362, 11400>, 0,
    <11405, 11404, 11396>, 0,
    <11405, 11396, 11400>, 0,
    <11405, 11400, 10362>, 0,
    <11405, 10362, 10364>, 0,
    <11405, 10364, 10361>, 0,
    <11405, 10361, 11403>, 0,
    <11405, 11403, 11402>, 0,
    <11405, 11402, 11404>, 0,
    <11409, 11398, 11396>, 0,
    <11409, 11396, 11404>, 0,
    <11409, 11404, 11402>, 0,
    <11409, 11402, 11407>, 0,
    <11409, 11407, 11406>, 0,
    <11409, 11406, 11408>, 0,
    <11409, 11408, 11397>, 0,
    <11409, 11397, 11398>, 0,
    <11413, 11412, 11410>, 0,
    <11413, 11410, 11411>, 0,
    <11413, 11411, 11402>, 0,
    <11413, 11402, 11403>, 0,
    <11413, 11403, 10361>, 0,
    <11413, 10361, 11351>, 0,
    <11413, 11351, 11349>, 0,
    <11413, 11349, 11412>, 0,
    <11417, 11416, 11410>, 0,
    <11417, 11410, 11412>, 0,
    <11417, 11412, 11349>, 0,
    <11417, 11349, 11360>, 0,
    <11417, 11360, 11358>, 0,
    <11417, 11358, 11415>, 0,
    <11417, 11415, 11414>, 0,
    <11417, 11414, 11416>, 0,
    <11419, 11411, 11410>, 0,
    <11419, 11410, 11416>, 0,
    <11419, 11416, 11414>, 0,
    <11419, 11414, 11418>, 0,
    <11419, 11418, 11406>, 0,
    <11419, 11406, 11407>, 0,
    <11419, 11407, 11402>, 0,
    <11419, 11402, 11411>, 0,
    <11425, 11424, 11420>, 0,
    <11425, 11420, 11422>, 0,
    <11425, 11422, 10313>, 0,
    <11425, 10313, 10314>, 0,
    <11425, 10314, 10208>, 0,
    <11425, 10208, 11423>, 0,
    <11425, 11423, 11421>, 0,
    <11425, 11421, 11424>, 0,
    <11431, 11430, 11420>, 0,
    <11431, 11420, 11424>, 0,
    <11431, 11424, 11421>, 0,
    <11431, 11421, 11428>, 0,
    <11431, 11428, 11426>, 0,
    <11431, 11426, 11429>, 0,
    <11431, 11429, 11427>, 0,
    <11431, 11427, 11430>, 0,
    <11433, 11422, 11420>, 0,
    <11433, 11420, 11430>, 0,
    <11433, 11430, 11427>, 0,
    <11433, 11427, 11432>, 0,
    <11433, 11432, 10317>, 0,
    <11433, 10317, 10318>, 0,
    <11433, 10318, 10313>, 0,
    <11433, 10313, 11422>, 0,
    <11437, 11436, 11434>, 0,
    <11437, 11434, 11435>, 0,
    <11437, 11435, 11373>, 0,
    <11437, 11373, 11375>, 0,
    <11437, 11375, 10317>, 0,
    <11437, 10317, 11432>, 0,
    <11437, 11432, 11427>, 0,
    <11437, 11427, 11436>, 0,
    <11441, 11440, 11434>, 0,
    <11441, 11434, 11436>, 0,
    <11441, 11436, 11427>, 0,
    <11441, 11427, 11429>, 0,
    <11441, 11429, 11426>, 0,
    <11441, 11426, 11439>, 0,
    <11441, 11439, 11438>, 0,
    <11441, 11438, 11440>, 0,
    <11443, 11435, 11434>, 0,
    <11443, 11434, 11440>, 0,
    <11443, 11440, 11438>, 0,
    <11443, 11438, 11442>, 0,
    <11443, 11442, 11378>, 0,
    <11443, 11378, 11380>, 0,
    <11443, 11380, 11373>, 0,
    <11443, 11373, 11435>, 0,
    <11449, 11448, 11444>, 0,
    <11449, 11444, 11446>, 0,
    <11449, 11446, 11445>, 0,
    <11449, 11445, 11447>, 0,
    <11449, 11447, 10153>, 0,
    <11449, 10153, 10271>, 0,
    <11449, 10271, 10266>, 0,
    <11449, 10266, 11448>, 0,
    <11453, 11452, 11444>, 0,
    <11453, 11444, 11448>, 0,
    <11453, 11448, 10266>, 0,
    <11453, 10266, 10268>, 0,
    <11453, 10268, 10265>, 0,
    <11453, 10265, 11451>, 0,
    <11453, 11451, 11450>, 0,
    <11453, 11450, 11452>, 0,
    <11457, 11446, 11444>, 0,
    <11457, 11444, 11452>, 0,
    <11457, 11452, 11450>, 0,
    <11457, 11450, 11455>, 0,
    <11457, 11455, 11454>, 0,
    <11457, 11454, 11456>, 0,
    <11457, 11456, 11445>, 0,
    <11457, 11445, 11446>, 0,
    <11461, 11460, 11458>, 0,
    <11461, 11458, 11459>, 0,
    <11461, 11459, 11450>, 0,
    <11461, 11450, 11451>, 0,
    <11461, 11451, 10265>, 0,
    <11461, 10265, 11399>, 0,
    <11461, 11399, 11397>, 0,
    <11461, 11397, 11460>, 0,
    <11465, 11464, 11458>, 0,
    <11465, 11458, 11460>, 0,
    <11465, 11460, 11397>, 0,
    <11465, 11397, 11408>, 0,
    <11465, 11408, 11406>, 0,
    <11465, 11406, 11463>, 0,
    <11465, 11463, 11462>, 0,
    <11465, 11462, 11464>, 0,
    <11467, 11459, 11458>, 0,
    <11467, 11458, 11464>, 0,
    <11467, 11464, 11462>, 0,
    <11467, 11462, 11466>, 0,
    <11467, 11466, 11454>, 0,
    <11467, 11454, 11455>, 0,
    <11467, 11455, 11450>, 0,
    <11467, 11450, 11459>, 0,
    <11475, 11474, 11468>, 0,
    <11475, 11468, 11471>, 0,
    <11475, 11471, 11469>, 0,
    <11475, 11469, 11472>, 0,
    <11475, 11472, 1820>, 0,
    <11475, 1820, 11473>, 0,
    <11475, 11473, 11470>, 0,
    <11475, 11470, 11474>, 0,
    <11481, 11480, 11468>, 0,
    <11481, 11468, 11474>, 0,
    <11481, 11474, 11470>, 0,
    <11481, 11470, 11478>, 0,
    <11481, 11478, 11476>, 0,
    <11481, 11476, 11479>, 0,
    <11481, 11479, 11477>, 0,
    <11481, 11477, 11480>, 0,
    <11485, 11471, 11468>, 0,
    <11485, 11468, 11480>, 0,
    <11485, 11480, 11477>, 0,
    <11485, 11477, 11483>, 0,
    <11485, 11483, 11482>, 0,
    <11485, 11482, 11484>, 0,
    <11485, 11484, 11469>, 0,
    <11485, 11469, 11471>, 0,
    <11489, 11488, 11486>, 0,
    <11489, 11486, 11487>, 0,
    <11489, 11487, 10203>, 0,
    <11489, 10203, 10205>, 0,
    <11489, 10205, 1820>, 0,
    <11489, 1820, 11472>, 0,
    <11489, 11472, 11469>, 0,
    <11489, 11469, 11488>, 0,
    <11493, 11492, 11486>, 0,
    <11493, 11486, 11488>, 0,
    <11493, 11488, 11469>, 0,
    <11493, 11469, 11484>, 0,
    <11493, 11484, 11482>, 0,
    <11493, 11482, 11491>, 0,
    <11493, 11491, 11490>, 0,
    <11493, 11490, 11492>, 0,
    <11495, 11487, 11486>, 0,
    <11495, 11486, 11492>, 0,
    <11495, 11492, 11490>, 0,
    <11495, 11490, 11494>, 0,
    <11495, 11494, 10208>, 0,
    <11495, 10208, 10209>, 0,
    <11495, 10209, 10203>, 0,
    <11495, 10203, 11487>, 0,
    <11499, 11498, 11496>, 0,
    <11499, 11496, 11497>, 0,
    <11499, 11497, 11421>, 0,
    <11499, 11421, 11423>, 0,
    <11499, 11423, 10208>, 0,
    <11499, 10208, 11494>, 0,
    <11499, 11494, 11490>, 0,
    <11499, 11490, 11498>, 0,
    <11503, 11502, 11496>, 0,
    <11503, 11496, 11498>, 0,
    <11503, 11498, 11490>, 0,
    <11503, 11490, 11491>, 0,
    <11503, 11491, 11482>, 0,
    <11503, 11482, 11501>, 0,
    <11503, 11501, 11500>, 0,
    <11503, 11500, 11502>, 0,
    <11505, 11497, 11496>, 0,
    <11505, 11496, 11502>, 0,
    <11505, 11502, 11500>, 0,
    <11505, 11500, 11504>, 0,
    <11505, 11504, 11426>, 0,
    <11505, 11426, 11428>, 0,
    <11505, 11428, 11421>, 0,
    <11505, 11421, 11497>, 0,
    <11511, 11510, 11506>, 0,
    <11511, 11506, 11508>, 0,
    <11511, 11508, 11507>, 0,
    <11511, 11507, 11509>, 0,
    <11511, 11509, 10051>, 0,
    <11511, 10051, 10159>, 0,
    <11511, 10159, 10154>, 0,
    <11511, 10154, 11510>, 0,
    <11515, 11514, 11506>, 0,
    <11515, 11506, 11510>, 0,
    <11515, 11510, 10154>, 0,
    <11515, 10154, 10156>, 0,
    <11515, 10156, 10153>, 0,
    <11515, 10153, 11513>, 0,
    <11515, 11513, 11512>, 0,
    <11515, 11512, 11514>, 0,
    <11519, 11508, 11506>, 0,
    <11519, 11506, 11514>, 0,
    <11519, 11514, 11512>, 0,
    <11519, 11512, 11517>, 0,
    <11519, 11517, 11516>, 0,
    <11519, 11516, 11518>, 0,
    <11519, 11518, 11507>, 0,
    <11519, 11507, 11508>, 0,
    <11523, 11522, 11520>, 0,
    <11523, 11520, 11521>, 0,
    <11523, 11521, 11512>, 0,
    <11523, 11512, 11513>, 0,
    <11523, 11513, 10153>, 0,
    <11523, 10153, 11447>, 0,
    <11523, 11447, 11445>, 0,
    <11523, 11445, 11522>, 0,
    <11527, 11526, 11520>, 0,
    <11527, 11520, 11522>, 0,
    <11527, 11522, 11445>, 0,
    <11527, 11445, 11456>, 0,
    <11527, 11456, 11454>, 0,
    <11527, 11454, 11525>, 0,
    <11527, 11525, 11524>, 0,
    <11527, 11524, 11526>, 0,
    <11529, 11521, 11520>, 0,
    <11529, 11520, 11526>, 0,
    <11529, 11526, 11524>, 0,
    <11529, 11524, 11528>, 0,
    <11529, 11528, 11516>, 0,
    <11529, 11516, 11517>, 0,
    <11529, 11517, 11512>, 0,
    <11529, 11512, 11521>, 0,
    <11535, 11534, 11530>, 0,
    <11535, 11530, 11532>, 0,
    <11535, 11532, 11477>, 0,
    <11535, 11477, 11479>, 0,
    <11535, 11479, 11476>, 0,
    <11535, 11476, 11533>, 0,
    <11535, 11533, 11531>, 0,
    <11535, 11531, 11534>, 0,
    <11540, 11539, 11530>, 0,
    <11540, 11530, 11534>, 0,
    <11540, 11534, 11531>, 0,
    <11540, 11531, 11537>, 0,
    <11540, 11537, 2064>, 0,
    <11540, 2064, 11538>, 0,
    <11540, 11538, 11536>, 0,
    <11540, 11536, 11539>, 0,
    <11542, 11532, 11530>, 0,
    <11542, 11530, 11539>, 0,
    <11542, 11539, 11536>, 0,
    <11542, 11536, 11541>, 0,
    <11542, 11541, 11482>, 0,
    <11542, 11482, 11483>, 0,
    <11542, 11483, 11477>, 0,
    <11542, 11477, 11532>, 0,
    <11551, 11550, 11543>, 0,
    <11551, 11543, 11547>, 0,
    <11551, 11547, 11544>, 0,
    <11551, 11544, 11548>, 0,
    <11551, 11548, 11545>, 0,
    <11551, 11545, 11549>, 0,
    <11551, 11549, 11546>, 0,
    <11551, 11546, 11550>, 0,
    <11556, 11555, 11543>, 0,
    <11556, 11543, 11550>, 0,
    <11556, 11550, 11546>, 0,
    <11556, 11546, 11553>, 0,
    <11556, 11553, 10807>, 0,
    <11556, 10807, 11554>, 0,
    <11556, 11554, 11552>, 0,
    <11556, 11552, 11555>, 0,
    <11560, 11547, 11543>, 0,
    <11560, 11543, 11555>, 0,
    <11560, 11555, 11552>, 0,
    <11560, 11552, 11558>, 0,
    <11560, 11558, 11557>, 0,
    <11560, 11557, 11559>, 0,
    <11560, 11559, 11544>, 0,
    <11560, 11544, 11547>, 0,
    <11564, 11563, 11561>, 0,
    <11564, 11561, 11562>, 0,
    <11564, 11562, 11552>, 0,
    <11564, 11552, 11554>, 0,
    <11564, 11554, 10807>, 0,
    <11564, 10807, 10810>, 0,
    <11564, 10810, 10806>, 0,
    <11564, 10806, 11563>, 0,
    <11568, 11567, 11561>, 0,
    <11568, 11561, 11563>, 0,
    <11568, 11563, 10806>, 0,
    <11568, 10806, 10817>, 0,
    <11568, 10817, 10051>, 0,
    <11568, 10051, 11566>, 0,
    <11568, 11566, 11565>, 0,
    <11568, 11565, 11567>, 0,
    <11570, 11562, 11561>, 0,
    <11570, 11561, 11567>, 0,
    <11570, 11567, 11565>, 0,
    <11570, 11565, 11569>, 0,
    <11570, 11569, 11557>, 0,
    <11570, 11557, 11558>, 0,
    <11570, 11558, 11552>, 0,
    <11570, 11552, 11562>, 0,
    <11574, 11573, 11571>, 0,
    <11574, 11571, 11572>, 0,
    <11574, 11572, 11565>, 0,
    <11574, 11565, 11566>, 0,
    <11574, 11566, 10051>, 0,
    <11574, 10051, 11509>, 0,
    <11574, 11509, 11507>, 0,
    <11574, 11507, 11573>, 0,
    <11578, 11577, 11571>, 0,
    <11578, 11571, 11573>, 0,
    <11578, 11573, 11507>, 0,
    <11578, 11507, 11518>, 0,
    <11578, 11518, 11516>, 0,
    <11578, 11516, 11576>, 0,
    <11578, 11576, 11575>, 0,
    <11578, 11575, 11577>, 0,
    <11580, 11572, 11571>, 0,
    <11580, 11571, 11577>, 0,
    <11580, 11577, 11575>, 0,
    <11580, 11575, 11579>, 0,
    <11580, 11579, 11557>, 0,
    <11580, 11557, 11569>, 0,
    <11580, 11569, 11565>, 0,
    <11580, 11565, 11572>, 0,
    <11586, 11585, 11581>, 0,
    <11586, 11581, 11583>, 0,
    <11586, 11583, 11582>, 0,
    <11586, 11582, 11584>, 0,
    <11586, 11584, 11545>, 0,
    <11586, 11545, 11548>, 0,
    <11586, 11548, 11544>, 0,
    <11586, 11544, 11585>, 0,
    <11590, 11589, 11581>, 0,
    <11590, 11581, 11585>, 0,
    <11590, 11585, 11544>, 0,
    <11590, 11544, 11559>, 0,
    <11590, 11559, 11557>, 0,
    <11590, 11557, 11588>, 0,
    <11590, 11588, 11587>, 0,
    <11590, 11587, 11589>, 0,
    <11593, 11583, 11581>, 0,
    <11593, 11581, 11589>, 0,
    <11593, 11589, 11587>, 0,
    <11593, 11587, 11591>, 0,
    <11593, 11591, 2057>, 0,
    <11593, 2057, 11592>, 0,
    <11593, 11592, 11582>, 0,
    <11593, 11582, 11583>, 0,
    <11602, 11601, 11594>, 0,
    <11602, 11594, 11598>, 0,
    <11602, 11598, 11595>, 0,
    <11602, 11595, 11599>, 0,
    <11602, 11599, 11596>, 0,
    <11602, 11596, 11600>, 0,
    <11602, 11600, 11597>, 0,
    <11602, 11597, 11601>, 0,
    <11605, 11604, 11594>, 0,
    <11605, 11594, 11601>, 0,
    <11605, 11601, 11597>, 0,
    <11605, 11597, 11603>, 0,
    <11605, 11603, 2057>, 0,
    <11605, 2057, 11591>, 0,
    <11605, 11591, 11587>, 0,
    <11605, 11587, 11604>, 0,
    <11607, 11598, 11594>, 0,
    <11607, 11594, 11604>, 0,
    <11607, 11604, 11587>, 0,
    <11607, 11587, 11588>, 0,
    <11607, 11588, 11557>, 0,
    <11607, 11557, 11606>, 0,
    <11607, 11606, 11595>, 0,
    <11607, 11595, 11598>, 0,
    <11616, 11615, 11608>, 0,
    <11616, 11608, 11612>, 0,
    <11616, 11612, 11609>, 0,
    <11616, 11609, 11613>, 0,
    <11616, 11613, 11610>, 0,
    <11616, 11610, 11614>, 0,
    <11616, 11614, 11611>, 0,
    <11616, 11611, 11615>, 0,
    <11619, 11618, 11608>, 0,
    <11619, 11608, 11615>, 0,
    <11619, 11615, 11611>, 0,
    <11619, 11611, 11617>, 0,
    <11619, 11617, 10849>, 0,
    <11619, 10849, 10882>, 0,
    <11619, 10882, 10877>, 0,
    <11619, 10877, 11618>, 0,
    <11621, 11612, 11608>, 0,
    <11621, 11608, 11618>, 0,
    <11621, 11618, 10877>, 0,
    <11621, 10877, 10879>, 0,
    <11621, 10879, 2163>, 0,
    <11621, 2163, 11620>, 0,
    <11621, 11620, 11609>, 0,
    <11621, 11609, 11612>, 0,
    <11630, 11629, 11622>, 0,
    <11630, 11622, 11626>, 0,
    <11630, 11626, 11623>, 0,
    <11630, 11623, 11627>, 0,
    <11630, 11627, 11624>, 0,
    <11630, 11624, 11628>, 0,
    <11630, 11628, 11625>, 0,
    <11630, 11625, 11629>, 0,
    <11633, 11632, 11622>, 0,
    <11633, 11622, 11629>, 0,
    <11633, 11629, 11625>, 0,
    <11633, 11625, 11631>, 0,
    <11633, 11631, 2149>, 0,
    <11633, 2149, 10938>, 0,
    <11633, 10938, 10936>, 0,
    <11633, 10936, 11632>, 0,
    <11635, 11626, 11622>, 0,
    <11635, 11622, 11632>, 0,
    <11635, 11632, 10936>, 0,
    <11635, 10936, 10943>, 0,
    <11635, 10943, 10923>, 0,
    <11635, 10923, 11634>, 0,
    <11635, 11634, 11623>, 0,
    <11635, 11623, 11626>, 0,
    <11641, 11640, 11636>, 0,
    <11641, 11636, 11638>, 0,
    <11641, 11638, 11236>, 0,
    <11641, 11236, 11237>, 0,
    <11641, 11237, 11224>, 0,
    <11641, 11224, 11639>, 0,
    <11641, 11639, 11637>, 0,
    <11641, 11637, 11640>, 0,
    <11646, 11645, 11636>, 0,
    <11646, 11636, 11640>, 0,
    <11646, 11640, 11637>, 0,
    <11646, 11637, 11643>, 0,
    <11646, 11643, 2250>, 0,
    <11646, 2250, 11644>, 0,
    <11646, 11644, 11642>, 0,
    <11646, 11642, 11645>, 0,
    <11648, 11638, 11636>, 0,
    <11648, 11636, 11645>, 0,
    <11648, 11645, 11642>, 0,
    <11648, 11642, 11647>, 0,
    <11648, 11647, 2091>, 0,
    <11648, 2091, 11240>, 0,
    <11648, 11240, 11236>, 0,
    <11648, 11236, 11638>, 0,
    <11654, 11653, 11649>, 0,
    <11654, 11649, 11651>, 0,
    <11654, 11651, 11260>, 0,
    <11654, 11260, 11261>, 0,
    <11654, 11261, 11248>, 0,
    <11654, 11248, 11652>, 0,
    <11654, 11652, 11650>, 0,
    <11654, 11650, 11653>, 0,
    <11660, 11659, 11649>, 0,
    <11660, 11649, 11653>, 0,
    <11660, 11653, 11650>, 0,
    <11660, 11650, 11657>, 0,
    <11660, 11657, 11655>, 0,
    <11660, 11655, 11658>, 0,
    <11660, 11658, 11656>, 0,
    <11660, 11656, 11659>, 0,
    <11662, 11651, 11649>, 0,
    <11662, 11649, 11659>, 0,
    <11662, 11659, 11656>, 0,
    <11662, 11656, 11661>, 0,
    <11662, 11661, 11224>, 0,
    <11662, 11224, 11264>, 0,
    <11662, 11264, 11260>, 0,
    <11662, 11260, 11651>, 0,
    <11666, 11665, 11663>, 0,
    <11666, 11663, 11664>, 0,
    <11666, 11664, 11637>, 0,
    <11666, 11637, 11639>, 0,
    <11666, 11639, 11224>, 0,
    <11666, 11224, 11661>, 0,
    <11666, 11661, 11656>, 0,
    <11666, 11656, 11665>, 0,
    <11670, 11669, 11663>, 0,
    <11670, 11663, 11665>, 0,
    <11670, 11665, 11656>, 0,
    <11670, 11656, 11658>, 0,
    <11670, 11658, 11655>, 0,
    <11670, 11655, 11668>, 0,
    <11670, 11668, 11667>, 0,
    <11670, 11667, 11669>, 0,
    <11672, 11664, 11663>, 0,
    <11672, 11663, 11669>, 0,
    <11672, 11669, 11667>, 0,
    <11672, 11667, 11671>, 0,
    <11672, 11671, 2250>, 0,
    <11672, 2250, 11643>, 0,
    <11672, 11643, 11637>, 0,
    <11672, 11637, 11664>, 0,
    <11681, 11680, 11673>, 0,
    <11681, 11673, 11677>, 0,
    <11681, 11677, 11674>, 0,
    <11681, 11674, 11678>, 0,
    <11681, 11678, 11675>, 0,
    <11681, 11675, 11679>, 0,
    <11681, 11679, 11676>, 0,
    <11681, 11676, 11680>, 0,
    <11684, 11683, 11673>, 0,
    <11684, 11673, 11680>, 0,
    <11684, 11680, 11676>, 0,
    <11684, 11676, 11682>, 0,
    <11684, 11682, 2117>, 0,
    <11684, 2117, 2283>, 0,
    <11684, 2283, 2278>, 0,
    <11684, 2278, 11683>, 0,
    <11686, 11677, 11673>, 0,
    <11686, 11673, 11683>, 0,
    <11686, 11683, 2278>, 0,
    <11686, 2278, 2280>, 0,
    <11686, 2280, 2277>, 0,
    <11686, 2277, 11685>, 0,
    <11686, 11685, 11674>, 0,
    <11686, 11674, 11677>, 0,
    <11692, 11691, 11687>, 0,
    <11692, 11687, 11689>, 0,
    <11692, 11689, 11676>, 0,
    <11692, 11676, 11679>, 0,
    <11692, 11679, 11675>, 0,
    <11692, 11675, 11690>, 0,
    <11692, 11690, 11688>, 0,
    <11692, 11688, 11691>, 0,
    <11695, 11694, 11687>, 0,
    <11695, 11687, 11691>, 0,
    <11695, 11691, 11688>, 0,
    <11695, 11688, 11693>, 0,
    <11695, 11693, 11176>, 0,
    <11695, 11176, 11201>, 0,
    <11695, 11201, 11199>, 0,
    <11695, 11199, 11694>, 0,
    <11696, 11689, 11687>, 0,
    <11696, 11687, 11694>, 0,
    <11696, 11694, 11199>, 0,
    <11696, 11199, 11206>, 0,
    <11696, 11206, 2117>, 0,
    <11696, 2117, 11682>, 0,
    <11696, 11682, 11676>, 0,
    <11696, 11676, 11689>, 0,
    <11702, 11701, 11697>, 0,
    <11702, 11697, 11699>, 0,
    <11702, 11699, 11318>, 0,
    <11702, 11318, 11319>, 0,
    <11702, 11319, 11306>, 0,
    <11702, 11306, 11700>, 0,
    <11702, 11700, 11698>, 0,
    <11702, 11698, 11701>, 0,
    <11708, 11707, 11697>, 0,
    <11708, 11697, 11701>, 0,
    <11708, 11701, 11698>, 0,
    <11708, 11698, 11705>, 0,
    <11708, 11705, 11703>, 0,
    <11708, 11703, 11706>, 0,
    <11708, 11706, 11704>, 0,
    <11708, 11704, 11707>, 0,
    <11710, 11699, 11697>, 0,
    <11710, 11697, 11707>, 0,
    <11710, 11707, 11704>, 0,
    <11710, 11704, 11709>, 0,
    <11710, 11709, 11248>, 0,
    <11710, 11248, 11322>, 0,
    <11710, 11322, 11318>, 0,
    <11710, 11318, 11699>, 0,
    <11714, 11713, 11711>, 0,
    <11714, 11711, 11712>, 0,
    <11714, 11712, 11650>, 0,
    <11714, 11650, 11652>, 0,
    <11714, 11652, 11248>, 0,
    <11714, 11248, 11709>, 0,
    <11714, 11709, 11704>, 0,
    <11714, 11704, 11713>, 0,
    <11718, 11717, 11711>, 0,
    <11718, 11711, 11713>, 0,
    <11718, 11713, 11704>, 0,
    <11718, 11704, 11706>, 0,
    <11718, 11706, 11703>, 0,
    <11718, 11703, 11716>, 0,
    <11718, 11716, 11715>, 0,
    <11718, 11715, 11717>, 0,
    <11720, 11712, 11711>, 0,
    <11720, 11711, 11717>, 0,
    <11720, 11717, 11715>, 0,
    <11720, 11715, 11719>, 0,
    <11720, 11719, 11655>, 0,
    <11720, 11655, 11657>, 0,
    <11720, 11657, 11650>, 0,
    <11720, 11650, 11712>, 0,
    <11729, 11728, 11721>, 0,
    <11729, 11721, 11725>, 0,
    <11729, 11725, 11722>, 0,
    <11729, 11722, 11726>, 0,
    <11729, 11726, 11723>, 0,
    <11729, 11723, 11727>, 0,
    <11729, 11727, 11724>, 0,
    <11729, 11724, 11728>, 0,
    <11732, 11731, 11721>, 0,
    <11732, 11721, 11728>, 0,
    <11732, 11728, 11724>, 0,
    <11732, 11724, 11730>, 0,
    <11732, 11730, 11176>, 0,
    <11732, 11176, 11693>, 0,
    <11732, 11693, 11688>, 0,
    <11732, 11688, 11731>, 0,
    <11734, 11725, 11721>, 0,
    <11734, 11721, 11731>, 0,
    <11734, 11731, 11688>, 0,
    <11734, 11688, 11690>, 0,
    <11734, 11690, 11675>, 0,
    <11734, 11675, 11733>, 0,
    <11734, 11733, 11722>, 0,
    <11734, 11722, 11725>, 0,
    <11740, 11739, 11735>, 0,
    <11740, 11735, 11737>, 0,
    <11740, 11737, 11724>, 0,
    <11740, 11724, 11727>, 0,
    <11740, 11727, 11723>, 0,
    <11740, 11723, 11738>, 0,
    <11740, 11738, 11736>, 0,
    <11740, 11736, 11739>, 0,
    <11743, 11742, 11735>, 0,
    <11743, 11735, 11739>, 0,
    <11743, 11739, 11736>, 0,
    <11743, 11736, 11741>, 0,
    <11743, 11741, 11152>, 0,
    <11743, 11152, 11191>, 0,
    <11743, 11191, 11189>, 0,
    <11743, 11189, 11742>, 0,
    <11744, 11737, 11735>, 0,
    <11744, 11735, 11742>, 0,
    <11744, 11742, 11189>, 0,
    <11744, 11189, 11196>, 0,
    <11744, 11196, 11176>, 0,
    <11744, 11176, 11730>, 0,
    <11744, 11730, 11724>, 0,
    <11744, 11724, 11737>, 0,
    <11750, 11749, 11745>, 0,
    <11750, 11745, 11747>, 0,
    <11750, 11747, 11746>, 0,
    <11750, 11746, 11748>, 0,
    <11750, 11748, 11286>, 0,
    <11750, 11286, 11298>, 0,
    <11750, 11298, 11294>, 0,
    <11750, 11294, 11749>, 0,
    <11754, 11753, 11745>, 0,
    <11754, 11745, 11749>, 0,
    <11754, 11749, 11294>, 0,
    <11754, 11294, 11295>, 0,
    <11754, 11295, 2097>, 0,
    <11754, 2097, 11752>, 0,
    <11754, 11752, 11751>, 0,
    <11754, 11751, 11753>, 0,
    <11757, 11747, 11745>, 0,
    <11757, 11745, 11753>, 0,
    <11757, 11753, 11751>, 0,
    <11757, 11751, 11755>, 0,
    <11757, 11755, 2264>, 0,
    <11757, 2264, 11756>, 0,
    <11757, 11756, 11746>, 0,
    <11757, 11746, 11747>, 0,
    <11763, 11762, 11758>, 0,
    <11763, 11758, 11760>, 0,
    <11763, 11760, 11759>, 0,
    <11763, 11759, 11761>, 0,
    <11763, 11761, 11334>, 0,
    <11763, 11334, 11346>, 0,
    <11763, 11346, 11342>, 0,
    <11763, 11342, 11762>, 0,
    <11767, 11766, 11758>, 0,
    <11767, 11758, 11762>, 0,
    <11767, 11762, 11342>, 0,
    <11767, 11342, 11343>, 0,
    <11767, 11343, 11286>, 0,
    <11767, 11286, 11765>, 0,
    <11767, 11765, 11764>, 0,
    <11767, 11764, 11766>, 0,
    <11771, 11760, 11758>, 0,
    <11771, 11758, 11766>, 0,
    <11771, 11766, 11764>, 0,
    <11771, 11764, 11769>, 0,
    <11771, 11769, 11768>, 0,
    <11771, 11768, 11770>, 0,
    <11771, 11770, 11759>, 0,
    <11771, 11759, 11760>, 0,
    <11775, 11774, 11772>, 0,
    <11775, 11772, 11773>, 0,
    <11775, 11773, 11764>, 0,
    <11775, 11764, 11765>, 0,
    <11775, 11765, 11286>, 0,
    <11775, 11286, 11748>, 0,
    <11775, 11748, 11746>, 0,
    <11775, 11746, 11774>, 0,
    <11779, 11778, 11772>, 0,
    <11779, 11772, 11774>, 0,
    <11779, 11774, 11746>, 0,
    <11779, 11746, 11756>, 0,
    <11779, 11756, 2264>, 0,
    <11779, 2264, 11777>, 0,
    <11779, 11777, 11776>, 0,
    <11779, 11776, 11778>, 0,
    <11781, 11773, 11772>, 0,
    <11781, 11772, 11778>, 0,
    <11781, 11778, 11776>, 0,
    <11781, 11776, 11780>, 0,
    <11781, 11780, 11768>, 0,
    <11781, 11768, 11769>, 0,
    <11781, 11769, 11764>, 0,
    <11781, 11764, 11773>, 0,
    <11790, 11789, 11782>, 0,
    <11790, 11782, 11786>, 0,
    <11790, 11786, 11783>, 0,
    <11790, 11783, 11787>, 0,
    <11790, 11787, 11784>, 0,
    <11790, 11784, 11788>, 0,
    <11790, 11788, 11785>, 0,
    <11790, 11785, 11789>, 0,
    <11793, 11792, 11782>, 0,
    <11793, 11782, 11789>, 0,
    <11793, 11789, 11785>, 0,
    <11793, 11785, 11791>, 0,
    <11793, 11791, 2270>, 0,
    <11793, 2270, 2289>, 0,
    <11793, 2289, 2287>, 0,
    <11793, 2287, 11792>, 0,
    <11795, 11786, 11782>, 0,
    <11795, 11782, 11792>, 0,
    <11795, 11792, 2287>, 0,
    <11795, 2287, 2294>, 0,
    <11795, 2294, 2127>, 0,
    <11795, 2127, 11794>, 0,
    <11795, 11794, 11783>, 0,
    <11795, 11783, 11786>, 0,
    <11801, 11800, 11796>, 0,
    <11801, 11796, 11798>, 0,
    <11801, 11798, 11797>, 0,
    <11801, 11797, 11799>, 0,
    <11801, 11799, 11784>, 0,
    <11801, 11784, 11787>, 0,
    <11801, 11787, 11783>, 0,
    <11801, 11783, 11800>, 0,
    <11803, 11802, 11796>, 0,
    <11803, 11796, 11800>, 0,
    <11803, 11800, 11783>, 0,
    <11803, 11783, 11794>, 0,
    <11803, 11794, 2127>, 0,
    <11803, 2127, 11144>, 0,
    <11803, 11144, 11138>, 0,
    <11803, 11138, 11802>, 0,
    <11805, 11798, 11796>, 0,
    <11805, 11796, 11802>, 0,
    <11805, 11802, 11138>, 0,
    <11805, 11138, 11140>, 0,
    <11805, 11140, 11115>, 0,
    <11805, 11115, 11804>, 0,
    <11805, 11804, 11797>, 0,
    <11805, 11797, 11798>, 0,
    <11811, 11810, 11806>, 0,
    <11811, 11806, 11808>, 0,
    <11811, 11808, 11390>, 0,
    <11811, 11390, 11391>, 0,
    <11811, 11391, 11378>, 0,
    <11811, 11378, 11809>, 0,
    <11811, 11809, 11807>, 0,
    <11811, 11807, 11810>, 0,
    <11817, 11816, 11806>, 0,
    <11817, 11806, 11810>, 0,
    <11817, 11810, 11807>, 0,
    <11817, 11807, 11814>, 0,
    <11817, 11814, 11812>, 0,
    <11817, 11812, 11815>, 0,
    <11817, 11815, 11813>, 0,
    <11817, 11813, 11816>, 0,
    <11819, 11808, 11806>, 0,
    <11819, 11806, 11816>, 0,
    <11819, 11816, 11813>, 0,
    <11819, 11813, 11818>, 0,
    <11819, 11818, 11306>, 0,
    <11819, 11306, 11394>, 0,
    <11819, 11394, 11390>, 0,
    <11819, 11390, 11808>, 0,
    <11823, 11822, 11820>, 0,
    <11823, 11820, 11821>, 0,
    <11823, 11821, 11698>, 0,
    <11823, 11698, 11700>, 0,
    <11823, 11700, 11306>, 0,
    <11823, 11306, 11818>, 0,
    <11823, 11818, 11813>, 0,
    <11823, 11813, 11822>, 0,
    <11827, 11826, 11820>, 0,
    <11827, 11820, 11822>, 0,
    <11827, 11822, 11813>, 0,
    <11827, 11813, 11815>, 0,
    <11827, 11815, 11812>, 0,
    <11827, 11812, 11825>, 0,
    <11827, 11825, 11824>, 0,
    <11827, 11824, 11826>, 0,
    <11829, 11821, 11820>, 0,
    <11829, 11820, 11826>, 0,
    <11829, 11826, 11824>, 0,
    <11829, 11824, 11828>, 0,
    <11829, 11828, 11703>, 0,
    <11829, 11703, 11705>, 0,
    <11829, 11705, 11698>, 0,
    <11829, 11698, 11821>, 0,
    <11838, 11837, 11830>, 0,
    <11838, 11830, 11834>, 0,
    <11838, 11834, 11831>, 0,
    <11838, 11831, 11835>, 0,
    <11838, 11835, 11832>, 0,
    <11838, 11832, 11836>, 0,
    <11838, 11836, 11833>, 0,
    <11838, 11833, 11837>, 0,
    <11841, 11840, 11830>, 0,
    <11841, 11830, 11837>, 0,
    <11841, 11837, 11833>, 0,
    <11841, 11833, 11839>, 0,
    <11841, 11839, 11152>, 0,
    <11841, 11152, 11741>, 0,
    <11841, 11741, 11736>, 0,
    <11841, 11736, 11840>, 0,
    <11843, 11834, 11830>, 0,
    <11843, 11830, 11840>, 0,
    <11843, 11840, 11736>, 0,
    <11843, 11736, 11738>, 0,
    <11843, 11738, 11723>, 0,
    <11843, 11723, 11842>, 0,
    <11843, 11842, 11831>, 0,
    <11843, 11831, 11834>, 0,
    <11849, 11848, 11844>, 0,
    <11849, 11844, 11846>, 0,
    <11849, 11846, 11833>, 0,
    <11849, 11833, 11836>, 0,
    <11849, 11836, 11832>, 0,
    <11849, 11832, 11847>, 0,
    <11849, 11847, 11845>, 0,
    <11849, 11845, 11848>, 0,
    <11852, 11851, 11844>, 0,
    <11852, 11844, 11848>, 0,
    <11852, 11848, 11845>, 0,
    <11852, 11845, 11850>, 0,
    <11852, 11850, 11091>, 0,
    <11852, 11091, 11167>, 0,
    <11852, 11167, 11165>, 0,
    <11852, 11165, 11851>, 0,
    <11853, 11846, 11844>, 0,
    <11853, 11844, 11851>, 0,
    <11853, 11851, 11165>, 0,
    <11853, 11165, 11172>, 0,
    <11853, 11172, 11152>, 0,
    <11853, 11152, 11839>, 0,
    <11853, 11839, 11833>, 0,
    <11853, 11833, 11846>, 0,
    <11859, 11858, 11854>, 0,
    <11859, 11854, 11856>, 0,
    <11859, 11856, 11855>, 0,
    <11859, 11855, 11857>, 0,
    <11859, 11857, 11358>, 0,
    <11859, 11358, 11370>, 0,
    <11859, 11370, 11366>, 0,
    <11859, 11366, 11858>, 0,
    <11863, 11862, 11854>, 0,
    <11863, 11854, 11858>, 0,
    <11863, 11858, 11366>, 0,
    <11863, 11366, 11367>, 0,
    <11863, 11367, 11334>, 0,
    <11863, 11334, 11861>, 0,
    <11863, 11861, 11860>, 0,
    <11863, 11860, 11862>, 0,
    <11867, 11856, 11854>, 0,
    <11867, 11854, 11862>, 0,
    <11867, 11862, 11860>, 0,
    <11867, 11860, 11865>, 0,
    <11867, 11865, 11864>, 0,
    <11867, 11864, 11866>, 0,
    <11867, 11866, 11855>, 0,
    <11867, 11855, 11856>, 0,
    <11871, 11870, 11868>, 0,
    <11871, 11868, 11869>, 0,
    <11871, 11869, 11860>, 0,
    <11871, 11860, 11861>, 0,
    <11871, 11861, 11334>, 0,
    <11871, 11334, 11761>, 0,
    <11871, 11761, 11759>, 0,
    <11871, 11759, 11870>, 0,
    <11875, 11874, 11868>, 0,
    <11875, 11868, 11870>, 0,
    <11875, 11870, 11759>, 0,
    <11875, 11759, 11770>, 0,
    <11875, 11770, 11768>, 0,
    <11875, 11768, 11873>, 0,
    <11875, 11873, 11872>, 0,
    <11875, 11872, 11874>, 0,
    <11877, 11869, 11868>, 0,
    <11877, 11868, 11874>, 0,
    <11877, 11874, 11872>, 0,
    <11877, 11872, 11876>, 0,
    <11877, 11876, 11864>, 0,
    <11877, 11864, 11865>, 0,
    <11877, 11865, 11860>, 0,
    <11877, 11860, 11869>, 0,
    <11886, 11885, 11878>, 0,
    <11886, 11878, 11882>, 0,
    <11886, 11882, 11879>, 0,
    <11886, 11879, 11883>, 0,
    <11886, 11883, 11880>, 0,
    <11886, 11880, 11884>, 0,
    <11886, 11884, 11881>, 0,
    <11886, 11881, 11885>, 0,
    <11889, 11888, 11878>, 0,
    <11889, 11878, 11885>, 0,
    <11889, 11885, 11881>, 0,
    <11889, 11881, 11887>, 0,
    <11889, 11887, 11784>, 0,
    <11889, 11784, 11799>, 0,
    <11889, 11799, 11797>, 0,
    <11889, 11797, 11888>, 0,
    <11891, 11882, 11878>, 0,
    <11891, 11878, 11888>, 0,
    <11891, 11888, 11797>, 0,
    <11891, 11797, 11804>, 0,
    <11891, 11804, 11115>, 0,
    <11891, 11115, 11890>, 0,
    <11891, 11890, 11879>, 0,
    <11891, 11879, 11882>, 0,
    <11897, 11896, 11892>, 0,
    <11897, 11892, 11894>, 0,
    <11897, 11894, 11893>, 0,
    <11897, 11893, 11895>, 0,
    <11897, 11895, 11880>, 0,
    <11897, 11880, 11883>, 0,
    <11897, 11883, 11879>, 0,
    <11897, 11879, 11896>, 0,
    <11899, 11898, 11892>, 0,
    <11899, 11892, 11896>, 0,
    <11899, 11896, 11879>, 0,
    <11899, 11879, 11890>, 0,
    <11899, 11890, 11115>, 0,
    <11899, 11115, 11133>, 0,
    <11899, 11133, 11128>, 0,
    <11899, 11128, 11898>, 0,
    <11901, 11894, 11892>, 0,
    <11901, 11892, 11898>, 0,
    <11901, 11898, 11128>, 0,
    <11901, 11128, 11130>, 0,
    <11901, 11130, 11067>, 0,
    <11901, 11067, 11900>, 0,
    <11901, 11900, 11893>, 0,
    <11901, 11893, 11894>, 0,
    <11907, 11906, 11902>, 0,
    <11907, 11902, 11904>, 0,
    <11907, 11904, 11903>, 0,
    <11907, 11903, 11905>, 0,
    <11907, 11905, 11406>, 0,
    <11907, 11406, 11418>, 0,
    <11907, 11418, 11414>, 0,
    <11907, 11414, 11906>, 0,
    <11911, 11910, 11902>, 0,
    <11911, 11902, 11906>, 0,
    <11911, 11906, 11414>, 0,
    <11911, 11414, 11415>, 0,
    <11911, 11415, 11358>, 0,
    <11911, 11358, 11909>, 0,
    <11911, 11909, 11908>, 0,
    <11911, 11908, 11910>, 0,
    <11915, 11904, 11902>, 0,
    <11915, 11902, 11910>, 0,
    <11915, 11910, 11908>, 0,
    <11915, 11908, 11913>, 0,
    <11915, 11913, 11912>, 0,
    <11915, 11912, 11914>, 0,
    <11915, 11914, 11903>, 0,
    <11915, 11903, 11904>, 0,
    <11919, 11918, 11916>, 0,
    <11919, 11916, 11917>, 0,
    <11919, 11917, 11908>, 0,
    <11919, 11908, 11909>, 0,
    <11919, 11909, 11358>, 0,
    <11919, 11358, 11857>, 0,
    <11919, 11857, 11855>, 0,
    <11919, 11855, 11918>, 0,
    <11923, 11922, 11916>, 0,
    <11923, 11916, 11918>, 0,
    <11923, 11918, 11855>, 0,
    <11923, 11855, 11866>, 0,
    <11923, 11866, 11864>, 0,
    <11923, 11864, 11921>, 0,
    <11923, 11921, 11920>, 0,
    <11923, 11920, 11922>, 0,
    <11925, 11917, 11916>, 0,
    <11925, 11916, 11922>, 0,
    <11925, 11922, 11920>, 0,
    <11925, 11920, 11924>, 0,
    <11925, 11924, 11912>, 0,
    <11925, 11912, 11913>, 0,
    <11925, 11913, 11908>, 0,
    <11925, 11908, 11917>, 0,
    <11934, 11933, 11926>, 0,
    <11934, 11926, 11930>, 0,
    <11934, 11930, 11927>, 0,
    <11934, 11927, 11931>, 0,
    <11934, 11931, 11928>, 0,
    <11934, 11928, 11932>, 0,
    <11934, 11932, 11929>, 0,
    <11934, 11929, 11933>, 0,
    <11937, 11936, 11926>, 0,
    <11937, 11926, 11933>, 0,
    <11937, 11933, 11929>, 0,
    <11937, 11929, 11935>, 0,
    <11937, 11935, 11880>, 0,
    <11937, 11880, 11895>, 0,
    <11937, 11895, 11893>, 0,
    <11937, 11893, 11936>, 0,
    <11939, 11930, 11926>, 0,
    <11939, 11926, 11936>, 0,
    <11939, 11936, 11893>, 0,
    <11939, 11893, 11900>, 0,
    <11939, 11900, 11067>, 0,
    <11939, 11067, 11938>, 0,
    <11939, 11938, 11927>, 0,
    <11939, 11927, 11930>, 0,
    <11945, 11944, 11940>, 0,
    <11945, 11940, 11942>, 0,
    <11945, 11942, 11941>, 0,
    <11945, 11941, 11943>, 0,
    <11945, 11943, 11928>, 0,
    <11945, 11928, 11931>, 0,
    <11945, 11931, 11927>, 0,
    <11945, 11927, 11944>, 0,
    <11947, 11946, 11940>, 0,
    <11947, 11940, 11944>, 0,
    <11947, 11944, 11927>, 0,
    <11947, 11927, 11938>, 0,
    <11947, 11938, 11067>, 0,
    <11947, 11067, 11085>, 0,
    <11947, 11085, 11080>, 0,
    <11947, 11080, 11946>, 0,
    <11949, 11942, 11940>, 0,
    <11949, 11940, 11946>, 0,
    <11949, 11946, 11080>, 0,
    <11949, 11080, 11082>, 0,
    <11949, 11082, 11043>, 0,
    <11949, 11043, 11948>, 0,
    <11949, 11948, 11941>, 0,
    <11949, 11941, 11942>, 0,
    <11955, 11954, 11950>, 0,
    <11955, 11950, 11952>, 0,
    <11955, 11952, 11438>, 0,
    <11955, 11438, 11439>, 0,
    <11955, 11439, 11426>, 0,
    <11955, 11426, 11953>, 0,
    <11955, 11953, 11951>, 0,
    <11955, 11951, 11954>, 0,
    <11961, 11960, 11950>, 0,
    <11961, 11950, 11954>, 0,
    <11961, 11954, 11951>, 0,
    <11961, 11951, 11958>, 0,
    <11961, 11958, 11956>, 0,
    <11961, 11956, 11959>, 0,
    <11961, 11959, 11957>, 0,
    <11961, 11957, 11960>, 0,
    <11963, 11952, 11950>, 0,
    <11963, 11950, 11960>, 0,
    <11963, 11960, 11957>, 0,
    <11963, 11957, 11962>, 0,
    <11963, 11962, 11378>, 0,
    <11963, 11378, 11442>, 0,
    <11963, 11442, 11438>, 0,
    <11963, 11438, 11952>, 0,
    <11967, 11966, 11964>, 0,
    <11967, 11964, 11965>, 0,
    <11967, 11965, 11807>, 0,
    <11967, 11807, 11809>, 0,
    <11967, 11809, 11378>, 0,
    <11967, 11378, 11962>, 0,
    <11967, 11962, 11957>, 0,
    <11967, 11957, 11966>, 0,
    <11971, 11970, 11964>, 0,
    <11971, 11964, 11966>, 0,
    <11971, 11966, 11957>, 0,
    <11971, 11957, 11959>, 0,
    <11971, 11959, 11956>, 0,
    <11971, 11956, 11969>, 0,
    <11971, 11969, 11968>, 0,
    <11971, 11968, 11970>, 0,
    <11973, 11965, 11964>, 0,
    <11973, 11964, 11970>, 0,
    <11973, 11970, 11968>, 0,
    <11973, 11968, 11972>, 0,
    <11973, 11972, 11812>, 0,
    <11973, 11812, 11814>, 0,
    <11973, 11814, 11807>, 0,
    <11973, 11807, 11965>, 0,
    <11982, 11981, 11974>, 0,
    <11982, 11974, 11978>, 0,
    <11982, 11978, 11975>, 0,
    <11982, 11975, 11979>, 0,
    <11982, 11979, 11976>, 0,
    <11982, 11976, 11980>, 0,
    <11982, 11980, 11977>, 0,
    <11982, 11977, 11981>, 0,
    <11985, 11984, 11974>, 0,
    <11985, 11974, 11981>, 0,
    <11985, 11981, 11977>, 0,
    <11985, 11977, 11983>, 0,
    <11985, 11983, 11091>, 0,
    <11985, 11091, 11850>, 0,
    <11985, 11850, 11845>, 0,
    <11985, 11845, 11984>, 0,
    <11987, 11978, 11974>, 0,
    <11987, 11974, 11984>, 0,
    <11987, 11984, 11845>, 0,
    <11987, 11845, 11847>, 0,
    <11987, 11847, 11832>, 0,
    <11987, 11832, 11986>, 0,
    <11987, 11986, 11975>, 0,
    <11987, 11975, 11978>, 0,
    <11993, 11992, 11988>, 0,
    <11993, 11988, 11990>, 0,
    <11993, 11990, 11977>, 0,
    <11993, 11977, 11980>, 0,
    <11993, 11980, 11976>, 0,
    <11993, 11976, 11991>, 0,
    <11993, 11991, 11989>, 0,
    <11993, 11989, 11992>, 0,
    <11996, 11995, 11988>, 0,
    <11996, 11988, 11992>, 0,
    <11996, 11992, 11989>, 0,
    <11996, 11989, 11994>, 0,
    <11996, 11994, 11019>, 0,
    <11996, 11019, 11106>, 0,
    <11996, 11106, 11104>, 0,
    <11996, 11104, 11995>, 0,
    <11997, 11990, 11988>, 0,
    <11997, 11988, 11995>, 0,
    <11997, 11995, 11104>, 0,
    <11997, 11104, 11111>, 0,
    <11997, 11111, 11091>, 0,
    <11997, 11091, 11983>, 0,
    <11997, 11983, 11977>, 0,
    <11997, 11977, 11990>, 0,
    <12003, 12002, 11998>, 0,
    <12003, 11998, 12000>, 0,
    <12003, 12000, 11999>, 0,
    <12003, 11999, 12001>, 0,
    <12003, 12001, 11454>, 0,
    <12003, 11454, 11466>, 0,
    <12003, 11466, 11462>, 0,
    <12003, 11462, 12002>, 0,
    <12007, 12006, 11998>, 0,
    <12007, 11998, 12002>, 0,
    <12007, 12002, 11462>, 0,
    <12007, 11462, 11463>, 0,
    <12007, 11463, 11406>, 0,
    <12007, 11406, 12005>, 0,
    <12007, 12005, 12004>, 0,
    <12007, 12004, 12006>, 0,
    <12011, 12000, 11998>, 0,
    <12011, 11998, 12006>, 0,
    <12011, 12006, 12004>, 0,
    <12011, 12004, 12009>, 0,
    <12011, 12009, 12008>, 0,
    <12011, 12008, 12010>, 0,
    <12011, 12010, 11999>, 0,
    <12011, 11999, 12000>, 0,
    <12015, 12014, 12012>, 0,
    <12015, 12012, 12013>, 0,
    <12015, 12013, 12004>, 0,
    <12015, 12004, 12005>, 0,
    <12015, 12005, 11406>, 0,
    <12015, 11406, 11905>, 0,
    <12015, 11905, 11903>, 0,
    <12015, 11903, 12014>, 0,
    <12019, 12018, 12012>, 0,
    <12019, 12012, 12014>, 0,
    <12019, 12014, 11903>, 0,
    <12019, 11903, 11914>, 0,
    <12019, 11914, 11912>, 0,
    <12019, 11912, 12017>, 0,
    <12019, 12017, 12016>, 0,
    <12019, 12016, 12018>, 0,
    <12021, 12013, 12012>, 0,
    <12021, 12012, 12018>, 0,
    <12021, 12018, 12016>, 0,
    <12021, 12016, 12020>, 0,
    <12021, 12020, 12008>, 0,
    <12021, 12008, 12009>, 0,
    <12021, 12009, 12004>, 0,
    <12021, 12004, 12013>, 0,
    <12030, 12029, 12022>, 0,
    <12030, 12022, 12026>, 0,
    <12030, 12026, 12023>, 0,
    <12030, 12023, 12027>, 0,
    <12030, 12027, 12024>, 0,
    <12030, 12024, 12028>, 0,
    <12030, 12028, 12025>, 0,
    <12030, 12025, 12029>, 0,
    <12033, 12032, 12022>, 0,
    <12033, 12022, 12029>, 0,
    <12033, 12029, 12025>, 0,
    <12033, 12025, 12031>, 0,
    <12033, 12031, 11928>, 0,
    <12033, 11928, 11943>, 0,
    <12033, 11943, 11941>, 0,
    <12033, 11941, 12032>, 0,
    <12035, 12026, 12022>, 0,
    <12035, 12022, 12032>, 0,
    <12035, 12032, 11941>, 0,
    <12035, 11941, 11948>, 0,
    <12035, 11948, 11043>, 0,
    <12035, 11043, 12034>, 0,
    <12035, 12034, 12023>, 0,
    <12035, 12023, 12026>, 0,
    <12041, 12040, 12036>, 0,
    <12041, 12036, 12038>, 0,
    <12041, 12038, 12037>, 0,
    <12041, 12037, 12039>, 0,
    <12041, 12039, 12024>, 0,
    <12041, 12024, 12027>, 0,
    <12041, 12027, 12023>, 0,
    <12041, 12023, 12040>, 0,
    <12043, 12042, 12036>, 0,
    <12043, 12036, 12040>, 0,
    <12043, 12040, 12023>, 0,
    <12043, 12023, 12034>, 0,
    <12043, 12034, 11043>, 0,
    <12043, 11043, 11061>, 0,
    <12043, 11061, 11056>, 0,
    <12043, 11056, 12042>, 0,
    <12045, 12038, 12036>, 0,
    <12045, 12036, 12042>, 0,
    <12045, 12042, 11056>, 0,
    <12045, 11056, 11058>, 0,
    <12045, 11058, 10995>, 0,
    <12045, 10995, 12044>, 0,
    <12045, 12044, 12037>, 0,
    <12045, 12037, 12038>, 0,
    <12051, 12050, 12046>, 0,
    <12051, 12046, 12048>, 0,
    <12051, 12048, 11500>, 0,
    <12051, 11500, 11501>, 0,
    <12051, 11501, 11482>, 0,
    <12051, 11482, 12049>, 0,
    <12051, 12049, 12047>, 0,
    <12051, 12047, 12050>, 0,
    <12057, 12056, 12046>, 0,
    <12057, 12046, 12050>, 0,
    <12057, 12050, 12047>, 0,
    <12057, 12047, 12054>, 0,
    <12057, 12054, 12052>, 0,
    <12057, 12052, 12055>, 0,
    <12057, 12055, 12053>, 0,
    <12057, 12053, 12056>, 0,
    <12059, 12048, 12046>, 0,
    <12059, 12046, 12056>, 0,
    <12059, 12056, 12053>, 0,
    <12059, 12053, 12058>, 0,
    <12059, 12058, 11426>, 0,
    <12059, 11426, 11504>, 0,
    <12059, 11504, 11500>, 0,
    <12059, 11500, 12048>, 0,
    <12063, 12062, 12060>, 0,
    <12063, 12060, 12061>, 0,
    <12063, 12061, 11951>, 0,
    <12063, 11951, 11953>, 0,
    <12063, 11953, 11426>, 0,
    <12063, 11426, 12058>, 0,
    <12063, 12058, 12053>, 0,
    <12063, 12053, 12062>, 0,
    <12067, 12066, 12060>, 0,
    <12067, 12060, 12062>, 0,
    <12067, 12062, 12053>, 0,
    <12067, 12053, 12055>, 0,
    <12067, 12055, 12052>, 0,
    <12067, 12052, 12065>, 0,
    <12067, 12065, 12064>, 0,
    <12067, 12064, 12066>, 0,
    <12069, 12061, 12060>, 0,
    <12069, 12060, 12066>, 0,
    <12069, 12066, 12064>, 0,
    <12069, 12064, 12068>, 0,
    <12069, 12068, 11956>, 0,
    <12069, 11956, 11958>, 0,
    <12069, 11958, 11951>, 0,
    <12069, 11951, 12061>, 0,
    <12078, 12077, 12070>, 0,
    <12078, 12070, 12074>, 0,
    <12078, 12074, 12071>, 0,
    <12078, 12071, 12075>, 0,
    <12078, 12075, 12072>, 0,
    <12078, 12072, 12076>, 0,
    <12078, 12076, 12073>, 0,
    <12078, 12073, 12077>, 0,
    <12081, 12080, 12070>, 0,
    <12081, 12070, 12077>, 0,
    <12081, 12077, 12073>, 0,
    <12081, 12073, 12079>, 0,
    <12081, 12079, 11019>, 0,
    <12081, 11019, 11994>, 0,
    <12081, 11994, 11989>, 0,
    <12081, 11989, 12080>, 0,
    <12083, 12074, 12070>, 0,
    <12083, 12070, 12080>, 0,
    <12083, 12080, 11989>, 0,
    <12083, 11989, 11991>, 0,
    <12083, 11991, 11976>, 0,
    <12083, 11976, 12082>, 0,
    <12083, 12082, 12071>, 0,
    <12083, 12071, 12074>, 0,
    <12089, 12088, 12084>, 0,
    <12089, 12084, 12086>, 0,
    <12089, 12086, 12073>, 0,
    <12089, 12073, 12076>, 0,
    <12089, 12076, 12072>, 0,
    <12089, 12072, 12087>, 0,
    <12089, 12087, 12085>, 0,
    <12089, 12085, 12088>, 0,
    <12092, 12091, 12084>, 0,
    <12092, 12084, 12088>, 0,
    <12092, 12088, 12085>, 0,
    <12092, 12085, 12090>, 0,
    <12092, 12090, 10971>, 0,
    <12092, 10971, 11034>, 0,
    <12092, 11034, 11032>, 0,
    <12092, 11032, 12091>, 0,
    <12093, 12086, 12084>, 0,
    <12093, 12084, 12091>, 0,
    <12093, 12091, 11032>, 0,
    <12093, 11032, 11039>, 0,
    <12093, 11039, 11019>, 0,
    <12093, 11019, 12079>, 0,
    <12093, 12079, 12073>, 0,
    <12093, 12073, 12086>, 0,
    <12099, 12098, 12094>, 0,
    <12099, 12094, 12096>, 0,
    <12099, 12096, 12095>, 0,
    <12099, 12095, 12097>, 0,
    <12099, 12097, 11516>, 0,
    <12099, 11516, 11528>, 0,
    <12099, 11528, 11524>, 0,
    <12099, 11524, 12098>, 0,
    <12103, 12102, 12094>, 0,
    <12103, 12094, 12098>, 0,
    <12103, 12098, 11524>, 0,
    <12103, 11524, 11525>, 0,
    <12103, 11525, 11454>, 0,
    <12103, 11454, 12101>, 0,
    <12103, 12101, 12100>, 0,
    <12103, 12100, 12102>, 0,
    <12107, 12096, 12094>, 0,
    <12107, 12094, 12102>, 0,
    <12107, 12102, 12100>, 0,
    <12107, 12100, 12105>, 0,
    <12107, 12105, 12104>, 0,
    <12107, 12104, 12106>, 0,
    <12107, 12106, 12095>, 0,
    <12107, 12095, 12096>, 0,
    <12111, 12110, 12108>, 0,
    <12111, 12108, 12109>, 0,
    <12111, 12109, 12100>, 0,
    <12111, 12100, 12101>, 0,
    <12111, 12101, 11454>, 0,
    <12111, 11454, 12001>, 0,
    <12111, 12001, 11999>, 0,
    <12111, 11999, 12110>, 0,
    <12115, 12114, 12108>, 0,
    <12115, 12108, 12110>, 0,
    <12115, 12110, 11999>, 0,
    <12115, 11999, 12010>, 0,
    <12115, 12010, 12008>, 0,
    <12115, 12008, 12113>, 0,
    <12115, 12113, 12112>, 0,
    <12115, 12112, 12114>, 0,
    <12117, 12109, 12108>, 0,
    <12117, 12108, 12114>, 0,
    <12117, 12114, 12112>, 0,
    <12117, 12112, 12116>, 0,
    <12117, 12116, 12104>, 0,
    <12117, 12104, 12105>, 0,
    <12117, 12105, 12100>, 0,
    <12117, 12100, 12109>, 0,
    <12126, 12125, 12118>, 0,
    <12126, 12118, 12122>, 0,
    <12126, 12122, 12119>, 0,
    <12126, 12119, 12123>, 0,
    <12126, 12123, 12120>, 0,
    <12126, 12120, 12124>, 0,
    <12126, 12124, 12121>, 0,
    <12126, 12121, 12125>, 0,
    <12129, 12128, 12118>, 0,
    <12129, 12118, 12125>, 0,
    <12129, 12125, 12121>, 0,
    <12129, 12121, 12127>, 0,
    <12129, 12127, 12024>, 0,
    <12129, 12024, 12039>, 0,
    <12129, 12039, 12037>, 0,
    <12129, 12037, 12128>, 0,
    <12131, 12122, 12118>, 0,
    <12131, 12118, 12128>, 0,
    <12131, 12128, 12037>, 0,
    <12131, 12037, 12044>, 0,
    <12131, 12044, 10995>, 0,
    <12131, 10995, 12130>, 0,
    <12131, 12130, 12119>, 0,
    <12131, 12119, 12122>, 0,
    <12137, 12136, 12132>, 0,
    <12137, 12132, 12134>, 0,
    <12137, 12134, 12133>, 0,
    <12137, 12133, 12135>, 0,
    <12137, 12135, 12120>, 0,
    <12137, 12120, 12123>, 0,
    <12137, 12123, 12119>, 0,
    <12137, 12119, 12136>, 0,
    <12139, 12138, 12132>, 0,
    <12139, 12132, 12136>, 0,
    <12139, 12136, 12119>, 0,
    <12139, 12119, 12130>, 0,
    <12139, 12130, 10995>, 0,
    <12139, 10995, 11013>, 0,
    <12139, 11013, 11008>, 0,
    <12139, 11008, 12138>, 0,
    <12141, 12134, 12132>, 0,
    <12141, 12132, 12138>, 0,
    <12141, 12138, 11008>, 0,
    <12141, 11008, 11010>, 0,
    <12141, 11010, 10947>, 0,
    <12141, 10947, 12140>, 0,
    <12141, 12140, 12133>, 0,
    <12141, 12133, 12134>, 0,
    <12147, 12146, 12142>, 0,
    <12147, 12142, 12144>, 0,
    <12147, 12144, 11536>, 0,
    <12147, 11536, 11538>, 0,
    <12147, 11538, 2064>, 0,
    <12147, 2064, 12145>, 0,
    <12147, 12145, 12143>, 0,
    <12147, 12143, 12146>, 0,
    <12153, 12152, 12142>, 0,
    <12153, 12142, 12146>, 0,
    <12153, 12146, 12143>, 0,
    <12153, 12143, 12150>, 0,
    <12153, 12150, 12148>, 0,
    <12153, 12148, 12151>, 0,
    <12153, 12151, 12149>, 0,
    <12153, 12149, 12152>, 0,
    <12155, 12144, 12142>, 0,
    <12155, 12142, 12152>, 0,
    <12155, 12152, 12149>, 0,
    <12155, 12149, 12154>, 0,
    <12155, 12154, 11482>, 0,
    <12155, 11482, 11541>, 0,
    <12155, 11541, 11536>, 0,
    <12155, 11536, 12144>, 0,
    <12161, 12160, 12156>, 0,
    <12161, 12156, 12158>, 0,
    <12161, 12158, 12143>, 0,
    <12161, 12143, 12145>, 0,
    <12161, 12145, 2064>, 0,
    <12161, 2064, 12159>, 0,
    <12161, 12159, 12157>, 0,
    <12161, 12157, 12160>, 0,
    <12166, 12165, 12156>, 0,
    <12166, 12156, 12160>, 0,
    <12166, 12160, 12157>, 0,
    <12166, 12157, 12163>, 0,
    <12166, 12163, 2324>, 0,
    <12166, 2324, 12164>, 0,
    <12166, 12164, 12162>, 0,
    <12166, 12162, 12165>, 0,
    <12168, 12158, 12156>, 0,
    <12168, 12156, 12165>, 0,
    <12168, 12165, 12162>, 0,
    <12168, 12162, 12167>, 0,
    <12168, 12167, 12148>, 0,
    <12168, 12148, 12150>, 0,
    <12168, 12150, 12143>, 0,
    <12168, 12143, 12158>, 0,
    <12172, 12171, 12169>, 0,
    <12172, 12169, 12170>, 0,
    <12172, 12170, 12047>, 0,
    <12172, 12047, 12049>, 0,
    <12172, 12049, 11482>, 0,
    <12172, 11482, 12154>, 0,
    <12172, 12154, 12149>, 0,
    <12172, 12149, 12171>, 0,
    <12176, 12175, 12169>, 0,
    <12176, 12169, 12171>, 0,
    <12176, 12171, 12149>, 0,
    <12176, 12149, 12151>, 0,
    <12176, 12151, 12148>, 0,
    <12176, 12148, 12174>, 0,
    <12176, 12174, 12173>, 0,
    <12176, 12173, 12175>, 0,
    <12178, 12170, 12169>, 0,
    <12178, 12169, 12175>, 0,
    <12178, 12175, 12173>, 0,
    <12178, 12173, 12177>, 0,
    <12178, 12177, 12052>, 0,
    <12178, 12052, 12054>, 0,
    <12178, 12054, 12047>, 0,
    <12178, 12047, 12170>, 0,
    <12187, 12186, 12179>, 0,
    <12187, 12179, 12183>, 0,
    <12187, 12183, 12180>, 0,
    <12187, 12180, 12184>, 0,
    <12187, 12184, 12181>, 0,
    <12187, 12181, 12185>, 0,
    <12187, 12185, 12182>, 0,
    <12187, 12182, 12186>, 0,
    <12190, 12189, 12179>, 0,
    <12190, 12179, 12186>, 0,
    <12190, 12186, 12182>, 0,
    <12190, 12182, 12188>, 0,
    <12190, 12188, 10971>, 0,
    <12190, 10971, 12090>, 0,
    <12190, 12090, 12085>, 0,
    <12190, 12085, 12189>, 0,
    <12192, 12183, 12179>, 0,
    <12192, 12179, 12189>, 0,
    <12192, 12189, 12085>, 0,
    <12192, 12085, 12087>, 0,
    <12192, 12087, 12072>, 0,
    <12192, 12072, 12191>, 0,
    <12192, 12191, 12180>, 0,
    <12192, 12180, 12183>, 0,
    <12198, 12197, 12193>, 0,
    <12198, 12193, 12195>, 0,
    <12198, 12195, 12182>, 0,
    <12198, 12182, 12185>, 0,
    <12198, 12185, 12181>, 0,
    <12198, 12181, 12196>, 0,
    <12198, 12196, 12194>, 0,
    <12198, 12194, 12197>, 0,
    <12201, 12200, 12193>, 0,
    <12201, 12193, 12197>, 0,
    <12201, 12197, 12194>, 0,
    <12201, 12194, 12199>, 0,
    <12201, 12199, 10923>, 0,
    <12201, 10923, 10986>, 0,
    <12201, 10986, 10984>, 0,
    <12201, 10984, 12200>, 0,
    <12202, 12195, 12193>, 0,
    <12202, 12193, 12200>, 0,
    <12202, 12200, 10984>, 0,
    <12202, 10984, 10991>, 0,
    <12202, 10991, 10971>, 0,
    <12202, 10971, 12188>, 0,
    <12202, 12188, 12182>, 0,
    <12202, 12182, 12195>, 0,
    <12208, 12207, 12203>, 0,
    <12208, 12203, 12205>, 0,
    <12208, 12205, 12204>, 0,
    <12208, 12204, 12206>, 0,
    <12208, 12206, 11557>, 0,
    <12208, 11557, 11579>, 0,
    <12208, 11579, 11575>, 0,
    <12208, 11575, 12207>, 0,
    <12212, 12211, 12203>, 0,
    <12212, 12203, 12207>, 0,
    <12212, 12207, 11575>, 0,
    <12212, 11575, 11576>, 0,
    <12212, 11576, 11516>, 0,
    <12212, 11516, 12210>, 0,
    <12212, 12210, 12209>, 0,
    <12212, 12209, 12211>, 0,
    <12216, 12205, 12203>, 0,
    <12216, 12203, 12211>, 0,
    <12216, 12211, 12209>, 0,
    <12216, 12209, 12214>, 0,
    <12216, 12214, 12213>, 0,
    <12216, 12213, 12215>, 0,
    <12216, 12215, 12204>, 0,
    <12216, 12204, 12205>, 0,
    <12220, 12219, 12217>, 0,
    <12220, 12217, 12218>, 0,
    <12220, 12218, 12209>, 0,
    <12220, 12209, 12210>, 0,
    <12220, 12210, 11516>, 0,
    <12220, 11516, 12097>, 0,
    <12220, 12097, 12095>, 0,
    <12220, 12095, 12219>, 0,
    <12224, 12223, 12217>, 0,
    <12224, 12217, 12219>, 0,
    <12224, 12219, 12095>, 0,
    <12224, 12095, 12106>, 0,
    <12224, 12106, 12104>, 0,
    <12224, 12104, 12222>, 0,
    <12224, 12222, 12221>, 0,
    <12224, 12221, 12223>, 0,
    <12226, 12218, 12217>, 0,
    <12226, 12217, 12223>, 0,
    <12226, 12223, 12221>, 0,
    <12226, 12221, 12225>, 0,
    <12226, 12225, 12213>, 0,
    <12226, 12213, 12214>, 0,
    <12226, 12214, 12209>, 0,
    <12226, 12209, 12218>, 0,
    <12235, 12234, 12227>, 0,
    <12235, 12227, 12231>, 0,
    <12235, 12231, 12228>, 0,
    <12235, 12228, 12232>, 0,
    <12235, 12232, 12229>, 0,
    <12235, 12229, 12233>, 0,
    <12235, 12233, 12230>, 0,
    <12235, 12230, 12234>, 0,
    <12238, 12237, 12227>, 0,
    <12238, 12227, 12234>, 0,
    <12238, 12234, 12230>, 0,
    <12238, 12230, 12236>, 0,
    <12238, 12236, 12120>, 0,
    <12238, 12120, 12135>, 0,
    <12238, 12135, 12133>, 0,
    <12238, 12133, 12237>, 0,
    <12240, 12231, 12227>, 0,
    <12240, 12227, 12237>, 0,
    <12240, 12237, 12133>, 0,
    <12240, 12133, 12140>, 0,
    <12240, 12140, 10947>, 0,
    <12240, 10947, 12239>, 0,
    <12240, 12239, 12228>, 0,
    <12240, 12228, 12231>, 0,
    <12246, 12245, 12241>, 0,
    <12246, 12241, 12243>, 0,
    <12246, 12243, 12242>, 0,
    <12246, 12242, 12244>, 0,
    <12246, 12244, 12229>, 0,
    <12246, 12229, 12232>, 0,
    <12246, 12232, 12228>, 0,
    <12246, 12228, 12245>, 0,
    <12248, 12247, 12241>, 0,
    <12248, 12241, 12245>, 0,
    <12248, 12245, 12228>, 0,
    <12248, 12228, 12239>, 0,
    <12248, 12239, 10947>, 0,
    <12248, 10947, 10965>, 0,
    <12248, 10965, 10960>, 0,
    <12248, 10960, 12247>, 0,
    <12250, 12243, 12241>, 0,
    <12250, 12241, 12247>, 0,
    <12250, 12247, 10960>, 0,
    <12250, 10960, 10962>, 0,
    <12250, 10962, 10899>, 0,
    <12250, 10899, 12249>, 0,
    <12250, 12249, 12242>, 0,
    <12250, 12242, 12243>, 0,
    <12256, 12255, 12251>, 0,
    <12256, 12251, 12253>, 0,
    <12256, 12253, 12162>, 0,
    <12256, 12162, 12164>, 0,
    <12256, 12164, 2324>, 0,
    <12256, 2324, 12254>, 0,
    <12256, 12254, 12252>, 0,
    <12256, 12252, 12255>, 0,
    <12261, 12260, 12251>, 0,
    <12261, 12251, 12255>, 0,
    <12261, 12255, 12252>, 0,
    <12261, 12252, 12258>, 0,
    <12261, 12258, 2312>, 0,
    <12261, 2312, 12259>, 0,
    <12261, 12259, 12257>, 0,
    <12261, 12257, 12260>, 0,
    <12263, 12253, 12251>, 0,
    <12263, 12251, 12260>, 0,
    <12263, 12260, 12257>, 0,
    <12263, 12257, 12262>, 0,
    <12263, 12262, 12148>, 0,
    <12263, 12148, 12167>, 0,
    <12263, 12167, 12162>, 0,
    <12263, 12162, 12253>, 0,
    <12271, 12270, 12264>, 0,
    <12271, 12264, 12267>, 0,
    <12271, 12267, 12265>, 0,
    <12271, 12265, 12268>, 0,
    <12271, 12268, 2369>, 0,
    <12271, 2369, 12269>, 0,
    <12271, 12269, 12266>, 0,
    <12271, 12266, 12270>, 0,
    <12274, 12273, 12264>, 0,
    <12274, 12264, 12270>, 0,
    <12274, 12270, 12266>, 0,
    <12274, 12266, 12272>, 0,
    <12274, 12272, 10923>, 0,
    <12274, 10923, 12199>, 0,
    <12274, 12199, 12194>, 0,
    <12274, 12194, 12273>, 0,
    <12276, 12267, 12264>, 0,
    <12276, 12264, 12273>, 0,
    <12276, 12273, 12194>, 0,
    <12276, 12194, 12196>, 0,
    <12276, 12196, 12181>, 0,
    <12276, 12181, 12275>, 0,
    <12276, 12275, 12265>, 0,
    <12276, 12265, 12267>, 0,
    <12282, 12281, 12277>, 0,
    <12282, 12277, 12279>, 0,
    <12282, 12279, 12266>, 0,
    <12282, 12266, 12269>, 0,
    <12282, 12269, 2369>, 0,
    <12282, 2369, 12280>, 0,
    <12282, 12280, 12278>, 0,
    <12282, 12278, 12281>, 0,
    <12285, 12284, 12277>, 0,
    <12285, 12277, 12281>, 0,
    <12285, 12281, 12278>, 0,
    <12285, 12278, 12283>, 0,
    <12285, 12283, 11624>, 0,
    <12285, 11624, 11627>, 0,
    <12285, 11627, 11623>, 0,
    <12285, 11623, 12284>, 0,
    <12286, 12279, 12277>, 0,
    <12286, 12277, 12284>, 0,
    <12286, 12284, 11623>, 0,
    <12286, 11623, 11634>, 0,
    <12286, 11634, 10923>, 0,
    <12286, 10923, 12272>, 0,
    <12286, 12272, 12266>, 0,
    <12286, 12266, 12279>, 0,
    <12295, 12294, 12287>, 0,
    <12295, 12287, 12291>, 0,
    <12295, 12291, 12288>, 0,
    <12295, 12288, 12292>, 0,
    <12295, 12292, 12289>, 0,
    <12295, 12289, 12293>, 0,
    <12295, 12293, 12290>, 0,
    <12295, 12290, 12294>, 0,
    <12300, 12299, 12287>, 0,
    <12300, 12287, 12294>, 0,
    <12300, 12294, 12290>, 0,
    <12300, 12290, 12297>, 0,
    <12300, 12297, 11596>, 0,
    <12300, 11596, 12298>, 0,
    <12300, 12298, 12296>, 0,
    <12300, 12296, 12299>, 0,
    <12304, 12291, 12287>, 0,
    <12304, 12287, 12299>, 0,
    <12304, 12299, 12296>, 0,
    <12304, 12296, 12302>, 0,
    <12304, 12302, 12301>, 0,
    <12304, 12301, 12303>, 0,
    <12304, 12303, 12288>, 0,
    <12304, 12288, 12291>, 0,
    <12308, 12307, 12305>, 0,
    <12308, 12305, 12306>, 0,
    <12308, 12306, 12296>, 0,
    <12308, 12296, 12298>, 0,
    <12308, 12298, 11596>, 0,
    <12308, 11596, 11599>, 0,
    <12308, 11599, 11595>, 0,
    <12308, 11595, 12307>, 0,
    <12312, 12311, 12305>, 0,
    <12312, 12305, 12307>, 0,
    <12312, 12307, 11595>, 0,
    <12312, 11595, 11606>, 0,
    <12312, 11606, 11557>, 0,
    <12312, 11557, 12310>, 0,
    <12312, 12310, 12309>, 0,
    <12312, 12309, 12311>, 0,
    <12314, 12306, 12305>, 0,
    <12314, 12305, 12311>, 0,
    <12314, 12311, 12309>, 0,
    <12314, 12309, 12313>, 0,
    <12314, 12313, 12301>, 0,
    <12314, 12301, 12302>, 0,
    <12314, 12302, 12296>, 0,
    <12314, 12296, 12306>, 0,
    <12318, 12317, 12315>, 0,
    <12318, 12315, 12316>, 0,
    <12318, 12316, 12309>, 0,
    <12318, 12309, 12310>, 0,
    <12318, 12310, 11557>, 0,
    <12318, 11557, 12206>, 0,
    <12318, 12206, 12204>, 0,
    <12318, 12204, 12317>, 0,
    <12322, 12321, 12315>, 0,
    <12322, 12315, 12317>, 0,
    <12322, 12317, 12204>, 0,
    <12322, 12204, 12215>, 0,
    <12322, 12215, 12213>, 0,
    <12322, 12213, 12320>, 0,
    <12322, 12320, 12319>, 0,
    <12322, 12319, 12321>, 0,
    <12324, 12316, 12315>, 0,
    <12324, 12315, 12321>, 0,
    <12324, 12321, 12319>, 0,
    <12324, 12319, 12323>, 0,
    <12324, 12323, 12301>, 0,
    <12324, 12301, 12313>, 0,
    <12324, 12313, 12309>, 0,
    <12324, 12309, 12316>, 0,
    <12333, 12332, 12325>, 0,
    <12333, 12325, 12329>, 0,
    <12333, 12329, 12326>, 0,
    <12333, 12326, 12330>, 0,
    <12333, 12330, 12327>, 0,
    <12333, 12327, 12331>, 0,
    <12333, 12331, 12328>, 0,
    <12333, 12328, 12332>, 0,
    <12336, 12335, 12325>, 0,
    <12336, 12325, 12332>, 0,
    <12336, 12332, 12328>, 0,
    <12336, 12328, 12334>, 0,
    <12336, 12334, 12229>, 0,
    <12336, 12229, 12244>, 0,
    <12336, 12244, 12242>, 0,
    <12336, 12242, 12335>, 0,
    <12338, 12329, 12325>, 0,
    <12338, 12325, 12335>, 0,
    <12338, 12335, 12242>, 0,
    <12338, 12242, 12249>, 0,
    <12338, 12249, 10899>, 0,
    <12338, 10899, 12337>, 0,
    <12338, 12337, 12326>, 0,
    <12338, 12326, 12329>, 0,
    <12344, 12343, 12339>, 0,
    <12344, 12339, 12341>, 0,
    <12344, 12341, 12340>, 0,
    <12344, 12340, 12342>, 0,
    <12344, 12342, 12327>, 0,
    <12344, 12327, 12330>, 0,
    <12344, 12330, 12326>, 0,
    <12344, 12326, 12343>, 0,
    <12346, 12345, 12339>, 0,
    <12346, 12339, 12343>, 0,
    <12346, 12343, 12326>, 0,
    <12346, 12326, 12337>, 0,
    <12346, 12337, 10899>, 0,
    <12346, 10899, 10917>, 0,
    <12346, 10917, 10912>, 0,
    <12346, 10912, 12345>, 0,
    <12348, 12341, 12339>, 0,
    <12348, 12339, 12345>, 0,
    <12348, 12345, 10912>, 0,
    <12348, 10912, 10914>, 0,
    <12348, 10914, 10849>, 0,
    <12348, 10849, 12347>, 0,
    <12348, 12347, 12340>, 0,
    <12348, 12340, 12341>, 0,
    <12354, 12353, 12349>, 0,
    <12354, 12349, 12351>, 0,
    <12354, 12351, 11611>, 0,
    <12354, 11611, 11614>, 0,
    <12354, 11614, 11610>, 0,
    <12354, 11610, 12352>, 0,
    <12354, 12352, 12350>, 0,
    <12354, 12350, 12353>, 0,
    <12357, 12356, 12349>, 0,
    <12357, 12349, 12353>, 0,
    <12357, 12353, 12350>, 0,
    <12357, 12350, 12355>, 0,
    <12357, 12355, 12327>, 0,
    <12357, 12327, 12342>, 0,
    <12357, 12342, 12340>, 0,
    <12357, 12340, 12356>, 0,
    <12358, 12351, 12349>, 0,
    <12358, 12349, 12356>, 0,
    <12358, 12356, 12340>, 0,
    <12358, 12340, 12347>, 0,
    <12358, 12347, 10849>, 0,
    <12358, 10849, 11617>, 0,
    <12358, 11617, 11611>, 0,
    <12358, 11611, 12351>, 0,
    <12364, 12363, 12359>, 0,
    <12364, 12359, 12361>, 0,
    <12364, 12361, 12350>, 0,
    <12364, 12350, 12352>, 0,
    <12364, 12352, 11610>, 0,
    <12364, 11610, 12362>, 0,
    <12364, 12362, 12360>, 0,
    <12364, 12360, 12363>, 0,
    <12370, 12369, 12359>, 0,
    <12370, 12359, 12363>, 0,
    <12370, 12363, 12360>, 0,
    <12370, 12360, 12367>, 0,
    <12370, 12367, 12365>, 0,
    <12370, 12365, 12368>, 0,
    <12370, 12368, 12366>, 0,
    <12370, 12366, 12369>, 0,
    <12372, 12361, 12359>, 0,
    <12372, 12359, 12369>, 0,
    <12372, 12369, 12366>, 0,
    <12372, 12366, 12371>, 0,
    <12372, 12371, 12327>, 0,
    <12372, 12327, 12355>, 0,
    <12372, 12355, 12350>, 0,
    <12372, 12350, 12361>, 0,
    <12378, 12377, 12373>, 0,
    <12378, 12373, 12375>, 0,
    <12378, 12375, 12374>, 0,
    <12378, 12374, 12376>, 0,
    <12378, 12376, 12289>, 0,
    <12378, 12289, 12292>, 0,
    <12378, 12292, 12288>, 0,
    <12378, 12288, 12377>, 0,
    <12382, 12381, 12373>, 0,
    <12382, 12373, 12377>, 0,
    <12382, 12377, 12288>, 0,
    <12382, 12288, 12303>, 0,
    <12382, 12303, 12301>, 0,
    <12382, 12301, 12380>, 0,
    <12382, 12380, 12379>, 0,
    <12382, 12379, 12381>, 0,
    <12385, 12375, 12373>, 0,
    <12385, 12373, 12381>, 0,
    <12385, 12381, 12379>, 0,
    <12385, 12379, 12383>, 0,
    <12385, 12383, 2343>, 0,
    <12385, 2343, 12384>, 0,
    <12385, 12384, 12374>, 0,
    <12385, 12374, 12375>, 0,
    <12391, 12390, 12386>, 0,
    <12391, 12386, 12388>, 0,
    <12391, 12388, 12366>, 0,
    <12391, 12366, 12368>, 0,
    <12391, 12368, 12365>, 0,
    <12391, 12365, 12389>, 0,
    <12391, 12389, 12387>, 0,
    <12391, 12387, 12390>, 0,
    <12396, 12395, 12386>, 0,
    <12396, 12386, 12390>, 0,
    <12396, 12390, 12387>, 0,
    <12396, 12387, 12393>, 0,
    <12396, 12393, 2357>, 0,
    <12396, 2357, 12394>, 0,
    <12396, 12394, 12392>, 0,
    <12396, 12392, 12395>, 0,
    <12398, 12388, 12386>, 0,
    <12398, 12386, 12395>, 0,
    <12398, 12395, 12392>, 0,
    <12398, 12392, 12397>, 0,
    <12398, 12397, 12327>, 0,
    <12398, 12327, 12371>, 0,
    <12398, 12371, 12366>, 0,
    <12398, 12366, 12388>, 0,
    <12407, 12406, 12399>, 0,
    <12407, 12399, 12403>, 0,
    <12407, 12403, 12400>, 0,
    <12407, 12400, 12404>, 0,
    <12407, 12404, 12401>, 0,
    <12407, 12401, 12405>, 0,
    <12407, 12405, 12402>, 0,
    <12407, 12402, 12406>, 0,
    <12410, 12409, 12399>, 0,
    <12410, 12399, 12406>, 0,
    <12410, 12406, 12402>, 0,
    <12410, 12402, 12408>, 0,
    <12410, 12408, 2343>, 0,
    <12410, 2343, 12383>, 0,
    <12410, 12383, 12379>, 0,
    <12410, 12379, 12409>, 0,
    <12412, 12403, 12399>, 0,
    <12412, 12399, 12409>, 0,
    <12412, 12409, 12379>, 0,
    <12412, 12379, 12380>, 0,
    <12412, 12380, 12301>, 0,
    <12412, 12301, 12411>, 0,
    <12412, 12411, 12400>, 0,
    <12412, 12400, 12403>, 0,
    <12421, 12420, 12413>, 0,
    <12421, 12413, 12417>, 0,
    <12421, 12417, 12414>, 0,
    <12421, 12414, 12418>, 0,
    <12421, 12418, 12415>, 0,
    <12421, 12415, 12419>, 0,
    <12421, 12419, 12416>, 0,
    <12421, 12416, 12420>, 0,
    <12424, 12423, 12413>, 0,
    <12424, 12413, 12420>, 0,
    <12424, 12420, 12416>, 0,
    <12424, 12416, 12422>, 0,
    <12424, 12422, 12327>, 0,
    <12424, 12327, 12397>, 0,
    <12424, 12397, 12392>, 0,
    <12424, 12392, 12423>, 0,
    <12426, 12417, 12413>, 0,
    <12426, 12413, 12423>, 0,
    <12426, 12423, 12392>, 0,
    <12426, 12392, 12394>, 0,
    <12426, 12394, 2357>, 0,
    <12426, 2357, 12425>, 0,
    <12426, 12425, 12414>, 0,
    <12426, 12414, 12417>, 0,
    <12435, 12434, 12427>, 0,
    <12435, 12427, 12431>, 0,
    <12435, 12431, 12428>, 0,
    <12435, 12428, 12432>, 0,
    <12435, 12432, 12429>, 0,
    <12435, 12429, 12433>, 0,
    <12435, 12433, 12430>, 0,
    <12435, 12430, 12434>, 0,
    <12438, 12437, 12427>, 0,
    <12438, 12427, 12434>, 0,
    <12438, 12434, 12430>, 0,
    <12438, 12430, 12436>, 0,
    <12438, 12436, 2369>, 0,
    <12438, 2369, 12268>, 0,
    <12438, 12268, 12265>, 0,
    <12438, 12265, 12437>, 0,
    <12440, 12431, 12427>, 0,
    <12440, 12427, 12437>, 0,
    <12440, 12437, 12265>, 0,
    <12440, 12265, 12275>, 0,
    <12440, 12275, 12181>, 0,
    <12440, 12181, 12439>, 0,
    <12440, 12439, 12428>, 0,
    <12440, 12428, 12431>, 0,
    <12446, 12445, 12441>, 0,
    <12446, 12441, 12443>, 0,
    <12446, 12443, 11667>, 0,
    <12446, 11667, 11668>, 0,
    <12446, 11668, 11655>, 0,
    <12446, 11655, 12444>, 0,
    <12446, 12444, 12442>, 0,
    <12446, 12442, 12445>, 0,
    <12451, 12450, 12441>, 0,
    <12451, 12441, 12445>, 0,
    <12451, 12445, 12442>, 0,
    <12451, 12442, 12448>, 0,
    <12451, 12448, 2495>, 0,
    <12451, 2495, 12449>, 0,
    <12451, 12449, 12447>, 0,
    <12451, 12447, 12450>, 0,
    <12453, 12443, 12441>, 0,
    <12453, 12441, 12450>, 0,
    <12453, 12450, 12447>, 0,
    <12453, 12447, 12452>, 0,
    <12453, 12452, 2250>, 0,
    <12453, 2250, 11671>, 0,
    <12453, 11671, 11667>, 0,
    <12453, 11667, 12443>, 0,
    <12459, 12458, 12454>, 0,
    <12459, 12454, 12456>, 0,
    <12459, 12456, 11715>, 0,
    <12459, 11715, 11716>, 0,
    <12459, 11716, 11703>, 0,
    <12459, 11703, 12457>, 0,
    <12459, 12457, 12455>, 0,
    <12459, 12455, 12458>, 0,
    <12465, 12464, 12454>, 0,
    <12465, 12454, 12458>, 0,
    <12465, 12458, 12455>, 0,
    <12465, 12455, 12462>, 0,
    <12465, 12462, 12460>, 0,
    <12465, 12460, 12463>, 0,
    <12465, 12463, 12461>, 0,
    <12465, 12461, 12464>, 0,
    <12467, 12456, 12454>, 0,
    <12467, 12454, 12464>, 0,
    <12467, 12464, 12461>, 0,
    <12467, 12461, 12466>, 0,
    <12467, 12466, 11655>, 0,
    <12467, 11655, 11719>, 0,
    <12467, 11719, 11715>, 0,
    <12467, 11715, 12456>, 0,
    <12471, 12470, 12468>, 0,
    <12471, 12468, 12469>, 0,
    <12471, 12469, 12442>, 0,
    <12471, 12442, 12444>, 0,
    <12471, 12444, 11655>, 0,
    <12471, 11655, 12466>, 0,
    <12471, 12466, 12461>, 0,
    <12471, 12461, 12470>, 0,
    <12475, 12474, 12468>, 0,
    <12475, 12468, 12470>, 0,
    <12475, 12470, 12461>, 0,
    <12475, 12461, 12463>, 0,
    <12475, 12463, 12460>, 0,
    <12475, 12460, 12473>, 0,
    <12475, 12473, 12472>, 0,
    <12475, 12472, 12474>, 0,
    <12477, 12469, 12468>, 0,
    <12477, 12468, 12474>, 0,
    <12477, 12474, 12472>, 0,
    <12477, 12472, 12476>, 0,
    <12477, 12476, 2495>, 0,
    <12477, 2495, 12448>, 0,
    <12477, 12448, 12442>, 0,
    <12477, 12442, 12469>, 0,
    <12486, 12485, 12478>, 0,
    <12486, 12478, 12482>, 0,
    <12486, 12482, 12479>, 0,
    <12486, 12479, 12483>, 0,
    <12486, 12483, 12480>, 0,
    <12486, 12480, 12484>, 0,
    <12486, 12484, 12481>, 0,
    <12486, 12481, 12485>, 0,
    <12491, 12490, 12478>, 0,
    <12491, 12478, 12485>, 0,
    <12491, 12485, 12481>, 0,
    <12491, 12481, 12488>, 0,
    <12491, 12488, 2277>, 0,
    <12491, 2277, 12489>, 0,
    <12491, 12489, 12487>, 0,
    <12491, 12487, 12490>, 0,
    <12494, 12482, 12478>, 0,
    <12494, 12478, 12490>, 0,
    <12494, 12490, 12487>, 0,
    <12494, 12487, 12492>, 0,
    <12494, 12492, 2519>, 0,
    <12494, 2519, 12493>, 0,
    <12494, 12493, 12479>, 0,
    <12494, 12479, 12482>, 0,
    <12500, 12499, 12495>, 0,
    <12500, 12495, 12497>, 0,
    <12500, 12497, 12481>, 0,
    <12500, 12481, 12484>, 0,
    <12500, 12484, 12480>, 0,
    <12500, 12480, 12498>, 0,
    <12500, 12498, 12496>, 0,
    <12500, 12496, 12499>, 0,
    <12503, 12502, 12495>, 0,
    <12503, 12495, 12499>, 0,
    <12503, 12499, 12496>, 0,
    <12503, 12496, 12501>, 0,
    <12503, 12501, 11675>, 0,
    <12503, 11675, 11678>, 0,
    <12503, 11678, 11674>, 0,
    <12503, 11674, 12502>, 0,
    <12504, 12497, 12495>, 0,
    <12504, 12495, 12502>, 0,
    <12504, 12502, 11674>, 0,
    <12504, 11674, 11685>, 0,
    <12504, 11685, 2277>, 0,
    <12504, 2277, 12488>, 0,
    <12504, 12488, 12481>, 0,
    <12504, 12481, 12497>, 0,
    <12510, 12509, 12505>, 0,
    <12510, 12505, 12507>, 0,
    <12510, 12507, 11824>, 0,
    <12510, 11824, 11825>, 0,
    <12510, 11825, 11812>, 0,
    <12510, 11812, 12508>, 0,
    <12510, 12508, 12506>, 0,
    <12510, 12506, 12509>, 0,
    <12516, 12515, 12505>, 0,
    <12516, 12505, 12509>, 0,
    <12516, 12509, 12506>, 0,
    <12516, 12506, 12513>, 0,
    <12516, 12513, 12511>, 0,
    <12516, 12511, 12514>, 0,
    <12516, 12514, 12512>, 0,
    <12516, 12512, 12515>, 0,
    <12518, 12507, 12505>, 0,
    <12518, 12505, 12515>, 0,
    <12518, 12515, 12512>, 0,
    <12518, 12512, 12517>, 0,
    <12518, 12517, 11703>, 0,
    <12518, 11703, 11828>, 0,
    <12518, 11828, 11824>, 0,
    <12518, 11824, 12507>, 0,
    <12522, 12521, 12519>, 0,
    <12522, 12519, 12520>, 0,
    <12522, 12520, 12455>, 0,
    <12522, 12455, 12457>, 0,
    <12522, 12457, 11703>, 0,
    <12522, 11703, 12517>, 0,
    <12522, 12517, 12512>, 0,
    <12522, 12512, 12521>, 0,
    <12526, 12525, 12519>, 0,
    <12526, 12519, 12521>, 0,
    <12526, 12521, 12512>, 0,
    <12526, 12512, 12514>, 0,
    <12526, 12514, 12511>, 0,
    <12526, 12511, 12524>, 0,
    <12526, 12524, 12523>, 0,
    <12526, 12523, 12525>, 0,
    <12528, 12520, 12519>, 0,
    <12528, 12519, 12525>, 0,
    <12528, 12525, 12523>, 0,
    <12528, 12523, 12527>, 0,
    <12528, 12527, 12460>, 0,
    <12528, 12460, 12462>, 0,
    <12528, 12462, 12455>, 0,
    <12528, 12455, 12520>, 0,
    <12537, 12536, 12529>, 0,
    <12537, 12529, 12533>, 0,
    <12537, 12533, 12530>, 0,
    <12537, 12530, 12534>, 0,
    <12537, 12534, 12531>, 0,
    <12537, 12531, 12535>, 0,
    <12537, 12535, 12532>, 0,
    <12537, 12532, 12536>, 0,
    <12540, 12539, 12529>, 0,
    <12540, 12529, 12536>, 0,
    <12540, 12536, 12532>, 0,
    <12540, 12532, 12538>, 0,
    <12540, 12538, 11675>, 0,
    <12540, 11675, 12501>, 0,
    <12540, 12501, 12496>, 0,
    <12540, 12496, 12539>, 0,
    <12542, 12533, 12529>, 0,
    <12542, 12529, 12539>, 0,
    <12542, 12539, 12496>, 0,
    <12542, 12496, 12498>, 0,
    <12542, 12498, 12480>, 0,
    <12542, 12480, 12541>, 0,
    <12542, 12541, 12530>, 0,
    <12542, 12530, 12533>, 0,
    <12548, 12547, 12543>, 0,
    <12548, 12543, 12545>, 0,
    <12548, 12545, 12532>, 0,
    <12548, 12532, 12535>, 0,
    <12548, 12535, 12531>, 0,
    <12548, 12531, 12546>, 0,
    <12548, 12546, 12544>, 0,
    <12548, 12544, 12547>, 0,
    <12551, 12550, 12543>, 0,
    <12551, 12543, 12547>, 0,
    <12551, 12547, 12544>, 0,
    <12551, 12544, 12549>, 0,
    <12551, 12549, 11723>, 0,
    <12551, 11723, 11726>, 0,
    <12551, 11726, 11722>, 0,
    <12551, 11722, 12550>, 0,
    <12552, 12545, 12543>, 0,
    <12552, 12543, 12550>, 0,
    <12552, 12550, 11722>, 0,
    <12552, 11722, 11733>, 0,
    <12552, 11733, 11675>, 0,
    <12552, 11675, 12538>, 0,
    <12552, 12538, 12532>, 0,
    <12552, 12532, 12545>, 0,
    <12558, 12557, 12553>, 0,
    <12558, 12553, 12555>, 0,
    <12558, 12555, 12554>, 0,
    <12558, 12554, 12556>, 0,
    <12558, 12556, 11768>, 0,
    <12558, 11768, 11780>, 0,
    <12558, 11780, 11776>, 0,
    <12558, 11776, 12557>, 0,
    <12562, 12561, 12553>, 0,
    <12562, 12553, 12557>, 0,
    <12562, 12557, 11776>, 0,
    <12562, 11776, 11777>, 0,
    <12562, 11777, 2264>, 0,
    <12562, 2264, 12560>, 0,
    <12562, 12560, 12559>, 0,
    <12562, 12559, 12561>, 0,
    <12565, 12555, 12553>, 0,
    <12565, 12553, 12561>, 0,
    <12565, 12561, 12559>, 0,
    <12565, 12559, 12563>, 0,
    <12565, 12563, 2547>, 0,
    <12565, 2547, 12564>, 0,
    <12565, 12564, 12554>, 0,
    <12565, 12554, 12555>, 0,
    <12571, 12570, 12566>, 0,
    <12571, 12566, 12568>, 0,
    <12571, 12568, 12567>, 0,
    <12571, 12567, 12569>, 0,
    <12571, 12569, 11864>, 0,
    <12571, 11864, 11876>, 0,
    <12571, 11876, 11872>, 0,
    <12571, 11872, 12570>, 0,
    <12575, 12574, 12566>, 0,
    <12575, 12566, 12570>, 0,
    <12575, 12570, 11872>, 0,
    <12575, 11872, 11873>, 0,
    <12575, 11873, 11768>, 0,
    <12575, 11768, 12573>, 0,
    <12575, 12573, 12572>, 0,
    <12575, 12572, 12574>, 0,
    <12579, 12568, 12566>, 0,
    <12579, 12566, 12574>, 0,
    <12579, 12574, 12572>, 0,
    <12579, 12572, 12577>, 0,
    <12579, 12577, 12576>, 0,
    <12579, 12576, 12578>, 0,
    <12579, 12578, 12567>, 0,
    <12579, 12567, 12568>, 0,
    <12583, 12582, 12580>, 0,
    <12583, 12580, 12581>, 0,
    <12583, 12581, 12572>, 0,
    <12583, 12572, 12573>, 0,
    <12583, 12573, 11768>, 0,
    <12583, 11768, 12556>, 0,
    <12583, 12556, 12554>, 0,
    <12583, 12554, 12582>, 0,
    <12587, 12586, 12580>, 0,
    <12587, 12580, 12582>, 0,
    <12587, 12582, 12554>, 0,
    <12587, 12554, 12564>, 0,
    <12587, 12564, 2547>, 0,
    <12587, 2547, 12585>, 0,
    <12587, 12585, 12584>, 0,
    <12587, 12584, 12586>, 0,
    <12589, 12581, 12580>, 0,
    <12589, 12580, 12586>, 0,
    <12589, 12586, 12584>, 0,
    <12589, 12584, 12588>, 0,
    <12589, 12588, 12576>, 0,
    <12589, 12576, 12577>, 0,
    <12589, 12577, 12572>, 0,
    <12589, 12572, 12581>, 0,
    <12598, 12597, 12590>, 0,
    <12598, 12590, 12594>, 0,
    <12598, 12594, 12591>, 0,
    <12598, 12591, 12595>, 0,
    <12598, 12595, 12592>, 0,
    <12598, 12592, 12596>, 0,
    <12598, 12596, 12593>, 0,
    <12598, 12593, 12597>, 0,
    <12603, 12602, 12590>, 0,
    <12603, 12590, 12597>, 0,
    <12603, 12597, 12593>, 0,
    <12603, 12593, 12600>, 0,
    <12603, 12600, 2525>, 0,
    <12603, 2525, 12601>, 0,
    <12603, 12601, 12599>, 0,
    <12603, 12599, 12602>, 0,
    <12606, 12594, 12590>, 0,
    <12606, 12590, 12602>, 0,
    <12606, 12602, 12599>, 0,
    <12606, 12599, 12604>, 0,
    <12606, 12604, 2270>, 0,
    <12606, 2270, 12605>, 0,
    <12606, 12605, 12591>, 0,
    <12606, 12591, 12594>, 0,
    <12612, 12611, 12607>, 0,
    <12612, 12607, 12609>, 0,
    <12612, 12609, 12608>, 0,
    <12612, 12608, 12610>, 0,
    <12612, 12610, 12592>, 0,
    <12612, 12592, 12595>, 0,
    <12612, 12595, 12591>, 0,
    <12612, 12591, 12611>, 0,
    <12614, 12613, 12607>, 0,
    <12614, 12607, 12611>, 0,
    <12614, 12611, 12591>, 0,
    <12614, 12591, 12605>, 0,
    <12614, 12605, 2270>, 0,
    <12614, 2270, 11791>, 0,
    <12614, 11791, 11785>, 0,
    <12614, 11785, 12613>, 0,
    <12616, 12609, 12607>, 0,
    <12616, 12607, 12613>, 0,
    <12616, 12613, 11785>, 0,
    <12616, 11785, 11788>, 0,
    <12616, 11788, 11784>, 0,
    <12616, 11784, 12615>, 0,
    <12616, 12615, 12608>, 0,
    <12616, 12608, 12609>, 0,
    <12622, 12621, 12617>, 0,
    <12622, 12617, 12619>, 0,
    <12622, 12619, 11968>, 0,
    <12622, 11968, 11969>, 0,
    <12622, 11969, 11956>, 0,
    <12622, 11956, 12620>, 0,
    <12622, 12620, 12618>, 0,
    <12622, 12618, 12621>, 0,
    <12628, 12627, 12617>, 0,
    <12628, 12617, 12621>, 0,
    <12628, 12621, 12618>, 0,
    <12628, 12618, 12625>, 0,
    <12628, 12625, 12623>, 0,
    <12628, 12623, 12626>, 0,
    <12628, 12626, 12624>, 0,
    <12628, 12624, 12627>, 0,
    <12630, 12619, 12617>, 0,
    <12630, 12617, 12627>, 0,
    <12630, 12627, 12624>, 0,
    <12630, 12624, 12629>, 0,
    <12630, 12629, 11812>, 0,
    <12630, 11812, 11972>, 0,
    <12630, 11972, 11968>, 0,
    <12630, 11968, 12619>, 0,
    <12634, 12633, 12631>, 0,
    <12634, 12631, 12632>, 0,
    <12634, 12632, 12506>, 0,
    <12634, 12506, 12508>, 0,
    <12634, 12508, 11812>, 0,
    <12634, 11812, 12629>, 0,
    <12634, 12629, 12624>, 0,
    <12634, 12624, 12633>, 0,
    <12638, 12637, 12631>, 0,
    <12638, 12631, 12633>, 0,
    <12638, 12633, 12624>, 0,
    <12638, 12624, 12626>, 0,
    <12638, 12626, 12623>, 0,
    <12638, 12623, 12636>, 0,
    <12638, 12636, 12635>, 0,
    <12638, 12635, 12637>, 0,
    <12640, 12632, 12631>, 0,
    <12640, 12631, 12637>, 0,
    <12640, 12637, 12635>, 0,
    <12640, 12635, 12639>, 0,
    <12640, 12639, 12511>, 0,
    <12640, 12511, 12513>, 0,
    <12640, 12513, 12506>, 0,
    <12640, 12506, 12632>, 0,
    <12649, 12648, 12641>, 0,
    <12649, 12641, 12645>, 0,
    <12649, 12645, 12642>, 0,
    <12649, 12642, 12646>, 0,
    <12649, 12646, 12643>, 0,
    <12649, 12643, 12647>, 0,
    <12649, 12647, 12644>, 0,
    <12649, 12644, 12648>, 0,
    <12652, 12651, 12641>, 0,
    <12652, 12641, 12648>, 0,
    <12652, 12648, 12644>, 0,
    <12652, 12644, 12650>, 0,
    <12652, 12650, 11723>, 0,
    <12652, 11723, 12549>, 0,
    <12652, 12549, 12544>, 0,
    <12652, 12544, 12651>, 0,
    <12654, 12645, 12641>, 0,
    <12654, 12641, 12651>, 0,
    <12654, 12651, 12544>, 0,
    <12654, 12544, 12546>, 0,
    <12654, 12546, 12531>, 0,
    <12654, 12531, 12653>, 0,
    <12654, 12653, 12642>, 0,
    <12654, 12642, 12645>, 0,
    <12660, 12659, 12655>, 0,
    <12660, 12655, 12657>, 0,
    <12660, 12657, 12644>, 0,
    <12660, 12644, 12647>, 0,
    <12660, 12647, 12643>, 0,
    <12660, 12643, 12658>, 0,
    <12660, 12658, 12656>, 0,
    <12660, 12656, 12659>, 0,
    <12663, 12662, 12655>, 0,
    <12663, 12655, 12659>, 0,
    <12663, 12659, 12656>, 0,
    <12663, 12656, 12661>, 0,
    <12663, 12661, 11832>, 0,
    <12663, 11832, 11835>, 0,
    <12663, 11835, 11831>, 0,
    <12663, 11831, 12662>, 0,
    <12664, 12657, 12655>, 0,
    <12664, 12655, 12662>, 0,
    <12664, 12662, 11831>, 0,
    <12664, 11831, 11842>, 0,
    <12664, 11842, 11723>, 0,
    <12664, 11723, 12650>, 0,
    <12664, 12650, 12644>, 0,
    <12664, 12644, 12657>, 0,
    <12670, 12669, 12665>, 0,
    <12670, 12665, 12667>, 0,
    <12670, 12667, 12666>, 0,
    <12670, 12666, 12668>, 0,
    <12670, 12668, 11912>, 0,
    <12670, 11912, 11924>, 0,
    <12670, 11924, 11920>, 0,
    <12670, 11920, 12669>, 0,
    <12674, 12673, 12665>, 0,
    <12674, 12665, 12669>, 0,
    <12674, 12669, 11920>, 0,
    <12674, 11920, 11921>, 0,
    <12674, 11921, 11864>, 0,
    <12674, 11864, 12672>, 0,
    <12674, 12672, 12671>, 0,
    <12674, 12671, 12673>, 0,
    <12678, 12667, 12665>, 0,
    <12678, 12665, 12673>, 0,
    <12678, 12673, 12671>, 0,
    <12678, 12671, 12676>, 0,
    <12678, 12676, 12675>, 0,
    <12678, 12675, 12677>, 0,
    <12678, 12677, 12666>, 0,
    <12678, 12666, 12667>, 0,
    <12682, 12681, 12679>, 0,
    <12682, 12679, 12680>, 0,
    <12682, 12680, 12671>, 0,
    <12682, 12671, 12672>, 0,
    <12682, 12672, 11864>, 0,
    <12682, 11864, 12569>, 0,
    <12682, 12569, 12567>, 0,
    <12682, 12567, 12681>, 0,
    <12686, 12685, 12679>, 0,
    <12686, 12679, 12681>, 0,
    <12686, 12681, 12567>, 0,
    <12686, 12567, 12578>, 0,
    <12686, 12578, 12576>, 0,
    <12686, 12576, 12684>, 0,
    <12686, 12684, 12683>, 0,
    <12686, 12683, 12685>, 0,
    <12688, 12680, 12679>, 0,
    <12688, 12679, 12685>, 0,
    <12688, 12685, 12683>, 0,
    <12688, 12683, 12687>, 0,
    <12688, 12687, 12675>, 0,
    <12688, 12675, 12676>, 0,
    <12688, 12676, 12671>, 0,
    <12688, 12671, 12680>, 0,
    <12697, 12696, 12689>, 0,
    <12697, 12689, 12693>, 0,
    <12697, 12693, 12690>, 0,
    <12697, 12690, 12694>, 0,
    <12697, 12694, 12691>, 0,
    <12697, 12691, 12695>, 0,
    <12697, 12695, 12692>, 0,
    <12697, 12692, 12696>, 0,
    <12700, 12699, 12689>, 0,
    <12700, 12689, 12696>, 0,
    <12700, 12696, 12692>, 0,
    <12700, 12692, 12698>, 0,
    <12700, 12698, 12592>, 0,
    <12700, 12592, 12610>, 0,
    <12700, 12610, 12608>, 0,
    <12700, 12608, 12699>, 0,
    <12702, 12693, 12689>, 0,
    <12702, 12689, 12699>, 0,
    <12702, 12699, 12608>, 0,
    <12702, 12608, 12615>, 0,
    <12702, 12615, 11784>, 0,
    <12702, 11784, 12701>, 0,
    <12702, 12701, 12690>, 0,
    <12702, 12690, 12693>, 0,
    <12708, 12707, 12703>, 0,
    <12708, 12703, 12705>, 0,
    <12708, 12705, 12704>, 0,
    <12708, 12704, 12706>, 0,
    <12708, 12706, 12691>, 0,
    <12708, 12691, 12694>, 0,
    <12708, 12694, 12690>, 0,
    <12708, 12690, 12707>, 0,
    <12710, 12709, 12703>, 0,
    <12710, 12703, 12707>, 0,
    <12710, 12707, 12690>, 0,
    <12710, 12690, 12701>, 0,
    <12710, 12701, 11784>, 0,
    <12710, 11784, 11887>, 0,
    <12710, 11887, 11881>, 0,
    <12710, 11881, 12709>, 0,
    <12712, 12705, 12703>, 0,
    <12712, 12703, 12709>, 0,
    <12712, 12709, 11881>, 0,
    <12712, 11881, 11884>, 0,
    <12712, 11884, 11880>, 0,
    <12712, 11880, 12711>, 0,
    <12712, 12711, 12704>, 0,
    <12712, 12704, 12705>, 0,
    <12718, 12717, 12713>, 0,
    <12718, 12713, 12715>, 0,
    <12718, 12715, 12714>, 0,
    <12718, 12714, 12716>, 0,
    <12718, 12716, 12008>, 0,
    <12718, 12008, 12020>, 0,
    <12718, 12020, 12016>, 0,
    <12718, 12016, 12717>, 0,
    <12722, 12721, 12713>, 0,
    <12722, 12713, 12717>, 0,
    <12722, 12717, 12016>, 0,
    <12722, 12016, 12017>, 0,
    <12722, 12017, 11912>, 0,
    <12722, 11912, 12720>, 0,
    <12722, 12720, 12719>, 0,
    <12722, 12719, 12721>, 0,
    <12726, 12715, 12713>, 0,
    <12726, 12713, 12721>, 0,
    <12726, 12721, 12719>, 0,
    <12726, 12719, 12724>, 0,
    <12726, 12724, 12723>, 0,
    <12726, 12723, 12725>, 0,
    <12726, 12725, 12714>, 0,
    <12726, 12714, 12715>, 0,
    <12730, 12729, 12727>, 0,
    <12730, 12727, 12728>, 0,
    <12730, 12728, 12719>, 0,
    <12730, 12719, 12720>, 0,
    <12730, 12720, 11912>, 0,
    <12730, 11912, 12668>, 0,
    <12730, 12668, 12666>, 0,
    <12730, 12666, 12729>, 0,
    <12734, 12733, 12727>, 0,
    <12734, 12727, 12729>, 0,
    <12734, 12729, 12666>, 0,
    <12734, 12666, 12677>, 0,
    <12734, 12677, 12675>, 0,
    <12734, 12675, 12732>, 0,
    <12734, 12732, 12731>, 0,
    <12734, 12731, 12733>, 0,
    <12736, 12728, 12727>, 0,
    <12736, 12727, 12733>, 0,
    <12736, 12733, 12731>, 0,
    <12736, 12731, 12735>, 0,
    <12736, 12735, 12723>, 0,
    <12736, 12723, 12724>, 0,
    <12736, 12724, 12719>, 0,
    <12736, 12719, 12728>, 0,
    <12745, 12744, 12737>, 0,
    <12745, 12737, 12741>, 0,
    <12745, 12741, 12738>, 0,
    <12745, 12738, 12742>, 0,
    <12745, 12742, 12739>, 0,
    <12745, 12739, 12743>, 0,
    <12745, 12743, 12740>, 0,
    <12745, 12740, 12744>, 0,
    <12748, 12747, 12737>, 0,
    <12748, 12737, 12744>, 0,
    <12748, 12744, 12740>, 0,
    <12748, 12740, 12746>, 0,
    <12748, 12746, 12691>, 0,
    <12748, 12691, 12706>, 0,
    <12748, 12706, 12704>, 0,
    <12748, 12704, 12747>, 0,
    <12750, 12741, 12737>, 0,
    <12750, 12737, 12747>, 0,
    <12750, 12747, 12704>, 0,
    <12750, 12704, 12711>, 0,
    <12750, 12711, 11880>, 0,
    <12750, 11880, 12749>, 0,
    <12750, 12749, 12738>, 0,
    <12750, 12738, 12741>, 0,
    <12756, 12755, 12751>, 0,
    <12756, 12751, 12753>, 0,
    <12756, 12753, 12752>, 0,
    <12756, 12752, 12754>, 0,
    <12756, 12754, 12739>, 0,
    <12756, 12739, 12742>, 0,
    <12756, 12742, 12738>, 0,
    <12756, 12738, 12755>, 0,
    <12758, 12757, 12751>, 0,
    <12758, 12751, 12755>, 0,
    <12758, 12755, 12738>, 0,
    <12758, 12738, 12749>, 0,
    <12758, 12749, 11880>, 0,
    <12758, 11880, 11935>, 0,
    <12758, 11935, 11929>, 0,
    <12758, 11929, 12757>, 0,
    <12760, 12753, 12751>, 0,
    <12760, 12751, 12757>, 0,
    <12760, 12757, 11929>, 0,
    <12760, 11929, 11932>, 0,
    <12760, 11932, 11928>, 0,
    <12760, 11928, 12759>, 0,
    <12760, 12759, 12752>, 0,
    <12760, 12752, 12753>, 0,
    <12766, 12765, 12761>, 0,
    <12766, 12761, 12763>, 0,
    <12766, 12763, 12064>, 0,
    <12766, 12064, 12065>, 0,
    <12766, 12065, 12052>, 0,
    <12766, 12052, 12764>, 0,
    <12766, 12764, 12762>, 0,
    <12766, 12762, 12765>, 0,
    <12772, 12771, 12761>, 0,
    <12772, 12761, 12765>, 0,
    <12772, 12765, 12762>, 0,
    <12772, 12762, 12769>, 0,
    <12772, 12769, 12767>, 0,
    <12772, 12767, 12770>, 0,
    <12772, 12770, 12768>, 0,
    <12772, 12768, 12771>, 0,
    <12774, 12763, 12761>, 0,
    <12774, 12761, 12771>, 0,
    <12774, 12771, 12768>, 0,
    <12774, 12768, 12773>, 0,
    <12774, 12773, 11956>, 0,
    <12774, 11956, 12068>, 0,
    <12774, 12068, 12064>, 0,
    <12774, 12064, 12763>, 0,
    <12778, 12777, 12775>, 0,
    <12778, 12775, 12776>, 0,
    <12778, 12776, 12618>, 0,
    <12778, 12618, 12620>, 0,
    <12778, 12620, 11956>, 0,
    <12778, 11956, 12773>, 0,
    <12778, 12773, 12768>, 0,
    <12778, 12768, 12777>, 0,
    <12782, 12781, 12775>, 0,
    <12782, 12775, 12777>, 0,
    <12782, 12777, 12768>, 0,
    <12782, 12768, 12770>, 0,
    <12782, 12770, 12767>, 0,
    <12782, 12767, 12780>, 0,
    <12782, 12780, 12779>, 0,
    <12782, 12779, 12781>, 0,
    <12784, 12776, 12775>, 0,
    <12784, 12775, 12781>, 0,
    <12784, 12781, 12779>, 0,
    <12784, 12779, 12783>, 0,
    <12784, 12783, 12623>, 0,
    <12784, 12623, 12625>, 0,
    <12784, 12625, 12618>, 0,
    <12784, 12618, 12776>, 0,
    <12793, 12792, 12785>, 0,
    <12793, 12785, 12789>, 0,
    <12793, 12789, 12786>, 0,
    <12793, 12786, 12790>, 0,
    <12793, 12790, 12787>, 0,
    <12793, 12787, 12791>, 0,
    <12793, 12791, 12788>, 0,
    <12793, 12788, 12792>, 0,
    <12796, 12795, 12785>, 0,
    <12796, 12785, 12792>, 0,
    <12796, 12792, 12788>, 0,
    <12796, 12788, 12794>, 0,
    <12796, 12794, 11832>, 0,
    <12796, 11832, 12661>, 0,
    <12796, 12661, 12656>, 0,
    <12796, 12656, 12795>, 0,
    <12798, 12789, 12785>, 0,
    <12798, 12785, 12795>, 0,
    <12798, 12795, 12656>, 0,
    <12798, 12656, 12658>, 0,
    <12798, 12658, 12643>, 0,
    <12798, 12643, 12797>, 0,
    <12798, 12797, 12786>, 0,
    <12798, 12786, 12789>, 0,
    <12804, 12803, 12799>, 0,
    <12804, 12799, 12801>, 0,
    <12804, 12801, 12788>, 0,
    <12804, 12788, 12791>, 0,
    <12804, 12791, 12787>, 0,
    <12804, 12787, 12802>, 0,
    <12804, 12802, 12800>, 0,
    <12804, 12800, 12803>, 0,
    <12807, 12806, 12799>, 0,
    <12807, 12799, 12803>, 0,
    <12807, 12803, 12800>, 0,
    <12807, 12800, 12805>, 0,
    <12807, 12805, 11976>, 0,
    <12807, 11976, 11979>, 0,
    <12807, 11979, 11975>, 0,
    <12807, 11975, 12806>, 0,
    <12808, 12801, 12799>, 0,
    <12808, 12799, 12806>, 0,
    <12808, 12806, 11975>, 0,
    <12808, 11975, 11986>, 0,
    <12808, 11986, 11832>, 0,
    <12808, 11832, 12794>, 0,
    <12808, 12794, 12788>, 0,
    <12808, 12788, 12801>, 0,
    <12814, 12813, 12809>, 0,
    <12814, 12809, 12811>, 0,
    <12814, 12811, 12810>, 0,
    <12814, 12810, 12812>, 0,
    <12814, 12812, 12104>, 0,
    <12814, 12104, 12116>, 0,
    <12814, 12116, 12112>, 0,
    <12814, 12112, 12813>, 0,
    <12818, 12817, 12809>, 0,
    <12818, 12809, 12813>, 0,
    <12818, 12813, 12112>, 0,
    <12818, 12112, 12113>, 0,
    <12818, 12113, 12008>, 0,
    <12818, 12008, 12816>, 0,
    <12818, 12816, 12815>, 0,
    <12818, 12815, 12817>, 0,
    <12822, 12811, 12809>, 0,
    <12822, 12809, 12817>, 0,
    <12822, 12817, 12815>, 0,
    <12822, 12815, 12820>, 0,
    <12822, 12820, 12819>, 0,
    <12822, 12819, 12821>, 0,
    <12822, 12821, 12810>, 0,
    <12822, 12810, 12811>, 0,
    <12826, 12825, 12823>, 0,
    <12826, 12823, 12824>, 0,
    <12826, 12824, 12815>, 0,
    <12826, 12815, 12816>, 0,
    <12826, 12816, 12008>, 0,
    <12826, 12008, 12716>, 0,
    <12826, 12716, 12714>, 0,
    <12826, 12714, 12825>, 0,
    <12830, 12829, 12823>, 0,
    <12830, 12823, 12825>, 0,
    <12830, 12825, 12714>, 0,
    <12830, 12714, 12725>, 0,
    <12830, 12725, 12723>, 0,
    <12830, 12723, 12828>, 0,
    <12830, 12828, 12827>, 0,
    <12830, 12827, 12829>, 0,
    <12832, 12824, 12823>, 0,
    <12832, 12823, 12829>, 0,
    <12832, 12829, 12827>, 0,
    <12832, 12827, 12831>, 0,
    <12832, 12831, 12819>, 0,
    <12832, 12819, 12820>, 0,
    <12832, 12820, 12815>, 0,
    <12832, 12815, 12824>, 0,
    <12841, 12840, 12833>, 0,
    <12841, 12833, 12837>, 0,
    <12841, 12837, 12834>, 0,
    <12841, 12834, 12838>, 0,
    <12841, 12838, 12835>, 0,
    <12841, 12835, 12839>, 0,
    <12841, 12839, 12836>, 0,
    <12841, 12836, 12840>, 0,
    <12844, 12843, 12833>, 0,
    <12844, 12833, 12840>, 0,
    <12844, 12840, 12836>, 0,
    <12844, 12836, 12842>, 0,
    <12844, 12842, 12739>, 0,
    <12844, 12739, 12754>, 0,
    <12844, 12754, 12752>, 0,
    <12844, 12752, 12843>, 0,
    <12846, 12837, 12833>, 0,
    <12846, 12833, 12843>, 0,
    <12846, 12843, 12752>, 0,
    <12846, 12752, 12759>, 0,
    <12846, 12759, 11928>, 0,
    <12846, 11928, 12845>, 0,
    <12846, 12845, 12834>, 0,
    <12846, 12834, 12837>, 0,
    <12852, 12851, 12847>, 0,
    <12852, 12847, 12849>, 0,
    <12852, 12849, 12848>, 0,
    <12852, 12848, 12850>, 0,
    <12852, 12850, 12835>, 0,
    <12852, 12835, 12838>, 0,
    <12852, 12838, 12834>, 0,
    <12852, 12834, 12851>, 0,
    <12854, 12853, 12847>, 0,
    <12854, 12847, 12851>, 0,
    <12854, 12851, 12834>, 0,
    <12854, 12834, 12845>, 0,
    <12854, 12845, 11928>, 0,
    <12854, 11928, 12031>, 0,
    <12854, 12031, 12025>, 0,
    <12854, 12025, 12853>, 0,
    <12856, 12849, 12847>, 0,
    <12856, 12847, 12853>, 0,
    <12856, 12853, 12025>, 0,
    <12856, 12025, 12028>, 0,
    <12856, 12028, 12024>, 0,
    <12856, 12024, 12855>, 0,
    <12856, 12855, 12848>, 0,
    <12856, 12848, 12849>, 0,
    <12862, 12861, 12857>, 0,
    <12862, 12857, 12859>, 0,
    <12862, 12859, 12173>, 0,
    <12862, 12173, 12174>, 0,
    <12862, 12174, 12148>, 0,
    <12862, 12148, 12860>, 0,
    <12862, 12860, 12858>, 0,
    <12862, 12858, 12861>, 0,
    <12868, 12867, 12857>, 0,
    <12868, 12857, 12861>, 0,
    <12868, 12861, 12858>, 0,
    <12868, 12858, 12865>, 0,
    <12868, 12865, 12863>, 0,
    <12868, 12863, 12866>, 0,
    <12868, 12866, 12864>, 0,
    <12868, 12864, 12867>, 0,
    <12870, 12859, 12857>, 0,
    <12870, 12857, 12867>, 0,
    <12870, 12867, 12864>, 0,
    <12870, 12864, 12869>, 0,
    <12870, 12869, 12052>, 0,
    <12870, 12052, 12177>, 0,
    <12870, 12177, 12173>, 0,
    <12870, 12173, 12859>, 0,
    <12874, 12873, 12871>, 0,
    <12874, 12871, 12872>, 0,
    <12874, 12872, 12762>, 0,
    <12874, 12762, 12764>, 0,
    <12874, 12764, 12052>, 0,
    <12874, 12052, 12869>, 0,
    <12874, 12869, 12864>, 0,
    <12874, 12864, 12873>, 0,
    <12878, 12877, 12871>, 0,
    <12878, 12871, 12873>, 0,
    <12878, 12873, 12864>, 0,
    <12878, 12864, 12866>, 0,
    <12878, 12866, 12863>, 0,
    <12878, 12863, 12876>, 0,
    <12878, 12876, 12875>, 0,
    <12878, 12875, 12877>, 0,
    <12880, 12872, 12871>, 0,
    <12880, 12871, 12877>, 0,
    <12880, 12877, 12875>, 0,
    <12880, 12875, 12879>, 0,
    <12880, 12879, 12767>, 0,
    <12880, 12767, 12769>, 0,
    <12880, 12769, 12762>, 0,
    <12880, 12762, 12872>, 0,
    <12889, 12888, 12881>, 0,
    <12889, 12881, 12885>, 0,
    <12889, 12885, 12882>, 0,
    <12889, 12882, 12886>, 0,
    <12889, 12886, 12883>, 0,
    <12889, 12883, 12887>, 0,
    <12889, 12887, 12884>, 0,
    <12889, 12884, 12888>, 0,
    <12892, 12891, 12881>, 0,
    <12892, 12881, 12888>, 0,
    <12892, 12888, 12884>, 0,
    <12892, 12884, 12890>, 0,
    <12892, 12890, 11976>, 0,
    <12892, 11976, 12805>, 0,
    <12892, 12805, 12800>, 0,
    <12892, 12800, 12891>, 0,
    <12894, 12885, 12881>, 0,
    <12894, 12881, 12891>, 0,
    <12894, 12891, 12800>, 0,
    <12894, 12800, 12802>, 0,
    <12894, 12802, 12787>, 0,
    <12894, 12787, 12893>, 0,
    <12894, 12893, 12882>, 0,
    <12894, 12882, 12885>, 0,
    <12900, 12899, 12895>, 0,
    <12900, 12895, 12897>, 0,
    <12900, 12897, 12884>, 0,
    <12900, 12884, 12887>, 0,
    <12900, 12887, 12883>, 0,
    <12900, 12883, 12898>, 0,
    <12900, 12898, 12896>, 0,
    <12900, 12896, 12899>, 0,
    <12903, 12902, 12895>, 0,
    <12903, 12895, 12899>, 0,
    <12903, 12899, 12896>, 0,
    <12903, 12896, 12901>, 0,
    <12903, 12901, 12072>, 0,
    <12903, 12072, 12075>, 0,
    <12903, 12075, 12071>, 0,
    <12903, 12071, 12902>, 0,
    <12904, 12897, 12895>, 0,
    <12904, 12895, 12902>, 0,
    <12904, 12902, 12071>, 0,
    <12904, 12071, 12082>, 0,
    <12904, 12082, 11976>, 0,
    <12904, 11976, 12890>, 0,
    <12904, 12890, 12884>, 0,
    <12904, 12884, 12897>, 0,
    <12910, 12909, 12905>, 0,
    <12910, 12905, 12907>, 0,
    <12910, 12907, 12906>, 0,
    <12910, 12906, 12908>, 0,
    <12910, 12908, 12213>, 0,
    <12910, 12213, 12225>, 0,
    <12910, 12225, 12221>, 0,
    <12910, 12221, 12909>, 0,
    <12914, 12913, 12905>, 0,
    <12914, 12905, 12909>, 0,
    <12914, 12909, 12221>, 0,
    <12914, 12221, 12222>, 0,
    <12914, 12222, 12104>, 0,
    <12914, 12104, 12912>, 0,
    <12914, 12912, 12911>, 0,
    <12914, 12911, 12913>, 0,
    <12918, 12907, 12905>, 0,
    <12918, 12905, 12913>, 0,
    <12918, 12913, 12911>, 0,
    <12918, 12911, 12916>, 0,
    <12918, 12916, 12915>, 0,
    <12918, 12915, 12917>, 0,
    <12918, 12917, 12906>, 0,
    <12918, 12906, 12907>, 0,
    <12922, 12921, 12919>, 0,
    <12922, 12919, 12920>, 0,
    <12922, 12920, 12911>, 0,
    <12922, 12911, 12912>, 0,
    <12922, 12912, 12104>, 0,
    <12922, 12104, 12812>, 0,
    <12922, 12812, 12810>, 0,
    <12922, 12810, 12921>, 0,
    <12926, 12925, 12919>, 0,
    <12926, 12919, 12921>, 0,
    <12926, 12921, 12810>, 0,
    <12926, 12810, 12821>, 0,
    <12926, 12821, 12819>, 0,
    <12926, 12819, 12924>, 0,
    <12926, 12924, 12923>, 0,
    <12926, 12923, 12925>, 0,
    <12928, 12920, 12919>, 0,
    <12928, 12919, 12925>, 0,
    <12928, 12925, 12923>, 0,
    <12928, 12923, 12927>, 0,
    <12928, 12927, 12915>, 0,
    <12928, 12915, 12916>, 0,
    <12928, 12916, 12911>, 0,
    <12928, 12911, 12920>, 0,
    <12937, 12936, 12929>, 0,
    <12937, 12929, 12933>, 0,
    <12937, 12933, 12930>, 0,
    <12937, 12930, 12934>, 0,
    <12937, 12934, 12931>, 0,
    <12937, 12931, 12935>, 0,
    <12937, 12935, 12932>, 0,
    <12937, 12932, 12936>, 0,
    <12940, 12939, 12929>, 0,
    <12940, 12929, 12936>, 0,
    <12940, 12936, 12932>, 0,
    <12940, 12932, 12938>, 0,
    <12940, 12938, 12835>, 0,
    <12940, 12835, 12850>, 0,
    <12940, 12850, 12848>, 0,
    <12940, 12848, 12939>, 0,
    <12942, 12933, 12929>, 0,
    <12942, 12929, 12939>, 0,
    <12942, 12939, 12848>, 0,
    <12942, 12848, 12855>, 0,
    <12942, 12855, 12024>, 0,
    <12942, 12024, 12941>, 0,
    <12942, 12941, 12930>, 0,
    <12942, 12930, 12933>, 0,
    <12948, 12947, 12943>, 0,
    <12948, 12943, 12945>, 0,
    <12948, 12945, 12944>, 0,
    <12948, 12944, 12946>, 0,
    <12948, 12946, 12931>, 0,
    <12948, 12931, 12934>, 0,
    <12948, 12934, 12930>, 0,
    <12948, 12930, 12947>, 0,
    <12950, 12949, 12943>, 0,
    <12950, 12943, 12947>, 0,
    <12950, 12947, 12930>, 0,
    <12950, 12930, 12941>, 0,
    <12950, 12941, 12024>, 0,
    <12950, 12024, 12127>, 0,
    <12950, 12127, 12121>, 0,
    <12950, 12121, 12949>, 0,
    <12952, 12945, 12943>, 0,
    <12952, 12943, 12949>, 0,
    <12952, 12949, 12121>, 0,
    <12952, 12121, 12124>, 0,
    <12952, 12124, 12120>, 0,
    <12952, 12120, 12951>, 0,
    <12952, 12951, 12944>, 0,
    <12952, 12944, 12945>, 0,
    <12960, 12959, 12953>, 0,
    <12960, 12953, 12956>, 0,
    <12960, 12956, 12954>, 0,
    <12960, 12954, 12957>, 0,
    <12960, 12957, 2312>, 0,
    <12960, 2312, 12958>, 0,
    <12960, 12958, 12955>, 0,
    <12960, 12955, 12959>, 0,
    <12965, 12964, 12953>, 0,
    <12965, 12953, 12959>, 0,
    <12965, 12959, 12955>, 0,
    <12965, 12955, 12962>, 0,
    <12965, 12962, 2565>, 0,
    <12965, 2565, 12963>, 0,
    <12965, 12963, 12961>, 0,
    <12965, 12961, 12964>, 0,
    <12969, 12956, 12953>, 0,
    <12969, 12953, 12964>, 0,
    <12969, 12964, 12961>, 0,
    <12969, 12961, 12967>, 0,
    <12969, 12967, 12966>, 0,
    <12969, 12966, 12968>, 0,
    <12969, 12968, 12954>, 0,
    <12969, 12954, 12956>, 0,
    <12973, 12972, 12970>, 0,
    <12973, 12970, 12971>, 0,
    <12973, 12971, 12257>, 0,
    <12973, 12257, 12259>, 0,
    <12973, 12259, 2312>, 0,
    <12973, 2312, 12957>, 0,
    <12973, 12957, 12954>, 0,
    <12973, 12954, 12972>, 0,
    <12977, 12976, 12970>, 0,
    <12977, 12970, 12972>, 0,
    <12977, 12972, 12954>, 0,
    <12977, 12954, 12968>, 0,
    <12977, 12968, 12966>, 0,
    <12977, 12966, 12975>, 0,
    <12977, 12975, 12974>, 0,
    <12977, 12974, 12976>, 0,
    <12979, 12971, 12970>, 0,
    <12979, 12970, 12976>, 0,
    <12979, 12976, 12974>, 0,
    <12979, 12974, 12978>, 0,
    <12979, 12978, 12148>, 0,
    <12979, 12148, 12262>, 0,
    <12979, 12262, 12257>, 0,
    <12979, 12257, 12971>, 0,
    <12983, 12982, 12980>, 0,
    <12983, 12980, 12981>, 0,
    <12983, 12981, 12858>, 0,
    <12983, 12858, 12860>, 0,
    <12983, 12860, 12148>, 0,
    <12983, 12148, 12978>, 0,
    <12983, 12978, 12974>, 0,
    <12983, 12974, 12982>, 0,
    <12987, 12986, 12980>, 0,
    <12987, 12980, 12982>, 0,
    <12987, 12982, 12974>, 0,
    <12987, 12974, 12975>, 0,
    <12987, 12975, 12966>, 0,
    <12987, 12966, 12985>, 0,
    <12987, 12985, 12984>, 0,
    <12987, 12984, 12986>, 0,
    <12989, 12981, 12980>, 0,
    <12989, 12980, 12986>, 0,
    <12989, 12986, 12984>, 0,
    <12989, 12984, 12988>, 0,
    <12989, 12988, 12863>, 0,
    <12989, 12863, 12865>, 0,
    <12989, 12865, 12858>, 0,
    <12989, 12858, 12981>, 0,
    <12998, 12997, 12990>, 0,
    <12998, 12990, 12994>, 0,
    <12998, 12994, 12991>, 0,
    <12998, 12991, 12995>, 0,
    <12998, 12995, 12992>, 0,
    <12998, 12992, 12996>, 0,
    <12998, 12996, 12993>, 0,
    <12998, 12993, 12997>, 0,
    <13001, 13000, 12990>, 0,
    <13001, 12990, 12997>, 0,
    <13001, 12997, 12993>, 0,
    <13001, 12993, 12999>, 0,
    <13001, 12999, 12072>, 0,
    <13001, 12072, 12901>, 0,
    <13001, 12901, 12896>, 0,
    <13001, 12896, 13000>, 0,
    <13003, 12994, 12990>, 0,
    <13003, 12990, 13000>, 0,
    <13003, 13000, 12896>, 0,
    <13003, 12896, 12898>, 0,
    <13003, 12898, 12883>, 0,
    <13003, 12883, 13002>, 0,
    <13003, 13002, 12991>, 0,
    <13003, 12991, 12994>, 0,
    <13009, 13008, 13004>, 0,
    <13009, 13004, 13006>, 0,
    <13009, 13006, 12993>, 0,
    <13009, 12993, 12996>, 0,
    <13009, 12996, 12992>, 0,
    <13009, 12992, 13007>, 0,
    <13009, 13007, 13005>, 0,
    <13009, 13005, 13008>, 0,
    <13012, 13011, 13004>, 0,
    <13012, 13004, 13008>, 0,
    <13012, 13008, 13005>, 0,
    <13012, 13005, 13010>, 0,
    <13012, 13010, 12181>, 0,
    <13012, 12181, 12184>, 0,
    <13012, 12184, 12180>, 0,
    <13012, 12180, 13011>, 0,
    <13013, 13006, 13004>, 0,
    <13013, 13004, 13011>, 0,
    <13013, 13011, 12180>, 0,
    <13013, 12180, 12191>, 0,
    <13013, 12191, 12072>, 0,
    <13013, 12072, 12999>, 0,
    <13013, 12999, 12993>, 0,
    <13013, 12993, 13006>, 0,
    <13019, 13018, 13014>, 0,
    <13019, 13014, 13016>, 0,
    <13019, 13016, 13015>, 0,
    <13019, 13015, 13017>, 0,
    <13019, 13017, 12301>, 0,
    <13019, 12301, 12323>, 0,
    <13019, 12323, 12319>, 0,
    <13019, 12319, 13018>, 0,
    <13023, 13022, 13014>, 0,
    <13023, 13014, 13018>, 0,
    <13023, 13018, 12319>, 0,
    <13023, 12319, 12320>, 0,
    <13023, 12320, 12213>, 0,
    <13023, 12213, 13021>, 0,
    <13023, 13021, 13020>, 0,
    <13023, 13020, 13022>, 0,
    <13027, 13016, 13014>, 0,
    <13027, 13014, 13022>, 0,
    <13027, 13022, 13020>, 0,
    <13027, 13020, 13025>, 0,
    <13027, 13025, 13024>, 0,
    <13027, 13024, 13026>, 0,
    <13027, 13026, 13015>, 0,
    <13027, 13015, 13016>, 0,
    <13031, 13030, 13028>, 0,
    <13031, 13028, 13029>, 0,
    <13031, 13029, 13020>, 0,
    <13031, 13020, 13021>, 0,
    <13031, 13021, 12213>, 0,
    <13031, 12213, 12908>, 0,
    <13031, 12908, 12906>, 0,
    <13031, 12906, 13030>, 0,
    <13035, 13034, 13028>, 0,
    <13035, 13028, 13030>, 0,
    <13035, 13030, 12906>, 0,
    <13035, 12906, 12917>, 0,
    <13035, 12917, 12915>, 0,
    <13035, 12915, 13033>, 0,
    <13035, 13033, 13032>, 0,
    <13035, 13032, 13034>, 0,
    <13037, 13029, 13028>, 0,
    <13037, 13028, 13034>, 0,
    <13037, 13034, 13032>, 0,
    <13037, 13032, 13036>, 0,
    <13037, 13036, 13024>, 0,
    <13037, 13024, 13025>, 0,
    <13037, 13025, 13020>, 0,
    <13037, 13020, 13029>, 0,
    <13046, 13045, 13038>, 0,
    <13046, 13038, 13042>, 0,
    <13046, 13042, 13039>, 0,
    <13046, 13039, 13043>, 0,
    <13046, 13043, 13040>, 0,
    <13046, 13040, 13044>, 0,
    <13046, 13044, 13041>, 0,
    <13046, 13041, 13045>, 0,
    <13049, 13048, 13038>, 0,
    <13049, 13038, 13045>, 0,
    <13049, 13045, 13041>, 0,
    <13049, 13041, 13047>, 0,
    <13049, 13047, 12931>, 0,
    <13049, 12931, 12946>, 0,
    <13049, 12946, 12944>, 0,
    <13049, 12944, 13048>, 0,
    <13051, 13042, 13038>, 0,
    <13051, 13038, 13048>, 0,
    <13051, 13048, 12944>, 0,
    <13051, 12944, 12951>, 0,
    <13051, 12951, 12120>, 0,
    <13051, 12120, 13050>, 0,
    <13051, 13050, 13039>, 0,
    <13051, 13039, 13042>, 0,
    <13057, 13056, 13052>, 0,
    <13057, 13052, 13054>, 0,
    <13057, 13054, 13053>, 0,
    <13057, 13053, 13055>, 0,
    <13057, 13055, 13040>, 0,
    <13057, 13040, 13043>, 0,
    <13057, 13043, 13039>, 0,
    <13057, 13039, 13056>, 0,
    <13059, 13058, 13052>, 0,
    <13059, 13052, 13056>, 0,
    <13059, 13056, 13039>, 0,
    <13059, 13039, 13050>, 0,
    <13059, 13050, 12120>, 0,
    <13059, 12120, 12236>, 0,
    <13059, 12236, 12230>, 0,
    <13059, 12230, 13058>, 0,
    <13061, 13054, 13052>, 0,
    <13061, 13052, 13058>, 0,
    <13061, 13058, 12230>, 0,
    <13061, 12230, 12233>, 0,
    <13061, 12233, 12229>, 0,
    <13061, 12229, 13060>, 0,
    <13061, 13060, 13053>, 0,
    <13061, 13053, 13054>, 0,
    <13067, 13066, 13062>, 0,
    <13067, 13062, 13064>, 0,
    <13067, 13064, 12961>, 0,
    <13067, 12961, 12963>, 0,
    <13067, 12963, 2565>, 0,
    <13067, 2565, 13065>, 0,
    <13067, 13065, 13063>, 0,
    <13067, 13063, 13066>, 0,
    <13072, 13071, 13062>, 0,
    <13072, 13062, 13066>, 0,
    <13072, 13066, 13063>, 0,
    <13072, 13063, 13069>, 0,
    <13072, 13069, 2553>, 0,
    <13072, 2553, 13070>, 0,
    <13072, 13070, 13068>, 0,
    <13072, 13068, 13071>, 0,
    <13074, 13064, 13062>, 0,
    <13074, 13062, 13071>, 0,
    <13074, 13071, 13068>, 0,
    <13074, 13068, 13073>, 0,
    <13074, 13073, 12966>, 0,
    <13074, 12966, 12967>, 0,
    <13074, 12967, 12961>, 0,
    <13074, 12961, 13064>, 0,
    <13082, 13081, 13075>, 0,
    <13082, 13075, 13078>, 0,
    <13082, 13078, 13076>, 0,
    <13082, 13076, 13079>, 0,
    <13082, 13079, 2618>, 0,
    <13082, 2618, 13080>, 0,
    <13082, 13080, 13077>, 0,
    <13082, 13077, 13081>, 0,
    <13085, 13084, 13075>, 0,
    <13085, 13075, 13081>, 0,
    <13085, 13081, 13077>, 0,
    <13085, 13077, 13083>, 0,
    <13085, 13083, 12181>, 0,
    <13085, 12181, 13010>, 0,
    <13085, 13010, 13005>, 0,
    <13085, 13005, 13084>, 0,
    <13087, 13078, 13075>, 0,
    <13087, 13075, 13084>, 0,
    <13087, 13084, 13005>, 0,
    <13087, 13005, 13007>, 0,
    <13087, 13007, 12992>, 0,
    <13087, 12992, 13086>, 0,
    <13087, 13086, 13076>, 0,
    <13087, 13076, 13078>, 0,
    <13093, 13092, 13088>, 0,
    <13093, 13088, 13090>, 0,
    <13093, 13090, 13077>, 0,
    <13093, 13077, 13080>, 0,
    <13093, 13080, 2618>, 0,
    <13093, 2618, 13091>, 0,
    <13093, 13091, 13089>, 0,
    <13093, 13089, 13092>, 0,
    <13096, 13095, 13088>, 0,
    <13096, 13088, 13092>, 0,
    <13096, 13092, 13089>, 0,
    <13096, 13089, 13094>, 0,
    <13096, 13094, 12429>, 0,
    <13096, 12429, 12432>, 0,
    <13096, 12432, 12428>, 0,
    <13096, 12428, 13095>, 0,
    <13097, 13090, 13088>, 0,
    <13097, 13088, 13095>, 0,
    <13097, 13095, 12428>, 0,
    <13097, 12428, 12439>, 0,
    <13097, 12439, 12181>, 0,
    <13097, 12181, 13083>, 0,
    <13097, 13083, 13077>, 0,
    <13097, 13077, 13090>, 0,
    <13106, 13105, 13098>, 0,
    <13106, 13098, 13102>, 0,
    <13106, 13102, 13099>, 0,
    <13106, 13099, 13103>, 0,
    <13106, 13103, 13100>, 0,
    <13106, 13100, 13104>, 0,
    <13106, 13104, 13101>, 0,
    <13106, 13101, 13105>, 0,
    <13111, 13110, 13098>, 0,
    <13111, 13098, 13105>, 0,
    <13111, 13105, 13101>, 0,
    <13111, 13101, 13108>, 0,
    <13111, 13108, 12401>, 0,
    <13111, 12401, 13109>, 0,
    <13111, 13109, 13107>, 0,
    <13111, 13107, 13110>, 0,
    <13115, 13102, 13098>, 0,
    <13115, 13098, 13110>, 0,
    <13115, 13110, 13107>, 0,
    <13115, 13107, 13113>, 0,
    <13115, 13113, 13112>, 0,
    <13115, 13112, 13114>, 0,
    <13115, 13114, 13099>, 0,
    <13115, 13099, 13102>, 0,
    <13119, 13118, 13116>, 0,
    <13119, 13116, 13117>, 0,
    <13119, 13117, 13107>, 0,
    <13119, 13107, 13109>, 0,
    <13119, 13109, 12401>, 0,
    <13119, 12401, 12404>, 0,
    <13119, 12404, 12400>, 0,
    <13119, 12400, 13118>, 0,
    <13123, 13122, 13116>, 0,
    <13123, 13116, 13118>, 0,
    <13123, 13118, 12400>, 0,
    <13123, 12400, 12411>, 0,
    <13123, 12411, 12301>, 0,
    <13123, 12301, 13121>, 0,
    <13123, 13121, 13120>, 0,
    <13123, 13120, 13122>, 0,
    <13125, 13117, 13116>, 0,
    <13125, 13116, 13122>, 0,
    <13125, 13122, 13120>, 0,
    <13125, 13120, 13124>, 0,
    <13125, 13124, 13112>, 0,
    <13125, 13112, 13113>, 0,
    <13125, 13113, 13107>, 0,
    <13125, 13107, 13117>, 0,
    <13129, 13128, 13126>, 0,
    <13129, 13126, 13127>, 0,
    <13129, 13127, 13120>, 0,
    <13129, 13120, 13121>, 0,
    <13129, 13121, 12301>, 0,
    <13129, 12301, 13017>, 0,
    <13129, 13017, 13015>, 0,
    <13129, 13015, 13128>, 0,
    <13133, 13132, 13126>, 0,
    <13133, 13126, 13128>, 0,
    <13133, 13128, 13015>, 0,
    <13133, 13015, 13026>, 0,
    <13133, 13026, 13024>, 0,
    <13133, 13024, 13131>, 0,
    <13133, 13131, 13130>, 0,
    <13133, 13130, 13132>, 0,
    <13135, 13127, 13126>, 0,
    <13135, 13126, 13132>, 0,
    <13135, 13132, 13130>, 0,
    <13135, 13130, 13134>, 0,
    <13135, 13134, 13112>, 0,
    <13135, 13112, 13124>, 0,
    <13135, 13124, 13120>, 0,
    <13135, 13120, 13127>, 0,
    <13143, 13142, 13136>, 0,
    <13143, 13136, 13139>, 0,
    <13143, 13139, 13137>, 0,
    <13143, 13137, 13140>, 0,
    <13143, 13140, 12415>, 0,
    <13143, 12415, 13141>, 0,
    <13143, 13141, 13138>, 0,
    <13143, 13138, 13142>, 0,
    <13149, 13148, 13136>, 0,
    <13149, 13136, 13142>, 0,
    <13149, 13142, 13138>, 0,
    <13149, 13138, 13146>, 0,
    <13149, 13146, 13144>, 0,
    <13149, 13144, 13147>, 0,
    <13149, 13147, 13145>, 0,
    <13149, 13145, 13148>, 0,
    <13153, 13139, 13136>, 0,
    <13153, 13136, 13148>, 0,
    <13153, 13148, 13145>, 0,
    <13153, 13145, 13151>, 0,
    <13153, 13151, 13150>, 0,
    <13153, 13150, 13152>, 0,
    <13153, 13152, 13137>, 0,
    <13153, 13137, 13139>, 0,
    <13161, 13160, 13154>, 0,
    <13161, 13154, 13157>, 0,
    <13161, 13157, 13155>, 0,
    <13161, 13155, 13158>, 0,
    <13161, 13158, 13150>, 0,
    <13161, 13150, 13159>, 0,
    <13161, 13159, 13156>, 0,
    <13161, 13156, 13160>, 0,
    <13164, 13163, 13154>, 0,
    <13164, 13154, 13160>, 0,
    <13164, 13160, 13156>, 0,
    <13164, 13156, 13162>, 0,
    <13164, 13162, 13040>, 0,
    <13164, 13040, 13055>, 0,
    <13164, 13055, 13053>, 0,
    <13164, 13053, 13163>, 0,
    <13166, 13157, 13154>, 0,
    <13166, 13154, 13163>, 0,
    <13166, 13163, 13053>, 0,
    <13166, 13053, 13060>, 0,
    <13166, 13060, 12229>, 0,
    <13166, 12229, 13165>, 0,
    <13166, 13165, 13155>, 0,
    <13166, 13155, 13157>, 0,
    <13170, 13169, 13167>, 0,
    <13170, 13167, 13168>, 0,
    <13170, 13168, 12416>, 0,
    <13170, 12416, 12419>, 0,
    <13170, 12419, 12415>, 0,
    <13170, 12415, 13140>, 0,
    <13170, 13140, 13137>, 0,
    <13170, 13137, 13169>, 0,
    <13174, 13173, 13167>, 0,
    <13174, 13167, 13169>, 0,
    <13174, 13169, 13137>, 0,
    <13174, 13137, 13152>, 0,
    <13174, 13152, 13150>, 0,
    <13174, 13150, 13172>, 0,
    <13174, 13172, 13171>, 0,
    <13174, 13171, 13173>, 0,
    <13176, 13168, 13167>, 0,
    <13176, 13167, 13173>, 0,
    <13176, 13173, 13171>, 0,
    <13176, 13171, 13175>, 0,
    <13176, 13175, 12327>, 0,
    <13176, 12327, 12422>, 0,
    <13176, 12422, 12416>, 0,
    <13176, 12416, 13168>, 0,
    <13180, 13179, 13177>, 0,
    <13180, 13177, 13178>, 0,
    <13180, 13178, 13171>, 0,
    <13180, 13171, 13172>, 0,
    <13180, 13172, 13150>, 0,
    <13180, 13150, 13158>, 0,
    <13180, 13158, 13155>, 0,
    <13180, 13155, 13179>, 0,
    <13182, 13181, 13177>, 0,
    <13182, 13177, 13179>, 0,
    <13182, 13179, 13155>, 0,
    <13182, 13155, 13165>, 0,
    <13182, 13165, 12229>, 0,
    <13182, 12229, 12334>, 0,
    <13182, 12334, 12328>, 0,
    <13182, 12328, 13181>, 0,
    <13183, 13178, 13177>, 0,
    <13183, 13177, 13181>, 0,
    <13183, 13181, 12328>, 0,
    <13183, 12328, 12331>, 0,
    <13183, 12331, 12327>, 0,
    <13183, 12327, 13175>, 0,
    <13183, 13175, 13171>, 0,
    <13183, 13171, 13178>, 0,
    <13189, 13188, 13184>, 0,
    <13189, 13184, 13186>, 0,
    <13189, 13186, 13185>, 0,
    <13189, 13185, 13187>, 0,
    <13189, 13187, 13100>, 0,
    <13189, 13100, 13103>, 0,
    <13189, 13103, 13099>, 0,
    <13189, 13099, 13188>, 0,
    <13193, 13192, 13184>, 0,
    <13193, 13184, 13188>, 0,
    <13193, 13188, 13099>, 0,
    <13193, 13099, 13114>, 0,
    <13193, 13114, 13112>, 0,
    <13193, 13112, 13191>, 0,
    <13193, 13191, 13190>, 0,
    <13193, 13190, 13192>, 0,
    <13196, 13186, 13184>, 0,
    <13196, 13184, 13192>, 0,
    <13196, 13192, 13190>, 0,
    <13196, 13190, 13194>, 0,
    <13196, 13194, 2598>, 0,
    <13196, 2598, 13195>, 0,
    <13196, 13195, 13185>, 0,
    <13196, 13185, 13186>, 0,
    <13202, 13201, 13197>, 0,
    <13202, 13197, 13199>, 0,
    <13202, 13199, 13145>, 0,
    <13202, 13145, 13147>, 0,
    <13202, 13147, 13144>, 0,
    <13202, 13144, 13200>, 0,
    <13202, 13200, 13198>, 0,
    <13202, 13198, 13201>, 0,
    <13207, 13206, 13197>, 0,
    <13207, 13197, 13201>, 0,
    <13207, 13201, 13198>, 0,
    <13207, 13198, 13204>, 0,
    <13207, 13204, 2624>, 0,
    <13207, 2624, 13205>, 0,
    <13207, 13205, 13203>, 0,
    <13207, 13203, 13206>, 0,
    <13209, 13199, 13197>, 0,
    <13209, 13197, 13206>, 0,
    <13209, 13206, 13203>, 0,
    <13209, 13203, 13208>, 0,
    <13209, 13208, 13150>, 0,
    <13209, 13150, 13151>, 0,
    <13209, 13151, 13145>, 0,
    <13209, 13145, 13199>, 0,
    <13218, 13217, 13210>, 0,
    <13218, 13210, 13214>, 0,
    <13218, 13214, 13211>, 0,
    <13218, 13211, 13215>, 0,
    <13218, 13215, 13212>, 0,
    <13218, 13212, 13216>, 0,
    <13218, 13216, 13213>, 0,
    <13218, 13213, 13217>, 0,
    <13221, 13220, 13210>, 0,
    <13221, 13210, 13217>, 0,
    <13221, 13217, 13213>, 0,
    <13221, 13213, 13219>, 0,
    <13221, 13219, 2598>, 0,
    <13221, 2598, 13194>, 0,
    <13221, 13194, 13190>, 0,
    <13221, 13190, 13220>, 0,
    <13223, 13214, 13210>, 0,
    <13223, 13210, 13220>, 0,
    <13223, 13220, 13190>, 0,
    <13223, 13190, 13191>, 0,
    <13223, 13191, 13112>, 0,
    <13223, 13112, 13222>, 0,
    <13223, 13222, 13211>, 0,
    <13223, 13211, 13214>, 0,
    <13232, 13231, 13224>, 0,
    <13232, 13224, 13228>, 0,
    <13232, 13228, 13225>, 0,
    <13232, 13225, 13229>, 0,
    <13232, 13229, 13226>, 0,
    <13232, 13226, 13230>, 0,
    <13232, 13230, 13227>, 0,
    <13232, 13227, 13231>, 0,
    <13235, 13234, 13224>, 0,
    <13235, 13224, 13231>, 0,
    <13235, 13231, 13227>, 0,
    <13235, 13227, 13233>, 0,
    <13235, 13233, 2618>, 0,
    <13235, 2618, 13079>, 0,
    <13235, 13079, 13076>, 0,
    <13235, 13076, 13234>, 0,
    <13237, 13228, 13224>, 0,
    <13237, 13224, 13234>, 0,
    <13237, 13234, 13076>, 0,
    <13237, 13076, 13086>, 0,
    <13237, 13086, 12992>, 0,
    <13237, 12992, 13236>, 0,
    <13237, 13236, 13225>, 0,
    <13237, 13225, 13228>, 0,
    <13246, 13245, 13238>, 0,
    <13246, 13238, 13242>, 0,
    <13246, 13242, 13239>, 0,
    <13246, 13239, 13243>, 0,
    <13246, 13243, 13240>, 0,
    <13246, 13240, 13244>, 0,
    <13246, 13244, 13241>, 0,
    <13246, 13241, 13245>, 0,
    <13249, 13248, 13238>, 0,
    <13249, 13238, 13245>, 0,
    <13249, 13245, 13241>, 0,
    <13249, 13241, 13247>, 0,
    <13249, 13247, 13150>, 0,
    <13249, 13150, 13208>, 0,
    <13249, 13208, 13203>, 0,
    <13249, 13203, 13248>, 0,
    <13251, 13242, 13238>, 0,
    <13251, 13238, 13248>, 0,
    <13251, 13248, 13203>, 0,
    <13251, 13203, 13205>, 0,
    <13251, 13205, 2624>, 0,
    <13251, 2624, 13250>, 0,
    <13251, 13250, 13239>, 0,
    <13251, 13239, 13242>, 0,
    <13257, 13256, 13252>, 0,
    <13257, 13252, 13254>, 0,
    <13257, 13254, 12472>, 0,
    <13257, 12472, 12473>, 0,
    <13257, 12473, 12460>, 0,
    <13257, 12460, 13255>, 0,
    <13257, 13255, 13253>, 0,
    <13257, 13253, 13256>, 0,
    <13262, 13261, 13252>, 0,
    <13262, 13252, 13256>, 0,
    <13262, 13256, 13253>, 0,
    <13262, 13253, 13259>, 0,
    <13262, 13259, 2753>, 0,
    <13262, 2753, 13260>, 0,
    <13262, 13260, 13258>, 0,
    <13262, 13258, 13261>, 0,
    <13264, 13254, 13252>, 0,
    <13264, 13252, 13261>, 0,
    <13264, 13261, 13258>, 0,
    <13264, 13258, 13263>, 0,
    <13264, 13263, 2495>, 0,
    <13264, 2495, 12476>, 0,
    <13264, 12476, 12472>, 0,
    <13264, 12472, 13254>, 0,
    <13270, 13269, 13265>, 0,
    <13270, 13265, 13267>, 0,
    <13270, 13267, 12523>, 0,
    <13270, 12523, 12524>, 0,
    <13270, 12524, 12511>, 0,
    <13270, 12511, 13268>, 0,
    <13270, 13268, 13266>, 0,
    <13270, 13266, 13269>, 0,
    <13276, 13275, 13265>, 0,
    <13276, 13265, 13269>, 0,
    <13276, 13269, 13266>, 0,
    <13276, 13266, 13273>, 0,
    <13276, 13273, 13271>, 0,
    <13276, 13271, 13274>, 0,
    <13276, 13274, 13272>, 0,
    <13276, 13272, 13275>, 0,
    <13278, 13267, 13265>, 0,
    <13278, 13265, 13275>, 0,
    <13278, 13275, 13272>, 0,
    <13278, 13272, 13277>, 0,
    <13278, 13277, 12460>, 0,
    <13278, 12460, 12527>, 0,
    <13278, 12527, 12523>, 0,
    <13278, 12523, 13267>, 0,
    <13282, 13281, 13279>, 0,
    <13282, 13279, 13280>, 0,
    <13282, 13280, 13253>, 0,
    <13282, 13253, 13255>, 0,
    <13282, 13255, 12460>, 0,
    <13282, 12460, 13277>, 0,
    <13282, 13277, 13272>, 0,
    <13282, 13272, 13281>, 0,
    <13286, 13285, 13279>, 0,
    <13286, 13279, 13281>, 0,
    <13286, 13281, 13272>, 0,
    <13286, 13272, 13274>, 0,
    <13286, 13274, 13271>, 0,
    <13286, 13271, 13284>, 0,
    <13286, 13284, 13283>, 0,
    <13286, 13283, 13285>, 0,
    <13288, 13280, 13279>, 0,
    <13288, 13279, 13285>, 0,
    <13288, 13285, 13283>, 0,
    <13288, 13283, 13287>, 0,
    <13288, 13287, 2753>, 0,
    <13288, 2753, 13259>, 0,
    <13288, 13259, 13253>, 0,
    <13288, 13253, 13280>, 0,
    <13297, 13296, 13289>, 0,
    <13297, 13289, 13293>, 0,
    <13297, 13293, 13290>, 0,
    <13297, 13290, 13294>, 0,
    <13297, 13294, 13291>, 0,
    <13297, 13291, 13295>, 0,
    <13297, 13295, 13292>, 0,
    <13297, 13292, 13296>, 0,
    <13302, 13301, 13289>, 0,
    <13302, 13289, 13296>, 0,
    <13302, 13296, 13292>, 0,
    <13302, 13292, 13299>, 0,
    <13302, 13299, 2519>, 0,
    <13302, 2519, 13300>, 0,
    <13302, 13300, 13298>, 0,
    <13302, 13298, 13301>, 0,
    <13305, 13293, 13289>, 0,
    <13305, 13289, 13301>, 0,
    <13305, 13301, 13298>, 0,
    <13305, 13298, 13303>, 0,
    <13305, 13303, 2777>, 0,
    <13305, 2777, 13304>, 0,
    <13305, 13304, 13290>, 0,
    <13305, 13290, 13293>, 0,
    <13311, 13310, 13306>, 0,
    <13311, 13306, 13308>, 0,
    <13311, 13308, 13292>, 0,
    <13311, 13292, 13295>, 0,
    <13311, 13295, 13291>, 0,
    <13311, 13291, 13309>, 0,
    <13311, 13309, 13307>, 0,
    <13311, 13307, 13310>, 0,
    <13314, 13313, 13306>, 0,
    <13314, 13306, 13310>, 0,
    <13314, 13310, 13307>, 0,
    <13314, 13307, 13312>, 0,
    <13314, 13312, 12480>, 0,
    <13314, 12480, 12483>, 0,
    <13314, 12483, 12479>, 0,
    <13314, 12479, 13313>, 0,
    <13315, 13308, 13306>, 0,
    <13315, 13306, 13313>, 0,
    <13315, 13313, 12479>, 0,
    <13315, 12479, 12493>, 0,
    <13315, 12493, 2519>, 0,
    <13315, 2519, 13299>, 0,
    <13315, 13299, 13292>, 0,
    <13315, 13292, 13308>, 0,
    <13321, 13320, 13316>, 0,
    <13321, 13316, 13318>, 0,
    <13321, 13318, 12635>, 0,
    <13321, 12635, 12636>, 0,
    <13321, 12636, 12623>, 0,
    <13321, 12623, 13319>, 0,
    <13321, 13319, 13317>, 0,
    <13321, 13317, 13320>, 0,
    <13327, 13326, 13316>, 0,
    <13327, 13316, 13320>, 0,
    <13327, 13320, 13317>, 0,
    <13327, 13317, 13324>, 0,
    <13327, 13324, 13322>, 0,
    <13327, 13322, 13325>, 0,
    <13327, 13325, 13323>, 0,
    <13327, 13323, 13326>, 0,
    <13329, 13318, 13316>, 0,
    <13329, 13316, 13326>, 0,
    <13329, 13326, 13323>, 0,
    <13329, 13323, 13328>, 0,
    <13329, 13328, 12511>, 0,
    <13329, 12511, 12639>, 0,
    <13329, 12639, 12635>, 0,
    <13329, 12635, 13318>, 0,
    <13333, 13332, 13330>, 0,
    <13333, 13330, 13331>, 0,
    <13333, 13331, 13266>, 0,
    <13333, 13266, 13268>, 0,
    <13333, 13268, 12511>, 0,
    <13333, 12511, 13328>, 0,
    <13333, 13328, 13323>, 0,
    <13333, 13323, 13332>, 0,
    <13337, 13336, 13330>, 0,
    <13337, 13330, 13332>, 0,
    <13337, 13332, 13323>, 0,
    <13337, 13323, 13325>, 0,
    <13337, 13325, 13322>, 0,
    <13337, 13322, 13335>, 0,
    <13337, 13335, 13334>, 0,
    <13337, 13334, 13336>, 0,
    <13339, 13331, 13330>, 0,
    <13339, 13330, 13336>, 0,
    <13339, 13336, 13334>, 0,
    <13339, 13334, 13338>, 0,
    <13339, 13338, 13271>, 0,
    <13339, 13271, 13273>, 0,
    <13339, 13273, 13266>, 0,
    <13339, 13266, 13331>, 0,
    <13348, 13347, 13340>, 0,
    <13348, 13340, 13344>, 0,
    <13348, 13344, 13341>, 0,
    <13348, 13341, 13345>, 0,
    <13348, 13345, 13342>, 0,
    <13348, 13342, 13346>, 0,
    <13348, 13346, 13343>, 0,
    <13348, 13343, 13347>, 0,
    <13351, 13350, 13340>, 0,
    <13351, 13340, 13347>, 0,
    <13351, 13347, 13343>, 0,
    <13351, 13343, 13349>, 0,
    <13351, 13349, 12480>, 0,
    <13351, 12480, 13312>, 0,
    <13351, 13312, 13307>, 0,
    <13351, 13307, 13350>, 0,
    <13353, 13344, 13340>, 0,
    <13353, 13340, 13350>, 0,
    <13353, 13350, 13307>, 0,
    <13353, 13307, 13309>, 0,
    <13353, 13309, 13291>, 0,
    <13353, 13291, 13352>, 0,
    <13353, 13352, 13341>, 0,
    <13353, 13341, 13344>, 0,
    <13359, 13358, 13354>, 0,
    <13359, 13354, 13356>, 0,
    <13359, 13356, 13343>, 0,
    <13359, 13343, 13346>, 0,
    <13359, 13346, 13342>, 0,
    <13359, 13342, 13357>, 0,
    <13359, 13357, 13355>, 0,
    <13359, 13355, 13358>, 0,
    <13362, 13361, 13354>, 0,
    <13362, 13354, 13358>, 0,
    <13362, 13358, 13355>, 0,
    <13362, 13355, 13360>, 0,
    <13362, 13360, 12531>, 0,
    <13362, 12531, 12534>, 0,
    <13362, 12534, 12530>, 0,
    <13362, 12530, 13361>, 0,
    <13363, 13356, 13354>, 0,
    <13363, 13354, 13361>, 0,
    <13363, 13361, 12530>, 0,
    <13363, 12530, 12541>, 0,
    <13363, 12541, 12480>, 0,
    <13363, 12480, 13349>, 0,
    <13363, 13349, 13343>, 0,
    <13363, 13343, 13356>, 0,
    <13369, 13368, 13364>, 0,
    <13369, 13364, 13366>, 0,
    <13369, 13366, 13365>, 0,
    <13369, 13365, 13367>, 0,
    <13369, 13367, 12576>, 0,
    <13369, 12576, 12588>, 0,
    <13369, 12588, 12584>, 0,
    <13369, 12584, 13368>, 0,
    <13373, 13372, 13364>, 0,
    <13373, 13364, 13368>, 0,
    <13373, 13368, 12584>, 0,
    <13373, 12584, 12585>, 0,
    <13373, 12585, 2547>, 0,
    <13373, 2547, 13371>, 0,
    <13373, 13371, 13370>, 0,
    <13373, 13370, 13372>, 0,
    <13376, 13366, 13364>, 0,
    <13376, 13364, 13372>, 0,
    <13376, 13372, 13370>, 0,
    <13376, 13370, 13374>, 0,
    <13376, 13374, 2791>, 0,
    <13376, 2791, 13375>, 0,
    <13376, 13375, 13365>, 0,
    <13376, 13365, 13366>, 0,
    <13382, 13381, 13377>, 0,
    <13382, 13377, 13379>, 0,
    <13382, 13379, 13378>, 0,
    <13382, 13378, 13380>, 0,
    <13382, 13380, 12675>, 0,
    <13382, 12675, 12687>, 0,
    <13382, 12687, 12683>, 0,
    <13382, 12683, 13381>, 0,
    <13386, 13385, 13377>, 0,
    <13386, 13377, 13381>, 0,
    <13386, 13381, 12683>, 0,
    <13386, 12683, 12684>, 0,
    <13386, 12684, 12576>, 0,
    <13386, 12576, 13384>, 0,
    <13386, 13384, 13383>, 0,
    <13386, 13383, 13385>, 0,
    <13390, 13379, 13377>, 0,
    <13390, 13377, 13385>, 0,
    <13390, 13385, 13383>, 0,
    <13390, 13383, 13388>, 0,
    <13390, 13388, 13387>, 0,
    <13390, 13387, 13389>, 0,
    <13390, 13389, 13378>, 0,
    <13390, 13378, 13379>, 0,
    <13394, 13393, 13391>, 0,
    <13394, 13391, 13392>, 0,
    <13394, 13392, 13383>, 0,
    <13394, 13383, 13384>, 0,
    <13394, 13384, 12576>, 0,
    <13394, 12576, 13367>, 0,
    <13394, 13367, 13365>, 0,
    <13394, 13365, 13393>, 0,
    <13398, 13397, 13391>, 0,
    <13398, 13391, 13393>, 0,
    <13398, 13393, 13365>, 0,
    <13398, 13365, 13375>, 0,
    <13398, 13375, 2791>, 0,
    <13398, 2791, 13396>, 0,
    <13398, 13396, 13395>, 0,
    <13398, 13395, 13397>, 0,
    <13400, 13392, 13391>, 0,
    <13400, 13391, 13397>, 0,
    <13400, 13397, 13395>, 0,
    <13400, 13395, 13399>, 0,
    <13400, 13399, 13387>, 0,
    <13400, 13387, 13388>, 0,
    <13400, 13388, 13383>, 0,
    <13400, 13383, 13392>, 0,
    <13409, 13408, 13401>, 0,
    <13409, 13401, 13405>, 0,
    <13409, 13405, 13402>, 0,
    <13409, 13402, 13406>, 0,
    <13409, 13406, 13403>, 0,
    <13409, 13403, 13407>, 0,
    <13409, 13407, 13404>, 0,
    <13409, 13404, 13408>, 0,
    <13414, 13413, 13401>, 0,
    <13414, 13401, 13408>, 0,
    <13414, 13408, 13404>, 0,
    <13414, 13404, 13411>, 0,
    <13414, 13411, 2797>, 0,
    <13414, 2797, 13412>, 0,
    <13414, 13412, 13410>, 0,
    <13414, 13410, 13413>, 0,
    <13417, 13405, 13401>, 0,
    <13417, 13401, 13413>, 0,
    <13417, 13413, 13410>, 0,
    <13417, 13410, 13415>, 0,
    <13417, 13415, 2525>, 0,
    <13417, 2525, 13416>, 0,
    <13417, 13416, 13402>, 0,
    <13417, 13402, 13405>, 0,
    <13423, 13422, 13418>, 0,
    <13423, 13418, 13420>, 0,
    <13423, 13420, 13419>, 0,
    <13423, 13419, 13421>, 0,
    <13423, 13421, 13403>, 0,
    <13423, 13403, 13406>, 0,
    <13423, 13406, 13402>, 0,
    <13423, 13402, 13422>, 0,
    <13425, 13424, 13418>, 0,
    <13425, 13418, 13422>, 0,
    <13425, 13422, 13402>, 0,
    <13425, 13402, 13416>, 0,
    <13425, 13416, 2525>, 0,
    <13425, 2525, 12600>, 0,
    <13425, 12600, 12593>, 0,
    <13425, 12593, 13424>, 0,
    <13427, 13420, 13418>, 0,
    <13427, 13418, 13424>, 0,
    <13427, 13424, 12593>, 0,
    <13427, 12593, 12596>, 0,
    <13427, 12596, 12592>, 0,
    <13427, 12592, 13426>, 0,
    <13427, 13426, 13419>, 0,
    <13427, 13419, 13420>, 0,
    <13433, 13432, 13428>, 0,
    <13433, 13428, 13430>, 0,
    <13433, 13430, 12779>, 0,
    <13433, 12779, 12780>, 0,
    <13433, 12780, 12767>, 0,
    <13433, 12767, 13431>, 0,
    <13433, 13431, 13429>, 0,
    <13433, 13429, 13432>, 0,
    <13439, 13438, 13428>, 0,
    <13439, 13428, 13432>, 0,
    <13439, 13432, 13429>, 0,
    <13439, 13429, 13436>, 0,
    <13439, 13436, 13434>, 0,
    <13439, 13434, 13437>, 0,
    <13439, 13437, 13435>, 0,
    <13439, 13435, 13438>, 0,
    <13441, 13430, 13428>, 0,
    <13441, 13428, 13438>, 0,
    <13441, 13438, 13435>, 0,
    <13441, 13435, 13440>, 0,
    <13441, 13440, 12623>, 0,
    <13441, 12623, 12783>, 0,
    <13441, 12783, 12779>, 0,
    <13441, 12779, 13430>, 0,
    <13445, 13444, 13442>, 0,
    <13445, 13442, 13443>, 0,
    <13445, 13443, 13317>, 0,
    <13445, 13317, 13319>, 0,
    <13445, 13319, 12623>, 0,
    <13445, 12623, 13440>, 0,
    <13445, 13440, 13435>, 0,
    <13445, 13435, 13444>, 0,
    <13449, 13448, 13442>, 0,
    <13449, 13442, 13444>, 0,
    <13449, 13444, 13435>, 0,
    <13449, 13435, 13437>, 0,
    <13449, 13437, 13434>, 0,
    <13449, 13434, 13447>, 0,
    <13449, 13447, 13446>, 0,
    <13449, 13446, 13448>, 0,
    <13451, 13443, 13442>, 0,
    <13451, 13442, 13448>, 0,
    <13451, 13448, 13446>, 0,
    <13451, 13446, 13450>, 0,
    <13451, 13450, 13322>, 0,
    <13451, 13322, 13324>, 0,
    <13451, 13324, 13317>, 0,
    <13451, 13317, 13443>, 0,
    <13460, 13459, 13452>, 0,
    <13460, 13452, 13456>, 0,
    <13460, 13456, 13453>, 0,
    <13460, 13453, 13457>, 0,
    <13460, 13457, 13454>, 0,
    <13460, 13454, 13458>, 0,
    <13460, 13458, 13455>, 0,
    <13460, 13455, 13459>, 0,
    <13463, 13462, 13452>, 0,
    <13463, 13452, 13459>, 0,
    <13463, 13459, 13455>, 0,
    <13463, 13455, 13461>, 0,
    <13463, 13461, 12531>, 0,
    <13463, 12531, 13360>, 0,
    <13463, 13360, 13355>, 0,
    <13463, 13355, 13462>, 0,
    <13465, 13456, 13452>, 0,
    <13465, 13452, 13462>, 0,
    <13465, 13462, 13355>, 0,
    <13465, 13355, 13357>, 0,
    <13465, 13357, 13342>, 0,
    <13465, 13342, 13464>, 0,
    <13465, 13464, 13453>, 0,
    <13465, 13453, 13456>, 0,
    <13471, 13470, 13466>, 0,
    <13471, 13466, 13468>, 0,
    <13471, 13468, 13455>, 0,
    <13471, 13455, 13458>, 0,
    <13471, 13458, 13454>, 0,
    <13471, 13454, 13469>, 0,
    <13471, 13469, 13467>, 0,
    <13471, 13467, 13470>, 0,
    <13474, 13473, 13466>, 0,
    <13474, 13466, 13470>, 0,
    <13474, 13470, 13467>, 0,
    <13474, 13467, 13472>, 0,
    <13474, 13472, 12643>, 0,
    <13474, 12643, 12646>, 0,
    <13474, 12646, 12642>, 0,
    <13474, 12642, 13473>, 0,
    <13475, 13468, 13466>, 0,
    <13475, 13466, 13473>, 0,
    <13475, 13473, 12642>, 0,
    <13475, 12642, 12653>, 0,
    <13475, 12653, 12531>, 0,
    <13475, 12531, 13461>, 0,
    <13475, 13461, 13455>, 0,
    <13475, 13455, 13468>, 0,
    <13481, 13480, 13476>, 0,
    <13481, 13476, 13478>, 0,
    <13481, 13478, 13477>, 0,
    <13481, 13477, 13479>, 0,
    <13481, 13479, 12723>, 0,
    <13481, 12723, 12735>, 0,
    <13481, 12735, 12731>, 0,
    <13481, 12731, 13480>, 0,
    <13485, 13484, 13476>, 0,
    <13485, 13476, 13480>, 0,
    <13485, 13480, 12731>, 0,
    <13485, 12731, 12732>, 0,
    <13485, 12732, 12675>, 0,
    <13485, 12675, 13483>, 0,
    <13485, 13483, 13482>, 0,
    <13485, 13482, 13484>, 0,
    <13489, 13478, 13476>, 0,
    <13489, 13476, 13484>, 0,
    <13489, 13484, 13482>, 0,
    <13489, 13482, 13487>, 0,
    <13489, 13487, 13486>, 0,
    <13489, 13486, 13488>, 0,
    <13489, 13488, 13477>, 0,
    <13489, 13477, 13478>, 0,
    <13493, 13492, 13490>, 0,
    <13493, 13490, 13491>, 0,
    <13493, 13491, 13482>, 0,
    <13493, 13482, 13483>, 0,
    <13493, 13483, 12675>, 0,
    <13493, 12675, 13380>, 0,
    <13493, 13380, 13378>, 0,
    <13493, 13378, 13492>, 0,
    <13497, 13496, 13490>, 0,
    <13497, 13490, 13492>, 0,
    <13497, 13492, 13378>, 0,
    <13497, 13378, 13389>, 0,
    <13497, 13389, 13387>, 0,
    <13497, 13387, 13495>, 0,
    <13497, 13495, 13494>, 0,
    <13497, 13494, 13496>, 0,
    <13499, 13491, 13490>, 0,
    <13499, 13490, 13496>, 0,
    <13499, 13496, 13494>, 0,
    <13499, 13494, 13498>, 0,
    <13499, 13498, 13486>, 0,
    <13499, 13486, 13487>, 0,
    <13499, 13487, 13482>, 0,
    <13499, 13482, 13491>, 0,
    <13508, 13507, 13500>, 0,
    <13508, 13500, 13504>, 0,
    <13508, 13504, 13501>, 0,
    <13508, 13501, 13505>, 0,
    <13508, 13505, 13502>, 0,
    <13508, 13502, 13506>, 0,
    <13508, 13506, 13503>, 0,
    <13508, 13503, 13507>, 0,
    <13511, 13510, 13500>, 0,
    <13511, 13500, 13507>, 0,
    <13511, 13507, 13503>, 0,
    <13511, 13503, 13509>, 0,
    <13511, 13509, 13403>, 0,
    <13511, 13403, 13421>, 0,
    <13511, 13421, 13419>, 0,
    <13511, 13419, 13510>, 0,
    <13513, 13504, 13500>, 0,
    <13513, 13500, 13510>, 0,
    <13513, 13510, 13419>, 0,
    <13513, 13419, 13426>, 0,
    <13513, 13426, 12592>, 0,
    <13513, 12592, 13512>, 0,
    <13513, 13512, 13501>, 0,
    <13513, 13501, 13504>, 0,
    <13519, 13518, 13514>, 0,
    <13519, 13514, 13516>, 0,
    <13519, 13516, 13515>, 0,
    <13519, 13515, 13517>, 0,
    <13519, 13517, 13502>, 0,
    <13519, 13502, 13505>, 0,
    <13519, 13505, 13501>, 0,
    <13519, 13501, 13518>, 0,
    <13521, 13520, 13514>, 0,
    <13521, 13514, 13518>, 0,
    <13521, 13518, 13501>, 0,
    <13521, 13501, 13512>, 0,
    <13521, 13512, 12592>, 0,
    <13521, 12592, 12698>, 0,
    <13521, 12698, 12692>, 0,
    <13521, 12692, 13520>, 0,
    <13523, 13516, 13514>, 0,
    <13523, 13514, 13520>, 0,
    <13523, 13520, 12692>, 0,
    <13523, 12692, 12695>, 0,
    <13523, 12695, 12691>, 0,
    <13523, 12691, 13522>, 0,
    <13523, 13522, 13515>, 0,
    <13523, 13515, 13516>, 0,
    <13529, 13528, 13524>, 0,
    <13529, 13524, 13526>, 0,
    <13529, 13526, 13525>, 0,
    <13529, 13525, 13527>, 0,
    <13529, 13527, 12819>, 0,
    <13529, 12819, 12831>, 0,
    <13529, 12831, 12827>, 0,
    <13529, 12827, 13528>, 0,
    <13533, 13532, 13524>, 0,
    <13533, 13524, 13528>, 0,
    <13533, 13528, 12827>, 0,
    <13533, 12827, 12828>, 0,
    <13533, 12828, 12723>, 0,
    <13533, 12723, 13531>, 0,
    <13533, 13531, 13530>, 0,
    <13533, 13530, 13532>, 0,
    <13537, 13526, 13524>, 0,
    <13537, 13524, 13532>, 0,
    <13537, 13532, 13530>, 0,
    <13537, 13530, 13535>, 0,
    <13537, 13535, 13534>, 0,
    <13537, 13534, 13536>, 0,
    <13537, 13536, 13525>, 0,
    <13537, 13525, 13526>, 0,
    <13541, 13540, 13538>, 0,
    <13541, 13538, 13539>, 0,
    <13541, 13539, 13530>, 0,
    <13541, 13530, 13531>, 0,
    <13541, 13531, 12723>, 0,
    <13541, 12723, 13479>, 0,
    <13541, 13479, 13477>, 0,
    <13541, 13477, 13540>, 0,
    <13545, 13544, 13538>, 0,
    <13545, 13538, 13540>, 0,
    <13545, 13540, 13477>, 0,
    <13545, 13477, 13488>, 0,
    <13545, 13488, 13486>, 0,
    <13545, 13486, 13543>, 0,
    <13545, 13543, 13542>, 0,
    <13545, 13542, 13544>, 0,
    <13547, 13539, 13538>, 0,
    <13547, 13538, 13544>, 0,
    <13547, 13544, 13542>, 0,
    <13547, 13542, 13546>, 0,
    <13547, 13546, 13534>, 0,
    <13547, 13534, 13535>, 0,
    <13547, 13535, 13530>, 0,
    <13547, 13530, 13539>, 0,
    <13556, 13555, 13548>, 0,
    <13556, 13548, 13552>, 0,
    <13556, 13552, 13549>, 0,
    <13556, 13549, 13553>, 0,
    <13556, 13553, 13550>, 0,
    <13556, 13550, 13554>, 0,
    <13556, 13554, 13551>, 0,
    <13556, 13551, 13555>, 0,
    <13559, 13558, 13548>, 0,
    <13559, 13548, 13555>, 0,
    <13559, 13555, 13551>, 0,
    <13559, 13551, 13557>, 0,
    <13559, 13557, 13502>, 0,
    <13559, 13502, 13517>, 0,
    <13559, 13517, 13515>, 0,
    <13559, 13515, 13558>, 0,
    <13561, 13552, 13548>, 0,
    <13561, 13548, 13558>, 0,
    <13561, 13558, 13515>, 0,
    <13561, 13515, 13522>, 0,
    <13561, 13522, 12691>, 0,
    <13561, 12691, 13560>, 0,
    <13561, 13560, 13549>, 0,
    <13561, 13549, 13552>, 0,
    <13567, 13566, 13562>, 0,
    <13567, 13562, 13564>, 0,
    <13567, 13564, 13563>, 0,
    <13567, 13563, 13565>, 0,
    <13567, 13565, 13550>, 0,
    <13567, 13550, 13553>, 0,
    <13567, 13553, 13549>, 0,
    <13567, 13549, 13566>, 0,
    <13569, 13568, 13562>, 0,
    <13569, 13562, 13566>, 0,
    <13569, 13566, 13549>, 0,
    <13569, 13549, 13560>, 0,
    <13569, 13560, 12691>, 0,
    <13569, 12691, 12746>, 0,
    <13569, 12746, 12740>, 0,
    <13569, 12740, 13568>, 0,
    <13571, 13564, 13562>, 0,
    <13571, 13562, 13568>, 0,
    <13571, 13568, 12740>, 0,
    <13571, 12740, 12743>, 0,
    <13571, 12743, 12739>, 0,
    <13571, 12739, 13570>, 0,
    <13571, 13570, 13563>, 0,
    <13571, 13563, 13564>, 0,
    <13577, 13576, 13572>, 0,
    <13577, 13572, 13574>, 0,
    <13577, 13574, 12875>, 0,
    <13577, 12875, 12876>, 0,
    <13577, 12876, 12863>, 0,
    <13577, 12863, 13575>, 0,
    <13577, 13575, 13573>, 0,
    <13577, 13573, 13576>, 0,
    <13583, 13582, 13572>, 0,
    <13583, 13572, 13576>, 0,
    <13583, 13576, 13573>, 0,
    <13583, 13573, 13580>, 0,
    <13583, 13580, 13578>, 0,
    <13583, 13578, 13581>, 0,
    <13583, 13581, 13579>, 0,
    <13583, 13579, 13582>, 0,
    <13585, 13574, 13572>, 0,
    <13585, 13572, 13582>, 0,
    <13585, 13582, 13579>, 0,
    <13585, 13579, 13584>, 0,
    <13585, 13584, 12767>, 0,
    <13585, 12767, 12879>, 0,
    <13585, 12879, 12875>, 0,
    <13585, 12875, 13574>, 0,
    <13589, 13588, 13586>, 0,
    <13589, 13586, 13587>, 0,
    <13589, 13587, 13429>, 0,
    <13589, 13429, 13431>, 0,
    <13589, 13431, 12767>, 0,
    <13589, 12767, 13584>, 0,
    <13589, 13584, 13579>, 0,
    <13589, 13579, 13588>, 0,
    <13593, 13592, 13586>, 0,
    <13593, 13586, 13588>, 0,
    <13593, 13588, 13579>, 0,
    <13593, 13579, 13581>, 0,
    <13593, 13581, 13578>, 0,
    <13593, 13578, 13591>, 0,
    <13593, 13591, 13590>, 0,
    <13593, 13590, 13592>, 0,
    <13595, 13587, 13586>, 0,
    <13595, 13586, 13592>, 0,
    <13595, 13592, 13590>, 0,
    <13595, 13590, 13594>, 0,
    <13595, 13594, 13434>, 0,
    <13595, 13434, 13436>, 0,
    <13595, 13436, 13429>, 0,
    <13595, 13429, 13587>, 0,
    <13604, 13603, 13596>, 0,
    <13604, 13596, 13600>, 0,
    <13604, 13600, 13597>, 0,
    <13604, 13597, 13601>, 0,
    <13604, 13601, 13598>, 0,
    <13604, 13598, 13602>, 0,
    <13604, 13602, 13599>, 0,
    <13604, 13599, 13603>, 0,
    <13607, 13606, 13596>, 0,
    <13607, 13596, 13603>, 0,
    <13607, 13603, 13599>, 0,
    <13607, 13599, 13605>, 0,
    <13607, 13605, 12643>, 0,
    <13607, 12643, 13472>, 0,
    <13607, 13472, 13467>, 0,
    <13607, 13467, 13606>, 0,
    <13609, 13600, 13596>, 0,
    <13609, 13596, 13606>, 0,
    <13609, 13606, 13467>, 0,
    <13609, 13467, 13469>, 0,
    <13609, 13469, 13454>, 0,
    <13609, 13454, 13608>, 0,
    <13609, 13608, 13597>, 0,
    <13609, 13597, 13600>, 0,
    <13615, 13614, 13610>, 0,
    <13615, 13610, 13612>, 0,
    <13615, 13612, 13599>, 0,
    <13615, 13599, 13602>, 0,
    <13615, 13602, 13598>, 0,
    <13615, 13598, 13613>, 0,
    <13615, 13613, 13611>, 0,
    <13615, 13611, 13614>, 0,
    <13618, 13617, 13610>, 0,
    <13618, 13610, 13614>, 0,
    <13618, 13614, 13611>, 0,
    <13618, 13611, 13616>, 0,
    <13618, 13616, 12787>, 0,
    <13618, 12787, 12790>, 0,
    <13618, 12790, 12786>, 0,
    <13618, 12786, 13617>, 0,
    <13619, 13612, 13610>, 0,
    <13619, 13610, 13617>, 0,
    <13619, 13617, 12786>, 0,
    <13619, 12786, 12797>, 0,
    <13619, 12797, 12643>, 0,
    <13619, 12643, 13605>, 0,
    <13619, 13605, 13599>, 0,
    <13619, 13599, 13612>, 0,
    <13625, 13624, 13620>, 0,
    <13625, 13620, 13622>, 0,
    <13625, 13622, 13621>, 0,
    <13625, 13621, 13623>, 0,
    <13625, 13623, 12915>, 0,
    <13625, 12915, 12927>, 0,
    <13625, 12927, 12923>, 0,
    <13625, 12923, 13624>, 0,
    <13629, 13628, 13620>, 0,
    <13629, 13620, 13624>, 0,
    <13629, 13624, 12923>, 0,
    <13629, 12923, 12924>, 0,
    <13629, 12924, 12819>, 0,
    <13629, 12819, 13627>, 0,
    <13629, 13627, 13626>, 0,
    <13629, 13626, 13628>, 0,
    <13633, 13622, 13620>, 0,
    <13633, 13620, 13628>, 0,
    <13633, 13628, 13626>, 0,
    <13633, 13626, 13631>, 0,
    <13633, 13631, 13630>, 0,
    <13633, 13630, 13632>, 0,
    <13633, 13632, 13621>, 0,
    <13633, 13621, 13622>, 0,
    <13637, 13636, 13634>, 0,
    <13637, 13634, 13635>, 0,
    <13637, 13635, 13626>, 0,
    <13637, 13626, 13627>, 0,
    <13637, 13627, 12819>, 0,
    <13637, 12819, 13527>, 0,
    <13637, 13527, 13525>, 0,
    <13637, 13525, 13636>, 0,
    <13641, 13640, 13634>, 0,
    <13641, 13634, 13636>, 0,
    <13641, 13636, 13525>, 0,
    <13641, 13525, 13536>, 0,
    <13641, 13536, 13534>, 0,
    <13641, 13534, 13639>, 0,
    <13641, 13639, 13638>, 0,
    <13641, 13638, 13640>, 0,
    <13643, 13635, 13634>, 0,
    <13643, 13634, 13640>, 0,
    <13643, 13640, 13638>, 0,
    <13643, 13638, 13642>, 0,
    <13643, 13642, 13630>, 0,
    <13643, 13630, 13631>, 0,
    <13643, 13631, 13626>, 0,
    <13643, 13626, 13635>, 0,
    <13652, 13651, 13644>, 0,
    <13652, 13644, 13648>, 0,
    <13652, 13648, 13645>, 0,
    <13652, 13645, 13649>, 0,
    <13652, 13649, 13646>, 0,
    <13652, 13646, 13650>, 0,
    <13652, 13650, 13647>, 0,
    <13652, 13647, 13651>, 0,
    <13655, 13654, 13644>, 0,
    <13655, 13644, 13651>, 0,
    <13655, 13651, 13647>, 0,
    <13655, 13647, 13653>, 0,
    <13655, 13653, 13550>, 0,
    <13655, 13550, 13565>, 0,
    <13655, 13565, 13563>, 0,
    <13655, 13563, 13654>, 0,
    <13657, 13648, 13644>, 0,
    <13657, 13644, 13654>, 0,
    <13657, 13654, 13563>, 0,
    <13657, 13563, 13570>, 0,
    <13657, 13570, 12739>, 0,
    <13657, 12739, 13656>, 0,
    <13657, 13656, 13645>, 0,
    <13657, 13645, 13648>, 0,
    <13663, 13662, 13658>, 0,
    <13663, 13658, 13660>, 0,
    <13663, 13660, 13659>, 0,
    <13663, 13659, 13661>, 0,
    <13663, 13661, 13646>, 0,
    <13663, 13646, 13649>, 0,
    <13663, 13649, 13645>, 0,
    <13663, 13645, 13662>, 0,
    <13665, 13664, 13658>, 0,
    <13665, 13658, 13662>, 0,
    <13665, 13662, 13645>, 0,
    <13665, 13645, 13656>, 0,
    <13665, 13656, 12739>, 0,
    <13665, 12739, 12842>, 0,
    <13665, 12842, 12836>, 0,
    <13665, 12836, 13664>, 0,
    <13667, 13660, 13658>, 0,
    <13667, 13658, 13664>, 0,
    <13667, 13664, 12836>, 0,
    <13667, 12836, 12839>, 0,
    <13667, 12839, 12835>, 0,
    <13667, 12835, 13666>, 0,
    <13667, 13666, 13659>, 0,
    <13667, 13659, 13660>, 0,
    <13673, 13672, 13668>, 0,
    <13673, 13668, 13670>, 0,
    <13673, 13670, 12984>, 0,
    <13673, 12984, 12985>, 0,
    <13673, 12985, 12966>, 0,
    <13673, 12966, 13671>, 0,
    <13673, 13671, 13669>, 0,
    <13673, 13669, 13672>, 0,
    <13679, 13678, 13668>, 0,
    <13679, 13668, 13672>, 0,
    <13679, 13672, 13669>, 0,
    <13679, 13669, 13676>, 0,
    <13679, 13676, 13674>, 0,
    <13679, 13674, 13677>, 0,
    <13679, 13677, 13675>, 0,
    <13679, 13675, 13678>, 0,
    <13681, 13670, 13668>, 0,
    <13681, 13668, 13678>, 0,
    <13681, 13678, 13675>, 0,
    <13681, 13675, 13680>, 0,
    <13681, 13680, 12863>, 0,
    <13681, 12863, 12988>, 0,
    <13681, 12988, 12984>, 0,
    <13681, 12984, 13670>, 0,
    <13685, 13684, 13682>, 0,
    <13685, 13682, 13683>, 0,
    <13685, 13683, 13573>, 0,
    <13685, 13573, 13575>, 0,
    <13685, 13575, 12863>, 0,
    <13685, 12863, 13680>, 0,
    <13685, 13680, 13675>, 0,
    <13685, 13675, 13684>, 0,
    <13689, 13688, 13682>, 0,
    <13689, 13682, 13684>, 0,
    <13689, 13684, 13675>, 0,
    <13689, 13675, 13677>, 0,
    <13689, 13677, 13674>, 0,
    <13689, 13674, 13687>, 0,
    <13689, 13687, 13686>, 0,
    <13689, 13686, 13688>, 0,
    <13691, 13683, 13682>, 0,
    <13691, 13682, 13688>, 0,
    <13691, 13688, 13686>, 0,
    <13691, 13686, 13690>, 0,
    <13691, 13690, 13578>, 0,
    <13691, 13578, 13580>, 0,
    <13691, 13580, 13573>, 0,
    <13691, 13573, 13683>, 0,
    <13700, 13699, 13692>, 0,
    <13700, 13692, 13696>, 0,
    <13700, 13696, 13693>, 0,
    <13700, 13693, 13697>, 0,
    <13700, 13697, 13694>, 0,
    <13700, 13694, 13698>, 0,
    <13700, 13698, 13695>, 0,
    <13700, 13695, 13699>, 0,
    <13703, 13702, 13692>, 0,
    <13703, 13692, 13699>, 0,
    <13703, 13699, 13695>, 0,
    <13703, 13695, 13701>, 0,
    <13703, 13701, 12787>, 0,
    <13703, 12787, 13616>, 0,
    <13703, 13616, 13611>, 0,
    <13703, 13611, 13702>, 0,
    <13705, 13696, 13692>, 0,
    <13705, 13692, 13702>, 0,
    <13705, 13702, 13611>, 0,
    <13705, 13611, 13613>, 0,
    <13705, 13613, 13598>, 0,
    <13705, 13598, 13704>, 0,
    <13705, 13704, 13693>, 0,
    <13705, 13693, 13696>, 0,
    <13711, 13710, 13706>, 0,
    <13711, 13706, 13708>, 0,
    <13711, 13708, 13695>, 0,
    <13711, 13695, 13698>, 0,
    <13711, 13698, 13694>, 0,
    <13711, 13694, 13709>, 0,
    <13711, 13709, 13707>, 0,
    <13711, 13707, 13710>, 0,
    <13714, 13713, 13706>, 0,
    <13714, 13706, 13710>, 0,
    <13714, 13710, 13707>, 0,
    <13714, 13707, 13712>, 0,
    <13714, 13712, 12883>, 0,
    <13714, 12883, 12886>, 0,
    <13714, 12886, 12882>, 0,
    <13714, 12882, 13713>, 0,
    <13715, 13708, 13706>, 0,
    <13715, 13706, 13713>, 0,
    <13715, 13713, 12882>, 0,
    <13715, 12882, 12893>, 0,
    <13715, 12893, 12787>, 0,
    <13715, 12787, 13701>, 0,
    <13715, 13701, 13695>, 0,
    <13715, 13695, 13708>, 0,
    <13721, 13720, 13716>, 0,
    <13721, 13716, 13718>, 0,
    <13721, 13718, 13717>, 0,
    <13721, 13717, 13719>, 0,
    <13721, 13719, 13024>, 0,
    <13721, 13024, 13036>, 0,
    <13721, 13036, 13032>, 0,
    <13721, 13032, 13720>, 0,
    <13725, 13724, 13716>, 0,
    <13725, 13716, 13720>, 0,
    <13725, 13720, 13032>, 0,
    <13725, 13032, 13033>, 0,
    <13725, 13033, 12915>, 0,
    <13725, 12915, 13723>, 0,
    <13725, 13723, 13722>, 0,
    <13725, 13722, 13724>, 0,
    <13729, 13718, 13716>, 0,
    <13729, 13716, 13724>, 0,
    <13729, 13724, 13722>, 0,
    <13729, 13722, 13727>, 0,
    <13729, 13727, 13726>, 0,
    <13729, 13726, 13728>, 0,
    <13729, 13728, 13717>, 0,
    <13729, 13717, 13718>, 0,
    <13733, 13732, 13730>, 0,
    <13733, 13730, 13731>, 0,
    <13733, 13731, 13722>, 0,
    <13733, 13722, 13723>, 0,
    <13733, 13723, 12915>, 0,
    <13733, 12915, 13623>, 0,
    <13733, 13623, 13621>, 0,
    <13733, 13621, 13732>, 0,
    <13737, 13736, 13730>, 0,
    <13737, 13730, 13732>, 0,
    <13737, 13732, 13621>, 0,
    <13737, 13621, 13632>, 0,
    <13737, 13632, 13630>, 0,
    <13737, 13630, 13735>, 0,
    <13737, 13735, 13734>, 0,
    <13737, 13734, 13736>, 0,
    <13739, 13731, 13730>, 0,
    <13739, 13730, 13736>, 0,
    <13739, 13736, 13734>, 0,
    <13739, 13734, 13738>, 0,
    <13739, 13738, 13726>, 0,
    <13739, 13726, 13727>, 0,
    <13739, 13727, 13722>, 0,
    <13739, 13722, 13731>, 0,
    <13748, 13747, 13740>, 0,
    <13748, 13740, 13744>, 0,
    <13748, 13744, 13741>, 0,
    <13748, 13741, 13745>, 0,
    <13748, 13745, 13742>, 0,
    <13748, 13742, 13746>, 0,
    <13748, 13746, 13743>, 0,
    <13748, 13743, 13747>, 0,
    <13751, 13750, 13740>, 0,
    <13751, 13740, 13747>, 0,
    <13751, 13747, 13743>, 0,
    <13751, 13743, 13749>, 0,
    <13751, 13749, 13646>, 0,
    <13751, 13646, 13661>, 0,
    <13751, 13661, 13659>, 0,
    <13751, 13659, 13750>, 0,
    <13753, 13744, 13740>, 0,
    <13753, 13740, 13750>, 0,
    <13753, 13750, 13659>, 0,
    <13753, 13659, 13666>, 0,
    <13753, 13666, 12835>, 0,
    <13753, 12835, 13752>, 0,
    <13753, 13752, 13741>, 0,
    <13753, 13741, 13744>, 0,
    <13759, 13758, 13754>, 0,
    <13759, 13754, 13756>, 0,
    <13759, 13756, 13755>, 0,
    <13759, 13755, 13757>, 0,
    <13759, 13757, 13742>, 0,
    <13759, 13742, 13745>, 0,
    <13759, 13745, 13741>, 0,
    <13759, 13741, 13758>, 0,
    <13761, 13760, 13754>, 0,
    <13761, 13754, 13758>, 0,
    <13761, 13758, 13741>, 0,
    <13761, 13741, 13752>, 0,
    <13761, 13752, 12835>, 0,
    <13761, 12835, 12938>, 0,
    <13761, 12938, 12932>, 0,
    <13761, 12932, 13760>, 0,
    <13763, 13756, 13754>, 0,
    <13763, 13754, 13760>, 0,
    <13763, 13760, 12932>, 0,
    <13763, 12932, 12935>, 0,
    <13763, 12935, 12931>, 0,
    <13763, 12931, 13762>, 0,
    <13763, 13762, 13755>, 0,
    <13763, 13755, 13756>, 0,
    <13769, 13768, 13764>, 0,
    <13769, 13764, 13766>, 0,
    <13769, 13766, 13068>, 0,
    <13769, 13068, 13070>, 0,
    <13769, 13070, 2553>, 0,
    <13769, 2553, 13767>, 0,
    <13769, 13767, 13765>, 0,
    <13769, 13765, 13768>, 0,
    <13775, 13774, 13764>, 0,
    <13775, 13764, 13768>, 0,
    <13775, 13768, 13765>, 0,
    <13775, 13765, 13772>, 0,
    <13775, 13772, 13770>, 0,
    <13775, 13770, 13773>, 0,
    <13775, 13773, 13771>, 0,
    <13775, 13771, 13774>, 0,
    <13777, 13766, 13764>, 0,
    <13777, 13764, 13774>, 0,
    <13777, 13774, 13771>, 0,
    <13777, 13771, 13776>, 0,
    <13777, 13776, 12966>, 0,
    <13777, 12966, 13073>, 0,
    <13777, 13073, 13068>, 0,
    <13777, 13068, 13766>, 0,
    <13783, 13782, 13778>, 0,
    <13783, 13778, 13780>, 0,
    <13783, 13780, 13765>, 0,
    <13783, 13765, 13767>, 0,
    <13783, 13767, 2553>, 0,
    <13783, 2553, 13781>, 0,
    <13783, 13781, 13779>, 0,
    <13783, 13779, 13782>, 0,
    <13788, 13787, 13778>, 0,
    <13788, 13778, 13782>, 0,
    <13788, 13782, 13779>, 0,
    <13788, 13779, 13785>, 0,
    <13788, 13785, 2823>, 0,
    <13788, 2823, 13786>, 0,
    <13788, 13786, 13784>, 0,
    <13788, 13784, 13787>, 0,
    <13790, 13780, 13778>, 0,
    <13790, 13778, 13787>, 0,
    <13790, 13787, 13784>, 0,
    <13790, 13784, 13789>, 0,
    <13790, 13789, 13770>, 0,
    <13790, 13770, 13772>, 0,
    <13790, 13772, 13765>, 0,
    <13790, 13765, 13780>, 0,
    <13794, 13793, 13791>, 0,
    <13794, 13791, 13792>, 0,
    <13794, 13792, 13669>, 0,
    <13794, 13669, 13671>, 0,
    <13794, 13671, 12966>, 0,
    <13794, 12966, 13776>, 0,
    <13794, 13776, 13771>, 0,
    <13794, 13771, 13793>, 0,
    <13798, 13797, 13791>, 0,
    <13798, 13791, 13793>, 0,
    <13798, 13793, 13771>, 0,
    <13798, 13771, 13773>, 0,
    <13798, 13773, 13770>, 0,
    <13798, 13770, 13796>, 0,
    <13798, 13796, 13795>, 0,
    <13798, 13795, 13797>, 0,
    <13800, 13792, 13791>, 0,
    <13800, 13791, 13797>, 0,
    <13800, 13797, 13795>, 0,
    <13800, 13795, 13799>, 0,
    <13800, 13799, 13674>, 0,
    <13800, 13674, 13676>, 0,
    <13800, 13676, 13669>, 0,
    <13800, 13669, 13792>, 0,
    <13809, 13808, 13801>, 0,
    <13809, 13801, 13805>, 0,
    <13809, 13805, 13802>, 0,
    <13809, 13802, 13806>, 0,
    <13809, 13806, 13803>, 0,
    <13809, 13803, 13807>, 0,
    <13809, 13807, 13804>, 0,
    <13809, 13804, 13808>, 0,
    <13812, 13811, 13801>, 0,
    <13812, 13801, 13808>, 0,
    <13812, 13808, 13804>, 0,
    <13812, 13804, 13810>, 0,
    <13812, 13810, 12883>, 0,
    <13812, 12883, 13712>, 0,
    <13812, 13712, 13707>, 0,
    <13812, 13707, 13811>, 0,
    <13814, 13805, 13801>, 0,
    <13814, 13801, 13811>, 0,
    <13814, 13811, 13707>, 0,
    <13814, 13707, 13709>, 0,
    <13814, 13709, 13694>, 0,
    <13814, 13694, 13813>, 0,
    <13814, 13813, 13802>, 0,
    <13814, 13802, 13805>, 0,
    <13820, 13819, 13815>, 0,
    <13820, 13815, 13817>, 0,
    <13820, 13817, 13804>, 0,
    <13820, 13804, 13807>, 0,
    <13820, 13807, 13803>, 0,
    <13820, 13803, 13818>, 0,
    <13820, 13818, 13816>, 0,
    <13820, 13816, 13819>, 0,
    <13823, 13822, 13815>, 0,
    <13823, 13815, 13819>, 0,
    <13823, 13819, 13816>, 0,
    <13823, 13816, 13821>, 0,
    <13823, 13821, 12992>, 0,
    <13823, 12992, 12995>, 0,
    <13823, 12995, 12991>, 0,
    <13823, 12991, 13822>, 0,
    <13824, 13817, 13815>, 0,
    <13824, 13815, 13822>, 0,
    <13824, 13822, 12991>, 0,
    <13824, 12991, 13002>, 0,
    <13824, 13002, 12883>, 0,
    <13824, 12883, 13810>, 0,
    <13824, 13810, 13804>, 0,
    <13824, 13804, 13817>, 0,
    <13830, 13829, 13825>, 0,
    <13830, 13825, 13827>, 0,
    <13830, 13827, 13826>, 0,
    <13830, 13826, 13828>, 0,
    <13830, 13828, 13112>, 0,
    <13830, 13112, 13134>, 0,
    <13830, 13134, 13130>, 0,
    <13830, 13130, 13829>, 0,
    <13834, 13833, 13825>, 0,
    <13834, 13825, 13829>, 0,
    <13834, 13829, 13130>, 0,
    <13834, 13130, 13131>, 0,
    <13834, 13131, 13024>, 0,
    <13834, 13024, 13832>, 0,
    <13834, 13832, 13831>, 0,
    <13834, 13831, 13833>, 0,
    <13838, 13827, 13825>, 0,
    <13838, 13825, 13833>, 0,
    <13838, 13833, 13831>, 0,
    <13838, 13831, 13836>, 0,
    <13838, 13836, 13835>, 0,
    <13838, 13835, 13837>, 0,
    <13838, 13837, 13826>, 0,
    <13838, 13826, 13827>, 0,
    <13842, 13841, 13839>, 0,
    <13842, 13839, 13840>, 0,
    <13842, 13840, 13831>, 0,
    <13842, 13831, 13832>, 0,
    <13842, 13832, 13024>, 0,
    <13842, 13024, 13719>, 0,
    <13842, 13719, 13717>, 0,
    <13842, 13717, 13841>, 0,
    <13846, 13845, 13839>, 0,
    <13846, 13839, 13841>, 0,
    <13846, 13841, 13717>, 0,
    <13846, 13717, 13728>, 0,
    <13846, 13728, 13726>, 0,
    <13846, 13726, 13844>, 0,
    <13846, 13844, 13843>, 0,
    <13846, 13843, 13845>, 0,
    <13848, 13840, 13839>, 0,
    <13848, 13839, 13845>, 0,
    <13848, 13845, 13843>, 0,
    <13848, 13843, 13847>, 0,
    <13848, 13847, 13835>, 0,
    <13848, 13835, 13836>, 0,
    <13848, 13836, 13831>, 0,
    <13848, 13831, 13840>, 0,
    <13857, 13856, 13849>, 0,
    <13857, 13849, 13853>, 0,
    <13857, 13853, 13850>, 0,
    <13857, 13850, 13854>, 0,
    <13857, 13854, 13851>, 0,
    <13857, 13851, 13855>, 0,
    <13857, 13855, 13852>, 0,
    <13857, 13852, 13856>, 0,
    <13860, 13859, 13849>, 0,
    <13860, 13849, 13856>, 0,
    <13860, 13856, 13852>, 0,
    <13860, 13852, 13858>, 0,
    <13860, 13858, 13742>, 0,
    <13860, 13742, 13757>, 0,
    <13860, 13757, 13755>, 0,
    <13860, 13755, 13859>, 0,
    <13862, 13853, 13849>, 0,
    <13862, 13849, 13859>, 0,
    <13862, 13859, 13755>, 0,
    <13862, 13755, 13762>, 0,
    <13862, 13762, 12931>, 0,
    <13862, 12931, 13861>, 0,
    <13862, 13861, 13850>, 0,
    <13862, 13850, 13853>, 0,
    <13868, 13867, 13863>, 0,
    <13868, 13863, 13865>, 0,
    <13868, 13865, 13864>, 0,
    <13868, 13864, 13866>, 0,
    <13868, 13866, 13851>, 0,
    <13868, 13851, 13854>, 0,
    <13868, 13854, 13850>, 0,
    <13868, 13850, 13867>, 0,
    <13870, 13869, 13863>, 0,
    <13870, 13863, 13867>, 0,
    <13870, 13867, 13850>, 0,
    <13870, 13850, 13861>, 0,
    <13870, 13861, 12931>, 0,
    <13870, 12931, 13047>, 0,
    <13870, 13047, 13041>, 0,
    <13870, 13041, 13869>, 0,
    <13872, 13865, 13863>, 0,
    <13872, 13863, 13869>, 0,
    <13872, 13869, 13041>, 0,
    <13872, 13041, 13044>, 0,
    <13872, 13044, 13040>, 0,
    <13872, 13040, 13871>, 0,
    <13872, 13871, 13864>, 0,
    <13872, 13864, 13865>, 0,
    <13878, 13877, 13873>, 0,
    <13878, 13873, 13875>, 0,
    <13878, 13875, 13784>, 0,
    <13878, 13784, 13786>, 0,
    <13878, 13786, 2823>, 0,
    <13878, 2823, 13876>, 0,
    <13878, 13876, 13874>, 0,
    <13878, 13874, 13877>, 0,
    <13883, 13882, 13873>, 0,
    <13883, 13873, 13877>, 0,
    <13883, 13877, 13874>, 0,
    <13883, 13874, 13880>, 0,
    <13883, 13880, 2811>, 0,
    <13883, 2811, 13881>, 0,
    <13883, 13881, 13879>, 0,
    <13883, 13879, 13882>, 0,
    <13885, 13875, 13873>, 0,
    <13885, 13873, 13882>, 0,
    <13885, 13882, 13879>, 0,
    <13885, 13879, 13884>, 0,
    <13885, 13884, 13770>, 0,
    <13885, 13770, 13789>, 0,
    <13885, 13789, 13784>, 0,
    <13885, 13784, 13875>, 0,
    <13893, 13892, 13886>, 0,
    <13893, 13886, 13889>, 0,
    <13893, 13889, 13887>, 0,
    <13893, 13887, 13890>, 0,
    <13893, 13890, 2896>, 0,
    <13893, 2896, 13891>, 0,
    <13893, 13891, 13888>, 0,
    <13893, 13888, 13892>, 0,
    <13896, 13895, 13886>, 0,
    <13896, 13886, 13892>, 0,
    <13896, 13892, 13888>, 0,
    <13896, 13888, 13894>, 0,
    <13896, 13894, 12992>, 0,
    <13896, 12992, 13821>, 0,
    <13896, 13821, 13816>, 0,
    <13896, 13816, 13895>, 0,
    <13898, 13889, 13886>, 0,
    <13898, 13886, 13895>, 0,
    <13898, 13895, 13816>, 0,
    <13898, 13816, 13818>, 0,
    <13898, 13818, 13803>, 0,
    <13898, 13803, 13897>, 0,
    <13898, 13897, 13887>, 0,
    <13898, 13887, 13889>, 0,
    <13904, 13903, 13899>, 0,
    <13904, 13899, 13901>, 0,
    <13904, 13901, 13888>, 0,
    <13904, 13888, 13891>, 0,
    <13904, 13891, 2896>, 0,
    <13904, 2896, 13902>, 0,
    <13904, 13902, 13900>, 0,
    <13904, 13900, 13903>, 0,
    <13907, 13906, 13899>, 0,
    <13907, 13899, 13903>, 0,
    <13907, 13903, 13900>, 0,
    <13907, 13900, 13905>, 0,
    <13907, 13905, 13226>, 0,
    <13907, 13226, 13229>, 0,
    <13907, 13229, 13225>, 0,
    <13907, 13225, 13906>, 0,
    <13908, 13901, 13899>, 0,
    <13908, 13899, 13906>, 0,
    <13908, 13906, 13225>, 0,
    <13908, 13225, 13236>, 0,
    <13908, 13236, 12992>, 0,
    <13908, 12992, 13894>, 0,
    <13908, 13894, 13888>, 0,
    <13908, 13888, 13901>, 0,
    <13917, 13916, 13909>, 0,
    <13917, 13909, 13913>, 0,
    <13917, 13913, 13910>, 0,
    <13917, 13910, 13914>, 0,
    <13917, 13914, 13911>, 0,
    <13917, 13911, 13915>, 0,
    <13917, 13915, 13912>, 0,
    <13917, 13912, 13916>, 0,
    <13922, 13921, 13909>, 0,
    <13922, 13909, 13916>, 0,
    <13922, 13916, 13912>, 0,
    <13922, 13912, 13919>, 0,
    <13922, 13919, 13212>, 0,
    <13922, 13212, 13920>, 0,
    <13922, 13920, 13918>, 0,
    <13922, 13918, 13921>, 0,
    <13926, 13913, 13909>, 0,
    <13926, 13909, 13921>, 0,
    <13926, 13921, 13918>, 0,
    <13926, 13918, 13924>, 0,
    <13926, 13924, 13923>, 0,
    <13926, 13923, 13925>, 0,
    <13926, 13925, 13910>, 0,
    <13926, 13910, 13913>, 0,
    <13930, 13929, 13927>, 0,
    <13930, 13927, 13928>, 0,
    <13930, 13928, 13918>, 0,
    <13930, 13918, 13920>, 0,
    <13930, 13920, 13212>, 0,
    <13930, 13212, 13215>, 0,
    <13930, 13215, 13211>, 0,
    <13930, 13211, 13929>, 0,
    <13934, 13933, 13927>, 0,
    <13934, 13927, 13929>, 0,
    <13934, 13929, 13211>, 0,
    <13934, 13211, 13222>, 0,
    <13934, 13222, 13112>, 0,
    <13934, 13112, 13932>, 0,
    <13934, 13932, 13931>, 0,
    <13934, 13931, 13933>, 0,
    <13936, 13928, 13927>, 0,
    <13936, 13927, 13933>, 0,
    <13936, 13933, 13931>, 0,
    <13936, 13931, 13935>, 0,
    <13936, 13935, 13923>, 0,
    <13936, 13923, 13924>, 0,
    <13936, 13924, 13918>, 0,
    <13936, 13918, 13928>, 0,
    <13940, 13939, 13937>, 0,
    <13940, 13937, 13938>, 0,
    <13940, 13938, 13931>, 0,
    <13940, 13931, 13932>, 0,
    <13940, 13932, 13112>, 0,
    <13940, 13112, 13828>, 0,
    <13940, 13828, 13826>, 0,
    <13940, 13826, 13939>, 0,
    <13944, 13943, 13937>, 0,
    <13944, 13937, 13939>, 0,
    <13944, 13939, 13826>, 0,
    <13944, 13826, 13837>, 0,
    <13944, 13837, 13835>, 0,
    <13944, 13835, 13942>, 0,
    <13944, 13942, 13941>, 0,
    <13944, 13941, 13943>, 0,
    <13946, 13938, 13937>, 0,
    <13946, 13937, 13943>, 0,
    <13946, 13943, 13941>, 0,
    <13946, 13941, 13945>, 0,
    <13946, 13945, 13923>, 0,
    <13946, 13923, 13935>, 0,
    <13946, 13935, 13931>, 0,
    <13946, 13931, 13938>, 0,
    <13954, 13953, 13947>, 0,
    <13954, 13947, 13950>, 0,
    <13954, 13950, 13948>, 0,
    <13954, 13948, 13951>, 0,
    <13954, 13951, 13240>, 0,
    <13954, 13240, 13952>, 0,
    <13954, 13952, 13949>, 0,
    <13954, 13949, 13953>, 0,
    <13960, 13959, 13947>, 0,
    <13960, 13947, 13953>, 0,
    <13960, 13953, 13949>, 0,
    <13960, 13949, 13957>, 0,
    <13960, 13957, 13955>, 0,
    <13960, 13955, 13958>, 0,
    <13960, 13958, 13956>, 0,
    <13960, 13956, 13959>, 0,
    <13964, 13950, 13947>, 0,
    <13964, 13947, 13959>, 0,
    <13964, 13959, 13956>, 0,
    <13964, 13956, 13962>, 0,
    <13964, 13962, 13961>, 0,
    <13964, 13961, 13963>, 0,
    <13964, 13963, 13948>, 0,
    <13964, 13948, 13950>, 0,
    <13972, 13971, 13965>, 0,
    <13972, 13965, 13968>, 0,
    <13972, 13968, 13966>, 0,
    <13972, 13966, 13969>, 0,
    <13972, 13969, 13961>, 0,
    <13972, 13961, 13970>, 0,
    <13972, 13970, 13967>, 0,
    <13972, 13967, 13971>, 0,
    <13975, 13974, 13965>, 0,
    <13975, 13965, 13971>, 0,
    <13975, 13971, 13967>, 0,
    <13975, 13967, 13973>, 0,
    <13975, 13973, 13851>, 0,
    <13975, 13851, 13866>, 0,
    <13975, 13866, 13864>, 0,
    <13975, 13864, 13974>, 0,
    <13977, 13968, 13965>, 0,
    <13977, 13965, 13974>, 0,
    <13977, 13974, 13864>, 0,
    <13977, 13864, 13871>, 0,
    <13977, 13871, 13040>, 0,
    <13977, 13040, 13976>, 0,
    <13977, 13976, 13966>, 0,
    <13977, 13966, 13968>, 0,
    <13981, 13980, 13978>, 0,
    <13981, 13978, 13979>, 0,
    <13981, 13979, 13241>, 0,
    <13981, 13241, 13244>, 0,
    <13981, 13244, 13240>, 0,
    <13981, 13240, 13951>, 0,
    <13981, 13951, 13948>, 0,
    <13981, 13948, 13980>, 0,
    <13985, 13984, 13978>, 0,
    <13985, 13978, 13980>, 0,
    <13985, 13980, 13948>, 0,
    <13985, 13948, 13963>, 0,
    <13985, 13963, 13961>, 0,
    <13985, 13961, 13983>, 0,
    <13985, 13983, 13982>, 0,
    <13985, 13982, 13984>, 0,
    <13987, 13979, 13978>, 0,
    <13987, 13978, 13984>, 0,
    <13987, 13984, 13982>, 0,
    <13987, 13982, 13986>, 0,
    <13987, 13986, 13150>, 0,
    <13987, 13150, 13247>, 0,
    <13987, 13247, 13241>, 0,
    <13987, 13241, 13979>, 0,
    <13991, 13990, 13988>, 0,
    <13991, 13988, 13989>, 0,
    <13991, 13989, 13982>, 0,
    <13991, 13982, 13983>, 0,
    <13991, 13983, 13961>, 0,
    <13991, 13961, 13969>, 0,
    <13991, 13969, 13966>, 0,
    <13991, 13966, 13990>, 0,
    <13993, 13992, 13988>, 0,
    <13993, 13988, 13990>, 0,
    <13993, 13990, 13966>, 0,
    <13993, 13966, 13976>, 0,
    <13993, 13976, 13040>, 0,
    <13993, 13040, 13162>, 0,
    <13993, 13162, 13156>, 0,
    <13993, 13156, 13992>, 0,
    <13994, 13989, 13988>, 0,
    <13994, 13988, 13992>, 0,
    <13994, 13992, 13156>, 0,
    <13994, 13156, 13159>, 0,
    <13994, 13159, 13150>, 0,
    <13994, 13150, 13986>, 0,
    <13994, 13986, 13982>, 0,
    <13994, 13982, 13989>, 0,
    <14000, 13999, 13995>, 0,
    <14000, 13995, 13997>, 0,
    <14000, 13997, 13956>, 0,
    <14000, 13956, 13958>, 0,
    <14000, 13958, 13955>, 0,
    <14000, 13955, 13998>, 0,
    <14000, 13998, 13996>, 0,
    <14000, 13996, 13999>, 0,
    <14005, 14004, 13995>, 0,
    <14005, 13995, 13999>, 0,
    <14005, 13999, 13996>, 0,
    <14005, 13996, 14002>, 0,
    <14005, 14002, 2884>, 0,
    <14005, 2884, 14003>, 0,
    <14005, 14003, 14001>, 0,
    <14005, 14001, 14004>, 0,
    <14007, 13997, 13995>, 0,
    <14007, 13995, 14004>, 0,
    <14007, 14004, 14001>, 0,
    <14007, 14001, 14006>, 0,
    <14007, 14006, 13961>, 0,
    <14007, 13961, 13962>, 0,
    <14007, 13962, 13956>, 0,
    <14007, 13956, 13997>, 0,
    <14013, 14012, 14008>, 0,
    <14013, 14008, 14010>, 0,
    <14013, 14010, 14009>, 0,
    <14013, 14009, 14011>, 0,
    <14013, 14011, 13911>, 0,
    <14013, 13911, 13914>, 0,
    <14013, 13914, 13910>, 0,
    <14013, 13910, 14012>, 0,
    <14017, 14016, 14008>, 0,
    <14017, 14008, 14012>, 0,
    <14017, 14012, 13910>, 0,
    <14017, 13910, 13925>, 0,
    <14017, 13925, 13923>, 0,
    <14017, 13923, 14015>, 0,
    <14017, 14015, 14014>, 0,
    <14017, 14014, 14016>, 0,
    <14020, 14010, 14008>, 0,
    <14020, 14008, 14016>, 0,
    <14020, 14016, 14014>, 0,
    <14020, 14014, 14018>, 0,
    <14020, 14018, 2870>, 0,
    <14020, 2870, 14019>, 0,
    <14020, 14019, 14009>, 0,
    <14020, 14009, 14010>, 0,
    <14029, 14028, 14021>, 0,
    <14029, 14021, 14025>, 0,
    <14029, 14025, 14022>, 0,
    <14029, 14022, 14026>, 0,
    <14029, 14026, 14023>, 0,
    <14029, 14023, 14027>, 0,
    <14029, 14027, 14024>, 0,
    <14029, 14024, 14028>, 0,
    <14032, 14031, 14021>, 0,
    <14032, 14021, 14028>, 0,
    <14032, 14028, 14024>, 0,
    <14032, 14024, 14030>, 0,
    <14032, 14030, 2870>, 0,
    <14032, 2870, 14018>, 0,
    <14032, 14018, 14014>, 0,
    <14032, 14014, 14031>, 0,
    <14034, 14025, 14021>, 0,
    <14034, 14021, 14031>, 0,
    <14034, 14031, 14014>, 0,
    <14034, 14014, 14015>, 0,
    <14034, 14015, 13923>, 0,
    <14034, 13923, 14033>, 0,
    <14034, 14033, 14022>, 0,
    <14034, 14022, 14025>, 0,
    <14043, 14042, 14035>, 0,
    <14043, 14035, 14039>, 0,
    <14043, 14039, 14036>, 0,
    <14043, 14036, 14040>, 0,
    <14043, 14040, 14037>, 0,
    <14043, 14037, 14041>, 0,
    <14043, 14041, 14038>, 0,
    <14043, 14038, 14042>, 0,
    <14046, 14045, 14035>, 0,
    <14046, 14035, 14042>, 0,
    <14046, 14042, 14038>, 0,
    <14046, 14038, 14044>, 0,
    <14046, 14044, 2896>, 0,
    <14046, 2896, 13890>, 0,
    <14046, 13890, 13887>, 0,
    <14046, 13887, 14045>, 0,
    <14048, 14039, 14035>, 0,
    <14048, 14035, 14045>, 0,
    <14048, 14045, 13887>, 0,
    <14048, 13887, 13897>, 0,
    <14048, 13897, 13803>, 0,
    <14048, 13803, 14047>, 0,
    <14048, 14047, 14036>, 0,
    <14048, 14036, 14039>, 0,
    <14057, 14056, 14049>, 0,
    <14057, 14049, 14053>, 0,
    <14057, 14053, 14050>, 0,
    <14057, 14050, 14054>, 0,
    <14057, 14054, 14051>, 0,
    <14057, 14051, 14055>, 0,
    <14057, 14055, 14052>, 0,
    <14057, 14052, 14056>, 0,
    <14060, 14059, 14049>, 0,
    <14060, 14049, 14056>, 0,
    <14060, 14056, 14052>, 0,
    <14060, 14052, 14058>, 0,
    <14060, 14058, 13961>, 0,
    <14060, 13961, 14006>, 0,
    <14060, 14006, 14001>, 0,
    <14060, 14001, 14059>, 0,
    <14062, 14053, 14049>, 0,
    <14062, 14049, 14059>, 0,
    <14062, 14059, 14001>, 0,
    <14062, 14001, 14003>, 0,
    <14062, 14003, 2884>, 0,
    <14062, 2884, 14061>, 0,
    <14062, 14061, 14050>, 0,
    <14062, 14050, 14053>, 0,
    <14068, 14067, 14063>, 0,
    <14068, 14063, 14065>, 0,
    <14068, 14065, 13283>, 0,
    <14068, 13283, 13284>, 0,
    <14068, 13284, 13271>, 0,
    <14068, 13271, 14066>, 0,
    <14068, 14066, 14064>, 0,
    <14068, 14064, 14067>, 0,
    <14073, 14072, 14063>, 0,
    <14073, 14063, 14067>, 0,
    <14073, 14067, 14064>, 0,
    <14073, 14064, 14070>, 0,
    <14073, 14070, 3007>, 0,
    <14073, 3007, 14071>, 0,
    <14073, 14071, 14069>, 0,
    <14073, 14069, 14072>, 0,
    <14075, 14065, 14063>, 0,
    <14075, 14063, 14072>, 0,
    <14075, 14072, 14069>, 0,
    <14075, 14069, 14074>, 0,
    <14075, 14074, 2753>, 0,
    <14075, 2753, 13287>, 0,
    <14075, 13287, 13283>, 0,
    <14075, 13283, 14065>, 0,
    <14081, 14080, 14076>, 0,
    <14081, 14076, 14078>, 0,
    <14081, 14078, 13334>, 0,
    <14081, 13334, 13335>, 0,
    <14081, 13335, 13322>, 0,
    <14081, 13322, 14079>, 0,
    <14081, 14079, 14077>, 0,
    <14081, 14077, 14080>, 0,
    <14087, 14086, 14076>, 0,
    <14087, 14076, 14080>, 0,
    <14087, 14080, 14077>, 0,
    <14087, 14077, 14084>, 0,
    <14087, 14084, 14082>, 0,
    <14087, 14082, 14085>, 0,
    <14087, 14085, 14083>, 0,
    <14087, 14083, 14086>, 0,
    <14089, 14078, 14076>, 0,
    <14089, 14076, 14086>, 0,
    <14089, 14086, 14083>, 0,
    <14089, 14083, 14088>, 0,
    <14089, 14088, 13271>, 0,
    <14089, 13271, 13338>, 0,
    <14089, 13338, 13334>, 0,
    <14089, 13334, 14078>, 0,
    <14093, 14092, 14090>, 0,
    <14093, 14090, 14091>, 0,
    <14093, 14091, 14064>, 0,
    <14093, 14064, 14066>, 0,
    <14093, 14066, 13271>, 0,
    <14093, 13271, 14088>, 0,
    <14093, 14088, 14083>, 0,
    <14093, 14083, 14092>, 0,
    <14097, 14096, 14090>, 0,
    <14097, 14090, 14092>, 0,
    <14097, 14092, 14083>, 0,
    <14097, 14083, 14085>, 0,
    <14097, 14085, 14082>, 0,
    <14097, 14082, 14095>, 0,
    <14097, 14095, 14094>, 0,
    <14097, 14094, 14096>, 0,
    <14099, 14091, 14090>, 0,
    <14099, 14090, 14096>, 0,
    <14099, 14096, 14094>, 0,
    <14099, 14094, 14098>, 0,
    <14099, 14098, 3007>, 0,
    <14099, 3007, 14070>, 0,
    <14099, 14070, 14064>, 0,
    <14099, 14064, 14091>, 0,
    <14108, 14107, 14100>, 0,
    <14108, 14100, 14104>, 0,
    <14108, 14104, 14101>, 0,
    <14108, 14101, 14105>, 0,
    <14108, 14105, 14102>, 0,
    <14108, 14102, 14106>, 0,
    <14108, 14106, 14103>, 0,
    <14108, 14103, 14107>, 0,
    <14113, 14112, 14100>, 0,
    <14113, 14100, 14107>, 0,
    <14113, 14107, 14103>, 0,
    <14113, 14103, 14110>, 0,
    <14113, 14110, 2777>, 0,
    <14113, 2777, 14111>, 0,
    <14113, 14111, 14109>, 0,
    <14113, 14109, 14112>, 0,
    <14116, 14104, 14100>, 0,
    <14116, 14100, 14112>, 0,
    <14116, 14112, 14109>, 0,
    <14116, 14109, 14114>, 0,
    <14116, 14114, 3020>, 0,
    <14116, 3020, 14115>, 0,
    <14116, 14115, 14101>, 0,
    <14116, 14101, 14104>, 0,
    <14122, 14121, 14117>, 0,
    <14122, 14117, 14119>, 0,
    <14122, 14119, 14103>, 0,
    <14122, 14103, 14106>, 0,
    <14122, 14106, 14102>, 0,
    <14122, 14102, 14120>, 0,
    <14122, 14120, 14118>, 0,
    <14122, 14118, 14121>, 0,
    <14125, 14124, 14117>, 0,
    <14125, 14117, 14121>, 0,
    <14125, 14121, 14118>, 0,
    <14125, 14118, 14123>, 0,
    <14125, 14123, 13291>, 0,
    <14125, 13291, 13294>, 0,
    <14125, 13294, 13290>, 0,
    <14125, 13290, 14124>, 0,
    <14126, 14119, 14117>, 0,
    <14126, 14117, 14124>, 0,
    <14126, 14124, 13290>, 0,
    <14126, 13290, 13304>, 0,
    <14126, 13304, 2777>, 0,
    <14126, 2777, 14110>, 0,
    <14126, 14110, 14103>, 0,
    <14126, 14103, 14119>, 0,
    <14132, 14131, 14127>, 0,
    <14132, 14127, 14129>, 0,
    <14132, 14129, 13446>, 0,
    <14132, 13446, 13447>, 0,
    <14132, 13447, 13434>, 0,
    <14132, 13434, 14130>, 0,
    <14132, 14130, 14128>, 0,
    <14132, 14128, 14131>, 0,
    <14138, 14137, 14127>, 0,
    <14138, 14127, 14131>, 0,
    <14138, 14131, 14128>, 0,
    <14138, 14128, 14135>, 0,
    <14138, 14135, 14133>, 0,
    <14138, 14133, 14136>, 0,
    <14138, 14136, 14134>, 0,
    <14138, 14134, 14137>, 0,
    <14140, 14129, 14127>, 0,
    <14140, 14127, 14137>, 0,
    <14140, 14137, 14134>, 0,
    <14140, 14134, 14139>, 0,
    <14140, 14139, 13322>, 0,
    <14140, 13322, 13450>, 0,
    <14140, 13450, 13446>, 0,
    <14140, 13446, 14129>, 0,
    <14144, 14143, 14141>, 0,
    <14144, 14141, 14142>, 0,
    <14144, 14142, 14077>, 0,
    <14144, 14077, 14079>, 0,
    <14144, 14079, 13322>, 0,
    <14144, 13322, 14139>, 0,
    <14144, 14139, 14134>, 0,
    <14144, 14134, 14143>, 0,
    <14148, 14147, 14141>, 0,
    <14148, 14141, 14143>, 0,
    <14148, 14143, 14134>, 0,
    <14148, 14134, 14136>, 0,
    <14148, 14136, 14133>, 0,
    <14148, 14133, 14146>, 0,
    <14148, 14146, 14145>, 0,
    <14148, 14145, 14147>, 0,
    <14150, 14142, 14141>, 0,
    <14150, 14141, 14147>, 0,
    <14150, 14147, 14145>, 0,
    <14150, 14145, 14149>, 0,
    <14150, 14149, 14082>, 0,
    <14150, 14082, 14084>, 0,
    <14150, 14084, 14077>, 0,
    <14150, 14077, 14142>, 0,
    <14159, 14158, 14151>, 0,
    <14159, 14151, 14155>, 0,
    <14159, 14155, 14152>, 0,
    <14159, 14152, 14156>, 0,
    <14159, 14156, 14153>, 0,
    <14159, 14153, 14157>, 0,
    <14159, 14157, 14154>, 0,
    <14159, 14154, 14158>, 0,
    <14162, 14161, 14151>, 0,
    <14162, 14151, 14158>, 0,
    <14162, 14158, 14154>, 0,
    <14162, 14154, 14160>, 0,
    <14162, 14160, 13291>, 0,
    <14162, 13291, 14123>, 0,
    <14162, 14123, 14118>, 0,
    <14162, 14118, 14161>, 0,
    <14164, 14155, 14151>, 0,
    <14164, 14151, 14161>, 0,
    <14164, 14161, 14118>, 0,
    <14164, 14118, 14120>, 0,
    <14164, 14120, 14102>, 0,
    <14164, 14102, 14163>, 0,
    <14164, 14163, 14152>, 0,
    <14164, 14152, 14155>, 0,
    <14170, 14169, 14165>, 0,
    <14170, 14165, 14167>, 0,
    <14170, 14167, 14154>, 0,
    <14170, 14154, 14157>, 0,
    <14170, 14157, 14153>, 0,
    <14170, 14153, 14168>, 0,
    <14170, 14168, 14166>, 0,
    <14170, 14166, 14169>, 0,
    <14173, 14172, 14165>, 0,
    <14173, 14165, 14169>, 0,
    <14173, 14169, 14166>, 0,
    <14173, 14166, 14171>, 0,
    <14173, 14171, 13342>, 0,
    <14173, 13342, 13345>, 0,
    <14173, 13345, 13341>, 0,
    <14173, 13341, 14172>, 0,
    <14174, 14167, 14165>, 0,
    <14174, 14165, 14172>, 0,
    <14174, 14172, 13341>, 0,
    <14174, 13341, 13352>, 0,
    <14174, 13352, 13291>, 0,
    <14174, 13291, 14160>, 0,
    <14174, 14160, 14154>, 0,
    <14174, 14154, 14167>, 0,
    <14180, 14179, 14175>, 0,
    <14180, 14175, 14177>, 0,
    <14180, 14177, 14176>, 0,
    <14180, 14176, 14178>, 0,
    <14180, 14178, 13387>, 0,
    <14180, 13387, 13399>, 0,
    <14180, 13399, 13395>, 0,
    <14180, 13395, 14179>, 0,
    <14184, 14183, 14175>, 0,
    <14184, 14175, 14179>, 0,
    <14184, 14179, 13395>, 0,
    <14184, 13395, 13396>, 0,
    <14184, 13396, 2791>, 0,
    <14184, 2791, 14182>, 0,
    <14184, 14182, 14181>, 0,
    <14184, 14181, 14183>, 0,
    <14187, 14177, 14175>, 0,
    <14187, 14175, 14183>, 0,
    <14187, 14183, 14181>, 0,
    <14187, 14181, 14185>, 0,
    <14187, 14185, 3049>, 0,
    <14187, 3049, 14186>, 0,
    <14187, 14186, 14176>, 0,
    <14187, 14176, 14177>, 0,
    <14193, 14192, 14188>, 0,
    <14193, 14188, 14190>, 0,
    <14193, 14190, 14189>, 0,
    <14193, 14189, 14191>, 0,
    <14193, 14191, 13486>, 0,
    <14193, 13486, 13498>, 0,
    <14193, 13498, 13494>, 0,
    <14193, 13494, 14192>, 0,
    <14197, 14196, 14188>, 0,
    <14197, 14188, 14192>, 0,
    <14197, 14192, 13494>, 0,
    <14197, 13494, 13495>, 0,
    <14197, 13495, 13387>, 0,
    <14197, 13387, 14195>, 0,
    <14197, 14195, 14194>, 0,
    <14197, 14194, 14196>, 0,
    <14201, 14190, 14188>, 0,
    <14201, 14188, 14196>, 0,
    <14201, 14196, 14194>, 0,
    <14201, 14194, 14199>, 0,
    <14201, 14199, 14198>, 0,
    <14201, 14198, 14200>, 0,
    <14201, 14200, 14189>, 0,
    <14201, 14189, 14190>, 0,
    <14205, 14204, 14202>, 0,
    <14205, 14202, 14203>, 0,
    <14205, 14203, 14194>, 0,
    <14205, 14194, 14195>, 0,
    <14205, 14195, 13387>, 0,
    <14205, 13387, 14178>, 0,
    <14205, 14178, 14176>, 0,
    <14205, 14176, 14204>, 0,
    <14209, 14208, 14202>, 0,
    <14209, 14202, 14204>, 0,
    <14209, 14204, 14176>, 0,
    <14209, 14176, 14186>, 0,
    <14209, 14186, 3049>, 0,
    <14209, 3049, 14207>, 0,
    <14209, 14207, 14206>, 0,
    <14209, 14206, 14208>, 0,
    <14211, 14203, 14202>, 0,
    <14211, 14202, 14208>, 0,
    <14211, 14208, 14206>, 0,
    <14211, 14206, 14210>, 0,
    <14211, 14210, 14198>, 0,
    <14211, 14198, 14199>, 0,
    <14211, 14199, 14194>, 0,
    <14211, 14194, 14203>, 0,
    <14220, 14219, 14212>, 0,
    <14220, 14212, 14216>, 0,
    <14220, 14216, 14213>, 0,
    <14220, 14213, 14217>, 0,
    <14220, 14217, 14214>, 0,
    <14220, 14214, 14218>, 0,
    <14220, 14218, 14215>, 0,
    <14220, 14215, 14219>, 0,
    <14225, 14224, 14212>, 0,
    <14225, 14212, 14219>, 0,
    <14225, 14219, 14215>, 0,
    <14225, 14215, 14222>, 0,
    <14225, 14222, 3055>, 0,
    <14225, 3055, 14223>, 0,
    <14225, 14223, 14221>, 0,
    <14225, 14221, 14224>, 0,
    <14228, 14216, 14212>, 0,
    <14228, 14212, 14224>, 0,
    <14228, 14224, 14221>, 0,
    <14228, 14221, 14226>, 0,
    <14228, 14226, 2797>, 0,
    <14228, 2797, 14227>, 0,
    <14228, 14227, 14213>, 0,
    <14228, 14213, 14216>, 0,
    <14234, 14233, 14229>, 0,
    <14234, 14229, 14231>, 0,
    <14234, 14231, 14230>, 0,
    <14234, 14230, 14232>, 0,
    <14234, 14232, 14214>, 0,
    <14234, 14214, 14217>, 0,
    <14234, 14217, 14213>, 0,
    <14234, 14213, 14233>, 0,
    <14236, 14235, 14229>, 0,
    <14236, 14229, 14233>, 0,
    <14236, 14233, 14213>, 0,
    <14236, 14213, 14227>, 0,
    <14236, 14227, 2797>, 0,
    <14236, 2797, 13411>, 0,
    <14236, 13411, 13404>, 0,
    <14236, 13404, 14235>, 0,
    <14238, 14231, 14229>, 0,
    <14238, 14229, 14235>, 0,
    <14238, 14235, 13404>, 0,
    <14238, 13404, 13407>, 0,
    <14238, 13407, 13403>, 0,
    <14238, 13403, 14237>, 0,
    <14238, 14237, 14230>, 0,
    <14238, 14230, 14231>, 0,
    <14244, 14243, 14239>, 0,
    <14244, 14239, 14241>, 0,
    <14244, 14241, 13590>, 0,
    <14244, 13590, 13591>, 0,
    <14244, 13591, 13578>, 0,
    <14244, 13578, 14242>, 0,
    <14244, 14242, 14240>, 0,
    <14244, 14240, 14243>, 0,
    <14250, 14249, 14239>, 0,
    <14250, 14239, 14243>, 0,
    <14250, 14243, 14240>, 0,
    <14250, 14240, 14247>, 0,
    <14250, 14247, 14245>, 0,
    <14250, 14245, 14248>, 0,
    <14250, 14248, 14246>, 0,
    <14250, 14246, 14249>, 0,
    <14252, 14241, 14239>, 0,
    <14252, 14239, 14249>, 0,
    <14252, 14249, 14246>, 0,
    <14252, 14246, 14251>, 0,
    <14252, 14251, 13434>, 0,
    <14252, 13434, 13594>, 0,
    <14252, 13594, 13590>, 0,
    <14252, 13590, 14241>, 0,
    <14256, 14255, 14253>, 0,
    <14256, 14253, 14254>, 0,
    <14256, 14254, 14128>, 0,
    <14256, 14128, 14130>, 0,
    <14256, 14130, 13434>, 0,
    <14256, 13434, 14251>, 0,
    <14256, 14251, 14246>, 0,
    <14256, 14246, 14255>, 0,
    <14260, 14259, 14253>, 0,
    <14260, 14253, 14255>, 0,
    <14260, 14255, 14246>, 0,
    <14260, 14246, 14248>, 0,
    <14260, 14248, 14245>, 0,
    <14260, 14245, 14258>, 0,
    <14260, 14258, 14257>, 0,
    <14260, 14257, 14259>, 0,
    <14262, 14254, 14253>, 0,
    <14262, 14253, 14259>, 0,
    <14262, 14259, 14257>, 0,
    <14262, 14257, 14261>, 0,
    <14262, 14261, 14133>, 0,
    <14262, 14133, 14135>, 0,
    <14262, 14135, 14128>, 0,
    <14262, 14128, 14254>, 0,
    <14271, 14270, 14263>, 0,
    <14271, 14263, 14267>, 0,
    <14271, 14267, 14264>, 0,
    <14271, 14264, 14268>, 0,
    <14271, 14268, 14265>, 0,
    <14271, 14265, 14269>, 0,
    <14271, 14269, 14266>, 0,
    <14271, 14266, 14270>, 0,
    <14274, 14273, 14263>, 0,
    <14274, 14263, 14270>, 0,
    <14274, 14270, 14266>, 0,
    <14274, 14266, 14272>, 0,
    <14274, 14272, 13342>, 0,
    <14274, 13342, 14171>, 0,
    <14274, 14171, 14166>, 0,
    <14274, 14166, 14273>, 0,
    <14276, 14267, 14263>, 0,
    <14276, 14263, 14273>, 0,
    <14276, 14273, 14166>, 0,
    <14276, 14166, 14168>, 0,
    <14276, 14168, 14153>, 0,
    <14276, 14153, 14275>, 0,
    <14276, 14275, 14264>, 0,
    <14276, 14264, 14267>, 0,
    <14282, 14281, 14277>, 0,
    <14282, 14277, 14279>, 0,
    <14282, 14279, 14266>, 0,
    <14282, 14266, 14269>, 0,
    <14282, 14269, 14265>, 0,
    <14282, 14265, 14280>, 0,
    <14282, 14280, 14278>, 0,
    <14282, 14278, 14281>, 0,
    <14285, 14284, 14277>, 0,
    <14285, 14277, 14281>, 0,
    <14285, 14281, 14278>, 0,
    <14285, 14278, 14283>, 0,
    <14285, 14283, 13454>, 0,
    <14285, 13454, 13457>, 0,
    <14285, 13457, 13453>, 0,
    <14285, 13453, 14284>, 0,
    <14286, 14279, 14277>, 0,
    <14286, 14277, 14284>, 0,
    <14286, 14284, 13453>, 0,
    <14286, 13453, 13464>, 0,
    <14286, 13464, 13342>, 0,
    <14286, 13342, 14272>, 0,
    <14286, 14272, 14266>, 0,
    <14286, 14266, 14279>, 0,
    <14292, 14291, 14287>, 0,
    <14292, 14287, 14289>, 0,
    <14292, 14289, 14288>, 0,
    <14292, 14288, 14290>, 0,
    <14292, 14290, 13534>, 0,
    <14292, 13534, 13546>, 0,
    <14292, 13546, 13542>, 0,
    <14292, 13542, 14291>, 0,
    <14296, 14295, 14287>, 0,
    <14296, 14287, 14291>, 0,
    <14296, 14291, 13542>, 0,
    <14296, 13542, 13543>, 0,
    <14296, 13543, 13486>, 0,
    <14296, 13486, 14294>, 0,
    <14296, 14294, 14293>, 0,
    <14296, 14293, 14295>, 0,
    <14300, 14289, 14287>, 0,
    <14300, 14287, 14295>, 0,
    <14300, 14295, 14293>, 0,
    <14300, 14293, 14298>, 0,
    <14300, 14298, 14297>, 0,
    <14300, 14297, 14299>, 0,
    <14300, 14299, 14288>, 0,
    <14300, 14288, 14289>, 0,
    <14304, 14303, 14301>, 0,
    <14304, 14301, 14302>, 0,
    <14304, 14302, 14293>, 0,
    <14304, 14293, 14294>, 0,
    <14304, 14294, 13486>, 0,
    <14304, 13486, 14191>, 0,
    <14304, 14191, 14189>, 0,
    <14304, 14189, 14303>, 0,
    <14308, 14307, 14301>, 0,
    <14308, 14301, 14303>, 0,
    <14308, 14303, 14189>, 0,
    <14308, 14189, 14200>, 0,
    <14308, 14200, 14198>, 0,
    <14308, 14198, 14306>, 0,
    <14308, 14306, 14305>, 0,
    <14308, 14305, 14307>, 0,
    <14310, 14302, 14301>, 0,
    <14310, 14301, 14307>, 0,
    <14310, 14307, 14305>, 0,
    <14310, 14305, 14309>, 0,
    <14310, 14309, 14297>, 0,
    <14310, 14297, 14298>, 0,
    <14310, 14298, 14293>, 0,
    <14310, 14293, 14302>, 0,
    <14319, 14318, 14311>, 0,
    <14319, 14311, 14315>, 0,
    <14319, 14315, 14312>, 0,
    <14319, 14312, 14316>, 0,
    <14319, 14316, 14313>, 0,
    <14319, 14313, 14317>, 0,
    <14319, 14317, 14314>, 0,
    <14319, 14314, 14318>, 0,
    <14322, 14321, 14311>, 0,
    <14322, 14311, 14318>, 0,
    <14322, 14318, 14314>, 0,
    <14322, 14314, 14320>, 0,
    <14322, 14320, 14214>, 0,
    <14322, 14214, 14232>, 0,
    <14322, 14232, 14230>, 0,
    <14322, 14230, 14321>, 0,
    <14324, 14315, 14311>, 0,
    <14324, 14311, 14321>, 0,
    <14324, 14321, 14230>, 0,
    <14324, 14230, 14237>, 0,
    <14324, 14237, 13403>, 0,
    <14324, 13403, 14323>, 0,
    <14324, 14323, 14312>, 0,
    <14324, 14312, 14315>, 0,
    <14330, 14329, 14325>, 0,
    <14330, 14325, 14327>, 0,
    <14330, 14327, 14326>, 0,
    <14330, 14326, 14328>, 0,
    <14330, 14328, 14313>, 0,
    <14330, 14313, 14316>, 0,
    <14330, 14316, 14312>, 0,
    <14330, 14312, 14329>, 0,
    <14332, 14331, 14325>, 0,
    <14332, 14325, 14329>, 0,
    <14332, 14329, 14312>, 0,
    <14332, 14312, 14323>, 0,
    <14332, 14323, 13403>, 0,
    <14332, 13403, 13509>, 0,
    <14332, 13509, 13503>, 0,
    <14332, 13503, 14331>, 0,
    <14334, 14327, 14325>, 0,
    <14334, 14325, 14331>, 0,
    <14334, 14331, 13503>, 0,
    <14334, 13503, 13506>, 0,
    <14334, 13506, 13502>, 0,
    <14334, 13502, 14333>, 0,
    <14334, 14333, 14326>, 0,
    <14334, 14326, 14327>, 0,
    <14340, 14339, 14335>, 0,
    <14340, 14335, 14337>, 0,
    <14340, 14337, 14336>, 0,
    <14340, 14336, 14338>, 0,
    <14340, 14338, 13630>, 0,
    <14340, 13630, 13642>, 0,
    <14340, 13642, 13638>, 0,
    <14340, 13638, 14339>, 0,
    <14344, 14343, 14335>, 0,
    <14344, 14335, 14339>, 0,
    <14344, 14339, 13638>, 0,
    <14344, 13638, 13639>, 0,
    <14344, 13639, 13534>, 0,
    <14344, 13534, 14342>, 0,
    <14344, 14342, 14341>, 0,
    <14344, 14341, 14343>, 0,
    <14348, 14337, 14335>, 0,
    <14348, 14335, 14343>, 0,
    <14348, 14343, 14341>, 0,
    <14348, 14341, 14346>, 0,
    <14348, 14346, 14345>, 0,
    <14348, 14345, 14347>, 0,
    <14348, 14347, 14336>, 0,
    <14348, 14336, 14337>, 0,
    <14352, 14351, 14349>, 0,
    <14352, 14349, 14350>, 0,
    <14352, 14350, 14341>, 0,
    <14352, 14341, 14342>, 0,
    <14352, 14342, 13534>, 0,
    <14352, 13534, 14290>, 0,
    <14352, 14290, 14288>, 0,
    <14352, 14288, 14351>, 0,
    <14356, 14355, 14349>, 0,
    <14356, 14349, 14351>, 0,
    <14356, 14351, 14288>, 0,
    <14356, 14288, 14299>, 0,
    <14356, 14299, 14297>, 0,
    <14356, 14297, 14354>, 0,
    <14356, 14354, 14353>, 0,
    <14356, 14353, 14355>, 0,
    <14358, 14350, 14349>, 0,
    <14358, 14349, 14355>, 0,
    <14358, 14355, 14353>, 0,
    <14358, 14353, 14357>, 0,
    <14358, 14357, 14345>, 0,
    <14358, 14345, 14346>, 0,
    <14358, 14346, 14341>, 0,
    <14358, 14341, 14350>, 0,
    <14367, 14366, 14359>, 0,
    <14367, 14359, 14363>, 0,
    <14367, 14363, 14360>, 0,
    <14367, 14360, 14364>, 0,
    <14367, 14364, 14361>, 0,
    <14367, 14361, 14365>, 0,
    <14367, 14365, 14362>, 0,
    <14367, 14362, 14366>, 0,
    <14370, 14369, 14359>, 0,
    <14370, 14359, 14366>, 0,
    <14370, 14366, 14362>, 0,
    <14370, 14362, 14368>, 0,
    <14370, 14368, 14313>, 0,
    <14370, 14313, 14328>, 0,
    <14370, 14328, 14326>, 0,
    <14370, 14326, 14369>, 0,
    <14372, 14363, 14359>, 0,
    <14372, 14359, 14369>, 0,
    <14372, 14369, 14326>, 0,
    <14372, 14326, 14333>, 0,
    <14372, 14333, 13502>, 0,
    <14372, 13502, 14371>, 0,
    <14372, 14371, 14360>, 0,
    <14372, 14360, 14363>, 0,
    <14378, 14377, 14373>, 0,
    <14378, 14373, 14375>, 0,
    <14378, 14375, 14374>, 0,
    <14378, 14374, 14376>, 0,
    <14378, 14376, 14361>, 0,
    <14378, 14361, 14364>, 0,
    <14378, 14364, 14360>, 0,
    <14378, 14360, 14377>, 0,
    <14380, 14379, 14373>, 0,
    <14380, 14373, 14377>, 0,
    <14380, 14377, 14360>, 0,
    <14380, 14360, 14371>, 0,
    <14380, 14371, 13502>, 0,
    <14380, 13502, 13557>, 0,
    <14380, 13557, 13551>, 0,
    <14380, 13551, 14379>, 0,
    <14382, 14375, 14373>, 0,
    <14382, 14373, 14379>, 0,
    <14382, 14379, 13551>, 0,
    <14382, 13551, 13554>, 0,
    <14382, 13554, 13550>, 0,
    <14382, 13550, 14381>, 0,
    <14382, 14381, 14374>, 0,
    <14382, 14374, 14375>, 0,
    <14388, 14387, 14383>, 0,
    <14388, 14383, 14385>, 0,
    <14388, 14385, 13686>, 0,
    <14388, 13686, 13687>, 0,
    <14388, 13687, 13674>, 0,
    <14388, 13674, 14386>, 0,
    <14388, 14386, 14384>, 0,
    <14388, 14384, 14387>, 0,
    <14394, 14393, 14383>, 0,
    <14394, 14383, 14387>, 0,
    <14394, 14387, 14384>, 0,
    <14394, 14384, 14391>, 0,
    <14394, 14391, 14389>, 0,
    <14394, 14389, 14392>, 0,
    <14394, 14392, 14390>, 0,
    <14394, 14390, 14393>, 0,
    <14396, 14385, 14383>, 0,
    <14396, 14383, 14393>, 0,
    <14396, 14393, 14390>, 0,
    <14396, 14390, 14395>, 0,
    <14396, 14395, 13578>, 0,
    <14396, 13578, 13690>, 0,
    <14396, 13690, 13686>, 0,
    <14396, 13686, 14385>, 0,
    <14400, 14399, 14397>, 0,
    <14400, 14397, 14398>, 0,
    <14400, 14398, 14240>, 0,
    <14400, 14240, 14242>, 0,
    <14400, 14242, 13578>, 0,
    <14400, 13578, 14395>, 0,
    <14400, 14395, 14390>, 0,
    <14400, 14390, 14399>, 0,
    <14404, 14403, 14397>, 0,
    <14404, 14397, 14399>, 0,
    <14404, 14399, 14390>, 0,
    <14404, 14390, 14392>, 0,
    <14404, 14392, 14389>, 0,
    <14404, 14389, 14402>, 0,
    <14404, 14402, 14401>, 0,
    <14404, 14401, 14403>, 0,
    <14406, 14398, 14397>, 0,
    <14406, 14397, 14403>, 0,
    <14406, 14403, 14401>, 0,
    <14406, 14401, 14405>, 0,
    <14406, 14405, 14245>, 0,
    <14406, 14245, 14247>, 0,
    <14406, 14247, 14240>, 0,
    <14406, 14240, 14398>, 0,
    <14415, 14414, 14407>, 0,
    <14415, 14407, 14411>, 0,
    <14415, 14411, 14408>, 0,
    <14415, 14408, 14412>, 0,
    <14415, 14412, 14409>, 0,
    <14415, 14409, 14413>, 0,
    <14415, 14413, 14410>, 0,
    <14415, 14410, 14414>, 0,
    <14418, 14417, 14407>, 0,
    <14418, 14407, 14414>, 0,
    <14418, 14414, 14410>, 0,
    <14418, 14410, 14416>, 0,
    <14418, 14416, 13454>, 0,
    <14418, 13454, 14283>, 0,
    <14418, 14283, 14278>, 0,
    <14418, 14278, 14417>, 0,
    <14420, 14411, 14407>, 0,
    <14420, 14407, 14417>, 0,
    <14420, 14417, 14278>, 0,
    <14420, 14278, 14280>, 0,
    <14420, 14280, 14265>, 0,
    <14420, 14265, 14419>, 0,
    <14420, 14419, 14408>, 0,
    <14420, 14408, 14411>, 0,
    <14426, 14425, 14421>, 0,
    <14426, 14421, 14423>, 0,
    <14426, 14423, 14410>, 0,
    <14426, 14410, 14413>, 0,
    <14426, 14413, 14409>, 0,
    <14426, 14409, 14424>, 0,
    <14426, 14424, 14422>, 0,
    <14426, 14422, 14425>, 0,
    <14429, 14428, 14421>, 0,
    <14429, 14421, 14425>, 0,
    <14429, 14425, 14422>, 0,
    <14429, 14422, 14427>, 0,
    <14429, 14427, 13598>, 0,
    <14429, 13598, 13601>, 0,
    <14429, 13601, 13597>, 0,
    <14429, 13597, 14428>, 0,
    <14430, 14423, 14421>, 0,
    <14430, 14421, 14428>, 0,
    <14430, 14428, 13597>, 0,
    <14430, 13597, 13608>, 0,
    <14430, 13608, 13454>, 0,
    <14430, 13454, 14416>, 0,
    <14430, 14416, 14410>, 0,
    <14430, 14410, 14423>, 0,
    <14436, 14435, 14431>, 0,
    <14436, 14431, 14433>, 0,
    <14436, 14433, 14432>, 0,
    <14436, 14432, 14434>, 0,
    <14436, 14434, 13726>, 0,
    <14436, 13726, 13738>, 0,
    <14436, 13738, 13734>, 0,
    <14436, 13734, 14435>, 0,
    <14440, 14439, 14431>, 0,
    <14440, 14431, 14435>, 0,
    <14440, 14435, 13734>, 0,
    <14440, 13734, 13735>, 0,
    <14440, 13735, 13630>, 0,
    <14440, 13630, 14438>, 0,
    <14440, 14438, 14437>, 0,
    <14440, 14437, 14439>, 0,
    <14444, 14433, 14431>, 0,
    <14444, 14431, 14439>, 0,
    <14444, 14439, 14437>, 0,
    <14444, 14437, 14442>, 0,
    <14444, 14442, 14441>, 0,
    <14444, 14441, 14443>, 0,
    <14444, 14443, 14432>, 0,
    <14444, 14432, 14433>, 0,
    <14448, 14447, 14445>, 0,
    <14448, 14445, 14446>, 0,
    <14448, 14446, 14437>, 0,
    <14448, 14437, 14438>, 0,
    <14448, 14438, 13630>, 0,
    <14448, 13630, 14338>, 0,
    <14448, 14338, 14336>, 0,
    <14448, 14336, 14447>, 0,
    <14452, 14451, 14445>, 0,
    <14452, 14445, 14447>, 0,
    <14452, 14447, 14336>, 0,
    <14452, 14336, 14347>, 0,
    <14452, 14347, 14345>, 0,
    <14452, 14345, 14450>, 0,
    <14452, 14450, 14449>, 0,
    <14452, 14449, 14451>, 0,
    <14454, 14446, 14445>, 0,
    <14454, 14445, 14451>, 0,
    <14454, 14451, 14449>, 0,
    <14454, 14449, 14453>, 0,
    <14454, 14453, 14441>, 0,
    <14454, 14441, 14442>, 0,
    <14454, 14442, 14437>, 0,
    <14454, 14437, 14446>, 0,
    <14463, 14462, 14455>, 0,
    <14463, 14455, 14459>, 0,
    <14463, 14459, 14456>, 0,
    <14463, 14456, 14460>, 0,
    <14463, 14460, 14457>, 0,
    <14463, 14457, 14461>, 0,
    <14463, 14461, 14458>, 0,
    <14463, 14458, 14462>, 0,
    <14466, 14465, 14455>, 0,
    <14466, 14455, 14462>, 0,
    <14466, 14462, 14458>, 0,
    <14466, 14458, 14464>, 0,
    <14466, 14464, 14361>, 0,
    <14466, 14361, 14376>, 0,
    <14466, 14376, 14374>, 0,
    <14466, 14374, 14465>, 0,
    <14468, 14459, 14455>, 0,
    <14468, 14455, 14465>, 0,
    <14468, 14465, 14374>, 0,
    <14468, 14374, 14381>, 0,
    <14468, 14381, 13550>, 0,
    <14468, 13550, 14467>, 0,
    <14468, 14467, 14456>, 0,
    <14468, 14456, 14459>, 0,
    <14474, 14473, 14469>, 0,
    <14474, 14469, 14471>, 0,
    <14474, 14471, 14470>, 0,
    <14474, 14470, 14472>, 0,
    <14474, 14472, 14457>, 0,
    <14474, 14457, 14460>, 0,
    <14474, 14460, 14456>, 0,
    <14474, 14456, 14473>, 0,
    <14476, 14475, 14469>, 0,
    <14476, 14469, 14473>, 0,
    <14476, 14473, 14456>, 0,
    <14476, 14456, 14467>, 0,
    <14476, 14467, 13550>, 0,
    <14476, 13550, 13653>, 0,
    <14476, 13653, 13647>, 0,
    <14476, 13647, 14475>, 0,
    <14478, 14471, 14469>, 0,
    <14478, 14469, 14475>, 0,
    <14478, 14475, 13647>, 0,
    <14478, 13647, 13650>, 0,
    <14478, 13650, 13646>, 0,
    <14478, 13646, 14477>, 0,
    <14478, 14477, 14470>, 0,
    <14478, 14470, 14471>, 0,
    <14484, 14483, 14479>, 0,
    <14484, 14479, 14481>, 0,
    <14484, 14481, 13795>, 0,
    <14484, 13795, 13796>, 0,
    <14484, 13796, 13770>, 0,
    <14484, 13770, 14482>, 0,
    <14484, 14482, 14480>, 0,
    <14484, 14480, 14483>, 0,
    <14490, 14489, 14479>, 0,
    <14490, 14479, 14483>, 0,
    <14490, 14483, 14480>, 0,
    <14490, 14480, 14487>, 0,
    <14490, 14487, 14485>, 0,
    <14490, 14485, 14488>, 0,
    <14490, 14488, 14486>, 0,
    <14490, 14486, 14489>, 0,
    <14492, 14481, 14479>, 0,
    <14492, 14479, 14489>, 0,
    <14492, 14489, 14486>, 0,
    <14492, 14486, 14491>, 0,
    <14492, 14491, 13674>, 0,
    <14492, 13674, 13799>, 0,
    <14492, 13799, 13795>, 0,
    <14492, 13795, 14481>, 0,
    <14496, 14495, 14493>, 0,
    <14496, 14493, 14494>, 0,
    <14496, 14494, 14384>, 0,
    <14496, 14384, 14386>, 0,
    <14496, 14386, 13674>, 0,
    <14496, 13674, 14491>, 0,
    <14496, 14491, 14486>, 0,
    <14496, 14486, 14495>, 0,
    <14500, 14499, 14493>, 0,
    <14500, 14493, 14495>, 0,
    <14500, 14495, 14486>, 0,
    <14500, 14486, 14488>, 0,
    <14500, 14488, 14485>, 0,
    <14500, 14485, 14498>, 0,
    <14500, 14498, 14497>, 0,
    <14500, 14497, 14499>, 0,
    <14502, 14494, 14493>, 0,
    <14502, 14493, 14499>, 0,
    <14502, 14499, 14497>, 0,
    <14502, 14497, 14501>, 0,
    <14502, 14501, 14389>, 0,
    <14502, 14389, 14391>, 0,
    <14502, 14391, 14384>, 0,
    <14502, 14384, 14494>, 0,
    <14511, 14510, 14503>, 0,
    <14511, 14503, 14507>, 0,
    <14511, 14507, 14504>, 0,
    <14511, 14504, 14508>, 0,
    <14511, 14508, 14505>, 0,
    <14511, 14505, 14509>, 0,
    <14511, 14509, 14506>, 0,
    <14511, 14506, 14510>, 0,
    <14514, 14513, 14503>, 0,
    <14514, 14503, 14510>, 0,
    <14514, 14510, 14506>, 0,
    <14514, 14506, 14512>, 0,
    <14514, 14512, 13598>, 0,
    <14514, 13598, 14427>, 0,
    <14514, 14427, 14422>, 0,
    <14514, 14422, 14513>, 0,
    <14516, 14507, 14503>, 0,
    <14516, 14503, 14513>, 0,
    <14516, 14513, 14422>, 0,
    <14516, 14422, 14424>, 0,
    <14516, 14424, 14409>, 0,
    <14516, 14409, 14515>, 0,
    <14516, 14515, 14504>, 0,
    <14516, 14504, 14507>, 0,
    <14522, 14521, 14517>, 0,
    <14522, 14517, 14519>, 0,
    <14522, 14519, 14506>, 0,
    <14522, 14506, 14509>, 0,
    <14522, 14509, 14505>, 0,
    <14522, 14505, 14520>, 0,
    <14522, 14520, 14518>, 0,
    <14522, 14518, 14521>, 0,
    <14525, 14524, 14517>, 0,
    <14525, 14517, 14521>, 0,
    <14525, 14521, 14518>, 0,
    <14525, 14518, 14523>, 0,
    <14525, 14523, 13694>, 0,
    <14525, 13694, 13697>, 0,
    <14525, 13697, 13693>, 0,
    <14525, 13693, 14524>, 0,
    <14526, 14519, 14517>, 0,
    <14526, 14517, 14524>, 0,
    <14526, 14524, 13693>, 0,
    <14526, 13693, 13704>, 0,
    <14526, 13704, 13598>, 0,
    <14526, 13598, 14512>, 0,
    <14526, 14512, 14506>, 0,
    <14526, 14506, 14519>, 0,
    <14532, 14531, 14527>, 0,
    <14532, 14527, 14529>, 0,
    <14532, 14529, 14528>, 0,
    <14532, 14528, 14530>, 0,
    <14532, 14530, 13835>, 0,
    <14532, 13835, 13847>, 0,
    <14532, 13847, 13843>, 0,
    <14532, 13843, 14531>, 0,
    <14536, 14535, 14527>, 0,
    <14536, 14527, 14531>, 0,
    <14536, 14531, 13843>, 0,
    <14536, 13843, 13844>, 0,
    <14536, 13844, 13726>, 0,
    <14536, 13726, 14534>, 0,
    <14536, 14534, 14533>, 0,
    <14536, 14533, 14535>, 0,
    <14540, 14529, 14527>, 0,
    <14540, 14527, 14535>, 0,
    <14540, 14535, 14533>, 0,
    <14540, 14533, 14538>, 0,
    <14540, 14538, 14537>, 0,
    <14540, 14537, 14539>, 0,
    <14540, 14539, 14528>, 0,
    <14540, 14528, 14529>, 0,
    <14544, 14543, 14541>, 0,
    <14544, 14541, 14542>, 0,
    <14544, 14542, 14533>, 0,
    <14544, 14533, 14534>, 0,
    <14544, 14534, 13726>, 0,
    <14544, 13726, 14434>, 0,
    <14544, 14434, 14432>, 0,
    <14544, 14432, 14543>, 0,
    <14548, 14547, 14541>, 0,
    <14548, 14541, 14543>, 0,
    <14548, 14543, 14432>, 0,
    <14548, 14432, 14443>, 0,
    <14548, 14443, 14441>, 0,
    <14548, 14441, 14546>, 0,
    <14548, 14546, 14545>, 0,
    <14548, 14545, 14547>, 0,
    <14550, 14542, 14541>, 0,
    <14550, 14541, 14547>, 0,
    <14550, 14547, 14545>, 0,
    <14550, 14545, 14549>, 0,
    <14550, 14549, 14537>, 0,
    <14550, 14537, 14538>, 0,
    <14550, 14538, 14533>, 0,
    <14550, 14533, 14542>, 0,
    <14559, 14558, 14551>, 0,
    <14559, 14551, 14555>, 0,
    <14559, 14555, 14552>, 0,
    <14559, 14552, 14556>, 0,
    <14559, 14556, 14553>, 0,
    <14559, 14553, 14557>, 0,
    <14559, 14557, 14554>, 0,
    <14559, 14554, 14558>, 0,
    <14562, 14561, 14551>, 0,
    <14562, 14551, 14558>, 0,
    <14562, 14558, 14554>, 0,
    <14562, 14554, 14560>, 0,
    <14562, 14560, 14457>, 0,
    <14562, 14457, 14472>, 0,
    <14562, 14472, 14470>, 0,
    <14562, 14470, 14561>, 0,
    <14564, 14555, 14551>, 0,
    <14564, 14551, 14561>, 0,
    <14564, 14561, 14470>, 0,
    <14564, 14470, 14477>, 0,
    <14564, 14477, 13646>, 0,
    <14564, 13646, 14563>, 0,
    <14564, 14563, 14552>, 0,
    <14564, 14552, 14555>, 0,
    <14570, 14569, 14565>, 0,
    <14570, 14565, 14567>, 0,
    <14570, 14567, 14566>, 0,
    <14570, 14566, 14568>, 0,
    <14570, 14568, 14553>, 0,
    <14570, 14553, 14556>, 0,
    <14570, 14556, 14552>, 0,
    <14570, 14552, 14569>, 0,
    <14572, 14571, 14565>, 0,
    <14572, 14565, 14569>, 0,
    <14572, 14569, 14552>, 0,
    <14572, 14552, 14563>, 0,
    <14572, 14563, 13646>, 0,
    <14572, 13646, 13749>, 0,
    <14572, 13749, 13743>, 0,
    <14572, 13743, 14571>, 0,
    <14574, 14567, 14565>, 0,
    <14574, 14565, 14571>, 0,
    <14574, 14571, 13743>, 0,
    <14574, 13743, 13746>, 0,
    <14574, 13746, 13742>, 0,
    <14574, 13742, 14573>, 0,
    <14574, 14573, 14566>, 0,
    <14574, 14566, 14567>, 0,
    <14582, 14581, 14575>, 0,
    <14582, 14575, 14578>, 0,
    <14582, 14578, 14576>, 0,
    <14582, 14576, 14579>, 0,
    <14582, 14579, 2811>, 0,
    <14582, 2811, 14580>, 0,
    <14582, 14580, 14577>, 0,
    <14582, 14577, 14581>, 0,
    <14587, 14586, 14575>, 0,
    <14587, 14575, 14581>, 0,
    <14587, 14581, 14577>, 0,
    <14587, 14577, 14584>, 0,
    <14587, 14584, 3081>, 0,
    <14587, 3081, 14585>, 0,
    <14587, 14585, 14583>, 0,
    <14587, 14583, 14586>, 0,
    <14591, 14578, 14575>, 0,
    <14591, 14575, 14586>, 0,
    <14591, 14586, 14583>, 0,
    <14591, 14583, 14589>, 0,
    <14591, 14589, 14588>, 0,
    <14591, 14588, 14590>, 0,
    <14591, 14590, 14576>, 0,
    <14591, 14576, 14578>, 0,
    <14595, 14594, 14592>, 0,
    <14595, 14592, 14593>, 0,
    <14595, 14593, 13879>, 0,
    <14595, 13879, 13881>, 0,
    <14595, 13881, 2811>, 0,
    <14595, 2811, 14579>, 0,
    <14595, 14579, 14576>, 0,
    <14595, 14576, 14594>, 0,
    <14599, 14598, 14592>, 0,
    <14599, 14592, 14594>, 0,
    <14599, 14594, 14576>, 0,
    <14599, 14576, 14590>, 0,
    <14599, 14590, 14588>, 0,
    <14599, 14588, 14597>, 0,
    <14599, 14597, 14596>, 0,
    <14599, 14596, 14598>, 0,
    <14601, 14593, 14592>, 0,
    <14601, 14592, 14598>, 0,
    <14601, 14598, 14596>, 0,
    <14601, 14596, 14600>, 0,
    <14601, 14600, 13770>, 0,
    <14601, 13770, 13884>, 0,
    <14601, 13884, 13879>, 0,
    <14601, 13879, 14593>, 0,
    <14605, 14604, 14602>, 0,
    <14605, 14602, 14603>, 0,
    <14605, 14603, 14480>, 0,
    <14605, 14480, 14482>, 0,
    <14605, 14482, 13770>, 0,
    <14605, 13770, 14600>, 0,
    <14605, 14600, 14596>, 0,
    <14605, 14596, 14604>, 0,
    <14609, 14608, 14602>, 0,
    <14609, 14602, 14604>, 0,
    <14609, 14604, 14596>, 0,
    <14609, 14596, 14597>, 0,
    <14609, 14597, 14588>, 0,
    <14609, 14588, 14607>, 0,
    <14609, 14607, 14606>, 0,
    <14609, 14606, 14608>, 0,
    <14611, 14603, 14602>, 0,
    <14611, 14602, 14608>, 0,
    <14611, 14608, 14606>, 0,
    <14611, 14606, 14610>, 0,
    <14611, 14610, 14485>, 0,
    <14611, 14485, 14487>, 0,
    <14611, 14487, 14480>, 0,
    <14611, 14480, 14603>, 0,
    <14620, 14619, 14612>, 0,
    <14620, 14612, 14616>, 0,
    <14620, 14616, 14613>, 0,
    <14620, 14613, 14617>, 0,
    <14620, 14617, 14614>, 0,
    <14620, 14614, 14618>, 0,
    <14620, 14618, 14615>, 0,
    <14620, 14615, 14619>, 0,
    <14623, 14622, 14612>, 0,
    <14623, 14612, 14619>, 0,
    <14623, 14619, 14615>, 0,
    <14623, 14615, 14621>, 0,
    <14623, 14621, 13694>, 0,
    <14623, 13694, 14523>, 0,
    <14623, 14523, 14518>, 0,
    <14623, 14518, 14622>, 0,
    <14625, 14616, 14612>, 0,
    <14625, 14612, 14622>, 0,
    <14625, 14622, 14518>, 0,
    <14625, 14518, 14520>, 0,
    <14625, 14520, 14505>, 0,
    <14625, 14505, 14624>, 0,
    <14625, 14624, 14613>, 0,
    <14625, 14613, 14616>, 0,
    <14631, 14630, 14626>, 0,
    <14631, 14626, 14628>, 0,
    <14631, 14628, 14615>, 0,
    <14631, 14615, 14618>, 0,
    <14631, 14618, 14614>, 0,
    <14631, 14614, 14629>, 0,
    <14631, 14629, 14627>, 0,
    <14631, 14627, 14630>, 0,
    <14634, 14633, 14626>, 0,
    <14634, 14626, 14630>, 0,
    <14634, 14630, 14627>, 0,
    <14634, 14627, 14632>, 0,
    <14634, 14632, 13803>, 0,
    <14634, 13803, 13806>, 0,
    <14634, 13806, 13802>, 0,
    <14634, 13802, 14633>, 0,
    <14635, 14628, 14626>, 0,
    <14635, 14626, 14633>, 0,
    <14635, 14633, 13802>, 0,
    <14635, 13802, 13813>, 0,
    <14635, 13813, 13694>, 0,
    <14635, 13694, 14621>, 0,
    <14635, 14621, 14615>, 0,
    <14635, 14615, 14628>, 0,
    <14641, 14640, 14636>, 0,
    <14641, 14636, 14638>, 0,
    <14641, 14638, 14637>, 0,
    <14641, 14637, 14639>, 0,
    <14641, 14639, 13923>, 0,
    <14641, 13923, 13945>, 0,
    <14641, 13945, 13941>, 0,
    <14641, 13941, 14640>, 0,
    <14645, 14644, 14636>, 0,
    <14645, 14636, 14640>, 0,
    <14645, 14640, 13941>, 0,
    <14645, 13941, 13942>, 0,
    <14645, 13942, 13835>, 0,
    <14645, 13835, 14643>, 0,
    <14645, 14643, 14642>, 0,
    <14645, 14642, 14644>, 0,
    <14649, 14638, 14636>, 0,
    <14649, 14636, 14644>, 0,
    <14649, 14644, 14642>, 0,
    <14649, 14642, 14647>, 0,
    <14649, 14647, 14646>, 0,
    <14649, 14646, 14648>, 0,
    <14649, 14648, 14637>, 0,
    <14649, 14637, 14638>, 0,
    <14653, 14652, 14650>, 0,
    <14653, 14650, 14651>, 0,
    <14653, 14651, 14642>, 0,
    <14653, 14642, 14643>, 0,
    <14653, 14643, 13835>, 0,
    <14653, 13835, 14530>, 0,
    <14653, 14530, 14528>, 0,
    <14653, 14528, 14652>, 0,
    <14657, 14656, 14650>, 0,
    <14657, 14650, 14652>, 0,
    <14657, 14652, 14528>, 0,
    <14657, 14528, 14539>, 0,
    <14657, 14539, 14537>, 0,
    <14657, 14537, 14655>, 0,
    <14657, 14655, 14654>, 0,
    <14657, 14654, 14656>, 0,
    <14659, 14651, 14650>, 0,
    <14659, 14650, 14656>, 0,
    <14659, 14656, 14654>, 0,
    <14659, 14654, 14658>, 0,
    <14659, 14658, 14646>, 0,
    <14659, 14646, 14647>, 0,
    <14659, 14647, 14642>, 0,
    <14659, 14642, 14651>, 0,
    <14668, 14667, 14660>, 0,
    <14668, 14660, 14664>, 0,
    <14668, 14664, 14661>, 0,
    <14668, 14661, 14665>, 0,
    <14668, 14665, 14662>, 0,
    <14668, 14662, 14666>, 0,
    <14668, 14666, 14663>, 0,
    <14668, 14663, 14667>, 0,
    <14671, 14670, 14660>, 0,
    <14671, 14660, 14667>, 0,
    <14671, 14667, 14663>, 0,
    <14671, 14663, 14669>, 0,
    <14671, 14669, 14553>, 0,
    <14671, 14553, 14568>, 0,
    <14671, 14568, 14566>, 0,
    <14671, 14566, 14670>, 0,
    <14673, 14664, 14660>, 0,
    <14673, 14660, 14670>, 0,
    <14673, 14670, 14566>, 0,
    <14673, 14566, 14573>, 0,
    <14673, 14573, 13742>, 0,
    <14673, 13742, 14672>, 0,
    <14673, 14672, 14661>, 0,
    <14673, 14661, 14664>, 0,
    <14679, 14678, 14674>, 0,
    <14679, 14674, 14676>, 0,
    <14679, 14676, 14675>, 0,
    <14679, 14675, 14677>, 0,
    <14679, 14677, 14662>, 0,
    <14679, 14662, 14665>, 0,
    <14679, 14665, 14661>, 0,
    <14679, 14661, 14678>, 0,
    <14681, 14680, 14674>, 0,
    <14681, 14674, 14678>, 0,
    <14681, 14678, 14661>, 0,
    <14681, 14661, 14672>, 0,
    <14681, 14672, 13742>, 0,
    <14681, 13742, 13858>, 0,
    <14681, 13858, 13852>, 0,
    <14681, 13852, 14680>, 0,
    <14683, 14676, 14674>, 0,
    <14683, 14674, 14680>, 0,
    <14683, 14680, 13852>, 0,
    <14683, 13852, 13855>, 0,
    <14683, 13855, 13851>, 0,
    <14683, 13851, 14682>, 0,
    <14683, 14682, 14675>, 0,
    <14683, 14675, 14676>, 0,
    <14689, 14688, 14684>, 0,
    <14689, 14684, 14686>, 0,
    <14689, 14686, 14583>, 0,
    <14689, 14583, 14585>, 0,
    <14689, 14585, 3081>, 0,
    <14689, 3081, 14687>, 0,
    <14689, 14687, 14685>, 0,
    <14689, 14685, 14688>, 0,
    <14694, 14693, 14684>, 0,
    <14694, 14684, 14688>, 0,
    <14694, 14688, 14685>, 0,
    <14694, 14685, 14691>, 0,
    <14694, 14691, 3069>, 0,
    <14694, 3069, 14692>, 0,
    <14694, 14692, 14690>, 0,
    <14694, 14690, 14693>, 0,
    <14696, 14686, 14684>, 0,
    <14696, 14684, 14693>, 0,
    <14696, 14693, 14690>, 0,
    <14696, 14690, 14695>, 0,
    <14696, 14695, 14588>, 0,
    <14696, 14588, 14589>, 0,
    <14696, 14589, 14583>, 0,
    <14696, 14583, 14686>, 0,
    <14704, 14703, 14697>, 0,
    <14704, 14697, 14700>, 0,
    <14704, 14700, 14698>, 0,
    <14704, 14698, 14701>, 0,
    <14704, 14701, 3134>, 0,
    <14704, 3134, 14702>, 0,
    <14704, 14702, 14699>, 0,
    <14704, 14699, 14703>, 0,
    <14707, 14706, 14697>, 0,
    <14707, 14697, 14703>, 0,
    <14707, 14703, 14699>, 0,
    <14707, 14699, 14705>, 0,
    <14707, 14705, 13803>, 0,
    <14707, 13803, 14632>, 0,
    <14707, 14632, 14627>, 0,
    <14707, 14627, 14706>, 0,
    <14709, 14700, 14697>, 0,
    <14709, 14697, 14706>, 0,
    <14709, 14706, 14627>, 0,
    <14709, 14627, 14629>, 0,
    <14709, 14629, 14614>, 0,
    <14709, 14614, 14708>, 0,
    <14709, 14708, 14698>, 0,
    <14709, 14698, 14700>, 0,
    <14715, 14714, 14710>, 0,
    <14715, 14710, 14712>, 0,
    <14715, 14712, 14699>, 0,
    <14715, 14699, 14702>, 0,
    <14715, 14702, 3134>, 0,
    <14715, 3134, 14713>, 0,
    <14715, 14713, 14711>, 0,
    <14715, 14711, 14714>, 0,
    <14718, 14717, 14710>, 0,
    <14718, 14710, 14714>, 0,
    <14718, 14714, 14711>, 0,
    <14718, 14711, 14716>, 0,
    <14718, 14716, 14037>, 0,
    <14718, 14037, 14040>, 0,
    <14718, 14040, 14036>, 0,
    <14718, 14036, 14717>, 0,
    <14719, 14712, 14710>, 0,
    <14719, 14710, 14717>, 0,
    <14719, 14717, 14036>, 0,
    <14719, 14036, 14047>, 0,
    <14719, 14047, 13803>, 0,
    <14719, 13803, 14705>, 0,
    <14719, 14705, 14699>, 0,
    <14719, 14699, 14712>, 0,
    <14728, 14727, 14720>, 0,
    <14728, 14720, 14724>, 0,
    <14728, 14724, 14721>, 0,
    <14728, 14721, 14725>, 0,
    <14728, 14725, 14722>, 0,
    <14728, 14722, 14726>, 0,
    <14728, 14726, 14723>, 0,
    <14728, 14723, 14727>, 0,
    <14733, 14732, 14720>, 0,
    <14733, 14720, 14727>, 0,
    <14733, 14727, 14723>, 0,
    <14733, 14723, 14730>, 0,
    <14733, 14730, 14023>, 0,
    <14733, 14023, 14731>, 0,
    <14733, 14731, 14729>, 0,
    <14733, 14729, 14732>, 0,
    <14737, 14724, 14720>, 0,
    <14737, 14720, 14732>, 0,
    <14737, 14732, 14729>, 0,
    <14737, 14729, 14735>, 0,
    <14737, 14735, 14734>, 0,
    <14737, 14734, 14736>, 0,
    <14737, 14736, 14721>, 0,
    <14737, 14721, 14724>, 0,
    <14741, 14740, 14738>, 0,
    <14741, 14738, 14739>, 0,
    <14741, 14739, 14729>, 0,
    <14741, 14729, 14731>, 0,
    <14741, 14731, 14023>, 0,
    <14741, 14023, 14026>, 0,
    <14741, 14026, 14022>, 0,
    <14741, 14022, 14740>, 0,
    <14745, 14744, 14738>, 0,
    <14745, 14738, 14740>, 0,
    <14745, 14740, 14022>, 0,
    <14745, 14022, 14033>, 0,
    <14745, 14033, 13923>, 0,
    <14745, 13923, 14743>, 0,
    <14745, 14743, 14742>, 0,
    <14745, 14742, 14744>, 0,
    <14747, 14739, 14738>, 0,
    <14747, 14738, 14744>, 0,
    <14747, 14744, 14742>, 0,
    <14747, 14742, 14746>, 0,
    <14747, 14746, 14734>, 0,
    <14747, 14734, 14735>, 0,
    <14747, 14735, 14729>, 0,
    <14747, 14729, 14739>, 0,
    <14751, 14750, 14748>, 0,
    <14751, 14748, 14749>, 0,
    <14751, 14749, 14742>, 0,
    <14751, 14742, 14743>, 0,
    <14751, 14743, 13923>, 0,
    <14751, 13923, 14639>, 0,
    <14751, 14639, 14637>, 0,
    <14751, 14637, 14750>, 0,
    <14755, 14754, 14748>, 0,
    <14755, 14748, 14750>, 0,
    <14755, 14750, 14637>, 0,
    <14755, 14637, 14648>, 0,
    <14755, 14648, 14646>, 0,
    <14755, 14646, 14753>, 0,
    <14755, 14753, 14752>, 0,
    <14755, 14752, 14754>, 0,
    <14757, 14749, 14748>, 0,
    <14757, 14748, 14754>, 0,
    <14757, 14754, 14752>, 0,
    <14757, 14752, 14756>, 0,
    <14757, 14756, 14734>, 0,
    <14757, 14734, 14746>, 0,
    <14757, 14746, 14742>, 0,
    <14757, 14742, 14749>, 0,
    <14765, 14764, 14758>, 0,
    <14765, 14758, 14761>, 0,
    <14765, 14761, 14759>, 0,
    <14765, 14759, 14762>, 0,
    <14765, 14762, 14051>, 0,
    <14765, 14051, 14763>, 0,
    <14765, 14763, 14760>, 0,
    <14765, 14760, 14764>, 0,
    <14771, 14770, 14758>, 0,
    <14771, 14758, 14764>, 0,
    <14771, 14764, 14760>, 0,
    <14771, 14760, 14768>, 0,
    <14771, 14768, 14766>, 0,
    <14771, 14766, 14769>, 0,
    <14771, 14769, 14767>, 0,
    <14771, 14767, 14770>, 0,
    <14775, 14761, 14758>, 0,
    <14775, 14758, 14770>, 0,
    <14775, 14770, 14767>, 0,
    <14775, 14767, 14773>, 0,
    <14775, 14773, 14772>, 0,
    <14775, 14772, 14774>, 0,
    <14775, 14774, 14759>, 0,
    <14775, 14759, 14761>, 0,
    <14783, 14782, 14776>, 0,
    <14783, 14776, 14779>, 0,
    <14783, 14779, 14777>, 0,
    <14783, 14777, 14780>, 0,
    <14783, 14780, 14772>, 0,
    <14783, 14772, 14781>, 0,
    <14783, 14781, 14778>, 0,
    <14783, 14778, 14782>, 0,
    <14786, 14785, 14776>, 0,
    <14786, 14776, 14782>, 0,
    <14786, 14782, 14778>, 0,
    <14786, 14778, 14784>, 0,
    <14786, 14784, 14662>, 0,
    <14786, 14662, 14677>, 0,
    <14786, 14677, 14675>, 0,
    <14786, 14675, 14785>, 0,
    <14788, 14779, 14776>, 0,
    <14788, 14776, 14785>, 0,
    <14788, 14785, 14675>, 0,
    <14788, 14675, 14682>, 0,
    <14788, 14682, 13851>, 0,
    <14788, 13851, 14787>, 0,
    <14788, 14787, 14777>, 0,
    <14788, 14777, 14779>, 0,
    <14792, 14791, 14789>, 0,
    <14792, 14789, 14790>, 0,
    <14792, 14790, 14052>, 0,
    <14792, 14052, 14055>, 0,
    <14792, 14055, 14051>, 0,
    <14792, 14051, 14762>, 0,
    <14792, 14762, 14759>, 0,
    <14792, 14759, 14791>, 0,
    <14796, 14795, 14789>, 0,
    <14796, 14789, 14791>, 0,
    <14796, 14791, 14759>, 0,
    <14796, 14759, 14774>, 0,
    <14796, 14774, 14772>, 0,
    <14796, 14772, 14794>, 0,
    <14796, 14794, 14793>, 0,
    <14796, 14793, 14795>, 0,
    <14798, 14790, 14789>, 0,
    <14798, 14789, 14795>, 0,
    <14798, 14795, 14793>, 0,
    <14798, 14793, 14797>, 0,
    <14798, 14797, 13961>, 0,
    <14798, 13961, 14058>, 0,
    <14798, 14058, 14052>, 0,
    <14798, 14052, 14790>, 0,
    <14802, 14801, 14799>, 0,
    <14802, 14799, 14800>, 0,
    <14802, 14800, 14793>, 0,
    <14802, 14793, 14794>, 0,
    <14802, 14794, 14772>, 0,
    <14802, 14772, 14780>, 0,
    <14802, 14780, 14777>, 0,
    <14802, 14777, 14801>, 0,
    <14804, 14803, 14799>, 0,
    <14804, 14799, 14801>, 0,
    <14804, 14801, 14777>, 0,
    <14804, 14777, 14787>, 0,
    <14804, 14787, 13851>, 0,
    <14804, 13851, 13973>, 0,
    <14804, 13973, 13967>, 0,
    <14804, 13967, 14803>, 0,
    <14805, 14800, 14799>, 0,
    <14805, 14799, 14803>, 0,
    <14805, 14803, 13967>, 0,
    <14805, 13967, 13970>, 0,
    <14805, 13970, 13961>, 0,
    <14805, 13961, 14797>, 0,
    <14805, 14797, 14793>, 0,
    <14805, 14793, 14800>, 0,
    <14811, 14810, 14806>, 0,
    <14811, 14806, 14808>, 0,
    <14811, 14808, 14807>, 0,
    <14811, 14807, 14809>, 0,
    <14811, 14809, 14722>, 0,
    <14811, 14722, 14725>, 0,
    <14811, 14725, 14721>, 0,
    <14811, 14721, 14810>, 0,
    <14815, 14814, 14806>, 0,
    <14815, 14806, 14810>, 0,
    <14815, 14810, 14721>, 0,
    <14815, 14721, 14736>, 0,
    <14815, 14736, 14734>, 0,
    <14815, 14734, 14813>, 0,
    <14815, 14813, 14812>, 0,
    <14815, 14812, 14814>, 0,
    <14818, 14808, 14806>, 0,
    <14818, 14806, 14814>, 0,
    <14818, 14814, 14812>, 0,
    <14818, 14812, 14816>, 0,
    <14818, 14816, 3114>, 0,
    <14818, 3114, 14817>, 0,
    <14818, 14817, 14807>, 0,
    <14818, 14807, 14808>, 0,
    <14824, 14823, 14819>, 0,
    <14824, 14819, 14821>, 0,
    <14824, 14821, 14767>, 0,
    <14824, 14767, 14769>, 0,
    <14824, 14769, 14766>, 0,
    <14824, 14766, 14822>, 0,
    <14824, 14822, 14820>, 0,
    <14824, 14820, 14823>, 0,
    <14829, 14828, 14819>, 0,
    <14829, 14819, 14823>, 0,
    <14829, 14823, 14820>, 0,
    <14829, 14820, 14826>, 0,
    <14829, 14826, 3140>, 0,
    <14829, 3140, 14827>, 0,
    <14829, 14827, 14825>, 0,
    <14829, 14825, 14828>, 0,
    <14831, 14821, 14819>, 0,
    <14831, 14819, 14828>, 0,
    <14831, 14828, 14825>, 0,
    <14831, 14825, 14830>, 0,
    <14831, 14830, 14772>, 0,
    <14831, 14772, 14773>, 0,
    <14831, 14773, 14767>, 0,
    <14831, 14767, 14821>, 0,
    <14840, 14839, 14832>, 0,
    <14840, 14832, 14836>, 0,
    <14840, 14836, 14833>, 0,
    <14840, 14833, 14837>, 0,
    <14840, 14837, 14834>, 0,
    <14840, 14834, 14838>, 0,
    <14840, 14838, 14835>, 0,
    <14840, 14835, 14839>, 0,
    <14843, 14842, 14832>, 0,
    <14843, 14832, 14839>, 0,
    <14843, 14839, 14835>, 0,
    <14843, 14835, 14841>, 0,
    <14843, 14841, 3114>, 0,
    <14843, 3114, 14816>, 0,
    <14843, 14816, 14812>, 0,
    <14843, 14812, 14842>, 0,
    <14845, 14836, 14832>, 0,
    <14845, 14832, 14842>, 0,
    <14845, 14842, 14812>, 0,
    <14845, 14812, 14813>, 0,
    <14845, 14813, 14734>, 0,
    <14845, 14734, 14844>, 0,
    <14845, 14844, 14833>, 0,
    <14845, 14833, 14836>, 0,
    <14854, 14853, 14846>, 0,
    <14854, 14846, 14850>, 0,
    <14854, 14850, 14847>, 0,
    <14854, 14847, 14851>, 0,
    <14854, 14851, 14848>, 0,
    <14854, 14848, 14852>, 0,
    <14854, 14852, 14849>, 0,
    <14854, 14849, 14853>, 0,
    <14857, 14856, 14846>, 0,
    <14857, 14846, 14853>, 0,
    <14857, 14853, 14849>, 0,
    <14857, 14849, 14855>, 0,
    <14857, 14855, 3134>, 0,
    <14857, 3134, 14701>, 0,
    <14857, 14701, 14698>, 0,
    <14857, 14698, 14856>, 0,
    <14859, 14850, 14846>, 0,
    <14859, 14846, 14856>, 0,
    <14859, 14856, 14698>, 0,
    <14859, 14698, 14708>, 0,
    <14859, 14708, 14614>, 0,
    <14859, 14614, 14858>, 0,
    <14859, 14858, 14847>, 0,
    <14859, 14847, 14850>, 0,
    <14865, 14864, 14860>, 0,
    <14865, 14860, 14862>, 0,
    <14865, 14862, 14094>, 0,
    <14865, 14094, 14095>, 0,
    <14865, 14095, 14082>, 0,
    <14865, 14082, 14863>, 0,
    <14865, 14863, 14861>, 0,
    <14865, 14861, 14864>, 0,
    <14870, 14869, 14860>, 0,
    <14870, 14860, 14864>, 0,
    <14870, 14864, 14861>, 0,
    <14870, 14861, 14867>, 0,
    <14870, 14867, 3238>, 0,
    <14870, 3238, 14868>, 0,
    <14870, 14868, 14866>, 0,
    <14870, 14866, 14869>, 0,
    <14872, 14862, 14860>, 0,
    <14872, 14860, 14869>, 0,
    <14872, 14869, 14866>, 0,
    <14872, 14866, 14871>, 0,
    <14872, 14871, 3007>, 0,
    <14872, 3007, 14098>, 0,
    <14872, 14098, 14094>, 0,
    <14872, 14094, 14862>, 0,
    <14878, 14877, 14873>, 0,
    <14878, 14873, 14875>, 0,
    <14878, 14875, 14145>, 0,
    <14878, 14145, 14146>, 0,
    <14878, 14146, 14133>, 0,
    <14878, 14133, 14876>, 0,
    <14878, 14876, 14874>, 0,
    <14878, 14874, 14877>, 0,
    <14884, 14883, 14873>, 0,
    <14884, 14873, 14877>, 0,
    <14884, 14877, 14874>, 0,
    <14884, 14874, 14881>, 0,
    <14884, 14881, 14879>, 0,
    <14884, 14879, 14882>, 0,
    <14884, 14882, 14880>, 0,
    <14884, 14880, 14883>, 0,
    <14886, 14875, 14873>, 0,
    <14886, 14873, 14883>, 0,
    <14886, 14883, 14880>, 0,
    <14886, 14880, 14885>, 0,
    <14886, 14885, 14082>, 0,
    <14886, 14082, 14149>, 0,
    <14886, 14149, 14145>, 0,
    <14886, 14145, 14875>, 0,
    <14890, 14889, 14887>, 0,
    <14890, 14887, 14888>, 0,
    <14890, 14888, 14861>, 0,
    <14890, 14861, 14863>, 0,
    <14890, 14863, 14082>, 0,
    <14890, 14082, 14885>, 0,
    <14890, 14885, 14880>, 0,
    <14890, 14880, 14889>, 0,
    <14894, 14893, 14887>, 0,
    <14894, 14887, 14889>, 0,
    <14894, 14889, 14880>, 0,
    <14894, 14880, 14882>, 0,
    <14894, 14882, 14879>, 0,
    <14894, 14879, 14892>, 0,
    <14894, 14892, 14891>, 0,
    <14894, 14891, 14893>, 0,
    <14896, 14888, 14887>, 0,
    <14896, 14887, 14893>, 0,
    <14896, 14893, 14891>, 0,
    <14896, 14891, 14895>, 0,
    <14896, 14895, 3238>, 0,
    <14896, 3238, 14867>, 0,
    <14896, 14867, 14861>, 0,
    <14896, 14861, 14888>, 0,
    <14905, 14904, 14897>, 0,
    <14905, 14897, 14901>, 0,
    <14905, 14901, 14898>, 0,
    <14905, 14898, 14902>, 0,
    <14905, 14902, 14899>, 0,
    <14905, 14899, 14903>, 0,
    <14905, 14903, 14900>, 0,
    <14905, 14900, 14904>, 0,
    <14910, 14909, 14897>, 0,
    <14910, 14897, 14904>, 0,
    <14910, 14904, 14900>, 0,
    <14910, 14900, 14907>, 0,
    <14910, 14907, 3020>, 0,
    <14910, 3020, 14908>, 0,
    <14910, 14908, 14906>, 0,
    <14910, 14906, 14909>, 0,
    <14913, 14901, 14897>, 0,
    <14913, 14897, 14909>, 0,
    <14913, 14909, 14906>, 0,
    <14913, 14906, 14911>, 0,
    <14913, 14911, 3262>, 0,
    <14913, 3262, 14912>, 0,
    <14913, 14912, 14898>, 0,
    <14913, 14898, 14901>, 0,
    <14919, 14918, 14914>, 0,
    <14919, 14914, 14916>, 0,
    <14919, 14916, 14900>, 0,
    <14919, 14900, 14903>, 0,
    <14919, 14903, 14899>, 0,
    <14919, 14899, 14917>, 0,
    <14919, 14917, 14915>, 0,
    <14919, 14915, 14918>, 0,
    <14922, 14921, 14914>, 0,
    <14922, 14914, 14918>, 0,
    <14922, 14918, 14915>, 0,
    <14922, 14915, 14920>, 0,
    <14922, 14920, 14102>, 0,
    <14922, 14102, 14105>, 0,
    <14922, 14105, 14101>, 0,
    <14922, 14101, 14921>, 0,
    <14923, 14916, 14914>, 0,
    <14923, 14914, 14921>, 0,
    <14923, 14921, 14101>, 0,
    <14923, 14101, 14115>, 0,
    <14923, 14115, 3020>, 0,
    <14923, 3020, 14907>, 0,
    <14923, 14907, 14900>, 0,
    <14923, 14900, 14916>, 0,
    <14929, 14928, 14924>, 0,
    <14929, 14924, 14926>, 0,
    <14929, 14926, 14257>, 0,
    <14929, 14257, 14258>, 0,
    <14929, 14258, 14245>, 0,
    <14929, 14245, 14927>, 0,
    <14929, 14927, 14925>, 0,
    <14929, 14925, 14928>, 0,
    <14935, 14934, 14924>, 0,
    <14935, 14924, 14928>, 0,
    <14935, 14928, 14925>, 0,
    <14935, 14925, 14932>, 0,
    <14935, 14932, 14930>, 0,
    <14935, 14930, 14933>, 0,
    <14935, 14933, 14931>, 0,
    <14935, 14931, 14934>, 0,
    <14937, 14926, 14924>, 0,
    <14937, 14924, 14934>, 0,
    <14937, 14934, 14931>, 0,
    <14937, 14931, 14936>, 0,
    <14937, 14936, 14133>, 0,
    <14937, 14133, 14261>, 0,
    <14937, 14261, 14257>, 0,
    <14937, 14257, 14926>, 0,
    <14941, 14940, 14938>, 0,
    <14941, 14938, 14939>, 0,
    <14941, 14939, 14874>, 0,
    <14941, 14874, 14876>, 0,
    <14941, 14876, 14133>, 0,
    <14941, 14133, 14936>, 0,
    <14941, 14936, 14931>, 0,
    <14941, 14931, 14940>, 0,
    <14945, 14944, 14938>, 0,
    <14945, 14938, 14940>, 0,
    <14945, 14940, 14931>, 0,
    <14945, 14931, 14933>, 0,
    <14945, 14933, 14930>, 0,
    <14945, 14930, 14943>, 0,
    <14945, 14943, 14942>, 0,
    <14945, 14942, 14944>, 0,
    <14947, 14939, 14938>, 0,
    <14947, 14938, 14944>, 0,
    <14947, 14944, 14942>, 0,
    <14947, 14942, 14946>, 0,
    <14947, 14946, 14879>, 0,
    <14947, 14879, 14881>, 0,
    <14947, 14881, 14874>, 0,
    <14947, 14874, 14939>, 0,
    <14956, 14955, 14948>, 0,
    <14956, 14948, 14952>, 0,
    <14956, 14952, 14949>, 0,
    <14956, 14949, 14953>, 0,
    <14956, 14953, 14950>, 0,
    <14956, 14950, 14954>, 0,
    <14956, 14954, 14951>, 0,
    <14956, 14951, 14955>, 0,
    <14959, 14958, 14948>, 0,
    <14959, 14948, 14955>, 0,
    <14959, 14955, 14951>, 0,
    <14959, 14951, 14957>, 0,
    <14959, 14957, 14102>, 0,
    <14959, 14102, 14920>, 0,
    <14959, 14920, 14915>, 0,
    <14959, 14915, 14958>, 0,
    <14961, 14952, 14948>, 0,
    <14961, 14948, 14958>, 0,
    <14961, 14958, 14915>, 0,
    <14961, 14915, 14917>, 0,
    <14961, 14917, 14899>, 0,
    <14961, 14899, 14960>, 0,
    <14961, 14960, 14949>, 0,
    <14961, 14949, 14952>, 0,
    <14967, 14966, 14962>, 0,
    <14967, 14962, 14964>, 0,
    <14967, 14964, 14951>, 0,
    <14967, 14951, 14954>, 0,
    <14967, 14954, 14950>, 0,
    <14967, 14950, 14965>, 0,
    <14967, 14965, 14963>, 0,
    <14967, 14963, 14966>, 0,
    <14970, 14969, 14962>, 0,
    <14970, 14962, 14966>, 0,
    <14970, 14966, 14963>, 0,
    <14970, 14963, 14968>, 0,
    <14970, 14968, 14153>, 0,
    <14970, 14153, 14156>, 0,
    <14970, 14156, 14152>, 0,
    <14970, 14152, 14969>, 0,
    <14971, 14964, 14962>, 0,
    <14971, 14962, 14969>, 0,
    <14971, 14969, 14152>, 0,
    <14971, 14152, 14163>, 0,
    <14971, 14163, 14102>, 0,
    <14971, 14102, 14957>, 0,
    <14971, 14957, 14951>, 0,
    <14971, 14951, 14964>, 0,
    <14977, 14976, 14972>, 0,
    <14977, 14972, 14974>, 0,
    <14977, 14974, 14973>, 0,
    <14977, 14973, 14975>, 0,
    <14977, 14975, 14198>, 0,
    <14977, 14198, 14210>, 0,
    <14977, 14210, 14206>, 0,
    <14977, 14206, 14976>, 0,
    <14981, 14980, 14972>, 0,
    <14981, 14972, 14976>, 0,
    <14981, 14976, 14206>, 0,
    <14981, 14206, 14207>, 0,
    <14981, 14207, 3049>, 0,
    <14981, 3049, 14979>, 0,
    <14981, 14979, 14978>, 0,
    <14981, 14978, 14980>, 0,
    <14984, 14974, 14972>, 0,
    <14984, 14972, 14980>, 0,
    <14984, 14980, 14978>, 0,
    <14984, 14978, 14982>, 0,
    <14984, 14982, 3276>, 0,
    <14984, 3276, 14983>, 0,
    <14984, 14983, 14973>, 0,
    <14984, 14973, 14974>, 0,
    <14993, 14992, 14985>, 0,
    <14993, 14985, 14989>, 0,
    <14993, 14989, 14986>, 0,
    <14993, 14986, 14990>, 0,
    <14993, 14990, 14987>, 0,
    <14993, 14987, 14991>, 0,
    <14993, 14991, 14988>, 0,
    <14993, 14988, 14992>, 0,
    <14996, 14995, 14985>, 0,
    <14996, 14985, 14992>, 0,
    <14996, 14992, 14988>, 0,
    <14996, 14988, 14994>, 0,
    <14996, 14994, 14772>, 0,
    <14996, 14772, 14830>, 0,
    <14996, 14830, 14825>, 0,
    <14996, 14825, 14995>, 0,
    <14998, 14989, 14985>, 0,
    <14998, 14985, 14995>, 0,
    <14998, 14995, 14825>, 0,
    <14998, 14825, 14827>, 0,
    <14998, 14827, 3140>, 0,
    <14998, 3140, 14997>, 0,
    <14998, 14997, 14986>, 0,
    <14998, 14986, 14989>, 0,
    <15004, 15003, 14999>, 0,
    <15004, 14999, 15001>, 0,
    <15004, 15001, 15000>, 0,
    <15004, 15000, 15002>, 0,
    <15004, 15002, 14297>, 0,
    <15004, 14297, 14309>, 0,
    <15004, 14309, 14305>, 0,
    <15004, 14305, 15003>, 0,
    <15008, 15007, 14999>, 0,
    <15008, 14999, 15003>, 0,
    <15008, 15003, 14305>, 0,
    <15008, 14305, 14306>, 0,
    <15008, 14306, 14198>, 0,
    <15008, 14198, 15006>, 0,
    <15008, 15006, 15005>, 0,
    <15008, 15005, 15007>, 0,
    <15012, 15001, 14999>, 0,
    <15012, 14999, 15007>, 0,
    <15012, 15007, 15005>, 0,
    <15012, 15005, 15010>, 0,
    <15012, 15010, 15009>, 0,
    <15012, 15009, 15011>, 0,
    <15012, 15011, 15000>, 0,
    <15012, 15000, 15001>, 0,
    <15016, 15015, 15013>, 0,
    <15016, 15013, 15014>, 0,
    <15016, 15014, 15005>, 0,
    <15016, 15005, 15006>, 0,
    <15016, 15006, 14198>, 0,
    <15016, 14198, 14975>, 0,
    <15016, 14975, 14973>, 0,
    <15016, 14973, 15015>, 0,
    <15020, 15019, 15013>, 0,
    <15020, 15013, 15015>, 0,
    <15020, 15015, 14973>, 0,
    <15020, 14973, 14983>, 0,
    <15020, 14983, 3276>, 0,
    <15020, 3276, 15018>, 0,
    <15020, 15018, 15017>, 0,
    <15020, 15017, 15019>, 0,
    <15022, 15014, 15013>, 0,
    <15022, 15013, 15019>, 0,
    <15022, 15019, 15017>, 0,
    <15022, 15017, 15021>, 0,
    <15022, 15021, 15009>, 0,
    <15022, 15009, 15010>, 0,
    <15022, 15010, 15005>, 0,
    <15022, 15005, 15014>, 0,
    <15031, 15030, 15023>, 0,
    <15031, 15023, 15027>, 0,
    <15031, 15027, 15024>, 0,
    <15031, 15024, 15028>, 0,
    <15031, 15028, 15025>, 0,
    <15031, 15025, 15029>, 0,
    <15031, 15029, 15026>, 0,
    <15031, 15026, 15030>, 0,
    <15036, 15035, 15023>, 0,
    <15036, 15023, 15030>, 0,
    <15036, 15030, 15026>, 0,
    <15036, 15026, 15033>, 0,
    <15036, 15033, 3282>, 0,
    <15036, 3282, 15034>, 0,
    <15036, 15034, 15032>, 0,
    <15036, 15032, 15035>, 0,
    <15039, 15027, 15023>, 0,
    <15039, 15023, 15035>, 0,
    <15039, 15035, 15032>, 0,
    <15039, 15032, 15037>, 0,
    <15039, 15037, 3055>, 0,
    <15039, 3055, 15038>, 0,
    <15039, 15038, 15024>, 0,
    <15039, 15024, 15027>, 0,
    <15045, 15044, 15040>, 0,
    <15045, 15040, 15042>, 0,
    <15045, 15042, 15041>, 0,
    <15045, 15041, 15043>, 0,
    <15045, 15043, 15025>, 0,
    <15045, 15025, 15028>, 0,
    <15045, 15028, 15024>, 0,
    <15045, 15024, 15044>, 0,
    <15047, 15046, 15040>, 0,
    <15047, 15040, 15044>, 0,
    <15047, 15044, 15024>, 0,
    <15047, 15024, 15038>, 0,
    <15047, 15038, 3055>, 0,
    <15047, 3055, 14222>, 0,
    <15047, 14222, 14215>, 0,
    <15047, 14215, 15046>, 0,
    <15049, 15042, 15040>, 0,
    <15049, 15040, 15046>, 0,
    <15049, 15046, 14215>, 0,
    <15049, 14215, 14218>, 0,
    <15049, 14218, 14214>, 0,
    <15049, 14214, 15048>, 0,
    <15049, 15048, 15041>, 0,
    <15049, 15041, 15042>, 0,
    <15055, 15054, 15050>, 0,
    <15055, 15050, 15052>, 0,
    <15055, 15052, 14401>, 0,
    <15055, 14401, 14402>, 0,
    <15055, 14402, 14389>, 0,
    <15055, 14389, 15053>, 0,
    <15055, 15053, 15051>, 0,
    <15055, 15051, 15054>, 0,
    <15061, 15060, 15050>, 0,
    <15061, 15050, 15054>, 0,
    <15061, 15054, 15051>, 0,
    <15061, 15051, 15058>, 0,
    <15061, 15058, 15056>, 0,
    <15061, 15056, 15059>, 0,
    <15061, 15059, 15057>, 0,
    <15061, 15057, 15060>, 0,
    <15063, 15052, 15050>, 0,
    <15063, 15050, 15060>, 0,
    <15063, 15060, 15057>, 0,
    <15063, 15057, 15062>, 0,
    <15063, 15062, 14245>, 0,
    <15063, 14245, 14405>, 0,
    <15063, 14405, 14401>, 0,
    <15063, 14401, 15052>, 0,
    <15067, 15066, 15064>, 0,
    <15067, 15064, 15065>, 0,
    <15067, 15065, 14925>, 0,
    <15067, 14925, 14927>, 0,
    <15067, 14927, 14245>, 0,
    <15067, 14245, 15062>, 0,
    <15067, 15062, 15057>, 0,
    <15067, 15057, 15066>, 0,
    <15071, 15070, 15064>, 0,
    <15071, 15064, 15066>, 0,
    <15071, 15066, 15057>, 0,
    <15071, 15057, 15059>, 0,
    <15071, 15059, 15056>, 0,
    <15071, 15056, 15069>, 0,
    <15071, 15069, 15068>, 0,
    <15071, 15068, 15070>, 0,
    <15073, 15065, 15064>, 0,
    <15073, 15064, 15070>, 0,
    <15073, 15070, 15068>, 0,
    <15073, 15068, 15072>, 0,
    <15073, 15072, 14930>, 0,
    <15073, 14930, 14932>, 0,
    <15073, 14932, 14925>, 0,
    <15073, 14925, 15065>, 0,
    <15082, 15081, 15074>, 0,
    <15082, 15074, 15078>, 0,
    <15082, 15078, 15075>, 0,
    <15082, 15075, 15079>, 0,
    <15082, 15079, 15076>, 0,
    <15082, 15076, 15080>, 0,
    <15082, 15080, 15077>, 0,
    <15082, 15077, 15081>, 0,
    <15085, 15084, 15074>, 0,
    <15085, 15074, 15081>, 0,
    <15085, 15081, 15077>, 0,
    <15085, 15077, 15083>, 0,
    <15085, 15083, 14153>, 0,
    <15085, 14153, 14968>, 0,
    <15085, 14968, 14963>, 0,
    <15085, 14963, 15084>, 0,
    <15087, 15078, 15074>, 0,
    <15087, 15074, 15084>, 0,
    <15087, 15084, 14963>, 0,
    <15087, 14963, 14965>, 0,
    <15087, 14965, 14950>, 0,
    <15087, 14950, 15086>, 0,
    <15087, 15086, 15075>, 0,
    <15087, 15075, 15078>, 0,
    <15093, 15092, 15088>, 0,
    <15093, 15088, 15090>, 0,
    <15093, 15090, 15077>, 0,
    <15093, 15077, 15080>, 0,
    <15093, 15080, 15076>, 0,
    <15093, 15076, 15091>, 0,
    <15093, 15091, 15089>, 0,
    <15093, 15089, 15092>, 0,
    <15096, 15095, 15088>, 0,
    <15096, 15088, 15092>, 0,
    <15096, 15092, 15089>, 0,
    <15096, 15089, 15094>, 0,
    <15096, 15094, 14265>, 0,
    <15096, 14265, 14268>, 0,
    <15096, 14268, 14264>, 0,
    <15096, 14264, 15095>, 0,
    <15097, 15090, 15088>, 0,
    <15097, 15088, 15095>, 0,
    <15097, 15095, 14264>, 0,
    <15097, 14264, 14275>, 0,
    <15097, 14275, 14153>, 0,
    <15097, 14153, 15083>, 0,
    <15097, 15083, 15077>, 0,
    <15097, 15077, 15090>, 0,
    <15103, 15102, 15098>, 0,
    <15103, 15098, 15100>, 0,
    <15103, 15100, 15099>, 0,
    <15103, 15099, 15101>, 0,
    <15103, 15101, 14345>, 0,
    <15103, 14345, 14357>, 0,
    <15103, 14357, 14353>, 0,
    <15103, 14353, 15102>, 0,
    <15107, 15106, 15098>, 0,
    <15107, 15098, 15102>, 0,
    <15107, 15102, 14353>, 0,
    <15107, 14353, 14354>, 0,
    <15107, 14354, 14297>, 0,
    <15107, 14297, 15105>, 0,
    <15107, 15105, 15104>, 0,
    <15107, 15104, 15106>, 0,
    <15111, 15100, 15098>, 0,
    <15111, 15098, 15106>, 0,
    <15111, 15106, 15104>, 0,
    <15111, 15104, 15109>, 0,
    <15111, 15109, 15108>, 0,
    <15111, 15108, 15110>, 0,
    <15111, 15110, 15099>, 0,
    <15111, 15099, 15100>, 0,
    <15115, 15114, 15112>, 0,
    <15115, 15112, 15113>, 0,
    <15115, 15113, 15104>, 0,
    <15115, 15104, 15105>, 0,
    <15115, 15105, 14297>, 0,
    <15115, 14297, 15002>, 0,
    <15115, 15002, 15000>, 0,
    <15115, 15000, 15114>, 0,
    <15119, 15118, 15112>, 0,
    <15119, 15112, 15114>, 0,
    <15119, 15114, 15000>, 0,
    <15119, 15000, 15011>, 0,
    <15119, 15011, 15009>, 0,
    <15119, 15009, 15117>, 0,
    <15119, 15117, 15116>, 0,
    <15119, 15116, 15118>, 0,
    <15121, 15113, 15112>, 0,
    <15121, 15112, 15118>, 0,
    <15121, 15118, 15116>, 0,
    <15121, 15116, 15120>, 0,
    <15121, 15120, 15108>, 0,
    <15121, 15108, 15109>, 0,
    <15121, 15109, 15104>, 0,
    <15121, 15104, 15113>, 0,
    <15130, 15129, 15122>, 0,
    <15130, 15122, 15126>, 0,
    <15130, 15126, 15123>, 0,
    <15130, 15123, 15127>, 0,
    <15130, 15127, 15124>, 0,
    <15130, 15124, 15128>, 0,
    <15130, 15128, 15125>, 0,
    <15130, 15125, 15129>, 0,
    <15133, 15132, 15122>, 0,
    <15133, 15122, 15129>, 0,
    <15133, 15129, 15125>, 0,
    <15133, 15125, 15131>, 0,
    <15133, 15131, 15025>, 0,
    <15133, 15025, 15043>, 0,
    <15133, 15043, 15041>, 0,
    <15133, 15041, 15132>, 0,
    <15135, 15126, 15122>, 0,
    <15135, 15122, 15132>, 0,
    <15135, 15132, 15041>, 0,
    <15135, 15041, 15048>, 0,
    <15135, 15048, 14214>, 0,
    <15135, 14214, 15134>, 0,
    <15135, 15134, 15123>, 0,
    <15135, 15123, 15126>, 0,
    <15141, 15140, 15136>, 0,
    <15141, 15136, 15138>, 0,
    <15141, 15138, 15137>, 0,
    <15141, 15137, 15139>, 0,
    <15141, 15139, 15124>, 0,
    <15141, 15124, 15127>, 0,
    <15141, 15127, 15123>, 0,
    <15141, 15123, 15140>, 0,
    <15143, 15142, 15136>, 0,
    <15143, 15136, 15140>, 0,
    <15143, 15140, 15123>, 0,
    <15143, 15123, 15134>, 0,
    <15143, 15134, 14214>, 0,
    <15143, 14214, 14320>, 0,
    <15143, 14320, 14314>, 0,
    <15143, 14314, 15142>, 0,
    <15145, 15138, 15136>, 0,
    <15145, 15136, 15142>, 0,
    <15145, 15142, 14314>, 0,
    <15145, 14314, 14317>, 0,
    <15145, 14317, 14313>, 0,
    <15145, 14313, 15144>, 0,
    <15145, 15144, 15137>, 0,
    <15145, 15137, 15138>, 0,
    <15151, 15150, 15146>, 0,
    <15151, 15146, 15148>, 0,
    <15151, 15148, 15147>, 0,
    <15151, 15147, 15149>, 0,
    <15151, 15149, 14441>, 0,
    <15151, 14441, 14453>, 0,
    <15151, 14453, 14449>, 0,
    <15151, 14449, 15150>, 0,
    <15155, 15154, 15146>, 0,
    <15155, 15146, 15150>, 0,
    <15155, 15150, 14449>, 0,
    <15155, 14449, 14450>, 0,
    <15155, 14450, 14345>, 0,
    <15155, 14345, 15153>, 0,
    <15155, 15153, 15152>, 0,
    <15155, 15152, 15154>, 0,
    <15159, 15148, 15146>, 0,
    <15159, 15146, 15154>, 0,
    <15159, 15154, 15152>, 0,
    <15159, 15152, 15157>, 0,
    <15159, 15157, 15156>, 0,
    <15159, 15156, 15158>, 0,
    <15159, 15158, 15147>, 0,
    <15159, 15147, 15148>, 0,
    <15163, 15162, 15160>, 0,
    <15163, 15160, 15161>, 0,
    <15163, 15161, 15152>, 0,
    <15163, 15152, 15153>, 0,
    <15163, 15153, 14345>, 0,
    <15163, 14345, 15101>, 0,
    <15163, 15101, 15099>, 0,
    <15163, 15099, 15162>, 0,
    <15167, 15166, 15160>, 0,
    <15167, 15160, 15162>, 0,
    <15167, 15162, 15099>, 0,
    <15167, 15099, 15110>, 0,
    <15167, 15110, 15108>, 0,
    <15167, 15108, 15165>, 0,
    <15167, 15165, 15164>, 0,
    <15167, 15164, 15166>, 0,
    <15169, 15161, 15160>, 0,
    <15169, 15160, 15166>, 0,
    <15169, 15166, 15164>, 0,
    <15169, 15164, 15168>, 0,
    <15169, 15168, 15156>, 0,
    <15169, 15156, 15157>, 0,
    <15169, 15157, 15152>, 0,
    <15169, 15152, 15161>, 0,
    <15178, 15177, 15170>, 0,
    <15178, 15170, 15174>, 0,
    <15178, 15174, 15171>, 0,
    <15178, 15171, 15175>, 0,
    <15178, 15175, 15172>, 0,
    <15178, 15172, 15176>, 0,
    <15178, 15176, 15173>, 0,
    <15178, 15173, 15177>, 0,
    <15181, 15180, 15170>, 0,
    <15181, 15170, 15177>, 0,
    <15181, 15177, 15173>, 0,
    <15181, 15173, 15179>, 0,
    <15181, 15179, 15124>, 0,
    <15181, 15124, 15139>, 0,
    <15181, 15139, 15137>, 0,
    <15181, 15137, 15180>, 0,
    <15183, 15174, 15170>, 0,
    <15183, 15170, 15180>, 0,
    <15183, 15180, 15137>, 0,
    <15183, 15137, 15144>, 0,
    <15183, 15144, 14313>, 0,
    <15183, 14313, 15182>, 0,
    <15183, 15182, 15171>, 0,
    <15183, 15171, 15174>, 0,
    <15189, 15188, 15184>, 0,
    <15189, 15184, 15186>, 0,
    <15189, 15186, 15185>, 0,
    <15189, 15185, 15187>, 0,
    <15189, 15187, 15172>, 0,
    <15189, 15172, 15175>, 0,
    <15189, 15175, 15171>, 0,
    <15189, 15171, 15188>, 0,
    <15191, 15190, 15184>, 0,
    <15191, 15184, 15188>, 0,
    <15191, 15188, 15171>, 0,
    <15191, 15171, 15182>, 0,
    <15191, 15182, 14313>, 0,
    <15191, 14313, 14368>, 0,
    <15191, 14368, 14362>, 0,
    <15191, 14362, 15190>, 0,
    <15193, 15186, 15184>, 0,
    <15193, 15184, 15190>, 0,
    <15193, 15190, 14362>, 0,
    <15193, 14362, 14365>, 0,
    <15193, 14365, 14361>, 0,
    <15193, 14361, 15192>, 0,
    <15193, 15192, 15185>, 0,
    <15193, 15185, 15186>, 0,
    <15199, 15198, 15194>, 0,
    <15199, 15194, 15196>, 0,
    <15199, 15196, 14497>, 0,
    <15199, 14497, 14498>, 0,
    <15199, 14498, 14485>, 0,
    <15199, 14485, 15197>, 0,
    <15199, 15197, 15195>, 0,
    <15199, 15195, 15198>, 0,
    <15205, 15204, 15194>, 0,
    <15205, 15194, 15198>, 0,
    <15205, 15198, 15195>, 0,
    <15205, 15195, 15202>, 0,
    <15205, 15202, 15200>, 0,
    <15205, 15200, 15203>, 0,
    <15205, 15203, 15201>, 0,
    <15205, 15201, 15204>, 0,
    <15207, 15196, 15194>, 0,
    <15207, 15194, 15204>, 0,
    <15207, 15204, 15201>, 0,
    <15207, 15201, 15206>, 0,
    <15207, 15206, 14389>, 0,
    <15207, 14389, 14501>, 0,
    <15207, 14501, 14497>, 0,
    <15207, 14497, 15196>, 0,
    <15211, 15210, 15208>, 0,
    <15211, 15208, 15209>, 0,
    <15211, 15209, 15051>, 0,
    <15211, 15051, 15053>, 0,
    <15211, 15053, 14389>, 0,
    <15211, 14389, 15206>, 0,
    <15211, 15206, 15201>, 0,
    <15211, 15201, 15210>, 0,
    <15215, 15214, 15208>, 0,
    <15215, 15208, 15210>, 0,
    <15215, 15210, 15201>, 0,
    <15215, 15201, 15203>, 0,
    <15215, 15203, 15200>, 0,
    <15215, 15200, 15213>, 0,
    <15215, 15213, 15212>, 0,
    <15215, 15212, 15214>, 0,
    <15217, 15209, 15208>, 0,
    <15217, 15208, 15214>, 0,
    <15217, 15214, 15212>, 0,
    <15217, 15212, 15216>, 0,
    <15217, 15216, 15056>, 0,
    <15217, 15056, 15058>, 0,
    <15217, 15058, 15051>, 0,
    <15217, 15051, 15209>, 0,
    <15226, 15225, 15218>, 0,
    <15226, 15218, 15222>, 0,
    <15226, 15222, 15219>, 0,
    <15226, 15219, 15223>, 0,
    <15226, 15223, 15220>, 0,
    <15226, 15220, 15224>, 0,
    <15226, 15224, 15221>, 0,
    <15226, 15221, 15225>, 0,
    <15229, 15228, 15218>, 0,
    <15229, 15218, 15225>, 0,
    <15229, 15225, 15221>, 0,
    <15229, 15221, 15227>, 0,
    <15229, 15227, 14265>, 0,
    <15229, 14265, 15094>, 0,
    <15229, 15094, 15089>, 0,
    <15229, 15089, 15228>, 0,
    <15231, 15222, 15218>, 0,
    <15231, 15218, 15228>, 0,
    <15231, 15228, 15089>, 0,
    <15231, 15089, 15091>, 0,
    <15231, 15091, 15076>, 0,
    <15231, 15076, 15230>, 0,
    <15231, 15230, 15219>, 0,
    <15231, 15219, 15222>, 0,
    <15237, 15236, 15232>, 0,
    <15237, 15232, 15234>, 0,
    <15237, 15234, 15221>, 0,
    <15237, 15221, 15224>, 0,
    <15237, 15224, 15220>, 0,
    <15237, 15220, 15235>, 0,
    <15237, 15235, 15233>, 0,
    <15237, 15233, 15236>, 0,
    <15240, 15239, 15232>, 0,
    <15240, 15232, 15236>, 0,
    <15240, 15236, 15233>, 0,
    <15240, 15233, 15238>, 0,
    <15240, 15238, 14409>, 0,
    <15240, 14409, 14412>, 0,
    <15240, 14412, 14408>, 0,
    <15240, 14408, 15239>, 0,
    <15241, 15234, 15232>, 0,
    <15241, 15232, 15239>, 0,
    <15241, 15239, 14408>, 0,
    <15241, 14408, 14419>, 0,
    <15241, 14419, 14265>, 0,
    <15241, 14265, 15227>, 0,
    <15241, 15227, 15221>, 0,
    <15241, 15221, 15234>, 0,
    <15247, 15246, 15242>, 0,
    <15247, 15242, 15244>, 0,
    <15247, 15244, 15243>, 0,
    <15247, 15243, 15245>, 0,
    <15247, 15245, 14537>, 0,
    <15247, 14537, 14549>, 0,
    <15247, 14549, 14545>, 0,
    <15247, 14545, 15246>, 0,
    <15251, 15250, 15242>, 0,
    <15251, 15242, 15246>, 0,
    <15251, 15246, 14545>, 0,
    <15251, 14545, 14546>, 0,
    <15251, 14546, 14441>, 0,
    <15251, 14441, 15249>, 0,
    <15251, 15249, 15248>, 0,
    <15251, 15248, 15250>, 0,
    <15255, 15244, 15242>, 0,
    <15255, 15242, 15250>, 0,
    <15255, 15250, 15248>, 0,
    <15255, 15248, 15253>, 0,
    <15255, 15253, 15252>, 0,
    <15255, 15252, 15254>, 0,
    <15255, 15254, 15243>, 0,
    <15255, 15243, 15244>, 0,
    <15259, 15258, 15256>, 0,
    <15259, 15256, 15257>, 0,
    <15259, 15257, 15248>, 0,
    <15259, 15248, 15249>, 0,
    <15259, 15249, 14441>, 0,
    <15259, 14441, 15149>, 0,
    <15259, 15149, 15147>, 0,
    <15259, 15147, 15258>, 0,
    <15263, 15262, 15256>, 0,
    <15263, 15256, 15258>, 0,
    <15263, 15258, 15147>, 0,
    <15263, 15147, 15158>, 0,
    <15263, 15158, 15156>, 0,
    <15263, 15156, 15261>, 0,
    <15263, 15261, 15260>, 0,
    <15263, 15260, 15262>, 0,
    <15265, 15257, 15256>, 0,
    <15265, 15256, 15262>, 0,
    <15265, 15262, 15260>, 0,
    <15265, 15260, 15264>, 0,
    <15265, 15264, 15252>, 0,
    <15265, 15252, 15253>, 0,
    <15265, 15253, 15248>, 0,
    <15265, 15248, 15257>, 0,
    <15274, 15273, 15266>, 0,
    <15274, 15266, 15270>, 0,
    <15274, 15270, 15267>, 0,
    <15274, 15267, 15271>, 0,
    <15274, 15271, 15268>, 0,
    <15274, 15268, 15272>, 0,
    <15274, 15272, 15269>, 0,
    <15274, 15269, 15273>, 0,
    <15277, 15276, 15266>, 0,
    <15277, 15266, 15273>, 0,
    <15277, 15273, 15269>, 0,
    <15277, 15269, 15275>, 0,
    <15277, 15275, 15172>, 0,
    <15277, 15172, 15187>, 0,
    <15277, 15187, 15185>, 0,
    <15277, 15185, 15276>, 0,
    <15279, 15270, 15266>, 0,
    <15279, 15266, 15276>, 0,
    <15279, 15276, 15185>, 0,
    <15279, 15185, 15192>, 0,
    <15279, 15192, 14361>, 0,
    <15279, 14361, 15278>, 0,
    <15279, 15278, 15267>, 0,
    <15279, 15267, 15270>, 0,
    <15285, 15284, 15280>, 0,
    <15285, 15280, 15282>, 0,
    <15285, 15282, 15281>, 0,
    <15285, 15281, 15283>, 0,
    <15285, 15283, 15268>, 0,
    <15285, 15268, 15271>, 0,
    <15285, 15271, 15267>, 0,
    <15285, 15267, 15284>, 0,
    <15287, 15286, 15280>, 0,
    <15287, 15280, 15284>, 0,
    <15287, 15284, 15267>, 0,
    <15287, 15267, 15278>, 0,
    <15287, 15278, 14361>, 0,
    <15287, 14361, 14464>, 0,
    <15287, 14464, 14458>, 0,
    <15287, 14458, 15286>, 0,
    <15289, 15282, 15280>, 0,
    <15289, 15280, 15286>, 0,
    <15289, 15286, 14458>, 0,
    <15289, 14458, 14461>, 0,
    <15289, 14461, 14457>, 0,
    <15289, 14457, 15288>, 0,
    <15289, 15288, 15281>, 0,
    <15289, 15281, 15282>, 0,
    <15295, 15294, 15290>, 0,
    <15295, 15290, 15292>, 0,
    <15295, 15292, 14606>, 0,
    <15295, 14606, 14607>, 0,
    <15295, 14607, 14588>, 0,
    <15295, 14588, 15293>, 0,
    <15295, 15293, 15291>, 0,
    <15295, 15291, 15294>, 0,
    <15301, 15300, 15290>, 0,
    <15301, 15290, 15294>, 0,
    <15301, 15294, 15291>, 0,
    <15301, 15291, 15298>, 0,
    <15301, 15298, 15296>, 0,
    <15301, 15296, 15299>, 0,
    <15301, 15299, 15297>, 0,
    <15301, 15297, 15300>, 0,
    <15303, 15292, 15290>, 0,
    <15303, 15290, 15300>, 0,
    <15303, 15300, 15297>, 0,
    <15303, 15297, 15302>, 0,
    <15303, 15302, 14485>, 0,
    <15303, 14485, 14610>, 0,
    <15303, 14610, 14606>, 0,
    <15303, 14606, 15292>, 0,
    <15307, 15306, 15304>, 0,
    <15307, 15304, 15305>, 0,
    <15307, 15305, 15195>, 0,
    <15307, 15195, 15197>, 0,
    <15307, 15197, 14485>, 0,
    <15307, 14485, 15302>, 0,
    <15307, 15302, 15297>, 0,
    <15307, 15297, 15306>, 0,
    <15311, 15310, 15304>, 0,
    <15311, 15304, 15306>, 0,
    <15311, 15306, 15297>, 0,
    <15311, 15297, 15299>, 0,
    <15311, 15299, 15296>, 0,
    <15311, 15296, 15309>, 0,
    <15311, 15309, 15308>, 0,
    <15311, 15308, 15310>, 0,
    <15313, 15305, 15304>, 0,
    <15313, 15304, 15310>, 0,
    <15313, 15310, 15308>, 0,
    <15313, 15308, 15312>, 0,
    <15313, 15312, 15200>, 0,
    <15313, 15200, 15202>, 0,
    <15313, 15202, 15195>, 0,
    <15313, 15195, 15305>, 0,
    <15322, 15321, 15314>, 0,
    <15322, 15314, 15318>, 0,
    <15322, 15318, 15315>, 0,
    <15322, 15315, 15319>, 0,
    <15322, 15319, 15316>, 0,
    <15322, 15316, 15320>, 0,
    <15322, 15320, 15317>, 0,
    <15322, 15317, 15321>, 0,
    <15325, 15324, 15314>, 0,
    <15325, 15314, 15321>, 0,
    <15325, 15321, 15317>, 0,
    <15325, 15317, 15323>, 0,
    <15325, 15323, 14409>, 0,
    <15325, 14409, 15238>, 0,
    <15325, 15238, 15233>, 0,
    <15325, 15233, 15324>, 0,
    <15327, 15318, 15314>, 0,
    <15327, 15314, 15324>, 0,
    <15327, 15324, 15233>, 0,
    <15327, 15233, 15235>, 0,
    <15327, 15235, 15220>, 0,
    <15327, 15220, 15326>, 0,
    <15327, 15326, 15315>, 0,
    <15327, 15315, 15318>, 0,
    <15333, 15332, 15328>, 0,
    <15333, 15328, 15330>, 0,
    <15333, 15330, 15317>, 0,
    <15333, 15317, 15320>, 0,
    <15333, 15320, 15316>, 0,
    <15333, 15316, 15331>, 0,
    <15333, 15331, 15329>, 0,
    <15333, 15329, 15332>, 0,
    <15336, 15335, 15328>, 0,
    <15336, 15328, 15332>, 0,
    <15336, 15332, 15329>, 0,
    <15336, 15329, 15334>, 0,
    <15336, 15334, 14505>, 0,
    <15336, 14505, 14508>, 0,
    <15336, 14508, 14504>, 0,
    <15336, 14504, 15335>, 0,
    <15337, 15330, 15328>, 0,
    <15337, 15328, 15335>, 0,
    <15337, 15335, 14504>, 0,
    <15337, 14504, 14515>, 0,
    <15337, 14515, 14409>, 0,
    <15337, 14409, 15323>, 0,
    <15337, 15323, 15317>, 0,
    <15337, 15317, 15330>, 0,
    <15343, 15342, 15338>, 0,
    <15343, 15338, 15340>, 0,
    <15343, 15340, 15339>, 0,
    <15343, 15339, 15341>, 0,
    <15343, 15341, 14646>, 0,
    <15343, 14646, 14658>, 0,
    <15343, 14658, 14654>, 0,
    <15343, 14654, 15342>, 0,
    <15347, 15346, 15338>, 0,
    <15347, 15338, 15342>, 0,
    <15347, 15342, 14654>, 0,
    <15347, 14654, 14655>, 0,
    <15347, 14655, 14537>, 0,
    <15347, 14537, 15345>, 0,
    <15347, 15345, 15344>, 0,
    <15347, 15344, 15346>, 0,
    <15351, 15340, 15338>, 0,
    <15351, 15338, 15346>, 0,
    <15351, 15346, 15344>, 0,
    <15351, 15344, 15349>, 0,
    <15351, 15349, 15348>, 0,
    <15351, 15348, 15350>, 0,
    <15351, 15350, 15339>, 0,
    <15351, 15339, 15340>, 0,
    <15355, 15354, 15352>, 0,
    <15355, 15352, 15353>, 0,
    <15355, 15353, 15344>, 0,
    <15355, 15344, 15345>, 0,
    <15355, 15345, 14537>, 0,
    <15355, 14537, 15245>, 0,
    <15355, 15245, 15243>, 0,
    <15355, 15243, 15354>, 0,
    <15359, 15358, 15352>, 0,
    <15359, 15352, 15354>, 0,
    <15359, 15354, 15243>, 0,
    <15359, 15243, 15254>, 0,
    <15359, 15254, 15252>, 0,
    <15359, 15252, 15357>, 0,
    <15359, 15357, 15356>, 0,
    <15359, 15356, 15358>, 0,
    <15361, 15353, 15352>, 0,
    <15361, 15352, 15358>, 0,
    <15361, 15358, 15356>, 0,
    <15361, 15356, 15360>, 0,
    <15361, 15360, 15348>, 0,
    <15361, 15348, 15349>, 0,
    <15361, 15349, 15344>, 0,
    <15361, 15344, 15353>, 0,
    <15370, 15369, 15362>, 0,
    <15370, 15362, 15366>, 0,
    <15370, 15366, 15363>, 0,
    <15370, 15363, 15367>, 0,
    <15370, 15367, 15364>, 0,
    <15370, 15364, 15368>, 0,
    <15370, 15368, 15365>, 0,
    <15370, 15365, 15369>, 0,
    <15373, 15372, 15362>, 0,
    <15373, 15362, 15369>, 0,
    <15373, 15369, 15365>, 0,
    <15373, 15365, 15371>, 0,
    <15373, 15371, 15268>, 0,
    <15373, 15268, 15283>, 0,
    <15373, 15283, 15281>, 0,
    <15373, 15281, 15372>, 0,
    <15375, 15366, 15362>, 0,
    <15375, 15362, 15372>, 0,
    <15375, 15372, 15281>, 0,
    <15375, 15281, 15288>, 0,
    <15375, 15288, 14457>, 0,
    <15375, 14457, 15374>, 0,
    <15375, 15374, 15363>, 0,
    <15375, 15363, 15366>, 0,
    <15381, 15380, 15376>, 0,
    <15381, 15376, 15378>, 0,
    <15381, 15378, 15377>, 0,
    <15381, 15377, 15379>, 0,
    <15381, 15379, 15364>, 0,
    <15381, 15364, 15367>, 0,
    <15381, 15367, 15363>, 0,
    <15381, 15363, 15380>, 0,
    <15383, 15382, 15376>, 0,
    <15383, 15376, 15380>, 0,
    <15383, 15380, 15363>, 0,
    <15383, 15363, 15374>, 0,
    <15383, 15374, 14457>, 0,
    <15383, 14457, 14560>, 0,
    <15383, 14560, 14554>, 0,
    <15383, 14554, 15382>, 0,
    <15385, 15378, 15376>, 0,
    <15385, 15376, 15382>, 0,
    <15385, 15382, 14554>, 0,
    <15385, 14554, 14557>, 0,
    <15385, 14557, 14553>, 0,
    <15385, 14553, 15384>, 0,
    <15385, 15384, 15377>, 0,
    <15385, 15377, 15378>, 0,
    <15393, 15392, 15386>, 0,
    <15393, 15386, 15389>, 0,
    <15393, 15389, 15387>, 0,
    <15393, 15387, 15390>, 0,
    <15393, 15390, 3069>, 0,
    <15393, 3069, 15391>, 0,
    <15393, 15391, 15388>, 0,
    <15393, 15388, 15392>, 0,
    <15399, 15398, 15386>, 0,
    <15399, 15386, 15392>, 0,
    <15399, 15392, 15388>, 0,
    <15399, 15388, 15396>, 0,
    <15399, 15396, 15394>, 0,
    <15399, 15394, 15397>, 0,
    <15399, 15397, 15395>, 0,
    <15399, 15395, 15398>, 0,
    <15403, 15389, 15386>, 0,
    <15403, 15386, 15398>, 0,
    <15403, 15398, 15395>, 0,
    <15403, 15395, 15401>, 0,
    <15403, 15401, 15400>, 0,
    <15403, 15400, 15402>, 0,
    <15403, 15402, 15387>, 0,
    <15403, 15387, 15389>, 0,
    <15407, 15406, 15404>, 0,
    <15407, 15404, 15405>, 0,
    <15407, 15405, 14690>, 0,
    <15407, 14690, 14692>, 0,
    <15407, 14692, 3069>, 0,
    <15407, 3069, 15390>, 0,
    <15407, 15390, 15387>, 0,
    <15407, 15387, 15406>, 0,
    <15411, 15410, 15404>, 0,
    <15411, 15404, 15406>, 0,
    <15411, 15406, 15387>, 0,
    <15411, 15387, 15402>, 0,
    <15411, 15402, 15400>, 0,
    <15411, 15400, 15409>, 0,
    <15411, 15409, 15408>, 0,
    <15411, 15408, 15410>, 0,
    <15413, 15405, 15404>, 0,
    <15413, 15404, 15410>, 0,
    <15413, 15410, 15408>, 0,
    <15413, 15408, 15412>, 0,
    <15413, 15412, 14588>, 0,
    <15413, 14588, 14695>, 0,
    <15413, 14695, 14690>, 0,
    <15413, 14690, 15405>, 0,
    <15417, 15416, 15414>, 0,
    <15417, 15414, 15415>, 0,
    <15417, 15415, 15291>, 0,
    <15417, 15291, 15293>, 0,
    <15417, 15293, 14588>, 0,
    <15417, 14588, 15412>, 0,
    <15417, 15412, 15408>, 0,
    <15417, 15408, 15416>, 0,
    <15421, 15420, 15414>, 0,
    <15421, 15414, 15416>, 0,
    <15421, 15416, 15408>, 0,
    <15421, 15408, 15409>, 0,
    <15421, 15409, 15400>, 0,
    <15421, 15400, 15419>, 0,
    <15421, 15419, 15418>, 0,
    <15421, 15418, 15420>, 0,
    <15423, 15415, 15414>, 0,
    <15423, 15414, 15420>, 0,
    <15423, 15420, 15418>, 0,
    <15423, 15418, 15422>, 0,
    <15423, 15422, 15296>, 0,
    <15423, 15296, 15298>, 0,
    <15423, 15298, 15291>, 0,
    <15423, 15291, 15415>, 0,
    <15432, 15431, 15424>, 0,
    <15432, 15424, 15428>, 0,
    <15432, 15428, 15425>, 0,
    <15432, 15425, 15429>, 0,
    <15432, 15429, 15426>, 0,
    <15432, 15426, 15430>, 0,
    <15432, 15430, 15427>, 0,
    <15432, 15427, 15431>, 0,
    <15435, 15434, 15424>, 0,
    <15435, 15424, 15431>, 0,
    <15435, 15431, 15427>, 0,
    <15435, 15427, 15433>, 0,
    <15435, 15433, 14505>, 0,
    <15435, 14505, 15334>, 0,
    <15435, 15334, 15329>, 0,
    <15435, 15329, 15434>, 0,
    <15437, 15428, 15424>, 0,
    <15437, 15424, 15434>, 0,
    <15437, 15434, 15329>, 0,
    <15437, 15329, 15331>, 0,
    <15437, 15331, 15316>, 0,
    <15437, 15316, 15436>, 0,
    <15437, 15436, 15425>, 0,
    <15437, 15425, 15428>, 0,
    <15443, 15442, 15438>, 0,
    <15443, 15438, 15440>, 0,
    <15443, 15440, 15427>, 0,
    <15443, 15427, 15430>, 0,
    <15443, 15430, 15426>, 0,
    <15443, 15426, 15441>, 0,
    <15443, 15441, 15439>, 0,
    <15443, 15439, 15442>, 0,
    <15446, 15445, 15438>, 0,
    <15446, 15438, 15442>, 0,
    <15446, 15442, 15439>, 0,
    <15446, 15439, 15444>, 0,
    <15446, 15444, 14614>, 0,
    <15446, 14614, 14617>, 0,
    <15446, 14617, 14613>, 0,
    <15446, 14613, 15445>, 0,
    <15447, 15440, 15438>, 0,
    <15447, 15438, 15445>, 0,
    <15447, 15445, 14613>, 0,
    <15447, 14613, 14624>, 0,
    <15447, 14624, 14505>, 0,
    <15447, 14505, 15433>, 0,
    <15447, 15433, 15427>, 0,
    <15447, 15427, 15440>, 0,
    <15453, 15452, 15448>, 0,
    <15453, 15448, 15450>, 0,
    <15453, 15450, 15449>, 0,
    <15453, 15449, 15451>, 0,
    <15453, 15451, 14734>, 0,
    <15453, 14734, 14756>, 0,
    <15453, 14756, 14752>, 0,
    <15453, 14752, 15452>, 0,
    <15457, 15456, 15448>, 0,
    <15457, 15448, 15452>, 0,
    <15457, 15452, 14752>, 0,
    <15457, 14752, 14753>, 0,
    <15457, 14753, 14646>, 0,
    <15457, 14646, 15455>, 0,
    <15457, 15455, 15454>, 0,
    <15457, 15454, 15456>, 0,
    <15461, 15450, 15448>, 0,
    <15461, 15448, 15456>, 0,
    <15461, 15456, 15454>, 0,
    <15461, 15454, 15459>, 0,
    <15461, 15459, 15458>, 0,
    <15461, 15458, 15460>, 0,
    <15461, 15460, 15449>, 0,
    <15461, 15449, 15450>, 0,
    <15465, 15464, 15462>, 0,
    <15465, 15462, 15463>, 0,
    <15465, 15463, 15454>, 0,
    <15465, 15454, 15455>, 0,
    <15465, 15455, 14646>, 0,
    <15465, 14646, 15341>, 0,
    <15465, 15341, 15339>, 0,
    <15465, 15339, 15464>, 0,
    <15469, 15468, 15462>, 0,
    <15469, 15462, 15464>, 0,
    <15469, 15464, 15339>, 0,
    <15469, 15339, 15350>, 0,
    <15469, 15350, 15348>, 0,
    <15469, 15348, 15467>, 0,
    <15469, 15467, 15466>, 0,
    <15469, 15466, 15468>, 0,
    <15471, 15463, 15462>, 0,
    <15471, 15462, 15468>, 0,
    <15471, 15468, 15466>, 0,
    <15471, 15466, 15470>, 0,
    <15471, 15470, 15458>, 0,
    <15471, 15458, 15459>, 0,
    <15471, 15459, 15454>, 0,
    <15471, 15454, 15463>, 0,
    <15480, 15479, 15472>, 0,
    <15480, 15472, 15476>, 0,
    <15480, 15476, 15473>, 0,
    <15480, 15473, 15477>, 0,
    <15480, 15477, 15474>, 0,
    <15480, 15474, 15478>, 0,
    <15480, 15478, 15475>, 0,
    <15480, 15475, 15479>, 0,
    <15483, 15482, 15472>, 0,
    <15483, 15472, 15479>, 0,
    <15483, 15479, 15475>, 0,
    <15483, 15475, 15481>, 0,
    <15483, 15481, 15364>, 0,
    <15483, 15364, 15379>, 0,
    <15483, 15379, 15377>, 0,
    <15483, 15377, 15482>, 0,
    <15485, 15476, 15472>, 0,
    <15485, 15472, 15482>, 0,
    <15485, 15482, 15377>, 0,
    <15485, 15377, 15384>, 0,
    <15485, 15384, 14553>, 0,
    <15485, 14553, 15484>, 0,
    <15485, 15484, 15473>, 0,
    <15485, 15473, 15476>, 0,
    <15491, 15490, 15486>, 0,
    <15491, 15486, 15488>, 0,
    <15491, 15488, 15487>, 0,
    <15491, 15487, 15489>, 0,
    <15491, 15489, 15474>, 0,
    <15491, 15474, 15477>, 0,
    <15491, 15477, 15473>, 0,
    <15491, 15473, 15490>, 0,
    <15493, 15492, 15486>, 0,
    <15493, 15486, 15490>, 0,
    <15493, 15490, 15473>, 0,
    <15493, 15473, 15484>, 0,
    <15493, 15484, 14553>, 0,
    <15493, 14553, 14669>, 0,
    <15493, 14669, 14663>, 0,
    <15493, 14663, 15492>, 0,
    <15495, 15488, 15486>, 0,
    <15495, 15486, 15492>, 0,
    <15495, 15492, 14663>, 0,
    <15495, 14663, 14666>, 0,
    <15495, 14666, 14662>, 0,
    <15495, 14662, 15494>, 0,
    <15495, 15494, 15487>, 0,
    <15495, 15487, 15488>, 0,
    <15501, 15500, 15496>, 0,
    <15501, 15496, 15498>, 0,
    <15501, 15498, 15395>, 0,
    <15501, 15395, 15397>, 0,
    <15501, 15397, 15394>, 0,
    <15501, 15394, 15499>, 0,
    <15501, 15499, 15497>, 0,
    <15501, 15497, 15500>, 0,
    <15506, 15505, 15496>, 0,
    <15506, 15496, 15500>, 0,
    <15506, 15500, 15497>, 0,
    <15506, 15497, 15503>, 0,
    <15506, 15503, 3370>, 0,
    <15506, 3370, 15504>, 0,
    <15506, 15504, 15502>, 0,
    <15506, 15502, 15505>, 0,
    <15508, 15498, 15496>, 0,
    <15508, 15496, 15505>, 0,
    <15508, 15505, 15502>, 0,
    <15508, 15502, 15507>, 0,
    <15508, 15507, 15400>, 0,
    <15508, 15400, 15401>, 0,
    <15508, 15401, 15395>, 0,
    <15508, 15395, 15498>, 0,
    <15516, 15515, 15509>, 0,
    <15516, 15509, 15512>, 0,
    <15516, 15512, 15510>, 0,
    <15516, 15510, 15513>, 0,
    <15516, 15513, 3406>, 0,
    <15516, 3406, 15514>, 0,
    <15516, 15514, 15511>, 0,
    <15516, 15511, 15515>, 0,
    <15519, 15518, 15509>, 0,
    <15519, 15509, 15515>, 0,
    <15519, 15515, 15511>, 0,
    <15519, 15511, 15517>, 0,
    <15519, 15517, 14614>, 0,
    <15519, 14614, 15444>, 0,
    <15519, 15444, 15439>, 0,
    <15519, 15439, 15518>, 0,
    <15521, 15512, 15509>, 0,
    <15521, 15509, 15518>, 0,
    <15521, 15518, 15439>, 0,
    <15521, 15439, 15441>, 0,
    <15521, 15441, 15426>, 0,
    <15521, 15426, 15520>, 0,
    <15521, 15520, 15510>, 0,
    <15521, 15510, 15512>, 0,
    <15527, 15526, 15522>, 0,
    <15527, 15522, 15524>, 0,
    <15527, 15524, 15511>, 0,
    <15527, 15511, 15514>, 0,
    <15527, 15514, 3406>, 0,
    <15527, 3406, 15525>, 0,
    <15527, 15525, 15523>, 0,
    <15527, 15523, 15526>, 0,
    <15530, 15529, 15522>, 0,
    <15530, 15522, 15526>, 0,
    <15530, 15526, 15523>, 0,
    <15530, 15523, 15528>, 0,
    <15530, 15528, 14848>, 0,
    <15530, 14848, 14851>, 0,
    <15530, 14851, 14847>, 0,
    <15530, 14847, 15529>, 0,
    <15531, 15524, 15522>, 0,
    <15531, 15522, 15529>, 0,
    <15531, 15529, 14847>, 0,
    <15531, 14847, 14858>, 0,
    <15531, 14858, 14614>, 0,
    <15531, 14614, 15517>, 0,
    <15531, 15517, 15511>, 0,
    <15531, 15511, 15524>, 0,
    <15540, 15539, 15532>, 0,
    <15540, 15532, 15536>, 0,
    <15540, 15536, 15533>, 0,
    <15540, 15533, 15537>, 0,
    <15540, 15537, 15534>, 0,
    <15540, 15534, 15538>, 0,
    <15540, 15538, 15535>, 0,
    <15540, 15535, 15539>, 0,
    <15545, 15544, 15532>, 0,
    <15545, 15532, 15539>, 0,
    <15545, 15539, 15535>, 0,
    <15545, 15535, 15542>, 0,
    <15545, 15542, 14834>, 0,
    <15545, 14834, 15543>, 0,
    <15545, 15543, 15541>, 0,
    <15545, 15541, 15544>, 0,
    <15549, 15536, 15532>, 0,
    <15549, 15532, 15544>, 0,
    <15549, 15544, 15541>, 0,
    <15549, 15541, 15547>, 0,
    <15549, 15547, 15546>, 0,
    <15549, 15546, 15548>, 0,
    <15549, 15548, 15533>, 0,
    <15549, 15533, 15536>, 0,
    <15553, 15552, 15550>, 0,
    <15553, 15550, 15551>, 0,
    <15553, 15551, 15541>, 0,
    <15553, 15541, 15543>, 0,
    <15553, 15543, 14834>, 0,
    <15553, 14834, 14837>, 0,
    <15553, 14837, 14833>, 0,
    <15553, 14833, 15552>, 0,
    <15557, 15556, 15550>, 0,
    <15557, 15550, 15552>, 0,
    <15557, 15552, 14833>, 0,
    <15557, 14833, 14844>, 0,
    <15557, 14844, 14734>, 0,
    <15557, 14734, 15555>, 0,
    <15557, 15555, 15554>, 0,
    <15557, 15554, 15556>, 0,
    <15559, 15551, 15550>, 0,
    <15559, 15550, 15556>, 0,
    <15559, 15556, 15554>, 0,
    <15559, 15554, 15558>, 0,
    <15559, 15558, 15546>, 0,
    <15559, 15546, 15547>, 0,
    <15559, 15547, 15541>, 0,
    <15559, 15541, 15551>, 0,
    <15563, 15562, 15560>, 0,
    <15563, 15560, 15561>, 0,
    <15563, 15561, 15554>, 0,
    <15563, 15554, 15555>, 0,
    <15563, 15555, 14734>, 0,
    <15563, 14734, 15451>, 0,
    <15563, 15451, 15449>, 0,
    <15563, 15449, 15562>, 0,
    <15567, 15566, 15560>, 0,
    <15567, 15560, 15562>, 0,
    <15567, 15562, 15449>, 0,
    <15567, 15449, 15460>, 0,
    <15567, 15460, 15458>, 0,
    <15567, 15458, 15565>, 0,
    <15567, 15565, 15564>, 0,
    <15567, 15564, 15566>, 0,
    <15569, 15561, 15560>, 0,
    <15569, 15560, 15566>, 0,
    <15569, 15566, 15564>, 0,
    <15569, 15564, 15568>, 0,
    <15569, 15568, 15546>, 0,
    <15569, 15546, 15558>, 0,
    <15569, 15558, 15554>, 0,
    <15569, 15554, 15561>, 0,
    <15577, 15576, 15570>, 0,
    <15577, 15570, 15573>, 0,
    <15577, 15573, 15571>, 0,
    <15577, 15571, 15574>, 0,
    <15577, 15574, 14987>, 0,
    <15577, 14987, 15575>, 0,
    <15577, 15575, 15572>, 0,
    <15577, 15572, 15576>, 0,
    <15583, 15582, 15570>, 0,
    <15583, 15570, 15576>, 0,
    <15583, 15576, 15572>, 0,
    <15583, 15572, 15580>, 0,
    <15583, 15580, 15578>, 0,
    <15583, 15578, 15581>, 0,
    <15583, 15581, 15579>, 0,
    <15583, 15579, 15582>, 0,
    <15587, 15573, 15570>, 0,
    <15587, 15570, 15582>, 0,
    <15587, 15582, 15579>, 0,
    <15587, 15579, 15585>, 0,
    <15587, 15585, 15584>, 0,
    <15587, 15584, 15586>, 0,
    <15587, 15586, 15571>, 0,
    <15587, 15571, 15573>, 0,
    <15595, 15594, 15588>, 0,
    <15595, 15588, 15591>, 0,
    <15595, 15591, 15589>, 0,
    <15595, 15589, 15592>, 0,
    <15595, 15592, 15584>, 0,
    <15595, 15584, 15593>, 0,
    <15595, 15593, 15590>, 0,
    <15595, 15590, 15594>, 0,
    <15598, 15597, 15588>, 0,
    <15598, 15588, 15594>, 0,
    <15598, 15594, 15590>, 0,
    <15598, 15590, 15596>, 0,
    <15598, 15596, 15474>, 0,
    <15598, 15474, 15489>, 0,
    <15598, 15489, 15487>, 0,
    <15598, 15487, 15597>, 0,
    <15600, 15591, 15588>, 0,
    <15600, 15588, 15597>, 0,
    <15600, 15597, 15487>, 0,
    <15600, 15487, 15494>, 0,
    <15600, 15494, 14662>, 0,
    <15600, 14662, 15599>, 0,
    <15600, 15599, 15589>, 0,
    <15600, 15589, 15591>, 0,
    <15604, 15603, 15601>, 0,
    <15604, 15601, 15602>, 0,
    <15604, 15602, 14988>, 0,
    <15604, 14988, 14991>, 0,
    <15604, 14991, 14987>, 0,
    <15604, 14987, 15574>, 0,
    <15604, 15574, 15571>, 0,
    <15604, 15571, 15603>, 0,
    <15608, 15607, 15601>, 0,
    <15608, 15601, 15603>, 0,
    <15608, 15603, 15571>, 0,
    <15608, 15571, 15586>, 0,
    <15608, 15586, 15584>, 0,
    <15608, 15584, 15606>, 0,
    <15608, 15606, 15605>, 0,
    <15608, 15605, 15607>, 0,
    <15610, 15602, 15601>, 0,
    <15610, 15601, 15607>, 0,
    <15610, 15607, 15605>, 0,
    <15610, 15605, 15609>, 0,
    <15610, 15609, 14772>, 0,
    <15610, 14772, 14994>, 0,
    <15610, 14994, 14988>, 0,
    <15610, 14988, 15602>, 0,
    <15614, 15613, 15611>, 0,
    <15614, 15611, 15612>, 0,
    <15614, 15612, 15605>, 0,
    <15614, 15605, 15606>, 0,
    <15614, 15606, 15584>, 0,
    <15614, 15584, 15592>, 0,
    <15614, 15592, 15589>, 0,
    <15614, 15589, 15613>, 0,
    <15616, 15615, 15611>, 0,
    <15616, 15611, 15613>, 0,
    <15616, 15613, 15589>, 0,
    <15616, 15589, 15599>, 0,
    <15616, 15599, 14662>, 0,
    <15616, 14662, 14784>, 0,
    <15616, 14784, 14778>, 0,
    <15616, 14778, 15615>, 0,
    <15617, 15612, 15611>, 0,
    <15617, 15611, 15615>, 0,
    <15617, 15615, 14778>, 0,
    <15617, 14778, 14781>, 0,
    <15617, 14781, 14772>, 0,
    <15617, 14772, 15609>, 0,
    <15617, 15609, 15605>, 0,
    <15617, 15605, 15612>, 0,
    <15623, 15622, 15618>, 0,
    <15623, 15618, 15620>, 0,
    <15623, 15620, 15619>, 0,
    <15623, 15619, 15621>, 0,
    <15623, 15621, 15534>, 0,
    <15623, 15534, 15537>, 0,
    <15623, 15537, 15533>, 0,
    <15623, 15533, 15622>, 0,
    <15627, 15626, 15618>, 0,
    <15627, 15618, 15622>, 0,
    <15627, 15622, 15533>, 0,
    <15627, 15533, 15548>, 0,
    <15627, 15548, 15546>, 0,
    <15627, 15546, 15625>, 0,
    <15627, 15625, 15624>, 0,
    <15627, 15624, 15626>, 0,
    <15630, 15620, 15618>, 0,
    <15630, 15618, 15626>, 0,
    <15630, 15626, 15624>, 0,
    <15630, 15624, 15628>, 0,
    <15630, 15628, 3380>, 0,
    <15630, 3380, 15629>, 0,
    <15630, 15629, 15619>, 0,
    <15630, 15619, 15620>, 0,
    <15636, 15635, 15631>, 0,
    <15636, 15631, 15633>, 0,
    <15636, 15633, 15579>, 0,
    <15636, 15579, 15581>, 0,
    <15636, 15581, 15578>, 0,
    <15636, 15578, 15634>, 0,
    <15636, 15634, 15632>, 0,
    <15636, 15632, 15635>, 0,
    <15641, 15640, 15631>, 0,
    <15641, 15631, 15635>, 0,
    <15641, 15635, 15632>, 0,
    <15641, 15632, 15638>, 0,
    <15641, 15638, 3394>, 0,
    <15641, 3394, 15639>, 0,
    <15641, 15639, 15637>, 0,
    <15641, 15637, 15640>, 0,
    <15643, 15633, 15631>, 0,
    <15643, 15631, 15640>, 0,
    <15643, 15640, 15637>, 0,
    <15643, 15637, 15642>, 0,
    <15643, 15642, 15584>, 0,
    <15643, 15584, 15585>, 0,
    <15643, 15585, 15579>, 0,
    <15643, 15579, 15633>, 0,
    <15649, 15648, 15644>, 0,
    <15649, 15644, 15646>, 0,
    <15649, 15646, 14891>, 0,
    <15649, 14891, 14892>, 0,
    <15649, 14892, 14879>, 0,
    <15649, 14879, 15647>, 0,
    <15649, 15647, 15645>, 0,
    <15649, 15645, 15648>, 0,
    <15654, 15653, 15644>, 0,
    <15654, 15644, 15648>, 0,
    <15654, 15648, 15645>, 0,
    <15654, 15645, 15651>, 0,
    <15654, 15651, 3493>, 0,
    <15654, 3493, 15652>, 0,
    <15654, 15652, 15650>, 0,
    <15654, 15650, 15653>, 0,
    <15656, 15646, 15644>, 0,
    <15656, 15644, 15653>, 0,
    <15656, 15653, 15650>, 0,
    <15656, 15650, 15655>, 0,
    <15656, 15655, 3238>, 0,
    <15656, 3238, 14895>, 0,
    <15656, 14895, 14891>, 0,
    <15656, 14891, 15646>, 0,
    <15662, 15661, 15657>, 0,
    <15662, 15657, 15659>, 0,
    <15662, 15659, 14942>, 0,
    <15662, 14942, 14943>, 0,
    <15662, 14943, 14930>, 0,
    <15662, 14930, 15660>, 0,
    <15662, 15660, 15658>, 0,
    <15662, 15658, 15661>, 0,
    <15668, 15667, 15657>, 0,
    <15668, 15657, 15661>, 0,
    <15668, 15661, 15658>, 0,
    <15668, 15658, 15665>, 0,
    <15668, 15665, 15663>, 0,
    <15668, 15663, 15666>, 0,
    <15668, 15666, 15664>, 0,
    <15668, 15664, 15667>, 0,
    <15670, 15659, 15657>, 0,
    <15670, 15657, 15667>, 0,
    <15670, 15667, 15664>, 0,
    <15670, 15664, 15669>, 0,
    <15670, 15669, 14879>, 0,
    <15670, 14879, 14946>, 0,
    <15670, 14946, 14942>, 0,
    <15670, 14942, 15659>, 0,
    <15674, 15673, 15671>, 0,
    <15674, 15671, 15672>, 0,
    <15674, 15672, 15645>, 0,
    <15674, 15645, 15647>, 0,
    <15674, 15647, 14879>, 0,
    <15674, 14879, 15669>, 0,
    <15674, 15669, 15664>, 0,
    <15674, 15664, 15673>, 0,
    <15678, 15677, 15671>, 0,
    <15678, 15671, 15673>, 0,
    <15678, 15673, 15664>, 0,
    <15678, 15664, 15666>, 0,
    <15678, 15666, 15663>, 0,
    <15678, 15663, 15676>, 0,
    <15678, 15676, 15675>, 0,
    <15678, 15675, 15677>, 0,
    <15680, 15672, 15671>, 0,
    <15680, 15671, 15677>, 0,
    <15680, 15677, 15675>, 0,
    <15680, 15675, 15679>, 0,
    <15680, 15679, 3493>, 0,
    <15680, 3493, 15651>, 0,
    <15680, 15651, 15645>, 0,
    <15680, 15645, 15672>, 0,
    <15689, 15688, 15681>, 0,
    <15689, 15681, 15685>, 0,
    <15689, 15685, 15682>, 0,
    <15689, 15682, 15686>, 0,
    <15689, 15686, 15683>, 0,
    <15689, 15683, 15687>, 0,
    <15689, 15687, 15684>, 0,
    <15689, 15684, 15688>, 0,
    <15694, 15693, 15681>, 0,
    <15694, 15681, 15688>, 0,
    <15694, 15688, 15684>, 0,
    <15694, 15684, 15691>, 0,
    <15694, 15691, 3262>, 0,
    <15694, 3262, 15692>, 0,
    <15694, 15692, 15690>, 0,
    <15694, 15690, 15693>, 0,
    <15697, 15685, 15681>, 0,
    <15697, 15681, 15693>, 0,
    <15697, 15693, 15690>, 0,
    <15697, 15690, 15695>, 0,
    <15697, 15695, 3516>, 0,
    <15697, 3516, 15696>, 0,
    <15697, 15696, 15682>, 0,
    <15697, 15682, 15685>, 0,
    <15703, 15702, 15698>, 0,
    <15703, 15698, 15700>, 0,
    <15703, 15700, 15684>, 0,
    <15703, 15684, 15687>, 0,
    <15703, 15687, 15683>, 0,
    <15703, 15683, 15701>, 0,
    <15703, 15701, 15699>, 0,
    <15703, 15699, 15702>, 0,
    <15706, 15705, 15698>, 0,
    <15706, 15698, 15702>, 0,
    <15706, 15702, 15699>, 0,
    <15706, 15699, 15704>, 0,
    <15706, 15704, 14899>, 0,
    <15706, 14899, 14902>, 0,
    <15706, 14902, 14898>, 0,
    <15706, 14898, 15705>, 0,
    <15707, 15700, 15698>, 0,
    <15707, 15698, 15705>, 0,
    <15707, 15705, 14898>, 0,
    <15707, 14898, 14912>, 0,
    <15707, 14912, 3262>, 0,
    <15707, 3262, 15691>, 0,
    <15707, 15691, 15684>, 0,
    <15707, 15684, 15700>, 0,
    <15713, 15712, 15708>, 0,
    <15713, 15708, 15710>, 0,
    <15713, 15710, 15068>, 0,
    <15713, 15068, 15069>, 0,
    <15713, 15069, 15056>, 0,
    <15713, 15056, 15711>, 0,
    <15713, 15711, 15709>, 0,
    <15713, 15709, 15712>, 0,
    <15719, 15718, 15708>, 0,
    <15719, 15708, 15712>, 0,
    <15719, 15712, 15709>, 0,
    <15719, 15709, 15716>, 0,
    <15719, 15716, 15714>, 0,
    <15719, 15714, 15717>, 0,
    <15719, 15717, 15715>, 0,
    <15719, 15715, 15718>, 0,
    <15721, 15710, 15708>, 0,
    <15721, 15708, 15718>, 0,
    <15721, 15718, 15715>, 0,
    <15721, 15715, 15720>, 0,
    <15721, 15720, 14930>, 0,
    <15721, 14930, 15072>, 0,
    <15721, 15072, 15068>, 0,
    <15721, 15068, 15710>, 0,
    <15725, 15724, 15722>, 0,
    <15725, 15722, 15723>, 0,
    <15725, 15723, 15658>, 0,
    <15725, 15658, 15660>, 0,
    <15725, 15660, 14930>, 0,
    <15725, 14930, 15720>, 0,
    <15725, 15720, 15715>, 0,
    <15725, 15715, 15724>, 0,
    <15729, 15728, 15722>, 0,
    <15729, 15722, 15724>, 0,
    <15729, 15724, 15715>, 0,
    <15729, 15715, 15717>, 0,
    <15729, 15717, 15714>, 0,
    <15729, 15714, 15727>, 0,
    <15729, 15727, 15726>, 0,
    <15729, 15726, 15728>, 0,
    <15731, 15723, 15722>, 0,
    <15731, 15722, 15728>, 0,
    <15731, 15728, 15726>, 0,
    <15731, 15726, 15730>, 0,
    <15731, 15730, 15663>, 0,
    <15731, 15663, 15665>, 0,
    <15731, 15665, 15658>, 0,
    <15731, 15658, 15723>, 0,
    <15740, 15739, 15732>, 0,
    <15740, 15732, 15736>, 0,
    <15740, 15736, 15733>, 0,
    <15740, 15733, 15737>, 0,
    <15740, 15737, 15734>, 0,
    <15740, 15734, 15738>, 0,
    <15740, 15738, 15735>, 0,
    <15740, 15735, 15739>, 0,
    <15743, 15742, 15732>, 0,
    <15743, 15732, 15739>, 0,
    <15743, 15739, 15735>, 0,
    <15743, 15735, 15741>, 0,
    <15743, 15741, 14899>, 0,
    <15743, 14899, 15704>, 0,
    <15743, 15704, 15699>, 0,
    <15743, 15699, 15742>, 0,
    <15745, 15736, 15732>, 0,
    <15745, 15732, 15742>, 0,
    <15745, 15742, 15699>, 0,
    <15745, 15699, 15701>, 0,
    <15745, 15701, 15683>, 0,
    <15745, 15683, 15744>, 0,
    <15745, 15744, 15733>, 0,
    <15745, 15733, 15736>, 0,
    <15751, 15750, 15746>, 0,
    <15751, 15746, 15748>, 0,
    <15751, 15748, 15735>, 0,
    <15751, 15735, 15738>, 0,
    <15751, 15738, 15734>, 0,
    <15751, 15734, 15749>, 0,
    <15751, 15749, 15747>, 0,
    <15751, 15747, 15750>, 0,
    <15754, 15753, 15746>, 0,
    <15754, 15746, 15750>, 0,
    <15754, 15750, 15747>, 0,
    <15754, 15747, 15752>, 0,
    <15754, 15752, 14950>, 0,
    <15754, 14950, 14953>, 0,
    <15754, 14953, 14949>, 0,
    <15754, 14949, 15753>, 0,
    <15755, 15748, 15746>, 0,
    <15755, 15746, 15753>, 0,
    <15755, 15753, 14949>, 0,
    <15755, 14949, 14960>, 0,
    <15755, 14960, 14899>, 0,
    <15755, 14899, 15741>, 0,
    <15755, 15741, 15735>, 0,
    <15755, 15735, 15748>, 0,
    <15761, 15760, 15756>, 0,
    <15761, 15756, 15758>, 0,
    <15761, 15758, 15757>, 0,
    <15761, 15757, 15759>, 0,
    <15761, 15759, 15009>, 0,
    <15761, 15009, 15021>, 0,
    <15761, 15021, 15017>, 0,
    <15761, 15017, 15760>, 0,
    <15765, 15764, 15756>, 0,
    <15765, 15756, 15760>, 0,
    <15765, 15760, 15017>, 0,
    <15765, 15017, 15018>, 0,
    <15765, 15018, 3276>, 0,
    <15765, 3276, 15763>, 0,
    <15765, 15763, 15762>, 0,
    <15765, 15762, 15764>, 0,
    <15768, 15758, 15756>, 0,
    <15768, 15756, 15764>, 0,
    <15768, 15764, 15762>, 0,
    <15768, 15762, 15766>, 0,
    <15768, 15766, 3545>, 0,
    <15768, 3545, 15767>, 0,
    <15768, 15767, 15757>, 0,
    <15768, 15757, 15758>, 0,
    <15774, 15773, 15769>, 0,
    <15774, 15769, 15771>, 0,
    <15774, 15771, 15770>, 0,
    <15774, 15770, 15772>, 0,
    <15774, 15772, 15108>, 0,
    <15774, 15108, 15120>, 0,
    <15774, 15120, 15116>, 0,
    <15774, 15116, 15773>, 0,
    <15778, 15777, 15769>, 0,
    <15778, 15769, 15773>, 0,
    <15778, 15773, 15116>, 0,
    <15778, 15116, 15117>, 0,
    <15778, 15117, 15009>, 0,
    <15778, 15009, 15776>, 0,
    <15778, 15776, 15775>, 0,
    <15778, 15775, 15777>, 0,
    <15782, 15771, 15769>, 0,
    <15782, 15769, 15777>, 0,
    <15782, 15777, 15775>, 0,
    <15782, 15775, 15780>, 0,
    <15782, 15780, 15779>, 0,
    <15782, 15779, 15781>, 0,
    <15782, 15781, 15770>, 0,
    <15782, 15770, 15771>, 0,
    <15786, 15785, 15783>, 0,
    <15786, 15783, 15784>, 0,
    <15786, 15784, 15775>, 0,
    <15786, 15775, 15776>, 0,
    <15786, 15776, 15009>, 0,
    <15786, 15009, 15759>, 0,
    <15786, 15759, 15757>, 0,
    <15786, 15757, 15785>, 0,
    <15790, 15789, 15783>, 0,
    <15790, 15783, 15785>, 0,
    <15790, 15785, 15757>, 0,
    <15790, 15757, 15767>, 0,
    <15790, 15767, 3545>, 0,
    <15790, 3545, 15788>, 0,
    <15790, 15788, 15787>, 0,
    <15790, 15787, 15789>, 0,
    <15792, 15784, 15783>, 0,
    <15792, 15783, 15789>, 0,
    <15792, 15789, 15787>, 0,
    <15792, 15787, 15791>, 0,
    <15792, 15791, 15779>, 0,
    <15792, 15779, 15780>, 0,
    <15792, 15780, 15775>, 0,
    <15792, 15775, 15784>, 0,
    <15801, 15800, 15793>, 0,
    <15801, 15793, 15797>, 0,
    <15801, 15797, 15794>, 0,
    <15801, 15794, 15798>, 0,
    <15801, 15798, 15795>, 0,
    <15801, 15795, 15799>, 0,
    <15801, 15799, 15796>, 0,
    <15801, 15796, 15800>, 0,
    <15806, 15805, 15793>, 0,
    <15806, 15793, 15800>, 0,
    <15806, 15800, 15796>, 0,
    <15806, 15796, 15803>, 0,
    <15806, 15803, 3551>, 0,
    <15806, 3551, 15804>, 0,
    <15806, 15804, 15802>, 0,
    <15806, 15802, 15805>, 0,
    <15809, 15797, 15793>, 0,
    <15809, 15793, 15805>, 0,
    <15809, 15805, 15802>, 0,
    <15809, 15802, 15807>, 0,
    <15809, 15807, 3282>, 0,
    <15809, 3282, 15808>, 0,
    <15809, 15808, 15794>, 0,
    <15809, 15794, 15797>, 0,
    <15815, 15814, 15810>, 0,
    <15815, 15810, 15812>, 0,
    <15815, 15812, 15811>, 0,
    <15815, 15811, 15813>, 0,
    <15815, 15813, 15795>, 0,
    <15815, 15795, 15798>, 0,
    <15815, 15798, 15794>, 0,
    <15815, 15794, 15814>, 0,
    <15817, 15816, 15810>, 0,
    <15817, 15810, 15814>, 0,
    <15817, 15814, 15794>, 0,
    <15817, 15794, 15808>, 0,
    <15817, 15808, 3282>, 0,
    <15817, 3282, 15033>, 0,
    <15817, 15033, 15026>, 0,
    <15817, 15026, 15816>, 0,
    <15819, 15812, 15810>, 0,
    <15819, 15810, 15816>, 0,
    <15819, 15816, 15026>, 0,
    <15819, 15026, 15029>, 0,
    <15819, 15029, 15025>, 0,
    <15819, 15025, 15818>, 0,
    <15819, 15818, 15811>, 0,
    <15819, 15811, 15812>, 0,
    <15825, 15824, 15820>, 0,
    <15825, 15820, 15822>, 0,
    <15825, 15822, 15212>, 0,
    <15825, 15212, 15213>, 0,
    <15825, 15213, 15200>, 0,
    <15825, 15200, 15823>, 0,
    <15825, 15823, 15821>, 0,
    <15825, 15821, 15824>, 0,
    <15831, 15830, 15820>, 0,
    <15831, 15820, 15824>, 0,
    <15831, 15824, 15821>, 0,
    <15831, 15821, 15828>, 0,
    <15831, 15828, 15826>, 0,
    <15831, 15826, 15829>, 0,
    <15831, 15829, 15827>, 0,
    <15831, 15827, 15830>, 0,
    <15833, 15822, 15820>, 0,
    <15833, 15820, 15830>, 0,
    <15833, 15830, 15827>, 0,
    <15833, 15827, 15832>, 0,
    <15833, 15832, 15056>, 0,
    <15833, 15056, 15216>, 0,
    <15833, 15216, 15212>, 0,
    <15833, 15212, 15822>, 0,
    <15837, 15836, 15834>, 0,
    <15837, 15834, 15835>, 0,
    <15837, 15835, 15709>, 0,
    <15837, 15709, 15711>, 0,
    <15837, 15711, 15056>, 0,
    <15837, 15056, 15832>, 0,
    <15837, 15832, 15827>, 0,
    <15837, 15827, 15836>, 0,
    <15841, 15840, 15834>, 0,
    <15841, 15834, 15836>, 0,
    <15841, 15836, 15827>, 0,
    <15841, 15827, 15829>, 0,
    <15841, 15829, 15826>, 0,
    <15841, 15826, 15839>, 0,
    <15841, 15839, 15838>, 0,
    <15841, 15838, 15840>, 0,
    <15843, 15835, 15834>, 0,
    <15843, 15834, 15840>, 0,
    <15843, 15840, 15838>, 0,
    <15843, 15838, 15842>, 0,
    <15843, 15842, 15714>, 0,
    <15843, 15714, 15716>, 0,
    <15843, 15716, 15709>, 0,
    <15843, 15709, 15835>, 0,
    <15852, 15851, 15844>, 0,
    <15852, 15844, 15848>, 0,
    <15852, 15848, 15845>, 0,
    <15852, 15845, 15849>, 0,
    <15852, 15849, 15846>, 0,
    <15852, 15846, 15850>, 0,
    <15852, 15850, 15847>, 0,
    <15852, 15847, 15851>, 0,
    <15855, 15854, 15844>, 0,
    <15855, 15844, 15851>, 0,
    <15855, 15851, 15847>, 0,
    <15855, 15847, 15853>, 0,
    <15855, 15853, 14950>, 0,
    <15855, 14950, 15752>, 0,
    <15855, 15752, 15747>, 0,
    <15855, 15747, 15854>, 0,
    <15857, 15848, 15844>, 0,
    <15857, 15844, 15854>, 0,
    <15857, 15854, 15747>, 0,
    <15857, 15747, 15749>, 0,
    <15857, 15749, 15734>, 0,
    <15857, 15734, 15856>, 0,
    <15857, 15856, 15845>, 0,
    <15857, 15845, 15848>, 0,
    <15863, 15862, 15858>, 0,
    <15863, 15858, 15860>, 0,
    <15863, 15860, 15847>, 0,
    <15863, 15847, 15850>, 0,
    <15863, 15850, 15846>, 0,
    <15863, 15846, 15861>, 0,
    <15863, 15861, 15859>, 0,
    <15863, 15859, 15862>, 0,
    <15866, 15865, 15858>, 0,
    <15866, 15858, 15862>, 0,
    <15866, 15862, 15859>, 0,
    <15866, 15859, 15864>, 0,
    <15866, 15864, 15076>, 0,
    <15866, 15076, 15079>, 0,
    <15866, 15079, 15075>, 0,
    <15866, 15075, 15865>, 0,
    <15867, 15860, 15858>, 0,
    <15867, 15858, 15865>, 0,
    <15867, 15865, 15075>, 0,
    <15867, 15075, 15086>, 0,
    <15867, 15086, 14950>, 0,
    <15867, 14950, 15853>, 0,
    <15867, 15853, 15847>, 0,
    <15867, 15847, 15860>, 0,
    <15873, 15872, 15868>, 0,
    <15873, 15868, 15870>, 0,
    <15873, 15870, 15869>, 0,
    <15873, 15869, 15871>, 0,
    <15873, 15871, 15156>, 0,
    <15873, 15156, 15168>, 0,
    <15873, 15168, 15164>, 0,
    <15873, 15164, 15872>, 0,
    <15877, 15876, 15868>, 0,
    <15877, 15868, 15872>, 0,
    <15877, 15872, 15164>, 0,
    <15877, 15164, 15165>, 0,
    <15877, 15165, 15108>, 0,
    <15877, 15108, 15875>, 0,
    <15877, 15875, 15874>, 0,
    <15877, 15874, 15876>, 0,
    <15881, 15870, 15868>, 0,
    <15881, 15868, 15876>, 0,
    <15881, 15876, 15874>, 0,
    <15881, 15874, 15879>, 0,
    <15881, 15879, 15878>, 0,
    <15881, 15878, 15880>, 0,
    <15881, 15880, 15869>, 0,
    <15881, 15869, 15870>, 0,
    <15885, 15884, 15882>, 0,
    <15885, 15882, 15883>, 0,
    <15885, 15883, 15874>, 0,
    <15885, 15874, 15875>, 0,
    <15885, 15875, 15108>, 0,
    <15885, 15108, 15772>, 0,
    <15885, 15772, 15770>, 0,
    <15885, 15770, 15884>, 0,
    <15889, 15888, 15882>, 0,
    <15889, 15882, 15884>, 0,
    <15889, 15884, 15770>, 0,
    <15889, 15770, 15781>, 0,
    <15889, 15781, 15779>, 0,
    <15889, 15779, 15887>, 0,
    <15889, 15887, 15886>, 0,
    <15889, 15886, 15888>, 0,
    <15891, 15883, 15882>, 0,
    <15891, 15882, 15888>, 0,
    <15891, 15888, 15886>, 0,
    <15891, 15886, 15890>, 0,
    <15891, 15890, 15878>, 0,
    <15891, 15878, 15879>, 0,
    <15891, 15879, 15874>, 0,
    <15891, 15874, 15883>, 0,
    <15900, 15899, 15892>, 0,
    <15900, 15892, 15896>, 0,
    <15900, 15896, 15893>, 0,
    <15900, 15893, 15897>, 0,
    <15900, 15897, 15894>, 0,
    <15900, 15894, 15898>, 0,
    <15900, 15898, 15895>, 0,
    <15900, 15895, 15899>, 0,
    <15903, 15902, 15892>, 0,
    <15903, 15892, 15899>, 0,
    <15903, 15899, 15895>, 0,
    <15903, 15895, 15901>, 0,
    <15903, 15901, 15795>, 0,
    <15903, 15795, 15813>, 0,
    <15903, 15813, 15811>, 0,
    <15903, 15811, 15902>, 0,
    <15905, 15896, 15892>, 0,
    <15905, 15892, 15902>, 0,
    <15905, 15902, 15811>, 0,
    <15905, 15811, 15818>, 0,
    <15905, 15818, 15025>, 0,
    <15905, 15025, 15904>, 0,
    <15905, 15904, 15893>, 0,
    <15905, 15893, 15896>, 0,
    <15911, 15910, 15906>, 0,
    <15911, 15906, 15908>, 0,
    <15911, 15908, 15907>, 0,
    <15911, 15907, 15909>, 0,
    <15911, 15909, 15894>, 0,
    <15911, 15894, 15897>, 0,
    <15911, 15897, 15893>, 0,
    <15911, 15893, 15910>, 0,
    <15913, 15912, 15906>, 0,
    <15913, 15906, 15910>, 0,
    <15913, 15910, 15893>, 0,
    <15913, 15893, 15904>, 0,
    <15913, 15904, 15025>, 0,
    <15913, 15025, 15131>, 0,
    <15913, 15131, 15125>, 0,
    <15913, 15125, 15912>, 0,
    <15915, 15908, 15906>, 0,
    <15915, 15906, 15912>, 0,
    <15915, 15912, 15125>, 0,
    <15915, 15125, 15128>, 0,
    <15915, 15128, 15124>, 0,
    <15915, 15124, 15914>, 0,
    <15915, 15914, 15907>, 0,
    <15915, 15907, 15908>, 0,
    <15924, 15923, 15916>, 0,
    <15924, 15916, 15920>, 0,
    <15924, 15920, 15917>, 0,
    <15924, 15917, 15921>, 0,
    <15924, 15921, 15918>, 0,
    <15924, 15918, 15922>, 0,
    <15924, 15922, 15919>, 0,
    <15924, 15919, 15923>, 0,
    <15927, 15926, 15916>, 0,
    <15927, 15916, 15923>, 0,
    <15927, 15923, 15919>, 0,
    <15927, 15919, 15925>, 0,
    <15927, 15925, 3406>, 0,
    <15927, 3406, 15513>, 0,
    <15927, 15513, 15510>, 0,
    <15927, 15510, 15926>, 0,
    <15929, 15920, 15916>, 0,
    <15929, 15916, 15926>, 0,
    <15929, 15926, 15510>, 0,
    <15929, 15510, 15520>, 0,
    <15929, 15520, 15426>, 0,
    <15929, 15426, 15928>, 0,
    <15929, 15928, 15917>, 0,
    <15929, 15917, 15920>, 0,
    <15938, 15937, 15930>, 0,
    <15938, 15930, 15934>, 0,
    <15938, 15934, 15931>, 0,
    <15938, 15931, 15935>, 0,
    <15938, 15935, 15932>, 0,
    <15938, 15932, 15936>, 0,
    <15938, 15936, 15933>, 0,
    <15938, 15933, 15937>, 0,
    <15941, 15940, 15930>, 0,
    <15941, 15930, 15937>, 0,
    <15941, 15937, 15933>, 0,
    <15941, 15933, 15939>, 0,
    <15941, 15939, 3380>, 0,
    <15941, 3380, 15628>, 0,
    <15941, 15628, 15624>, 0,
    <15941, 15624, 15940>, 0,
    <15943, 15934, 15930>, 0,
    <15943, 15930, 15940>, 0,
    <15943, 15940, 15624>, 0,
    <15943, 15624, 15625>, 0,
    <15943, 15625, 15546>, 0,
    <15943, 15546, 15942>, 0,
    <15943, 15942, 15931>, 0,
    <15943, 15931, 15934>, 0,
    <15949, 15948, 15944>, 0,
    <15949, 15944, 15946>, 0,
    <15949, 15946, 15945>, 0,
    <15949, 15945, 15947>, 0,
    <15949, 15947, 15252>, 0,
    <15949, 15252, 15264>, 0,
    <15949, 15264, 15260>, 0,
    <15949, 15260, 15948>, 0,
    <15953, 15952, 15944>, 0,
    <15953, 15944, 15948>, 0,
    <15953, 15948, 15260>, 0,
    <15953, 15260, 15261>, 0,
    <15953, 15261, 15156>, 0,
    <15953, 15156, 15951>, 0,
    <15953, 15951, 15950>, 0,
    <15953, 15950, 15952>, 0,
    <15957, 15946, 15944>, 0,
    <15957, 15944, 15952>, 0,
    <15957, 15952, 15950>, 0,
    <15957, 15950, 15955>, 0,
    <15957, 15955, 15954>, 0,
    <15957, 15954, 15956>, 0,
    <15957, 15956, 15945>, 0,
    <15957, 15945, 15946>, 0,
    <15961, 15960, 15958>, 0,
    <15961, 15958, 15959>, 0,
    <15961, 15959, 15950>, 0,
    <15961, 15950, 15951>, 0,
    <15961, 15951, 15156>, 0,
    <15961, 15156, 15871>, 0,
    <15961, 15871, 15869>, 0,
    <15961, 15869, 15960>, 0,
    <15965, 15964, 15958>, 0,
    <15965, 15958, 15960>, 0,
    <15965, 15960, 15869>, 0,
    <15965, 15869, 15880>, 0,
    <15965, 15880, 15878>, 0,
    <15965, 15878, 15963>, 0,
    <15965, 15963, 15962>, 0,
    <15965, 15962, 15964>, 0,
    <15967, 15959, 15958>, 0,
    <15967, 15958, 15964>, 0,
    <15967, 15964, 15962>, 0,
    <15967, 15962, 15966>, 0,
    <15967, 15966, 15954>, 0,
    <15967, 15954, 15955>, 0,
    <15967, 15955, 15950>, 0,
    <15967, 15950, 15959>, 0,
    <15976, 15975, 15968>, 0,
    <15976, 15968, 15972>, 0,
    <15976, 15972, 15969>, 0,
    <15976, 15969, 15973>, 0,
    <15976, 15973, 15970>, 0,
    <15976, 15970, 15974>, 0,
    <15976, 15974, 15971>, 0,
    <15976, 15971, 15975>, 0,
    <15979, 15978, 15968>, 0,
    <15979, 15968, 15975>, 0,
    <15979, 15975, 15971>, 0,
    <15979, 15971, 15977>, 0,
    <15979, 15977, 15894>, 0,
    <15979, 15894, 15909>, 0,
    <15979, 15909, 15907>, 0,
    <15979, 15907, 15978>, 0,
    <15981, 15972, 15968>, 0,
    <15981, 15968, 15978>, 0,
    <15981, 15978, 15907>, 0,
    <15981, 15907, 15914>, 0,
    <15981, 15914, 15124>, 0,
    <15981, 15124, 15980>, 0,
    <15981, 15980, 15969>, 0,
    <15981, 15969, 15972>, 0,
    <15987, 15986, 15982>, 0,
    <15987, 15982, 15984>, 0,
    <15987, 15984, 15983>, 0,
    <15987, 15983, 15985>, 0,
    <15987, 15985, 15970>, 0,
    <15987, 15970, 15973>, 0,
    <15987, 15973, 15969>, 0,
    <15987, 15969, 15986>, 0,
    <15989, 15988, 15982>, 0,
    <15989, 15982, 15986>, 0,
    <15989, 15986, 15969>, 0,
    <15989, 15969, 15980>, 0,
    <15989, 15980, 15124>, 0,
    <15989, 15124, 15179>, 0,
    <15989, 15179, 15173>, 0,
    <15989, 15173, 15988>, 0,
    <15991, 15984, 15982>, 0,
    <15991, 15982, 15988>, 0,
    <15991, 15988, 15173>, 0,
    <15991, 15173, 15176>, 0,
    <15991, 15176, 15172>, 0,
    <15991, 15172, 15990>, 0,
    <15991, 15990, 15983>, 0,
    <15991, 15983, 15984>, 0,
    <15997, 15996, 15992>, 0,
    <15997, 15992, 15994>, 0,
    <15997, 15994, 15308>, 0,
    <15997, 15308, 15309>, 0,
    <15997, 15309, 15296>, 0,
    <15997, 15296, 15995>, 0,
    <15997, 15995, 15993>, 0,
    <15997, 15993, 15996>, 0,
    <16003, 16002, 15992>, 0,
    <16003, 15992, 15996>, 0,
    <16003, 15996, 15993>, 0,
    <16003, 15993, 16000>, 0,
    <16003, 16000, 15998>, 0,
    <16003, 15998, 16001>, 0,
    <16003, 16001, 15999>, 0,
    <16003, 15999, 16002>, 0,
    <16005, 15994, 15992>, 0,
    <16005, 15992, 16002>, 0,
    <16005, 16002, 15999>, 0,
    <16005, 15999, 16004>, 0,
    <16005, 16004, 15200>, 0,
    <16005, 15200, 15312>, 0,
    <16005, 15312, 15308>, 0,
    <16005, 15308, 15994>, 0,
    <16009, 16008, 16006>, 0,
    <16009, 16006, 16007>, 0,
    <16009, 16007, 15821>, 0,
    <16009, 15821, 15823>, 0,
    <16009, 15823, 15200>, 0,
    <16009, 15200, 16004>, 0,
    <16009, 16004, 15999>, 0,
    <16009, 15999, 16008>, 0,
    <16013, 16012, 16006>, 0,
    <16013, 16006, 16008>, 0,
    <16013, 16008, 15999>, 0,
    <16013, 15999, 16001>, 0,
    <16013, 16001, 15998>, 0,
    <16013, 15998, 16011>, 0,
    <16013, 16011, 16010>, 0,
    <16013, 16010, 16012>, 0,
    <16015, 16007, 16006>, 0,
    <16015, 16006, 16012>, 0,
    <16015, 16012, 16010>, 0,
    <16015, 16010, 16014>, 0,
    <16015, 16014, 15826>, 0,
    <16015, 15826, 15828>, 0,
    <16015, 15828, 15821>, 0,
    <16015, 15821, 16007>, 0,
    <16024, 16023, 16016>, 0,
    <16024, 16016, 16020>, 0,
    <16024, 16020, 16017>, 0,
    <16024, 16017, 16021>, 0,
    <16024, 16021, 16018>, 0,
    <16024, 16018, 16022>, 0,
    <16024, 16022, 16019>, 0,
    <16024, 16019, 16023>, 0,
    <16027, 16026, 16016>, 0,
    <16027, 16016, 16023>, 0,
    <16027, 16023, 16019>, 0,
    <16027, 16019, 16025>, 0,
    <16027, 16025, 15076>, 0,
    <16027, 15076, 15864>, 0,
    <16027, 15864, 15859>, 0,
    <16027, 15859, 16026>, 0,
    <16029, 16020, 16016>, 0,
    <16029, 16016, 16026>, 0,
    <16029, 16026, 15859>, 0,
    <16029, 15859, 15861>, 0,
    <16029, 15861, 15846>, 0,
    <16029, 15846, 16028>, 0,
    <16029, 16028, 16017>, 0,
    <16029, 16017, 16020>, 0,
    <16035, 16034, 16030>, 0,
    <16035, 16030, 16032>, 0,
    <16035, 16032, 16019>, 0,
    <16035, 16019, 16022>, 0,
    <16035, 16022, 16018>, 0,
    <16035, 16018, 16033>, 0,
    <16035, 16033, 16031>, 0,
    <16035, 16031, 16034>, 0,
    <16038, 16037, 16030>, 0,
    <16038, 16030, 16034>, 0,
    <16038, 16034, 16031>, 0,
    <16038, 16031, 16036>, 0,
    <16038, 16036, 15220>, 0,
    <16038, 15220, 15223>, 0,
    <16038, 15223, 15219>, 0,
    <16038, 15219, 16037>, 0,
    <16039, 16032, 16030>, 0,
    <16039, 16030, 16037>, 0,
    <16039, 16037, 15219>, 0,
    <16039, 15219, 15230>, 0,
    <16039, 15230, 15076>, 0,
    <16039, 15076, 16025>, 0,
    <16039, 16025, 16019>, 0,
    <16039, 16019, 16032>, 0,
    <16048, 16047, 16040>, 0,
    <16048, 16040, 16044>, 0,
    <16048, 16044, 16041>, 0,
    <16048, 16041, 16045>, 0,
    <16048, 16045, 16042>, 0,
    <16048, 16042, 16046>, 0,
    <16048, 16046, 16043>, 0,
    <16048, 16043, 16047>, 0,
    <16051, 16050, 16040>, 0,
    <16051, 16040, 16047>, 0,
    <16051, 16047, 16043>, 0,
    <16051, 16043, 16049>, 0,
    <16051, 16049, 15584>, 0,
    <16051, 15584, 15642>, 0,
    <16051, 15642, 15637>, 0,
    <16051, 15637, 16050>, 0,
    <16053, 16044, 16040>, 0,
    <16053, 16040, 16050>, 0,
    <16053, 16050, 15637>, 0,
    <16053, 15637, 15639>, 0,
    <16053, 15639, 3394>, 0,
    <16053, 3394, 16052>, 0,
    <16053, 16052, 16041>, 0,
    <16053, 16041, 16044>, 0,
    <16059, 16058, 16054>, 0,
    <16059, 16054, 16056>, 0,
    <16059, 16056, 16055>, 0,
    <16059, 16055, 16057>, 0,
    <16059, 16057, 15348>, 0,
    <16059, 15348, 15360>, 0,
    <16059, 15360, 15356>, 0,
    <16059, 15356, 16058>, 0,
    <16063, 16062, 16054>, 0,
    <16063, 16054, 16058>, 0,
    <16063, 16058, 15356>, 0,
    <16063, 15356, 15357>, 0,
    <16063, 15357, 15252>, 0,
    <16063, 15252, 16061>, 0,
    <16063, 16061, 16060>, 0,
    <16063, 16060, 16062>, 0,
    <16067, 16056, 16054>, 0,
    <16067, 16054, 16062>, 0,
    <16067, 16062, 16060>, 0,
    <16067, 16060, 16065>, 0,
    <16067, 16065, 16064>, 0,
    <16067, 16064, 16066>, 0,
    <16067, 16066, 16055>, 0,
    <16067, 16055, 16056>, 0,
    <16071, 16070, 16068>, 0,
    <16071, 16068, 16069>, 0,
    <16071, 16069, 16060>, 0,
    <16071, 16060, 16061>, 0,
    <16071, 16061, 15252>, 0,
    <16071, 15252, 15947>, 0,
    <16071, 15947, 15945>, 0,
    <16071, 15945, 16070>, 0,
    <16075, 16074, 16068>, 0,
    <16075, 16068, 16070>, 0,
    <16075, 16070, 15945>, 0,
    <16075, 15945, 15956>, 0,
    <16075, 15956, 15954>, 0,
    <16075, 15954, 16073>, 0,
    <16075, 16073, 16072>, 0,
    <16075, 16072, 16074>, 0,
    <16077, 16069, 16068>, 0,
    <16077, 16068, 16074>, 0,
    <16077, 16074, 16072>, 0,
    <16077, 16072, 16076>, 0,
    <16077, 16076, 16064>, 0,
    <16077, 16064, 16065>, 0,
    <16077, 16065, 16060>, 0,
    <16077, 16060, 16069>, 0,
    <16086, 16085, 16078>, 0,
    <16086, 16078, 16082>, 0,
    <16086, 16082, 16079>, 0,
    <16086, 16079, 16083>, 0,
    <16086, 16083, 16080>, 0,
    <16086, 16080, 16084>, 0,
    <16086, 16084, 16081>, 0,
    <16086, 16081, 16085>, 0,
    <16089, 16088, 16078>, 0,
    <16089, 16078, 16085>, 0,
    <16089, 16085, 16081>, 0,
    <16089, 16081, 16087>, 0,
    <16089, 16087, 15970>, 0,
    <16089, 15970, 15985>, 0,
    <16089, 15985, 15983>, 0,
    <16089, 15983, 16088>, 0,
    <16091, 16082, 16078>, 0,
    <16091, 16078, 16088>, 0,
    <16091, 16088, 15983>, 0,
    <16091, 15983, 15990>, 0,
    <16091, 15990, 15172>, 0,
    <16091, 15172, 16090>, 0,
    <16091, 16090, 16079>, 0,
    <16091, 16079, 16082>, 0,
    <16097, 16096, 16092>, 0,
    <16097, 16092, 16094>, 0,
    <16097, 16094, 16093>, 0,
    <16097, 16093, 16095>, 0,
    <16097, 16095, 16080>, 0,
    <16097, 16080, 16083>, 0,
    <16097, 16083, 16079>, 0,
    <16097, 16079, 16096>, 0,
    <16099, 16098, 16092>, 0,
    <16099, 16092, 16096>, 0,
    <16099, 16096, 16079>, 0,
    <16099, 16079, 16090>, 0,
    <16099, 16090, 15172>, 0,
    <16099, 15172, 15275>, 0,
    <16099, 15275, 15269>, 0,
    <16099, 15269, 16098>, 0,
    <16101, 16094, 16092>, 0,
    <16101, 16092, 16098>, 0,
    <16101, 16098, 15269>, 0,
    <16101, 15269, 15272>, 0,
    <16101, 15272, 15268>, 0,
    <16101, 15268, 16100>, 0,
    <16101, 16100, 16093>, 0,
    <16101, 16093, 16094>, 0,
    <16107, 16106, 16102>, 0,
    <16107, 16102, 16104>, 0,
    <16107, 16104, 15418>, 0,
    <16107, 15418, 15419>, 0,
    <16107, 15419, 15400>, 0,
    <16107, 15400, 16105>, 0,
    <16107, 16105, 16103>, 0,
    <16107, 16103, 16106>, 0,
    <16113, 16112, 16102>, 0,
    <16113, 16102, 16106>, 0,
    <16113, 16106, 16103>, 0,
    <16113, 16103, 16110>, 0,
    <16113, 16110, 16108>, 0,
    <16113, 16108, 16111>, 0,
    <16113, 16111, 16109>, 0,
    <16113, 16109, 16112>, 0,
    <16115, 16104, 16102>, 0,
    <16115, 16102, 16112>, 0,
    <16115, 16112, 16109>, 0,
    <16115, 16109, 16114>, 0,
    <16115, 16114, 15296>, 0,
    <16115, 15296, 15422>, 0,
    <16115, 15422, 15418>, 0,
    <16115, 15418, 16104>, 0,
    <16119, 16118, 16116>, 0,
    <16119, 16116, 16117>, 0,
    <16119, 16117, 15993>, 0,
    <16119, 15993, 15995>, 0,
    <16119, 15995, 15296>, 0,
    <16119, 15296, 16114>, 0,
    <16119, 16114, 16109>, 0,
    <16119, 16109, 16118>, 0,
    <16123, 16122, 16116>, 0,
    <16123, 16116, 16118>, 0,
    <16123, 16118, 16109>, 0,
    <16123, 16109, 16111>, 0,
    <16123, 16111, 16108>, 0,
    <16123, 16108, 16121>, 0,
    <16123, 16121, 16120>, 0,
    <16123, 16120, 16122>, 0,
    <16125, 16117, 16116>, 0,
    <16125, 16116, 16122>, 0,
    <16125, 16122, 16120>, 0,
    <16125, 16120, 16124>, 0,
    <16125, 16124, 15998>, 0,
    <16125, 15998, 16000>, 0,
    <16125, 16000, 15993>, 0,
    <16125, 15993, 16117>, 0,
    <16134, 16133, 16126>, 0,
    <16134, 16126, 16130>, 0,
    <16134, 16130, 16127>, 0,
    <16134, 16127, 16131>, 0,
    <16134, 16131, 16128>, 0,
    <16134, 16128, 16132>, 0,
    <16134, 16132, 16129>, 0,
    <16134, 16129, 16133>, 0,
    <16137, 16136, 16126>, 0,
    <16137, 16126, 16133>, 0,
    <16137, 16133, 16129>, 0,
    <16137, 16129, 16135>, 0,
    <16137, 16135, 15220>, 0,
    <16137, 15220, 16036>, 0,
    <16137, 16036, 16031>, 0,
    <16137, 16031, 16136>, 0,
    <16139, 16130, 16126>, 0,
    <16139, 16126, 16136>, 0,
    <16139, 16136, 16031>, 0,
    <16139, 16031, 16033>, 0,
    <16139, 16033, 16018>, 0,
    <16139, 16018, 16138>, 0,
    <16139, 16138, 16127>, 0,
    <16139, 16127, 16130>, 0,
    <16145, 16144, 16140>, 0,
    <16145, 16140, 16142>, 0,
    <16145, 16142, 16129>, 0,
    <16145, 16129, 16132>, 0,
    <16145, 16132, 16128>, 0,
    <16145, 16128, 16143>, 0,
    <16145, 16143, 16141>, 0,
    <16145, 16141, 16144>, 0,
    <16148, 16147, 16140>, 0,
    <16148, 16140, 16144>, 0,
    <16148, 16144, 16141>, 0,
    <16148, 16141, 16146>, 0,
    <16148, 16146, 15316>, 0,
    <16148, 15316, 15319>, 0,
    <16148, 15319, 15315>, 0,
    <16148, 15315, 16147>, 0,
    <16149, 16142, 16140>, 0,
    <16149, 16140, 16147>, 0,
    <16149, 16147, 15315>, 0,
    <16149, 15315, 15326>, 0,
    <16149, 15326, 15220>, 0,
    <16149, 15220, 16135>, 0,
    <16149, 16135, 16129>, 0,
    <16149, 16129, 16142>, 0,
    <16155, 16154, 16150>, 0,
    <16155, 16150, 16152>, 0,
    <16155, 16152, 16151>, 0,
    <16155, 16151, 16153>, 0,
    <16155, 16153, 15458>, 0,
    <16155, 15458, 15470>, 0,
    <16155, 15470, 15466>, 0,
    <16155, 15466, 16154>, 0,
    <16159, 16158, 16150>, 0,
    <16159, 16150, 16154>, 0,
    <16159, 16154, 15466>, 0,
    <16159, 15466, 15467>, 0,
    <16159, 15467, 15348>, 0,
    <16159, 15348, 16157>, 0,
    <16159, 16157, 16156>, 0,
    <16159, 16156, 16158>, 0,
    <16163, 16152, 16150>, 0,
    <16163, 16150, 16158>, 0,
    <16163, 16158, 16156>, 0,
    <16163, 16156, 16161>, 0,
    <16163, 16161, 16160>, 0,
    <16163, 16160, 16162>, 0,
    <16163, 16162, 16151>, 0,
    <16163, 16151, 16152>, 0,
    <16167, 16166, 16164>, 0,
    <16167, 16164, 16165>, 0,
    <16167, 16165, 16156>, 0,
    <16167, 16156, 16157>, 0,
    <16167, 16157, 15348>, 0,
    <16167, 15348, 16057>, 0,
    <16167, 16057, 16055>, 0,
    <16167, 16055, 16166>, 0,
    <16171, 16170, 16164>, 0,
    <16171, 16164, 16166>, 0,
    <16171, 16166, 16055>, 0,
    <16171, 16055, 16066>, 0,
    <16171, 16066, 16064>, 0,
    <16171, 16064, 16169>, 0,
    <16171, 16169, 16168>, 0,
    <16171, 16168, 16170>, 0,
    <16173, 16165, 16164>, 0,
    <16173, 16164, 16170>, 0,
    <16173, 16170, 16168>, 0,
    <16173, 16168, 16172>, 0,
    <16173, 16172, 16160>, 0,
    <16173, 16160, 16161>, 0,
    <16173, 16161, 16156>, 0,
    <16173, 16156, 16165>, 0,
    <16182, 16181, 16174>, 0,
    <16182, 16174, 16178>, 0,
    <16182, 16178, 16175>, 0,
    <16182, 16175, 16179>, 0,
    <16182, 16179, 16176>, 0,
    <16182, 16176, 16180>, 0,
    <16182, 16180, 16177>, 0,
    <16182, 16177, 16181>, 0,
    <16185, 16184, 16174>, 0,
    <16185, 16174, 16181>, 0,
    <16185, 16181, 16177>, 0,
    <16185, 16177, 16183>, 0,
    <16185, 16183, 16080>, 0,
    <16185, 16080, 16095>, 0,
    <16185, 16095, 16093>, 0,
    <16185, 16093, 16184>, 0,
    <16187, 16178, 16174>, 0,
    <16187, 16174, 16184>, 0,
    <16187, 16184, 16093>, 0,
    <16187, 16093, 16100>, 0,
    <16187, 16100, 15268>, 0,
    <16187, 15268, 16186>, 0,
    <16187, 16186, 16175>, 0,
    <16187, 16175, 16178>, 0,
    <16193, 16192, 16188>, 0,
    <16193, 16188, 16190>, 0,
    <16193, 16190, 16189>, 0,
    <16193, 16189, 16191>, 0,
    <16193, 16191, 16176>, 0,
    <16193, 16176, 16179>, 0,
    <16193, 16179, 16175>, 0,
    <16193, 16175, 16192>, 0,
    <16195, 16194, 16188>, 0,
    <16195, 16188, 16192>, 0,
    <16195, 16192, 16175>, 0,
    <16195, 16175, 16186>, 0,
    <16195, 16186, 15268>, 0,
    <16195, 15268, 15371>, 0,
    <16195, 15371, 15365>, 0,
    <16195, 15365, 16194>, 0,
    <16197, 16190, 16188>, 0,
    <16197, 16188, 16194>, 0,
    <16197, 16194, 15365>, 0,
    <16197, 15365, 15368>, 0,
    <16197, 15368, 15364>, 0,
    <16197, 15364, 16196>, 0,
    <16197, 16196, 16189>, 0,
    <16197, 16189, 16190>, 0,
    <16203, 16202, 16198>, 0,
    <16203, 16198, 16200>, 0,
    <16203, 16200, 15502>, 0,
    <16203, 15502, 15504>, 0,
    <16203, 15504, 3370>, 0,
    <16203, 3370, 16201>, 0,
    <16203, 16201, 16199>, 0,
    <16203, 16199, 16202>, 0,
    <16209, 16208, 16198>, 0,
    <16209, 16198, 16202>, 0,
    <16209, 16202, 16199>, 0,
    <16209, 16199, 16206>, 0,
    <16209, 16206, 16204>, 0,
    <16209, 16204, 16207>, 0,
    <16209, 16207, 16205>, 0,
    <16209, 16205, 16208>, 0,
    <16211, 16200, 16198>, 0,
    <16211, 16198, 16208>, 0,
    <16211, 16208, 16205>, 0,
    <16211, 16205, 16210>, 0,
    <16211, 16210, 15400>, 0,
    <16211, 15400, 15507>, 0,
    <16211, 15507, 15502>, 0,
    <16211, 15502, 16200>, 0,
    <16217, 16216, 16212>, 0,
    <16217, 16212, 16214>, 0,
    <16217, 16214, 16199>, 0,
    <16217, 16199, 16201>, 0,
    <16217, 16201, 3370>, 0,
    <16217, 3370, 16215>, 0,
    <16217, 16215, 16213>, 0,
    <16217, 16213, 16216>, 0,
    <16223, 16222, 16212>, 0,
    <16223, 16212, 16216>, 0,
    <16223, 16216, 16213>, 0,
    <16223, 16213, 16220>, 0,
    <16223, 16220, 16218>, 0,
    <16223, 16218, 16221>, 0,
    <16223, 16221, 16219>, 0,
    <16223, 16219, 16222>, 0,
    <16225, 16214, 16212>, 0,
    <16225, 16212, 16222>, 0,
    <16225, 16222, 16219>, 0,
    <16225, 16219, 16224>, 0,
    <16225, 16224, 16204>, 0,
    <16225, 16204, 16206>, 0,
    <16225, 16206, 16199>, 0,
    <16225, 16199, 16214>, 0,
    <16229, 16228, 16226>, 0,
    <16229, 16226, 16227>, 0,
    <16229, 16227, 16103>, 0,
    <16229, 16103, 16105>, 0,
    <16229, 16105, 15400>, 0,
    <16229, 15400, 16210>, 0,
    <16229, 16210, 16205>, 0,
    <16229, 16205, 16228>, 0,
    <16233, 16232, 16226>, 0,
    <16233, 16226, 16228>, 0,
    <16233, 16228, 16205>, 0,
    <16233, 16205, 16207>, 0,
    <16233, 16207, 16204>, 0,
    <16233, 16204, 16231>, 0,
    <16233, 16231, 16230>, 0,
    <16233, 16230, 16232>, 0,
    <16235, 16227, 16226>, 0,
    <16235, 16226, 16232>, 0,
    <16235, 16232, 16230>, 0,
    <16235, 16230, 16234>, 0,
    <16235, 16234, 16108>, 0,
    <16235, 16108, 16110>, 0,
    <16235, 16110, 16103>, 0,
    <16235, 16103, 16227>, 0,
    <16244, 16243, 16236>, 0,
    <16244, 16236, 16240>, 0,
    <16244, 16240, 16237>, 0,
    <16244, 16237, 16241>, 0,
    <16244, 16241, 16238>, 0,
    <16244, 16238, 16242>, 0,
    <16244, 16242, 16239>, 0,
    <16244, 16239, 16243>, 0,
    <16247, 16246, 16236>, 0,
    <16247, 16236, 16243>, 0,
    <16247, 16243, 16239>, 0,
    <16247, 16239, 16245>, 0,
    <16247, 16245, 15316>, 0,
    <16247, 15316, 16146>, 0,
    <16247, 16146, 16141>, 0,
    <16247, 16141, 16246>, 0,
    <16249, 16240, 16236>, 0,
    <16249, 16236, 16246>, 0,
    <16249, 16246, 16141>, 0,
    <16249, 16141, 16143>, 0,
    <16249, 16143, 16128>, 0,
    <16249, 16128, 16248>, 0,
    <16249, 16248, 16237>, 0,
    <16249, 16237, 16240>, 0,
    <16255, 16254, 16250>, 0,
    <16255, 16250, 16252>, 0,
    <16255, 16252, 16239>, 0,
    <16255, 16239, 16242>, 0,
    <16255, 16242, 16238>, 0,
    <16255, 16238, 16253>, 0,
    <16255, 16253, 16251>, 0,
    <16255, 16251, 16254>, 0,
    <16258, 16257, 16250>, 0,
    <16258, 16250, 16254>, 0,
    <16258, 16254, 16251>, 0,
    <16258, 16251, 16256>, 0,
    <16258, 16256, 15426>, 0,
    <16258, 15426, 15429>, 0,
    <16258, 15429, 15425>, 0,
    <16258, 15425, 16257>, 0,
    <16259, 16252, 16250>, 0,
    <16259, 16250, 16257>, 0,
    <16259, 16257, 15425>, 0,
    <16259, 15425, 15436>, 0,
    <16259, 15436, 15316>, 0,
    <16259, 15316, 16245>, 0,
    <16259, 16245, 16239>, 0,
    <16259, 16239, 16252>, 0,
    <16265, 16264, 16260>, 0,
    <16265, 16260, 16262>, 0,
    <16265, 16262, 16261>, 0,
    <16265, 16261, 16263>, 0,
    <16265, 16263, 15546>, 0,
    <16265, 15546, 15568>, 0,
    <16265, 15568, 15564>, 0,
    <16265, 15564, 16264>, 0,
    <16269, 16268, 16260>, 0,
    <16269, 16260, 16264>, 0,
    <16269, 16264, 15564>, 0,
    <16269, 15564, 15565>, 0,
    <16269, 15565, 15458>, 0,
    <16269, 15458, 16267>, 0,
    <16269, 16267, 16266>, 0,
    <16269, 16266, 16268>, 0,
    <16273, 16262, 16260>, 0,
    <16273, 16260, 16268>, 0,
    <16273, 16268, 16266>, 0,
    <16273, 16266, 16271>, 0,
    <16273, 16271, 16270>, 0,
    <16273, 16270, 16272>, 0,
    <16273, 16272, 16261>, 0,
    <16273, 16261, 16262>, 0,
    <16277, 16276, 16274>, 0,
    <16277, 16274, 16275>, 0,
    <16277, 16275, 16266>, 0,
    <16277, 16266, 16267>, 0,
    <16277, 16267, 15458>, 0,
    <16277, 15458, 16153>, 0,
    <16277, 16153, 16151>, 0,
    <16277, 16151, 16276>, 0,
    <16281, 16280, 16274>, 0,
    <16281, 16274, 16276>, 0,
    <16281, 16276, 16151>, 0,
    <16281, 16151, 16162>, 0,
    <16281, 16162, 16160>, 0,
    <16281, 16160, 16279>, 0,
    <16281, 16279, 16278>, 0,
    <16281, 16278, 16280>, 0,
    <16283, 16275, 16274>, 0,
    <16283, 16274, 16280>, 0,
    <16283, 16280, 16278>, 0,
    <16283, 16278, 16282>, 0,
    <16283, 16282, 16270>, 0,
    <16283, 16270, 16271>, 0,
    <16283, 16271, 16266>, 0,
    <16283, 16266, 16275>, 0,
    <16292, 16291, 16284>, 0,
    <16292, 16284, 16288>, 0,
    <16292, 16288, 16285>, 0,
    <16292, 16285, 16289>, 0,
    <16292, 16289, 16286>, 0,
    <16292, 16286, 16290>, 0,
    <16292, 16290, 16287>, 0,
    <16292, 16287, 16291>, 0,
    <16295, 16294, 16284>, 0,
    <16295, 16284, 16291>, 0,
    <16295, 16291, 16287>, 0,
    <16295, 16287, 16293>, 0,
    <16295, 16293, 16176>, 0,
    <16295, 16176, 16191>, 0,
    <16295, 16191, 16189>, 0,
    <16295, 16189, 16294>, 0,
    <16297, 16288, 16284>, 0,
    <16297, 16284, 16294>, 0,
    <16297, 16294, 16189>, 0,
    <16297, 16189, 16196>, 0,
    <16297, 16196, 15364>, 0,
    <16297, 15364, 16296>, 0,
    <16297, 16296, 16285>, 0,
    <16297, 16285, 16288>, 0,
    <16303, 16302, 16298>, 0,
    <16303, 16298, 16300>, 0,
    <16303, 16300, 16299>, 0,
    <16303, 16299, 16301>, 0,
    <16303, 16301, 16286>, 0,
    <16303, 16286, 16289>, 0,
    <16303, 16289, 16285>, 0,
    <16303, 16285, 16302>, 0,
    <16305, 16304, 16298>, 0,
    <16305, 16298, 16302>, 0,
    <16305, 16302, 16285>, 0,
    <16305, 16285, 16296>, 0,
    <16305, 16296, 15364>, 0,
    <16305, 15364, 15481>, 0,
    <16305, 15481, 15475>, 0,
    <16305, 15475, 16304>, 0,
    <16307, 16300, 16298>, 0,
    <16307, 16298, 16304>, 0,
    <16307, 16304, 15475>, 0,
    <16307, 15475, 15478>, 0,
    <16307, 15478, 15474>, 0,
    <16307, 15474, 16306>, 0,
    <16307, 16306, 16299>, 0,
    <16307, 16299, 16300>, 0,
    <16315, 16314, 16308>, 0,
    <16315, 16308, 16311>, 0,
    <16315, 16311, 16309>, 0,
    <16315, 16309, 16312>, 0,
    <16315, 16312, 3717>, 0,
    <16315, 3717, 16313>, 0,
    <16315, 16313, 16310>, 0,
    <16315, 16310, 16314>, 0,
    <16318, 16317, 16308>, 0,
    <16318, 16308, 16314>, 0,
    <16318, 16314, 16310>, 0,
    <16318, 16310, 16316>, 0,
    <16318, 16316, 15918>, 0,
    <16318, 15918, 15921>, 0,
    <16318, 15921, 15917>, 0,
    <16318, 15917, 16317>, 0,
    <16320, 16311, 16308>, 0,
    <16320, 16308, 16317>, 0,
    <16320, 16317, 15917>, 0,
    <16320, 15917, 15928>, 0,
    <16320, 15928, 15426>, 0,
    <16320, 15426, 16319>, 0,
    <16320, 16319, 16309>, 0,
    <16320, 16309, 16311>, 0,
    <16326, 16325, 16321>, 0,
    <16326, 16321, 16323>, 0,
    <16326, 16323, 16219>, 0,
    <16326, 16219, 16221>, 0,
    <16326, 16221, 16218>, 0,
    <16326, 16218, 16324>, 0,
    <16326, 16324, 16322>, 0,
    <16326, 16322, 16325>, 0,
    <16331, 16330, 16321>, 0,
    <16331, 16321, 16325>, 0,
    <16331, 16325, 16322>, 0,
    <16331, 16322, 16328>, 0,
    <16331, 16328, 3681>, 0,
    <16331, 3681, 16329>, 0,
    <16331, 16329, 16327>, 0,
    <16331, 16327, 16330>, 0,
    <16333, 16323, 16321>, 0,
    <16333, 16321, 16330>, 0,
    <16333, 16330, 16327>, 0,
    <16333, 16327, 16332>, 0,
    <16333, 16332, 16204>, 0,
    <16333, 16204, 16224>, 0,
    <16333, 16224, 16219>, 0,
    <16333, 16219, 16323>, 0,
    <16339, 16338, 16334>, 0,
    <16339, 16334, 16336>, 0,
    <16339, 16336, 16335>, 0,
    <16339, 16335, 16337>, 0,
    <16339, 16337, 3717>, 0,
    <16339, 3717, 16312>, 0,
    <16339, 16312, 16309>, 0,
    <16339, 16309, 16338>, 0,
    <16341, 16340, 16334>, 0,
    <16341, 16334, 16338>, 0,
    <16341, 16338, 16309>, 0,
    <16341, 16309, 16319>, 0,
    <16341, 16319, 15426>, 0,
    <16341, 15426, 16256>, 0,
    <16341, 16256, 16251>, 0,
    <16341, 16251, 16340>, 0,
    <16343, 16336, 16334>, 0,
    <16343, 16334, 16340>, 0,
    <16343, 16340, 16251>, 0,
    <16343, 16251, 16253>, 0,
    <16343, 16253, 16238>, 0,
    <16343, 16238, 16342>, 0,
    <16343, 16342, 16335>, 0,
    <16343, 16335, 16336>, 0,
    <16352, 16351, 16344>, 0,
    <16352, 16344, 16348>, 0,
    <16352, 16348, 16345>, 0,
    <16352, 16345, 16349>, 0,
    <16352, 16349, 16346>, 0,
    <16352, 16346, 16350>, 0,
    <16352, 16350, 16347>, 0,
    <16352, 16347, 16351>, 0,
    <16357, 16356, 16344>, 0,
    <16357, 16344, 16351>, 0,
    <16357, 16351, 16347>, 0,
    <16357, 16347, 16354>, 0,
    <16357, 16354, 15932>, 0,
    <16357, 15932, 16355>, 0,
    <16357, 16355, 16353>, 0,
    <16357, 16353, 16356>, 0,
    <16361, 16348, 16344>, 0,
    <16361, 16344, 16356>, 0,
    <16361, 16356, 16353>, 0,
    <16361, 16353, 16359>, 0,
    <16361, 16359, 16358>, 0,
    <16361, 16358, 16360>, 0,
    <16361, 16360, 16345>, 0,
    <16361, 16345, 16348>, 0,
    <16365, 16364, 16362>, 0,
    <16365, 16362, 16363>, 0,
    <16365, 16363, 16353>, 0,
    <16365, 16353, 16355>, 0,
    <16365, 16355, 15932>, 0,
    <16365, 15932, 15935>, 0,
    <16365, 15935, 15931>, 0,
    <16365, 15931, 16364>, 0,
    <16369, 16368, 16362>, 0,
    <16369, 16362, 16364>, 0,
    <16369, 16364, 15931>, 0,
    <16369, 15931, 15942>, 0,
    <16369, 15942, 15546>, 0,
    <16369, 15546, 16367>, 0,
    <16369, 16367, 16366>, 0,
    <16369, 16366, 16368>, 0,
    <16371, 16363, 16362>, 0,
    <16371, 16362, 16368>, 0,
    <16371, 16368, 16366>, 0,
    <16371, 16366, 16370>, 0,
    <16371, 16370, 16358>, 0,
    <16371, 16358, 16359>, 0,
    <16371, 16359, 16353>, 0,
    <16371, 16353, 16363>, 0,
    <16375, 16374, 16372>, 0,
    <16375, 16372, 16373>, 0,
    <16375, 16373, 16366>, 0,
    <16375, 16366, 16367>, 0,
    <16375, 16367, 15546>, 0,
    <16375, 15546, 16263>, 0,
    <16375, 16263, 16261>, 0,
    <16375, 16261, 16374>, 0,
    <16379, 16378, 16372>, 0,
    <16379, 16372, 16374>, 0,
    <16379, 16374, 16261>, 0,
    <16379, 16261, 16272>, 0,
    <16379, 16272, 16270>, 0,
    <16379, 16270, 16377>, 0,
    <16379, 16377, 16376>, 0,
    <16379, 16376, 16378>, 0,
    <16381, 16373, 16372>, 0,
    <16381, 16372, 16378>, 0,
    <16381, 16378, 16376>, 0,
    <16381, 16376, 16380>, 0,
    <16381, 16380, 16358>, 0,
    <16381, 16358, 16370>, 0,
    <16381, 16370, 16366>, 0,
    <16381, 16366, 16373>, 0,
    <16389, 16388, 16382>, 0,
    <16389, 16382, 16385>, 0,
    <16389, 16385, 16383>, 0,
    <16389, 16383, 16386>, 0,
    <16389, 16386, 16042>, 0,
    <16389, 16042, 16387>, 0,
    <16389, 16387, 16384>, 0,
    <16389, 16384, 16388>, 0,
    <16395, 16394, 16382>, 0,
    <16395, 16382, 16388>, 0,
    <16395, 16388, 16384>, 0,
    <16395, 16384, 16392>, 0,
    <16395, 16392, 16390>, 0,
    <16395, 16390, 16393>, 0,
    <16395, 16393, 16391>, 0,
    <16395, 16391, 16394>, 0,
    <16399, 16385, 16382>, 0,
    <16399, 16382, 16394>, 0,
    <16399, 16394, 16391>, 0,
    <16399, 16391, 16397>, 0,
    <16399, 16397, 16396>, 0,
    <16399, 16396, 16398>, 0,
    <16399, 16398, 16383>, 0,
    <16399, 16383, 16385>, 0,
    <16407, 16406, 16400>, 0,
    <16407, 16400, 16403>, 0,
    <16407, 16403, 16401>, 0,
    <16407, 16401, 16404>, 0,
    <16407, 16404, 16396>, 0,
    <16407, 16396, 16405>, 0,
    <16407, 16405, 16402>, 0,
    <16407, 16402, 16406>, 0,
    <16410, 16409, 16400>, 0,
    <16410, 16400, 16406>, 0,
    <16410, 16406, 16402>, 0,
    <16410, 16402, 16408>, 0,
    <16410, 16408, 16286>, 0,
    <16410, 16286, 16301>, 0,
    <16410, 16301, 16299>, 0,
    <16410, 16299, 16409>, 0,
    <16412, 16403, 16400>, 0,
    <16412, 16400, 16409>, 0,
    <16412, 16409, 16299>, 0,
    <16412, 16299, 16306>, 0,
    <16412, 16306, 15474>, 0,
    <16412, 15474, 16411>, 0,
    <16412, 16411, 16401>, 0,
    <16412, 16401, 16403>, 0,
    <16416, 16415, 16413>, 0,
    <16416, 16413, 16414>, 0,
    <16416, 16414, 16043>, 0,
    <16416, 16043, 16046>, 0,
    <16416, 16046, 16042>, 0,
    <16416, 16042, 16386>, 0,
    <16416, 16386, 16383>, 0,
    <16416, 16383, 16415>, 0,
    <16420, 16419, 16413>, 0,
    <16420, 16413, 16415>, 0,
    <16420, 16415, 16383>, 0,
    <16420, 16383, 16398>, 0,
    <16420, 16398, 16396>, 0,
    <16420, 16396, 16418>, 0,
    <16420, 16418, 16417>, 0,
    <16420, 16417, 16419>, 0,
    <16422, 16414, 16413>, 0,
    <16422, 16413, 16419>, 0,
    <16422, 16419, 16417>, 0,
    <16422, 16417, 16421>, 0,
    <16422, 16421, 15584>, 0,
    <16422, 15584, 16049>, 0,
    <16422, 16049, 16043>, 0,
    <16422, 16043, 16414>, 0,
    <16426, 16425, 16423>, 0,
    <16426, 16423, 16424>, 0,
    <16426, 16424, 16417>, 0,
    <16426, 16417, 16418>, 0,
    <16426, 16418, 16396>, 0,
    <16426, 16396, 16404>, 0,
    <16426, 16404, 16401>, 0,
    <16426, 16401, 16425>, 0,
    <16428, 16427, 16423>, 0,
    <16428, 16423, 16425>, 0,
    <16428, 16425, 16401>, 0,
    <16428, 16401, 16411>, 0,
    <16428, 16411, 15474>, 0,
    <16428, 15474, 15596>, 0,
    <16428, 15596, 15590>, 0,
    <16428, 15590, 16427>, 0,
    <16429, 16424, 16423>, 0,
    <16429, 16423, 16427>, 0,
    <16429, 16427, 15590>, 0,
    <16429, 15590, 15593>, 0,
    <16429, 15593, 15584>, 0,
    <16429, 15584, 16421>, 0,
    <16429, 16421, 16417>, 0,
    <16429, 16417, 16424>, 0,
    <16435, 16434, 16430>, 0,
    <16435, 16430, 16432>, 0,
    <16435, 16432, 15675>, 0,
    <16435, 15675, 15676>, 0,
    <16435, 15676, 15663>, 0,
    <16435, 15663, 16433>, 0,
    <16435, 16433, 16431>, 0,
    <16435, 16431, 16434>, 0,
    <16438, 16437, 16430>, 0,
    <16438, 16430, 16434>, 0,
    <16438, 16434, 16431>, 0,
    <16438, 16431, 16436>, 0,
    <16438, 16436, 3643>, 0,
    <16438, 3643, 3644>, 0,
    <16438, 3644, 3639>, 0,
    <16438, 3639, 16437>, 0,
    <16439, 16432, 16430>, 0,
    <16439, 16430, 16437>, 0,
    <16439, 16437, 3639>, 0,
    <16439, 3639, 3640>, 0,
    <16439, 3640, 3493>, 0,
    <16439, 3493, 15679>, 0,
    <16439, 15679, 15675>, 0,
    <16439, 15675, 16432>, 0,
    <16445, 16444, 16440>, 0,
    <16445, 16440, 16442>, 0,
    <16445, 16442, 15726>, 0,
    <16445, 15726, 15727>, 0,
    <16445, 15727, 15714>, 0,
    <16445, 15714, 16443>, 0,
    <16445, 16443, 16441>, 0,
    <16445, 16441, 16444>, 0,
    <16451, 16450, 16440>, 0,
    <16451, 16440, 16444>, 0,
    <16451, 16444, 16441>, 0,
    <16451, 16441, 16448>, 0,
    <16451, 16448, 16446>, 0,
    <16451, 16446, 16449>, 0,
    <16451, 16449, 16447>, 0,
    <16451, 16447, 16450>, 0,
    <16453, 16442, 16440>, 0,
    <16453, 16440, 16450>, 0,
    <16453, 16450, 16447>, 0,
    <16453, 16447, 16452>, 0,
    <16453, 16452, 15663>, 0,
    <16453, 15663, 15730>, 0,
    <16453, 15730, 15726>, 0,
    <16453, 15726, 16442>, 0,
    <16457, 16456, 16454>, 0,
    <16457, 16454, 16455>, 0,
    <16457, 16455, 16431>, 0,
    <16457, 16431, 16433>, 0,
    <16457, 16433, 15663>, 0,
    <16457, 15663, 16452>, 0,
    <16457, 16452, 16447>, 0,
    <16457, 16447, 16456>, 0,
    <16461, 16460, 16454>, 0,
    <16461, 16454, 16456>, 0,
    <16461, 16456, 16447>, 0,
    <16461, 16447, 16449>, 0,
    <16461, 16449, 16446>, 0,
    <16461, 16446, 16459>, 0,
    <16461, 16459, 16458>, 0,
    <16461, 16458, 16460>, 0,
    <16463, 16455, 16454>, 0,
    <16463, 16454, 16460>, 0,
    <16463, 16460, 16458>, 0,
    <16463, 16458, 16462>, 0,
    <16463, 16462, 3643>, 0,
    <16463, 3643, 16436>, 0,
    <16463, 16436, 16431>, 0,
    <16463, 16431, 16455>, 0,
    <16472, 16471, 16464>, 0,
    <16472, 16464, 16468>, 0,
    <16472, 16468, 16465>, 0,
    <16472, 16465, 16469>, 0,
    <16472, 16469, 16466>, 0,
    <16472, 16466, 16470>, 0,
    <16472, 16470, 16467>, 0,
    <16472, 16467, 16471>, 0,
    <16477, 16476, 16464>, 0,
    <16477, 16464, 16471>, 0,
    <16477, 16471, 16467>, 0,
    <16477, 16467, 16474>, 0,
    <16477, 16474, 3516>, 0,
    <16477, 3516, 16475>, 0,
    <16477, 16475, 16473>, 0,
    <16477, 16473, 16476>, 0,
    <16480, 16468, 16464>, 0,
    <16480, 16464, 16476>, 0,
    <16480, 16476, 16473>, 0,
    <16480, 16473, 16478>, 0,
    <16480, 16478, 3657>, 0,
    <16480, 3657, 16479>, 0,
    <16480, 16479, 16465>, 0,
    <16480, 16465, 16468>, 0,
    <16486, 16485, 16481>, 0,
    <16486, 16481, 16483>, 0,
    <16486, 16483, 16467>, 0,
    <16486, 16467, 16470>, 0,
    <16486, 16470, 16466>, 0,
    <16486, 16466, 16484>, 0,
    <16486, 16484, 16482>, 0,
    <16486, 16482, 16485>, 0,
    <16489, 16488, 16481>, 0,
    <16489, 16481, 16485>, 0,
    <16489, 16485, 16482>, 0,
    <16489, 16482, 16487>, 0,
    <16489, 16487, 15683>, 0,
    <16489, 15683, 15686>, 0,
    <16489, 15686, 15682>, 0,
    <16489, 15682, 16488>, 0,
    <16490, 16483, 16481>, 0,
    <16490, 16481, 16488>, 0,
    <16490, 16488, 15682>, 0,
    <16490, 15682, 15696>, 0,
    <16490, 15696, 3516>, 0,
    <16490, 3516, 16474>, 0,
    <16490, 16474, 16467>, 0,
    <16490, 16467, 16483>, 0,
    <16496, 16495, 16491>, 0,
    <16496, 16491, 16493>, 0,
    <16496, 16493, 16492>, 0,
    <16496, 16492, 16494>, 0,
    <16496, 16494, 16346>, 0,
    <16496, 16346, 16349>, 0,
    <16496, 16349, 16345>, 0,
    <16496, 16345, 16495>, 0,
    <16500, 16499, 16491>, 0,
    <16500, 16491, 16495>, 0,
    <16500, 16495, 16345>, 0,
    <16500, 16345, 16360>, 0,
    <16500, 16360, 16358>, 0,
    <16500, 16358, 16498>, 0,
    <16500, 16498, 16497>, 0,
    <16500, 16497, 16499>, 0,
    <16503, 16493, 16491>, 0,
    <16503, 16491, 16499>, 0,
    <16503, 16499, 16497>, 0,
    <16503, 16497, 16501>, 0,
    <16503, 16501, 3691>, 0,
    <16503, 3691, 16502>, 0,
    <16503, 16502, 16492>, 0,
    <16503, 16492, 16493>, 0,
    <16509, 16508, 16504>, 0,
    <16509, 16504, 16506>, 0,
    <16509, 16506, 16391>, 0,
    <16509, 16391, 16393>, 0,
    <16509, 16393, 16390>, 0,
    <16509, 16390, 16507>, 0,
    <16509, 16507, 16505>, 0,
    <16509, 16505, 16508>, 0,
    <16514, 16513, 16504>, 0,
    <16514, 16504, 16508>, 0,
    <16514, 16508, 16505>, 0,
    <16514, 16505, 16511>, 0,
    <16514, 16511, 3705>, 0,
    <16514, 3705, 16512>, 0,
    <16514, 16512, 16510>, 0,
    <16514, 16510, 16513>, 0,
    <16516, 16506, 16504>, 0,
    <16516, 16504, 16513>, 0,
    <16516, 16513, 16510>, 0,
    <16516, 16510, 16515>, 0,
    <16516, 16515, 16396>, 0,
    <16516, 16396, 16397>, 0,
    <16516, 16397, 16391>, 0,
    <16516, 16391, 16506>, 0,
    <16522, 16521, 16517>, 0,
    <16522, 16517, 16519>, 0,
    <16522, 16519, 15838>, 0,
    <16522, 15838, 15839>, 0,
    <16522, 15839, 15826>, 0,
    <16522, 15826, 16520>, 0,
    <16522, 16520, 16518>, 0,
    <16522, 16518, 16521>, 0,
    <16528, 16527, 16517>, 0,
    <16528, 16517, 16521>, 0,
    <16528, 16521, 16518>, 0,
    <16528, 16518, 16525>, 0,
    <16528, 16525, 16523>, 0,
    <16528, 16523, 16526>, 0,
    <16528, 16526, 16524>, 0,
    <16528, 16524, 16527>, 0,
    <16530, 16519, 16517>, 0,
    <16530, 16517, 16527>, 0,
    <16530, 16527, 16524>, 0,
    <16530, 16524, 16529>, 0,
    <16530, 16529, 15714>, 0,
    <16530, 15714, 15842>, 0,
    <16530, 15842, 15838>, 0,
    <16530, 15838, 16519>, 0,
    <16534, 16533, 16531>, 0,
    <16534, 16531, 16532>, 0,
    <16534, 16532, 16441>, 0,
    <16534, 16441, 16443>, 0,
    <16534, 16443, 15714>, 0,
    <16534, 15714, 16529>, 0,
    <16534, 16529, 16524>, 0,
    <16534, 16524, 16533>, 0,
    <16538, 16537, 16531>, 0,
    <16538, 16531, 16533>, 0,
    <16538, 16533, 16524>, 0,
    <16538, 16524, 16526>, 0,
    <16538, 16526, 16523>, 0,
    <16538, 16523, 16536>, 0,
    <16538, 16536, 16535>, 0,
    <16538, 16535, 16537>, 0,
    <16540, 16532, 16531>, 0,
    <16540, 16531, 16537>, 0,
    <16540, 16537, 16535>, 0,
    <16540, 16535, 16539>, 0,
    <16540, 16539, 16446>, 0,
    <16540, 16446, 16448>, 0,
    <16540, 16448, 16441>, 0,
    <16540, 16441, 16532>, 0,
    <16549, 16548, 16541>, 0,
    <16549, 16541, 16545>, 0,
    <16549, 16545, 16542>, 0,
    <16549, 16542, 16546>, 0,
    <16549, 16546, 16543>, 0,
    <16549, 16543, 16547>, 0,
    <16549, 16547, 16544>, 0,
    <16549, 16544, 16548>, 0,
    <16552, 16551, 16541>, 0,
    <16552, 16541, 16548>, 0,
    <16552, 16548, 16544>, 0,
    <16552, 16544, 16550>, 0,
    <16552, 16550, 15683>, 0,
    <16552, 15683, 16487>, 0,
    <16552, 16487, 16482>, 0,
    <16552, 16482, 16551>, 0,
    <16554, 16545, 16541>, 0,
    <16554, 16541, 16551>, 0,
    <16554, 16551, 16482>, 0,
    <16554, 16482, 16484>, 0,
    <16554, 16484, 16466>, 0,
    <16554, 16466, 16553>, 0,
    <16554, 16553, 16542>, 0,
    <16554, 16542, 16545>, 0,
    <16560, 16559, 16555>, 0,
    <16560, 16555, 16557>, 0,
    <16560, 16557, 16544>, 0,
    <16560, 16544, 16547>, 0,
    <16560, 16547, 16543>, 0,
    <16560, 16543, 16558>, 0,
    <16560, 16558, 16556>, 0,
    <16560, 16556, 16559>, 0,
    <16563, 16562, 16555>, 0,
    <16563, 16555, 16559>, 0,
    <16563, 16559, 16556>, 0,
    <16563, 16556, 16561>, 0,
    <16563, 16561, 15734>, 0,
    <16563, 15734, 15737>, 0,
    <16563, 15737, 15733>, 0,
    <16563, 15733, 16562>, 0,
    <16564, 16557, 16555>, 0,
    <16564, 16555, 16562>, 0,
    <16564, 16562, 15733>, 0,
    <16564, 15733, 15744>, 0,
    <16564, 15744, 15683>, 0,
    <16564, 15683, 16550>, 0,
    <16564, 16550, 16544>, 0,
    <16564, 16544, 16557>, 0,
    <16570, 16569, 16565>, 0,
    <16570, 16565, 16567>, 0,
    <16570, 16567, 16566>, 0,
    <16570, 16566, 16568>, 0,
    <16570, 16568, 15779>, 0,
    <16570, 15779, 15791>, 0,
    <16570, 15791, 15787>, 0,
    <16570, 15787, 16569>, 0,
    <16572, 16571, 16565>, 0,
    <16572, 16565, 16569>, 0,
    <16572, 16569, 15787>, 0,
    <16572, 15787, 15788>, 0,
    <16572, 15788, 3545>, 0,
    <16572, 3545, 3749>, 0,
    <16572, 3749, 3746>, 0,
    <16572, 3746, 16571>, 0,
    <16574, 16567, 16565>, 0,
    <16574, 16565, 16571>, 0,
    <16574, 16571, 3746>, 0,
    <16574, 3746, 3760>, 0,
    <16574, 3760, 3758>, 0,
    <16574, 3758, 16573>, 0,
    <16574, 16573, 16566>, 0,
    <16574, 16566, 16567>, 0,
    <16580, 16579, 16575>, 0,
    <16580, 16575, 16577>, 0,
    <16580, 16577, 16576>, 0,
    <16580, 16576, 16578>, 0,
    <16580, 16578, 15878>, 0,
    <16580, 15878, 15890>, 0,
    <16580, 15890, 15886>, 0,
    <16580, 15886, 16579>, 0,
    <16584, 16583, 16575>, 0,
    <16584, 16575, 16579>, 0,
    <16584, 16579, 15886>, 0,
    <16584, 15886, 15887>, 0,
    <16584, 15887, 15779>, 0,
    <16584, 15779, 16582>, 0,
    <16584, 16582, 16581>, 0,
    <16584, 16581, 16583>, 0,
    <16588, 16577, 16575>, 0,
    <16588, 16575, 16583>, 0,
    <16588, 16583, 16581>, 0,
    <16588, 16581, 16586>, 0,
    <16588, 16586, 16585>, 0,
    <16588, 16585, 16587>, 0,
    <16588, 16587, 16576>, 0,
    <16588, 16576, 16577>, 0,
    <16592, 16591, 16589>, 0,
    <16592, 16589, 16590>, 0,
    <16592, 16590, 16581>, 0,
    <16592, 16581, 16582>, 0,
    <16592, 16582, 15779>, 0,
    <16592, 15779, 16568>, 0,
    <16592, 16568, 16566>, 0,
    <16592, 16566, 16591>, 0,
    <16596, 16595, 16589>, 0,
    <16596, 16589, 16591>, 0,
    <16596, 16591, 16566>, 0,
    <16596, 16566, 16573>, 0,
    <16596, 16573, 3758>, 0,
    <16596, 3758, 16594>, 0,
    <16596, 16594, 16593>, 0,
    <16596, 16593, 16595>, 0,
    <16598, 16590, 16589>, 0,
    <16598, 16589, 16595>, 0,
    <16598, 16595, 16593>, 0,
    <16598, 16593, 16597>, 0,
    <16598, 16597, 16585>, 0,
    <16598, 16585, 16586>, 0,
    <16598, 16586, 16581>, 0,
    <16598, 16581, 16590>, 0,
    <16607, 16606, 16599>, 0,
    <16607, 16599, 16603>, 0,
    <16607, 16603, 16600>, 0,
    <16607, 16600, 16604>, 0,
    <16607, 16604, 16601>, 0,
    <16607, 16601, 16605>, 0,
    <16607, 16605, 16602>, 0,
    <16607, 16602, 16606>, 0,
    <16612, 16611, 16599>, 0,
    <16612, 16599, 16606>, 0,
    <16612, 16606, 16602>, 0,
    <16612, 16602, 16609>, 0,
    <16612, 16609, 3764>, 0,
    <16612, 3764, 16610>, 0,
    <16612, 16610, 16608>, 0,
    <16612, 16608, 16611>, 0,
    <16615, 16603, 16599>, 0,
    <16615, 16599, 16611>, 0,
    <16615, 16611, 16608>, 0,
    <16615, 16608, 16613>, 0,
    <16615, 16613, 3551>, 0,
    <16615, 3551, 16614>, 0,
    <16615, 16614, 16600>, 0,
    <16615, 16600, 16603>, 0,
    <16621, 16620, 16616>, 0,
    <16621, 16616, 16618>, 0,
    <16621, 16618, 16617>, 0,
    <16621, 16617, 16619>, 0,
    <16621, 16619, 16601>, 0,
    <16621, 16601, 16604>, 0,
    <16621, 16604, 16600>, 0,
    <16621, 16600, 16620>, 0,
    <16623, 16622, 16616>, 0,
    <16623, 16616, 16620>, 0,
    <16623, 16620, 16600>, 0,
    <16623, 16600, 16614>, 0,
    <16623, 16614, 3551>, 0,
    <16623, 3551, 15803>, 0,
    <16623, 15803, 15796>, 0,
    <16623, 15796, 16622>, 0,
    <16625, 16618, 16616>, 0,
    <16625, 16616, 16622>, 0,
    <16625, 16622, 15796>, 0,
    <16625, 15796, 15799>, 0,
    <16625, 15799, 15795>, 0,
    <16625, 15795, 16624>, 0,
    <16625, 16624, 16617>, 0,
    <16625, 16617, 16618>, 0,
    <16631, 16630, 16626>, 0,
    <16631, 16626, 16628>, 0,
    <16631, 16628, 16010>, 0,
    <16631, 16010, 16011>, 0,
    <16631, 16011, 15998>, 0,
    <16631, 15998, 16629>, 0,
    <16631, 16629, 16627>, 0,
    <16631, 16627, 16630>, 0,
    <16637, 16636, 16626>, 0,
    <16637, 16626, 16630>, 0,
    <16637, 16630, 16627>, 0,
    <16637, 16627, 16634>, 0,
    <16637, 16634, 16632>, 0,
    <16637, 16632, 16635>, 0,
    <16637, 16635, 16633>, 0,
    <16637, 16633, 16636>, 0,
    <16639, 16628, 16626>, 0,
    <16639, 16626, 16636>, 0,
    <16639, 16636, 16633>, 0,
    <16639, 16633, 16638>, 0,
    <16639, 16638, 15826>, 0,
    <16639, 15826, 16014>, 0,
    <16639, 16014, 16010>, 0,
    <16639, 16010, 16628>, 0,
    <16643, 16642, 16640>, 0,
    <16643, 16640, 16641>, 0,
    <16643, 16641, 16518>, 0,
    <16643, 16518, 16520>, 0,
    <16643, 16520, 15826>, 0,
    <16643, 15826, 16638>, 0,
    <16643, 16638, 16633>, 0,
    <16643, 16633, 16642>, 0,
    <16647, 16646, 16640>, 0,
    <16647, 16640, 16642>, 0,
    <16647, 16642, 16633>, 0,
    <16647, 16633, 16635>, 0,
    <16647, 16635, 16632>, 0,
    <16647, 16632, 16645>, 0,
    <16647, 16645, 16644>, 0,
    <16647, 16644, 16646>, 0,
    <16649, 16641, 16640>, 0,
    <16649, 16640, 16646>, 0,
    <16649, 16646, 16644>, 0,
    <16649, 16644, 16648>, 0,
    <16649, 16648, 16523>, 0,
    <16649, 16523, 16525>, 0,
    <16649, 16525, 16518>, 0,
    <16649, 16518, 16641>, 0,
    <16658, 16657, 16650>, 0,
    <16658, 16650, 16654>, 0,
    <16658, 16654, 16651>, 0,
    <16658, 16651, 16655>, 0,
    <16658, 16655, 16652>, 0,
    <16658, 16652, 16656>, 0,
    <16658, 16656, 16653>, 0,
    <16658, 16653, 16657>, 0,
    <16661, 16660, 16650>, 0,
    <16661, 16650, 16657>, 0,
    <16661, 16657, 16653>, 0,
    <16661, 16653, 16659>, 0,
    <16661, 16659, 15734>, 0,
    <16661, 15734, 16561>, 0,
    <16661, 16561, 16556>, 0,
    <16661, 16556, 16660>, 0,
    <16663, 16654, 16650>, 0,
    <16663, 16650, 16660>, 0,
    <16663, 16660, 16556>, 0,
    <16663, 16556, 16558>, 0,
    <16663, 16558, 16543>, 0,
    <16663, 16543, 16662>, 0,
    <16663, 16662, 16651>, 0,
    <16663, 16651, 16654>, 0,
    <16669, 16668, 16664>, 0,
    <16669, 16664, 16666>, 0,
    <16669, 16666, 16653>, 0,
    <16669, 16653, 16656>, 0,
    <16669, 16656, 16652>, 0,
    <16669, 16652, 16667>, 0,
    <16669, 16667, 16665>, 0,
    <16669, 16665, 16668>, 0,
    <16672, 16671, 16664>, 0,
    <16672, 16664, 16668>, 0,
    <16672, 16668, 16665>, 0,
    <16672, 16665, 16670>, 0,
    <16672, 16670, 15846>, 0,
    <16672, 15846, 15849>, 0,
    <16672, 15849, 15845>, 0,
    <16672, 15845, 16671>, 0,
    <16673, 16666, 16664>, 0,
    <16673, 16664, 16671>, 0,
    <16673, 16671, 15845>, 0,
    <16673, 15845, 15856>, 0,
    <16673, 15856, 15734>, 0,
    <16673, 15734, 16659>, 0,
    <16673, 16659, 16653>, 0,
    <16673, 16653, 16666>, 0,
    <16679, 16678, 16674>, 0,
    <16679, 16674, 16676>, 0,
    <16679, 16676, 16675>, 0,
    <16679, 16675, 16677>, 0,
    <16679, 16677, 15954>, 0,
    <16679, 15954, 15966>, 0,
    <16679, 15966, 15962>, 0,
    <16679, 15962, 16678>, 0,
    <16683, 16682, 16674>, 0,
    <16683, 16674, 16678>, 0,
    <16683, 16678, 15962>, 0,
    <16683, 15962, 15963>, 0,
    <16683, 15963, 15878>, 0,
    <16683, 15878, 16681>, 0,
    <16683, 16681, 16680>, 0,
    <16683, 16680, 16682>, 0,
    <16687, 16676, 16674>, 0,
    <16687, 16674, 16682>, 0,
    <16687, 16682, 16680>, 0,
    <16687, 16680, 16685>, 0,
    <16687, 16685, 16684>, 0,
    <16687, 16684, 16686>, 0,
    <16687, 16686, 16675>, 0,
    <16687, 16675, 16676>, 0,
    <16691, 16690, 16688>, 0,
    <16691, 16688, 16689>, 0,
    <16691, 16689, 16680>, 0,
    <16691, 16680, 16681>, 0,
    <16691, 16681, 15878>, 0,
    <16691, 15878, 16578>, 0,
    <16691, 16578, 16576>, 0,
    <16691, 16576, 16690>, 0,
    <16695, 16694, 16688>, 0,
    <16695, 16688, 16690>, 0,
    <16695, 16690, 16576>, 0,
    <16695, 16576, 16587>, 0,
    <16695, 16587, 16585>, 0,
    <16695, 16585, 16693>, 0,
    <16695, 16693, 16692>, 0,
    <16695, 16692, 16694>, 0,
    <16697, 16689, 16688>, 0,
    <16697, 16688, 16694>, 0,
    <16697, 16694, 16692>, 0,
    <16697, 16692, 16696>, 0,
    <16697, 16696, 16684>, 0,
    <16697, 16684, 16685>, 0,
    <16697, 16685, 16680>, 0,
    <16697, 16680, 16689>, 0,
    <16706, 16705, 16698>, 0,
    <16706, 16698, 16702>, 0,
    <16706, 16702, 16699>, 0,
    <16706, 16699, 16703>, 0,
    <16706, 16703, 16700>, 0,
    <16706, 16700, 16704>, 0,
    <16706, 16704, 16701>, 0,
    <16706, 16701, 16705>, 0,
    <16709, 16708, 16698>, 0,
    <16709, 16698, 16705>, 0,
    <16709, 16705, 16701>, 0,
    <16709, 16701, 16707>, 0,
    <16709, 16707, 16601>, 0,
    <16709, 16601, 16619>, 0,
    <16709, 16619, 16617>, 0,
    <16709, 16617, 16708>, 0,
    <16711, 16702, 16698>, 0,
    <16711, 16698, 16708>, 0,
    <16711, 16708, 16617>, 0,
    <16711, 16617, 16624>, 0,
    <16711, 16624, 15795>, 0,
    <16711, 15795, 16710>, 0,
    <16711, 16710, 16699>, 0,
    <16711, 16699, 16702>, 0,
    <16717, 16716, 16712>, 0,
    <16717, 16712, 16714>, 0,
    <16717, 16714, 16713>, 0,
    <16717, 16713, 16715>, 0,
    <16717, 16715, 16700>, 0,
    <16717, 16700, 16703>, 0,
    <16717, 16703, 16699>, 0,
    <16717, 16699, 16716>, 0,
    <16719, 16718, 16712>, 0,
    <16719, 16712, 16716>, 0,
    <16719, 16716, 16699>, 0,
    <16719, 16699, 16710>, 0,
    <16719, 16710, 15795>, 0,
    <16719, 15795, 15901>, 0,
    <16719, 15901, 15895>, 0,
    <16719, 15895, 16718>, 0,
    <16721, 16714, 16712>, 0,
    <16721, 16712, 16718>, 0,
    <16721, 16718, 15895>, 0,
    <16721, 15895, 15898>, 0,
    <16721, 15898, 15894>, 0,
    <16721, 15894, 16720>, 0,
    <16721, 16720, 16713>, 0,
    <16721, 16713, 16714>, 0,
    <16727, 16726, 16722>, 0,
    <16727, 16722, 16724>, 0,
    <16727, 16724, 16723>, 0,
    <16727, 16723, 16725>, 0,
    <16727, 16725, 16064>, 0,
    <16727, 16064, 16076>, 0,
    <16727, 16076, 16072>, 0,
    <16727, 16072, 16726>, 0,
    <16731, 16730, 16722>, 0,
    <16731, 16722, 16726>, 0,
    <16731, 16726, 16072>, 0,
    <16731, 16072, 16073>, 0,
    <16731, 16073, 15954>, 0,
    <16731, 15954, 16729>, 0,
    <16731, 16729, 16728>, 0,
    <16731, 16728, 16730>, 0,
    <16735, 16724, 16722>, 0,
    <16735, 16722, 16730>, 0,
    <16735, 16730, 16728>, 0,
    <16735, 16728, 16733>, 0,
    <16735, 16733, 16732>, 0,
    <16735, 16732, 16734>, 0,
    <16735, 16734, 16723>, 0,
    <16735, 16723, 16724>, 0,
    <16739, 16738, 16736>, 0,
    <16739, 16736, 16737>, 0,
    <16739, 16737, 16728>, 0,
    <16739, 16728, 16729>, 0,
    <16739, 16729, 15954>, 0,
    <16739, 15954, 16677>, 0,
    <16739, 16677, 16675>, 0,
    <16739, 16675, 16738>, 0,
    <16743, 16742, 16736>, 0,
    <16743, 16736, 16738>, 0,
    <16743, 16738, 16675>, 0,
    <16743, 16675, 16686>, 0,
    <16743, 16686, 16684>, 0,
    <16743, 16684, 16741>, 0,
    <16743, 16741, 16740>, 0,
    <16743, 16740, 16742>, 0,
    <16745, 16737, 16736>, 0,
    <16745, 16736, 16742>, 0,
    <16745, 16742, 16740>, 0,
    <16745, 16740, 16744>, 0,
    <16745, 16744, 16732>, 0,
    <16745, 16732, 16733>, 0,
    <16745, 16733, 16728>, 0,
    <16745, 16728, 16737>, 0,
    <16754, 16753, 16746>, 0,
    <16754, 16746, 16750>, 0,
    <16754, 16750, 16747>, 0,
    <16754, 16747, 16751>, 0,
    <16754, 16751, 16748>, 0,
    <16754, 16748, 16752>, 0,
    <16754, 16752, 16749>, 0,
    <16754, 16749, 16753>, 0,
    <16757, 16756, 16746>, 0,
    <16757, 16746, 16753>, 0,
    <16757, 16753, 16749>, 0,
    <16757, 16749, 16755>, 0,
    <16757, 16755, 16700>, 0,
    <16757, 16700, 16715>, 0,
    <16757, 16715, 16713>, 0,
    <16757, 16713, 16756>, 0,
    <16759, 16750, 16746>, 0,
    <16759, 16746, 16756>, 0,
    <16759, 16756, 16713>, 0,
    <16759, 16713, 16720>, 0,
    <16759, 16720, 15894>, 0,
    <16759, 15894, 16758>, 0,
    <16759, 16758, 16747>, 0,
    <16759, 16747, 16750>, 0,
    <16765, 16764, 16760>, 0,
    <16765, 16760, 16762>, 0,
    <16765, 16762, 16761>, 0,
    <16765, 16761, 16763>, 0,
    <16765, 16763, 16748>, 0,
    <16765, 16748, 16751>, 0,
    <16765, 16751, 16747>, 0,
    <16765, 16747, 16764>, 0,
    <16767, 16766, 16760>, 0,
    <16767, 16760, 16764>, 0,
    <16767, 16764, 16747>, 0,
    <16767, 16747, 16758>, 0,
    <16767, 16758, 15894>, 0,
    <16767, 15894, 15977>, 0,
    <16767, 15977, 15971>, 0,
    <16767, 15971, 16766>, 0,
    <16769, 16762, 16760>, 0,
    <16769, 16760, 16766>, 0,
    <16769, 16766, 15971>, 0,
    <16769, 15971, 15974>, 0,
    <16769, 15974, 15970>, 0,
    <16769, 15970, 16768>, 0,
    <16769, 16768, 16761>, 0,
    <16769, 16761, 16762>, 0,
    <16775, 16774, 16770>, 0,
    <16775, 16770, 16772>, 0,
    <16775, 16772, 16120>, 0,
    <16775, 16120, 16121>, 0,
    <16775, 16121, 16108>, 0,
    <16775, 16108, 16773>, 0,
    <16775, 16773, 16771>, 0,
    <16775, 16771, 16774>, 0,
    <16781, 16780, 16770>, 0,
    <16781, 16770, 16774>, 0,
    <16781, 16774, 16771>, 0,
    <16781, 16771, 16778>, 0,
    <16781, 16778, 16776>, 0,
    <16781, 16776, 16779>, 0,
    <16781, 16779, 16777>, 0,
    <16781, 16777, 16780>, 0,
    <16783, 16772, 16770>, 0,
    <16783, 16770, 16780>, 0,
    <16783, 16780, 16777>, 0,
    <16783, 16777, 16782>, 0,
    <16783, 16782, 15998>, 0,
    <16783, 15998, 16124>, 0,
    <16783, 16124, 16120>, 0,
    <16783, 16120, 16772>, 0,
    <16787, 16786, 16784>, 0,
    <16787, 16784, 16785>, 0,
    <16787, 16785, 16627>, 0,
    <16787, 16627, 16629>, 0,
    <16787, 16629, 15998>, 0,
    <16787, 15998, 16782>, 0,
    <16787, 16782, 16777>, 0,
    <16787, 16777, 16786>, 0,
    <16791, 16790, 16784>, 0,
    <16791, 16784, 16786>, 0,
    <16791, 16786, 16777>, 0,
    <16791, 16777, 16779>, 0,
    <16791, 16779, 16776>, 0,
    <16791, 16776, 16789>, 0,
    <16791, 16789, 16788>, 0,
    <16791, 16788, 16790>, 0,
    <16793, 16785, 16784>, 0,
    <16793, 16784, 16790>, 0,
    <16793, 16790, 16788>, 0,
    <16793, 16788, 16792>, 0,
    <16793, 16792, 16632>, 0,
    <16793, 16632, 16634>, 0,
    <16793, 16634, 16627>, 0,
    <16793, 16627, 16785>, 0,
    <16802, 16801, 16794>, 0,
    <16802, 16794, 16798>, 0,
    <16802, 16798, 16795>, 0,
    <16802, 16795, 16799>, 0,
    <16802, 16799, 16796>, 0,
    <16802, 16796, 16800>, 0,
    <16802, 16800, 16797>, 0,
    <16802, 16797, 16801>, 0,
    <16805, 16804, 16794>, 0,
    <16805, 16794, 16801>, 0,
    <16805, 16801, 16797>, 0,
    <16805, 16797, 16803>, 0,
    <16805, 16803, 15846>, 0,
    <16805, 15846, 16670>, 0,
    <16805, 16670, 16665>, 0,
    <16805, 16665, 16804>, 0,
    <16807, 16798, 16794>, 0,
    <16807, 16794, 16804>, 0,
    <16807, 16804, 16665>, 0,
    <16807, 16665, 16667>, 0,
    <16807, 16667, 16652>, 0,
    <16807, 16652, 16806>, 0,
    <16807, 16806, 16795>, 0,
    <16807, 16795, 16798>, 0,
    <16813, 16812, 16808>, 0,
    <16813, 16808, 16810>, 0,
    <16813, 16810, 16797>, 0,
    <16813, 16797, 16800>, 0,
    <16813, 16800, 16796>, 0,
    <16813, 16796, 16811>, 0,
    <16813, 16811, 16809>, 0,
    <16813, 16809, 16812>, 0,
    <16816, 16815, 16808>, 0,
    <16816, 16808, 16812>, 0,
    <16816, 16812, 16809>, 0,
    <16816, 16809, 16814>, 0,
    <16816, 16814, 16018>, 0,
    <16816, 16018, 16021>, 0,
    <16816, 16021, 16017>, 0,
    <16816, 16017, 16815>, 0,
    <16817, 16810, 16808>, 0,
    <16817, 16808, 16815>, 0,
    <16817, 16815, 16017>, 0,
    <16817, 16017, 16028>, 0,
    <16817, 16028, 15846>, 0,
    <16817, 15846, 16803>, 0,
    <16817, 16803, 16797>, 0,
    <16817, 16797, 16810>, 0,
    <16825, 16824, 16818>, 0,
    <16825, 16818, 16821>, 0,
    <16825, 16821, 16819>, 0,
    <16825, 16819, 16822>, 0,
    <16825, 16822, 4105>, 0,
    <16825, 4105, 16823>, 0,
    <16825, 16823, 16820>, 0,
    <16825, 16820, 16824>, 0,
    <16828, 16827, 16818>, 0,
    <16828, 16818, 16824>, 0,
    <16828, 16824, 16820>, 0,
    <16828, 16820, 16826>, 0,
    <16828, 16826, 3717>, 0,
    <16828, 3717, 16337>, 0,
    <16828, 16337, 16335>, 0,
    <16828, 16335, 16827>, 0,
    <16830, 16821, 16818>, 0,
    <16830, 16818, 16827>, 0,
    <16830, 16827, 16335>, 0,
    <16830, 16335, 16342>, 0,
    <16830, 16342, 16238>, 0,
    <16830, 16238, 16829>, 0,
    <16830, 16829, 16819>, 0,
    <16830, 16819, 16821>, 0,
    <16836, 16835, 16831>, 0,
    <16836, 16831, 16833>, 0,
    <16836, 16833, 16832>, 0,
    <16836, 16832, 16834>, 0,
    <16836, 16834, 16160>, 0,
    <16836, 16160, 16172>, 0,
    <16836, 16172, 16168>, 0,
    <16836, 16168, 16835>, 0,
    <16840, 16839, 16831>, 0,
    <16840, 16831, 16835>, 0,
    <16840, 16835, 16168>, 0,
    <16840, 16168, 16169>, 0,
    <16840, 16169, 16064>, 0,
    <16840, 16064, 16838>, 0,
    <16840, 16838, 16837>, 0,
    <16840, 16837, 16839>, 0,
    <16844, 16833, 16831>, 0,
    <16844, 16831, 16839>, 0,
    <16844, 16839, 16837>, 0,
    <16844, 16837, 16842>, 0,
    <16844, 16842, 16841>, 0,
    <16844, 16841, 16843>, 0,
    <16844, 16843, 16832>, 0,
    <16844, 16832, 16833>, 0,
    <16848, 16847, 16845>, 0,
    <16848, 16845, 16846>, 0,
    <16848, 16846, 16837>, 0,
    <16848, 16837, 16838>, 0,
    <16848, 16838, 16064>, 0,
    <16848, 16064, 16725>, 0,
    <16848, 16725, 16723>, 0,
    <16848, 16723, 16847>, 0,
    <16852, 16851, 16845>, 0,
    <16852, 16845, 16847>, 0,
    <16852, 16847, 16723>, 0,
    <16852, 16723, 16734>, 0,
    <16852, 16734, 16732>, 0,
    <16852, 16732, 16850>, 0,
    <16852, 16850, 16849>, 0,
    <16852, 16849, 16851>, 0,
    <16854, 16846, 16845>, 0,
    <16854, 16845, 16851>, 0,
    <16854, 16851, 16849>, 0,
    <16854, 16849, 16853>, 0,
    <16854, 16853, 16841>, 0,
    <16854, 16841, 16842>, 0,
    <16854, 16842, 16837>, 0,
    <16854, 16837, 16846>, 0,
    <16863, 16862, 16855>, 0,
    <16863, 16855, 16859>, 0,
    <16863, 16859, 16856>, 0,
    <16863, 16856, 16860>, 0,
    <16863, 16860, 16857>, 0,
    <16863, 16857, 16861>, 0,
    <16863, 16861, 16858>, 0,
    <16863, 16858, 16862>, 0,
    <16866, 16865, 16855>, 0,
    <16866, 16855, 16862>, 0,
    <16866, 16862, 16858>, 0,
    <16866, 16858, 16864>, 0,
    <16866, 16864, 16748>, 0,
    <16866, 16748, 16763>, 0,
    <16866, 16763, 16761>, 0,
    <16866, 16761, 16865>, 0,
    <16868, 16859, 16855>, 0,
    <16868, 16855, 16865>, 0,
    <16868, 16865, 16761>, 0,
    <16868, 16761, 16768>, 0,
    <16868, 16768, 15970>, 0,
    <16868, 15970, 16867>, 0,
    <16868, 16867, 16856>, 0,
    <16868, 16856, 16859>, 0,
    <16874, 16873, 16869>, 0,
    <16874, 16869, 16871>, 0,
    <16874, 16871, 16870>, 0,
    <16874, 16870, 16872>, 0,
    <16874, 16872, 16857>, 0,
    <16874, 16857, 16860>, 0,
    <16874, 16860, 16856>, 0,
    <16874, 16856, 16873>, 0,
    <16876, 16875, 16869>, 0,
    <16876, 16869, 16873>, 0,
    <16876, 16873, 16856>, 0,
    <16876, 16856, 16867>, 0,
    <16876, 16867, 15970>, 0,
    <16876, 15970, 16087>, 0,
    <16876, 16087, 16081>, 0,
    <16876, 16081, 16875>, 0,
    <16878, 16871, 16869>, 0,
    <16878, 16869, 16875>, 0,
    <16878, 16875, 16081>, 0,
    <16878, 16081, 16084>, 0,
    <16878, 16084, 16080>, 0,
    <16878, 16080, 16877>, 0,
    <16878, 16877, 16870>, 0,
    <16878, 16870, 16871>, 0,
    <16884, 16883, 16879>, 0,
    <16884, 16879, 16881>, 0,
    <16884, 16881, 16230>, 0,
    <16884, 16230, 16231>, 0,
    <16884, 16231, 16204>, 0,
    <16884, 16204, 16882>, 0,
    <16884, 16882, 16880>, 0,
    <16884, 16880, 16883>, 0,
    <16890, 16889, 16879>, 0,
    <16890, 16879, 16883>, 0,
    <16890, 16883, 16880>, 0,
    <16890, 16880, 16887>, 0,
    <16890, 16887, 16885>, 0,
    <16890, 16885, 16888>, 0,
    <16890, 16888, 16886>, 0,
    <16890, 16886, 16889>, 0,
    <16892, 16881, 16879>, 0,
    <16892, 16879, 16889>, 0,
    <16892, 16889, 16886>, 0,
    <16892, 16886, 16891>, 0,
    <16892, 16891, 16108>, 0,
    <16892, 16108, 16234>, 0,
    <16892, 16234, 16230>, 0,
    <16892, 16230, 16881>, 0,
    <16896, 16895, 16893>, 0,
    <16896, 16893, 16894>, 0,
    <16896, 16894, 16771>, 0,
    <16896, 16771, 16773>, 0,
    <16896, 16773, 16108>, 0,
    <16896, 16108, 16891>, 0,
    <16896, 16891, 16886>, 0,
    <16896, 16886, 16895>, 0,
    <16900, 16899, 16893>, 0,
    <16900, 16893, 16895>, 0,
    <16900, 16895, 16886>, 0,
    <16900, 16886, 16888>, 0,
    <16900, 16888, 16885>, 0,
    <16900, 16885, 16898>, 0,
    <16900, 16898, 16897>, 0,
    <16900, 16897, 16899>, 0,
    <16902, 16894, 16893>, 0,
    <16902, 16893, 16899>, 0,
    <16902, 16899, 16897>, 0,
    <16902, 16897, 16901>, 0,
    <16902, 16901, 16776>, 0,
    <16902, 16776, 16778>, 0,
    <16902, 16778, 16771>, 0,
    <16902, 16771, 16894>, 0,
    <16911, 16910, 16903>, 0,
    <16911, 16903, 16907>, 0,
    <16911, 16907, 16904>, 0,
    <16911, 16904, 16908>, 0,
    <16911, 16908, 16905>, 0,
    <16911, 16905, 16909>, 0,
    <16911, 16909, 16906>, 0,
    <16911, 16906, 16910>, 0,
    <16914, 16913, 16903>, 0,
    <16914, 16903, 16910>, 0,
    <16914, 16910, 16906>, 0,
    <16914, 16906, 16912>, 0,
    <16914, 16912, 16018>, 0,
    <16914, 16018, 16814>, 0,
    <16914, 16814, 16809>, 0,
    <16914, 16809, 16913>, 0,
    <16916, 16907, 16903>, 0,
    <16916, 16903, 16913>, 0,
    <16916, 16913, 16809>, 0,
    <16916, 16809, 16811>, 0,
    <16916, 16811, 16796>, 0,
    <16916, 16796, 16915>, 0,
    <16916, 16915, 16904>, 0,
    <16916, 16904, 16907>, 0,
    <16922, 16921, 16917>, 0,
    <16922, 16917, 16919>, 0,
    <16922, 16919, 16906>, 0,
    <16922, 16906, 16909>, 0,
    <16922, 16909, 16905>, 0,
    <16922, 16905, 16920>, 0,
    <16922, 16920, 16918>, 0,
    <16922, 16918, 16921>, 0,
    <16925, 16924, 16917>, 0,
    <16925, 16917, 16921>, 0,
    <16925, 16921, 16918>, 0,
    <16925, 16918, 16923>, 0,
    <16925, 16923, 16128>, 0,
    <16925, 16128, 16131>, 0,
    <16925, 16131, 16127>, 0,
    <16925, 16127, 16924>, 0,
    <16926, 16919, 16917>, 0,
    <16926, 16917, 16924>, 0,
    <16926, 16924, 16127>, 0,
    <16926, 16127, 16138>, 0,
    <16926, 16138, 16018>, 0,
    <16926, 16018, 16912>, 0,
    <16926, 16912, 16906>, 0,
    <16926, 16906, 16919>, 0,
    <16935, 16934, 16927>, 0,
    <16935, 16927, 16931>, 0,
    <16935, 16931, 16928>, 0,
    <16935, 16928, 16932>, 0,
    <16935, 16932, 16929>, 0,
    <16935, 16929, 16933>, 0,
    <16935, 16933, 16930>, 0,
    <16935, 16930, 16934>, 0,
    <16938, 16937, 16927>, 0,
    <16938, 16927, 16934>, 0,
    <16938, 16934, 16930>, 0,
    <16938, 16930, 16936>, 0,
    <16938, 16936, 3691>, 0,
    <16938, 3691, 16501>, 0,
    <16938, 16501, 16497>, 0,
    <16938, 16497, 16937>, 0,
    <16940, 16931, 16927>, 0,
    <16940, 16927, 16937>, 0,
    <16940, 16937, 16497>, 0,
    <16940, 16497, 16498>, 0,
    <16940, 16498, 16358>, 0,
    <16940, 16358, 16939>, 0,
    <16940, 16939, 16928>, 0,
    <16940, 16928, 16931>, 0,
    <16946, 16945, 16941>, 0,
    <16946, 16941, 16943>, 0,
    <16946, 16943, 16458>, 0,
    <16946, 16458, 16459>, 0,
    <16946, 16459, 16446>, 0,
    <16946, 16446, 16944>, 0,
    <16946, 16944, 16942>, 0,
    <16946, 16942, 16945>, 0,
    <16951, 16950, 16941>, 0,
    <16951, 16941, 16945>, 0,
    <16951, 16945, 16942>, 0,
    <16951, 16942, 16948>, 0,
    <16951, 16948, 3873>, 0,
    <16951, 3873, 16949>, 0,
    <16951, 16949, 16947>, 0,
    <16951, 16947, 16950>, 0,
    <16953, 16943, 16941>, 0,
    <16953, 16941, 16950>, 0,
    <16953, 16950, 16947>, 0,
    <16953, 16947, 16952>, 0,
    <16953, 16952, 3643>, 0,
    <16953, 3643, 16462>, 0,
    <16953, 16462, 16458>, 0,
    <16953, 16458, 16943>, 0,
    <16959, 16958, 16954>, 0,
    <16959, 16954, 16956>, 0,
    <16959, 16956, 16955>, 0,
    <16959, 16955, 16957>, 0,
    <16959, 16957, 16270>, 0,
    <16959, 16270, 16282>, 0,
    <16959, 16282, 16278>, 0,
    <16959, 16278, 16958>, 0,
    <16963, 16962, 16954>, 0,
    <16963, 16954, 16958>, 0,
    <16963, 16958, 16278>, 0,
    <16963, 16278, 16279>, 0,
    <16963, 16279, 16160>, 0,
    <16963, 16160, 16961>, 0,
    <16963, 16961, 16960>, 0,
    <16963, 16960, 16962>, 0,
    <16967, 16956, 16954>, 0,
    <16967, 16954, 16962>, 0,
    <16967, 16962, 16960>, 0,
    <16967, 16960, 16965>, 0,
    <16967, 16965, 16964>, 0,
    <16967, 16964, 16966>, 0,
    <16967, 16966, 16955>, 0,
    <16967, 16955, 16956>, 0,
    <16971, 16970, 16968>, 0,
    <16971, 16968, 16969>, 0,
    <16971, 16969, 16960>, 0,
    <16971, 16960, 16961>, 0,
    <16971, 16961, 16160>, 0,
    <16971, 16160, 16834>, 0,
    <16971, 16834, 16832>, 0,
    <16971, 16832, 16970>, 0,
    <16975, 16974, 16968>, 0,
    <16975, 16968, 16970>, 0,
    <16975, 16970, 16832>, 0,
    <16975, 16832, 16843>, 0,
    <16975, 16843, 16841>, 0,
    <16975, 16841, 16973>, 0,
    <16975, 16973, 16972>, 0,
    <16975, 16972, 16974>, 0,
    <16977, 16969, 16968>, 0,
    <16977, 16968, 16974>, 0,
    <16977, 16974, 16972>, 0,
    <16977, 16972, 16976>, 0,
    <16977, 16976, 16964>, 0,
    <16977, 16964, 16965>, 0,
    <16977, 16965, 16960>, 0,
    <16977, 16960, 16969>, 0,
    <16986, 16985, 16978>, 0,
    <16986, 16978, 16982>, 0,
    <16986, 16982, 16979>, 0,
    <16986, 16979, 16983>, 0,
    <16986, 16983, 16980>, 0,
    <16986, 16980, 16984>, 0,
    <16986, 16984, 16981>, 0,
    <16986, 16981, 16985>, 0,
    <16989, 16988, 16978>, 0,
    <16989, 16978, 16985>, 0,
    <16989, 16985, 16981>, 0,
    <16989, 16981, 16987>, 0,
    <16989, 16987, 16857>, 0,
    <16989, 16857, 16872>, 0,
    <16989, 16872, 16870>, 0,
    <16989, 16870, 16988>, 0,
    <16991, 16982, 16978>, 0,
    <16991, 16978, 16988>, 0,
    <16991, 16988, 16870>, 0,
    <16991, 16870, 16877>, 0,
    <16991, 16877, 16080>, 0,
    <16991, 16080, 16990>, 0,
    <16991, 16990, 16979>, 0,
    <16991, 16979, 16982>, 0,
    <16997, 16996, 16992>, 0,
    <16997, 16992, 16994>, 0,
    <16997, 16994, 16993>, 0,
    <16997, 16993, 16995>, 0,
    <16997, 16995, 16980>, 0,
    <16997, 16980, 16983>, 0,
    <16997, 16983, 16979>, 0,
    <16997, 16979, 16996>, 0,
    <16999, 16998, 16992>, 0,
    <16999, 16992, 16996>, 0,
    <16999, 16996, 16979>, 0,
    <16999, 16979, 16990>, 0,
    <16999, 16990, 16080>, 0,
    <16999, 16080, 16183>, 0,
    <16999, 16183, 16177>, 0,
    <16999, 16177, 16998>, 0,
    <17001, 16994, 16992>, 0,
    <17001, 16992, 16998>, 0,
    <17001, 16998, 16177>, 0,
    <17001, 16177, 16180>, 0,
    <17001, 16180, 16176>, 0,
    <17001, 16176, 17000>, 0,
    <17001, 17000, 16993>, 0,
    <17001, 16993, 16994>, 0,
    <17007, 17006, 17002>, 0,
    <17007, 17002, 17004>, 0,
    <17007, 17004, 16535>, 0,
    <17007, 16535, 16536>, 0,
    <17007, 16536, 16523>, 0,
    <17007, 16523, 17005>, 0,
    <17007, 17005, 17003>, 0,
    <17007, 17003, 17006>, 0,
    <17013, 17012, 17002>, 0,
    <17013, 17002, 17006>, 0,
    <17013, 17006, 17003>, 0,
    <17013, 17003, 17010>, 0,
    <17013, 17010, 17008>, 0,
    <17013, 17008, 17011>, 0,
    <17013, 17011, 17009>, 0,
    <17013, 17009, 17012>, 0,
    <17015, 17004, 17002>, 0,
    <17015, 17002, 17012>, 0,
    <17015, 17012, 17009>, 0,
    <17015, 17009, 17014>, 0,
    <17015, 17014, 16446>, 0,
    <17015, 16446, 16539>, 0,
    <17015, 16539, 16535>, 0,
    <17015, 16535, 17004>, 0,
    <17019, 17018, 17016>, 0,
    <17019, 17016, 17017>, 0,
    <17019, 17017, 16942>, 0,
    <17019, 16942, 16944>, 0,
    <17019, 16944, 16446>, 0,
    <17019, 16446, 17014>, 0,
    <17019, 17014, 17009>, 0,
    <17019, 17009, 17018>, 0,
    <17023, 17022, 17016>, 0,
    <17023, 17016, 17018>, 0,
    <17023, 17018, 17009>, 0,
    <17023, 17009, 17011>, 0,
    <17023, 17011, 17008>, 0,
    <17023, 17008, 17021>, 0,
    <17023, 17021, 17020>, 0,
    <17023, 17020, 17022>, 0,
    <17025, 17017, 17016>, 0,
    <17025, 17016, 17022>, 0,
    <17025, 17022, 17020>, 0,
    <17025, 17020, 17024>, 0,
    <17025, 17024, 3873>, 0,
    <17025, 3873, 16948>, 0,
    <17025, 16948, 16942>, 0,
    <17025, 16942, 17017>, 0,
    <17034, 17033, 17026>, 0,
    <17034, 17026, 17030>, 0,
    <17034, 17030, 17027>, 0,
    <17034, 17027, 17031>, 0,
    <17034, 17031, 17028>, 0,
    <17034, 17028, 17032>, 0,
    <17034, 17032, 17029>, 0,
    <17034, 17029, 17033>, 0,
    <17039, 17038, 17026>, 0,
    <17039, 17026, 17033>, 0,
    <17039, 17033, 17029>, 0,
    <17039, 17029, 17036>, 0,
    <17039, 17036, 3657>, 0,
    <17039, 3657, 17037>, 0,
    <17039, 17037, 17035>, 0,
    <17039, 17035, 17038>, 0,
    <17042, 17030, 17026>, 0,
    <17042, 17026, 17038>, 0,
    <17042, 17038, 17035>, 0,
    <17042, 17035, 17040>, 0,
    <17042, 17040, 3887>, 0,
    <17042, 3887, 17041>, 0,
    <17042, 17041, 17027>, 0,
    <17042, 17027, 17030>, 0,
    <17048, 17047, 17043>, 0,
    <17048, 17043, 17045>, 0,
    <17048, 17045, 17029>, 0,
    <17048, 17029, 17032>, 0,
    <17048, 17032, 17028>, 0,
    <17048, 17028, 17046>, 0,
    <17048, 17046, 17044>, 0,
    <17048, 17044, 17047>, 0,
    <17051, 17050, 17043>, 0,
    <17051, 17043, 17047>, 0,
    <17051, 17047, 17044>, 0,
    <17051, 17044, 17049>, 0,
    <17051, 17049, 16466>, 0,
    <17051, 16466, 16469>, 0,
    <17051, 16469, 16465>, 0,
    <17051, 16465, 17050>, 0,
    <17052, 17045, 17043>, 0,
    <17052, 17043, 17050>, 0,
    <17052, 17050, 16465>, 0,
    <17052, 16465, 16479>, 0,
    <17052, 16479, 3657>, 0,
    <17052, 3657, 17036>, 0,
    <17052, 17036, 17029>, 0,
    <17052, 17029, 17045>, 0,
    <17061, 17060, 17053>, 0,
    <17061, 17053, 17057>, 0,
    <17061, 17057, 17054>, 0,
    <17061, 17054, 17058>, 0,
    <17061, 17058, 17055>, 0,
    <17061, 17055, 17059>, 0,
    <17061, 17059, 17056>, 0,
    <17061, 17056, 17060>, 0,
    <17064, 17063, 17053>, 0,
    <17064, 17053, 17060>, 0,
    <17064, 17060, 17056>, 0,
    <17064, 17056, 17062>, 0,
    <17064, 17062, 16396>, 0,
    <17064, 16396, 16515>, 0,
    <17064, 16515, 16510>, 0,
    <17064, 16510, 17063>, 0,
    <17066, 17057, 17053>, 0,
    <17066, 17053, 17063>, 0,
    <17066, 17063, 16510>, 0,
    <17066, 16510, 16512>, 0,
    <17066, 16512, 3705>, 0,
    <17066, 3705, 17065>, 0,
    <17066, 17065, 17054>, 0,
    <17066, 17054, 17057>, 0,
    <17072, 17071, 17067>, 0,
    <17072, 17067, 17069>, 0,
    <17072, 17069, 16644>, 0,
    <17072, 16644, 16645>, 0,
    <17072, 16645, 16632>, 0,
    <17072, 16632, 17070>, 0,
    <17072, 17070, 17068>, 0,
    <17072, 17068, 17071>, 0,
    <17078, 17077, 17067>, 0,
    <17078, 17067, 17071>, 0,
    <17078, 17071, 17068>, 0,
    <17078, 17068, 17075>, 0,
    <17078, 17075, 17073>, 0,
    <17078, 17073, 17076>, 0,
    <17078, 17076, 17074>, 0,
    <17078, 17074, 17077>, 0,
    <17080, 17069, 17067>, 0,
    <17080, 17067, 17077>, 0,
    <17080, 17077, 17074>, 0,
    <17080, 17074, 17079>, 0,
    <17080, 17079, 16523>, 0,
    <17080, 16523, 16648>, 0,
    <17080, 16648, 16644>, 0,
    <17080, 16644, 17069>, 0,
    <17084, 17083, 17081>, 0,
    <17084, 17081, 17082>, 0,
    <17084, 17082, 17003>, 0,
    <17084, 17003, 17005>, 0,
    <17084, 17005, 16523>, 0,
    <17084, 16523, 17079>, 0,
    <17084, 17079, 17074>, 0,
    <17084, 17074, 17083>, 0,
    <17088, 17087, 17081>, 0,
    <17088, 17081, 17083>, 0,
    <17088, 17083, 17074>, 0,
    <17088, 17074, 17076>, 0,
    <17088, 17076, 17073>, 0,
    <17088, 17073, 17086>, 0,
    <17088, 17086, 17085>, 0,
    <17088, 17085, 17087>, 0,
    <17090, 17082, 17081>, 0,
    <17090, 17081, 17087>, 0,
    <17090, 17087, 17085>, 0,
    <17090, 17085, 17089>, 0,
    <17090, 17089, 17008>, 0,
    <17090, 17008, 17010>, 0,
    <17090, 17010, 17003>, 0,
    <17090, 17003, 17082>, 0,
    <17099, 17098, 17091>, 0,
    <17099, 17091, 17095>, 0,
    <17099, 17095, 17092>, 0,
    <17099, 17092, 17096>, 0,
    <17099, 17096, 17093>, 0,
    <17099, 17093, 17097>, 0,
    <17099, 17097, 17094>, 0,
    <17099, 17094, 17098>, 0,
    <17102, 17101, 17091>, 0,
    <17102, 17091, 17098>, 0,
    <17102, 17098, 17094>, 0,
    <17102, 17094, 17100>, 0,
    <17102, 17100, 16466>, 0,
    <17102, 16466, 17049>, 0,
    <17102, 17049, 17044>, 0,
    <17102, 17044, 17101>, 0,
    <17104, 17095, 17091>, 0,
    <17104, 17091, 17101>, 0,
    <17104, 17101, 17044>, 0,
    <17104, 17044, 17046>, 0,
    <17104, 17046, 17028>, 0,
    <17104, 17028, 17103>, 0,
    <17104, 17103, 17092>, 0,
    <17104, 17092, 17095>, 0,
    <17110, 17109, 17105>, 0,
    <17110, 17105, 17107>, 0,
    <17110, 17107, 17094>, 0,
    <17110, 17094, 17097>, 0,
    <17110, 17097, 17093>, 0,
    <17110, 17093, 17108>, 0,
    <17110, 17108, 17106>, 0,
    <17110, 17106, 17109>, 0,
    <17113, 17112, 17105>, 0,
    <17113, 17105, 17109>, 0,
    <17113, 17109, 17106>, 0,
    <17113, 17106, 17111>, 0,
    <17113, 17111, 16543>, 0,
    <17113, 16543, 16546>, 0,
    <17113, 16546, 16542>, 0,
    <17113, 16542, 17112>, 0,
    <17114, 17107, 17105>, 0,
    <17114, 17105, 17112>, 0,
    <17114, 17112, 16542>, 0,
    <17114, 16542, 16553>, 0,
    <17114, 16553, 16466>, 0,
    <17114, 16466, 17100>, 0,
    <17114, 17100, 17094>, 0,
    <17114, 17094, 17107>, 0,
    <17120, 17119, 17115>, 0,
    <17120, 17115, 17117>, 0,
    <17120, 17117, 16327>, 0,
    <17120, 16327, 16329>, 0,
    <17120, 16329, 3681>, 0,
    <17120, 3681, 17118>, 0,
    <17120, 17118, 17116>, 0,
    <17120, 17116, 17119>, 0,
    <17126, 17125, 17115>, 0,
    <17126, 17115, 17119>, 0,
    <17126, 17119, 17116>, 0,
    <17126, 17116, 17123>, 0,
    <17126, 17123, 17121>, 0,
    <17126, 17121, 17124>, 0,
    <17126, 17124, 17122>, 0,
    <17126, 17122, 17125>, 0,
    <17128, 17117, 17115>, 0,
    <17128, 17115, 17125>, 0,
    <17128, 17125, 17122>, 0,
    <17128, 17122, 17127>, 0,
    <17128, 17127, 16204>, 0,
    <17128, 16204, 16332>, 0,
    <17128, 16332, 16327>, 0,
    <17128, 16327, 17117>, 0,
    <17134, 17133, 17129>, 0,
    <17134, 17129, 17131>, 0,
    <17134, 17131, 17116>, 0,
    <17134, 17116, 17118>, 0,
    <17134, 17118, 3681>, 0,
    <17134, 3681, 17132>, 0,
    <17134, 17132, 17130>, 0,
    <17134, 17130, 17133>, 0,
    <17139, 17138, 17129>, 0,
    <17139, 17129, 17133>, 0,
    <17139, 17133, 17130>, 0,
    <17139, 17130, 17136>, 0,
    <17139, 17136, 3980>, 0,
    <17139, 3980, 17137>, 0,
    <17139, 17137, 17135>, 0,
    <17139, 17135, 17138>, 0,
    <17141, 17131, 17129>, 0,
    <17141, 17129, 17138>, 0,
    <17141, 17138, 17135>, 0,
    <17141, 17135, 17140>, 0,
    <17141, 17140, 17121>, 0,
    <17141, 17121, 17123>, 0,
    <17141, 17123, 17116>, 0,
    <17141, 17116, 17131>, 0,
    <17145, 17144, 17142>, 0,
    <17145, 17142, 17143>, 0,
    <17145, 17143, 16880>, 0,
    <17145, 16880, 16882>, 0,
    <17145, 16882, 16204>, 0,
    <17145, 16204, 17127>, 0,
    <17145, 17127, 17122>, 0,
    <17145, 17122, 17144>, 0,
    <17149, 17148, 17142>, 0,
    <17149, 17142, 17144>, 0,
    <17149, 17144, 17122>, 0,
    <17149, 17122, 17124>, 0,
    <17149, 17124, 17121>, 0,
    <17149, 17121, 17147>, 0,
    <17149, 17147, 17146>, 0,
    <17149, 17146, 17148>, 0,
    <17151, 17143, 17142>, 0,
    <17151, 17142, 17148>, 0,
    <17151, 17148, 17146>, 0,
    <17151, 17146, 17150>, 0,
    <17151, 17150, 16885>, 0,
    <17151, 16885, 16887>, 0,
    <17151, 16887, 16880>, 0,
    <17151, 16880, 17143>, 0,
    <17160, 17159, 17152>, 0,
    <17160, 17152, 17156>, 0,
    <17160, 17156, 17153>, 0,
    <17160, 17153, 17157>, 0,
    <17160, 17157, 17154>, 0,
    <17160, 17154, 17158>, 0,
    <17160, 17158, 17155>, 0,
    <17160, 17155, 17159>, 0,
    <17163, 17162, 17152>, 0,
    <17163, 17152, 17159>, 0,
    <17163, 17159, 17155>, 0,
    <17163, 17155, 17161>, 0,
    <17163, 17161, 16128>, 0,
    <17163, 16128, 16923>, 0,
    <17163, 16923, 16918>, 0,
    <17163, 16918, 17162>, 0,
    <17165, 17156, 17152>, 0,
    <17165, 17152, 17162>, 0,
    <17165, 17162, 16918>, 0,
    <17165, 16918, 16920>, 0,
    <17165, 16920, 16905>, 0,
    <17165, 16905, 17164>, 0,
    <17165, 17164, 17153>, 0,
    <17165, 17153, 17156>, 0,
    <17171, 17170, 17166>, 0,
    <17171, 17166, 17168>, 0,
    <17171, 17168, 17155>, 0,
    <17171, 17155, 17158>, 0,
    <17171, 17158, 17154>, 0,
    <17171, 17154, 17169>, 0,
    <17171, 17169, 17167>, 0,
    <17171, 17167, 17170>, 0,
    <17174, 17173, 17166>, 0,
    <17174, 17166, 17170>, 0,
    <17174, 17170, 17167>, 0,
    <17174, 17167, 17172>, 0,
    <17174, 17172, 16238>, 0,
    <17174, 16238, 16241>, 0,
    <17174, 16241, 16237>, 0,
    <17174, 16237, 17173>, 0,
    <17175, 17168, 17166>, 0,
    <17175, 17166, 17173>, 0,
    <17175, 17173, 16237>, 0,
    <17175, 16237, 16248>, 0,
    <17175, 16248, 16128>, 0,
    <17175, 16128, 17161>, 0,
    <17175, 17161, 17155>, 0,
    <17175, 17155, 17168>, 0,
    <17181, 17180, 17176>, 0,
    <17181, 17176, 17178>, 0,
    <17181, 17178, 17177>, 0,
    <17181, 17177, 17179>, 0,
    <17181, 17179, 16585>, 0,
    <17181, 16585, 16597>, 0,
    <17181, 16597, 16593>, 0,
    <17181, 16593, 17180>, 0,
    <17185, 17184, 17176>, 0,
    <17185, 17176, 17180>, 0,
    <17185, 17180, 16593>, 0,
    <17185, 16593, 16594>, 0,
    <17185, 16594, 3758>, 0,
    <17185, 3758, 17183>, 0,
    <17185, 17183, 17182>, 0,
    <17185, 17182, 17184>, 0,
    <17188, 17178, 17176>, 0,
    <17188, 17176, 17184>, 0,
    <17188, 17184, 17182>, 0,
    <17188, 17182, 17186>, 0,
    <17188, 17186, 3901>, 0,
    <17188, 3901, 17187>, 0,
    <17188, 17187, 17177>, 0,
    <17188, 17177, 17178>, 0,
    <17194, 17193, 17189>, 0,
    <17194, 17189, 17191>, 0,
    <17194, 17191, 17190>, 0,
    <17194, 17190, 17192>, 0,
    <17194, 17192, 16684>, 0,
    <17194, 16684, 16696>, 0,
    <17194, 16696, 16692>, 0,
    <17194, 16692, 17193>, 0,
    <17198, 17197, 17189>, 0,
    <17198, 17189, 17193>, 0,
    <17198, 17193, 16692>, 0,
    <17198, 16692, 16693>, 0,
    <17198, 16693, 16585>, 0,
    <17198, 16585, 17196>, 0,
    <17198, 17196, 17195>, 0,
    <17198, 17195, 17197>, 0,
    <17202, 17191, 17189>, 0,
    <17202, 17189, 17197>, 0,
    <17202, 17197, 17195>, 0,
    <17202, 17195, 17200>, 0,
    <17202, 17200, 17199>, 0,
    <17202, 17199, 17201>, 0,
    <17202, 17201, 17190>, 0,
    <17202, 17190, 17191>, 0,
    <17206, 17205, 17203>, 0,
    <17206, 17203, 17204>, 0,
    <17206, 17204, 17195>, 0,
    <17206, 17195, 17196>, 0,
    <17206, 17196, 16585>, 0,
    <17206, 16585, 17179>, 0,
    <17206, 17179, 17177>, 0,
    <17206, 17177, 17205>, 0,
    <17210, 17209, 17203>, 0,
    <17210, 17203, 17205>, 0,
    <17210, 17205, 17177>, 0,
    <17210, 17177, 17187>, 0,
    <17210, 17187, 3901>, 0,
    <17210, 3901, 17208>, 0,
    <17210, 17208, 17207>, 0,
    <17210, 17207, 17209>, 0,
    <17212, 17204, 17203>, 0,
    <17212, 17203, 17209>, 0,
    <17212, 17209, 17207>, 0,
    <17212, 17207, 17211>, 0,
    <17212, 17211, 17199>, 0,
    <17212, 17199, 17200>, 0,
    <17212, 17200, 17195>, 0,
    <17212, 17195, 17204>, 0,
    <17221, 17220, 17213>, 0,
    <17221, 17213, 17217>, 0,
    <17221, 17217, 17214>, 0,
    <17221, 17214, 17218>, 0,
    <17221, 17218, 17215>, 0,
    <17221, 17215, 17219>, 0,
    <17221, 17219, 17216>, 0,
    <17221, 17216, 17220>, 0,
    <17226, 17225, 17213>, 0,
    <17226, 17213, 17220>, 0,
    <17226, 17220, 17216>, 0,
    <17226, 17216, 17223>, 0,
    <17226, 17223, 3907>, 0,
    <17226, 3907, 17224>, 0,
    <17226, 17224, 17222>, 0,
    <17226, 17222, 17225>, 0,
    <17229, 17217, 17213>, 0,
    <17229, 17213, 17225>, 0,
    <17229, 17225, 17222>, 0,
    <17229, 17222, 17227>, 0,
    <17229, 17227, 3764>, 0,
    <17229, 3764, 17228>, 0,
    <17229, 17228, 17214>, 0,
    <17229, 17214, 17217>, 0,
    <17235, 17234, 17230>, 0,
    <17235, 17230, 17232>, 0,
    <17235, 17232, 17231>, 0,
    <17235, 17231, 17233>, 0,
    <17235, 17233, 17215>, 0,
    <17235, 17215, 17218>, 0,
    <17235, 17218, 17214>, 0,
    <17235, 17214, 17234>, 0,
    <17237, 17236, 17230>, 0,
    <17237, 17230, 17234>, 0,
    <17237, 17234, 17214>, 0,
    <17237, 17214, 17228>, 0,
    <17237, 17228, 3764>, 0,
    <17237, 3764, 16609>, 0,
    <17237, 16609, 16602>, 0,
    <17237, 16602, 17236>, 0,
    <17239, 17232, 17230>, 0,
    <17239, 17230, 17236>, 0,
    <17239, 17236, 16602>, 0,
    <17239, 16602, 16605>, 0,
    <17239, 16605, 16601>, 0,
    <17239, 16601, 17238>, 0,
    <17239, 17238, 17231>, 0,
    <17239, 17231, 17232>, 0,
    <17245, 17244, 17240>, 0,
    <17245, 17240, 17242>, 0,
    <17245, 17242, 17241>, 0,
    <17245, 17241, 17243>, 0,
    <17245, 17243, 16358>, 0,
    <17245, 16358, 16380>, 0,
    <17245, 16380, 16376>, 0,
    <17245, 16376, 17244>, 0,
    <17249, 17248, 17240>, 0,
    <17249, 17240, 17244>, 0,
    <17249, 17244, 16376>, 0,
    <17249, 16376, 16377>, 0,
    <17249, 16377, 16270>, 0,
    <17249, 16270, 17247>, 0,
    <17249, 17247, 17246>, 0,
    <17249, 17246, 17248>, 0,
    <17253, 17242, 17240>, 0,
    <17253, 17240, 17248>, 0,
    <17253, 17248, 17246>, 0,
    <17253, 17246, 17251>, 0,
    <17253, 17251, 17250>, 0,
    <17253, 17250, 17252>, 0,
    <17253, 17252, 17241>, 0,
    <17253, 17241, 17242>, 0,
    <17257, 17256, 17254>, 0,
    <17257, 17254, 17255>, 0,
    <17257, 17255, 17246>, 0,
    <17257, 17246, 17247>, 0,
    <17257, 17247, 16270>, 0,
    <17257, 16270, 16957>, 0,
    <17257, 16957, 16955>, 0,
    <17257, 16955, 17256>, 0,
    <17261, 17260, 17254>, 0,
    <17261, 17254, 17256>, 0,
    <17261, 17256, 16955>, 0,
    <17261, 16955, 16966>, 0,
    <17261, 16966, 16964>, 0,
    <17261, 16964, 17259>, 0,
    <17261, 17259, 17258>, 0,
    <17261, 17258, 17260>, 0,
    <17263, 17255, 17254>, 0,
    <17263, 17254, 17260>, 0,
    <17263, 17260, 17258>, 0,
    <17263, 17258, 17262>, 0,
    <17263, 17262, 17250>, 0,
    <17263, 17250, 17251>, 0,
    <17263, 17251, 17246>, 0,
    <17263, 17246, 17255>, 0,
    <17272, 17271, 17264>, 0,
    <17272, 17264, 17268>, 0,
    <17272, 17268, 17265>, 0,
    <17272, 17265, 17269>, 0,
    <17272, 17269, 17266>, 0,
    <17272, 17266, 17270>, 0,
    <17272, 17270, 17267>, 0,
    <17272, 17267, 17271>, 0,
    <17275, 17274, 17264>, 0,
    <17275, 17264, 17271>, 0,
    <17275, 17271, 17267>, 0,
    <17275, 17267, 17273>, 0,
    <17275, 17273, 16980>, 0,
    <17275, 16980, 16995>, 0,
    <17275, 16995, 16993>, 0,
    <17275, 16993, 17274>, 0,
    <17277, 17268, 17264>, 0,
    <17277, 17264, 17274>, 0,
    <17277, 17274, 16993>, 0,
    <17277, 16993, 17000>, 0,
    <17277, 17000, 16176>, 0,
    <17277, 16176, 17276>, 0,
    <17277, 17276, 17265>, 0,
    <17277, 17265, 17268>, 0,
    <17283, 17282, 17278>, 0,
    <17283, 17278, 17280>, 0,
    <17283, 17280, 17279>, 0,
    <17283, 17279, 17281>, 0,
    <17283, 17281, 17266>, 0,
    <17283, 17266, 17269>, 0,
    <17283, 17269, 17265>, 0,
    <17283, 17265, 17282>, 0,
    <17285, 17284, 17278>, 0,
    <17285, 17278, 17282>, 0,
    <17285, 17282, 17265>, 0,
    <17285, 17265, 17276>, 0,
    <17285, 17276, 16176>, 0,
    <17285, 16176, 16293>, 0,
    <17285, 16293, 16287>, 0,
    <17285, 16287, 17284>, 0,
    <17287, 17280, 17278>, 0,
    <17287, 17278, 17284>, 0,
    <17287, 17284, 16287>, 0,
    <17287, 16287, 16290>, 0,
    <17287, 16290, 16286>, 0,
    <17287, 16286, 17286>, 0,
    <17287, 17286, 17279>, 0,
    <17287, 17279, 17280>, 0,
    <17293, 17292, 17288>, 0,
    <17293, 17288, 17290>, 0,
    <17293, 17290, 17020>, 0,
    <17293, 17020, 17021>, 0,
    <17293, 17021, 17008>, 0,
    <17293, 17008, 17291>, 0,
    <17293, 17291, 17289>, 0,
    <17293, 17289, 17292>, 0,
    <17296, 17295, 17288>, 0,
    <17296, 17288, 17292>, 0,
    <17296, 17292, 17289>, 0,
    <17296, 17289, 17294>, 0,
    <17296, 17294, 3929>, 0,
    <17296, 3929, 3930>, 0,
    <17296, 3930, 3925>, 0,
    <17296, 3925, 17295>, 0,
    <17297, 17290, 17288>, 0,
    <17297, 17288, 17295>, 0,
    <17297, 17295, 3925>, 0,
    <17297, 3925, 3926>, 0,
    <17297, 3926, 3873>, 0,
    <17297, 3873, 17024>, 0,
    <17297, 17024, 17020>, 0,
    <17297, 17020, 17290>, 0,
    <17303, 17302, 17298>, 0,
    <17303, 17298, 17300>, 0,
    <17303, 17300, 16788>, 0,
    <17303, 16788, 16789>, 0,
    <17303, 16789, 16776>, 0,
    <17303, 16776, 17301>, 0,
    <17303, 17301, 17299>, 0,
    <17303, 17299, 17302>, 0,
    <17309, 17308, 17298>, 0,
    <17309, 17298, 17302>, 0,
    <17309, 17302, 17299>, 0,
    <17309, 17299, 17306>, 0,
    <17309, 17306, 17304>, 0,
    <17309, 17304, 17307>, 0,
    <17309, 17307, 17305>, 0,
    <17309, 17305, 17308>, 0,
    <17311, 17300, 17298>, 0,
    <17311, 17298, 17308>, 0,
    <17311, 17308, 17305>, 0,
    <17311, 17305, 17310>, 0,
    <17311, 17310, 16632>, 0,
    <17311, 16632, 16792>, 0,
    <17311, 16792, 16788>, 0,
    <17311, 16788, 17300>, 0,
    <17315, 17314, 17312>, 0,
    <17315, 17312, 17313>, 0,
    <17315, 17313, 17068>, 0,
    <17315, 17068, 17070>, 0,
    <17315, 17070, 16632>, 0,
    <17315, 16632, 17310>, 0,
    <17315, 17310, 17305>, 0,
    <17315, 17305, 17314>, 0,
    <17319, 17318, 17312>, 0,
    <17319, 17312, 17314>, 0,
    <17319, 17314, 17305>, 0,
    <17319, 17305, 17307>, 0,
    <17319, 17307, 17304>, 0,
    <17319, 17304, 17317>, 0,
    <17319, 17317, 17316>, 0,
    <17319, 17316, 17318>, 0,
    <17321, 17313, 17312>, 0,
    <17321, 17312, 17318>, 0,
    <17321, 17318, 17316>, 0,
    <17321, 17316, 17320>, 0,
    <17321, 17320, 17073>, 0,
    <17321, 17073, 17075>, 0,
    <17321, 17075, 17068>, 0,
    <17321, 17068, 17313>, 0,
    <17330, 17329, 17322>, 0,
    <17330, 17322, 17326>, 0,
    <17330, 17326, 17323>, 0,
    <17330, 17323, 17327>, 0,
    <17330, 17327, 17324>, 0,
    <17330, 17324, 17328>, 0,
    <17330, 17328, 17325>, 0,
    <17330, 17325, 17329>, 0,
    <17333, 17332, 17322>, 0,
    <17333, 17322, 17329>, 0,
    <17333, 17329, 17325>, 0,
    <17333, 17325, 17331>, 0,
    <17333, 17331, 16543>, 0,
    <17333, 16543, 17111>, 0,
    <17333, 17111, 17106>, 0,
    <17333, 17106, 17332>, 0,
    <17335, 17326, 17322>, 0,
    <17335, 17322, 17332>, 0,
    <17335, 17332, 17106>, 0,
    <17335, 17106, 17108>, 0,
    <17335, 17108, 17093>, 0,
    <17335, 17093, 17334>, 0,
    <17335, 17334, 17323>, 0,
    <17335, 17323, 17326>, 0,
    <17341, 17340, 17336>, 0,
    <17341, 17336, 17338>, 0,
    <17341, 17338, 17325>, 0,
    <17341, 17325, 17328>, 0,
    <17341, 17328, 17324>, 0,
    <17341, 17324, 17339>, 0,
    <17341, 17339, 17337>, 0,
    <17341, 17337, 17340>, 0,
    <17344, 17343, 17336>, 0,
    <17344, 17336, 17340>, 0,
    <17344, 17340, 17337>, 0,
    <17344, 17337, 17342>, 0,
    <17344, 17342, 16652>, 0,
    <17344, 16652, 16655>, 0,
    <17344, 16655, 16651>, 0,
    <17344, 16651, 17343>, 0,
    <17345, 17338, 17336>, 0,
    <17345, 17336, 17343>, 0,
    <17345, 17343, 16651>, 0,
    <17345, 16651, 16662>, 0,
    <17345, 16662, 16543>, 0,
    <17345, 16543, 17331>, 0,
    <17345, 17331, 17325>, 0,
    <17345, 17325, 17338>, 0,
    <17351, 17350, 17346>, 0,
    <17351, 17346, 17348>, 0,
    <17351, 17348, 17347>, 0,
    <17351, 17347, 17349>, 0,
    <17351, 17349, 16732>, 0,
    <17351, 16732, 16744>, 0,
    <17351, 16744, 16740>, 0,
    <17351, 16740, 17350>, 0,
    <17355, 17354, 17346>, 0,
    <17355, 17346, 17350>, 0,
    <17355, 17350, 16740>, 0,
    <17355, 16740, 16741>, 0,
    <17355, 16741, 16684>, 0,
    <17355, 16684, 17353>, 0,
    <17355, 17353, 17352>, 0,
    <17355, 17352, 17354>, 0,
    <17359, 17348, 17346>, 0,
    <17359, 17346, 17354>, 0,
    <17359, 17354, 17352>, 0,
    <17359, 17352, 17357>, 0,
    <17359, 17357, 17356>, 0,
    <17359, 17356, 17358>, 0,
    <17359, 17358, 17347>, 0,
    <17359, 17347, 17348>, 0,
    <17363, 17362, 17360>, 0,
    <17363, 17360, 17361>, 0,
    <17363, 17361, 17352>, 0,
    <17363, 17352, 17353>, 0,
    <17363, 17353, 16684>, 0,
    <17363, 16684, 17192>, 0,
    <17363, 17192, 17190>, 0,
    <17363, 17190, 17362>, 0,
    <17367, 17366, 17360>, 0,
    <17367, 17360, 17362>, 0,
    <17367, 17362, 17190>, 0,
    <17367, 17190, 17201>, 0,
    <17367, 17201, 17199>, 0,
    <17367, 17199, 17365>, 0,
    <17367, 17365, 17364>, 0,
    <17367, 17364, 17366>, 0,
    <17369, 17361, 17360>, 0,
    <17369, 17360, 17366>, 0,
    <17369, 17366, 17364>, 0,
    <17369, 17364, 17368>, 0,
    <17369, 17368, 17356>, 0,
    <17369, 17356, 17357>, 0,
    <17369, 17357, 17352>, 0,
    <17369, 17352, 17361>, 0,
    <17378, 17377, 17370>, 0,
    <17378, 17370, 17374>, 0,
    <17378, 17374, 17371>, 0,
    <17378, 17371, 17375>, 0,
    <17378, 17375, 17372>, 0,
    <17378, 17372, 17376>, 0,
    <17378, 17376, 17373>, 0,
    <17378, 17373, 17377>, 0,
    <17381, 17380, 17370>, 0,
    <17381, 17370, 17377>, 0,
    <17381, 17377, 17373>, 0,
    <17381, 17373, 17379>, 0,
    <17381, 17379, 17215>, 0,
    <17381, 17215, 17233>, 0,
    <17381, 17233, 17231>, 0,
    <17381, 17231, 17380>, 0,
    <17383, 17374, 17370>, 0,
    <17383, 17370, 17380>, 0,
    <17383, 17380, 17231>, 0,
    <17383, 17231, 17238>, 0,
    <17383, 17238, 16601>, 0,
    <17383, 16601, 17382>, 0,
    <17383, 17382, 17371>, 0,
    <17383, 17371, 17374>, 0,
    <17389, 17388, 17384>, 0,
    <17389, 17384, 17386>, 0,
    <17389, 17386, 17385>, 0,
    <17389, 17385, 17387>, 0,
    <17389, 17387, 17372>, 0,
    <17389, 17372, 17375>, 0,
    <17389, 17375, 17371>, 0,
    <17389, 17371, 17388>, 0,
    <17391, 17390, 17384>, 0,
    <17391, 17384, 17388>, 0,
    <17391, 17388, 17371>, 0,
    <17391, 17371, 17382>, 0,
    <17391, 17382, 16601>, 0,
    <17391, 16601, 16707>, 0,
    <17391, 16707, 16701>, 0,
    <17391, 16701, 17390>, 0,
    <17393, 17386, 17384>, 0,
    <17393, 17384, 17390>, 0,
    <17393, 17390, 16701>, 0,
    <17393, 16701, 16704>, 0,
    <17393, 16704, 16700>, 0,
    <17393, 16700, 17392>, 0,
    <17393, 17392, 17385>, 0,
    <17393, 17385, 17386>, 0,
    <17399, 17398, 17394>, 0,
    <17399, 17394, 17396>, 0,
    <17399, 17396, 17085>, 0,
    <17399, 17085, 17086>, 0,
    <17399, 17086, 17073>, 0,
    <17399, 17073, 17397>, 0,
    <17399, 17397, 17395>, 0,
    <17399, 17395, 17398>, 0,
    <17405, 17404, 17394>, 0,
    <17405, 17394, 17398>, 0,
    <17405, 17398, 17395>, 0,
    <17405, 17395, 17402>, 0,
    <17405, 17402, 17400>, 0,
    <17405, 17400, 17403>, 0,
    <17405, 17403, 17401>, 0,
    <17405, 17401, 17404>, 0,
    <17407, 17396, 17394>, 0,
    <17407, 17394, 17404>, 0,
    <17407, 17404, 17401>, 0,
    <17407, 17401, 17406>, 0,
    <17407, 17406, 17008>, 0,
    <17407, 17008, 17089>, 0,
    <17407, 17089, 17085>, 0,
    <17407, 17085, 17396>, 0,
    <17411, 17410, 17408>, 0,
    <17411, 17408, 17409>, 0,
    <17411, 17409, 17289>, 0,
    <17411, 17289, 17291>, 0,
    <17411, 17291, 17008>, 0,
    <17411, 17008, 17406>, 0,
    <17411, 17406, 17401>, 0,
    <17411, 17401, 17410>, 0,
    <17415, 17414, 17408>, 0,
    <17415, 17408, 17410>, 0,
    <17415, 17410, 17401>, 0,
    <17415, 17401, 17403>, 0,
    <17415, 17403, 17400>, 0,
    <17415, 17400, 17413>, 0,
    <17415, 17413, 17412>, 0,
    <17415, 17412, 17414>, 0,
    <17417, 17409, 17408>, 0,
    <17417, 17408, 17414>, 0,
    <17417, 17414, 17412>, 0,
    <17417, 17412, 17416>, 0,
    <17417, 17416, 3929>, 0,
    <17417, 3929, 17294>, 0,
    <17417, 17294, 17289>, 0,
    <17417, 17289, 17409>, 0,
    <17423, 17422, 17418>, 0,
    <17423, 17418, 17420>, 0,
    <17423, 17420, 17412>, 0,
    <17423, 17412, 17413>, 0,
    <17423, 17413, 17400>, 0,
    <17423, 17400, 17421>, 0,
    <17423, 17421, 17419>, 0,
    <17423, 17419, 17422>, 0,
    <17426, 17425, 17418>, 0,
    <17426, 17418, 17422>, 0,
    <17426, 17422, 17419>, 0,
    <17426, 17419, 17424>, 0,
    <17426, 17424, 3887>, 0,
    <17426, 3887, 3975>, 0,
    <17426, 3975, 3970>, 0,
    <17426, 3970, 17425>, 0,
    <17427, 17420, 17418>, 0,
    <17427, 17418, 17425>, 0,
    <17427, 17425, 3970>, 0,
    <17427, 3970, 3972>, 0,
    <17427, 3972, 3929>, 0,
    <17427, 3929, 17416>, 0,
    <17427, 17416, 17412>, 0,
    <17427, 17412, 17420>, 0,
    <17433, 17432, 17428>, 0,
    <17433, 17428, 17430>, 0,
    <17433, 17430, 17419>, 0,
    <17433, 17419, 17421>, 0,
    <17433, 17421, 17400>, 0,
    <17433, 17400, 17431>, 0,
    <17433, 17431, 17429>, 0,
    <17433, 17429, 17432>, 0,
    <17436, 17435, 17428>, 0,
    <17436, 17428, 17432>, 0,
    <17436, 17432, 17429>, 0,
    <17436, 17429, 17434>, 0,
    <17436, 17434, 17028>, 0,
    <17436, 17028, 17031>, 0,
    <17436, 17031, 17027>, 0,
    <17436, 17027, 17435>, 0,
    <17437, 17430, 17428>, 0,
    <17437, 17428, 17435>, 0,
    <17437, 17435, 17027>, 0,
    <17437, 17027, 17041>, 0,
    <17437, 17041, 3887>, 0,
    <17437, 3887, 17424>, 0,
    <17437, 17424, 17419>, 0,
    <17437, 17419, 17430>, 0,
    <17445, 17444, 17438>, 0,
    <17445, 17438, 17441>, 0,
    <17445, 17441, 17439>, 0,
    <17445, 17439, 17442>, 0,
    <17445, 17442, 4082>, 0,
    <17445, 4082, 17443>, 0,
    <17445, 17443, 17440>, 0,
    <17445, 17440, 17444>, 0,
    <17448, 17447, 17438>, 0,
    <17448, 17438, 17444>, 0,
    <17448, 17444, 17440>, 0,
    <17448, 17440, 17446>, 0,
    <17448, 17446, 4105>, 0,
    <17448, 4105, 16822>, 0,
    <17448, 16822, 16819>, 0,
    <17448, 16819, 17447>, 0,
    <17450, 17441, 17438>, 0,
    <17450, 17438, 17447>, 0,
    <17450, 17447, 16819>, 0,
    <17450, 16819, 16829>, 0,
    <17450, 16829, 16238>, 0,
    <17450, 16238, 17449>, 0,
    <17450, 17449, 17439>, 0,
    <17450, 17439, 17441>, 0,
    <17456, 17455, 17451>, 0,
    <17456, 17451, 17453>, 0,
    <17456, 17453, 17135>, 0,
    <17456, 17135, 17137>, 0,
    <17456, 17137, 3980>, 0,
    <17456, 3980, 17454>, 0,
    <17456, 17454, 17452>, 0,
    <17456, 17452, 17455>, 0,
    <17461, 17460, 17451>, 0,
    <17461, 17451, 17455>, 0,
    <17461, 17455, 17452>, 0,
    <17461, 17452, 17458>, 0,
    <17461, 17458, 3987>, 0,
    <17461, 3987, 17459>, 0,
    <17461, 17459, 17457>, 0,
    <17461, 17457, 17460>, 0,
    <17463, 17453, 17451>, 0,
    <17463, 17451, 17460>, 0,
    <17463, 17460, 17457>, 0,
    <17463, 17457, 17462>, 0,
    <17463, 17462, 17121>, 0,
    <17463, 17121, 17140>, 0,
    <17463, 17140, 17135>, 0,
    <17463, 17135, 17453>, 0,
    <17469, 17468, 17464>, 0,
    <17469, 17464, 17466>, 0,
    <17469, 17466, 17465>, 0,
    <17469, 17465, 17467>, 0,
    <17469, 17467, 4082>, 0,
    <17469, 4082, 17442>, 0,
    <17469, 17442, 17439>, 0,
    <17469, 17439, 17468>, 0,
    <17471, 17470, 17464>, 0,
    <17471, 17464, 17468>, 0,
    <17471, 17468, 17439>, 0,
    <17471, 17439, 17449>, 0,
    <17471, 17449, 16238>, 0,
    <17471, 16238, 17172>, 0,
    <17471, 17172, 17167>, 0,
    <17471, 17167, 17470>, 0,
    <17473, 17466, 17464>, 0,
    <17473, 17464, 17470>, 0,
    <17473, 17470, 17167>, 0,
    <17473, 17167, 17169>, 0,
    <17473, 17169, 17154>, 0,
    <17473, 17154, 17472>, 0,
    <17473, 17472, 17465>, 0,
    <17473, 17465, 17466>, 0,
    <17479, 17478, 17474>, 0,
    <17479, 17474, 17476>, 0,
    <17479, 17476, 17316>, 0,
    <17479, 17316, 17317>, 0,
    <17479, 17317, 17304>, 0,
    <17479, 17304, 17477>, 0,
    <17479, 17477, 17475>, 0,
    <17479, 17475, 17478>, 0,
    <17485, 17484, 17474>, 0,
    <17485, 17474, 17478>, 0,
    <17485, 17478, 17475>, 0,
    <17485, 17475, 17482>, 0,
    <17485, 17482, 17480>, 0,
    <17485, 17480, 17483>, 0,
    <17485, 17483, 17481>, 0,
    <17485, 17481, 17484>, 0,
    <17487, 17476, 17474>, 0,
    <17487, 17474, 17484>, 0,
    <17487, 17484, 17481>, 0,
    <17487, 17481, 17486>, 0,
    <17487, 17486, 17073>, 0,
    <17487, 17073, 17320>, 0,
    <17487, 17320, 17316>, 0,
    <17487, 17316, 17476>, 0,
    <17491, 17490, 17488>, 0,
    <17491, 17488, 17489>, 0,
    <17491, 17489, 17395>, 0,
    <17491, 17395, 17397>, 0,
    <17491, 17397, 17073>, 0,
    <17491, 17073, 17486>, 0,
    <17491, 17486, 17481>, 0,
    <17491, 17481, 17490>, 0,
    <17495, 17494, 17488>, 0,
    <17495, 17488, 17490>, 0,
    <17495, 17490, 17481>, 0,
    <17495, 17481, 17483>, 0,
    <17495, 17483, 17480>, 0,
    <17495, 17480, 17493>, 0,
    <17495, 17493, 17492>, 0,
    <17495, 17492, 17494>, 0,
    <17497, 17489, 17488>, 0,
    <17497, 17488, 17494>, 0,
    <17497, 17494, 17492>, 0,
    <17497, 17492, 17496>, 0,
    <17497, 17496, 17400>, 0,
    <17497, 17400, 17402>, 0,
    <17497, 17402, 17395>, 0,
    <17497, 17395, 17489>, 0,
    <17503, 17502, 17498>, 0,
    <17503, 17498, 17500>, 0,
    <17503, 17500, 17492>, 0,
    <17503, 17492, 17493>, 0,
    <17503, 17493, 17480>, 0,
    <17503, 17480, 17501>, 0,
    <17503, 17501, 17499>, 0,
    <17503, 17499, 17502>, 0,
    <17506, 17505, 17498>, 0,
    <17506, 17498, 17502>, 0,
    <17506, 17502, 17499>, 0,
    <17506, 17499, 17504>, 0,
    <17506, 17504, 17028>, 0,
    <17506, 17028, 17434>, 0,
    <17506, 17434, 17429>, 0,
    <17506, 17429, 17505>, 0,
    <17507, 17500, 17498>, 0,
    <17507, 17498, 17505>, 0,
    <17507, 17505, 17429>, 0,
    <17507, 17429, 17431>, 0,
    <17507, 17431, 17400>, 0,
    <17507, 17400, 17496>, 0,
    <17507, 17496, 17492>, 0,
    <17507, 17492, 17500>, 0,
    <17513, 17512, 17508>, 0,
    <17513, 17508, 17510>, 0,
    <17513, 17510, 17499>, 0,
    <17513, 17499, 17501>, 0,
    <17513, 17501, 17480>, 0,
    <17513, 17480, 17511>, 0,
    <17513, 17511, 17509>, 0,
    <17513, 17509, 17512>, 0,
    <17516, 17515, 17508>, 0,
    <17516, 17508, 17512>, 0,
    <17516, 17512, 17509>, 0,
    <17516, 17509, 17514>, 0,
    <17516, 17514, 17093>, 0,
    <17516, 17093, 17096>, 0,
    <17516, 17096, 17092>, 0,
    <17516, 17092, 17515>, 0,
    <17517, 17510, 17508>, 0,
    <17517, 17508, 17515>, 0,
    <17517, 17515, 17092>, 0,
    <17517, 17092, 17103>, 0,
    <17517, 17103, 17028>, 0,
    <17517, 17028, 17504>, 0,
    <17517, 17504, 17499>, 0,
    <17517, 17499, 17510>, 0,
    <17523, 17522, 17518>, 0,
    <17523, 17518, 17520>, 0,
    <17523, 17520, 17519>, 0,
    <17523, 17519, 17521>, 0,
    <17523, 17521, 16841>, 0,
    <17523, 16841, 16853>, 0,
    <17523, 16853, 16849>, 0,
    <17523, 16849, 17522>, 0,
    <17527, 17526, 17518>, 0,
    <17527, 17518, 17522>, 0,
    <17527, 17522, 16849>, 0,
    <17527, 16849, 16850>, 0,
    <17527, 16850, 16732>, 0,
    <17527, 16732, 17525>, 0,
    <17527, 17525, 17524>, 0,
    <17527, 17524, 17526>, 0,
    <17531, 17520, 17518>, 0,
    <17531, 17518, 17526>, 0,
    <17531, 17526, 17524>, 0,
    <17531, 17524, 17529>, 0,
    <17531, 17529, 17528>, 0,
    <17531, 17528, 17530>, 0,
    <17531, 17530, 17519>, 0,
    <17531, 17519, 17520>, 0,
    <17535, 17534, 17532>, 0,
    <17535, 17532, 17533>, 0,
    <17535, 17533, 17524>, 0,
    <17535, 17524, 17525>, 0,
    <17535, 17525, 16732>, 0,
    <17535, 16732, 17349>, 0,
    <17535, 17349, 17347>, 0,
    <17535, 17347, 17534>, 0,
    <17539, 17538, 17532>, 0,
    <17539, 17532, 17534>, 0,
    <17539, 17534, 17347>, 0,
    <17539, 17347, 17358>, 0,
    <17539, 17358, 17356>, 0,
    <17539, 17356, 17537>, 0,
    <17539, 17537, 17536>, 0,
    <17539, 17536, 17538>, 0,
    <17541, 17533, 17532>, 0,
    <17541, 17532, 17538>, 0,
    <17541, 17538, 17536>, 0,
    <17541, 17536, 17540>, 0,
    <17541, 17540, 17528>, 0,
    <17541, 17528, 17529>, 0,
    <17541, 17529, 17524>, 0,
    <17541, 17524, 17533>, 0,
    <17550, 17549, 17542>, 0,
    <17550, 17542, 17546>, 0,
    <17550, 17546, 17543>, 0,
    <17550, 17543, 17547>, 0,
    <17550, 17547, 17544>, 0,
    <17550, 17544, 17548>, 0,
    <17550, 17548, 17545>, 0,
    <17550, 17545, 17549>, 0,
    <17553, 17552, 17542>, 0,
    <17553, 17542, 17549>, 0,
    <17553, 17549, 17545>, 0,
    <17553, 17545, 17551>, 0,
    <17553, 17551, 17372>, 0,
    <17553, 17372, 17387>, 0,
    <17553, 17387, 17385>, 0,
    <17553, 17385, 17552>, 0,
    <17555, 17546, 17542>, 0,
    <17555, 17542, 17552>, 0,
    <17555, 17552, 17385>, 0,
    <17555, 17385, 17392>, 0,
    <17555, 17392, 16700>, 0,
    <17555, 16700, 17554>, 0,
    <17555, 17554, 17543>, 0,
    <17555, 17543, 17546>, 0,
    <17561, 17560, 17556>, 0,
    <17561, 17556, 17558>, 0,
    <17561, 17558, 17557>, 0,
    <17561, 17557, 17559>, 0,
    <17561, 17559, 17544>, 0,
    <17561, 17544, 17547>, 0,
    <17561, 17547, 17543>, 0,
    <17561, 17543, 17560>, 0,
    <17563, 17562, 17556>, 0,
    <17563, 17556, 17560>, 0,
    <17563, 17560, 17543>, 0,
    <17563, 17543, 17554>, 0,
    <17563, 17554, 16700>, 0,
    <17563, 16700, 16755>, 0,
    <17563, 16755, 16749>, 0,
    <17563, 16749, 17562>, 0,
    <17565, 17558, 17556>, 0,
    <17565, 17556, 17562>, 0,
    <17565, 17562, 16749>, 0,
    <17565, 16749, 16752>, 0,
    <17565, 16752, 16748>, 0,
    <17565, 16748, 17564>, 0,
    <17565, 17564, 17557>, 0,
    <17565, 17557, 17558>, 0,
    <17571, 17570, 17566>, 0,
    <17571, 17566, 17568>, 0,
    <17571, 17568, 17567>, 0,
    <17571, 17567, 17569>, 0,
    <17571, 17569, 17199>, 0,
    <17571, 17199, 17211>, 0,
    <17571, 17211, 17207>, 0,
    <17571, 17207, 17570>, 0,
    <17573, 17572, 17566>, 0,
    <17573, 17566, 17570>, 0,
    <17573, 17570, 17207>, 0,
    <17573, 17207, 17208>, 0,
    <17573, 17208, 3901>, 0,
    <17573, 3901, 3999>, 0,
    <17573, 3999, 3997>, 0,
    <17573, 3997, 17572>, 0,
    <17575, 17568, 17566>, 0,
    <17575, 17566, 17572>, 0,
    <17575, 17572, 3997>, 0,
    <17575, 3997, 4008>, 0,
    <17575, 4008, 4006>, 0,
    <17575, 4006, 17574>, 0,
    <17575, 17574, 17567>, 0,
    <17575, 17567, 17568>, 0,
    <17581, 17580, 17576>, 0,
    <17581, 17576, 17578>, 0,
    <17581, 17578, 16897>, 0,
    <17581, 16897, 16898>, 0,
    <17581, 16898, 16885>, 0,
    <17581, 16885, 17579>, 0,
    <17581, 17579, 17577>, 0,
    <17581, 17577, 17580>, 0,
    <17587, 17586, 17576>, 0,
    <17587, 17576, 17580>, 0,
    <17587, 17580, 17577>, 0,
    <17587, 17577, 17584>, 0,
    <17587, 17584, 17582>, 0,
    <17587, 17582, 17585>, 0,
    <17587, 17585, 17583>, 0,
    <17587, 17583, 17586>, 0,
    <17589, 17578, 17576>, 0,
    <17589, 17576, 17586>, 0,
    <17589, 17586, 17583>, 0,
    <17589, 17583, 17588>, 0,
    <17589, 17588, 16776>, 0,
    <17589, 16776, 16901>, 0,
    <17589, 16901, 16897>, 0,
    <17589, 16897, 17578>, 0,
    <17593, 17592, 17590>, 0,
    <17593, 17590, 17591>, 0,
    <17593, 17591, 17299>, 0,
    <17593, 17299, 17301>, 0,
    <17593, 17301, 16776>, 0,
    <17593, 16776, 17588>, 0,
    <17593, 17588, 17583>, 0,
    <17593, 17583, 17592>, 0,
    <17597, 17596, 17590>, 0,
    <17597, 17590, 17592>, 0,
    <17597, 17592, 17583>, 0,
    <17597, 17583, 17585>, 0,
    <17597, 17585, 17582>, 0,
    <17597, 17582, 17595>, 0,
    <17597, 17595, 17594>, 0,
    <17597, 17594, 17596>, 0,
    <17599, 17591, 17590>, 0,
    <17599, 17590, 17596>, 0,
    <17599, 17596, 17594>, 0,
    <17599, 17594, 17598>, 0,
    <17599, 17598, 17304>, 0,
    <17599, 17304, 17306>, 0,
    <17599, 17306, 17299>, 0,
    <17599, 17299, 17591>, 0,
    <17608, 17607, 17600>, 0,
    <17608, 17600, 17604>, 0,
    <17608, 17604, 17601>, 0,
    <17608, 17601, 17605>, 0,
    <17608, 17605, 17602>, 0,
    <17608, 17602, 17606>, 0,
    <17608, 17606, 17603>, 0,
    <17608, 17603, 17607>, 0,
    <17611, 17610, 17600>, 0,
    <17611, 17600, 17607>, 0,
    <17611, 17607, 17603>, 0,
    <17611, 17603, 17609>, 0,
    <17611, 17609, 16652>, 0,
    <17611, 16652, 17342>, 0,
    <17611, 17342, 17337>, 0,
    <17611, 17337, 17610>, 0,
    <17613, 17604, 17600>, 0,
    <17613, 17600, 17610>, 0,
    <17613, 17610, 17337>, 0,
    <17613, 17337, 17339>, 0,
    <17613, 17339, 17324>, 0,
    <17613, 17324, 17612>, 0,
    <17613, 17612, 17601>, 0,
    <17613, 17601, 17604>, 0,
    <17619, 17618, 17614>, 0,
    <17619, 17614, 17616>, 0,
    <17619, 17616, 17603>, 0,
    <17619, 17603, 17606>, 0,
    <17619, 17606, 17602>, 0,
    <17619, 17602, 17617>, 0,
    <17619, 17617, 17615>, 0,
    <17619, 17615, 17618>, 0,
    <17622, 17621, 17614>, 0,
    <17622, 17614, 17618>, 0,
    <17622, 17618, 17615>, 0,
    <17622, 17615, 17620>, 0,
    <17622, 17620, 16796>, 0,
    <17622, 16796, 16799>, 0,
    <17622, 16799, 16795>, 0,
    <17622, 16795, 17621>, 0,
    <17623, 17616, 17614>, 0,
    <17623, 17614, 17621>, 0,
    <17623, 17621, 16795>, 0,
    <17623, 16795, 16806>, 0,
    <17623, 16806, 16652>, 0,
    <17623, 16652, 17609>, 0,
    <17623, 17609, 17603>, 0,
    <17623, 17603, 17616>, 0,
    <17629, 17628, 17624>, 0,
    <17629, 17624, 17626>, 0,
    <17629, 17626, 17625>, 0,
    <17629, 17625, 17627>, 0,
    <17629, 17627, 17356>, 0,
    <17629, 17356, 17368>, 0,
    <17629, 17368, 17364>, 0,
    <17629, 17364, 17628>, 0,
    <17633, 17632, 17624>, 0,
    <17633, 17624, 17628>, 0,
    <17633, 17628, 17364>, 0,
    <17633, 17364, 17365>, 0,
    <17633, 17365, 17199>, 0,
    <17633, 17199, 17631>, 0,
    <17633, 17631, 17630>, 0,
    <17633, 17630, 17632>, 0,
    <17637, 17626, 17624>, 0,
    <17637, 17624, 17632>, 0,
    <17637, 17632, 17630>, 0,
    <17637, 17630, 17635>, 0,
    <17637, 17635, 17634>, 0,
    <17637, 17634, 17636>, 0,
    <17637, 17636, 17625>, 0,
    <17637, 17625, 17626>, 0,
    <17641, 17640, 17638>, 0,
    <17641, 17638, 17639>, 0,
    <17641, 17639, 17630>, 0,
    <17641, 17630, 17631>, 0,
    <17641, 17631, 17199>, 0,
    <17641, 17199, 17569>, 0,
    <17641, 17569, 17567>, 0,
    <17641, 17567, 17640>, 0,
    <17645, 17644, 17638>, 0,
    <17645, 17638, 17640>, 0,
    <17645, 17640, 17567>, 0,
    <17645, 17567, 17574>, 0,
    <17645, 17574, 4006>, 0,
    <17645, 4006, 17643>, 0,
    <17645, 17643, 17642>, 0,
    <17645, 17642, 17644>, 0,
    <17647, 17639, 17638>, 0,
    <17647, 17638, 17644>, 0,
    <17647, 17644, 17642>, 0,
    <17647, 17642, 17646>, 0,
    <17647, 17646, 17634>, 0,
    <17647, 17634, 17635>, 0,
    <17647, 17635, 17630>, 0,
    <17647, 17630, 17639>, 0,
    <17653, 17652, 17648>, 0,
    <17653, 17648, 17650>, 0,
    <17653, 17650, 17649>, 0,
    <17653, 17649, 17651>, 0,
    <17653, 17651, 17634>, 0,
    <17653, 17634, 17646>, 0,
    <17653, 17646, 17642>, 0,
    <17653, 17642, 17652>, 0,
    <17657, 17656, 17648>, 0,
    <17657, 17648, 17652>, 0,
    <17657, 17652, 17642>, 0,
    <17657, 17642, 17643>, 0,
    <17657, 17643, 4006>, 0,
    <17657, 4006, 17655>, 0,
    <17657, 17655, 17654>, 0,
    <17657, 17654, 17656>, 0,
    <17660, 17650, 17648>, 0,
    <17660, 17648, 17656>, 0,
    <17660, 17656, 17654>, 0,
    <17660, 17654, 17658>, 0,
    <17660, 17658, 3907>, 0,
    <17660, 3907, 17659>, 0,
    <17660, 17659, 17649>, 0,
    <17660, 17649, 17650>, 0,
    <17666, 17665, 17661>, 0,
    <17666, 17661, 17663>, 0,
    <17666, 17663, 17662>, 0,
    <17666, 17662, 17664>, 0,
    <17666, 17664, 17634>, 0,
    <17666, 17634, 17651>, 0,
    <17666, 17651, 17649>, 0,
    <17666, 17649, 17665>, 0,
    <17668, 17667, 17661>, 0,
    <17668, 17661, 17665>, 0,
    <17668, 17665, 17649>, 0,
    <17668, 17649, 17659>, 0,
    <17668, 17659, 3907>, 0,
    <17668, 3907, 17223>, 0,
    <17668, 17223, 17216>, 0,
    <17668, 17216, 17667>, 0,
    <17670, 17663, 17661>, 0,
    <17670, 17661, 17667>, 0,
    <17670, 17667, 17216>, 0,
    <17670, 17216, 17219>, 0,
    <17670, 17219, 17215>, 0,
    <17670, 17215, 17669>, 0,
    <17670, 17669, 17662>, 0,
    <17670, 17662, 17663>, 0,
    <17679, 17678, 17671>, 0,
    <17679, 17671, 17675>, 0,
    <17679, 17675, 17672>, 0,
    <17679, 17672, 17676>, 0,
    <17679, 17676, 17673>, 0,
    <17679, 17673, 17677>, 0,
    <17679, 17677, 17674>, 0,
    <17679, 17674, 17678>, 0,
    <17684, 17683, 17671>, 0,
    <17684, 17671, 17678>, 0,
    <17684, 17678, 17674>, 0,
    <17684, 17674, 17681>, 0,
    <17684, 17681, 16929>, 0,
    <17684, 16929, 17682>, 0,
    <17684, 17682, 17680>, 0,
    <17684, 17680, 17683>, 0,
    <17688, 17675, 17671>, 0,
    <17688, 17671, 17683>, 0,
    <17688, 17683, 17680>, 0,
    <17688, 17680, 17686>, 0,
    <17688, 17686, 17685>, 0,
    <17688, 17685, 17687>, 0,
    <17688, 17687, 17672>, 0,
    <17688, 17672, 17675>, 0,
    <17692, 17691, 17689>, 0,
    <17692, 17689, 17690>, 0,
    <17692, 17690, 17680>, 0,
    <17692, 17680, 17682>, 0,
    <17692, 17682, 16929>, 0,
    <17692, 16929, 16932>, 0,
    <17692, 16932, 16928>, 0,
    <17692, 16928, 17691>, 0,
    <17696, 17695, 17689>, 0,
    <17696, 17689, 17691>, 0,
    <17696, 17691, 16928>, 0,
    <17696, 16928, 16939>, 0,
    <17696, 16939, 16358>, 0,
    <17696, 16358, 17694>, 0,
    <17696, 17694, 17693>, 0,
    <17696, 17693, 17695>, 0,
    <17698, 17690, 17689>, 0,
    <17698, 17689, 17695>, 0,
    <17698, 17695, 17693>, 0,
    <17698, 17693, 17697>, 0,
    <17698, 17697, 17685>, 0,
    <17698, 17685, 17686>, 0,
    <17698, 17686, 17680>, 0,
    <17698, 17680, 17690>, 0,
    <17702, 17701, 17699>, 0,
    <17702, 17699, 17700>, 0,
    <17702, 17700, 17693>, 0,
    <17702, 17693, 17694>, 0,
    <17702, 17694, 16358>, 0,
    <17702, 16358, 17243>, 0,
    <17702, 17243, 17241>, 0,
    <17702, 17241, 17701>, 0,
    <17706, 17705, 17699>, 0,
    <17706, 17699, 17701>, 0,
    <17706, 17701, 17241>, 0,
    <17706, 17241, 17252>, 0,
    <17706, 17252, 17250>, 0,
    <17706, 17250, 17704>, 0,
    <17706, 17704, 17703>, 0,
    <17706, 17703, 17705>, 0,
    <17708, 17700, 17699>, 0,
    <17708, 17699, 17705>, 0,
    <17708, 17705, 17703>, 0,
    <17708, 17703, 17707>, 0,
    <17708, 17707, 17685>, 0,
    <17708, 17685, 17697>, 0,
    <17708, 17697, 17693>, 0,
    <17708, 17693, 17700>, 0,
    <17717, 17716, 17709>, 0,
    <17717, 17709, 17713>, 0,
    <17717, 17713, 17710>, 0,
    <17717, 17710, 17714>, 0,
    <17717, 17714, 17711>, 0,
    <17717, 17711, 17715>, 0,
    <17717, 17715, 17712>, 0,
    <17717, 17712, 17716>, 0,
    <17720, 17719, 17709>, 0,
    <17720, 17709, 17716>, 0,
    <17720, 17716, 17712>, 0,
    <17720, 17712, 17718>, 0,
    <17720, 17718, 17266>, 0,
    <17720, 17266, 17281>, 0,
    <17720, 17281, 17279>, 0,
    <17720, 17279, 17719>, 0,
    <17722, 17713, 17709>, 0,
    <17722, 17709, 17719>, 0,
    <17722, 17719, 17279>, 0,
    <17722, 17279, 17286>, 0,
    <17722, 17286, 16286>, 0,
    <17722, 16286, 17721>, 0,
    <17722, 17721, 17710>, 0,
    <17722, 17710, 17713>, 0,
    <17728, 17727, 17723>, 0,
    <17728, 17723, 17725>, 0,
    <17728, 17725, 17056>, 0,
    <17728, 17056, 17059>, 0,
    <17728, 17059, 17055>, 0,
    <17728, 17055, 17726>, 0,
    <17728, 17726, 17724>, 0,
    <17728, 17724, 17727>, 0,
    <17733, 17732, 17723>, 0,
    <17733, 17723, 17727>, 0,
    <17733, 17727, 17724>, 0,
    <17733, 17724, 17730>, 0,
    <17733, 17730, 17711>, 0,
    <17733, 17711, 17731>, 0,
    <17733, 17731, 17729>, 0,
    <17733, 17729, 17732>, 0,
    <17735, 17725, 17723>, 0,
    <17735, 17723, 17732>, 0,
    <17735, 17732, 17729>, 0,
    <17735, 17729, 17734>, 0,
    <17735, 17734, 16396>, 0,
    <17735, 16396, 17062>, 0,
    <17735, 17062, 17056>, 0,
    <17735, 17056, 17725>, 0,
    <17739, 17738, 17736>, 0,
    <17739, 17736, 17737>, 0,
    <17739, 17737, 17729>, 0,
    <17739, 17729, 17731>, 0,
    <17739, 17731, 17711>, 0,
    <17739, 17711, 17714>, 0,
    <17739, 17714, 17710>, 0,
    <17739, 17710, 17738>, 0,
    <17741, 17740, 17736>, 0,
    <17741, 17736, 17738>, 0,
    <17741, 17738, 17710>, 0,
    <17741, 17710, 17721>, 0,
    <17741, 17721, 16286>, 0,
    <17741, 16286, 16408>, 0,
    <17741, 16408, 16402>, 0,
    <17741, 16402, 17740>, 0,
    <17742, 17737, 17736>, 0,
    <17742, 17736, 17740>, 0,
    <17742, 17740, 16402>, 0,
    <17742, 16402, 16405>, 0,
    <17742, 16405, 16396>, 0,
    <17742, 16396, 17734>, 0,
    <17742, 17734, 17729>, 0,
    <17742, 17729, 17737>, 0,
    <17748, 17747, 17743>, 0,
    <17748, 17743, 17745>, 0,
    <17748, 17745, 17594>, 0,
    <17748, 17594, 17595>, 0,
    <17748, 17595, 17582>, 0,
    <17748, 17582, 17746>, 0,
    <17748, 17746, 17744>, 0,
    <17748, 17744, 17747>, 0,
    <17754, 17753, 17743>, 0,
    <17754, 17743, 17747>, 0,
    <17754, 17747, 17744>, 0,
    <17754, 17744, 17751>, 0,
    <17754, 17751, 17749>, 0,
    <17754, 17749, 17752>, 0,
    <17754, 17752, 17750>, 0,
    <17754, 17750, 17753>, 0,
    <17756, 17745, 17743>, 0,
    <17756, 17743, 17753>, 0,
    <17756, 17753, 17750>, 0,
    <17756, 17750, 17755>, 0,
    <17756, 17755, 17304>, 0,
    <17756, 17304, 17598>, 0,
    <17756, 17598, 17594>, 0,
    <17756, 17594, 17745>, 0,
    <17760, 17759, 17757>, 0,
    <17760, 17757, 17758>, 0,
    <17760, 17758, 17475>, 0,
    <17760, 17475, 17477>, 0,
    <17760, 17477, 17304>, 0,
    <17760, 17304, 17755>, 0,
    <17760, 17755, 17750>, 0,
    <17760, 17750, 17759>, 0,
    <17764, 17763, 17757>, 0,
    <17764, 17757, 17759>, 0,
    <17764, 17759, 17750>, 0,
    <17764, 17750, 17752>, 0,
    <17764, 17752, 17749>, 0,
    <17764, 17749, 17762>, 0,
    <17764, 17762, 17761>, 0,
    <17764, 17761, 17763>, 0,
    <17766, 17758, 17757>, 0,
    <17766, 17757, 17763>, 0,
    <17766, 17763, 17761>, 0,
    <17766, 17761, 17765>, 0,
    <17766, 17765, 17480>, 0,
    <17766, 17480, 17482>, 0,
    <17766, 17482, 17475>, 0,
    <17766, 17475, 17758>, 0,
    <17772, 17771, 17767>, 0,
    <17772, 17767, 17769>, 0,
    <17772, 17769, 17761>, 0,
    <17772, 17761, 17762>, 0,
    <17772, 17762, 17749>, 0,
    <17772, 17749, 17770>, 0,
    <17772, 17770, 17768>, 0,
    <17772, 17768, 17771>, 0,
    <17775, 17774, 17767>, 0,
    <17775, 17767, 17771>, 0,
    <17775, 17771, 17768>, 0,
    <17775, 17768, 17773>, 0,
    <17775, 17773, 17093>, 0,
    <17775, 17093, 17514>, 0,
    <17775, 17514, 17509>, 0,
    <17775, 17509, 17774>, 0,
    <17776, 17769, 17767>, 0,
    <17776, 17767, 17774>, 0,
    <17776, 17774, 17509>, 0,
    <17776, 17509, 17511>, 0,
    <17776, 17511, 17480>, 0,
    <17776, 17480, 17765>, 0,
    <17776, 17765, 17761>, 0,
    <17776, 17761, 17769>, 0,
    <17782, 17781, 17777>, 0,
    <17782, 17777, 17779>, 0,
    <17782, 17779, 17768>, 0,
    <17782, 17768, 17770>, 0,
    <17782, 17770, 17749>, 0,
    <17782, 17749, 17780>, 0,
    <17782, 17780, 17778>, 0,
    <17782, 17778, 17781>, 0,
    <17785, 17784, 17777>, 0,
    <17785, 17777, 17781>, 0,
    <17785, 17781, 17778>, 0,
    <17785, 17778, 17783>, 0,
    <17785, 17783, 17324>, 0,
    <17785, 17324, 17327>, 0,
    <17785, 17327, 17323>, 0,
    <17785, 17323, 17784>, 0,
    <17786, 17779, 17777>, 0,
    <17786, 17777, 17784>, 0,
    <17786, 17784, 17323>, 0,
    <17786, 17323, 17334>, 0,
    <17786, 17334, 17093>, 0,
    <17786, 17093, 17773>, 0,
    <17786, 17773, 17768>, 0,
    <17786, 17768, 17779>, 0,
    <17792, 17791, 17787>, 0,
    <17792, 17787, 17789>, 0,
    <17792, 17789, 17724>, 0,
    <17792, 17724, 17726>, 0,
    <17792, 17726, 17055>, 0,
    <17792, 17055, 17790>, 0,
    <17792, 17790, 17788>, 0,
    <17792, 17788, 17791>, 0,
    <17798, 17797, 17787>, 0,
    <17798, 17787, 17791>, 0,
    <17798, 17791, 17788>, 0,
    <17798, 17788, 17795>, 0,
    <17798, 17795, 17793>, 0,
    <17798, 17793, 17796>, 0,
    <17798, 17796, 17794>, 0,
    <17798, 17794, 17797>, 0,
    <17800, 17789, 17787>, 0,
    <17800, 17787, 17797>, 0,
    <17800, 17797, 17794>, 0,
    <17800, 17794, 17799>, 0,
    <17800, 17799, 17711>, 0,
    <17800, 17711, 17730>, 0,
    <17800, 17730, 17724>, 0,
    <17800, 17724, 17789>, 0,
    <17806, 17805, 17801>, 0,
    <17806, 17801, 17803>, 0,
    <17806, 17803, 17802>, 0,
    <17806, 17802, 17804>, 0,
    <17806, 17804, 17528>, 0,
    <17806, 17528, 17540>, 0,
    <17806, 17540, 17536>, 0,
    <17806, 17536, 17805>, 0,
    <17810, 17809, 17801>, 0,
    <17810, 17801, 17805>, 0,
    <17810, 17805, 17536>, 0,
    <17810, 17536, 17537>, 0,
    <17810, 17537, 17356>, 0,
    <17810, 17356, 17808>, 0,
    <17810, 17808, 17807>, 0,
    <17810, 17807, 17809>, 0,
    <17814, 17803, 17801>, 0,
    <17814, 17801, 17809>, 0,
    <17814, 17809, 17807>, 0,
    <17814, 17807, 17812>, 0,
    <17814, 17812, 17811>, 0,
    <17814, 17811, 17813>, 0,
    <17814, 17813, 17802>, 0,
    <17814, 17802, 17803>, 0,
    <17818, 17817, 17815>, 0,
    <17818, 17815, 17816>, 0,
    <17818, 17816, 17807>, 0,
    <17818, 17807, 17808>, 0,
    <17818, 17808, 17356>, 0,
    <17818, 17356, 17627>, 0,
    <17818, 17627, 17625>, 0,
    <17818, 17625, 17817>, 0,
    <17822, 17821, 17815>, 0,
    <17822, 17815, 17817>, 0,
    <17822, 17817, 17625>, 0,
    <17822, 17625, 17636>, 0,
    <17822, 17636, 17634>, 0,
    <17822, 17634, 17820>, 0,
    <17822, 17820, 17819>, 0,
    <17822, 17819, 17821>, 0,
    <17824, 17816, 17815>, 0,
    <17824, 17815, 17821>, 0,
    <17824, 17821, 17819>, 0,
    <17824, 17819, 17823>, 0,
    <17824, 17823, 17811>, 0,
    <17824, 17811, 17812>, 0,
    <17824, 17812, 17807>, 0,
    <17824, 17807, 17816>, 0,
    <17830, 17829, 17825>, 0,
    <17830, 17825, 17827>, 0,
    <17830, 17827, 17826>, 0,
    <17830, 17826, 17828>, 0,
    <17830, 17828, 17811>, 0,
    <17830, 17811, 17823>, 0,
    <17830, 17823, 17819>, 0,
    <17830, 17819, 17829>, 0,
    <17832, 17831, 17825>, 0,
    <17832, 17825, 17829>, 0,
    <17832, 17829, 17819>, 0,
    <17832, 17819, 17820>, 0,
    <17832, 17820, 17634>, 0,
    <17832, 17634, 17664>, 0,
    <17832, 17664, 17662>, 0,
    <17832, 17662, 17831>, 0,
    <17834, 17827, 17825>, 0,
    <17834, 17825, 17831>, 0,
    <17834, 17831, 17662>, 0,
    <17834, 17662, 17669>, 0,
    <17834, 17669, 17215>, 0,
    <17834, 17215, 17833>, 0,
    <17834, 17833, 17826>, 0,
    <17834, 17826, 17827>, 0,
    <17840, 17839, 17835>, 0,
    <17840, 17835, 17837>, 0,
    <17840, 17837, 17836>, 0,
    <17840, 17836, 17838>, 0,
    <17840, 17838, 17811>, 0,
    <17840, 17811, 17828>, 0,
    <17840, 17828, 17826>, 0,
    <17840, 17826, 17839>, 0,
    <17842, 17841, 17835>, 0,
    <17842, 17835, 17839>, 0,
    <17842, 17839, 17826>, 0,
    <17842, 17826, 17833>, 0,
    <17842, 17833, 17215>, 0,
    <17842, 17215, 17379>, 0,
    <17842, 17379, 17373>, 0,
    <17842, 17373, 17841>, 0,
    <17844, 17837, 17835>, 0,
    <17844, 17835, 17841>, 0,
    <17844, 17841, 17373>, 0,
    <17844, 17373, 17376>, 0,
    <17844, 17376, 17372>, 0,
    <17844, 17372, 17843>, 0,
    <17844, 17843, 17836>, 0,
    <17844, 17836, 17837>, 0,
    <17850, 17849, 17845>, 0,
    <17850, 17845, 17847>, 0,
    <17850, 17847, 17846>, 0,
    <17850, 17846, 17848>, 0,
    <17850, 17848, 16964>, 0,
    <17850, 16964, 16976>, 0,
    <17850, 16976, 16972>, 0,
    <17850, 16972, 17849>, 0,
    <17854, 17853, 17845>, 0,
    <17854, 17845, 17849>, 0,
    <17854, 17849, 16972>, 0,
    <17854, 16972, 16973>, 0,
    <17854, 16973, 16841>, 0,
    <17854, 16841, 17852>, 0,
    <17854, 17852, 17851>, 0,
    <17854, 17851, 17853>, 0,
    <17858, 17847, 17845>, 0,
    <17858, 17845, 17853>, 0,
    <17858, 17853, 17851>, 0,
    <17858, 17851, 17856>, 0,
    <17858, 17856, 17855>, 0,
    <17858, 17855, 17857>, 0,
    <17858, 17857, 17846>, 0,
    <17858, 17846, 17847>, 0,
    <17862, 17861, 17859>, 0,
    <17862, 17859, 17860>, 0,
    <17862, 17860, 17851>, 0,
    <17862, 17851, 17852>, 0,
    <17862, 17852, 16841>, 0,
    <17862, 16841, 17521>, 0,
    <17862, 17521, 17519>, 0,
    <17862, 17519, 17861>, 0,
    <17866, 17865, 17859>, 0,
    <17866, 17859, 17861>, 0,
    <17866, 17861, 17519>, 0,
    <17866, 17519, 17530>, 0,
    <17866, 17530, 17528>, 0,
    <17866, 17528, 17864>, 0,
    <17866, 17864, 17863>, 0,
    <17866, 17863, 17865>, 0,
    <17868, 17860, 17859>, 0,
    <17868, 17859, 17865>, 0,
    <17868, 17865, 17863>, 0,
    <17868, 17863, 17867>, 0,
    <17868, 17867, 17855>, 0,
    <17868, 17855, 17856>, 0,
    <17868, 17856, 17851>, 0,
    <17868, 17851, 17860>, 0,
    <17877, 17876, 17869>, 0,
    <17877, 17869, 17873>, 0,
    <17877, 17873, 17870>, 0,
    <17877, 17870, 17874>, 0,
    <17877, 17874, 17871>, 0,
    <17877, 17871, 17875>, 0,
    <17877, 17875, 17872>, 0,
    <17877, 17872, 17876>, 0,
    <17880, 17879, 17869>, 0,
    <17880, 17869, 17876>, 0,
    <17880, 17876, 17872>, 0,
    <17880, 17872, 17878>, 0,
    <17880, 17878, 17544>, 0,
    <17880, 17544, 17559>, 0,
    <17880, 17559, 17557>, 0,
    <17880, 17557, 17879>, 0,
    <17882, 17873, 17869>, 0,
    <17882, 17869, 17879>, 0,
    <17882, 17879, 17557>, 0,
    <17882, 17557, 17564>, 0,
    <17882, 17564, 16748>, 0,
    <17882, 16748, 17881>, 0,
    <17882, 17881, 17870>, 0,
    <17882, 17870, 17873>, 0,
    <17888, 17887, 17883>, 0,
    <17888, 17883, 17885>, 0,
    <17888, 17885, 17884>, 0,
    <17888, 17884, 17886>, 0,
    <17888, 17886, 17871>, 0,
    <17888, 17871, 17874>, 0,
    <17888, 17874, 17870>, 0,
    <17888, 17870, 17887>, 0,
    <17890, 17889, 17883>, 0,
    <17890, 17883, 17887>, 0,
    <17890, 17887, 17870>, 0,
    <17890, 17870, 17881>, 0,
    <17890, 17881, 16748>, 0,
    <17890, 16748, 16864>, 0,
    <17890, 16864, 16858>, 0,
    <17890, 16858, 17889>, 0,
    <17892, 17885, 17883>, 0,
    <17892, 17883, 17889>, 0,
    <17892, 17889, 16858>, 0,
    <17892, 16858, 16861>, 0,
    <17892, 16861, 16857>, 0,
    <17892, 16857, 17891>, 0,
    <17892, 17891, 17884>, 0,
    <17892, 17884, 17885>, 0,
    <17898, 17897, 17893>, 0,
    <17898, 17893, 17895>, 0,
    <17898, 17895, 17894>, 0,
    <17898, 17894, 17896>, 0,
    <17898, 17896, 17673>, 0,
    <17898, 17673, 17676>, 0,
    <17898, 17676, 17672>, 0,
    <17898, 17672, 17897>, 0,
    <17902, 17901, 17893>, 0,
    <17902, 17893, 17897>, 0,
    <17902, 17897, 17672>, 0,
    <17902, 17672, 17687>, 0,
    <17902, 17687, 17685>, 0,
    <17902, 17685, 17900>, 0,
    <17902, 17900, 17899>, 0,
    <17902, 17899, 17901>, 0,
    <17905, 17895, 17893>, 0,
    <17905, 17893, 17901>, 0,
    <17905, 17901, 17899>, 0,
    <17905, 17899, 17903>, 0,
    <17905, 17903, 4062>, 0,
    <17905, 4062, 17904>, 0,
    <17905, 17904, 17894>, 0,
    <17905, 17894, 17895>, 0,
    <17911, 17910, 17906>, 0,
    <17911, 17906, 17908>, 0,
    <17911, 17908, 17794>, 0,
    <17911, 17794, 17796>, 0,
    <17911, 17796, 17793>, 0,
    <17911, 17793, 17909>, 0,
    <17911, 17909, 17907>, 0,
    <17911, 17907, 17910>, 0,
    <17916, 17915, 17906>, 0,
    <17916, 17906, 17910>, 0,
    <17916, 17910, 17907>, 0,
    <17916, 17907, 17913>, 0,
    <17916, 17913, 4088>, 0,
    <17916, 4088, 17914>, 0,
    <17916, 17914, 17912>, 0,
    <17916, 17912, 17915>, 0,
    <17918, 17908, 17906>, 0,
    <17918, 17906, 17915>, 0,
    <17918, 17915, 17912>, 0,
    <17918, 17912, 17917>, 0,
    <17918, 17917, 17711>, 0,
    <17918, 17711, 17799>, 0,
    <17918, 17799, 17794>, 0,
    <17918, 17794, 17908>, 0,
    <17924, 17923, 17919>, 0,
    <17924, 17919, 17921>, 0,
    <17924, 17921, 17920>, 0,
    <17924, 17920, 17922>, 0,
    <17924, 17922, 17855>, 0,
    <17924, 17855, 17867>, 0,
    <17924, 17867, 17863>, 0,
    <17924, 17863, 17923>, 0,
    <17928, 17927, 17919>, 0,
    <17928, 17919, 17923>, 0,
    <17928, 17923, 17863>, 0,
    <17928, 17863, 17864>, 0,
    <17928, 17864, 17528>, 0,
    <17928, 17528, 17926>, 0,
    <17928, 17926, 17925>, 0,
    <17928, 17925, 17927>, 0,
    <17932, 17921, 17919>, 0,
    <17932, 17919, 17927>, 0,
    <17932, 17927, 17925>, 0,
    <17932, 17925, 17930>, 0,
    <17932, 17930, 17929>, 0,
    <17932, 17929, 17931>, 0,
    <17932, 17931, 17920>, 0,
    <17932, 17920, 17921>, 0,
    <17936, 17935, 17933>, 0,
    <17936, 17933, 17934>, 0,
    <17936, 17934, 17925>, 0,
    <17936, 17925, 17926>, 0,
    <17936, 17926, 17528>, 0,
    <17936, 17528, 17804>, 0,
    <17936, 17804, 17802>, 0,
    <17936, 17802, 17935>, 0,
    <17940, 17939, 17933>, 0,
    <17940, 17933, 17935>, 0,
    <17940, 17935, 17802>, 0,
    <17940, 17802, 17813>, 0,
    <17940, 17813, 17811>, 0,
    <17940, 17811, 17938>, 0,
    <17940, 17938, 17937>, 0,
    <17940, 17937, 17939>, 0,
    <17942, 17934, 17933>, 0,
    <17942, 17933, 17939>, 0,
    <17942, 17939, 17937>, 0,
    <17942, 17937, 17941>, 0,
    <17942, 17941, 17929>, 0,
    <17942, 17929, 17930>, 0,
    <17942, 17930, 17925>, 0,
    <17942, 17925, 17934>, 0,
    <17948, 17947, 17943>, 0,
    <17948, 17943, 17945>, 0,
    <17948, 17945, 17944>, 0,
    <17948, 17944, 17946>, 0,
    <17948, 17946, 17929>, 0,
    <17948, 17929, 17941>, 0,
    <17948, 17941, 17937>, 0,
    <17948, 17937, 17947>, 0,
    <17950, 17949, 17943>, 0,
    <17950, 17943, 17947>, 0,
    <17950, 17947, 17937>, 0,
    <17950, 17937, 17938>, 0,
    <17950, 17938, 17811>, 0,
    <17950, 17811, 17838>, 0,
    <17950, 17838, 17836>, 0,
    <17950, 17836, 17949>, 0,
    <17952, 17945, 17943>, 0,
    <17952, 17943, 17949>, 0,
    <17952, 17949, 17836>, 0,
    <17952, 17836, 17843>, 0,
    <17952, 17843, 17372>, 0,
    <17952, 17372, 17951>, 0,
    <17952, 17951, 17944>, 0,
    <17952, 17944, 17945>, 0,
    <17958, 17957, 17953>, 0,
    <17958, 17953, 17955>, 0,
    <17958, 17955, 17954>, 0,
    <17958, 17954, 17956>, 0,
    <17958, 17956, 17929>, 0,
    <17958, 17929, 17946>, 0,
    <17958, 17946, 17944>, 0,
    <17958, 17944, 17957>, 0,
    <17960, 17959, 17953>, 0,
    <17960, 17953, 17957>, 0,
    <17960, 17957, 17944>, 0,
    <17960, 17944, 17951>, 0,
    <17960, 17951, 17372>, 0,
    <17960, 17372, 17551>, 0,
    <17960, 17551, 17545>, 0,
    <17960, 17545, 17959>, 0,
    <17962, 17955, 17953>, 0,
    <17962, 17953, 17959>, 0,
    <17962, 17959, 17545>, 0,
    <17962, 17545, 17548>, 0,
    <17962, 17548, 17544>, 0,
    <17962, 17544, 17961>, 0,
    <17962, 17961, 17954>, 0,
    <17962, 17954, 17955>, 0,
    <17968, 17967, 17963>, 0,
    <17968, 17963, 17965>, 0,
    <17968, 17965, 17146>, 0,
    <17968, 17146, 17147>, 0,
    <17968, 17147, 17121>, 0,
    <17968, 17121, 17966>, 0,
    <17968, 17966, 17964>, 0,
    <17968, 17964, 17967>, 0,
    <17974, 17973, 17963>, 0,
    <17974, 17963, 17967>, 0,
    <17974, 17967, 17964>, 0,
    <17974, 17964, 17971>, 0,
    <17974, 17971, 17969>, 0,
    <17974, 17969, 17972>, 0,
    <17974, 17972, 17970>, 0,
    <17974, 17970, 17973>, 0,
    <17976, 17965, 17963>, 0,
    <17976, 17963, 17973>, 0,
    <17976, 17973, 17970>, 0,
    <17976, 17970, 17975>, 0,
    <17976, 17975, 16885>, 0,
    <17976, 16885, 17150>, 0,
    <17976, 17150, 17146>, 0,
    <17976, 17146, 17965>, 0,
    <17980, 17979, 17977>, 0,
    <17980, 17977, 17978>, 0,
    <17980, 17978, 17577>, 0,
    <17980, 17577, 17579>, 0,
    <17980, 17579, 16885>, 0,
    <17980, 16885, 17975>, 0,
    <17980, 17975, 17970>, 0,
    <17980, 17970, 17979>, 0,
    <17984, 17983, 17977>, 0,
    <17984, 17977, 17979>, 0,
    <17984, 17979, 17970>, 0,
    <17984, 17970, 17972>, 0,
    <17984, 17972, 17969>, 0,
    <17984, 17969, 17982>, 0,
    <17984, 17982, 17981>, 0,
    <17984, 17981, 17983>, 0,
    <17986, 17978, 17977>, 0,
    <17986, 17977, 17983>, 0,
    <17986, 17983, 17981>, 0,
    <17986, 17981, 17985>, 0,
    <17986, 17985, 17582>, 0,
    <17986, 17582, 17584>, 0,
    <17986, 17584, 17577>, 0,
    <17986, 17577, 17978>, 0,
    <17995, 17994, 17987>, 0,
    <17995, 17987, 17991>, 0,
    <17995, 17991, 17988>, 0,
    <17995, 17988, 17992>, 0,
    <17995, 17992, 17989>, 0,
    <17995, 17989, 17993>, 0,
    <17995, 17993, 17990>, 0,
    <17995, 17990, 17994>, 0,
    <17998, 17997, 17987>, 0,
    <17998, 17987, 17994>, 0,
    <17998, 17994, 17990>, 0,
    <17998, 17990, 17996>, 0,
    <17998, 17996, 16796>, 0,
    <17998, 16796, 17620>, 0,
    <17998, 17620, 17615>, 0,
    <17998, 17615, 17997>, 0,
    <18000, 17991, 17987>, 0,
    <18000, 17987, 17997>, 0,
    <18000, 17997, 17615>, 0,
    <18000, 17615, 17617>, 0,
    <18000, 17617, 17602>, 0,
    <18000, 17602, 17999>, 0,
    <18000, 17999, 17988>, 0,
    <18000, 17988, 17991>, 0,
    <18006, 18005, 18001>, 0,
    <18006, 18001, 18003>, 0,
    <18006, 18003, 17990>, 0,
    <18006, 17990, 17993>, 0,
    <18006, 17993, 17989>, 0,
    <18006, 17989, 18004>, 0,
    <18006, 18004, 18002>, 0,
    <18006, 18002, 18005>, 0,
    <18009, 18008, 18001>, 0,
    <18009, 18001, 18005>, 0,
    <18009, 18005, 18002>, 0,
    <18009, 18002, 18007>, 0,
    <18009, 18007, 16905>, 0,
    <18009, 16905, 16908>, 0,
    <18009, 16908, 16904>, 0,
    <18009, 16904, 18008>, 0,
    <18010, 18003, 18001>, 0,
    <18010, 18001, 18008>, 0,
    <18010, 18008, 16904>, 0,
    <18010, 16904, 16915>, 0,
    <18010, 16915, 16796>, 0,
    <18010, 16796, 17996>, 0,
    <18010, 17996, 17990>, 0,
    <18010, 17990, 18003>, 0,
    <18016, 18015, 18011>, 0,
    <18016, 18011, 18013>, 0,
    <18016, 18013, 17981>, 0,
    <18016, 17981, 17982>, 0,
    <18016, 17982, 17969>, 0,
    <18016, 17969, 18014>, 0,
    <18016, 18014, 18012>, 0,
    <18016, 18012, 18015>, 0,
    <18022, 18021, 18011>, 0,
    <18022, 18011, 18015>, 0,
    <18022, 18015, 18012>, 0,
    <18022, 18012, 18019>, 0,
    <18022, 18019, 18017>, 0,
    <18022, 18017, 18020>, 0,
    <18022, 18020, 18018>, 0,
    <18022, 18018, 18021>, 0,
    <18024, 18013, 18011>, 0,
    <18024, 18011, 18021>, 0,
    <18024, 18021, 18018>, 0,
    <18024, 18018, 18023>, 0,
    <18024, 18023, 17582>, 0,
    <18024, 17582, 17985>, 0,
    <18024, 17985, 17981>, 0,
    <18024, 17981, 18013>, 0,
    <18028, 18027, 18025>, 0,
    <18028, 18025, 18026>, 0,
    <18028, 18026, 17744>, 0,
    <18028, 17744, 17746>, 0,
    <18028, 17746, 17582>, 0,
    <18028, 17582, 18023>, 0,
    <18028, 18023, 18018>, 0,
    <18028, 18018, 18027>, 0,
    <18032, 18031, 18025>, 0,
    <18032, 18025, 18027>, 0,
    <18032, 18027, 18018>, 0,
    <18032, 18018, 18020>, 0,
    <18032, 18020, 18017>, 0,
    <18032, 18017, 18030>, 0,
    <18032, 18030, 18029>, 0,
    <18032, 18029, 18031>, 0,
    <18034, 18026, 18025>, 0,
    <18034, 18025, 18031>, 0,
    <18034, 18031, 18029>, 0,
    <18034, 18029, 18033>, 0,
    <18034, 18033, 17749>, 0,
    <18034, 17749, 17751>, 0,
    <18034, 17751, 17744>, 0,
    <18034, 17744, 18026>, 0,
    <18040, 18039, 18035>, 0,
    <18040, 18035, 18037>, 0,
    <18040, 18037, 18029>, 0,
    <18040, 18029, 18030>, 0,
    <18040, 18030, 18017>, 0,
    <18040, 18017, 18038>, 0,
    <18040, 18038, 18036>, 0,
    <18040, 18036, 18039>, 0,
    <18043, 18042, 18035>, 0,
    <18043, 18035, 18039>, 0,
    <18043, 18039, 18036>, 0,
    <18043, 18036, 18041>, 0,
    <18043, 18041, 17324>, 0,
    <18043, 17324, 17783>, 0,
    <18043, 17783, 17778>, 0,
    <18043, 17778, 18042>, 0,
    <18044, 18037, 18035>, 0,
    <18044, 18035, 18042>, 0,
    <18044, 18042, 17778>, 0,
    <18044, 17778, 17780>, 0,
    <18044, 17780, 17749>, 0,
    <18044, 17749, 18033>, 0,
    <18044, 18033, 18029>, 0,
    <18044, 18029, 18037>, 0,
    <18050, 18049, 18045>, 0,
    <18050, 18045, 18047>, 0,
    <18050, 18047, 18036>, 0,
    <18050, 18036, 18038>, 0,
    <18050, 18038, 18017>, 0,
    <18050, 18017, 18048>, 0,
    <18050, 18048, 18046>, 0,
    <18050, 18046, 18049>, 0,
    <18053, 18052, 18045>, 0,
    <18053, 18045, 18049>, 0,
    <18053, 18049, 18046>, 0,
    <18053, 18046, 18051>, 0,
    <18053, 18051, 17602>, 0,
    <18053, 17602, 17605>, 0,
    <18053, 17605, 17601>, 0,
    <18053, 17601, 18052>, 0,
    <18054, 18047, 18045>, 0,
    <18054, 18045, 18052>, 0,
    <18054, 18052, 17601>, 0,
    <18054, 17601, 17612>, 0,
    <18054, 17612, 17324>, 0,
    <18054, 17324, 18041>, 0,
    <18054, 18041, 18036>, 0,
    <18054, 18036, 18047>, 0,
    <18060, 18059, 18055>, 0,
    <18060, 18055, 18057>, 0,
    <18060, 18057, 18056>, 0,
    <18060, 18056, 18058>, 0,
    <18060, 18058, 17250>, 0,
    <18060, 17250, 17262>, 0,
    <18060, 17262, 17258>, 0,
    <18060, 17258, 18059>, 0,
    <18064, 18063, 18055>, 0,
    <18064, 18055, 18059>, 0,
    <18064, 18059, 17258>, 0,
    <18064, 17258, 17259>, 0,
    <18064, 17259, 16964>, 0,
    <18064, 16964, 18062>, 0,
    <18064, 18062, 18061>, 0,
    <18064, 18061, 18063>, 0,
    <18068, 18057, 18055>, 0,
    <18068, 18055, 18063>, 0,
    <18068, 18063, 18061>, 0,
    <18068, 18061, 18066>, 0,
    <18068, 18066, 18065>, 0,
    <18068, 18065, 18067>, 0,
    <18068, 18067, 18056>, 0,
    <18068, 18056, 18057>, 0,
    <18072, 18071, 18069>, 0,
    <18072, 18069, 18070>, 0,
    <18072, 18070, 18061>, 0,
    <18072, 18061, 18062>, 0,
    <18072, 18062, 16964>, 0,
    <18072, 16964, 17848>, 0,
    <18072, 17848, 17846>, 0,
    <18072, 17846, 18071>, 0,
    <18076, 18075, 18069>, 0,
    <18076, 18069, 18071>, 0,
    <18076, 18071, 17846>, 0,
    <18076, 17846, 17857>, 0,
    <18076, 17857, 17855>, 0,
    <18076, 17855, 18074>, 0,
    <18076, 18074, 18073>, 0,
    <18076, 18073, 18075>, 0,
    <18078, 18070, 18069>, 0,
    <18078, 18069, 18075>, 0,
    <18078, 18075, 18073>, 0,
    <18078, 18073, 18077>, 0,
    <18078, 18077, 18065>, 0,
    <18078, 18065, 18066>, 0,
    <18078, 18066, 18061>, 0,
    <18078, 18061, 18070>, 0,
    <18087, 18086, 18079>, 0,
    <18087, 18079, 18083>, 0,
    <18087, 18083, 18080>, 0,
    <18087, 18080, 18084>, 0,
    <18087, 18084, 18081>, 0,
    <18087, 18081, 18085>, 0,
    <18087, 18085, 18082>, 0,
    <18087, 18082, 18086>, 0,
    <18090, 18089, 18079>, 0,
    <18090, 18079, 18086>, 0,
    <18090, 18086, 18082>, 0,
    <18090, 18082, 18088>, 0,
    <18090, 18088, 17871>, 0,
    <18090, 17871, 17886>, 0,
    <18090, 17886, 17884>, 0,
    <18090, 17884, 18089>, 0,
    <18092, 18083, 18079>, 0,
    <18092, 18079, 18089>, 0,
    <18092, 18089, 17884>, 0,
    <18092, 17884, 17891>, 0,
    <18092, 17891, 16857>, 0,
    <18092, 16857, 18091>, 0,
    <18092, 18091, 18080>, 0,
    <18092, 18080, 18083>, 0,
    <18098, 18097, 18093>, 0,
    <18098, 18093, 18095>, 0,
    <18098, 18095, 18094>, 0,
    <18098, 18094, 18096>, 0,
    <18098, 18096, 18081>, 0,
    <18098, 18081, 18084>, 0,
    <18098, 18084, 18080>, 0,
    <18098, 18080, 18097>, 0,
    <18100, 18099, 18093>, 0,
    <18100, 18093, 18097>, 0,
    <18100, 18097, 18080>, 0,
    <18100, 18080, 18091>, 0,
    <18100, 18091, 16857>, 0,
    <18100, 16857, 16987>, 0,
    <18100, 16987, 16981>, 0,
    <18100, 16981, 18099>, 0,
    <18102, 18095, 18093>, 0,
    <18102, 18093, 18099>, 0,
    <18102, 18099, 16981>, 0,
    <18102, 16981, 16984>, 0,
    <18102, 16984, 16980>, 0,
    <18102, 16980, 18101>, 0,
    <18102, 18101, 18094>, 0,
    <18102, 18094, 18095>, 0,
    <18110, 18109, 18103>, 0,
    <18110, 18103, 18106>, 0,
    <18110, 18106, 18104>, 0,
    <18110, 18104, 18107>, 0,
    <18110, 18107, 4237>, 0,
    <18110, 4237, 18108>, 0,
    <18110, 18108, 18105>, 0,
    <18110, 18105, 18109>, 0,
    <18113, 18112, 18103>, 0,
    <18113, 18103, 18109>, 0,
    <18113, 18109, 18105>, 0,
    <18113, 18105, 18111>, 0,
    <18113, 18111, 4082>, 0,
    <18113, 4082, 17467>, 0,
    <18113, 17467, 17465>, 0,
    <18113, 17465, 18112>, 0,
    <18115, 18106, 18103>, 0,
    <18115, 18103, 18112>, 0,
    <18115, 18112, 17465>, 0,
    <18115, 17465, 17472>, 0,
    <18115, 17472, 17154>, 0,
    <18115, 17154, 18114>, 0,
    <18115, 18114, 18104>, 0,
    <18115, 18104, 18106>, 0,
    <18121, 18120, 18116>, 0,
    <18121, 18116, 18118>, 0,
    <18121, 18118, 18117>, 0,
    <18121, 18117, 18119>, 0,
    <18121, 18119, 18065>, 0,
    <18121, 18065, 18077>, 0,
    <18121, 18077, 18073>, 0,
    <18121, 18073, 18120>, 0,
    <18125, 18124, 18116>, 0,
    <18125, 18116, 18120>, 0,
    <18125, 18120, 18073>, 0,
    <18125, 18073, 18074>, 0,
    <18125, 18074, 17855>, 0,
    <18125, 17855, 18123>, 0,
    <18125, 18123, 18122>, 0,
    <18125, 18122, 18124>, 0,
    <18129, 18118, 18116>, 0,
    <18129, 18116, 18124>, 0,
    <18129, 18124, 18122>, 0,
    <18129, 18122, 18127>, 0,
    <18129, 18127, 18126>, 0,
    <18129, 18126, 18128>, 0,
    <18129, 18128, 18117>, 0,
    <18129, 18117, 18118>, 0,
    <18133, 18132, 18130>, 0,
    <18133, 18130, 18131>, 0,
    <18133, 18131, 18122>, 0,
    <18133, 18122, 18123>, 0,
    <18133, 18123, 17855>, 0,
    <18133, 17855, 17922>, 0,
    <18133, 17922, 17920>, 0,
    <18133, 17920, 18132>, 0,
    <18137, 18136, 18130>, 0,
    <18137, 18130, 18132>, 0,
    <18137, 18132, 17920>, 0,
    <18137, 17920, 17931>, 0,
    <18137, 17931, 17929>, 0,
    <18137, 17929, 18135>, 0,
    <18137, 18135, 18134>, 0,
    <18137, 18134, 18136>, 0,
    <18139, 18131, 18130>, 0,
    <18139, 18130, 18136>, 0,
    <18139, 18136, 18134>, 0,
    <18139, 18134, 18138>, 0,
    <18139, 18138, 18126>, 0,
    <18139, 18126, 18127>, 0,
    <18139, 18127, 18122>, 0,
    <18139, 18122, 18131>, 0,
    <18145, 18144, 18140>, 0,
    <18145, 18140, 18142>, 0,
    <18145, 18142, 18141>, 0,
    <18145, 18141, 18143>, 0,
    <18145, 18143, 18126>, 0,
    <18145, 18126, 18138>, 0,
    <18145, 18138, 18134>, 0,
    <18145, 18134, 18144>, 0,
    <18147, 18146, 18140>, 0,
    <18147, 18140, 18144>, 0,
    <18147, 18144, 18134>, 0,
    <18147, 18134, 18135>, 0,
    <18147, 18135, 17929>, 0,
    <18147, 17929, 17956>, 0,
    <18147, 17956, 17954>, 0,
    <18147, 17954, 18146>, 0,
    <18149, 18142, 18140>, 0,
    <18149, 18140, 18146>, 0,
    <18149, 18146, 17954>, 0,
    <18149, 17954, 17961>, 0,
    <18149, 17961, 17544>, 0,
    <18149, 17544, 18148>, 0,
    <18149, 18148, 18141>, 0,
    <18149, 18141, 18142>, 0,
    <18155, 18154, 18150>, 0,
    <18155, 18150, 18152>, 0,
    <18155, 18152, 18151>, 0,
    <18155, 18151, 18153>, 0,
    <18155, 18153, 18126>, 0,
    <18155, 18126, 18143>, 0,
    <18155, 18143, 18141>, 0,
    <18155, 18141, 18154>, 0,
    <18157, 18156, 18150>, 0,
    <18157, 18150, 18154>, 0,
    <18157, 18154, 18141>, 0,
    <18157, 18141, 18148>, 0,
    <18157, 18148, 17544>, 0,
    <18157, 17544, 17878>, 0,
    <18157, 17878, 17872>, 0,
    <18157, 17872, 18156>, 0,
    <18159, 18152, 18150>, 0,
    <18159, 18150, 18156>, 0,
    <18159, 18156, 17872>, 0,
    <18159, 17872, 17875>, 0,
    <18159, 17875, 17871>, 0,
    <18159, 17871, 18158>, 0,
    <18159, 18158, 18151>, 0,
    <18159, 18151, 18152>, 0,
    <18165, 18164, 18160>, 0,
    <18165, 18160, 18162>, 0,
    <18165, 18162, 18012>, 0,
    <18165, 18012, 18014>, 0,
    <18165, 18014, 17969>, 0,
    <18165, 17969, 18163>, 0,
    <18165, 18163, 18161>, 0,
    <18165, 18161, 18164>, 0,
    <18171, 18170, 18160>, 0,
    <18171, 18160, 18164>, 0,
    <18171, 18164, 18161>, 0,
    <18171, 18161, 18168>, 0,
    <18171, 18168, 18166>, 0,
    <18171, 18166, 18169>, 0,
    <18171, 18169, 18167>, 0,
    <18171, 18167, 18170>, 0,
    <18173, 18162, 18160>, 0,
    <18173, 18160, 18170>, 0,
    <18173, 18170, 18167>, 0,
    <18173, 18167, 18172>, 0,
    <18173, 18172, 18017>, 0,
    <18173, 18017, 18019>, 0,
    <18173, 18019, 18012>, 0,
    <18173, 18012, 18162>, 0,
    <18179, 18178, 18174>, 0,
    <18179, 18174, 18176>, 0,
    <18179, 18176, 18167>, 0,
    <18179, 18167, 18169>, 0,
    <18179, 18169, 18166>, 0,
    <18179, 18166, 18177>, 0,
    <18179, 18177, 18175>, 0,
    <18179, 18175, 18178>, 0,
    <18182, 18181, 18174>, 0,
    <18182, 18174, 18178>, 0,
    <18182, 18178, 18175>, 0,
    <18182, 18175, 18180>, 0,
    <18182, 18180, 17602>, 0,
    <18182, 17602, 18051>, 0,
    <18182, 18051, 18046>, 0,
    <18182, 18046, 18181>, 0,
    <18183, 18176, 18174>, 0,
    <18183, 18174, 18181>, 0,
    <18183, 18181, 18046>, 0,
    <18183, 18046, 18048>, 0,
    <18183, 18048, 18017>, 0,
    <18183, 18017, 18172>, 0,
    <18183, 18172, 18167>, 0,
    <18183, 18167, 18176>, 0,
    <18189, 18188, 18184>, 0,
    <18189, 18184, 18186>, 0,
    <18189, 18186, 18175>, 0,
    <18189, 18175, 18177>, 0,
    <18189, 18177, 18166>, 0,
    <18189, 18166, 18187>, 0,
    <18189, 18187, 18185>, 0,
    <18189, 18185, 18188>, 0,
    <18192, 18191, 18184>, 0,
    <18192, 18184, 18188>, 0,
    <18192, 18188, 18185>, 0,
    <18192, 18185, 18190>, 0,
    <18192, 18190, 17989>, 0,
    <18192, 17989, 17992>, 0,
    <18192, 17992, 17988>, 0,
    <18192, 17988, 18191>, 0,
    <18193, 18186, 18184>, 0,
    <18193, 18184, 18191>, 0,
    <18193, 18191, 17988>, 0,
    <18193, 17988, 17999>, 0,
    <18193, 17999, 17602>, 0,
    <18193, 17602, 18180>, 0,
    <18193, 18180, 18175>, 0,
    <18193, 18175, 18186>, 0,
    <18199, 18198, 18194>, 0,
    <18199, 18194, 18196>, 0,
    <18199, 18196, 17457>, 0,
    <18199, 17457, 17459>, 0,
    <18199, 17459, 3987>, 0,
    <18199, 3987, 18197>, 0,
    <18199, 18197, 18195>, 0,
    <18199, 18195, 18198>, 0,
    <18205, 18204, 18194>, 0,
    <18205, 18194, 18198>, 0,
    <18205, 18198, 18195>, 0,
    <18205, 18195, 18202>, 0,
    <18205, 18202, 18200>, 0,
    <18205, 18200, 18203>, 0,
    <18205, 18203, 18201>, 0,
    <18205, 18201, 18204>, 0,
    <18207, 18196, 18194>, 0,
    <18207, 18194, 18204>, 0,
    <18207, 18204, 18201>, 0,
    <18207, 18201, 18206>, 0,
    <18207, 18206, 17121>, 0,
    <18207, 17121, 17462>, 0,
    <18207, 17462, 17457>, 0,
    <18207, 17457, 18196>, 0,
    <18213, 18212, 18208>, 0,
    <18213, 18208, 18210>, 0,
    <18213, 18210, 18195>, 0,
    <18213, 18195, 18197>, 0,
    <18213, 18197, 3987>, 0,
    <18213, 3987, 18211>, 0,
    <18213, 18211, 18209>, 0,
    <18213, 18209, 18212>, 0,
    <18218, 18217, 18208>, 0,
    <18218, 18208, 18212>, 0,
    <18218, 18212, 18209>, 0,
    <18218, 18209, 18215>, 0,
    <18218, 18215, 4135>, 0,
    <18218, 4135, 18216>, 0,
    <18218, 18216, 18214>, 0,
    <18218, 18214, 18217>, 0,
    <18220, 18210, 18208>, 0,
    <18220, 18208, 18217>, 0,
    <18220, 18217, 18214>, 0,
    <18220, 18214, 18219>, 0,
    <18220, 18219, 18200>, 0,
    <18220, 18200, 18202>, 0,
    <18220, 18202, 18195>, 0,
    <18220, 18195, 18210>, 0,
    <18224, 18223, 18221>, 0,
    <18224, 18221, 18222>, 0,
    <18224, 18222, 17964>, 0,
    <18224, 17964, 17966>, 0,
    <18224, 17966, 17121>, 0,
    <18224, 17121, 18206>, 0,
    <18224, 18206, 18201>, 0,
    <18224, 18201, 18223>, 0,
    <18228, 18227, 18221>, 0,
    <18228, 18221, 18223>, 0,
    <18228, 18223, 18201>, 0,
    <18228, 18201, 18203>, 0,
    <18228, 18203, 18200>, 0,
    <18228, 18200, 18226>, 0,
    <18228, 18226, 18225>, 0,
    <18228, 18225, 18227>, 0,
    <18230, 18222, 18221>, 0,
    <18230, 18221, 18227>, 0,
    <18230, 18227, 18225>, 0,
    <18230, 18225, 18229>, 0,
    <18230, 18229, 17969>, 0,
    <18230, 17969, 17971>, 0,
    <18230, 17971, 17964>, 0,
    <18230, 17964, 18222>, 0,
    <18236, 18235, 18231>, 0,
    <18236, 18231, 18233>, 0,
    <18236, 18233, 18225>, 0,
    <18236, 18225, 18226>, 0,
    <18236, 18226, 18200>, 0,
    <18236, 18200, 18234>, 0,
    <18236, 18234, 18232>, 0,
    <18236, 18232, 18235>, 0,
    <18239, 18238, 18231>, 0,
    <18239, 18231, 18235>, 0,
    <18239, 18235, 18232>, 0,
    <18239, 18232, 18237>, 0,
    <18239, 18237, 18166>, 0,
    <18239, 18166, 18168>, 0,
    <18239, 18168, 18161>, 0,
    <18239, 18161, 18238>, 0,
    <18240, 18233, 18231>, 0,
    <18240, 18231, 18238>, 0,
    <18240, 18238, 18161>, 0,
    <18240, 18161, 18163>, 0,
    <18240, 18163, 17969>, 0,
    <18240, 17969, 18229>, 0,
    <18240, 18229, 18225>, 0,
    <18240, 18225, 18233>, 0,
    <18249, 18248, 18241>, 0,
    <18249, 18241, 18245>, 0,
    <18249, 18245, 18242>, 0,
    <18249, 18242, 18246>, 0,
    <18249, 18246, 18243>, 0,
    <18249, 18243, 18247>, 0,
    <18249, 18247, 18244>, 0,
    <18249, 18244, 18248>, 0,
    <18252, 18251, 18241>, 0,
    <18252, 18241, 18248>, 0,
    <18252, 18248, 18244>, 0,
    <18252, 18244, 18250>, 0,
    <18252, 18250, 16905>, 0,
    <18252, 16905, 18007>, 0,
    <18252, 18007, 18002>, 0,
    <18252, 18002, 18251>, 0,
    <18254, 18245, 18241>, 0,
    <18254, 18241, 18251>, 0,
    <18254, 18251, 18002>, 0,
    <18254, 18002, 18004>, 0,
    <18254, 18004, 17989>, 0,
    <18254, 17989, 18253>, 0,
    <18254, 18253, 18242>, 0,
    <18254, 18242, 18245>, 0,
    <18260, 18259, 18255>, 0,
    <18260, 18255, 18257>, 0,
    <18260, 18257, 18244>, 0,
    <18260, 18244, 18247>, 0,
    <18260, 18247, 18243>, 0,
    <18260, 18243, 18258>, 0,
    <18260, 18258, 18256>, 0,
    <18260, 18256, 18259>, 0,
    <18263, 18262, 18255>, 0,
    <18263, 18255, 18259>, 0,
    <18263, 18259, 18256>, 0,
    <18263, 18256, 18261>, 0,
    <18263, 18261, 17154>, 0,
    <18263, 17154, 17157>, 0,
    <18263, 17157, 17153>, 0,
    <18263, 17153, 18262>, 0,
    <18264, 18257, 18255>, 0,
    <18264, 18255, 18262>, 0,
    <18264, 18262, 17153>, 0,
    <18264, 17153, 17164>, 0,
    <18264, 17164, 16905>, 0,
    <18264, 16905, 18250>, 0,
    <18264, 18250, 18244>, 0,
    <18264, 18244, 18257>, 0,
    <18273, 18272, 18265>, 0,
    <18273, 18265, 18269>, 0,
    <18273, 18269, 18266>, 0,
    <18273, 18266, 18270>, 0,
    <18273, 18270, 18267>, 0,
    <18273, 18267, 18271>, 0,
    <18273, 18271, 18268>, 0,
    <18273, 18268, 18272>, 0,
    <18276, 18275, 18265>, 0,
    <18276, 18265, 18272>, 0,
    <18276, 18272, 18268>, 0,
    <18276, 18268, 18274>, 0,
    <18276, 18274, 4062>, 0,
    <18276, 4062, 17903>, 0,
    <18276, 17903, 17899>, 0,
    <18276, 17899, 18275>, 0,
    <18278, 18269, 18265>, 0,
    <18278, 18265, 18275>, 0,
    <18278, 18275, 17899>, 0,
    <18278, 17899, 17900>, 0,
    <18278, 17900, 17685>, 0,
    <18278, 17685, 18277>, 0,
    <18278, 18277, 18266>, 0,
    <18278, 18266, 18269>, 0,
    <18284, 18283, 18279>, 0,
    <18284, 18279, 18281>, 0,
    <18284, 18281, 18280>, 0,
    <18284, 18280, 18282>, 0,
    <18284, 18282, 17685>, 0,
    <18284, 17685, 17707>, 0,
    <18284, 17707, 17703>, 0,
    <18284, 17703, 18283>, 0,
    <18288, 18287, 18279>, 0,
    <18288, 18279, 18283>, 0,
    <18288, 18283, 17703>, 0,
    <18288, 17703, 17704>, 0,
    <18288, 17704, 17250>, 0,
    <18288, 17250, 18286>, 0,
    <18288, 18286, 18285>, 0,
    <18288, 18285, 18287>, 0,
    <18292, 18281, 18279>, 0,
    <18292, 18279, 18287>, 0,
    <18292, 18287, 18285>, 0,
    <18292, 18285, 18290>, 0,
    <18292, 18290, 18289>, 0,
    <18292, 18289, 18291>, 0,
    <18292, 18291, 18280>, 0,
    <18292, 18280, 18281>, 0,
    <18296, 18295, 18293>, 0,
    <18296, 18293, 18294>, 0,
    <18296, 18294, 18285>, 0,
    <18296, 18285, 18286>, 0,
    <18296, 18286, 17250>, 0,
    <18296, 17250, 18058>, 0,
    <18296, 18058, 18056>, 0,
    <18296, 18056, 18295>, 0,
    <18300, 18299, 18293>, 0,
    <18300, 18293, 18295>, 0,
    <18300, 18295, 18056>, 0,
    <18300, 18056, 18067>, 0,
    <18300, 18067, 18065>, 0,
    <18300, 18065, 18298>, 0,
    <18300, 18298, 18297>, 0,
    <18300, 18297, 18299>, 0,
    <18302, 18294, 18293>, 0,
    <18302, 18293, 18299>, 0,
    <18302, 18299, 18297>, 0,
    <18302, 18297, 18301>, 0,
    <18302, 18301, 18289>, 0,
    <18302, 18289, 18290>, 0,
    <18302, 18290, 18285>, 0,
    <18302, 18285, 18294>, 0,
    <18311, 18310, 18303>, 0,
    <18311, 18303, 18307>, 0,
    <18311, 18307, 18304>, 0,
    <18311, 18304, 18308>, 0,
    <18311, 18308, 18305>, 0,
    <18311, 18305, 18309>, 0,
    <18311, 18309, 18306>, 0,
    <18311, 18306, 18310>, 0,
    <18314, 18313, 18303>, 0,
    <18314, 18303, 18310>, 0,
    <18314, 18310, 18306>, 0,
    <18314, 18306, 18312>, 0,
    <18314, 18312, 18081>, 0,
    <18314, 18081, 18096>, 0,
    <18314, 18096, 18094>, 0,
    <18314, 18094, 18313>, 0,
    <18316, 18307, 18303>, 0,
    <18316, 18303, 18313>, 0,
    <18316, 18313, 18094>, 0,
    <18316, 18094, 18101>, 0,
    <18316, 18101, 16980>, 0,
    <18316, 16980, 18315>, 0,
    <18316, 18315, 18304>, 0,
    <18316, 18304, 18307>, 0,
    <18322, 18321, 18317>, 0,
    <18322, 18317, 18319>, 0,
    <18322, 18319, 18318>, 0,
    <18322, 18318, 18320>, 0,
    <18322, 18320, 18305>, 0,
    <18322, 18305, 18308>, 0,
    <18322, 18308, 18304>, 0,
    <18322, 18304, 18321>, 0,
    <18324, 18323, 18317>, 0,
    <18324, 18317, 18321>, 0,
    <18324, 18321, 18304>, 0,
    <18324, 18304, 18315>, 0,
    <18324, 18315, 16980>, 0,
    <18324, 16980, 17273>, 0,
    <18324, 17273, 17267>, 0,
    <18324, 17267, 18323>, 0,
    <18326, 18319, 18317>, 0,
    <18326, 18317, 18323>, 0,
    <18326, 18323, 17267>, 0,
    <18326, 17267, 17270>, 0,
    <18326, 17270, 17266>, 0,
    <18326, 17266, 18325>, 0,
    <18326, 18325, 18318>, 0,
    <18326, 18318, 18319>, 0,
    <18332, 18331, 18327>, 0,
    <18332, 18327, 18329>, 0,
    <18332, 18329, 18328>, 0,
    <18332, 18328, 18330>, 0,
    <18332, 18330, 18289>, 0,
    <18332, 18289, 18301>, 0,
    <18332, 18301, 18297>, 0,
    <18332, 18297, 18331>, 0,
    <18336, 18335, 18327>, 0,
    <18336, 18327, 18331>, 0,
    <18336, 18331, 18297>, 0,
    <18336, 18297, 18298>, 0,
    <18336, 18298, 18065>, 0,
    <18336, 18065, 18334>, 0,
    <18336, 18334, 18333>, 0,
    <18336, 18333, 18335>, 0,
    <18340, 18329, 18327>, 0,
    <18340, 18327, 18335>, 0,
    <18340, 18335, 18333>, 0,
    <18340, 18333, 18338>, 0,
    <18340, 18338, 18337>, 0,
    <18340, 18337, 18339>, 0,
    <18340, 18339, 18328>, 0,
    <18340, 18328, 18329>, 0,
    <18344, 18343, 18341>, 0,
    <18344, 18341, 18342>, 0,
    <18344, 18342, 18333>, 0,
    <18344, 18333, 18334>, 0,
    <18344, 18334, 18065>, 0,
    <18344, 18065, 18119>, 0,
    <18344, 18119, 18117>, 0,
    <18344, 18117, 18343>, 0,
    <18348, 18347, 18341>, 0,
    <18348, 18341, 18343>, 0,
    <18348, 18343, 18117>, 0,
    <18348, 18117, 18128>, 0,
    <18348, 18128, 18126>, 0,
    <18348, 18126, 18346>, 0,
    <18348, 18346, 18345>, 0,
    <18348, 18345, 18347>, 0,
    <18350, 18342, 18341>, 0,
    <18350, 18341, 18347>, 0,
    <18350, 18347, 18345>, 0,
    <18350, 18345, 18349>, 0,
    <18350, 18349, 18337>, 0,
    <18350, 18337, 18338>, 0,
    <18350, 18338, 18333>, 0,
    <18350, 18333, 18342>, 0,
    <18356, 18355, 18351>, 0,
    <18356, 18351, 18353>, 0,
    <18356, 18353, 18352>, 0,
    <18356, 18352, 18354>, 0,
    <18356, 18354, 18337>, 0,
    <18356, 18337, 18349>, 0,
    <18356, 18349, 18345>, 0,
    <18356, 18345, 18355>, 0,
    <18358, 18357, 18351>, 0,
    <18358, 18351, 18355>, 0,
    <18358, 18355, 18345>, 0,
    <18358, 18345, 18346>, 0,
    <18358, 18346, 18126>, 0,
    <18358, 18126, 18153>, 0,
    <18358, 18153, 18151>, 0,
    <18358, 18151, 18357>, 0,
    <18360, 18353, 18351>, 0,
    <18360, 18351, 18357>, 0,
    <18360, 18357, 18151>, 0,
    <18360, 18151, 18158>, 0,
    <18360, 18158, 17871>, 0,
    <18360, 17871, 18359>, 0,
    <18360, 18359, 18352>, 0,
    <18360, 18352, 18353>, 0,
    <18366, 18365, 18361>, 0,
    <18366, 18361, 18363>, 0,
    <18366, 18363, 18362>, 0,
    <18366, 18362, 18364>, 0,
    <18366, 18364, 18337>, 0,
    <18366, 18337, 18354>, 0,
    <18366, 18354, 18352>, 0,
    <18366, 18352, 18365>, 0,
    <18368, 18367, 18361>, 0,
    <18368, 18361, 18365>, 0,
    <18368, 18365, 18352>, 0,
    <18368, 18352, 18359>, 0,
    <18368, 18359, 17871>, 0,
    <18368, 17871, 18088>, 0,
    <18368, 18088, 18082>, 0,
    <18368, 18082, 18367>, 0,
    <18370, 18363, 18361>, 0,
    <18370, 18361, 18367>, 0,
    <18370, 18367, 18082>, 0,
    <18370, 18082, 18085>, 0,
    <18370, 18085, 18081>, 0,
    <18370, 18081, 18369>, 0,
    <18370, 18369, 18362>, 0,
    <18370, 18362, 18363>, 0,
    <18379, 18378, 18371>, 0,
    <18379, 18371, 18375>, 0,
    <18379, 18375, 18372>, 0,
    <18379, 18372, 18376>, 0,
    <18379, 18376, 18373>, 0,
    <18379, 18373, 18377>, 0,
    <18379, 18377, 18374>, 0,
    <18379, 18374, 18378>, 0,
    <18382, 18381, 18371>, 0,
    <18382, 18371, 18378>, 0,
    <18382, 18378, 18374>, 0,
    <18382, 18374, 18380>, 0,
    <18382, 18380, 17711>, 0,
    <18382, 17711, 17917>, 0,
    <18382, 17917, 17912>, 0,
    <18382, 17912, 18381>, 0,
    <18384, 18375, 18371>, 0,
    <18384, 18371, 18381>, 0,
    <18384, 18381, 17912>, 0,
    <18384, 17912, 17914>, 0,
    <18384, 17914, 4088>, 0,
    <18384, 4088, 18383>, 0,
    <18384, 18383, 18372>, 0,
    <18384, 18372, 18375>, 0,
    <18390, 18389, 18385>, 0,
    <18390, 18385, 18387>, 0,
    <18390, 18387, 18214>, 0,
    <18390, 18214, 18216>, 0,
    <18390, 18216, 4135>, 0,
    <18390, 4135, 18388>, 0,
    <18390, 18388, 18386>, 0,
    <18390, 18386, 18389>, 0,
    <18395, 18394, 18385>, 0,
    <18395, 18385, 18389>, 0,
    <18395, 18389, 18386>, 0,
    <18395, 18386, 18392>, 0,
    <18395, 18392, 4142>, 0,
    <18395, 4142, 18393>, 0,
    <18395, 18393, 18391>, 0,
    <18395, 18391, 18394>, 0,
    <18397, 18387, 18385>, 0,
    <18397, 18385, 18394>, 0,
    <18397, 18394, 18391>, 0,
    <18397, 18391, 18396>, 0,
    <18397, 18396, 18200>, 0,
    <18397, 18200, 18219>, 0,
    <18397, 18219, 18214>, 0,
    <18397, 18214, 18387>, 0,
    <18405, 18404, 18398>, 0,
    <18405, 18398, 18401>, 0,
    <18405, 18401, 18399>, 0,
    <18405, 18399, 18402>, 0,
    <18405, 18402, 4220>, 0,
    <18405, 4220, 18403>, 0,
    <18405, 18403, 18400>, 0,
    <18405, 18400, 18404>, 0,
    <18408, 18407, 18398>, 0,
    <18408, 18398, 18404>, 0,
    <18408, 18404, 18400>, 0,
    <18408, 18400, 18406>, 0,
    <18408, 18406, 17154>, 0,
    <18408, 17154, 18261>, 0,
    <18408, 18261, 18256>, 0,
    <18408, 18256, 18407>, 0,
    <18410, 18401, 18398>, 0,
    <18410, 18398, 18407>, 0,
    <18410, 18407, 18256>, 0,
    <18410, 18256, 18258>, 0,
    <18410, 18258, 18243>, 0,
    <18410, 18243, 18409>, 0,
    <18410, 18409, 18399>, 0,
    <18410, 18399, 18401>, 0,
    <18416, 18415, 18411>, 0,
    <18416, 18411, 18413>, 0,
    <18416, 18413, 18400>, 0,
    <18416, 18400, 18403>, 0,
    <18416, 18403, 4220>, 0,
    <18416, 4220, 18414>, 0,
    <18416, 18414, 18412>, 0,
    <18416, 18412, 18415>, 0,
    <18419, 18418, 18411>, 0,
    <18419, 18411, 18415>, 0,
    <18419, 18415, 18412>, 0,
    <18419, 18412, 18417>, 0,
    <18419, 18417, 4237>, 0,
    <18419, 4237, 18107>, 0,
    <18419, 18107, 18104>, 0,
    <18419, 18104, 18418>, 0,
    <18420, 18413, 18411>, 0,
    <18420, 18411, 18418>, 0,
    <18420, 18418, 18104>, 0,
    <18420, 18104, 18114>, 0,
    <18420, 18114, 17154>, 0,
    <18420, 17154, 18406>, 0,
    <18420, 18406, 18400>, 0,
    <18420, 18400, 18413>, 0,
    <18426, 18425, 18421>, 0,
    <18426, 18421, 18423>, 0,
    <18426, 18423, 18391>, 0,
    <18426, 18391, 18393>, 0,
    <18426, 18393, 4142>, 0,
    <18426, 4142, 18424>, 0,
    <18426, 18424, 18422>, 0,
    <18426, 18422, 18425>, 0,
    <18432, 18431, 18421>, 0,
    <18432, 18421, 18425>, 0,
    <18432, 18425, 18422>, 0,
    <18432, 18422, 18429>, 0,
    <18432, 18429, 18427>, 0,
    <18432, 18427, 18430>, 0,
    <18432, 18430, 18428>, 0,
    <18432, 18428, 18431>, 0,
    <18434, 18423, 18421>, 0,
    <18434, 18421, 18431>, 0,
    <18434, 18431, 18428>, 0,
    <18434, 18428, 18433>, 0,
    <18434, 18433, 18200>, 0,
    <18434, 18200, 18396>, 0,
    <18434, 18396, 18391>, 0,
    <18434, 18391, 18423>, 0,
    <18438, 18437, 18435>, 0,
    <18438, 18435, 18436>, 0,
    <18438, 18436, 18232>, 0,
    <18438, 18232, 18234>, 0,
    <18438, 18234, 18200>, 0,
    <18438, 18200, 18433>, 0,
    <18438, 18433, 18428>, 0,
    <18438, 18428, 18437>, 0,
    <18442, 18441, 18435>, 0,
    <18442, 18435, 18437>, 0,
    <18442, 18437, 18428>, 0,
    <18442, 18428, 18430>, 0,
    <18442, 18430, 18427>, 0,
    <18442, 18427, 18440>, 0,
    <18442, 18440, 18439>, 0,
    <18442, 18439, 18441>, 0,
    <18444, 18436, 18435>, 0,
    <18444, 18435, 18441>, 0,
    <18444, 18441, 18439>, 0,
    <18444, 18439, 18443>, 0,
    <18444, 18443, 18166>, 0,
    <18444, 18166, 18237>, 0,
    <18444, 18237, 18232>, 0,
    <18444, 18232, 18436>, 0,
    <18450, 18449, 18445>, 0,
    <18450, 18445, 18447>, 0,
    <18450, 18447, 18439>, 0,
    <18450, 18439, 18440>, 0,
    <18450, 18440, 18427>, 0,
    <18450, 18427, 18448>, 0,
    <18450, 18448, 18446>, 0,
    <18450, 18446, 18449>, 0,
    <18453, 18452, 18445>, 0,
    <18453, 18445, 18449>, 0,
    <18453, 18449, 18446>, 0,
    <18453, 18446, 18451>, 0,
    <18453, 18451, 17989>, 0,
    <18453, 17989, 18190>, 0,
    <18453, 18190, 18185>, 0,
    <18453, 18185, 18452>, 0,
    <18454, 18447, 18445>, 0,
    <18454, 18445, 18452>, 0,
    <18454, 18452, 18185>, 0,
    <18454, 18185, 18187>, 0,
    <18454, 18187, 18166>, 0,
    <18454, 18166, 18443>, 0,
    <18454, 18443, 18439>, 0,
    <18454, 18439, 18447>, 0,
    <18460, 18459, 18455>, 0,
    <18460, 18455, 18457>, 0,
    <18460, 18457, 18446>, 0,
    <18460, 18446, 18448>, 0,
    <18460, 18448, 18427>, 0,
    <18460, 18427, 18458>, 0,
    <18460, 18458, 18456>, 0,
    <18460, 18456, 18459>, 0,
    <18463, 18462, 18455>, 0,
    <18463, 18455, 18459>, 0,
    <18463, 18459, 18456>, 0,
    <18463, 18456, 18461>, 0,
    <18463, 18461, 18243>, 0,
    <18463, 18243, 18246>, 0,
    <18463, 18246, 18242>, 0,
    <18463, 18242, 18462>, 0,
    <18464, 18457, 18455>, 0,
    <18464, 18455, 18462>, 0,
    <18464, 18462, 18242>, 0,
    <18464, 18242, 18253>, 0,
    <18464, 18253, 17989>, 0,
    <18464, 17989, 18451>, 0,
    <18464, 18451, 18446>, 0,
    <18464, 18446, 18457>, 0,
    <18470, 18469, 18465>, 0,
    <18470, 18465, 18467>, 0,
    <18470, 18467, 18422>, 0,
    <18470, 18422, 18424>, 0,
    <18470, 18424, 4142>, 0,
    <18470, 4142, 18468>, 0,
    <18470, 18468, 18466>, 0,
    <18470, 18466, 18469>, 0,
    <18476, 18475, 18465>, 0,
    <18476, 18465, 18469>, 0,
    <18476, 18469, 18466>, 0,
    <18476, 18466, 18473>, 0,
    <18476, 18473, 18471>, 0,
    <18476, 18471, 18474>, 0,
    <18476, 18474, 18472>, 0,
    <18476, 18472, 18475>, 0,
    <18478, 18467, 18465>, 0,
    <18478, 18465, 18475>, 0,
    <18478, 18475, 18472>, 0,
    <18478, 18472, 18477>, 0,
    <18478, 18477, 18427>, 0,
    <18478, 18427, 18429>, 0,
    <18478, 18429, 18422>, 0,
    <18478, 18422, 18467>, 0,
    <18486, 18485, 18479>, 0,
    <18486, 18479, 18482>, 0,
    <18486, 18482, 18480>, 0,
    <18486, 18480, 18483>, 0,
    <18486, 18483, 4333>, 0,
    <18486, 4333, 18484>, 0,
    <18486, 18484, 18481>, 0,
    <18486, 18481, 18485>, 0,
    <18489, 18488, 18479>, 0,
    <18489, 18479, 18485>, 0,
    <18489, 18485, 18481>, 0,
    <18489, 18481, 18487>, 0,
    <18489, 18487, 4220>, 0,
    <18489, 4220, 18402>, 0,
    <18489, 18402, 18399>, 0,
    <18489, 18399, 18488>, 0,
    <18491, 18482, 18479>, 0,
    <18491, 18479, 18488>, 0,
    <18491, 18488, 18399>, 0,
    <18491, 18399, 18409>, 0,
    <18491, 18409, 18243>, 0,
    <18491, 18243, 18490>, 0,
    <18491, 18490, 18480>, 0,
    <18491, 18480, 18482>, 0,
    <18497, 18496, 18492>, 0,
    <18497, 18492, 18494>, 0,
    <18497, 18494, 18493>, 0,
    <18497, 18493, 18495>, 0,
    <18497, 18495, 18289>, 0,
    <18497, 18289, 18330>, 0,
    <18497, 18330, 18328>, 0,
    <18497, 18328, 18496>, 0,
    <18501, 18500, 18492>, 0,
    <18501, 18492, 18496>, 0,
    <18501, 18496, 18328>, 0,
    <18501, 18328, 18339>, 0,
    <18501, 18339, 18337>, 0,
    <18501, 18337, 18499>, 0,
    <18501, 18499, 18498>, 0,
    <18501, 18498, 18500>, 0,
    <18505, 18494, 18492>, 0,
    <18505, 18492, 18500>, 0,
    <18505, 18500, 18498>, 0,
    <18505, 18498, 18503>, 0,
    <18505, 18503, 18502>, 0,
    <18505, 18502, 18504>, 0,
    <18505, 18504, 18493>, 0,
    <18505, 18493, 18494>, 0,
    <18511, 18510, 18506>, 0,
    <18511, 18506, 18508>, 0,
    <18511, 18508, 18507>, 0,
    <18511, 18507, 18509>, 0,
    <18511, 18509, 18502>, 0,
    <18511, 18502, 18503>, 0,
    <18511, 18503, 18498>, 0,
    <18511, 18498, 18510>, 0,
    <18513, 18512, 18506>, 0,
    <18513, 18506, 18510>, 0,
    <18513, 18510, 18498>, 0,
    <18513, 18498, 18499>, 0,
    <18513, 18499, 18337>, 0,
    <18513, 18337, 18364>, 0,
    <18513, 18364, 18362>, 0,
    <18513, 18362, 18512>, 0,
    <18515, 18508, 18506>, 0,
    <18515, 18506, 18512>, 0,
    <18515, 18512, 18362>, 0,
    <18515, 18362, 18369>, 0,
    <18515, 18369, 18081>, 0,
    <18515, 18081, 18514>, 0,
    <18515, 18514, 18507>, 0,
    <18515, 18507, 18508>, 0,
    <18521, 18520, 18516>, 0,
    <18521, 18516, 18518>, 0,
    <18521, 18518, 18517>, 0,
    <18521, 18517, 18519>, 0,
    <18521, 18519, 18502>, 0,
    <18521, 18502, 18509>, 0,
    <18521, 18509, 18507>, 0,
    <18521, 18507, 18520>, 0,
    <18523, 18522, 18516>, 0,
    <18523, 18516, 18520>, 0,
    <18523, 18520, 18507>, 0,
    <18523, 18507, 18514>, 0,
    <18523, 18514, 18081>, 0,
    <18523, 18081, 18312>, 0,
    <18523, 18312, 18306>, 0,
    <18523, 18306, 18522>, 0,
    <18525, 18518, 18516>, 0,
    <18525, 18516, 18522>, 0,
    <18525, 18522, 18306>, 0,
    <18525, 18306, 18309>, 0,
    <18525, 18309, 18305>, 0,
    <18525, 18305, 18524>, 0,
    <18525, 18524, 18517>, 0,
    <18525, 18517, 18518>, 0,
    <18531, 18530, 18526>, 0,
    <18531, 18526, 18528>, 0,
    <18531, 18528, 18527>, 0,
    <18531, 18527, 18529>, 0,
    <18531, 18529, 18267>, 0,
    <18531, 18267, 18270>, 0,
    <18531, 18270, 18266>, 0,
    <18531, 18266, 18530>, 0,
    <18535, 18534, 18526>, 0,
    <18535, 18526, 18530>, 0,
    <18535, 18530, 18266>, 0,
    <18535, 18266, 18277>, 0,
    <18535, 18277, 17685>, 0,
    <18535, 17685, 18533>, 0,
    <18535, 18533, 18532>, 0,
    <18535, 18532, 18534>, 0,
    <18539, 18528, 18526>, 0,
    <18539, 18526, 18534>, 0,
    <18539, 18534, 18532>, 0,
    <18539, 18532, 18537>, 0,
    <18539, 18537, 18536>, 0,
    <18539, 18536, 18538>, 0,
    <18539, 18538, 18527>, 0,
    <18539, 18527, 18528>, 0,
    <18543, 18542, 18540>, 0,
    <18543, 18540, 18541>, 0,
    <18543, 18541, 18532>, 0,
    <18543, 18532, 18533>, 0,
    <18543, 18533, 17685>, 0,
    <18543, 17685, 18282>, 0,
    <18543, 18282, 18280>, 0,
    <18543, 18280, 18542>, 0,
    <18547, 18546, 18540>, 0,
    <18547, 18540, 18542>, 0,
    <18547, 18542, 18280>, 0,
    <18547, 18280, 18291>, 0,
    <18547, 18291, 18289>, 0,
    <18547, 18289, 18545>, 0,
    <18547, 18545, 18544>, 0,
    <18547, 18544, 18546>, 0,
    <18549, 18541, 18540>, 0,
    <18549, 18540, 18546>, 0,
    <18549, 18546, 18544>, 0,
    <18549, 18544, 18548>, 0,
    <18549, 18548, 18536>, 0,
    <18549, 18536, 18537>, 0,
    <18549, 18537, 18532>, 0,
    <18549, 18532, 18541>, 0,
    <18555, 18554, 18550>, 0,
    <18555, 18550, 18552>, 0,
    <18555, 18552, 18551>, 0,
    <18555, 18551, 18553>, 0,
    <18555, 18553, 18536>, 0,
    <18555, 18536, 18548>, 0,
    <18555, 18548, 18544>, 0,
    <18555, 18544, 18554>, 0,
    <18557, 18556, 18550>, 0,
    <18557, 18550, 18554>, 0,
    <18557, 18554, 18544>, 0,
    <18557, 18544, 18545>, 0,
    <18557, 18545, 18289>, 0,
    <18557, 18289, 18495>, 0,
    <18557, 18495, 18493>, 0,
    <18557, 18493, 18556>, 0,
    <18559, 18552, 18550>, 0,
    <18559, 18550, 18556>, 0,
    <18559, 18556, 18493>, 0,
    <18559, 18493, 18504>, 0,
    <18559, 18504, 18502>, 0,
    <18559, 18502, 18558>, 0,
    <18559, 18558, 18551>, 0,
    <18559, 18551, 18552>, 0,
    <18568, 18567, 18560>, 0,
    <18568, 18560, 18564>, 0,
    <18568, 18564, 18561>, 0,
    <18568, 18561, 18565>, 0,
    <18568, 18565, 18562>, 0,
    <18568, 18562, 18566>, 0,
    <18568, 18566, 18563>, 0,
    <18568, 18563, 18567>, 0,
    <18571, 18570, 18560>, 0,
    <18571, 18560, 18567>, 0,
    <18571, 18567, 18563>, 0,
    <18571, 18563, 18569>, 0,
    <18571, 18569, 18305>, 0,
    <18571, 18305, 18320>, 0,
    <18571, 18320, 18318>, 0,
    <18571, 18318, 18570>, 0,
    <18573, 18564, 18560>, 0,
    <18573, 18560, 18570>, 0,
    <18573, 18570, 18318>, 0,
    <18573, 18318, 18325>, 0,
    <18573, 18325, 17266>, 0,
    <18573, 17266, 18572>, 0,
    <18573, 18572, 18561>, 0,
    <18573, 18561, 18564>, 0,
    <18579, 18578, 18574>, 0,
    <18579, 18574, 18576>, 0,
    <18579, 18576, 18374>, 0,
    <18579, 18374, 18377>, 0,
    <18579, 18377, 18373>, 0,
    <18579, 18373, 18577>, 0,
    <18579, 18577, 18575>, 0,
    <18579, 18575, 18578>, 0,
    <18584, 18583, 18574>, 0,
    <18584, 18574, 18578>, 0,
    <18584, 18578, 18575>, 0,
    <18584, 18575, 18581>, 0,
    <18584, 18581, 18562>, 0,
    <18584, 18562, 18582>, 0,
    <18584, 18582, 18580>, 0,
    <18584, 18580, 18583>, 0,
    <18586, 18576, 18574>, 0,
    <18586, 18574, 18583>, 0,
    <18586, 18583, 18580>, 0,
    <18586, 18580, 18585>, 0,
    <18586, 18585, 17711>, 0,
    <18586, 17711, 18380>, 0,
    <18586, 18380, 18374>, 0,
    <18586, 18374, 18576>, 0,
    <18590, 18589, 18587>, 0,
    <18590, 18587, 18588>, 0,
    <18590, 18588, 18580>, 0,
    <18590, 18580, 18582>, 0,
    <18590, 18582, 18562>, 0,
    <18590, 18562, 18565>, 0,
    <18590, 18565, 18561>, 0,
    <18590, 18561, 18589>, 0,
    <18592, 18591, 18587>, 0,
    <18592, 18587, 18589>, 0,
    <18592, 18589, 18561>, 0,
    <18592, 18561, 18572>, 0,
    <18592, 18572, 17266>, 0,
    <18592, 17266, 17718>, 0,
    <18592, 17718, 17712>, 0,
    <18592, 17712, 18591>, 0,
    <18593, 18588, 18587>, 0,
    <18593, 18587, 18591>, 0,
    <18593, 18591, 17712>, 0,
    <18593, 17712, 17715>, 0,
    <18593, 17715, 17711>, 0,
    <18593, 17711, 18585>, 0,
    <18593, 18585, 18580>, 0,
    <18593, 18580, 18588>, 0,
    <18602, 18601, 18594>, 0,
    <18602, 18594, 18598>, 0,
    <18602, 18598, 18595>, 0,
    <18602, 18595, 18599>, 0,
    <18602, 18599, 18596>, 0,
    <18602, 18596, 18600>, 0,
    <18602, 18600, 18597>, 0,
    <18602, 18597, 18601>, 0,
    <18605, 18604, 18594>, 0,
    <18605, 18594, 18601>, 0,
    <18605, 18601, 18597>, 0,
    <18605, 18597, 18603>, 0,
    <18605, 18603, 18267>, 0,
    <18605, 18267, 18529>, 0,
    <18605, 18529, 18527>, 0,
    <18605, 18527, 18604>, 0,
    <18607, 18598, 18594>, 0,
    <18607, 18594, 18604>, 0,
    <18607, 18604, 18527>, 0,
    <18607, 18527, 18538>, 0,
    <18607, 18538, 18536>, 0,
    <18607, 18536, 18606>, 0,
    <18607, 18606, 18595>, 0,
    <18607, 18595, 18598>, 0,
    <18613, 18612, 18608>, 0,
    <18613, 18608, 18610>, 0,
    <18613, 18610, 18575>, 0,
    <18613, 18575, 18577>, 0,
    <18613, 18577, 18373>, 0,
    <18613, 18373, 18611>, 0,
    <18613, 18611, 18609>, 0,
    <18613, 18609, 18612>, 0,
    <18619, 18618, 18608>, 0,
    <18619, 18608, 18612>, 0,
    <18619, 18612, 18609>, 0,
    <18619, 18609, 18616>, 0,
    <18619, 18616, 18614>, 0,
    <18619, 18614, 18617>, 0,
    <18619, 18617, 18615>, 0,
    <18619, 18615, 18618>, 0,
    <18621, 18610, 18608>, 0,
    <18621, 18608, 18618>, 0,
    <18621, 18618, 18615>, 0,
    <18621, 18615, 18620>, 0,
    <18621, 18620, 18562>, 0,
    <18621, 18562, 18581>, 0,
    <18621, 18581, 18575>, 0,
    <18621, 18575, 18610>, 0,
    <18627, 18626, 18622>, 0,
    <18627, 18622, 18624>, 0,
    <18627, 18624, 18472>, 0,
    <18627, 18472, 18474>, 0,
    <18627, 18474, 18471>, 0,
    <18627, 18471, 18625>, 0,
    <18627, 18625, 18623>, 0,
    <18627, 18623, 18626>, 0,
    <18632, 18631, 18622>, 0,
    <18632, 18622, 18626>, 0,
    <18632, 18626, 18623>, 0,
    <18632, 18623, 18629>, 0,
    <18632, 18629, 4285>, 0,
    <18632, 4285, 18630>, 0,
    <18632, 18630, 18628>, 0,
    <18632, 18628, 18631>, 0,
    <18634, 18624, 18622>, 0,
    <18634, 18622, 18631>, 0,
    <18634, 18631, 18628>, 0,
    <18634, 18628, 18633>, 0,
    <18634, 18633, 18427>, 0,
    <18634, 18427, 18477>, 0,
    <18634, 18477, 18472>, 0,
    <18634, 18472, 18624>, 0,
    <18640, 18639, 18635>, 0,
    <18640, 18635, 18637>, 0,
    <18640, 18637, 18628>, 0,
    <18640, 18628, 18630>, 0,
    <18640, 18630, 4285>, 0,
    <18640, 4285, 18638>, 0,
    <18640, 18638, 18636>, 0,
    <18640, 18636, 18639>, 0,
    <18643, 18642, 18635>, 0,
    <18643, 18635, 18639>, 0,
    <18643, 18639, 18636>, 0,
    <18643, 18636, 18641>, 0,
    <18643, 18641, 18243>, 0,
    <18643, 18243, 18461>, 0,
    <18643, 18461, 18456>, 0,
    <18643, 18456, 18642>, 0,
    <18644, 18637, 18635>, 0,
    <18644, 18635, 18642>, 0,
    <18644, 18642, 18456>, 0,
    <18644, 18456, 18458>, 0,
    <18644, 18458, 18427>, 0,
    <18644, 18427, 18633>, 0,
    <18644, 18633, 18628>, 0,
    <18644, 18628, 18637>, 0,
    <18650, 18649, 18645>, 0,
    <18650, 18645, 18647>, 0,
    <18650, 18647, 18636>, 0,
    <18650, 18636, 18638>, 0,
    <18650, 18638, 4285>, 0,
    <18650, 4285, 18648>, 0,
    <18650, 18648, 18646>, 0,
    <18650, 18646, 18649>, 0,
    <18653, 18652, 18645>, 0,
    <18653, 18645, 18649>, 0,
    <18653, 18649, 18646>, 0,
    <18653, 18646, 18651>, 0,
    <18653, 18651, 4333>, 0,
    <18653, 4333, 18483>, 0,
    <18653, 18483, 18480>, 0,
    <18653, 18480, 18652>, 0,
    <18654, 18647, 18645>, 0,
    <18654, 18645, 18652>, 0,
    <18654, 18652, 18480>, 0,
    <18654, 18480, 18490>, 0,
    <18654, 18490, 18243>, 0,
    <18654, 18243, 18641>, 0,
    <18654, 18641, 18636>, 0,
    <18654, 18636, 18647>, 0,
    <18660, 18659, 18655>, 0,
    <18660, 18655, 18657>, 0,
    <18660, 18657, 18656>, 0,
    <18660, 18656, 18658>, 0,
    <18660, 18658, 18596>, 0,
    <18660, 18596, 18599>, 0,
    <18660, 18599, 18595>, 0,
    <18660, 18595, 18659>, 0,
    <18664, 18663, 18655>, 0,
    <18664, 18655, 18659>, 0,
    <18664, 18659, 18595>, 0,
    <18664, 18595, 18606>, 0,
    <18664, 18606, 18536>, 0,
    <18664, 18536, 18662>, 0,
    <18664, 18662, 18661>, 0,
    <18664, 18661, 18663>, 0,
    <18667, 18657, 18655>, 0,
    <18667, 18655, 18663>, 0,
    <18667, 18663, 18661>, 0,
    <18667, 18661, 18665>, 0,
    <18667, 18665, 4194>, 0,
    <18667, 4194, 18666>, 0,
    <18667, 18666, 18656>, 0,
    <18667, 18656, 18657>, 0,
    <18673, 18672, 18668>, 0,
    <18673, 18668, 18670>, 0,
    <18673, 18670, 18615>, 0,
    <18673, 18615, 18617>, 0,
    <18673, 18617, 18614>, 0,
    <18673, 18614, 18671>, 0,
    <18673, 18671, 18669>, 0,
    <18673, 18669, 18672>, 0,
    <18678, 18677, 18668>, 0,
    <18678, 18668, 18672>, 0,
    <18678, 18672, 18669>, 0,
    <18678, 18669, 18675>, 0,
    <18678, 18675, 4208>, 0,
    <18678, 4208, 18676>, 0,
    <18678, 18676, 18674>, 0,
    <18678, 18674, 18677>, 0,
    <18680, 18670, 18668>, 0,
    <18680, 18668, 18677>, 0,
    <18680, 18677, 18674>, 0,
    <18680, 18674, 18679>, 0,
    <18680, 18679, 18562>, 0,
    <18680, 18562, 18620>, 0,
    <18680, 18620, 18615>, 0,
    <18680, 18615, 18670>, 0,
    <18686, 18685, 18681>, 0,
    <18686, 18681, 18683>, 0,
    <18686, 18683, 18682>, 0,
    <18686, 18682, 18684>, 0,
    <18686, 18684, 18536>, 0,
    <18686, 18536, 18553>, 0,
    <18686, 18553, 18551>, 0,
    <18686, 18551, 18685>, 0,
    <18690, 18689, 18681>, 0,
    <18690, 18681, 18685>, 0,
    <18690, 18685, 18551>, 0,
    <18690, 18551, 18558>, 0,
    <18690, 18558, 18502>, 0,
    <18690, 18502, 18688>, 0,
    <18690, 18688, 18687>, 0,
    <18690, 18687, 18689>, 0,
    <18694, 18683, 18681>, 0,
    <18694, 18681, 18689>, 0,
    <18694, 18689, 18687>, 0,
    <18694, 18687, 18692>, 0,
    <18694, 18692, 18691>, 0,
    <18694, 18691, 18693>, 0,
    <18694, 18693, 18682>, 0,
    <18694, 18682, 18683>, 0,
    <18700, 18699, 18695>, 0,
    <18700, 18695, 18697>, 0,
    <18700, 18697, 18696>, 0,
    <18700, 18696, 18698>, 0,
    <18700, 18698, 18691>, 0,
    <18700, 18691, 18692>, 0,
    <18700, 18692, 18687>, 0,
    <18700, 18687, 18699>, 0,
    <18702, 18701, 18695>, 0,
    <18702, 18695, 18699>, 0,
    <18702, 18699, 18687>, 0,
    <18702, 18687, 18688>, 0,
    <18702, 18688, 18502>, 0,
    <18702, 18502, 18519>, 0,
    <18702, 18519, 18517>, 0,
    <18702, 18517, 18701>, 0,
    <18704, 18697, 18695>, 0,
    <18704, 18695, 18701>, 0,
    <18704, 18701, 18517>, 0,
    <18704, 18517, 18524>, 0,
    <18704, 18524, 18305>, 0,
    <18704, 18305, 18703>, 0,
    <18704, 18703, 18696>, 0,
    <18704, 18696, 18697>, 0,
    <18710, 18709, 18705>, 0,
    <18710, 18705, 18707>, 0,
    <18710, 18707, 18706>, 0,
    <18710, 18706, 18708>, 0,
    <18710, 18708, 18691>, 0,
    <18710, 18691, 18698>, 0,
    <18710, 18698, 18696>, 0,
    <18710, 18696, 18709>, 0,
    <18712, 18711, 18705>, 0,
    <18712, 18705, 18709>, 0,
    <18712, 18709, 18696>, 0,
    <18712, 18696, 18703>, 0,
    <18712, 18703, 18305>, 0,
    <18712, 18305, 18569>, 0,
    <18712, 18569, 18563>, 0,
    <18712, 18563, 18711>, 0,
    <18714, 18707, 18705>, 0,
    <18714, 18705, 18711>, 0,
    <18714, 18711, 18563>, 0,
    <18714, 18563, 18566>, 0,
    <18714, 18566, 18562>, 0,
    <18714, 18562, 18713>, 0,
    <18714, 18713, 18706>, 0,
    <18714, 18706, 18707>, 0,
    <18723, 18722, 18715>, 0,
    <18723, 18715, 18719>, 0,
    <18723, 18719, 18716>, 0,
    <18723, 18716, 18720>, 0,
    <18723, 18720, 18717>, 0,
    <18723, 18717, 18721>, 0,
    <18723, 18721, 18718>, 0,
    <18723, 18718, 18722>, 0,
    <18726, 18725, 18715>, 0,
    <18726, 18715, 18722>, 0,
    <18726, 18722, 18718>, 0,
    <18726, 18718, 18724>, 0,
    <18726, 18724, 4194>, 0,
    <18726, 4194, 18665>, 0,
    <18726, 18665, 18661>, 0,
    <18726, 18661, 18725>, 0,
    <18728, 18719, 18715>, 0,
    <18728, 18715, 18725>, 0,
    <18728, 18725, 18661>, 0,
    <18728, 18661, 18662>, 0,
    <18728, 18662, 18536>, 0,
    <18728, 18536, 18727>, 0,
    <18728, 18727, 18716>, 0,
    <18728, 18716, 18719>, 0,
    <18734, 18733, 18729>, 0,
    <18734, 18729, 18731>, 0,
    <18734, 18731, 18730>, 0,
    <18734, 18730, 18732>, 0,
    <18734, 18732, 18717>, 0,
    <18734, 18717, 18720>, 0,
    <18734, 18720, 18716>, 0,
    <18734, 18716, 18733>, 0,
    <18736, 18735, 18729>, 0,
    <18736, 18729, 18733>, 0,
    <18736, 18733, 18716>, 0,
    <18736, 18716, 18727>, 0,
    <18736, 18727, 18536>, 0,
    <18736, 18536, 18684>, 0,
    <18736, 18684, 18682>, 0,
    <18736, 18682, 18735>, 0,
    <18738, 18731, 18729>, 0,
    <18738, 18729, 18735>, 0,
    <18738, 18735, 18682>, 0,
    <18738, 18682, 18693>, 0,
    <18738, 18693, 18691>, 0,
    <18738, 18691, 18737>, 0,
    <18738, 18737, 18730>, 0,
    <18738, 18730, 18731>, 0,
    <18747, 18746, 18739>, 0,
    <18747, 18739, 18743>, 0,
    <18747, 18743, 18740>, 0,
    <18747, 18740, 18744>, 0,
    <18747, 18744, 18741>, 0,
    <18747, 18741, 18745>, 0,
    <18747, 18745, 18742>, 0,
    <18747, 18742, 18746>, 0,
    <18750, 18749, 18739>, 0,
    <18750, 18739, 18746>, 0,
    <18750, 18746, 18742>, 0,
    <18750, 18742, 18748>, 0,
    <18750, 18748, 18691>, 0,
    <18750, 18691, 18708>, 0,
    <18750, 18708, 18706>, 0,
    <18750, 18706, 18749>, 0,
    <18752, 18743, 18739>, 0,
    <18752, 18739, 18749>, 0,
    <18752, 18749, 18706>, 0,
    <18752, 18706, 18713>, 0,
    <18752, 18713, 18562>, 0,
    <18752, 18562, 18751>, 0,
    <18752, 18751, 18740>, 0,
    <18752, 18740, 18743>, 0,
    <18758, 18757, 18753>, 0,
    <18758, 18753, 18755>, 0,
    <18758, 18755, 18754>, 0,
    <18758, 18754, 18756>, 0,
    <18758, 18756, 18741>, 0,
    <18758, 18741, 18744>, 0,
    <18758, 18744, 18740>, 0,
    <18758, 18740, 18757>, 0,
    <18760, 18759, 18753>, 0,
    <18760, 18753, 18757>, 0,
    <18760, 18757, 18740>, 0,
    <18760, 18740, 18751>, 0,
    <18760, 18751, 18562>, 0,
    <18760, 18562, 18679>, 0,
    <18760, 18679, 18674>, 0,
    <18760, 18674, 18759>, 0,
    <18762, 18755, 18753>, 0,
    <18762, 18753, 18759>, 0,
    <18762, 18759, 18674>, 0,
    <18762, 18674, 18676>, 0,
    <18762, 18676, 4208>, 0,
    <18762, 4208, 18761>, 0,
    <18762, 18761, 18754>, 0,
    <18762, 18754, 18755>, 0,
    <18771, 18770, 18763>, 0,
    <18771, 18763, 18767>, 0,
    <18771, 18767, 18764>, 0,
    <18771, 18764, 18768>, 0,
    <18771, 18768, 18765>, 0,
    <18771, 18765, 18769>, 0,
    <18771, 18769, 18766>, 0,
    <18771, 18766, 18770>, 0,
    <18774, 18773, 18763>, 0,
    <18774, 18763, 18770>, 0,
    <18774, 18770, 18766>, 0,
    <18774, 18766, 18772>, 0,
    <18774, 18772, 18717>, 0,
    <18774, 18717, 18732>, 0,
    <18774, 18732, 18730>, 0,
    <18774, 18730, 18773>, 0,
    <18776, 18767, 18763>, 0,
    <18776, 18763, 18773>, 0,
    <18776, 18773, 18730>, 0,
    <18776, 18730, 18737>, 0,
    <18776, 18737, 18691>, 0,
    <18776, 18691, 18775>, 0,
    <18776, 18775, 18764>, 0,
    <18776, 18764, 18767>, 0,
    <18782, 18781, 18777>, 0,
    <18782, 18777, 18779>, 0,
    <18782, 18779, 18742>, 0,
    <18782, 18742, 18745>, 0,
    <18782, 18745, 18741>, 0,
    <18782, 18741, 18780>, 0,
    <18782, 18780, 18778>, 0,
    <18782, 18778, 18781>, 0,
    <18787, 18786, 18777>, 0,
    <18787, 18777, 18781>, 0,
    <18787, 18781, 18778>, 0,
    <18787, 18778, 18784>, 0,
    <18787, 18784, 4295>, 0,
    <18787, 4295, 18785>, 0,
    <18787, 18785, 18783>, 0,
    <18787, 18783, 18786>, 0,
    <18789, 18779, 18777>, 0,
    <18789, 18777, 18786>, 0,
    <18789, 18786, 18783>, 0,
    <18789, 18783, 18788>, 0,
    <18789, 18788, 18691>, 0,
    <18789, 18691, 18748>, 0,
    <18789, 18748, 18742>, 0,
    <18789, 18742, 18779>, 0,
    <18795, 18794, 18790>, 0,
    <18795, 18790, 18792>, 0,
    <18795, 18792, 18791>, 0,
    <18795, 18791, 18793>, 0,
    <18795, 18793, 18765>, 0,
    <18795, 18765, 18768>, 0,
    <18795, 18768, 18764>, 0,
    <18795, 18764, 18794>, 0,
    <18797, 18796, 18790>, 0,
    <18797, 18790, 18794>, 0,
    <18797, 18794, 18764>, 0,
    <18797, 18764, 18775>, 0,
    <18797, 18775, 18691>, 0,
    <18797, 18691, 18788>, 0,
    <18797, 18788, 18783>, 0,
    <18797, 18783, 18796>, 0,
    <18799, 18792, 18790>, 0,
    <18799, 18790, 18796>, 0,
    <18799, 18796, 18783>, 0,
    <18799, 18783, 18785>, 0,
    <18799, 18785, 4295>, 0,
    <18799, 4295, 18798>, 0,
    <18799, 18798, 18791>, 0,
    <18799, 18791, 18792>, 0
  }
  normal_indices {
    35712,   // from 0 triangles and 17856 quads
    <0, 1, 2>,
    <0, 2, 3>,
    <0, 3, 4>,
    <0, 4, 5>,
    <0, 6, 7>,
    <0, 7, 8>,
    <0, 8, 9>,
    <0, 9, 1>,
    <10, 11, 2>,
    <10, 2, 1>,
    <10, 1, 9>,
    <10, 9, 12>,
    <10, 12, 13>,
    <10, 13, 14>,
    <10, 14, 15>,
    <10, 15, 11>,
    <16, 3, 2>,
    <16, 2, 11>,
    <16, 11, 15>,
    <16, 15, 17>,
    <16, 17, 18>,
    <16, 18, 19>,
    <16, 20, 21>,
    <16, 21, 3>,
    <22, 23, 24>,
    <22, 24, 25>,
    <22, 25, 26>,
    <22, 26, 27>,
    <22, 27, 28>,
    <22, 28, 29>,
    <22, 30, 31>,
    <22, 31, 23>,
    <32, 33, 24>,
    <32, 24, 23>,
    <32, 23, 34>,
    <32, 34, 35>,
    <32, 36, 37>,
    <32, 37, 17>,
    <32, 17, 15>,
    <32, 15, 33>,
    <38, 25, 24>,
    <38, 24, 33>,
    <38, 33, 15>,
    <38, 15, 14>,
    <38, 14, 39>,
    <38, 39, 40>,
    <38, 40, 26>,
    <38, 26, 25>,
    <41, 42, 43>,
    <41, 43, 44>,
    <41, 44, 45>,
    <41, 45, 46>,
    <41, 47, 48>,
    <41, 48, 49>,
    <41, 49, 50>,
    <41, 50, 42>,
    <51, 52, 43>,
    <51, 43, 42>,
    <51, 42, 50>,
    <51, 50, 53>,
    <51, 53, 54>,
    <51, 54, 12>,
    <51, 12, 9>,
    <51, 9, 52>,
    <55, 44, 43>,
    <55, 43, 52>,
    <55, 52, 9>,
    <55, 9, 8>,
    <55, 8, 56>,
    <55, 56, 57>,
    <55, 58, 59>,
    <55, 59, 44>,
    <60, 61, 62>,
    <60, 62, 63>,
    <60, 63, 64>,
    <60, 64, 65>,
    <60, 66, 67>,
    <60, 67, 68>,
    <60, 68, 69>,
    <60, 69, 61>,
    <70, 71, 62>,
    <70, 62, 61>,
    <70, 61, 69>,
    <70, 69, 72>,
    <70, 72, 73>,
    <70, 73, 74>,
    <70, 74, 75>,
    <70, 75, 71>,
    <76, 63, 62>,
    <76, 62, 71>,
    <76, 71, 75>,
    <76, 75, 77>,
    <76, 77, 78>,
    <76, 78, 79>,
    <76, 80, 81>,
    <76, 81, 63>,
    <82, 83, 84>,
    <82, 84, 85>,
    <82, 85, 50>,
    <82, 50, 49>,
    <82, 49, 86>,
    <82, 86, 77>,
    <82, 77, 75>,
    <82, 75, 83>,
    <87, 88, 84>,
    <87, 84, 83>,
    <87, 83, 75>,
    <87, 75, 74>,
    <87, 74, 89>,
    <87, 89, 90>,
    <87, 91, 92>,
    <87, 92, 88>,
    <93, 85, 84>,
    <93, 84, 88>,
    <93, 88, 94>,
    <93, 94, 95>,
    <93, 96, 97>,
    <93, 97, 53>,
    <93, 53, 50>,
    <93, 50, 85>,
    <98, 99, 100>,
    <98, 100, 101>,
    <98, 101, 102>,
    <98, 102, 103>,
    <98, 103, 104>,
    <98, 104, 27>,
    <98, 27, 26>,
    <98, 26, 99>,
    <105, 106, 100>,
    <105, 100, 99>,
    <105, 99, 26>,
    <105, 26, 40>,
    <105, 40, 107>,
    <105, 107, 108>,
    <105, 109, 110>,
    <105, 110, 106>,
    <111, 101, 100>,
    <111, 100, 106>,
    <111, 106, 112>,
    <111, 112, 113>,
    <111, 114, 115>,
    <111, 115, 116>,
    <111, 116, 102>,
    <111, 102, 101>,
    <117, 118, 119>,
    <117, 119, 120>,
    <117, 120, 121>,
    <117, 121, 122>,
    <117, 122, 123>,
    <117, 123, 124>,
    <117, 125, 126>,
    <117, 126, 118>,
    <127, 128, 119>,
    <127, 119, 118>,
    <127, 118, 129>,
    <127, 129, 130>,
    <127, 131, 132>,
    <127, 132, 103>,
    <127, 103, 102>,
    <127, 102, 128>,
    <133, 120, 119>,
    <133, 119, 128>,
    <133, 128, 102>,
    <133, 102, 116>,
    <133, 116, 134>,
    <133, 134, 135>,
    <133, 135, 121>,
    <133, 121, 120>,
    <136, 137, 138>,
    <136, 138, 139>,
    <136, 139, 140>,
    <136, 140, 141>,
    <136, 142, 143>,
    <136, 143, 122>,
    <136, 122, 121>,
    <136, 121, 137>,
    <144, 145, 138>,
    <144, 138, 137>,
    <144, 137, 121>,
    <144, 121, 135>,
    <144, 135, 146>,
    <144, 146, 147>,
    <144, 147, 148>,
    <144, 148, 145>,
    <149, 139, 138>,
    <149, 138, 145>,
    <149, 145, 148>,
    <149, 148, 150>,
    <149, 150, 151>,
    <149, 151, 152>,
    <149, 153, 154>,
    <149, 154, 139>,
    <155, 156, 157>,
    <155, 157, 158>,
    <155, 158, 159>,
    <155, 159, 160>,
    <155, 161, 162>,
    <155, 162, 163>,
    <155, 164, 165>,
    <155, 165, 156>,
    <166, 167, 157>,
    <166, 157, 156>,
    <166, 156, 168>,
    <166, 168, 169>,
    <166, 170, 171>,
    <166, 171, 172>,
    <166, 173, 174>,
    <166, 174, 167>,
    <175, 158, 157>,
    <175, 157, 167>,
    <175, 167, 176>,
    <175, 176, 177>,
    <175, 178, 179>,
    <175, 179, 180>,
    <175, 181, 182>,
    <175, 182, 158>,
    <183, 184, 185>,
    <183, 185, 186>,
    <183, 186, 187>,
    <183, 187, 188>,
    <183, 189, 190>,
    <183, 190, 191>,
    <183, 192, 193>,
    <183, 193, 184>,
    <194, 195, 185>,
    <194, 185, 184>,
    <194, 184, 196>,
    <194, 196, 197>,
    <194, 198, 199>,
    <194, 199, 200>,
    <194, 201, 202>,
    <194, 202, 195>,
    <203, 186, 185>,
    <203, 185, 195>,
    <203, 195, 204>,
    <203, 204, 205>,
    <203, 206, 207>,
    <203, 207, 208>,
    <203, 209, 210>,
    <203, 210, 186>,
    <211, 212, 213>,
    <211, 213, 214>,
    <211, 214, 215>,
    <211, 215, 216>,
    <211, 216, 217>,
    <211, 217, 218>,
    <211, 219, 220>,
    <211, 220, 212>,
    <221, 222, 213>,
    <221, 213, 212>,
    <221, 212, 223>,
    <221, 223, 224>,
    <221, 225, 226>,
    <221, 226, 150>,
    <221, 150, 148>,
    <221, 148, 222>,
    <227, 214, 213>,
    <227, 213, 222>,
    <227, 222, 148>,
    <227, 148, 147>,
    <227, 147, 228>,
    <227, 228, 229>,
    <227, 229, 215>,
    <227, 215, 214>,
    <230, 231, 232>,
    <230, 232, 233>,
    <230, 233, 234>,
    <230, 234, 235>,
    <230, 236, 237>,
    <230, 237, 238>,
    <230, 238, 239>,
    <230, 239, 231>,
    <240, 241, 232>,
    <240, 232, 231>,
    <240, 231, 239>,
    <240, 239, 242>,
    <240, 242, 243>,
    <240, 243, 72>,
    <240, 72, 69>,
    <240, 69, 241>,
    <244, 233, 232>,
    <244, 232, 241>,
    <244, 241, 69>,
    <244, 69, 68>,
    <244, 68, 245>,
    <244, 245, 246>,
    <244, 247, 248>,
    <244, 248, 233>,
    <249, 250, 251>,
    <249, 251, 252>,
    <249, 252, 253>,
    <249, 253, 254>,
    <249, 255, 256>,
    <249, 256, 257>,
    <249, 257, 258>,
    <249, 258, 250>,
    <259, 260, 251>,
    <259, 251, 250>,
    <259, 250, 258>,
    <259, 258, 261>,
    <259, 261, 262>,
    <259, 262, 263>,
    <259, 263, 264>,
    <259, 264, 260>,
    <265, 252, 251>,
    <265, 251, 260>,
    <265, 260, 264>,
    <265, 264, 266>,
    <265, 266, 267>,
    <265, 267, 268>,
    <265, 269, 270>,
    <265, 270, 252>,
    <271, 272, 273>,
    <271, 273, 274>,
    <271, 274, 239>,
    <271, 239, 238>,
    <271, 238, 275>,
    <271, 275, 266>,
    <271, 266, 264>,
    <271, 264, 272>,
    <276, 277, 273>,
    <276, 273, 272>,
    <276, 272, 264>,
    <276, 264, 263>,
    <276, 263, 278>,
    <276, 278, 279>,
    <276, 280, 281>,
    <276, 281, 277>,
    <282, 274, 273>,
    <282, 273, 277>,
    <282, 277, 283>,
    <282, 283, 284>,
    <282, 285, 286>,
    <282, 286, 242>,
    <282, 242, 239>,
    <282, 239, 274>,
    <287, 288, 289>,
    <287, 289, 290>,
    <287, 290, 291>,
    <287, 291, 292>,
    <287, 292, 293>,
    <287, 293, 216>,
    <287, 216, 215>,
    <287, 215, 288>,
    <294, 295, 289>,
    <294, 289, 288>,
    <294, 288, 215>,
    <294, 215, 229>,
    <294, 229, 296>,
    <294, 296, 297>,
    <294, 298, 299>,
    <294, 299, 295>,
    <300, 290, 289>,
    <300, 289, 295>,
    <300, 295, 301>,
    <300, 301, 302>,
    <300, 303, 304>,
    <300, 304, 305>,
    <300, 305, 291>,
    <300, 291, 290>,
    <306, 307, 308>,
    <306, 308, 309>,
    <306, 309, 310>,
    <306, 310, 311>,
    <306, 312, 313>,
    <306, 313, 292>,
    <306, 292, 291>,
    <306, 291, 307>,
    <314, 315, 308>,
    <314, 308, 307>,
    <314, 307, 291>,
    <314, 291, 305>,
    <314, 305, 316>,
    <314, 316, 317>,
    <314, 317, 318>,
    <314, 318, 315>,
    <319, 309, 308>,
    <319, 308, 315>,
    <319, 315, 318>,
    <319, 318, 320>,
    <319, 320, 321>,
    <319, 321, 322>,
    <319, 323, 324>,
    <319, 324, 309>,
    <325, 326, 327>,
    <325, 327, 328>,
    <325, 328, 329>,
    <325, 329, 330>,
    <325, 331, 332>,
    <325, 332, 320>,
    <325, 320, 318>,
    <325, 318, 326>,
    <333, 334, 327>,
    <333, 327, 326>,
    <333, 326, 318>,
    <333, 318, 317>,
    <333, 317, 335>,
    <333, 335, 336>,
    <333, 336, 337>,
    <333, 337, 334>,
    <338, 328, 327>,
    <338, 327, 334>,
    <338, 334, 337>,
    <338, 337, 339>,
    <338, 339, 340>,
    <338, 340, 341>,
    <338, 342, 343>,
    <338, 343, 328>,
    <344, 345, 346>,
    <344, 346, 347>,
    <344, 347, 348>,
    <344, 348, 349>,
    <344, 350, 351>,
    <344, 351, 352>,
    <344, 353, 354>,
    <344, 354, 345>,
    <355, 356, 346>,
    <355, 346, 345>,
    <355, 345, 357>,
    <355, 357, 358>,
    <355, 359, 360>,
    <355, 360, 361>,
    <355, 362, 363>,
    <355, 363, 356>,
    <364, 347, 346>,
    <364, 346, 356>,
    <364, 356, 365>,
    <364, 365, 366>,
    <364, 367, 368>,
    <364, 368, 369>,
    <364, 370, 371>,
    <364, 371, 347>,
    <372, 373, 374>,
    <372, 374, 375>,
    <372, 375, 376>,
    <372, 376, 377>,
    <372, 377, 378>,
    <372, 378, 379>,
    <372, 380, 381>,
    <372, 381, 373>,
    <382, 383, 374>,
    <382, 374, 373>,
    <382, 373, 384>,
    <382, 384, 385>,
    <382, 386, 387>,
    <382, 387, 388>,
    <382, 388, 389>,
    <382, 389, 383>,
    <390, 375, 374>,
    <390, 374, 383>,
    <390, 383, 389>,
    <390, 389, 391>,
    <390, 391, 392>,
    <390, 392, 393>,
    <390, 393, 376>,
    <390, 376, 375>,
    <394, 395, 396>,
    <394, 396, 397>,
    <394, 397, 398>,
    <394, 398, 399>,
    <394, 400, 401>,
    <394, 401, 402>,
    <394, 402, 403>,
    <394, 403, 395>,
    <404, 405, 396>,
    <404, 396, 395>,
    <404, 395, 403>,
    <404, 403, 406>,
    <404, 406, 407>,
    <404, 407, 391>,
    <404, 391, 389>,
    <404, 389, 405>,
    <408, 397, 396>,
    <408, 396, 405>,
    <408, 405, 389>,
    <408, 389, 388>,
    <408, 388, 409>,
    <408, 409, 410>,
    <408, 411, 412>,
    <408, 412, 397>,
    <413, 414, 415>,
    <413, 415, 416>,
    <413, 416, 417>,
    <413, 417, 418>,
    <413, 418, 419>,
    <413, 419, 420>,
    <413, 421, 422>,
    <413, 422, 414>,
    <423, 424, 415>,
    <423, 415, 414>,
    <423, 414, 425>,
    <423, 425, 426>,
    <423, 427, 428>,
    <423, 428, 429>,
    <423, 429, 430>,
    <423, 430, 424>,
    <431, 416, 415>,
    <431, 415, 424>,
    <431, 424, 430>,
    <431, 430, 432>,
    <431, 432, 433>,
    <431, 433, 434>,
    <431, 434, 417>,
    <431, 417, 416>,
    <435, 436, 437>,
    <435, 437, 438>,
    <435, 438, 439>,
    <435, 439, 440>,
    <435, 440, 441>,
    <435, 441, 432>,
    <435, 432, 430>,
    <435, 430, 436>,
    <442, 443, 437>,
    <442, 437, 436>,
    <442, 436, 430>,
    <442, 430, 429>,
    <442, 429, 444>,
    <442, 444, 445>,
    <442, 446, 447>,
    <442, 447, 443>,
    <448, 438, 437>,
    <448, 437, 443>,
    <448, 443, 449>,
    <448, 449, 450>,
    <448, 451, 452>,
    <448, 452, 453>,
    <448, 453, 439>,
    <448, 439, 438>,
    <454, 455, 456>,
    <454, 456, 457>,
    <454, 457, 458>,
    <454, 458, 459>,
    <454, 460, 461>,
    <454, 461, 440>,
    <454, 440, 439>,
    <454, 439, 455>,
    <462, 463, 456>,
    <462, 456, 455>,
    <462, 455, 439>,
    <462, 439, 453>,
    <462, 453, 464>,
    <462, 464, 377>,
    <462, 377, 376>,
    <462, 376, 463>,
    <465, 457, 456>,
    <465, 456, 463>,
    <465, 463, 376>,
    <465, 376, 393>,
    <465, 393, 466>,
    <465, 466, 467>,
    <465, 468, 469>,
    <465, 469, 457>,
    <470, 471, 472>,
    <470, 472, 473>,
    <470, 473, 474>,
    <470, 474, 475>,
    <470, 476, 477>,
    <470, 477, 478>,
    <470, 478, 479>,
    <470, 479, 471>,
    <480, 481, 472>,
    <480, 472, 471>,
    <480, 471, 479>,
    <480, 479, 482>,
    <480, 482, 483>,
    <480, 483, 484>,
    <480, 484, 485>,
    <480, 485, 481>,
    <486, 473, 472>,
    <486, 472, 481>,
    <486, 481, 485>,
    <486, 485, 487>,
    <486, 487, 488>,
    <486, 488, 489>,
    <486, 490, 491>,
    <486, 491, 473>,
    <492, 493, 494>,
    <492, 494, 495>,
    <492, 495, 479>,
    <492, 479, 478>,
    <492, 478, 496>,
    <492, 496, 418>,
    <492, 418, 417>,
    <492, 417, 493>,
    <497, 498, 494>,
    <497, 494, 493>,
    <497, 493, 417>,
    <497, 417, 434>,
    <497, 434, 499>,
    <497, 499, 500>,
    <497, 501, 502>,
    <497, 502, 498>,
    <503, 495, 494>,
    <503, 494, 498>,
    <503, 498, 504>,
    <503, 504, 505>,
    <503, 506, 507>,
    <503, 507, 482>,
    <503, 482, 479>,
    <503, 479, 495>,
    <508, 509, 510>,
    <508, 510, 511>,
    <508, 511, 403>,
    <508, 403, 402>,
    <508, 402, 512>,
    <508, 512, 513>,
    <508, 513, 514>,
    <508, 514, 509>,
    <515, 516, 510>,
    <515, 510, 509>,
    <515, 509, 514>,
    <515, 514, 517>,
    <515, 517, 518>,
    <515, 518, 519>,
    <515, 519, 520>,
    <515, 520, 516>,
    <521, 511, 510>,
    <521, 510, 516>,
    <521, 516, 520>,
    <521, 520, 522>,
    <521, 522, 523>,
    <521, 523, 406>,
    <521, 406, 403>,
    <521, 403, 511>,
    <524, 525, 526>,
    <524, 526, 527>,
    <524, 527, 528>,
    <524, 528, 529>,
    <524, 530, 531>,
    <524, 531, 532>,
    <524, 532, 533>,
    <524, 533, 525>,
    <534, 535, 526>,
    <534, 526, 525>,
    <534, 525, 533>,
    <534, 533, 536>,
    <534, 536, 518>,
    <534, 518, 517>,
    <534, 517, 514>,
    <534, 514, 535>,
    <537, 527, 526>,
    <537, 526, 535>,
    <537, 535, 514>,
    <537, 514, 513>,
    <537, 513, 538>,
    <537, 538, 539>,
    <537, 540, 541>,
    <537, 541, 527>,
    <542, 543, 544>,
    <542, 544, 545>,
    <542, 545, 546>,
    <542, 546, 547>,
    <542, 547, 548>,
    <542, 548, 549>,
    <542, 550, 551>,
    <542, 551, 543>,
    <552, 553, 544>,
    <552, 544, 543>,
    <552, 543, 554>,
    <552, 554, 555>,
    <552, 556, 557>,
    <552, 557, 487>,
    <552, 487, 485>,
    <552, 485, 553>,
    <558, 545, 544>,
    <558, 544, 553>,
    <558, 553, 485>,
    <558, 485, 484>,
    <558, 484, 559>,
    <558, 559, 560>,
    <558, 560, 546>,
    <558, 546, 545>,
    <561, 562, 563>,
    <561, 563, 564>,
    <561, 564, 565>,
    <561, 565, 566>,
    <561, 567, 568>,
    <561, 568, 569>,
    <561, 569, 570>,
    <561, 570, 562>,
    <571, 572, 563>,
    <571, 563, 562>,
    <571, 562, 570>,
    <571, 570, 573>,
    <571, 573, 518>,
    <571, 518, 536>,
    <571, 536, 533>,
    <571, 533, 572>,
    <574, 564, 563>,
    <574, 563, 572>,
    <574, 572, 533>,
    <574, 533, 532>,
    <574, 532, 575>,
    <574, 575, 576>,
    <574, 577, 578>,
    <574, 578, 564>,
    <579, 580, 581>,
    <579, 581, 582>,
    <579, 582, 583>,
    <579, 583, 584>,
    <579, 584, 585>,
    <579, 585, 586>,
    <579, 587, 588>,
    <579, 588, 580>,
    <589, 590, 581>,
    <589, 581, 580>,
    <589, 580, 591>,
    <589, 591, 592>,
    <589, 593, 594>,
    <589, 594, 339>,
    <589, 339, 337>,
    <589, 337, 590>,
    <595, 582, 581>,
    <595, 581, 590>,
    <595, 590, 337>,
    <595, 337, 336>,
    <595, 336, 596>,
    <595, 596, 597>,
    <595, 597, 583>,
    <595, 583, 582>,
    <598, 599, 600>,
    <598, 600, 601>,
    <598, 601, 602>,
    <598, 602, 603>,
    <598, 603, 604>,
    <598, 604, 605>,
    <598, 606, 607>,
    <598, 607, 599>,
    <608, 609, 600>,
    <608, 600, 599>,
    <608, 599, 610>,
    <608, 610, 611>,
    <608, 612, 613>,
    <608, 613, 547>,
    <608, 547, 546>,
    <608, 546, 609>,
    <614, 601, 600>,
    <614, 600, 609>,
    <614, 609, 546>,
    <614, 546, 560>,
    <614, 560, 615>,
    <614, 615, 616>,
    <614, 616, 602>,
    <614, 602, 601>,
    <617, 618, 619>,
    <617, 619, 620>,
    <617, 620, 570>,
    <617, 570, 569>,
    <617, 569, 621>,
    <617, 621, 622>,
    <617, 623, 624>,
    <617, 624, 618>,
    <625, 626, 619>,
    <625, 619, 618>,
    <625, 618, 627>,
    <625, 627, 628>,
    <625, 629, 630>,
    <625, 630, 631>,
    <625, 631, 632>,
    <625, 632, 626>,
    <633, 620, 619>,
    <633, 619, 626>,
    <633, 626, 632>,
    <633, 632, 634>,
    <633, 634, 518>,
    <633, 518, 573>,
    <633, 573, 570>,
    <633, 570, 620>,
    <635, 636, 637>,
    <635, 637, 638>,
    <635, 638, 639>,
    <635, 639, 640>,
    <635, 641, 642>,
    <635, 642, 643>,
    <635, 643, 644>,
    <635, 644, 636>,
    <645, 646, 637>,
    <645, 637, 636>,
    <645, 636, 644>,
    <645, 644, 647>,
    <645, 647, 648>,
    <645, 648, 261>,
    <645, 261, 258>,
    <645, 258, 646>,
    <649, 638, 637>,
    <649, 637, 646>,
    <649, 646, 258>,
    <649, 258, 257>,
    <649, 257, 650>,
    <649, 650, 651>,
    <649, 652, 653>,
    <649, 653, 638>,
    <654, 655, 656>,
    <654, 656, 657>,
    <654, 657, 658>,
    <654, 658, 659>,
    <654, 660, 661>,
    <654, 661, 662>,
    <654, 662, 663>,
    <654, 663, 655>,
    <664, 665, 656>,
    <664, 656, 655>,
    <664, 655, 663>,
    <664, 663, 666>,
    <664, 666, 667>,
    <664, 667, 668>,
    <664, 668, 669>,
    <664, 669, 665>,
    <670, 657, 656>,
    <670, 656, 665>,
    <670, 665, 669>,
    <670, 669, 671>,
    <670, 671, 672>,
    <670, 672, 673>,
    <670, 674, 675>,
    <670, 675, 657>,
    <676, 677, 678>,
    <676, 678, 679>,
    <676, 679, 644>,
    <676, 644, 643>,
    <676, 643, 680>,
    <676, 680, 671>,
    <676, 671, 669>,
    <676, 669, 677>,
    <681, 682, 678>,
    <681, 678, 677>,
    <681, 677, 669>,
    <681, 669, 668>,
    <681, 668, 683>,
    <681, 683, 684>,
    <681, 685, 686>,
    <681, 686, 682>,
    <687, 679, 678>,
    <687, 678, 682>,
    <687, 682, 688>,
    <687, 688, 689>,
    <687, 690, 691>,
    <687, 691, 647>,
    <687, 647, 644>,
    <687, 644, 679>,
    <692, 693, 694>,
    <692, 694, 695>,
    <692, 695, 696>,
    <692, 696, 697>,
    <692, 697, 698>,
    <692, 698, 584>,
    <692, 584, 583>,
    <692, 583, 693>,
    <699, 700, 694>,
    <699, 694, 693>,
    <699, 693, 583>,
    <699, 583, 597>,
    <699, 597, 701>,
    <699, 701, 702>,
    <699, 703, 704>,
    <699, 704, 700>,
    <705, 695, 694>,
    <705, 694, 700>,
    <705, 700, 706>,
    <705, 706, 707>,
    <705, 708, 709>,
    <705, 709, 710>,
    <705, 710, 696>,
    <705, 696, 695>,
    <711, 712, 713>,
    <711, 713, 714>,
    <711, 714, 715>,
    <711, 715, 716>,
    <711, 716, 717>,
    <711, 717, 718>,
    <711, 719, 720>,
    <711, 720, 712>,
    <721, 722, 713>,
    <721, 713, 712>,
    <721, 712, 723>,
    <721, 723, 724>,
    <721, 725, 726>,
    <721, 726, 697>,
    <721, 697, 696>,
    <721, 696, 722>,
    <727, 714, 713>,
    <727, 713, 722>,
    <727, 722, 696>,
    <727, 696, 710>,
    <727, 710, 728>,
    <727, 728, 729>,
    <727, 729, 715>,
    <727, 715, 714>,
    <730, 731, 732>,
    <730, 732, 733>,
    <730, 733, 734>,
    <730, 734, 735>,
    <730, 736, 737>,
    <730, 737, 716>,
    <730, 716, 715>,
    <730, 715, 731>,
    <738, 739, 732>,
    <738, 732, 731>,
    <738, 731, 715>,
    <738, 715, 729>,
    <738, 729, 740>,
    <738, 740, 741>,
    <738, 741, 742>,
    <738, 742, 739>,
    <743, 733, 732>,
    <743, 732, 739>,
    <743, 739, 742>,
    <743, 742, 744>,
    <743, 744, 745>,
    <743, 745, 746>,
    <743, 747, 748>,
    <743, 748, 733>,
    <749, 750, 751>,
    <749, 751, 752>,
    <749, 752, 753>,
    <749, 753, 754>,
    <749, 755, 756>,
    <749, 756, 757>,
    <749, 757, 758>,
    <749, 758, 750>,
    <759, 760, 751>,
    <759, 751, 750>,
    <759, 750, 758>,
    <759, 758, 761>,
    <759, 761, 762>,
    <759, 762, 763>,
    <759, 763, 764>,
    <759, 764, 760>,
    <765, 752, 751>,
    <765, 751, 760>,
    <765, 760, 764>,
    <765, 764, 766>,
    <765, 766, 767>,
    <765, 767, 768>,
    <765, 769, 770>,
    <765, 770, 752>,
    <771, 772, 773>,
    <771, 773, 774>,
    <771, 774, 758>,
    <771, 758, 757>,
    <771, 757, 775>,
    <771, 775, 776>,
    <771, 777, 778>,
    <771, 778, 772>,
    <779, 780, 773>,
    <779, 773, 772>,
    <779, 772, 781>,
    <779, 781, 782>,
    <779, 783, 784>,
    <779, 784, 785>,
    <779, 785, 786>,
    <779, 786, 780>,
    <787, 774, 773>,
    <787, 773, 780>,
    <787, 780, 786>,
    <787, 786, 788>,
    <787, 788, 762>,
    <787, 762, 761>,
    <787, 761, 758>,
    <787, 758, 774>,
    <789, 790, 791>,
    <789, 791, 792>,
    <789, 792, 786>,
    <789, 786, 785>,
    <789, 785, 793>,
    <789, 793, 603>,
    <789, 603, 602>,
    <789, 602, 790>,
    <794, 795, 791>,
    <794, 791, 790>,
    <794, 790, 602>,
    <794, 602, 616>,
    <794, 616, 796>,
    <794, 796, 797>,
    <794, 797, 798>,
    <794, 798, 795>,
    <799, 792, 791>,
    <799, 791, 795>,
    <799, 795, 798>,
    <799, 798, 800>,
    <799, 800, 762>,
    <799, 762, 788>,
    <799, 788, 786>,
    <799, 786, 792>,
    <801, 802, 803>,
    <801, 803, 804>,
    <801, 804, 805>,
    <801, 805, 806>,
    <801, 807, 808>,
    <801, 808, 809>,
    <801, 809, 810>,
    <801, 810, 802>,
    <811, 812, 803>,
    <811, 803, 802>,
    <811, 802, 810>,
    <811, 810, 813>,
    <811, 813, 814>,
    <811, 814, 815>,
    <811, 815, 816>,
    <811, 816, 812>,
    <817, 804, 803>,
    <817, 803, 812>,
    <817, 812, 816>,
    <817, 816, 818>,
    <817, 818, 819>,
    <817, 819, 820>,
    <817, 821, 822>,
    <817, 822, 804>,
    <823, 824, 825>,
    <823, 825, 826>,
    <823, 826, 632>,
    <823, 632, 631>,
    <823, 631, 827>,
    <823, 827, 818>,
    <823, 818, 816>,
    <823, 816, 824>,
    <828, 829, 825>,
    <828, 825, 824>,
    <828, 824, 816>,
    <828, 816, 815>,
    <828, 815, 814>,
    <828, 814, 830>,
    <828, 830, 831>,
    <828, 831, 829>,
    <832, 826, 825>,
    <832, 825, 829>,
    <832, 829, 831>,
    <832, 831, 833>,
    <832, 833, 518>,
    <832, 518, 634>,
    <832, 634, 632>,
    <832, 632, 826>,
    <834, 835, 836>,
    <834, 836, 837>,
    <834, 837, 838>,
    <834, 838, 839>,
    <834, 840, 841>,
    <834, 841, 842>,
    <834, 842, 843>,
    <834, 843, 835>,
    <844, 845, 836>,
    <844, 836, 835>,
    <844, 835, 843>,
    <844, 843, 846>,
    <844, 846, 814>,
    <844, 814, 813>,
    <844, 813, 810>,
    <844, 810, 845>,
    <847, 837, 836>,
    <847, 836, 845>,
    <847, 845, 810>,
    <847, 810, 809>,
    <847, 809, 848>,
    <847, 848, 849>,
    <847, 850, 851>,
    <847, 851, 837>,
    <852, 853, 854>,
    <852, 854, 855>,
    <852, 855, 856>,
    <852, 856, 857>,
    <852, 858, 859>,
    <852, 859, 860>,
    <852, 861, 862>,
    <852, 862, 853>,
    <863, 864, 854>,
    <863, 854, 853>,
    <863, 853, 865>,
    <863, 865, 866>,
    <863, 867, 868>,
    <863, 868, 869>,
    <863, 870, 871>,
    <863, 871, 864>,
    <872, 855, 854>,
    <872, 854, 864>,
    <872, 864, 873>,
    <872, 873, 874>,
    <872, 875, 876>,
    <872, 876, 877>,
    <872, 878, 879>,
    <872, 879, 855>,
    <880, 881, 882>,
    <880, 882, 883>,
    <880, 883, 884>,
    <880, 884, 885>,
    <880, 886, 887>,
    <880, 887, 888>,
    <880, 888, 889>,
    <880, 889, 881>,
    <890, 891, 882>,
    <890, 882, 881>,
    <890, 881, 889>,
    <890, 889, 892>,
    <890, 892, 814>,
    <890, 814, 846>,
    <890, 846, 843>,
    <890, 843, 891>,
    <893, 883, 882>,
    <893, 882, 891>,
    <893, 891, 843>,
    <893, 843, 842>,
    <893, 842, 894>,
    <893, 894, 895>,
    <893, 896, 897>,
    <893, 897, 883>,
    <898, 899, 900>,
    <898, 900, 901>,
    <898, 901, 902>,
    <898, 902, 903>,
    <898, 903, 904>,
    <898, 904, 905>,
    <898, 906, 907>,
    <898, 907, 899>,
    <908, 909, 900>,
    <908, 900, 899>,
    <908, 899, 910>,
    <908, 910, 911>,
    <908, 912, 913>,
    <908, 913, 766>,
    <908, 766, 764>,
    <908, 764, 909>,
    <914, 901, 900>,
    <914, 900, 909>,
    <914, 909, 764>,
    <914, 764, 763>,
    <914, 763, 762>,
    <914, 762, 915>,
    <914, 915, 902>,
    <914, 902, 901>,
    <916, 917, 918>,
    <916, 918, 919>,
    <916, 919, 889>,
    <916, 889, 888>,
    <916, 888, 920>,
    <916, 920, 921>,
    <916, 922, 923>,
    <916, 923, 917>,
    <924, 925, 918>,
    <924, 918, 917>,
    <924, 917, 926>,
    <924, 926, 927>,
    <924, 928, 929>,
    <924, 929, 930>,
    <924, 930, 931>,
    <924, 931, 925>,
    <932, 919, 918>,
    <932, 918, 925>,
    <932, 925, 931>,
    <932, 931, 933>,
    <932, 933, 814>,
    <932, 814, 892>,
    <932, 892, 889>,
    <932, 889, 919>,
    <934, 935, 936>,
    <934, 936, 937>,
    <934, 937, 938>,
    <934, 938, 939>,
    <934, 939, 940>,
    <934, 940, 941>,
    <934, 942, 943>,
    <934, 943, 935>,
    <944, 945, 936>,
    <944, 936, 935>,
    <944, 935, 946>,
    <944, 946, 947>,
    <944, 948, 949>,
    <944, 949, 744>,
    <944, 744, 742>,
    <944, 742, 945>,
    <950, 937, 936>,
    <950, 936, 945>,
    <950, 945, 742>,
    <950, 742, 741>,
    <950, 741, 951>,
    <950, 951, 952>,
    <950, 952, 938>,
    <950, 938, 937>,
    <953, 954, 955>,
    <953, 955, 956>,
    <953, 956, 957>,
    <953, 957, 958>,
    <953, 959, 960>,
    <953, 960, 961>,
    <953, 961, 962>,
    <953, 962, 954>,
    <963, 964, 955>,
    <963, 955, 954>,
    <963, 954, 962>,
    <963, 962, 965>,
    <963, 965, 966>,
    <963, 966, 967>,
    <963, 967, 968>,
    <963, 968, 964>,
    <969, 956, 955>,
    <969, 955, 964>,
    <969, 964, 968>,
    <969, 968, 970>,
    <969, 970, 971>,
    <969, 971, 972>,
    <969, 973, 974>,
    <969, 974, 956>,
    <975, 976, 977>,
    <975, 977, 978>,
    <975, 978, 962>,
    <975, 962, 961>,
    <975, 961, 979>,
    <975, 979, 980>,
    <975, 981, 982>,
    <975, 982, 976>,
    <983, 984, 977>,
    <983, 977, 976>,
    <983, 976, 985>,
    <983, 985, 986>,
    <983, 987, 988>,
    <983, 988, 989>,
    <983, 989, 990>,
    <983, 990, 984>,
    <991, 978, 977>,
    <991, 977, 984>,
    <991, 984, 990>,
    <991, 990, 992>,
    <991, 992, 966>,
    <991, 966, 965>,
    <991, 965, 962>,
    <991, 962, 978>,
    <993, 994, 995>,
    <993, 995, 996>,
    <993, 996, 990>,
    <993, 990, 989>,
    <993, 989, 997>,
    <993, 997, 903>,
    <993, 903, 902>,
    <993, 902, 994>,
    <998, 999, 995>,
    <998, 995, 994>,
    <998, 994, 902>,
    <998, 902, 915>,
    <998, 915, 762>,
    <998, 762, 1000>,
    <998, 1000, 1001>,
    <998, 1001, 999>,
    <1002, 996, 995>,
    <1002, 995, 999>,
    <1002, 999, 1001>,
    <1002, 1001, 1003>,
    <1002, 1003, 966>,
    <1002, 966, 992>,
    <1002, 992, 990>,
    <1002, 990, 996>,
    <1004, 1005, 1006>,
    <1004, 1006, 1007>,
    <1004, 1007, 1008>,
    <1004, 1008, 1009>,
    <1004, 1010, 1011>,
    <1004, 1011, 1012>,
    <1004, 1012, 1013>,
    <1004, 1013, 1005>,
    <1014, 1015, 1006>,
    <1014, 1006, 1005>,
    <1014, 1005, 1013>,
    <1014, 1013, 1016>,
    <1014, 1016, 1017>,
    <1014, 1017, 1018>,
    <1014, 1018, 1019>,
    <1014, 1019, 1015>,
    <1020, 1007, 1006>,
    <1020, 1006, 1015>,
    <1020, 1015, 1019>,
    <1020, 1019, 1021>,
    <1020, 1021, 1022>,
    <1020, 1022, 1023>,
    <1020, 1024, 1025>,
    <1020, 1025, 1007>,
    <1026, 1027, 1028>,
    <1026, 1028, 1029>,
    <1026, 1029, 931>,
    <1026, 931, 930>,
    <1026, 930, 1030>,
    <1026, 1030, 1021>,
    <1026, 1021, 1019>,
    <1026, 1019, 1027>,
    <1031, 1032, 1028>,
    <1031, 1028, 1027>,
    <1031, 1027, 1019>,
    <1031, 1019, 1018>,
    <1031, 1018, 1017>,
    <1031, 1017, 1033>,
    <1031, 1033, 1034>,
    <1031, 1034, 1032>,
    <1035, 1029, 1028>,
    <1035, 1028, 1032>,
    <1035, 1032, 1034>,
    <1035, 1034, 1036>,
    <1035, 1036, 814>,
    <1035, 814, 933>,
    <1035, 933, 931>,
    <1035, 931, 1029>,
    <1037, 1038, 1039>,
    <1037, 1039, 1040>,
    <1037, 1040, 1041>,
    <1037, 1041, 1042>,
    <1037, 1043, 1044>,
    <1037, 1044, 1045>,
    <1037, 1045, 1046>,
    <1037, 1046, 1038>,
    <1047, 1048, 1039>,
    <1047, 1039, 1038>,
    <1047, 1038, 1046>,
    <1047, 1046, 1049>,
    <1047, 1049, 1017>,
    <1047, 1017, 1016>,
    <1047, 1016, 1013>,
    <1047, 1013, 1048>,
    <1050, 1040, 1039>,
    <1050, 1039, 1048>,
    <1050, 1048, 1013>,
    <1050, 1013, 1012>,
    <1050, 1012, 1051>,
    <1050, 1051, 1052>,
    <1050, 1053, 1054>,
    <1050, 1054, 1040>,
    <1055, 1056, 1057>,
    <1055, 1057, 1058>,
    <1055, 1058, 1059>,
    <1055, 1059, 1060>,
    <1055, 1060, 1061>,
    <1055, 1061, 1062>,
    <1055, 1063, 1064>,
    <1055, 1064, 1056>,
    <1065, 1066, 1057>,
    <1065, 1057, 1056>,
    <1065, 1056, 1067>,
    <1065, 1067, 1068>,
    <1065, 1069, 1070>,
    <1065, 1070, 970>,
    <1065, 970, 968>,
    <1065, 968, 1066>,
    <1071, 1058, 1057>,
    <1071, 1057, 1066>,
    <1071, 1066, 968>,
    <1071, 968, 967>,
    <1071, 967, 966>,
    <1071, 966, 1072>,
    <1071, 1072, 1059>,
    <1071, 1059, 1058>,
    <1073, 1074, 1075>,
    <1073, 1075, 1076>,
    <1073, 1076, 1077>,
    <1073, 1077, 1078>,
    <1073, 1079, 1080>,
    <1073, 1080, 1081>,
    <1073, 1081, 1082>,
    <1073, 1082, 1074>,
    <1083, 1084, 1075>,
    <1083, 1075, 1074>,
    <1083, 1074, 1082>,
    <1083, 1082, 1085>,
    <1083, 1085, 1017>,
    <1083, 1017, 1049>,
    <1083, 1049, 1046>,
    <1083, 1046, 1084>,
    <1086, 1076, 1075>,
    <1086, 1075, 1084>,
    <1086, 1084, 1046>,
    <1086, 1046, 1045>,
    <1086, 1045, 1087>,
    <1086, 1087, 1088>,
    <1086, 1089, 1090>,
    <1086, 1090, 1076>,
    <1091, 1092, 1093>,
    <1091, 1093, 1094>,
    <1091, 1094, 1095>,
    <1091, 1095, 1096>,
    <1091, 1097, 1098>,
    <1091, 1098, 1099>,
    <1091, 1099, 1100>,
    <1091, 1100, 1092>,
    <1101, 1102, 1093>,
    <1101, 1093, 1092>,
    <1101, 1092, 1100>,
    <1101, 1100, 1103>,
    <1101, 1103, 1104>,
    <1101, 1104, 666>,
    <1101, 666, 663>,
    <1101, 663, 1102>,
    <1105, 1094, 1093>,
    <1105, 1093, 1102>,
    <1105, 1102, 663>,
    <1105, 663, 662>,
    <1105, 662, 1106>,
    <1105, 1106, 1107>,
    <1105, 1108, 1109>,
    <1105, 1109, 1094>,
    <1110, 1111, 1112>,
    <1110, 1112, 1113>,
    <1110, 1113, 1114>,
    <1110, 1114, 1115>,
    <1110, 1116, 1117>,
    <1110, 1117, 1118>,
    <1110, 1118, 1119>,
    <1110, 1119, 1111>,
    <1120, 1121, 1112>,
    <1120, 1112, 1111>,
    <1120, 1111, 1119>,
    <1120, 1119, 1122>,
    <1120, 1122, 1123>,
    <1120, 1123, 1124>,
    <1120, 1124, 1125>,
    <1120, 1125, 1121>,
    <1126, 1113, 1112>,
    <1126, 1112, 1121>,
    <1126, 1121, 1125>,
    <1126, 1125, 1127>,
    <1126, 1127, 1128>,
    <1126, 1128, 1129>,
    <1126, 1130, 1131>,
    <1126, 1131, 1113>,
    <1132, 1133, 1134>,
    <1132, 1134, 1135>,
    <1132, 1135, 1100>,
    <1132, 1100, 1099>,
    <1132, 1099, 1136>,
    <1132, 1136, 1127>,
    <1132, 1127, 1125>,
    <1132, 1125, 1133>,
    <1137, 1138, 1134>,
    <1137, 1134, 1133>,
    <1137, 1133, 1125>,
    <1137, 1125, 1124>,
    <1137, 1124, 1139>,
    <1137, 1139, 1140>,
    <1137, 1141, 1142>,
    <1137, 1142, 1138>,
    <1143, 1135, 1134>,
    <1143, 1134, 1138>,
    <1143, 1138, 1144>,
    <1143, 1144, 1145>,
    <1143, 1146, 1147>,
    <1143, 1147, 1103>,
    <1143, 1103, 1100>,
    <1143, 1100, 1135>,
    <1148, 1149, 1150>,
    <1148, 1150, 1151>,
    <1148, 1151, 1152>,
    <1148, 1152, 1153>,
    <1148, 1153, 1154>,
    <1148, 1154, 939>,
    <1148, 939, 938>,
    <1148, 938, 1149>,
    <1155, 1156, 1150>,
    <1155, 1150, 1149>,
    <1155, 1149, 938>,
    <1155, 938, 952>,
    <1155, 952, 1157>,
    <1155, 1157, 1158>,
    <1155, 1159, 1160>,
    <1155, 1160, 1156>,
    <1161, 1151, 1150>,
    <1161, 1150, 1156>,
    <1161, 1156, 1162>,
    <1161, 1162, 1163>,
    <1161, 1164, 1165>,
    <1161, 1165, 1166>,
    <1161, 1166, 1152>,
    <1161, 1152, 1151>,
    <1167, 1168, 1169>,
    <1167, 1169, 1170>,
    <1167, 1170, 1171>,
    <1167, 1171, 1172>,
    <1167, 1173, 1174>,
    <1167, 1174, 1153>,
    <1167, 1153, 1152>,
    <1167, 1152, 1168>,
    <1175, 1176, 1169>,
    <1175, 1169, 1168>,
    <1175, 1168, 1152>,
    <1175, 1152, 1166>,
    <1175, 1166, 1177>,
    <1175, 1177, 1178>,
    <1175, 1178, 1179>,
    <1175, 1179, 1176>,
    <1180, 1170, 1169>,
    <1180, 1169, 1176>,
    <1180, 1176, 1179>,
    <1180, 1179, 1181>,
    <1180, 1181, 1182>,
    <1180, 1182, 1183>,
    <1180, 1184, 1185>,
    <1180, 1185, 1170>,
    <1186, 1187, 1188>,
    <1186, 1188, 1189>,
    <1186, 1189, 1190>,
    <1186, 1190, 1191>,
    <1186, 1192, 1193>,
    <1186, 1193, 1181>,
    <1186, 1181, 1179>,
    <1186, 1179, 1187>,
    <1194, 1195, 1188>,
    <1194, 1188, 1187>,
    <1194, 1187, 1179>,
    <1194, 1179, 1178>,
    <1194, 1178, 1196>,
    <1194, 1196, 1197>,
    <1194, 1197, 1198>,
    <1194, 1198, 1195>,
    <1199, 1189, 1188>,
    <1199, 1188, 1195>,
    <1199, 1195, 1198>,
    <1199, 1198, 1200>,
    <1199, 1200, 1201>,
    <1199, 1201, 1202>,
    <1199, 1203, 1204>,
    <1199, 1204, 1189>,
    <1205, 1206, 1207>,
    <1205, 1207, 1208>,
    <1205, 1208, 1209>,
    <1205, 1209, 1210>,
    <1205, 1210, 1211>,
    <1205, 1211, 1212>,
    <1205, 1213, 1214>,
    <1205, 1214, 1206>,
    <1215, 1216, 1207>,
    <1215, 1207, 1206>,
    <1215, 1206, 1217>,
    <1215, 1217, 1218>,
    <1215, 1219, 1220>,
    <1215, 1220, 1060>,
    <1215, 1060, 1059>,
    <1215, 1059, 1216>,
    <1221, 1208, 1207>,
    <1221, 1207, 1216>,
    <1221, 1216, 1059>,
    <1221, 1059, 1072>,
    <1221, 1072, 966>,
    <1221, 966, 1222>,
    <1221, 1222, 1209>,
    <1221, 1209, 1208>,
    <1223, 1224, 1225>,
    <1223, 1225, 1226>,
    <1223, 1226, 1082>,
    <1223, 1082, 1081>,
    <1223, 1081, 1227>,
    <1223, 1227, 1228>,
    <1223, 1229, 1230>,
    <1223, 1230, 1224>,
    <1231, 1232, 1225>,
    <1231, 1225, 1224>,
    <1231, 1224, 1233>,
    <1231, 1233, 1234>,
    <1231, 1235, 1236>,
    <1231, 1236, 1237>,
    <1231, 1237, 1238>,
    <1231, 1238, 1232>,
    <1239, 1226, 1225>,
    <1239, 1225, 1232>,
    <1239, 1232, 1238>,
    <1239, 1238, 1240>,
    <1239, 1240, 1017>,
    <1239, 1017, 1085>,
    <1239, 1085, 1082>,
    <1239, 1082, 1226>,
    <1241, 1242, 1243>,
    <1241, 1243, 1244>,
    <1241, 1244, 1245>,
    <1241, 1245, 1246>,
    <1241, 1247, 1248>,
    <1241, 1248, 1249>,
    <1241, 1249, 1250>,
    <1241, 1250, 1242>,
    <1251, 1252, 1243>,
    <1251, 1243, 1242>,
    <1251, 1242, 1250>,
    <1251, 1250, 1253>,
    <1251, 1253, 1254>,
    <1251, 1254, 1255>,
    <1251, 1255, 1256>,
    <1251, 1256, 1252>,
    <1257, 1244, 1243>,
    <1257, 1243, 1252>,
    <1257, 1252, 1256>,
    <1257, 1256, 1258>,
    <1257, 1258, 1259>,
    <1257, 1259, 1260>,
    <1257, 1261, 1262>,
    <1257, 1262, 1244>,
    <1263, 1264, 1265>,
    <1263, 1265, 1266>,
    <1263, 1266, 1250>,
    <1263, 1250, 1249>,
    <1263, 1249, 1267>,
    <1263, 1267, 1268>,
    <1263, 1269, 1270>,
    <1263, 1270, 1264>,
    <1271, 1272, 1265>,
    <1271, 1265, 1264>,
    <1271, 1264, 1273>,
    <1271, 1273, 1274>,
    <1271, 1275, 1276>,
    <1271, 1276, 1277>,
    <1271, 1277, 1278>,
    <1271, 1278, 1272>,
    <1279, 1266, 1265>,
    <1279, 1265, 1272>,
    <1279, 1272, 1278>,
    <1279, 1278, 1280>,
    <1279, 1280, 1254>,
    <1279, 1254, 1253>,
    <1279, 1253, 1250>,
    <1279, 1250, 1266>,
    <1281, 1282, 1283>,
    <1281, 1283, 1284>,
    <1281, 1284, 1278>,
    <1281, 1278, 1277>,
    <1281, 1277, 1285>,
    <1281, 1285, 1210>,
    <1281, 1210, 1209>,
    <1281, 1209, 1282>,
    <1286, 1287, 1283>,
    <1286, 1283, 1282>,
    <1286, 1282, 1209>,
    <1286, 1209, 1222>,
    <1286, 1222, 966>,
    <1286, 966, 1288>,
    <1286, 1288, 1289>,
    <1286, 1289, 1287>,
    <1290, 1284, 1283>,
    <1290, 1283, 1287>,
    <1290, 1287, 1289>,
    <1290, 1289, 1291>,
    <1290, 1291, 1254>,
    <1290, 1254, 1280>,
    <1290, 1280, 1278>,
    <1290, 1278, 1284>,
    <1292, 1293, 1294>,
    <1292, 1294, 1295>,
    <1292, 1295, 1296>,
    <1292, 1296, 1297>,
    <1292, 1298, 1299>,
    <1292, 1299, 1300>,
    <1292, 1300, 1301>,
    <1292, 1301, 1293>,
    <1302, 1303, 1294>,
    <1302, 1294, 1293>,
    <1302, 1293, 1301>,
    <1302, 1301, 1304>,
    <1302, 1304, 1305>,
    <1302, 1305, 1306>,
    <1302, 1306, 1307>,
    <1302, 1307, 1303>,
    <1308, 1295, 1294>,
    <1308, 1294, 1303>,
    <1308, 1303, 1307>,
    <1308, 1307, 1309>,
    <1308, 1309, 1310>,
    <1308, 1310, 1311>,
    <1308, 1312, 1313>,
    <1308, 1313, 1295>,
    <1314, 1315, 1316>,
    <1314, 1316, 1317>,
    <1314, 1317, 1238>,
    <1314, 1238, 1237>,
    <1314, 1237, 1318>,
    <1314, 1318, 1309>,
    <1314, 1309, 1307>,
    <1314, 1307, 1315>,
    <1319, 1320, 1316>,
    <1319, 1316, 1315>,
    <1319, 1315, 1307>,
    <1319, 1307, 1306>,
    <1319, 1306, 1305>,
    <1319, 1305, 1321>,
    <1319, 1321, 1322>,
    <1319, 1322, 1320>,
    <1323, 1317, 1316>,
    <1323, 1316, 1320>,
    <1323, 1320, 1322>,
    <1323, 1322, 1324>,
    <1323, 1324, 1017>,
    <1323, 1017, 1240>,
    <1323, 1240, 1238>,
    <1323, 1238, 1317>,
    <1325, 1326, 1327>,
    <1325, 1327, 1328>,
    <1325, 1328, 1329>,
    <1325, 1329, 1330>,
    <1325, 1331, 1332>,
    <1325, 1332, 1333>,
    <1325, 1333, 1334>,
    <1325, 1334, 1326>,
    <1335, 1336, 1327>,
    <1335, 1327, 1326>,
    <1335, 1326, 1334>,
    <1335, 1334, 1337>,
    <1335, 1337, 1305>,
    <1335, 1305, 1304>,
    <1335, 1304, 1301>,
    <1335, 1301, 1336>,
    <1338, 1328, 1327>,
    <1338, 1327, 1336>,
    <1338, 1336, 1301>,
    <1338, 1301, 1300>,
    <1338, 1300, 1339>,
    <1338, 1339, 1340>,
    <1338, 1341, 1342>,
    <1338, 1342, 1328>,
    <1343, 1344, 1345>,
    <1343, 1345, 1346>,
    <1343, 1346, 1347>,
    <1343, 1347, 1348>,
    <1343, 1348, 1349>,
    <1343, 1349, 1350>,
    <1343, 1351, 1352>,
    <1343, 1352, 1344>,
    <1353, 1354, 1345>,
    <1353, 1345, 1344>,
    <1353, 1344, 1355>,
    <1353, 1355, 1356>,
    <1353, 1357, 1358>,
    <1353, 1358, 1200>,
    <1353, 1200, 1198>,
    <1353, 1198, 1354>,
    <1359, 1346, 1345>,
    <1359, 1345, 1354>,
    <1359, 1354, 1198>,
    <1359, 1198, 1197>,
    <1359, 1197, 1360>,
    <1359, 1360, 1361>,
    <1359, 1361, 1347>,
    <1359, 1347, 1346>,
    <1362, 1363, 1364>,
    <1362, 1364, 1365>,
    <1362, 1365, 1366>,
    <1362, 1366, 1367>,
    <1362, 1368, 1369>,
    <1362, 1369, 1370>,
    <1362, 1370, 1371>,
    <1362, 1371, 1363>,
    <1372, 1373, 1364>,
    <1372, 1364, 1363>,
    <1372, 1363, 1371>,
    <1372, 1371, 1374>,
    <1372, 1374, 1375>,
    <1372, 1375, 1122>,
    <1372, 1122, 1119>,
    <1372, 1119, 1373>,
    <1376, 1365, 1364>,
    <1376, 1364, 1373>,
    <1376, 1373, 1119>,
    <1376, 1119, 1118>,
    <1376, 1118, 1377>,
    <1376, 1377, 1378>,
    <1376, 1379, 1380>,
    <1376, 1380, 1365>,
    <1381, 1382, 1383>,
    <1381, 1383, 1384>,
    <1381, 1384, 1385>,
    <1381, 1385, 1386>,
    <1381, 1387, 1388>,
    <1381, 1388, 1389>,
    <1381, 1389, 1390>,
    <1381, 1390, 1382>,
    <1391, 1392, 1383>,
    <1391, 1383, 1382>,
    <1391, 1382, 1390>,
    <1391, 1390, 1393>,
    <1391, 1393, 1394>,
    <1391, 1394, 1395>,
    <1391, 1395, 1396>,
    <1391, 1396, 1392>,
    <1397, 1384, 1383>,
    <1397, 1383, 1392>,
    <1397, 1392, 1396>,
    <1397, 1396, 1398>,
    <1397, 1398, 1399>,
    <1397, 1399, 1400>,
    <1397, 1401, 1402>,
    <1397, 1402, 1384>,
    <1403, 1404, 1405>,
    <1403, 1405, 1406>,
    <1403, 1406, 1371>,
    <1403, 1371, 1370>,
    <1403, 1370, 1407>,
    <1403, 1407, 1398>,
    <1403, 1398, 1396>,
    <1403, 1396, 1404>,
    <1408, 1409, 1405>,
    <1408, 1405, 1404>,
    <1408, 1404, 1396>,
    <1408, 1396, 1395>,
    <1408, 1395, 1410>,
    <1408, 1410, 1411>,
    <1408, 1412, 1413>,
    <1408, 1413, 1409>,
    <1414, 1406, 1405>,
    <1414, 1405, 1409>,
    <1414, 1409, 1415>,
    <1414, 1415, 1416>,
    <1414, 1417, 1418>,
    <1414, 1418, 1374>,
    <1414, 1374, 1371>,
    <1414, 1371, 1406>,
    <1419, 1420, 1421>,
    <1419, 1421, 1422>,
    <1419, 1422, 1423>,
    <1419, 1423, 1424>,
    <1419, 1424, 1425>,
    <1419, 1425, 1348>,
    <1419, 1348, 1347>,
    <1419, 1347, 1420>,
    <1426, 1427, 1421>,
    <1426, 1421, 1420>,
    <1426, 1420, 1347>,
    <1426, 1347, 1361>,
    <1426, 1361, 1428>,
    <1426, 1428, 1429>,
    <1426, 1430, 1431>,
    <1426, 1431, 1427>,
    <1432, 1422, 1421>,
    <1432, 1421, 1427>,
    <1432, 1427, 1433>,
    <1432, 1433, 1434>,
    <1432, 1435, 1436>,
    <1432, 1436, 1437>,
    <1432, 1437, 1423>,
    <1432, 1423, 1422>,
    <1438, 1439, 1440>,
    <1438, 1440, 1441>,
    <1438, 1441, 1442>,
    <1438, 1442, 1443>,
    <1438, 1443, 1444>,
    <1438, 1444, 1445>,
    <1438, 1446, 1447>,
    <1438, 1447, 1439>,
    <1448, 1449, 1440>,
    <1448, 1440, 1439>,
    <1448, 1439, 1450>,
    <1448, 1450, 1451>,
    <1448, 1452, 1453>,
    <1448, 1453, 1424>,
    <1448, 1424, 1423>,
    <1448, 1423, 1449>,
    <1454, 1441, 1440>,
    <1454, 1440, 1449>,
    <1454, 1449, 1423>,
    <1454, 1423, 1437>,
    <1454, 1437, 1455>,
    <1454, 1455, 1456>,
    <1454, 1456, 1442>,
    <1454, 1442, 1441>,
    <1457, 1458, 1459>,
    <1457, 1459, 1460>,
    <1457, 1460, 1461>,
    <1457, 1461, 1462>,
    <1457, 1463, 1464>,
    <1457, 1464, 1443>,
    <1457, 1443, 1442>,
    <1457, 1442, 1458>,
    <1465, 1466, 1459>,
    <1465, 1459, 1458>,
    <1465, 1458, 1442>,
    <1465, 1442, 1456>,
    <1465, 1456, 1467>,
    <1465, 1467, 1468>,
    <1465, 1468, 1469>,
    <1465, 1469, 1466>,
    <1470, 1460, 1459>,
    <1470, 1459, 1466>,
    <1470, 1466, 1469>,
    <1470, 1469, 1471>,
    <1470, 1471, 1472>,
    <1470, 1472, 1473>,
    <1470, 1474, 1475>,
    <1470, 1475, 1460>,
    <1476, 1477, 1478>,
    <1476, 1478, 1479>,
    <1476, 1479, 1480>,
    <1476, 1480, 1481>,
    <1476, 1481, 1482>,
    <1476, 1482, 1483>,
    <1476, 1484, 1485>,
    <1476, 1485, 1477>,
    <1486, 1487, 1478>,
    <1486, 1478, 1477>,
    <1486, 1477, 1488>,
    <1486, 1488, 1489>,
    <1486, 1490, 1491>,
    <1486, 1491, 1258>,
    <1486, 1258, 1256>,
    <1486, 1256, 1487>,
    <1492, 1479, 1478>,
    <1492, 1478, 1487>,
    <1492, 1487, 1256>,
    <1492, 1256, 1255>,
    <1492, 1255, 1254>,
    <1492, 1254, 1493>,
    <1492, 1493, 1480>,
    <1492, 1480, 1479>,
    <1494, 1495, 1496>,
    <1494, 1496, 1497>,
    <1494, 1497, 1498>,
    <1494, 1498, 1499>,
    <1494, 1500, 1501>,
    <1494, 1501, 1502>,
    <1494, 1502, 1503>,
    <1494, 1503, 1495>,
    <1504, 1505, 1496>,
    <1504, 1496, 1495>,
    <1504, 1495, 1503>,
    <1504, 1503, 1506>,
    <1504, 1506, 1305>,
    <1504, 1305, 1337>,
    <1504, 1337, 1334>,
    <1504, 1334, 1505>,
    <1507, 1497, 1496>,
    <1507, 1496, 1505>,
    <1507, 1505, 1334>,
    <1507, 1334, 1333>,
    <1507, 1333, 1508>,
    <1507, 1508, 1509>,
    <1507, 1510, 1511>,
    <1507, 1511, 1497>,
    <1512, 1513, 1514>,
    <1512, 1514, 1515>,
    <1512, 1515, 1516>,
    <1512, 1516, 1517>,
    <1512, 1518, 1519>,
    <1512, 1519, 1520>,
    <1512, 1520, 1521>,
    <1512, 1521, 1513>,
    <1522, 1523, 1514>,
    <1522, 1514, 1513>,
    <1522, 1513, 1521>,
    <1522, 1521, 1524>,
    <1522, 1524, 1525>,
    <1522, 1525, 1526>,
    <1522, 1526, 1527>,
    <1522, 1527, 1523>,
    <1528, 1515, 1514>,
    <1528, 1514, 1523>,
    <1528, 1523, 1527>,
    <1528, 1527, 1529>,
    <1528, 1529, 1530>,
    <1528, 1530, 1531>,
    <1528, 1532, 1533>,
    <1528, 1533, 1515>,
    <1534, 1535, 1536>,
    <1534, 1536, 1537>,
    <1534, 1537, 1521>,
    <1534, 1521, 1520>,
    <1534, 1520, 1538>,
    <1534, 1538, 1539>,
    <1534, 1540, 1541>,
    <1534, 1541, 1535>,
    <1542, 1543, 1536>,
    <1542, 1536, 1535>,
    <1542, 1535, 1544>,
    <1542, 1544, 1545>,
    <1542, 1546, 1547>,
    <1542, 1547, 1548>,
    <1542, 1548, 1549>,
    <1542, 1549, 1543>,
    <1550, 1537, 1536>,
    <1550, 1536, 1543>,
    <1550, 1543, 1549>,
    <1550, 1549, 1551>,
    <1550, 1551, 1525>,
    <1550, 1525, 1524>,
    <1550, 1524, 1521>,
    <1550, 1521, 1537>,
    <1552, 1553, 1554>,
    <1552, 1554, 1555>,
    <1552, 1555, 1549>,
    <1552, 1549, 1548>,
    <1552, 1548, 1556>,
    <1552, 1556, 1481>,
    <1552, 1481, 1480>,
    <1552, 1480, 1553>,
    <1557, 1558, 1554>,
    <1557, 1554, 1553>,
    <1557, 1553, 1480>,
    <1557, 1480, 1493>,
    <1557, 1493, 1254>,
    <1557, 1254, 1559>,
    <1557, 1559, 1560>,
    <1557, 1560, 1558>,
    <1561, 1555, 1554>,
    <1561, 1554, 1558>,
    <1561, 1558, 1560>,
    <1561, 1560, 1562>,
    <1561, 1562, 1525>,
    <1561, 1525, 1551>,
    <1561, 1551, 1549>,
    <1561, 1549, 1555>,
    <1563, 1564, 1565>,
    <1563, 1565, 1566>,
    <1563, 1566, 1567>,
    <1563, 1567, 1568>,
    <1563, 1569, 1570>,
    <1563, 1570, 1571>,
    <1563, 1571, 1572>,
    <1563, 1572, 1564>,
    <1573, 1574, 1565>,
    <1573, 1565, 1564>,
    <1573, 1564, 1572>,
    <1573, 1572, 1575>,
    <1573, 1575, 1576>,
    <1573, 1576, 1577>,
    <1573, 1577, 1578>,
    <1573, 1578, 1574>,
    <1579, 1566, 1565>,
    <1579, 1565, 1574>,
    <1579, 1574, 1578>,
    <1579, 1578, 1580>,
    <1579, 1580, 1581>,
    <1579, 1581, 1582>,
    <1579, 1583, 1584>,
    <1579, 1584, 1566>,
    <1585, 1586, 1587>,
    <1585, 1587, 1588>,
    <1585, 1588, 1503>,
    <1585, 1503, 1502>,
    <1585, 1502, 1589>,
    <1585, 1589, 1580>,
    <1585, 1580, 1578>,
    <1585, 1578, 1586>,
    <1590, 1591, 1587>,
    <1590, 1587, 1586>,
    <1590, 1586, 1578>,
    <1590, 1578, 1577>,
    <1590, 1577, 1576>,
    <1590, 1576, 1592>,
    <1590, 1592, 1593>,
    <1590, 1593, 1591>,
    <1594, 1588, 1587>,
    <1594, 1587, 1591>,
    <1594, 1591, 1593>,
    <1594, 1593, 1595>,
    <1594, 1595, 1305>,
    <1594, 1305, 1506>,
    <1594, 1506, 1503>,
    <1594, 1503, 1588>,
    <1596, 1597, 1598>,
    <1596, 1598, 1599>,
    <1596, 1599, 1600>,
    <1596, 1600, 1601>,
    <1596, 1602, 1603>,
    <1596, 1603, 1604>,
    <1596, 1604, 1605>,
    <1596, 1605, 1597>,
    <1606, 1607, 1598>,
    <1606, 1598, 1597>,
    <1606, 1597, 1605>,
    <1606, 1605, 1608>,
    <1606, 1608, 1576>,
    <1606, 1576, 1575>,
    <1606, 1575, 1572>,
    <1606, 1572, 1607>,
    <1609, 1599, 1598>,
    <1609, 1598, 1607>,
    <1609, 1607, 1572>,
    <1609, 1572, 1571>,
    <1609, 1571, 1610>,
    <1609, 1610, 1611>,
    <1609, 1612, 1613>,
    <1609, 1613, 1599>,
    <1614, 1615, 1616>,
    <1614, 1616, 1617>,
    <1614, 1617, 1618>,
    <1614, 1618, 1619>,
    <1614, 1620, 1621>,
    <1614, 1621, 1622>,
    <1614, 1622, 1623>,
    <1614, 1623, 1615>,
    <1624, 1625, 1616>,
    <1624, 1616, 1615>,
    <1624, 1615, 1623>,
    <1624, 1623, 1626>,
    <1624, 1626, 1576>,
    <1624, 1576, 1608>,
    <1624, 1608, 1605>,
    <1624, 1605, 1625>,
    <1627, 1617, 1616>,
    <1627, 1616, 1625>,
    <1627, 1625, 1605>,
    <1627, 1605, 1604>,
    <1627, 1604, 1628>,
    <1627, 1628, 1629>,
    <1627, 1630, 1631>,
    <1627, 1631, 1617>,
    <1632, 1633, 1634>,
    <1632, 1634, 1635>,
    <1632, 1635, 1636>,
    <1632, 1636, 1637>,
    <1632, 1637, 1638>,
    <1632, 1638, 1639>,
    <1632, 1640, 1641>,
    <1632, 1641, 1633>,
    <1642, 1643, 1634>,
    <1642, 1634, 1633>,
    <1642, 1633, 1644>,
    <1642, 1644, 1645>,
    <1642, 1646, 1647>,
    <1642, 1647, 1529>,
    <1642, 1529, 1527>,
    <1642, 1527, 1643>,
    <1648, 1635, 1634>,
    <1648, 1634, 1643>,
    <1648, 1643, 1527>,
    <1648, 1527, 1526>,
    <1648, 1526, 1525>,
    <1648, 1525, 1649>,
    <1648, 1649, 1636>,
    <1648, 1636, 1635>,
    <1650, 1651, 1652>,
    <1650, 1652, 1653>,
    <1650, 1653, 1654>,
    <1650, 1654, 1655>,
    <1650, 1655, 1656>,
    <1650, 1656, 1657>,
    <1650, 1658, 1659>,
    <1650, 1659, 1651>,
    <1660, 1661, 1652>,
    <1660, 1652, 1651>,
    <1660, 1651, 1662>,
    <1660, 1662, 1663>,
    <1660, 1664, 1665>,
    <1660, 1665, 1471>,
    <1660, 1471, 1469>,
    <1660, 1469, 1661>,
    <1666, 1653, 1652>,
    <1666, 1652, 1661>,
    <1666, 1661, 1469>,
    <1666, 1469, 1468>,
    <1666, 1468, 1667>,
    <1666, 1667, 1668>,
    <1666, 1668, 1654>,
    <1666, 1654, 1653>,
    <1669, 1670, 1671>,
    <1669, 1671, 1672>,
    <1669, 1672, 1673>,
    <1669, 1673, 1674>,
    <1669, 1674, 1675>,
    <1669, 1675, 1676>,
    <1669, 1677, 1678>,
    <1669, 1678, 1670>,
    <1679, 1680, 1671>,
    <1679, 1671, 1670>,
    <1679, 1670, 1681>,
    <1679, 1681, 1682>,
    <1679, 1683, 1684>,
    <1679, 1684, 1637>,
    <1679, 1637, 1636>,
    <1679, 1636, 1680>,
    <1685, 1672, 1671>,
    <1685, 1671, 1680>,
    <1685, 1680, 1636>,
    <1685, 1636, 1649>,
    <1685, 1649, 1525>,
    <1685, 1525, 1686>,
    <1685, 1686, 1673>,
    <1685, 1673, 1672>,
    <1687, 1688, 1689>,
    <1687, 1689, 1690>,
    <1687, 1690, 1623>,
    <1687, 1623, 1622>,
    <1687, 1622, 1691>,
    <1687, 1691, 1692>,
    <1687, 1693, 1694>,
    <1687, 1694, 1688>,
    <1695, 1696, 1689>,
    <1695, 1689, 1688>,
    <1695, 1688, 1697>,
    <1695, 1697, 1698>,
    <1695, 1699, 1700>,
    <1695, 1700, 1701>,
    <1695, 1701, 1702>,
    <1695, 1702, 1696>,
    <1703, 1690, 1689>,
    <1703, 1689, 1696>,
    <1703, 1696, 1702>,
    <1703, 1702, 1704>,
    <1703, 1704, 1576>,
    <1703, 1576, 1626>,
    <1703, 1626, 1623>,
    <1703, 1623, 1690>,
    <1705, 1706, 1707>,
    <1705, 1707, 1708>,
    <1705, 1708, 1709>,
    <1705, 1709, 1710>,
    <1705, 1711, 1712>,
    <1705, 1712, 1713>,
    <1705, 1713, 1714>,
    <1705, 1714, 1706>,
    <1715, 1716, 1707>,
    <1715, 1707, 1706>,
    <1715, 1706, 1714>,
    <1715, 1714, 1717>,
    <1715, 1717, 1718>,
    <1715, 1718, 1393>,
    <1715, 1393, 1390>,
    <1715, 1390, 1716>,
    <1719, 1708, 1707>,
    <1719, 1707, 1716>,
    <1719, 1716, 1390>,
    <1719, 1390, 1389>,
    <1719, 1389, 1720>,
    <1719, 1720, 1721>,
    <1719, 1722, 1723>,
    <1719, 1723, 1708>,
    <1724, 1725, 1726>,
    <1724, 1726, 1727>,
    <1724, 1727, 1728>,
    <1724, 1728, 1729>,
    <1724, 1730, 1731>,
    <1724, 1731, 1732>,
    <1724, 1732, 1733>,
    <1724, 1733, 1725>,
    <1734, 1735, 1726>,
    <1734, 1726, 1725>,
    <1734, 1725, 1733>,
    <1734, 1733, 1736>,
    <1734, 1736, 1737>,
    <1734, 1737, 1738>,
    <1734, 1738, 1739>,
    <1734, 1739, 1735>,
    <1740, 1727, 1726>,
    <1740, 1726, 1735>,
    <1740, 1735, 1739>,
    <1740, 1739, 1741>,
    <1740, 1741, 1742>,
    <1740, 1742, 1743>,
    <1740, 1744, 1745>,
    <1740, 1745, 1727>,
    <1746, 1747, 1748>,
    <1746, 1748, 1749>,
    <1746, 1749, 1714>,
    <1746, 1714, 1713>,
    <1746, 1713, 1750>,
    <1746, 1750, 1741>,
    <1746, 1741, 1739>,
    <1746, 1739, 1747>,
    <1751, 1752, 1748>,
    <1751, 1748, 1747>,
    <1751, 1747, 1739>,
    <1751, 1739, 1738>,
    <1751, 1738, 1753>,
    <1751, 1753, 1754>,
    <1751, 1755, 1756>,
    <1751, 1756, 1752>,
    <1757, 1749, 1748>,
    <1757, 1748, 1752>,
    <1757, 1752, 1758>,
    <1757, 1758, 1759>,
    <1757, 1760, 1761>,
    <1757, 1761, 1717>,
    <1757, 1717, 1714>,
    <1757, 1714, 1749>,
    <1762, 1763, 1764>,
    <1762, 1764, 1765>,
    <1762, 1765, 1766>,
    <1762, 1766, 1767>,
    <1762, 1768, 1769>,
    <1762, 1769, 1770>,
    <1762, 1771, 1772>,
    <1762, 1772, 1763>,
    <1773, 1774, 1764>,
    <1773, 1764, 1763>,
    <1773, 1763, 1775>,
    <1773, 1775, 1776>,
    <1773, 1777, 1778>,
    <1773, 1778, 1779>,
    <1773, 1780, 1781>,
    <1773, 1781, 1774>,
    <1782, 1765, 1764>,
    <1782, 1764, 1774>,
    <1782, 1774, 1783>,
    <1782, 1783, 1784>,
    <1782, 1785, 1786>,
    <1782, 1786, 1787>,
    <1782, 1788, 1789>,
    <1782, 1789, 1765>,
    <1790, 1791, 1792>,
    <1790, 1792, 1793>,
    <1790, 1793, 1794>,
    <1790, 1794, 1795>,
    <1790, 1795, 1796>,
    <1790, 1796, 1655>,
    <1790, 1655, 1654>,
    <1790, 1654, 1791>,
    <1797, 1798, 1792>,
    <1797, 1792, 1791>,
    <1797, 1791, 1654>,
    <1797, 1654, 1668>,
    <1797, 1668, 1799>,
    <1797, 1799, 1800>,
    <1797, 1801, 1802>,
    <1797, 1802, 1798>,
    <1803, 1793, 1792>,
    <1803, 1792, 1798>,
    <1803, 1798, 1804>,
    <1803, 1804, 1805>,
    <1803, 1806, 1807>,
    <1803, 1807, 1808>,
    <1803, 1808, 1794>,
    <1803, 1794, 1793>,
    <1809, 1810, 1811>,
    <1809, 1811, 1812>,
    <1809, 1812, 1813>,
    <1809, 1813, 1814>,
    <1809, 1814, 1815>,
    <1809, 1815, 1816>,
    <1809, 1817, 1818>,
    <1809, 1818, 1810>,
    <1819, 1820, 1811>,
    <1819, 1811, 1810>,
    <1819, 1810, 1821>,
    <1819, 1821, 1822>,
    <1819, 1823, 1824>,
    <1819, 1824, 1795>,
    <1819, 1795, 1794>,
    <1819, 1794, 1820>,
    <1825, 1812, 1811>,
    <1825, 1811, 1820>,
    <1825, 1820, 1794>,
    <1825, 1794, 1808>,
    <1825, 1808, 1826>,
    <1825, 1826, 1827>,
    <1825, 1827, 1813>,
    <1825, 1813, 1812>,
    <1828, 1829, 1830>,
    <1828, 1830, 1831>,
    <1828, 1831, 1832>,
    <1828, 1832, 1833>,
    <1828, 1834, 1835>,
    <1828, 1835, 1814>,
    <1828, 1814, 1813>,
    <1828, 1813, 1829>,
    <1836, 1837, 1830>,
    <1836, 1830, 1829>,
    <1836, 1829, 1813>,
    <1836, 1813, 1827>,
    <1836, 1827, 1838>,
    <1836, 1838, 1839>,
    <1836, 1839, 1840>,
    <1836, 1840, 1837>,
    <1841, 1831, 1830>,
    <1841, 1830, 1837>,
    <1841, 1837, 1840>,
    <1841, 1840, 1842>,
    <1841, 1842, 1843>,
    <1841, 1843, 1844>,
    <1841, 1845, 1846>,
    <1841, 1846, 1831>,
    <1847, 1848, 1849>,
    <1847, 1849, 1850>,
    <1847, 1850, 1851>,
    <1847, 1851, 1852>,
    <1847, 1853, 1854>,
    <1847, 1854, 1855>,
    <1847, 1856, 1857>,
    <1847, 1857, 1848>,
    <1858, 1859, 1849>,
    <1858, 1849, 1848>,
    <1858, 1848, 1860>,
    <1858, 1860, 1861>,
    <1858, 1862, 1863>,
    <1858, 1863, 1864>,
    <1858, 1865, 1866>,
    <1858, 1866, 1859>,
    <1867, 1850, 1849>,
    <1867, 1849, 1859>,
    <1867, 1859, 1868>,
    <1867, 1868, 1869>,
    <1867, 1870, 1871>,
    <1867, 1871, 1872>,
    <1867, 1873, 1874>,
    <1867, 1874, 1850>,
    <1875, 1876, 1877>,
    <1875, 1877, 1878>,
    <1875, 1878, 1879>,
    <1875, 1879, 1880>,
    <1875, 1881, 1882>,
    <1875, 1882, 1883>,
    <1875, 1883, 1884>,
    <1875, 1884, 1876>,
    <1885, 1886, 1877>,
    <1885, 1877, 1876>,
    <1885, 1876, 1884>,
    <1885, 1884, 1887>,
    <1885, 1887, 1888>,
    <1885, 1888, 1889>,
    <1885, 1889, 1890>,
    <1885, 1890, 1886>,
    <1891, 1878, 1877>,
    <1891, 1877, 1886>,
    <1891, 1886, 1890>,
    <1891, 1890, 1892>,
    <1891, 1892, 1893>,
    <1891, 1893, 1894>,
    <1891, 1895, 1896>,
    <1891, 1896, 1878>,
    <1897, 1898, 1899>,
    <1897, 1899, 1900>,
    <1897, 1900, 1884>,
    <1897, 1884, 1883>,
    <1897, 1883, 1901>,
    <1897, 1901, 1902>,
    <1897, 1903, 1904>,
    <1897, 1904, 1898>,
    <1905, 1906, 1899>,
    <1905, 1899, 1898>,
    <1905, 1898, 1907>,
    <1905, 1907, 1908>,
    <1905, 1909, 1910>,
    <1905, 1910, 1911>,
    <1905, 1911, 1912>,
    <1905, 1912, 1906>,
    <1913, 1900, 1899>,
    <1913, 1899, 1906>,
    <1913, 1906, 1912>,
    <1913, 1912, 1914>,
    <1913, 1914, 1888>,
    <1913, 1888, 1887>,
    <1913, 1887, 1884>,
    <1913, 1884, 1900>,
    <1915, 1916, 1917>,
    <1915, 1917, 1918>,
    <1915, 1918, 1912>,
    <1915, 1912, 1911>,
    <1915, 1911, 1919>,
    <1915, 1919, 1674>,
    <1915, 1674, 1673>,
    <1915, 1673, 1916>,
    <1920, 1921, 1917>,
    <1920, 1917, 1916>,
    <1920, 1916, 1673>,
    <1920, 1673, 1686>,
    <1920, 1686, 1525>,
    <1920, 1525, 1922>,
    <1920, 1922, 1923>,
    <1920, 1923, 1921>,
    <1924, 1918, 1917>,
    <1924, 1917, 1921>,
    <1924, 1921, 1923>,
    <1924, 1923, 1925>,
    <1924, 1925, 1888>,
    <1924, 1888, 1914>,
    <1924, 1914, 1912>,
    <1924, 1912, 1918>,
    <1926, 1927, 1928>,
    <1926, 1928, 1929>,
    <1926, 1929, 1930>,
    <1926, 1930, 1931>,
    <1926, 1932, 1933>,
    <1926, 1933, 1934>,
    <1926, 1934, 1935>,
    <1926, 1935, 1927>,
    <1936, 1937, 1928>,
    <1936, 1928, 1927>,
    <1936, 1927, 1935>,
    <1936, 1935, 1938>,
    <1936, 1938, 1939>,
    <1936, 1939, 1940>,
    <1936, 1940, 1941>,
    <1936, 1941, 1937>,
    <1942, 1929, 1928>,
    <1942, 1928, 1937>,
    <1942, 1937, 1941>,
    <1942, 1941, 1943>,
    <1942, 1943, 1944>,
    <1942, 1944, 1945>,
    <1942, 1946, 1947>,
    <1942, 1947, 1929>,
    <1948, 1949, 1950>,
    <1948, 1950, 1951>,
    <1948, 1951, 1702>,
    <1948, 1702, 1701>,
    <1948, 1701, 1952>,
    <1948, 1952, 1943>,
    <1948, 1943, 1941>,
    <1948, 1941, 1949>,
    <1953, 1954, 1950>,
    <1953, 1950, 1949>,
    <1953, 1949, 1941>,
    <1953, 1941, 1940>,
    <1953, 1940, 1939>,
    <1953, 1939, 1955>,
    <1953, 1955, 1956>,
    <1953, 1956, 1954>,
    <1957, 1951, 1950>,
    <1957, 1950, 1954>,
    <1957, 1954, 1956>,
    <1957, 1956, 1958>,
    <1957, 1958, 1576>,
    <1957, 1576, 1704>,
    <1957, 1704, 1702>,
    <1957, 1702, 1951>,
    <1959, 1960, 1961>,
    <1959, 1961, 1962>,
    <1959, 1962, 1963>,
    <1959, 1963, 1964>,
    <1959, 1965, 1966>,
    <1959, 1966, 1967>,
    <1959, 1967, 1968>,
    <1959, 1968, 1960>,
    <1969, 1970, 1961>,
    <1969, 1961, 1960>,
    <1969, 1960, 1968>,
    <1969, 1968, 1971>,
    <1969, 1971, 1939>,
    <1969, 1939, 1938>,
    <1969, 1938, 1935>,
    <1969, 1935, 1970>,
    <1972, 1962, 1961>,
    <1972, 1961, 1970>,
    <1972, 1970, 1935>,
    <1972, 1935, 1934>,
    <1972, 1934, 1973>,
    <1972, 1973, 1974>,
    <1972, 1975, 1976>,
    <1972, 1976, 1962>,
    <1977, 1978, 1979>,
    <1977, 1979, 1980>,
    <1977, 1980, 1981>,
    <1977, 1981, 1982>,
    <1977, 1982, 1983>,
    <1977, 1983, 1984>,
    <1977, 1985, 1986>,
    <1977, 1986, 1978>,
    <1987, 1988, 1979>,
    <1987, 1979, 1978>,
    <1987, 1978, 1989>,
    <1987, 1989, 1990>,
    <1987, 1991, 1992>,
    <1987, 1992, 1892>,
    <1987, 1892, 1890>,
    <1987, 1890, 1988>,
    <1993, 1980, 1979>,
    <1993, 1979, 1988>,
    <1993, 1988, 1890>,
    <1993, 1890, 1889>,
    <1993, 1889, 1888>,
    <1993, 1888, 1994>,
    <1993, 1994, 1981>,
    <1993, 1981, 1980>,
    <1995, 1996, 1997>,
    <1995, 1997, 1998>,
    <1995, 1998, 1999>,
    <1995, 1999, 2000>,
    <1995, 2001, 2002>,
    <1995, 2002, 2003>,
    <1995, 2003, 2004>,
    <1995, 2004, 1996>,
    <2005, 2006, 1997>,
    <2005, 1997, 1996>,
    <2005, 1996, 2004>,
    <2005, 2004, 2007>,
    <2005, 2007, 1939>,
    <2005, 1939, 1971>,
    <2005, 1971, 1968>,
    <2005, 1968, 2006>,
    <2008, 1998, 1997>,
    <2008, 1997, 2006>,
    <2008, 2006, 1968>,
    <2008, 1968, 1967>,
    <2008, 1967, 2009>,
    <2008, 2009, 2010>,
    <2008, 2011, 2012>,
    <2008, 2012, 1998>,
    <2013, 2014, 2015>,
    <2013, 2015, 2016>,
    <2013, 2016, 2017>,
    <2013, 2017, 2018>,
    <2013, 2018, 2019>,
    <2013, 2019, 2020>,
    <2013, 2021, 2022>,
    <2013, 2022, 2014>,
    <2023, 2024, 2015>,
    <2023, 2015, 2014>,
    <2023, 2014, 2025>,
    <2023, 2025, 2026>,
    <2023, 2027, 2028>,
    <2023, 2028, 1842>,
    <2023, 1842, 1840>,
    <2023, 1840, 2024>,
    <2029, 2016, 2015>,
    <2029, 2015, 2024>,
    <2029, 2024, 1840>,
    <2029, 1840, 1839>,
    <2029, 1839, 2030>,
    <2029, 2030, 2031>,
    <2029, 2031, 2017>,
    <2029, 2017, 2016>,
    <2032, 2033, 2034>,
    <2032, 2034, 2035>,
    <2032, 2035, 2036>,
    <2032, 2036, 2037>,
    <2032, 2037, 2038>,
    <2032, 2038, 2039>,
    <2032, 2040, 2041>,
    <2032, 2041, 2033>,
    <2042, 2043, 2034>,
    <2042, 2034, 2033>,
    <2042, 2033, 2044>,
    <2042, 2044, 2045>,
    <2042, 2046, 2047>,
    <2042, 2047, 1982>,
    <2042, 1982, 1981>,
    <2042, 1981, 2043>,
    <2048, 2035, 2034>,
    <2048, 2034, 2043>,
    <2048, 2043, 1981>,
    <2048, 1981, 1994>,
    <2048, 1994, 1888>,
    <2048, 1888, 2049>,
    <2048, 2049, 2036>,
    <2048, 2036, 2035>,
    <2050, 2051, 2052>,
    <2050, 2052, 2053>,
    <2050, 2053, 2054>,
    <2050, 2054, 2055>,
    <2050, 2056, 2057>,
    <2050, 2057, 2058>,
    <2050, 2058, 2059>,
    <2050, 2059, 2051>,
    <2060, 2061, 2052>,
    <2060, 2052, 2051>,
    <2060, 2051, 2059>,
    <2060, 2059, 2062>,
    <2060, 2062, 2063>,
    <2060, 2063, 1736>,
    <2060, 1736, 1733>,
    <2060, 1733, 2061>,
    <2064, 2053, 2052>,
    <2064, 2052, 2061>,
    <2064, 2061, 1733>,
    <2064, 1733, 1732>,
    <2064, 1732, 2065>,
    <2064, 2065, 2066>,
    <2064, 2067, 2068>,
    <2064, 2068, 2053>,
    <2069, 2070, 2071>,
    <2069, 2071, 2072>,
    <2069, 2072, 2073>,
    <2069, 2073, 2074>,
    <2069, 2075, 2076>,
    <2069, 2076, 2077>,
    <2069, 2077, 2078>,
    <2069, 2078, 2070>,
    <2079, 2080, 2071>,
    <2079, 2071, 2070>,
    <2079, 2070, 2078>,
    <2079, 2078, 2081>,
    <2079, 2081, 2082>,
    <2079, 2082, 2083>,
    <2079, 2083, 2084>,
    <2079, 2084, 2080>,
    <2085, 2072, 2071>,
    <2085, 2071, 2080>,
    <2085, 2080, 2084>,
    <2085, 2084, 2086>,
    <2085, 2086, 2087>,
    <2085, 2087, 2088>,
    <2085, 2089, 2090>,
    <2085, 2090, 2072>,
    <2091, 2092, 2093>,
    <2091, 2093, 2094>,
    <2091, 2094, 2059>,
    <2091, 2059, 2058>,
    <2091, 2058, 2095>,
    <2091, 2095, 2086>,
    <2091, 2086, 2084>,
    <2091, 2084, 2092>,
    <2096, 2097, 2093>,
    <2096, 2093, 2092>,
    <2096, 2092, 2084>,
    <2096, 2084, 2083>,
    <2096, 2083, 2098>,
    <2096, 2098, 2099>,
    <2096, 2100, 2101>,
    <2096, 2101, 2097>,
    <2102, 2094, 2093>,
    <2102, 2093, 2097>,
    <2102, 2097, 2103>,
    <2102, 2103, 2104>,
    <2102, 2105, 2106>,
    <2102, 2106, 2062>,
    <2102, 2062, 2059>,
    <2102, 2059, 2094>,
    <2107, 2108, 2109>,
    <2107, 2109, 2110>,
    <2107, 2110, 2111>,
    <2107, 2111, 2112>,
    <2107, 2113, 2114>,
    <2107, 2114, 2115>,
    <2107, 2116, 2117>,
    <2107, 2117, 2108>,
    <2118, 2119, 2109>,
    <2118, 2109, 2108>,
    <2118, 2108, 2120>,
    <2118, 2120, 2121>,
    <2118, 2122, 2123>,
    <2118, 2123, 2124>,
    <2118, 2125, 2126>,
    <2118, 2126, 2119>,
    <2127, 2110, 2109>,
    <2127, 2109, 2119>,
    <2127, 2119, 2128>,
    <2127, 2128, 2129>,
    <2127, 2130, 2131>,
    <2127, 2131, 2132>,
    <2127, 2133, 2134>,
    <2127, 2134, 2110>,
    <2135, 2136, 2137>,
    <2135, 2137, 2138>,
    <2135, 2138, 2139>,
    <2135, 2139, 2140>,
    <2135, 2140, 2141>,
    <2135, 2141, 2018>,
    <2135, 2018, 2017>,
    <2135, 2017, 2136>,
    <2142, 2143, 2137>,
    <2142, 2137, 2136>,
    <2142, 2136, 2017>,
    <2142, 2017, 2031>,
    <2142, 2031, 2144>,
    <2142, 2144, 2145>,
    <2142, 2146, 2147>,
    <2142, 2147, 2143>,
    <2148, 2138, 2137>,
    <2148, 2137, 2143>,
    <2148, 2143, 2149>,
    <2148, 2149, 2150>,
    <2148, 2151, 2152>,
    <2148, 2152, 2153>,
    <2148, 2153, 2139>,
    <2148, 2139, 2138>,
    <2154, 2155, 2156>,
    <2154, 2156, 2157>,
    <2154, 2157, 2158>,
    <2154, 2158, 2159>,
    <2154, 2160, 2161>,
    <2154, 2161, 2140>,
    <2154, 2140, 2139>,
    <2154, 2139, 2155>,
    <2162, 2163, 2156>,
    <2162, 2156, 2155>,
    <2162, 2155, 2139>,
    <2162, 2139, 2153>,
    <2162, 2153, 2164>,
    <2162, 2164, 2165>,
    <2162, 2165, 2166>,
    <2162, 2166, 2163>,
    <2167, 2157, 2156>,
    <2167, 2156, 2163>,
    <2167, 2163, 2166>,
    <2167, 2166, 2168>,
    <2167, 2168, 2169>,
    <2167, 2169, 2170>,
    <2167, 2171, 2172>,
    <2167, 2172, 2157>,
    <2173, 2174, 2175>,
    <2173, 2175, 2176>,
    <2173, 2176, 2177>,
    <2173, 2177, 2178>,
    <2173, 2179, 2180>,
    <2173, 2180, 2168>,
    <2173, 2168, 2166>,
    <2173, 2166, 2174>,
    <2181, 2182, 2175>,
    <2181, 2175, 2174>,
    <2181, 2174, 2166>,
    <2181, 2166, 2165>,
    <2181, 2165, 2183>,
    <2181, 2183, 2184>,
    <2181, 2184, 2185>,
    <2181, 2185, 2182>,
    <2186, 2176, 2175>,
    <2186, 2175, 2182>,
    <2186, 2182, 2185>,
    <2186, 2185, 2187>,
    <2186, 2187, 2188>,
    <2186, 2188, 2189>,
    <2186, 2190, 2191>,
    <2186, 2191, 2176>,
    <2192, 2193, 2194>,
    <2192, 2194, 2195>,
    <2192, 2195, 2196>,
    <2192, 2196, 2197>,
    <2192, 2198, 2199>,
    <2192, 2199, 2200>,
    <2192, 2201, 2202>,
    <2192, 2202, 2193>,
    <2203, 2204, 2194>,
    <2203, 2194, 2193>,
    <2203, 2193, 2205>,
    <2203, 2205, 2206>,
    <2203, 2207, 2208>,
    <2203, 2208, 2209>,
    <2203, 2210, 2211>,
    <2203, 2211, 2204>,
    <2212, 2195, 2194>,
    <2212, 2194, 2204>,
    <2212, 2204, 2213>,
    <2212, 2213, 2214>,
    <2212, 2215, 2216>,
    <2212, 2216, 2217>,
    <2212, 2218, 2219>,
    <2212, 2219, 2195>,
    <2220, 2221, 2222>,
    <2220, 2222, 2223>,
    <2220, 2223, 2004>,
    <2220, 2004, 2003>,
    <2220, 2003, 2224>,
    <2220, 2224, 2225>,
    <2220, 2226, 2227>,
    <2220, 2227, 2221>,
    <2228, 2229, 2222>,
    <2228, 2222, 2221>,
    <2228, 2221, 2230>,
    <2228, 2230, 2231>,
    <2228, 2232, 2233>,
    <2228, 2233, 2234>,
    <2228, 2234, 2235>,
    <2228, 2235, 2229>,
    <2236, 2223, 2222>,
    <2236, 2222, 2229>,
    <2236, 2229, 2235>,
    <2236, 2235, 2237>,
    <2236, 2237, 1939>,
    <2236, 1939, 2007>,
    <2236, 2007, 2004>,
    <2236, 2004, 2223>,
    <2238, 2239, 2240>,
    <2238, 2240, 2241>,
    <2238, 2241, 2242>,
    <2238, 2242, 2243>,
    <2238, 2244, 2245>,
    <2238, 2245, 2246>,
    <2238, 2246, 2247>,
    <2238, 2247, 2239>,
    <2248, 2249, 2240>,
    <2248, 2240, 2239>,
    <2248, 2239, 2247>,
    <2248, 2247, 2250>,
    <2248, 2250, 2251>,
    <2248, 2251, 2252>,
    <2248, 2252, 2253>,
    <2248, 2253, 2249>,
    <2254, 2241, 2240>,
    <2254, 2240, 2249>,
    <2254, 2249, 2253>,
    <2254, 2253, 2255>,
    <2254, 2255, 2256>,
    <2254, 2256, 2257>,
    <2254, 2258, 2259>,
    <2254, 2259, 2241>,
    <2260, 2261, 2262>,
    <2260, 2262, 2263>,
    <2260, 2263, 2247>,
    <2260, 2247, 2246>,
    <2260, 2246, 2264>,
    <2260, 2264, 2037>,
    <2260, 2037, 2036>,
    <2260, 2036, 2261>,
    <2265, 2266, 2262>,
    <2265, 2262, 2261>,
    <2265, 2261, 2036>,
    <2265, 2036, 2049>,
    <2265, 2049, 1888>,
    <2265, 1888, 2267>,
    <2265, 2267, 2268>,
    <2265, 2268, 2266>,
    <2269, 2263, 2262>,
    <2269, 2262, 2266>,
    <2269, 2266, 2268>,
    <2269, 2268, 2270>,
    <2269, 2270, 2251>,
    <2269, 2251, 2250>,
    <2269, 2250, 2247>,
    <2269, 2247, 2263>,
    <2271, 2272, 2273>,
    <2271, 2273, 2274>,
    <2271, 2274, 2235>,
    <2271, 2235, 2234>,
    <2271, 2234, 2275>,
    <2271, 2275, 2276>,
    <2271, 2276, 2277>,
    <2271, 2277, 2272>,
    <2278, 2279, 2273>,
    <2278, 2273, 2272>,
    <2278, 2272, 2277>,
    <2278, 2277, 2280>,
    <2278, 2280, 2281>,
    <2278, 2281, 2282>,
    <2278, 2282, 2283>,
    <2278, 2283, 2279>,
    <2284, 2274, 2273>,
    <2284, 2273, 2279>,
    <2284, 2279, 2283>,
    <2284, 2283, 2285>,
    <2284, 2285, 1939>,
    <2284, 1939, 2237>,
    <2284, 2237, 2235>,
    <2284, 2235, 2274>,
    <2286, 2287, 2288>,
    <2286, 2288, 2289>,
    <2286, 2289, 2290>,
    <2286, 2290, 2291>,
    <2286, 2292, 2293>,
    <2286, 2293, 2294>,
    <2286, 2294, 2295>,
    <2286, 2295, 2287>,
    <2296, 2297, 2288>,
    <2296, 2288, 2287>,
    <2296, 2287, 2295>,
    <2296, 2295, 2298>,
    <2296, 2298, 2281>,
    <2296, 2281, 2280>,
    <2296, 2280, 2277>,
    <2296, 2277, 2297>,
    <2299, 2289, 2288>,
    <2299, 2288, 2297>,
    <2299, 2297, 2277>,
    <2299, 2277, 2276>,
    <2299, 2276, 2300>,
    <2299, 2300, 2301>,
    <2299, 2302, 2303>,
    <2299, 2303, 2289>,
    <2304, 2305, 2306>,
    <2304, 2306, 2307>,
    <2304, 2307, 2308>,
    <2304, 2308, 2309>,
    <2304, 2309, 2310>,
    <2304, 2310, 2311>,
    <2304, 2312, 2313>,
    <2304, 2313, 2305>,
    <2314, 2315, 2306>,
    <2314, 2306, 2305>,
    <2314, 2305, 2316>,
    <2314, 2316, 2317>,
    <2314, 2318, 2319>,
    <2314, 2319, 2255>,
    <2314, 2255, 2253>,
    <2314, 2253, 2315>,
    <2320, 2307, 2306>,
    <2320, 2306, 2315>,
    <2320, 2315, 2253>,
    <2320, 2253, 2252>,
    <2320, 2252, 2251>,
    <2320, 2251, 2321>,
    <2320, 2321, 2308>,
    <2320, 2308, 2307>,
    <2322, 2323, 2324>,
    <2322, 2324, 2325>,
    <2322, 2325, 2326>,
    <2322, 2326, 2327>,
    <2322, 2327, 2328>,
    <2322, 2328, 2329>,
    <2322, 2330, 2331>,
    <2322, 2331, 2323>,
    <2332, 2333, 2324>,
    <2332, 2324, 2323>,
    <2332, 2323, 2334>,
    <2332, 2334, 2335>,
    <2332, 2336, 2337>,
    <2332, 2337, 2187>,
    <2332, 2187, 2185>,
    <2332, 2185, 2333>,
    <2338, 2325, 2324>,
    <2338, 2324, 2333>,
    <2338, 2333, 2185>,
    <2338, 2185, 2184>,
    <2338, 2184, 2339>,
    <2338, 2339, 2340>,
    <2338, 2340, 2326>,
    <2338, 2326, 2325>,
    <2341, 2342, 2343>,
    <2341, 2343, 2344>,
    <2341, 2344, 2295>,
    <2341, 2295, 2294>,
    <2341, 2294, 2345>,
    <2341, 2345, 2346>,
    <2341, 2347, 2348>,
    <2341, 2348, 2342>,
    <2349, 2350, 2343>,
    <2349, 2343, 2342>,
    <2349, 2342, 2351>,
    <2349, 2351, 2352>,
    <2349, 2353, 2354>,
    <2349, 2354, 2355>,
    <2349, 2355, 2356>,
    <2349, 2356, 2350>,
    <2357, 2344, 2343>,
    <2357, 2343, 2350>,
    <2357, 2350, 2356>,
    <2357, 2356, 2358>,
    <2357, 2358, 2281>,
    <2357, 2281, 2298>,
    <2357, 2298, 2295>,
    <2357, 2295, 2344>,
    <2359, 2360, 2361>,
    <2359, 2361, 2362>,
    <2359, 2362, 2363>,
    <2359, 2363, 2364>,
    <2359, 2364, 2365>,
    <2359, 2365, 2366>,
    <2359, 2367, 2368>,
    <2359, 2368, 2360>,
    <2369, 2370, 2361>,
    <2369, 2361, 2360>,
    <2369, 2360, 2371>,
    <2369, 2371, 2372>,
    <2369, 2373, 2374>,
    <2369, 2374, 2309>,
    <2369, 2309, 2308>,
    <2369, 2308, 2370>,
    <2375, 2362, 2361>,
    <2375, 2361, 2370>,
    <2375, 2370, 2308>,
    <2375, 2308, 2321>,
    <2375, 2321, 2251>,
    <2375, 2251, 2376>,
    <2375, 2376, 2363>,
    <2375, 2363, 2362>,
    <2377, 2378, 2379>,
    <2377, 2379, 2380>,
    <2377, 2380, 2381>,
    <2377, 2381, 2382>,
    <2377, 2383, 2384>,
    <2377, 2384, 2385>,
    <2377, 2385, 2386>,
    <2377, 2386, 2378>,
    <2387, 2388, 2379>,
    <2387, 2379, 2378>,
    <2387, 2378, 2386>,
    <2387, 2386, 2389>,
    <2387, 2389, 2390>,
    <2387, 2390, 2081>,
    <2387, 2081, 2078>,
    <2387, 2078, 2388>,
    <2391, 2380, 2379>,
    <2391, 2379, 2388>,
    <2391, 2388, 2078>,
    <2391, 2078, 2077>,
    <2391, 2077, 2392>,
    <2391, 2392, 2393>,
    <2391, 2394, 2395>,
    <2391, 2395, 2380>,
    <2396, 2397, 2398>,
    <2396, 2398, 2399>,
    <2396, 2399, 2400>,
    <2396, 2400, 2401>,
    <2396, 2402, 2403>,
    <2396, 2403, 2404>,
    <2396, 2404, 2405>,
    <2396, 2405, 2397>,
    <2406, 2407, 2398>,
    <2406, 2398, 2397>,
    <2406, 2397, 2405>,
    <2406, 2405, 2408>,
    <2406, 2408, 2409>,
    <2406, 2409, 2410>,
    <2406, 2410, 2411>,
    <2406, 2411, 2407>,
    <2412, 2399, 2398>,
    <2412, 2398, 2407>,
    <2412, 2407, 2411>,
    <2412, 2411, 2413>,
    <2412, 2413, 2414>,
    <2412, 2414, 2415>,
    <2412, 2416, 2417>,
    <2412, 2417, 2399>,
    <2418, 2419, 2420>,
    <2418, 2420, 2421>,
    <2418, 2421, 2386>,
    <2418, 2386, 2385>,
    <2418, 2385, 2422>,
    <2418, 2422, 2413>,
    <2418, 2413, 2411>,
    <2418, 2411, 2419>,
    <2423, 2424, 2420>,
    <2423, 2420, 2419>,
    <2423, 2419, 2411>,
    <2423, 2411, 2410>,
    <2423, 2410, 2425>,
    <2423, 2425, 2426>,
    <2423, 2427, 2428>,
    <2423, 2428, 2424>,
    <2429, 2421, 2420>,
    <2429, 2420, 2424>,
    <2429, 2424, 2430>,
    <2429, 2430, 2431>,
    <2429, 2432, 2433>,
    <2429, 2433, 2389>,
    <2429, 2389, 2386>,
    <2429, 2386, 2421>,
    <2434, 2435, 2436>,
    <2434, 2436, 2437>,
    <2434, 2437, 2438>,
    <2434, 2438, 2439>,
    <2434, 2440, 2441>,
    <2434, 2441, 2442>,
    <2434, 2443, 2444>,
    <2434, 2444, 2435>,
    <2445, 2446, 2436>,
    <2445, 2436, 2435>,
    <2445, 2435, 2447>,
    <2445, 2447, 2448>,
    <2445, 2449, 2450>,
    <2445, 2450, 2451>,
    <2445, 2452, 2453>,
    <2445, 2453, 2446>,
    <2454, 2437, 2436>,
    <2454, 2436, 2446>,
    <2454, 2446, 2455>,
    <2454, 2455, 2456>,
    <2454, 2457, 2458>,
    <2454, 2458, 2459>,
    <2454, 2460, 2461>,
    <2454, 2461, 2437>,
    <2462, 2463, 2464>,
    <2462, 2464, 2465>,
    <2462, 2465, 2466>,
    <2462, 2466, 2467>,
    <2462, 2467, 2468>,
    <2462, 2468, 2327>,
    <2462, 2327, 2326>,
    <2462, 2326, 2463>,
    <2469, 2470, 2464>,
    <2469, 2464, 2463>,
    <2469, 2463, 2326>,
    <2469, 2326, 2340>,
    <2469, 2340, 2471>,
    <2469, 2471, 2472>,
    <2469, 2473, 2474>,
    <2469, 2474, 2470>,
    <2475, 2465, 2464>,
    <2475, 2464, 2470>,
    <2475, 2470, 2476>,
    <2475, 2476, 2477>,
    <2475, 2478, 2479>,
    <2475, 2479, 2480>,
    <2475, 2480, 2466>,
    <2475, 2466, 2465>,
    <2481, 2482, 2483>,
    <2481, 2483, 2484>,
    <2481, 2484, 2485>,
    <2481, 2485, 2486>,
    <2481, 2486, 2487>,
    <2481, 2487, 2488>,
    <2481, 2489, 2490>,
    <2481, 2490, 2482>,
    <2491, 2492, 2483>,
    <2491, 2483, 2482>,
    <2491, 2482, 2493>,
    <2491, 2493, 2494>,
    <2491, 2495, 2496>,
    <2491, 2496, 2467>,
    <2491, 2467, 2466>,
    <2491, 2466, 2492>,
    <2497, 2484, 2483>,
    <2497, 2483, 2492>,
    <2497, 2492, 2466>,
    <2497, 2466, 2480>,
    <2497, 2480, 2498>,
    <2497, 2498, 2499>,
    <2497, 2499, 2485>,
    <2497, 2485, 2484>,
    <2500, 2501, 2502>,
    <2500, 2502, 2503>,
    <2500, 2503, 2504>,
    <2500, 2504, 2505>,
    <2500, 2506, 2507>,
    <2500, 2507, 2508>,
    <2500, 2509, 2510>,
    <2500, 2510, 2501>,
    <2511, 2512, 2502>,
    <2511, 2502, 2501>,
    <2511, 2501, 2513>,
    <2511, 2513, 2514>,
    <2511, 2515, 2516>,
    <2511, 2516, 2517>,
    <2511, 2518, 2519>,
    <2511, 2519, 2512>,
    <2520, 2503, 2502>,
    <2520, 2502, 2512>,
    <2520, 2512, 2521>,
    <2520, 2521, 2522>,
    <2520, 2523, 2524>,
    <2520, 2524, 2525>,
    <2520, 2526, 2527>,
    <2520, 2527, 2503>,
    <2528, 2529, 2530>,
    <2528, 2530, 2531>,
    <2528, 2531, 2532>,
    <2528, 2532, 2533>,
    <2528, 2534, 2535>,
    <2528, 2535, 2486>,
    <2528, 2486, 2485>,
    <2528, 2485, 2529>,
    <2536, 2537, 2530>,
    <2536, 2530, 2529>,
    <2536, 2529, 2485>,
    <2536, 2485, 2499>,
    <2536, 2499, 2538>,
    <2536, 2538, 2539>,
    <2536, 2539, 2540>,
    <2536, 2540, 2537>,
    <2541, 2531, 2530>,
    <2541, 2530, 2537>,
    <2541, 2537, 2540>,
    <2541, 2540, 2542>,
    <2541, 2542, 2543>,
    <2541, 2543, 2544>,
    <2541, 2545, 2546>,
    <2541, 2546, 2531>,
    <2547, 2548, 2549>,
    <2547, 2549, 2550>,
    <2547, 2550, 2551>,
    <2547, 2551, 2552>,
    <2547, 2553, 2554>,
    <2547, 2554, 2555>,
    <2547, 2555, 2556>,
    <2547, 2556, 2548>,
    <2557, 2558, 2549>,
    <2557, 2549, 2548>,
    <2557, 2548, 2556>,
    <2557, 2556, 2559>,
    <2557, 2559, 2560>,
    <2557, 2560, 2561>,
    <2557, 2561, 2562>,
    <2557, 2562, 2558>,
    <2563, 2550, 2549>,
    <2563, 2549, 2558>,
    <2563, 2558, 2562>,
    <2563, 2562, 2564>,
    <2563, 2564, 2565>,
    <2563, 2565, 2566>,
    <2563, 2567, 2568>,
    <2563, 2568, 2550>,
    <2569, 2570, 2571>,
    <2569, 2571, 2572>,
    <2569, 2572, 2556>,
    <2569, 2556, 2555>,
    <2569, 2555, 2573>,
    <2569, 2573, 2574>,
    <2569, 2575, 2576>,
    <2569, 2576, 2570>,
    <2577, 2578, 2571>,
    <2577, 2571, 2570>,
    <2577, 2570, 2579>,
    <2577, 2579, 2580>,
    <2577, 2581, 2582>,
    <2577, 2582, 2583>,
    <2577, 2583, 2584>,
    <2577, 2584, 2578>,
    <2585, 2572, 2571>,
    <2585, 2571, 2578>,
    <2585, 2578, 2584>,
    <2585, 2584, 2586>,
    <2585, 2586, 2560>,
    <2585, 2560, 2559>,
    <2585, 2559, 2556>,
    <2585, 2556, 2572>,
    <2587, 2588, 2589>,
    <2587, 2589, 2590>,
    <2587, 2590, 2584>,
    <2587, 2584, 2583>,
    <2587, 2583, 2591>,
    <2587, 2591, 2364>,
    <2587, 2364, 2363>,
    <2587, 2363, 2588>,
    <2592, 2593, 2589>,
    <2592, 2589, 2588>,
    <2592, 2588, 2363>,
    <2592, 2363, 2376>,
    <2592, 2376, 2251>,
    <2592, 2251, 2594>,
    <2592, 2594, 2595>,
    <2592, 2595, 2593>,
    <2596, 2590, 2589>,
    <2596, 2589, 2593>,
    <2596, 2593, 2595>,
    <2596, 2595, 2597>,
    <2596, 2597, 2560>,
    <2596, 2560, 2586>,
    <2596, 2586, 2584>,
    <2596, 2584, 2590>,
    <2598, 2599, 2600>,
    <2598, 2600, 2601>,
    <2598, 2601, 2356>,
    <2598, 2356, 2355>,
    <2598, 2355, 2602>,
    <2598, 2602, 2603>,
    <2598, 2603, 2604>,
    <2598, 2604, 2599>,
    <2605, 2606, 2600>,
    <2605, 2600, 2599>,
    <2605, 2599, 2604>,
    <2605, 2604, 2607>,
    <2605, 2607, 2608>,
    <2605, 2608, 2609>,
    <2605, 2609, 2610>,
    <2605, 2610, 2606>,
    <2611, 2601, 2600>,
    <2611, 2600, 2606>,
    <2611, 2606, 2610>,
    <2611, 2610, 2612>,
    <2611, 2612, 2281>,
    <2611, 2281, 2358>,
    <2611, 2358, 2356>,
    <2611, 2356, 2601>,
    <2613, 2614, 2615>,
    <2613, 2615, 2616>,
    <2613, 2616, 2617>,
    <2613, 2617, 2618>,
    <2613, 2619, 2620>,
    <2613, 2620, 2621>,
    <2613, 2621, 2622>,
    <2613, 2622, 2614>,
    <2623, 2624, 2615>,
    <2623, 2615, 2614>,
    <2623, 2614, 2622>,
    <2623, 2622, 2625>,
    <2623, 2625, 2608>,
    <2623, 2608, 2607>,
    <2623, 2607, 2604>,
    <2623, 2604, 2624>,
    <2626, 2616, 2615>,
    <2626, 2615, 2624>,
    <2626, 2624, 2604>,
    <2626, 2604, 2603>,
    <2626, 2603, 2627>,
    <2626, 2627, 2628>,
    <2626, 2629, 2630>,
    <2626, 2630, 2616>,
    <2631, 2632, 2633>,
    <2631, 2633, 2634>,
    <2631, 2634, 2635>,
    <2631, 2635, 2636>,
    <2631, 2637, 2638>,
    <2631, 2638, 2639>,
    <2631, 2639, 2640>,
    <2631, 2640, 2632>,
    <2641, 2642, 2633>,
    <2641, 2633, 2632>,
    <2641, 2632, 2640>,
    <2641, 2640, 2643>,
    <2641, 2643, 2608>,
    <2641, 2608, 2625>,
    <2641, 2625, 2622>,
    <2641, 2622, 2642>,
    <2644, 2634, 2633>,
    <2644, 2633, 2642>,
    <2644, 2642, 2622>,
    <2644, 2622, 2621>,
    <2644, 2621, 2645>,
    <2644, 2645, 2646>,
    <2644, 2647, 2648>,
    <2644, 2648, 2634>,
    <2649, 2650, 2651>,
    <2649, 2651, 2652>,
    <2649, 2652, 2653>,
    <2649, 2653, 2654>,
    <2649, 2655, 2656>,
    <2649, 2656, 2657>,
    <2649, 2657, 2658>,
    <2649, 2658, 2650>,
    <2659, 2660, 2651>,
    <2659, 2651, 2650>,
    <2659, 2650, 2658>,
    <2659, 2658, 2661>,
    <2659, 2661, 2608>,
    <2659, 2608, 2643>,
    <2659, 2643, 2640>,
    <2659, 2640, 2660>,
    <2662, 2652, 2651>,
    <2662, 2651, 2660>,
    <2662, 2660, 2640>,
    <2662, 2640, 2639>,
    <2662, 2639, 2663>,
    <2662, 2663, 2664>,
    <2662, 2665, 2666>,
    <2662, 2666, 2652>,
    <2667, 2668, 2669>,
    <2667, 2669, 2670>,
    <2667, 2670, 2658>,
    <2667, 2658, 2657>,
    <2667, 2657, 2671>,
    <2667, 2671, 2672>,
    <2667, 2673, 2674>,
    <2667, 2674, 2668>,
    <2675, 2676, 2669>,
    <2675, 2669, 2668>,
    <2675, 2668, 2677>,
    <2675, 2677, 2678>,
    <2675, 2679, 2680>,
    <2675, 2680, 2681>,
    <2675, 2681, 2682>,
    <2675, 2682, 2676>,
    <2683, 2670, 2669>,
    <2683, 2669, 2676>,
    <2683, 2676, 2682>,
    <2683, 2682, 2684>,
    <2683, 2684, 2608>,
    <2683, 2608, 2661>,
    <2683, 2661, 2658>,
    <2683, 2658, 2670>,
    <2685, 2686, 2687>,
    <2685, 2687, 2688>,
    <2685, 2688, 2689>,
    <2685, 2689, 2690>,
    <2685, 2690, 2691>,
    <2685, 2691, 2692>,
    <2685, 2693, 2694>,
    <2685, 2694, 2686>,
    <2695, 2696, 2687>,
    <2695, 2687, 2686>,
    <2695, 2686, 2697>,
    <2695, 2697, 2698>,
    <2695, 2699, 2700>,
    <2695, 2700, 2542>,
    <2695, 2542, 2540>,
    <2695, 2540, 2696>,
    <2701, 2688, 2687>,
    <2701, 2687, 2696>,
    <2701, 2696, 2540>,
    <2701, 2540, 2539>,
    <2701, 2539, 2702>,
    <2701, 2702, 2703>,
    <2701, 2703, 2689>,
    <2701, 2689, 2688>,
    <2704, 2705, 2706>,
    <2704, 2706, 2707>,
    <2704, 2707, 2708>,
    <2704, 2708, 2709>,
    <2704, 2710, 2711>,
    <2704, 2711, 2712>,
    <2704, 2712, 2713>,
    <2704, 2713, 2705>,
    <2714, 2715, 2706>,
    <2714, 2706, 2705>,
    <2714, 2705, 2713>,
    <2714, 2713, 2716>,
    <2714, 2716, 2717>,
    <2714, 2717, 2408>,
    <2714, 2408, 2405>,
    <2714, 2405, 2715>,
    <2718, 2707, 2706>,
    <2718, 2706, 2715>,
    <2718, 2715, 2405>,
    <2718, 2405, 2404>,
    <2718, 2404, 2719>,
    <2718, 2719, 2720>,
    <2718, 2721, 2722>,
    <2718, 2722, 2707>,
    <2723, 2724, 2725>,
    <2723, 2725, 2726>,
    <2723, 2726, 2727>,
    <2723, 2727, 2728>,
    <2723, 2729, 2730>,
    <2723, 2730, 2731>,
    <2723, 2731, 2732>,
    <2723, 2732, 2724>,
    <2733, 2734, 2725>,
    <2733, 2725, 2724>,
    <2733, 2724, 2732>,
    <2733, 2732, 2735>,
    <2733, 2735, 2736>,
    <2733, 2736, 2737>,
    <2733, 2737, 2738>,
    <2733, 2738, 2734>,
    <2739, 2726, 2725>,
    <2739, 2725, 2734>,
    <2739, 2734, 2738>,
    <2739, 2738, 2740>,
    <2739, 2740, 2741>,
    <2739, 2741, 2742>,
    <2739, 2743, 2744>,
    <2739, 2744, 2726>,
    <2745, 2746, 2747>,
    <2745, 2747, 2748>,
    <2745, 2748, 2713>,
    <2745, 2713, 2712>,
    <2745, 2712, 2749>,
    <2745, 2749, 2740>,
    <2745, 2740, 2738>,
    <2745, 2738, 2746>,
    <2750, 2751, 2747>,
    <2750, 2747, 2746>,
    <2750, 2746, 2738>,
    <2750, 2738, 2737>,
    <2750, 2737, 2752>,
    <2750, 2752, 2753>,
    <2750, 2754, 2755>,
    <2750, 2755, 2751>,
    <2756, 2748, 2747>,
    <2756, 2747, 2751>,
    <2756, 2751, 2757>,
    <2756, 2757, 2758>,
    <2756, 2759, 2760>,
    <2756, 2760, 2716>,
    <2756, 2716, 2713>,
    <2756, 2713, 2748>,
    <2761, 2762, 2763>,
    <2761, 2763, 2764>,
    <2761, 2764, 2765>,
    <2761, 2765, 2766>,
    <2761, 2766, 2767>,
    <2761, 2767, 2768>,
    <2761, 2768, 2769>,
    <2761, 2769, 2762>,
    <2770, 2771, 2763>,
    <2770, 2763, 2762>,
    <2770, 2762, 2769>,
    <2770, 2769, 2772>,
    <2770, 2772, 2773>,
    <2770, 2773, 2774>,
    <2770, 2774, 2775>,
    <2770, 2775, 2771>,
    <2776, 2764, 2763>,
    <2776, 2763, 2771>,
    <2776, 2771, 2775>,
    <2776, 2775, 2777>,
    <2776, 2777, 2778>,
    <2776, 2778, 2779>,
    <2776, 2779, 2765>,
    <2776, 2765, 2764>,
    <2780, 2781, 2782>,
    <2780, 2782, 2783>,
    <2780, 2783, 2769>,
    <2780, 2769, 2768>,
    <2780, 2768, 2784>,
    <2780, 2784, 2564>,
    <2780, 2564, 2562>,
    <2780, 2562, 2781>,
    <2785, 2786, 2782>,
    <2785, 2782, 2781>,
    <2785, 2781, 2562>,
    <2785, 2562, 2561>,
    <2785, 2561, 2560>,
    <2785, 2560, 2787>,
    <2785, 2787, 2788>,
    <2785, 2788, 2786>,
    <2789, 2783, 2782>,
    <2789, 2782, 2786>,
    <2789, 2786, 2788>,
    <2789, 2788, 2790>,
    <2789, 2790, 2791>,
    <2789, 2791, 2772>,
    <2789, 2772, 2769>,
    <2789, 2769, 2783>,
    <2792, 2793, 2794>,
    <2792, 2794, 2795>,
    <2792, 2795, 2682>,
    <2792, 2682, 2681>,
    <2792, 2681, 2796>,
    <2792, 2796, 2797>,
    <2792, 2797, 2798>,
    <2792, 2798, 2793>,
    <2799, 2800, 2794>,
    <2799, 2794, 2793>,
    <2799, 2793, 2798>,
    <2799, 2798, 2801>,
    <2799, 2801, 2802>,
    <2799, 2802, 2803>,
    <2799, 2803, 2804>,
    <2799, 2804, 2800>,
    <2805, 2795, 2794>,
    <2805, 2794, 2800>,
    <2805, 2800, 2804>,
    <2805, 2804, 2806>,
    <2805, 2806, 2608>,
    <2805, 2608, 2684>,
    <2805, 2684, 2682>,
    <2805, 2682, 2795>,
    <2807, 2808, 2809>,
    <2807, 2809, 2810>,
    <2807, 2810, 2811>,
    <2807, 2811, 2812>,
    <2807, 2813, 2814>,
    <2807, 2814, 2815>,
    <2807, 2815, 2816>,
    <2807, 2816, 2808>,
    <2817, 2818, 2809>,
    <2817, 2809, 2808>,
    <2817, 2808, 2816>,
    <2817, 2816, 2819>,
    <2817, 2819, 2802>,
    <2817, 2802, 2801>,
    <2817, 2801, 2798>,
    <2817, 2798, 2818>,
    <2820, 2810, 2809>,
    <2820, 2809, 2818>,
    <2820, 2818, 2798>,
    <2820, 2798, 2797>,
    <2820, 2797, 2821>,
    <2820, 2821, 2822>,
    <2820, 2823, 2824>,
    <2820, 2824, 2810>,
    <2825, 2826, 2827>,
    <2825, 2827, 2828>,
    <2825, 2828, 2829>,
    <2825, 2829, 2830>,
    <2825, 2830, 2831>,
    <2825, 2831, 2690>,
    <2825, 2690, 2689>,
    <2825, 2689, 2826>,
    <2832, 2833, 2827>,
    <2832, 2827, 2826>,
    <2832, 2826, 2689>,
    <2832, 2689, 2703>,
    <2832, 2703, 2834>,
    <2832, 2834, 2835>,
    <2832, 2836, 2837>,
    <2832, 2837, 2833>,
    <2838, 2828, 2827>,
    <2838, 2827, 2833>,
    <2838, 2833, 2839>,
    <2838, 2839, 2840>,
    <2838, 2841, 2842>,
    <2838, 2842, 2843>,
    <2838, 2843, 2829>,
    <2838, 2829, 2828>,
    <2844, 2845, 2846>,
    <2844, 2846, 2847>,
    <2844, 2847, 2848>,
    <2844, 2848, 2849>,
    <2844, 2850, 2851>,
    <2844, 2851, 2830>,
    <2844, 2830, 2829>,
    <2844, 2829, 2845>,
    <2852, 2853, 2846>,
    <2852, 2846, 2845>,
    <2852, 2845, 2829>,
    <2852, 2829, 2843>,
    <2852, 2843, 2854>,
    <2852, 2854, 2855>,
    <2852, 2855, 2856>,
    <2852, 2856, 2853>,
    <2857, 2847, 2846>,
    <2857, 2846, 2853>,
    <2857, 2853, 2856>,
    <2857, 2856, 2858>,
    <2857, 2858, 2859>,
    <2857, 2859, 2860>,
    <2857, 2861, 2862>,
    <2857, 2862, 2847>,
    <2863, 2864, 2865>,
    <2863, 2865, 2866>,
    <2863, 2866, 2867>,
    <2863, 2867, 2868>,
    <2863, 2869, 2870>,
    <2863, 2870, 2858>,
    <2863, 2858, 2856>,
    <2863, 2856, 2864>,
    <2871, 2872, 2865>,
    <2871, 2865, 2864>,
    <2871, 2864, 2856>,
    <2871, 2856, 2855>,
    <2871, 2855, 2873>,
    <2871, 2873, 2874>,
    <2871, 2874, 2875>,
    <2871, 2875, 2872>,
    <2876, 2866, 2865>,
    <2876, 2865, 2872>,
    <2876, 2872, 2875>,
    <2876, 2875, 2877>,
    <2876, 2877, 2878>,
    <2876, 2878, 2879>,
    <2876, 2880, 2881>,
    <2876, 2881, 2866>,
    <2882, 2883, 2884>,
    <2882, 2884, 2885>,
    <2882, 2885, 2886>,
    <2882, 2886, 2887>,
    <2882, 2887, 2888>,
    <2882, 2888, 2889>,
    <2882, 2890, 2891>,
    <2882, 2891, 2883>,
    <2892, 2893, 2884>,
    <2892, 2884, 2883>,
    <2892, 2883, 2894>,
    <2892, 2894, 2895>,
    <2892, 2896, 2897>,
    <2892, 2897, 2777>,
    <2892, 2777, 2775>,
    <2892, 2775, 2893>,
    <2898, 2885, 2884>,
    <2898, 2884, 2893>,
    <2898, 2893, 2775>,
    <2898, 2775, 2774>,
    <2898, 2774, 2899>,
    <2898, 2899, 2900>,
    <2898, 2900, 2886>,
    <2898, 2886, 2885>,
    <2901, 2902, 2903>,
    <2901, 2903, 2904>,
    <2901, 2904, 2905>,
    <2901, 2905, 2906>,
    <2901, 2907, 2908>,
    <2901, 2908, 2909>,
    <2901, 2910, 2911>,
    <2901, 2911, 2902>,
    <2912, 2913, 2903>,
    <2912, 2903, 2902>,
    <2912, 2902, 2914>,
    <2912, 2914, 2915>,
    <2912, 2916, 2917>,
    <2912, 2917, 2887>,
    <2912, 2887, 2886>,
    <2912, 2886, 2913>,
    <2918, 2904, 2903>,
    <2918, 2903, 2913>,
    <2918, 2913, 2886>,
    <2918, 2886, 2900>,
    <2918, 2900, 2919>,
    <2918, 2919, 2920>,
    <2918, 2921, 2922>,
    <2918, 2922, 2904>,
    <2923, 2924, 2925>,
    <2923, 2925, 2926>,
    <2923, 2926, 2927>,
    <2923, 2927, 2928>,
    <2923, 2929, 2930>,
    <2923, 2930, 2931>,
    <2923, 2931, 2932>,
    <2923, 2932, 2924>,
    <2933, 2934, 2925>,
    <2933, 2925, 2924>,
    <2933, 2924, 2932>,
    <2933, 2932, 2935>,
    <2933, 2935, 2936>,
    <2933, 2936, 2937>,
    <2933, 2938, 2939>,
    <2933, 2939, 2934>,
    <2940, 2926, 2925>,
    <2940, 2925, 2934>,
    <2940, 2934, 2941>,
    <2940, 2941, 2942>,
    <2940, 2943, 2944>,
    <2940, 2944, 2945>,
    <2940, 2946, 2947>,
    <2940, 2947, 2926>,
    <2948, 2949, 2950>,
    <2948, 2950, 2951>,
    <2948, 2951, 2952>,
    <2948, 2952, 2953>,
    <2948, 2953, 2954>,
    <2948, 2954, 2955>,
    <2948, 2956, 2957>,
    <2948, 2957, 2949>,
    <2958, 2959, 2950>,
    <2958, 2950, 2949>,
    <2958, 2949, 2960>,
    <2958, 2960, 2961>,
    <2958, 2962, 2963>,
    <2958, 2963, 2877>,
    <2958, 2877, 2875>,
    <2958, 2875, 2959>,
    <2964, 2951, 2950>,
    <2964, 2950, 2959>,
    <2964, 2959, 2875>,
    <2964, 2875, 2874>,
    <2964, 2874, 2965>,
    <2964, 2965, 2966>,
    <2964, 2966, 2952>,
    <2964, 2952, 2951>,
    <2967, 2968, 2969>,
    <2967, 2969, 2970>,
    <2967, 2970, 2971>,
    <2967, 2971, 2972>,
    <2967, 2972, 2973>,
    <2967, 2973, 2935>,
    <2967, 2935, 2932>,
    <2967, 2932, 2968>,
    <2974, 2975, 2969>,
    <2974, 2969, 2968>,
    <2974, 2968, 2932>,
    <2974, 2932, 2931>,
    <2974, 2931, 2976>,
    <2974, 2976, 2977>,
    <2974, 2978, 2979>,
    <2974, 2979, 2975>,
    <2980, 2970, 2969>,
    <2980, 2969, 2975>,
    <2980, 2975, 2981>,
    <2980, 2981, 2982>,
    <2980, 2983, 2984>,
    <2980, 2984, 2985>,
    <2980, 2985, 2971>,
    <2980, 2971, 2970>,
    <2986, 2987, 2988>,
    <2986, 2988, 2989>,
    <2986, 2989, 2990>,
    <2986, 2990, 2991>,
    <2986, 2992, 2993>,
    <2986, 2993, 2972>,
    <2986, 2972, 2971>,
    <2986, 2971, 2987>,
    <2994, 2995, 2988>,
    <2994, 2988, 2987>,
    <2994, 2987, 2971>,
    <2994, 2971, 2985>,
    <2994, 2985, 2996>,
    <2994, 2996, 2997>,
    <2994, 2997, 2998>,
    <2994, 2998, 2995>,
    <2999, 2989, 2988>,
    <2999, 2988, 2995>,
    <2999, 2995, 2998>,
    <2999, 2998, 3000>,
    <2999, 3000, 3001>,
    <2999, 3001, 3002>,
    <2999, 3003, 3004>,
    <2999, 3004, 2989>,
    <3005, 3006, 3007>,
    <3005, 3007, 3008>,
    <3005, 3008, 3009>,
    <3005, 3009, 3010>,
    <3005, 3010, 3011>,
    <3005, 3011, 3012>,
    <3005, 3012, 3013>,
    <3005, 3013, 3006>,
    <3014, 3015, 3007>,
    <3014, 3007, 3006>,
    <3014, 3006, 3013>,
    <3014, 3013, 3016>,
    <3014, 3016, 3017>,
    <3014, 3017, 3018>,
    <3014, 3018, 3019>,
    <3014, 3019, 3015>,
    <3020, 3008, 3007>,
    <3020, 3007, 3015>,
    <3020, 3015, 3019>,
    <3020, 3019, 3021>,
    <3020, 3021, 2802>,
    <3020, 2802, 3022>,
    <3020, 3022, 3009>,
    <3020, 3009, 3008>,
    <3023, 3024, 3025>,
    <3023, 3025, 3026>,
    <3023, 3026, 3027>,
    <3023, 3027, 3028>,
    <3023, 3028, 3029>,
    <3023, 3029, 3010>,
    <3023, 3010, 3009>,
    <3023, 3009, 3024>,
    <3030, 3031, 3025>,
    <3030, 3025, 3024>,
    <3030, 3024, 3009>,
    <3030, 3009, 3022>,
    <3030, 3022, 2802>,
    <3030, 2802, 2819>,
    <3030, 2819, 2816>,
    <3030, 2816, 3031>,
    <3032, 3026, 3025>,
    <3032, 3025, 3031>,
    <3032, 3031, 2816>,
    <3032, 2816, 2815>,
    <3032, 2815, 3033>,
    <3032, 3033, 3034>,
    <3032, 3034, 3027>,
    <3032, 3027, 3026>,
    <3035, 3036, 3037>,
    <3035, 3037, 3038>,
    <3035, 3038, 3039>,
    <3035, 3039, 3040>,
    <3035, 3041, 3042>,
    <3035, 3042, 3043>,
    <3035, 3043, 3044>,
    <3035, 3044, 3036>,
    <3045, 3046, 3037>,
    <3045, 3037, 3036>,
    <3045, 3036, 3044>,
    <3045, 3044, 3047>,
    <3045, 3047, 3048>,
    <3045, 3048, 2735>,
    <3045, 2735, 2732>,
    <3045, 2732, 3046>,
    <3049, 3038, 3037>,
    <3049, 3037, 3046>,
    <3049, 3046, 2732>,
    <3049, 2732, 2731>,
    <3049, 2731, 3050>,
    <3049, 3050, 3051>,
    <3049, 3052, 3053>,
    <3049, 3053, 3038>,
    <3054, 3055, 3056>,
    <3054, 3056, 3057>,
    <3054, 3057, 3058>,
    <3054, 3058, 3059>,
    <3054, 3060, 3061>,
    <3054, 3061, 3062>,
    <3054, 3063, 3064>,
    <3054, 3064, 3055>,
    <3065, 3066, 3056>,
    <3065, 3056, 3055>,
    <3065, 3055, 3067>,
    <3065, 3067, 3068>,
    <3065, 3069, 3070>,
    <3065, 3070, 3071>,
    <3065, 3072, 3073>,
    <3065, 3073, 3066>,
    <3074, 3057, 3056>,
    <3074, 3056, 3066>,
    <3074, 3066, 3075>,
    <3074, 3075, 3076>,
    <3074, 3077, 3078>,
    <3074, 3078, 3079>,
    <3074, 3080, 3081>,
    <3074, 3081, 3057>,
    <3082, 3083, 3084>,
    <3082, 3084, 3085>,
    <3082, 3085, 3044>,
    <3082, 3044, 3043>,
    <3082, 3043, 3086>,
    <3082, 3086, 3087>,
    <3082, 3087, 3088>,
    <3082, 3088, 3083>,
    <3089, 3090, 3084>,
    <3089, 3084, 3083>,
    <3089, 3083, 3088>,
    <3089, 3088, 3091>,
    <3089, 3091, 3092>,
    <3089, 3092, 3093>,
    <3089, 3094, 3095>,
    <3089, 3095, 3090>,
    <3096, 3085, 3084>,
    <3096, 3084, 3090>,
    <3096, 3090, 3097>,
    <3096, 3097, 3098>,
    <3096, 3099, 3100>,
    <3096, 3100, 3047>,
    <3096, 3047, 3044>,
    <3096, 3044, 3085>,
    <3101, 3102, 3103>,
    <3101, 3103, 3104>,
    <3101, 3104, 3105>,
    <3101, 3105, 3106>,
    <3101, 3107, 3108>,
    <3101, 3108, 3109>,
    <3101, 3109, 3110>,
    <3101, 3110, 3102>,
    <3111, 3112, 3103>,
    <3111, 3103, 3102>,
    <3111, 3102, 3110>,
    <3111, 3110, 3113>,
    <3111, 3113, 3114>,
    <3111, 3114, 3091>,
    <3111, 3091, 3088>,
    <3111, 3088, 3112>,
    <3115, 3104, 3103>,
    <3115, 3103, 3112>,
    <3115, 3112, 3088>,
    <3115, 3088, 3087>,
    <3115, 3087, 3116>,
    <3115, 3116, 3117>,
    <3115, 3118, 3119>,
    <3115, 3119, 3104>,
    <3120, 3121, 3122>,
    <3120, 3122, 3123>,
    <3120, 3123, 3124>,
    <3120, 3124, 3125>,
    <3120, 3125, 3126>,
    <3120, 3126, 3127>,
    <3120, 3128, 3129>,
    <3120, 3129, 3121>,
    <3130, 3131, 3122>,
    <3130, 3122, 3121>,
    <3130, 3121, 3132>,
    <3130, 3132, 3133>,
    <3130, 3134, 3135>,
    <3130, 3135, 3136>,
    <3130, 3136, 3137>,
    <3130, 3137, 3131>,
    <3138, 3123, 3122>,
    <3138, 3122, 3131>,
    <3138, 3131, 3137>,
    <3138, 3137, 3139>,
    <3138, 3139, 3140>,
    <3138, 3140, 3141>,
    <3138, 3141, 3124>,
    <3138, 3124, 3123>,
    <3142, 3143, 3144>,
    <3142, 3144, 3145>,
    <3142, 3145, 3137>,
    <3142, 3137, 3136>,
    <3142, 3136, 3146>,
    <3142, 3146, 2953>,
    <3142, 2953, 2952>,
    <3142, 2952, 3143>,
    <3147, 3148, 3144>,
    <3147, 3144, 3143>,
    <3147, 3143, 2952>,
    <3147, 2952, 2966>,
    <3147, 2966, 3149>,
    <3147, 3149, 3150>,
    <3147, 3151, 3152>,
    <3147, 3152, 3148>,
    <3153, 3145, 3144>,
    <3153, 3144, 3148>,
    <3153, 3148, 3154>,
    <3153, 3154, 3155>,
    <3153, 3156, 3157>,
    <3153, 3157, 3139>,
    <3153, 3139, 3137>,
    <3153, 3137, 3145>,
    <3158, 3159, 3160>,
    <3158, 3160, 3161>,
    <3158, 3161, 3162>,
    <3158, 3162, 3163>,
    <3158, 3164, 3165>,
    <3158, 3165, 3125>,
    <3158, 3125, 3124>,
    <3158, 3124, 3159>,
    <3166, 3167, 3160>,
    <3166, 3160, 3159>,
    <3166, 3159, 3124>,
    <3166, 3124, 3141>,
    <3166, 3141, 3168>,
    <3166, 3168, 3169>,
    <3166, 3169, 3170>,
    <3166, 3170, 3167>,
    <3171, 3161, 3160>,
    <3171, 3160, 3167>,
    <3171, 3167, 3170>,
    <3171, 3170, 3172>,
    <3171, 3172, 3173>,
    <3171, 3173, 3174>,
    <3171, 3175, 3176>,
    <3171, 3176, 3161>,
    <3177, 3178, 3179>,
    <3177, 3179, 3180>,
    <3177, 3180, 3181>,
    <3177, 3181, 3182>,
    <3177, 3183, 3184>,
    <3177, 3184, 3185>,
    <3177, 3185, 3186>,
    <3177, 3186, 3178>,
    <3187, 3188, 3179>,
    <3187, 3179, 3178>,
    <3187, 3178, 3186>,
    <3187, 3186, 3189>,
    <3187, 3189, 3190>,
    <3187, 3190, 3016>,
    <3187, 3016, 3013>,
    <3187, 3013, 3188>,
    <3191, 3180, 3179>,
    <3191, 3179, 3188>,
    <3191, 3188, 3013>,
    <3191, 3013, 3012>,
    <3191, 3012, 3192>,
    <3191, 3192, 3193>,
    <3191, 3194, 3195>,
    <3191, 3195, 3180>,
    <3196, 3197, 3198>,
    <3196, 3198, 3199>,
    <3196, 3199, 3200>,
    <3196, 3200, 3201>,
    <3196, 3202, 3203>,
    <3196, 3203, 3204>,
    <3196, 3204, 3205>,
    <3196, 3205, 3197>,
    <3206, 3207, 3198>,
    <3206, 3198, 3197>,
    <3206, 3197, 3205>,
    <3206, 3205, 3208>,
    <3206, 3208, 3209>,
    <3206, 3209, 3000>,
    <3206, 3000, 2998>,
    <3206, 2998, 3207>,
    <3210, 3199, 3198>,
    <3210, 3198, 3207>,
    <3210, 3207, 2998>,
    <3210, 2998, 2997>,
    <3210, 2997, 3211>,
    <3210, 3211, 3212>,
    <3210, 3213, 3214>,
    <3210, 3214, 3199>,
    <3215, 3216, 3217>,
    <3215, 3217, 3218>,
    <3215, 3218, 3186>,
    <3215, 3186, 3185>,
    <3215, 3185, 3219>,
    <3215, 3219, 3220>,
    <3215, 3221, 3222>,
    <3215, 3222, 3216>,
    <3223, 3224, 3217>,
    <3223, 3217, 3216>,
    <3223, 3216, 3225>,
    <3223, 3225, 3226>,
    <3223, 3227, 3228>,
    <3223, 3228, 3229>,
    <3223, 3229, 3230>,
    <3223, 3230, 3224>,
    <3231, 3218, 3217>,
    <3231, 3217, 3224>,
    <3231, 3224, 3230>,
    <3231, 3230, 3232>,
    <3231, 3232, 3233>,
    <3231, 3233, 3189>,
    <3231, 3189, 3186>,
    <3231, 3186, 3218>,
    <3234, 3235, 3236>,
    <3234, 3236, 3237>,
    <3234, 3237, 3230>,
    <3234, 3230, 3229>,
    <3234, 3229, 3238>,
    <3234, 3238, 3239>,
    <3234, 3239, 3240>,
    <3234, 3240, 3235>,
    <3241, 3242, 3236>,
    <3241, 3236, 3235>,
    <3241, 3235, 3240>,
    <3241, 3240, 3243>,
    <3241, 3243, 3244>,
    <3241, 3244, 3245>,
    <3241, 3246, 3247>,
    <3241, 3247, 3242>,
    <3248, 3237, 3236>,
    <3248, 3236, 3242>,
    <3248, 3242, 3249>,
    <3248, 3249, 3250>,
    <3248, 3251, 3252>,
    <3248, 3252, 3232>,
    <3248, 3232, 3230>,
    <3248, 3230, 3237>,
    <3253, 3254, 3255>,
    <3253, 3255, 3256>,
    <3253, 3256, 3205>,
    <3253, 3205, 3204>,
    <3253, 3204, 3257>,
    <3253, 3257, 3258>,
    <3253, 3258, 3259>,
    <3253, 3259, 3254>,
    <3260, 3261, 3255>,
    <3260, 3255, 3254>,
    <3260, 3254, 3259>,
    <3260, 3259, 3262>,
    <3260, 3262, 3263>,
    <3260, 3263, 3264>,
    <3260, 3265, 3266>,
    <3260, 3266, 3261>,
    <3267, 3256, 3255>,
    <3267, 3255, 3261>,
    <3267, 3261, 3268>,
    <3267, 3268, 3269>,
    <3267, 3270, 3271>,
    <3267, 3271, 3208>,
    <3267, 3208, 3205>,
    <3267, 3205, 3256>,
    <3272, 3273, 3274>,
    <3272, 3274, 3275>,
    <3272, 3275, 3276>,
    <3272, 3276, 3277>,
    <3272, 3277, 3278>,
    <3272, 3278, 3279>,
    <3272, 3280, 3281>,
    <3272, 3281, 3273>,
    <3282, 3283, 3274>,
    <3282, 3274, 3273>,
    <3282, 3273, 3284>,
    <3282, 3284, 3285>,
    <3282, 3286, 3287>,
    <3282, 3287, 3172>,
    <3282, 3172, 3170>,
    <3282, 3170, 3283>,
    <3288, 3275, 3274>,
    <3288, 3274, 3283>,
    <3288, 3283, 3170>,
    <3288, 3170, 3169>,
    <3288, 3169, 3289>,
    <3288, 3289, 3290>,
    <3288, 3290, 3276>,
    <3288, 3276, 3275>,
    <3291, 3292, 3293>,
    <3291, 3293, 3294>,
    <3291, 3294, 3295>,
    <3291, 3295, 3296>,
    <3291, 3296, 3297>,
    <3291, 3297, 3298>,
    <3291, 3299, 3300>,
    <3291, 3300, 3292>,
    <3301, 3302, 3293>,
    <3301, 3293, 3292>,
    <3301, 3292, 3303>,
    <3301, 3303, 3304>,
    <3301, 3305, 3306>,
    <3301, 3306, 3307>,
    <3301, 3307, 3308>,
    <3301, 3308, 3302>,
    <3309, 3294, 3293>,
    <3309, 3293, 3302>,
    <3309, 3302, 3308>,
    <3309, 3308, 3310>,
    <3309, 3310, 3311>,
    <3309, 3311, 3312>,
    <3309, 3312, 3295>,
    <3309, 3295, 3294>,
    <3313, 3314, 3315>,
    <3313, 3315, 3316>,
    <3313, 3316, 3308>,
    <3313, 3308, 3307>,
    <3313, 3307, 3317>,
    <3313, 3317, 3262>,
    <3313, 3262, 3259>,
    <3313, 3259, 3314>,
    <3318, 3319, 3315>,
    <3318, 3315, 3314>,
    <3318, 3314, 3259>,
    <3318, 3259, 3258>,
    <3318, 3258, 3320>,
    <3318, 3320, 3321>,
    <3318, 3322, 3323>,
    <3318, 3323, 3319>,
    <3324, 3316, 3315>,
    <3324, 3315, 3319>,
    <3324, 3319, 3325>,
    <3324, 3325, 3326>,
    <3324, 3327, 3328>,
    <3324, 3328, 3310>,
    <3324, 3310, 3308>,
    <3324, 3308, 3316>,
    <3329, 3330, 3331>,
    <3329, 3331, 3332>,
    <3329, 3332, 3333>,
    <3329, 3333, 3334>,
    <3329, 3335, 3336>,
    <3329, 3336, 3243>,
    <3329, 3243, 3240>,
    <3329, 3240, 3330>,
    <3337, 3338, 3331>,
    <3337, 3331, 3330>,
    <3337, 3330, 3240>,
    <3337, 3240, 3239>,
    <3337, 3239, 3339>,
    <3337, 3339, 3340>,
    <3337, 3340, 3341>,
    <3337, 3341, 3338>,
    <3342, 3332, 3331>,
    <3342, 3331, 3338>,
    <3342, 3338, 3341>,
    <3342, 3341, 3343>,
    <3342, 3343, 3344>,
    <3342, 3344, 3345>,
    <3342, 3346, 3347>,
    <3342, 3347, 3332>,
    <3348, 3349, 3350>,
    <3348, 3350, 3351>,
    <3348, 3351, 3352>,
    <3348, 3352, 3353>,
    <3348, 3354, 3355>,
    <3348, 3355, 3356>,
    <3348, 3356, 3357>,
    <3348, 3357, 3349>,
    <3358, 3359, 3350>,
    <3358, 3350, 3349>,
    <3358, 3349, 3357>,
    <3358, 3357, 3360>,
    <3358, 3360, 3361>,
    <3358, 3361, 3343>,
    <3358, 3343, 3341>,
    <3358, 3341, 3359>,
    <3362, 3351, 3350>,
    <3362, 3350, 3359>,
    <3362, 3359, 3341>,
    <3362, 3341, 3340>,
    <3362, 3340, 3363>,
    <3362, 3363, 3364>,
    <3362, 3365, 3366>,
    <3362, 3366, 3351>,
    <3367, 3368, 3369>,
    <3367, 3369, 3370>,
    <3367, 3370, 3371>,
    <3367, 3371, 3372>,
    <3367, 3373, 3374>,
    <3367, 3374, 3296>,
    <3367, 3296, 3295>,
    <3367, 3295, 3368>,
    <3375, 3376, 3369>,
    <3375, 3369, 3368>,
    <3375, 3368, 3295>,
    <3375, 3295, 3312>,
    <3375, 3312, 3377>,
    <3375, 3377, 3378>,
    <3375, 3378, 3379>,
    <3375, 3379, 3376>,
    <3380, 3370, 3369>,
    <3380, 3369, 3376>,
    <3380, 3376, 3379>,
    <3380, 3379, 3381>,
    <3380, 3381, 3382>,
    <3380, 3382, 3383>,
    <3380, 3384, 3385>,
    <3380, 3385, 3370>,
    <3386, 3387, 3388>,
    <3386, 3388, 3389>,
    <3386, 3389, 3390>,
    <3386, 3390, 3391>,
    <3386, 3392, 3393>,
    <3386, 3393, 3394>,
    <3386, 3395, 3396>,
    <3386, 3396, 3387>,
    <3397, 3398, 3388>,
    <3397, 3388, 3387>,
    <3397, 3387, 3399>,
    <3397, 3399, 3400>,
    <3397, 3401, 3402>,
    <3397, 3402, 3403>,
    <3397, 3404, 3405>,
    <3397, 3405, 3398>,
    <3406, 3389, 3388>,
    <3406, 3388, 3398>,
    <3406, 3398, 3407>,
    <3406, 3407, 3408>,
    <3406, 3409, 3410>,
    <3406, 3410, 3411>,
    <3406, 3412, 3413>,
    <3406, 3413, 3389>,
    <3414, 3415, 3416>,
    <3414, 3416, 3417>,
    <3414, 3417, 3418>,
    <3414, 3418, 3419>,
    <3414, 3420, 3421>,
    <3414, 3421, 3422>,
    <3414, 3422, 3423>,
    <3414, 3423, 3415>,
    <3424, 3425, 3416>,
    <3424, 3416, 3415>,
    <3424, 3415, 3423>,
    <3424, 3423, 3426>,
    <3424, 3426, 3427>,
    <3424, 3427, 3113>,
    <3424, 3113, 3110>,
    <3424, 3110, 3425>,
    <3428, 3417, 3416>,
    <3428, 3416, 3425>,
    <3428, 3425, 3110>,
    <3428, 3110, 3109>,
    <3428, 3109, 3429>,
    <3428, 3429, 3430>,
    <3428, 3431, 3432>,
    <3428, 3432, 3417>,
    <3433, 3434, 3435>,
    <3433, 3435, 3436>,
    <3433, 3436, 3423>,
    <3433, 3423, 3422>,
    <3433, 3422, 3437>,
    <3433, 3437, 3438>,
    <3433, 3438, 3439>,
    <3433, 3439, 3434>,
    <3440, 3441, 3435>,
    <3440, 3435, 3434>,
    <3440, 3434, 3439>,
    <3440, 3439, 3442>,
    <3440, 3442, 3443>,
    <3440, 3443, 3444>,
    <3440, 3445, 3446>,
    <3440, 3446, 3441>,
    <3447, 3436, 3435>,
    <3447, 3435, 3441>,
    <3447, 3441, 3448>,
    <3447, 3448, 3449>,
    <3447, 3450, 3451>,
    <3447, 3451, 3426>,
    <3447, 3426, 3423>,
    <3447, 3423, 3436>,
    <3452, 3453, 3454>,
    <3452, 3454, 3455>,
    <3452, 3455, 3456>,
    <3452, 3456, 3457>,
    <3452, 3458, 3459>,
    <3452, 3459, 3460>,
    <3452, 3460, 3461>,
    <3452, 3461, 3453>,
    <3462, 3463, 3454>,
    <3462, 3454, 3453>,
    <3462, 3453, 3461>,
    <3462, 3461, 3464>,
    <3462, 3464, 3465>,
    <3462, 3465, 3442>,
    <3462, 3442, 3439>,
    <3462, 3439, 3463>,
    <3466, 3455, 3454>,
    <3466, 3454, 3463>,
    <3466, 3463, 3439>,
    <3466, 3439, 3438>,
    <3466, 3438, 3467>,
    <3466, 3467, 3468>,
    <3466, 3469, 3470>,
    <3466, 3470, 3455>,
    <3471, 3472, 3473>,
    <3471, 3473, 3474>,
    <3471, 3474, 3475>,
    <3471, 3475, 3476>,
    <3471, 3477, 3478>,
    <3471, 3478, 3479>,
    <3471, 3479, 3480>,
    <3471, 3480, 3472>,
    <3481, 3482, 3473>,
    <3481, 3473, 3472>,
    <3481, 3472, 3480>,
    <3481, 3480, 3483>,
    <3481, 3483, 3484>,
    <3481, 3484, 3485>,
    <3481, 3485, 3486>,
    <3481, 3486, 3482>,
    <3487, 3474, 3473>,
    <3487, 3473, 3482>,
    <3487, 3482, 3486>,
    <3487, 3486, 3488>,
    <3487, 3488, 3489>,
    <3487, 3489, 3490>,
    <3487, 3491, 3492>,
    <3487, 3492, 3474>,
    <3493, 3494, 3495>,
    <3493, 3495, 3496>,
    <3493, 3496, 3480>,
    <3493, 3480, 3479>,
    <3493, 3479, 3497>,
    <3493, 3497, 3277>,
    <3493, 3277, 3276>,
    <3493, 3276, 3494>,
    <3498, 3499, 3495>,
    <3498, 3495, 3494>,
    <3498, 3494, 3276>,
    <3498, 3276, 3290>,
    <3498, 3290, 3500>,
    <3498, 3500, 3501>,
    <3498, 3502, 3503>,
    <3498, 3503, 3499>,
    <3504, 3496, 3495>,
    <3504, 3495, 3499>,
    <3504, 3499, 3505>,
    <3504, 3505, 3506>,
    <3504, 3507, 3508>,
    <3504, 3508, 3483>,
    <3504, 3483, 3480>,
    <3504, 3480, 3496>,
    <3509, 3510, 3511>,
    <3509, 3511, 3512>,
    <3509, 3512, 3513>,
    <3509, 3513, 3514>,
    <3509, 3515, 3516>,
    <3509, 3516, 3488>,
    <3509, 3488, 3486>,
    <3509, 3486, 3510>,
    <3517, 3518, 3511>,
    <3517, 3511, 3510>,
    <3517, 3510, 3486>,
    <3517, 3486, 3485>,
    <3517, 3485, 3519>,
    <3517, 3519, 3520>,
    <3517, 3520, 3521>,
    <3517, 3521, 3518>,
    <3522, 3512, 3511>,
    <3522, 3511, 3518>,
    <3522, 3518, 3521>,
    <3522, 3521, 3523>,
    <3522, 3523, 3524>,
    <3522, 3524, 3525>,
    <3522, 3526, 3527>,
    <3522, 3527, 3512>,
    <3528, 3529, 3530>,
    <3528, 3530, 3531>,
    <3528, 3531, 3532>,
    <3528, 3532, 3533>,
    <3528, 3533, 3534>,
    <3528, 3534, 3535>,
    <3528, 3536, 3537>,
    <3528, 3537, 3529>,
    <3538, 3539, 3530>,
    <3538, 3530, 3529>,
    <3538, 3529, 3540>,
    <3538, 3540, 3541>,
    <3538, 3542, 3543>,
    <3538, 3543, 3381>,
    <3538, 3381, 3379>,
    <3538, 3379, 3539>,
    <3544, 3531, 3530>,
    <3544, 3530, 3539>,
    <3544, 3539, 3379>,
    <3544, 3379, 3378>,
    <3544, 3378, 3545>,
    <3544, 3545, 3546>,
    <3544, 3546, 3532>,
    <3544, 3532, 3531>,
    <3547, 3548, 3549>,
    <3547, 3549, 3550>,
    <3547, 3550, 3551>,
    <3547, 3551, 3552>,
    <3547, 3553, 3554>,
    <3547, 3554, 3555>,
    <3547, 3556, 3557>,
    <3547, 3557, 3548>,
    <3558, 3559, 3549>,
    <3558, 3549, 3548>,
    <3558, 3548, 3560>,
    <3558, 3560, 3561>,
    <3558, 3562, 3563>,
    <3558, 3563, 3533>,
    <3558, 3533, 3532>,
    <3558, 3532, 3559>,
    <3564, 3550, 3549>,
    <3564, 3549, 3559>,
    <3564, 3559, 3532>,
    <3564, 3532, 3546>,
    <3564, 3546, 3565>,
    <3564, 3565, 3566>,
    <3564, 3567, 3568>,
    <3564, 3568, 3550>,
    <3569, 3570, 3571>,
    <3569, 3571, 3572>,
    <3569, 3572, 3573>,
    <3569, 3573, 3574>,
    <3569, 3575, 3576>,
    <3569, 3576, 3577>,
    <3569, 3577, 3578>,
    <3569, 3578, 3570>,
    <3579, 3580, 3571>,
    <3579, 3571, 3570>,
    <3579, 3570, 3578>,
    <3579, 3578, 3581>,
    <3579, 3581, 3582>,
    <3579, 3582, 3583>,
    <3579, 3584, 3585>,
    <3579, 3585, 3580>,
    <3586, 3572, 3571>,
    <3586, 3571, 3580>,
    <3586, 3580, 3587>,
    <3586, 3587, 3588>,
    <3586, 3589, 3590>,
    <3586, 3590, 3591>,
    <3586, 3592, 3593>,
    <3586, 3593, 3572>,
    <3594, 3595, 3596>,
    <3594, 3596, 3597>,
    <3594, 3597, 3598>,
    <3594, 3598, 3599>,
    <3594, 3599, 3600>,
    <3594, 3600, 3601>,
    <3594, 3601, 3602>,
    <3594, 3602, 3595>,
    <3603, 3604, 3596>,
    <3603, 3596, 3595>,
    <3603, 3595, 3602>,
    <3603, 3602, 3605>,
    <3603, 3605, 3606>,
    <3603, 3606, 3607>,
    <3603, 3608, 3609>,
    <3603, 3609, 3604>,
    <3610, 3597, 3596>,
    <3610, 3596, 3604>,
    <3610, 3604, 3611>,
    <3610, 3611, 3612>,
    <3610, 3613, 3614>,
    <3610, 3614, 3615>,
    <3610, 3615, 3598>,
    <3610, 3598, 3597>,
    <3616, 3617, 3618>,
    <3616, 3618, 3619>,
    <3616, 3619, 3620>,
    <3616, 3620, 3621>,
    <3616, 3622, 3623>,
    <3616, 3623, 3599>,
    <3616, 3599, 3598>,
    <3616, 3598, 3617>,
    <3624, 3625, 3618>,
    <3624, 3618, 3617>,
    <3624, 3617, 3598>,
    <3624, 3598, 3615>,
    <3624, 3615, 3626>,
    <3624, 3626, 3360>,
    <3624, 3360, 3357>,
    <3624, 3357, 3625>,
    <3627, 3619, 3618>,
    <3627, 3618, 3625>,
    <3627, 3625, 3357>,
    <3627, 3357, 3356>,
    <3627, 3356, 3628>,
    <3627, 3628, 3629>,
    <3627, 3630, 3631>,
    <3627, 3631, 3619>,
    <3632, 3633, 3634>,
    <3632, 3634, 3635>,
    <3632, 3635, 3636>,
    <3632, 3636, 3637>,
    <3632, 3637, 3638>,
    <3632, 3638, 3639>,
    <3632, 3640, 3641>,
    <3632, 3641, 3633>,
    <3642, 3643, 3634>,
    <3642, 3634, 3633>,
    <3642, 3633, 3644>,
    <3642, 3644, 3645>,
    <3642, 3646, 3647>,
    <3642, 3647, 3523>,
    <3642, 3523, 3521>,
    <3642, 3521, 3643>,
    <3648, 3635, 3634>,
    <3648, 3634, 3643>,
    <3648, 3643, 3521>,
    <3648, 3521, 3520>,
    <3648, 3520, 3649>,
    <3648, 3649, 3650>,
    <3648, 3650, 3636>,
    <3648, 3636, 3635>,
    <3651, 3652, 3653>,
    <3651, 3653, 3654>,
    <3651, 3654, 3655>,
    <3651, 3655, 3656>,
    <3651, 3656, 3657>,
    <3651, 3657, 3658>,
    <3651, 3659, 3660>,
    <3651, 3660, 3652>,
    <3661, 3662, 3653>,
    <3661, 3653, 3652>,
    <3661, 3652, 3663>,
    <3661, 3663, 3664>,
    <3661, 3665, 3666>,
    <3661, 3666, 3667>,
    <3661, 3667, 3668>,
    <3661, 3668, 3662>,
    <3669, 3654, 3653>,
    <3669, 3653, 3662>,
    <3669, 3662, 3668>,
    <3669, 3668, 3670>,
    <3669, 3670, 3671>,
    <3669, 3671, 3672>,
    <3669, 3672, 3655>,
    <3669, 3655, 3654>,
    <3673, 3674, 3675>,
    <3673, 3675, 3676>,
    <3673, 3676, 3668>,
    <3673, 3668, 3667>,
    <3673, 3667, 3677>,
    <3673, 3677, 3581>,
    <3673, 3581, 3578>,
    <3673, 3578, 3674>,
    <3678, 3679, 3675>,
    <3678, 3675, 3674>,
    <3678, 3674, 3578>,
    <3678, 3578, 3577>,
    <3678, 3577, 3680>,
    <3678, 3680, 3681>,
    <3678, 3682, 3683>,
    <3678, 3683, 3679>,
    <3684, 3676, 3675>,
    <3684, 3675, 3679>,
    <3684, 3679, 3685>,
    <3684, 3685, 3686>,
    <3684, 3687, 3688>,
    <3684, 3688, 3670>,
    <3684, 3670, 3668>,
    <3684, 3668, 3676>,
    <3689, 3690, 3691>,
    <3689, 3691, 3692>,
    <3689, 3692, 3693>,
    <3689, 3693, 3694>,
    <3689, 3695, 3696>,
    <3689, 3696, 3605>,
    <3689, 3605, 3602>,
    <3689, 3602, 3690>,
    <3697, 3698, 3691>,
    <3697, 3691, 3690>,
    <3697, 3690, 3602>,
    <3697, 3602, 3601>,
    <3697, 3601, 3699>,
    <3697, 3699, 3700>,
    <3697, 3700, 3701>,
    <3697, 3701, 3698>,
    <3702, 3692, 3691>,
    <3702, 3691, 3698>,
    <3702, 3698, 3701>,
    <3702, 3701, 3703>,
    <3702, 3703, 3704>,
    <3702, 3704, 3705>,
    <3702, 3706, 3707>,
    <3702, 3707, 3692>,
    <3708, 3709, 3710>,
    <3708, 3710, 3711>,
    <3708, 3711, 3712>,
    <3708, 3712, 3713>,
    <3708, 3714, 3715>,
    <3708, 3715, 3656>,
    <3708, 3656, 3655>,
    <3708, 3655, 3709>,
    <3716, 3717, 3710>,
    <3716, 3710, 3709>,
    <3716, 3709, 3655>,
    <3716, 3655, 3672>,
    <3716, 3672, 3718>,
    <3716, 3718, 3719>,
    <3716, 3719, 3720>,
    <3716, 3720, 3717>,
    <3721, 3711, 3710>,
    <3721, 3710, 3717>,
    <3721, 3717, 3720>,
    <3721, 3720, 3722>,
    <3721, 3722, 3723>,
    <3721, 3723, 3724>,
    <3721, 3725, 3726>,
    <3721, 3726, 3711>,
    <3727, 3728, 3729>,
    <3727, 3729, 3730>,
    <3727, 3730, 3731>,
    <3727, 3731, 3732>,
    <3727, 3733, 3734>,
    <3727, 3734, 3735>,
    <3727, 3735, 3736>,
    <3727, 3736, 3728>,
    <3737, 3738, 3729>,
    <3737, 3729, 3728>,
    <3737, 3728, 3736>,
    <3737, 3736, 3739>,
    <3737, 3739, 3740>,
    <3737, 3740, 3703>,
    <3737, 3703, 3701>,
    <3737, 3701, 3738>,
    <3741, 3730, 3729>,
    <3741, 3729, 3738>,
    <3741, 3738, 3701>,
    <3741, 3701, 3700>,
    <3741, 3700, 3742>,
    <3741, 3742, 3743>,
    <3741, 3744, 3745>,
    <3741, 3745, 3730>,
    <3746, 3747, 3748>,
    <3746, 3748, 3749>,
    <3746, 3749, 3750>,
    <3746, 3750, 3751>,
    <3746, 3752, 3753>,
    <3746, 3753, 3754>,
    <3746, 3755, 3756>,
    <3746, 3756, 3747>,
    <3757, 3758, 3748>,
    <3757, 3748, 3747>,
    <3757, 3747, 3759>,
    <3757, 3759, 3760>,
    <3757, 3761, 3762>,
    <3757, 3762, 3763>,
    <3757, 3764, 3765>,
    <3757, 3765, 3758>,
    <3766, 3749, 3748>,
    <3766, 3748, 3758>,
    <3766, 3758, 3767>,
    <3766, 3767, 3768>,
    <3766, 3769, 3770>,
    <3766, 3770, 3771>,
    <3766, 3772, 3773>,
    <3766, 3773, 3749>,
    <3774, 3775, 3776>,
    <3774, 3776, 3777>,
    <3774, 3777, 3778>,
    <3774, 3778, 3779>,
    <3774, 3779, 3780>,
    <3774, 3780, 3781>,
    <3774, 3782, 3783>,
    <3774, 3783, 3775>,
    <3784, 3785, 3776>,
    <3784, 3776, 3775>,
    <3784, 3775, 3786>,
    <3784, 3786, 3787>,
    <3784, 3788, 3789>,
    <3784, 3789, 3722>,
    <3784, 3722, 3720>,
    <3784, 3720, 3785>,
    <3790, 3777, 3776>,
    <3790, 3776, 3785>,
    <3790, 3785, 3720>,
    <3790, 3720, 3719>,
    <3790, 3719, 3791>,
    <3790, 3791, 3792>,
    <3790, 3792, 3778>,
    <3790, 3778, 3777>,
    <3793, 3794, 3795>,
    <3793, 3795, 3796>,
    <3793, 3796, 3797>,
    <3793, 3797, 3798>,
    <3793, 3799, 3800>,
    <3793, 3800, 3801>,
    <3793, 3801, 3802>,
    <3793, 3802, 3794>,
    <3803, 3804, 3795>,
    <3803, 3795, 3794>,
    <3803, 3794, 3802>,
    <3803, 3802, 3805>,
    <3803, 3805, 3806>,
    <3803, 3806, 3464>,
    <3803, 3464, 3461>,
    <3803, 3461, 3804>,
    <3807, 3796, 3795>,
    <3807, 3795, 3804>,
    <3807, 3804, 3461>,
    <3807, 3461, 3460>,
    <3807, 3460, 3808>,
    <3807, 3808, 3809>,
    <3807, 3810, 3811>,
    <3807, 3811, 3796>,
    <3812, 3813, 3814>,
    <3812, 3814, 3815>,
    <3812, 3815, 3802>,
    <3812, 3802, 3801>,
    <3812, 3801, 3816>,
    <3812, 3816, 3817>,
    <3812, 3817, 3818>,
    <3812, 3818, 3813>,
    <3819, 3820, 3814>,
    <3819, 3814, 3813>,
    <3819, 3813, 3818>,
    <3819, 3818, 3821>,
    <3819, 3821, 3822>,
    <3819, 3822, 3823>,
    <3819, 3824, 3825>,
    <3819, 3825, 3820>,
    <3826, 3815, 3814>,
    <3826, 3814, 3820>,
    <3826, 3820, 3827>,
    <3826, 3827, 3828>,
    <3826, 3829, 3830>,
    <3826, 3830, 3805>,
    <3826, 3805, 3802>,
    <3826, 3802, 3815>,
    <3831, 3832, 3833>,
    <3831, 3833, 3834>,
    <3831, 3834, 3835>,
    <3831, 3835, 3836>,
    <3831, 3837, 3838>,
    <3831, 3838, 3839>,
    <3831, 3839, 3840>,
    <3831, 3840, 3832>,
    <3841, 3842, 3833>,
    <3841, 3833, 3832>,
    <3841, 3832, 3840>,
    <3841, 3840, 3843>,
    <3841, 3843, 3844>,
    <3841, 3844, 3821>,
    <3841, 3821, 3818>,
    <3841, 3818, 3842>,
    <3845, 3834, 3833>,
    <3845, 3833, 3842>,
    <3845, 3842, 3818>,
    <3845, 3818, 3817>,
    <3845, 3817, 3846>,
    <3845, 3846, 3847>,
    <3845, 3848, 3849>,
    <3845, 3849, 3834>,
    <3850, 3851, 3852>,
    <3850, 3852, 3853>,
    <3850, 3853, 3854>,
    <3850, 3854, 3855>,
    <3850, 3855, 3856>,
    <3850, 3856, 3857>,
    <3850, 3858, 3859>,
    <3850, 3859, 3851>,
    <3860, 3861, 3852>,
    <3860, 3852, 3851>,
    <3860, 3851, 3862>,
    <3860, 3862, 3863>,
    <3860, 3864, 3865>,
    <3860, 3865, 3866>,
    <3860, 3866, 3867>,
    <3860, 3867, 3861>,
    <3868, 3853, 3852>,
    <3868, 3852, 3861>,
    <3868, 3861, 3867>,
    <3868, 3867, 3869>,
    <3868, 3869, 3870>,
    <3868, 3870, 3871>,
    <3868, 3871, 3854>,
    <3868, 3854, 3853>,
    <3872, 3873, 3874>,
    <3872, 3874, 3875>,
    <3872, 3875, 3867>,
    <3872, 3867, 3866>,
    <3872, 3866, 3876>,
    <3872, 3876, 3637>,
    <3872, 3637, 3636>,
    <3872, 3636, 3873>,
    <3877, 3878, 3874>,
    <3877, 3874, 3873>,
    <3877, 3873, 3636>,
    <3877, 3636, 3650>,
    <3877, 3650, 3879>,
    <3877, 3879, 3880>,
    <3877, 3881, 3882>,
    <3877, 3882, 3878>,
    <3883, 3875, 3874>,
    <3883, 3874, 3878>,
    <3883, 3878, 3884>,
    <3883, 3884, 3885>,
    <3883, 3886, 3887>,
    <3883, 3887, 3869>,
    <3883, 3869, 3867>,
    <3883, 3867, 3875>,
    <3888, 3889, 3890>,
    <3888, 3890, 3891>,
    <3888, 3891, 3892>,
    <3888, 3892, 3893>,
    <3888, 3894, 3895>,
    <3888, 3895, 3855>,
    <3888, 3855, 3854>,
    <3888, 3854, 3889>,
    <3896, 3897, 3890>,
    <3896, 3890, 3889>,
    <3896, 3889, 3854>,
    <3896, 3854, 3871>,
    <3896, 3871, 3898>,
    <3896, 3898, 3899>,
    <3896, 3899, 3900>,
    <3896, 3900, 3897>,
    <3901, 3891, 3890>,
    <3901, 3890, 3897>,
    <3901, 3897, 3900>,
    <3901, 3900, 3902>,
    <3901, 3902, 3903>,
    <3901, 3903, 3904>,
    <3901, 3905, 3906>,
    <3901, 3906, 3891>,
    <3907, 3908, 3909>,
    <3907, 3909, 3910>,
    <3907, 3910, 3911>,
    <3907, 3911, 3912>,
    <3907, 3913, 3914>,
    <3907, 3914, 3915>,
    <3907, 3915, 3916>,
    <3907, 3916, 3908>,
    <3917, 3918, 3909>,
    <3917, 3909, 3908>,
    <3917, 3908, 3916>,
    <3917, 3916, 3919>,
    <3917, 3919, 3920>,
    <3917, 3920, 3739>,
    <3917, 3739, 3736>,
    <3917, 3736, 3918>,
    <3921, 3910, 3909>,
    <3921, 3909, 3918>,
    <3921, 3918, 3736>,
    <3921, 3736, 3735>,
    <3921, 3735, 3922>,
    <3921, 3922, 3923>,
    <3921, 3924, 3925>,
    <3921, 3925, 3910>,
    <3926, 3927, 3928>,
    <3926, 3928, 3929>,
    <3926, 3929, 3930>,
    <3926, 3930, 3931>,
    <3926, 3932, 3933>,
    <3926, 3933, 3934>,
    <3926, 3935, 3936>,
    <3926, 3936, 3927>,
    <3937, 3938, 3928>,
    <3937, 3928, 3927>,
    <3937, 3927, 3939>,
    <3937, 3939, 3940>,
    <3937, 3941, 3942>,
    <3937, 3942, 3779>,
    <3937, 3779, 3778>,
    <3937, 3778, 3938>,
    <3943, 3929, 3928>,
    <3943, 3928, 3938>,
    <3943, 3938, 3778>,
    <3943, 3778, 3792>,
    <3943, 3792, 3944>,
    <3943, 3944, 3945>,
    <3943, 3946, 3947>,
    <3943, 3947, 3929>,
    <3948, 3949, 3950>,
    <3948, 3950, 3951>,
    <3948, 3951, 3916>,
    <3948, 3916, 3915>,
    <3948, 3915, 3952>,
    <3948, 3952, 3953>,
    <3948, 3954, 3955>,
    <3948, 3955, 3949>,
    <3956, 3957, 3950>,
    <3956, 3950, 3949>,
    <3956, 3949, 3958>,
    <3956, 3958, 3959>,
    <3956, 3960, 3961>,
    <3956, 3961, 3962>,
    <3956, 3962, 3963>,
    <3956, 3963, 3957>,
    <3964, 3951, 3950>,
    <3964, 3950, 3957>,
    <3964, 3957, 3963>,
    <3964, 3963, 3965>,
    <3964, 3965, 3966>,
    <3964, 3966, 3919>,
    <3964, 3919, 3916>,
    <3964, 3916, 3951>,
    <3967, 3968, 3969>,
    <3967, 3969, 3970>,
    <3967, 3970, 3963>,
    <3967, 3963, 3962>,
    <3967, 3962, 3971>,
    <3967, 3971, 3972>,
    <3967, 3972, 3973>,
    <3967, 3973, 3968>,
    <3974, 3975, 3969>,
    <3974, 3969, 3968>,
    <3974, 3968, 3973>,
    <3974, 3973, 3976>,
    <3974, 3976, 3977>,
    <3974, 3977, 3978>,
    <3974, 3979, 3980>,
    <3974, 3980, 3975>,
    <3981, 3970, 3969>,
    <3981, 3969, 3975>,
    <3981, 3975, 3982>,
    <3981, 3982, 3983>,
    <3981, 3984, 3985>,
    <3981, 3985, 3965>,
    <3981, 3965, 3963>,
    <3981, 3963, 3970>,
    <3986, 3987, 3988>,
    <3986, 3988, 3989>,
    <3986, 3989, 3990>,
    <3986, 3990, 3991>,
    <3986, 3992, 3993>,
    <3986, 3993, 3994>,
    <3986, 3994, 3995>,
    <3986, 3995, 3987>,
    <3996, 3997, 3988>,
    <3996, 3988, 3987>,
    <3996, 3987, 3995>,
    <3996, 3995, 3998>,
    <3996, 3998, 3999>,
    <3996, 3999, 4000>,
    <3996, 4001, 4002>,
    <3996, 4002, 3997>,
    <4003, 3989, 3988>,
    <4003, 3988, 3997>,
    <4003, 3997, 4004>,
    <4003, 4004, 4005>,
    <4003, 4006, 4007>,
    <4003, 4007, 4008>,
    <4003, 4009, 4010>,
    <4003, 4010, 3989>,
    <4011, 4012, 4013>,
    <4011, 4013, 4014>,
    <4011, 4014, 4015>,
    <4011, 4015, 4016>,
    <4011, 4016, 4017>,
    <4011, 4017, 3998>,
    <4011, 3998, 3995>,
    <4011, 3995, 4012>,
    <4018, 4019, 4013>,
    <4018, 4013, 4012>,
    <4018, 4012, 3995>,
    <4018, 3995, 3994>,
    <4018, 3994, 4020>,
    <4018, 4020, 4021>,
    <4018, 4022, 4023>,
    <4018, 4023, 4019>,
    <4024, 4014, 4013>,
    <4024, 4013, 4019>,
    <4024, 4019, 4025>,
    <4024, 4025, 4026>,
    <4024, 4027, 4028>,
    <4024, 4028, 4029>,
    <4024, 4029, 4015>,
    <4024, 4015, 4014>,
    <4030, 4031, 4032>,
    <4030, 4032, 4033>,
    <4030, 4033, 4034>,
    <4030, 4034, 4035>,
    <4030, 4036, 4037>,
    <4030, 4037, 4038>,
    <4030, 4038, 4039>,
    <4030, 4039, 4031>,
    <4040, 4041, 4032>,
    <4040, 4032, 4031>,
    <4040, 4031, 4039>,
    <4040, 4039, 4042>,
    <4040, 4042, 4043>,
    <4040, 4043, 4044>,
    <4040, 4044, 4045>,
    <4040, 4045, 4041>,
    <4046, 4033, 4032>,
    <4046, 4032, 4041>,
    <4046, 4041, 4045>,
    <4046, 4045, 4047>,
    <4046, 4047, 4048>,
    <4046, 4048, 4049>,
    <4046, 4050, 4051>,
    <4046, 4051, 4033>,
    <4052, 4053, 4054>,
    <4052, 4054, 4055>,
    <4052, 4055, 4056>,
    <4052, 4056, 4057>,
    <4052, 4058, 4059>,
    <4052, 4059, 3976>,
    <4052, 3976, 3973>,
    <4052, 3973, 4053>,
    <4060, 4061, 4054>,
    <4060, 4054, 4053>,
    <4060, 4053, 3973>,
    <4060, 3973, 3972>,
    <4060, 3972, 4062>,
    <4060, 4062, 4047>,
    <4060, 4047, 4045>,
    <4060, 4045, 4061>,
    <4063, 4055, 4054>,
    <4063, 4054, 4061>,
    <4063, 4061, 4045>,
    <4063, 4045, 4044>,
    <4063, 4044, 4064>,
    <4063, 4064, 4065>,
    <4063, 4066, 4067>,
    <4063, 4067, 4055>,
    <4068, 4069, 4070>,
    <4068, 4070, 4071>,
    <4068, 4071, 4072>,
    <4068, 4072, 4073>,
    <4068, 4074, 4075>,
    <4068, 4075, 4016>,
    <4068, 4016, 4015>,
    <4068, 4015, 4069>,
    <4076, 4077, 4070>,
    <4076, 4070, 4069>,
    <4076, 4069, 4015>,
    <4076, 4015, 4029>,
    <4076, 4029, 4078>,
    <4076, 4078, 4079>,
    <4076, 4079, 4080>,
    <4076, 4080, 4077>,
    <4081, 4071, 4070>,
    <4081, 4070, 4077>,
    <4081, 4077, 4080>,
    <4081, 4080, 4082>,
    <4081, 4082, 4083>,
    <4081, 4083, 4084>,
    <4081, 4085, 4086>,
    <4081, 4086, 4071>,
    <4087, 4088, 4089>,
    <4087, 4089, 4090>,
    <4087, 4090, 4091>,
    <4087, 4091, 4092>,
    <4087, 4093, 4094>,
    <4087, 4094, 4095>,
    <4087, 4095, 4096>,
    <4087, 4096, 4088>,
    <4097, 4098, 4089>,
    <4097, 4089, 4088>,
    <4097, 4088, 4096>,
    <4097, 4096, 4099>,
    <4097, 4099, 4100>,
    <4097, 4100, 4042>,
    <4097, 4042, 4039>,
    <4097, 4039, 4098>,
    <4101, 4090, 4089>,
    <4101, 4089, 4098>,
    <4101, 4098, 4039>,
    <4101, 4039, 4038>,
    <4101, 4038, 4102>,
    <4101, 4102, 4103>,
    <4101, 4104, 4105>,
    <4101, 4105, 4090>,
    <4106, 4107, 4108>,
    <4106, 4108, 4109>,
    <4106, 4109, 4110>,
    <4106, 4110, 4111>,
    <4106, 4112, 4113>,
    <4106, 4113, 4114>,
    <4106, 4115, 4116>,
    <4106, 4116, 4107>,
    <4117, 4118, 4108>,
    <4117, 4108, 4107>,
    <4117, 4107, 4119>,
    <4117, 4119, 4120>,
    <4117, 4121, 4122>,
    <4117, 4122, 4123>,
    <4117, 4124, 4125>,
    <4117, 4125, 4118>,
    <4126, 4109, 4108>,
    <4126, 4108, 4118>,
    <4126, 4118, 4127>,
    <4126, 4127, 4128>,
    <4126, 4129, 4130>,
    <4126, 4130, 4131>,
    <4126, 4132, 4133>,
    <4126, 4133, 4109>,
    <4134, 4135, 4136>,
    <4134, 4136, 4137>,
    <4134, 4137, 4138>,
    <4134, 4138, 4139>,
    <4134, 4140, 4141>,
    <4134, 4141, 4142>,
    <4134, 4142, 4143>,
    <4134, 4143, 4135>,
    <4144, 4145, 4136>,
    <4144, 4136, 4135>,
    <4144, 4135, 4143>,
    <4144, 4143, 4146>,
    <4144, 4146, 4147>,
    <4144, 4147, 3843>,
    <4144, 3843, 3840>,
    <4144, 3840, 4145>,
    <4148, 4137, 4136>,
    <4148, 4136, 4145>,
    <4148, 4145, 3840>,
    <4148, 3840, 3839>,
    <4148, 3839, 4149>,
    <4148, 4149, 4150>,
    <4148, 4151, 4152>,
    <4148, 4152, 4137>,
    <4153, 4154, 4155>,
    <4153, 4155, 4156>,
    <4153, 4156, 4143>,
    <4153, 4143, 4142>,
    <4153, 4142, 4157>,
    <4153, 4157, 4158>,
    <4153, 4158, 4159>,
    <4153, 4159, 4154>,
    <4160, 4161, 4155>,
    <4160, 4155, 4154>,
    <4160, 4154, 4159>,
    <4160, 4159, 4162>,
    <4160, 4162, 4163>,
    <4160, 4163, 4164>,
    <4160, 4165, 4166>,
    <4160, 4166, 4161>,
    <4167, 4156, 4155>,
    <4167, 4155, 4161>,
    <4167, 4161, 4168>,
    <4167, 4168, 4169>,
    <4167, 4170, 4171>,
    <4167, 4171, 4146>,
    <4167, 4146, 4143>,
    <4167, 4143, 4156>,
    <4172, 4173, 4174>,
    <4172, 4174, 4175>,
    <4172, 4175, 4176>,
    <4172, 4176, 4177>,
    <4172, 4178, 4179>,
    <4172, 4179, 4180>,
    <4172, 4180, 4181>,
    <4172, 4181, 4173>,
    <4182, 4183, 4174>,
    <4182, 4174, 4173>,
    <4182, 4173, 4181>,
    <4182, 4181, 4184>,
    <4182, 4184, 4185>,
    <4182, 4185, 4162>,
    <4182, 4162, 4159>,
    <4182, 4159, 4183>,
    <4186, 4175, 4174>,
    <4186, 4174, 4183>,
    <4186, 4183, 4159>,
    <4186, 4159, 4158>,
    <4186, 4158, 4187>,
    <4186, 4187, 4188>,
    <4186, 4189, 4190>,
    <4186, 4190, 4175>,
    <4191, 4192, 4193>,
    <4191, 4193, 4194>,
    <4191, 4194, 4195>,
    <4191, 4195, 4196>,
    <4191, 4197, 4198>,
    <4191, 4198, 4199>,
    <4191, 4199, 4200>,
    <4191, 4200, 4192>,
    <4201, 4202, 4193>,
    <4201, 4193, 4192>,
    <4201, 4192, 4200>,
    <4201, 4200, 4203>,
    <4201, 4203, 4204>,
    <4201, 4204, 4205>,
    <4201, 4205, 4206>,
    <4201, 4206, 4202>,
    <4207, 4194, 4193>,
    <4207, 4193, 4202>,
    <4207, 4202, 4206>,
    <4207, 4206, 4208>,
    <4207, 4208, 4209>,
    <4207, 4209, 4210>,
    <4207, 4211, 4212>,
    <4207, 4212, 4194>,
    <4213, 4214, 4215>,
    <4213, 4215, 4216>,
    <4213, 4216, 4200>,
    <4213, 4200, 4199>,
    <4213, 4199, 4217>,
    <4213, 4217, 3902>,
    <4213, 3902, 3900>,
    <4213, 3900, 4214>,
    <4218, 4219, 4215>,
    <4218, 4215, 4214>,
    <4218, 4214, 3900>,
    <4218, 3900, 3899>,
    <4218, 3899, 4220>,
    <4218, 4220, 4221>,
    <4218, 4222, 4223>,
    <4218, 4223, 4219>,
    <4224, 4216, 4215>,
    <4224, 4215, 4219>,
    <4224, 4219, 4225>,
    <4224, 4225, 4226>,
    <4224, 4227, 4228>,
    <4224, 4228, 4203>,
    <4224, 4203, 4200>,
    <4224, 4200, 4216>,
    <4229, 4230, 4231>,
    <4229, 4231, 4232>,
    <4229, 4232, 4233>,
    <4229, 4233, 4234>,
    <4229, 4235, 4236>,
    <4229, 4236, 4208>,
    <4229, 4208, 4206>,
    <4229, 4206, 4230>,
    <4237, 4238, 4231>,
    <4237, 4231, 4230>,
    <4237, 4230, 4206>,
    <4237, 4206, 4205>,
    <4237, 4205, 4239>,
    <4237, 4239, 4240>,
    <4237, 4240, 4241>,
    <4237, 4241, 4238>,
    <4242, 4232, 4231>,
    <4242, 4231, 4238>,
    <4242, 4238, 4241>,
    <4242, 4241, 4243>,
    <4242, 4243, 4244>,
    <4242, 4244, 4245>,
    <4242, 4246, 4247>,
    <4242, 4247, 4232>,
    <4248, 4249, 4250>,
    <4248, 4250, 4251>,
    <4248, 4251, 4252>,
    <4248, 4252, 4253>,
    <4248, 4254, 4255>,
    <4248, 4255, 4256>,
    <4248, 4256, 4257>,
    <4248, 4257, 4249>,
    <4258, 4259, 4250>,
    <4258, 4250, 4249>,
    <4258, 4249, 4257>,
    <4258, 4257, 4260>,
    <4258, 4260, 4261>,
    <4258, 4261, 4082>,
    <4258, 4082, 4080>,
    <4258, 4080, 4259>,
    <4262, 4251, 4250>,
    <4262, 4250, 4259>,
    <4262, 4259, 4080>,
    <4262, 4080, 4079>,
    <4262, 4079, 4263>,
    <4262, 4263, 4264>,
    <4262, 4265, 4266>,
    <4262, 4266, 4251>,
    <4267, 4268, 4269>,
    <4267, 4269, 4270>,
    <4267, 4270, 4257>,
    <4267, 4257, 4256>,
    <4267, 4256, 4271>,
    <4267, 4271, 4272>,
    <4267, 4272, 4273>,
    <4267, 4273, 4268>,
    <4274, 4275, 4269>,
    <4274, 4269, 4268>,
    <4274, 4268, 4273>,
    <4274, 4273, 4276>,
    <4274, 4276, 4277>,
    <4274, 4277, 4278>,
    <4274, 4279, 4280>,
    <4274, 4280, 4275>,
    <4281, 4270, 4269>,
    <4281, 4269, 4275>,
    <4281, 4275, 4282>,
    <4281, 4282, 4283>,
    <4281, 4284, 4285>,
    <4281, 4285, 4260>,
    <4281, 4260, 4257>,
    <4281, 4257, 4270>,
    <4286, 4287, 4288>,
    <4286, 4288, 4289>,
    <4286, 4289, 4290>,
    <4286, 4290, 4291>,
    <4286, 4291, 4292>,
    <4286, 4292, 4293>,
    <4286, 4293, 4294>,
    <4286, 4294, 4287>,
    <4295, 4296, 4288>,
    <4295, 4288, 4287>,
    <4295, 4287, 4294>,
    <4295, 4294, 4297>,
    <4295, 4297, 4298>,
    <4295, 4298, 4299>,
    <4295, 4300, 4301>,
    <4295, 4301, 4296>,
    <4302, 4289, 4288>,
    <4302, 4288, 4296>,
    <4302, 4296, 4303>,
    <4302, 4303, 4304>,
    <4302, 4305, 4306>,
    <4302, 4306, 4307>,
    <4302, 4307, 4290>,
    <4302, 4290, 4289>,
    <4308, 4309, 4310>,
    <4308, 4310, 4311>,
    <4308, 4311, 4312>,
    <4308, 4312, 4313>,
    <4308, 4314, 4315>,
    <4308, 4315, 4291>,
    <4308, 4291, 4290>,
    <4308, 4290, 4309>,
    <4316, 4317, 4310>,
    <4316, 4310, 4309>,
    <4316, 4309, 4290>,
    <4316, 4290, 4307>,
    <4316, 4307, 4318>,
    <4316, 4318, 4099>,
    <4316, 4099, 4096>,
    <4316, 4096, 4317>,
    <4319, 4311, 4310>,
    <4319, 4310, 4317>,
    <4319, 4317, 4096>,
    <4319, 4096, 4095>,
    <4319, 4095, 4320>,
    <4319, 4320, 4321>,
    <4319, 4322, 4323>,
    <4319, 4323, 4311>,
    <4324, 4325, 4326>,
    <4324, 4326, 4327>,
    <4324, 4327, 4328>,
    <4324, 4328, 4329>,
    <4324, 4329, 4330>,
    <4324, 4330, 4331>,
    <4324, 4332, 4333>,
    <4324, 4333, 4325>,
    <4334, 4335, 4326>,
    <4334, 4326, 4325>,
    <4334, 4325, 4336>,
    <4334, 4336, 4337>,
    <4334, 4338, 4339>,
    <4334, 4339, 4340>,
    <4334, 4340, 4341>,
    <4334, 4341, 4335>,
    <4342, 4327, 4326>,
    <4342, 4326, 4335>,
    <4342, 4335, 4341>,
    <4342, 4341, 4343>,
    <4342, 4343, 4344>,
    <4342, 4344, 4345>,
    <4342, 4345, 4328>,
    <4342, 4328, 4327>,
    <4346, 4347, 4348>,
    <4346, 4348, 4349>,
    <4346, 4349, 4341>,
    <4346, 4341, 4340>,
    <4346, 4340, 4350>,
    <4346, 4350, 4276>,
    <4346, 4276, 4273>,
    <4346, 4273, 4347>,
    <4351, 4352, 4348>,
    <4351, 4348, 4347>,
    <4351, 4347, 4273>,
    <4351, 4273, 4272>,
    <4351, 4272, 4353>,
    <4351, 4353, 4354>,
    <4351, 4355, 4356>,
    <4351, 4356, 4352>,
    <4357, 4349, 4348>,
    <4357, 4348, 4352>,
    <4357, 4352, 4358>,
    <4357, 4358, 4359>,
    <4357, 4360, 4361>,
    <4357, 4361, 4343>,
    <4357, 4343, 4341>,
    <4357, 4341, 4349>,
    <4362, 4363, 4364>,
    <4362, 4364, 4365>,
    <4362, 4365, 4366>,
    <4362, 4366, 4367>,
    <4362, 4368, 4369>,
    <4362, 4369, 4297>,
    <4362, 4297, 4294>,
    <4362, 4294, 4363>,
    <4370, 4371, 4364>,
    <4370, 4364, 4363>,
    <4370, 4363, 4294>,
    <4370, 4294, 4293>,
    <4370, 4293, 4372>,
    <4370, 4372, 4373>,
    <4370, 4373, 4374>,
    <4370, 4374, 4371>,
    <4375, 4365, 4364>,
    <4375, 4364, 4371>,
    <4375, 4371, 4374>,
    <4375, 4374, 4376>,
    <4375, 4376, 4377>,
    <4375, 4377, 4378>,
    <4375, 4379, 4380>,
    <4375, 4380, 4365>,
    <4381, 4382, 4383>,
    <4381, 4383, 4384>,
    <4381, 4384, 4385>,
    <4381, 4385, 4386>,
    <4381, 4387, 4388>,
    <4381, 4388, 4329>,
    <4381, 4329, 4328>,
    <4381, 4328, 4382>,
    <4389, 4390, 4383>,
    <4389, 4383, 4382>,
    <4389, 4382, 4328>,
    <4389, 4328, 4345>,
    <4389, 4345, 4391>,
    <4389, 4391, 4392>,
    <4389, 4392, 4393>,
    <4389, 4393, 4390>,
    <4394, 4384, 4383>,
    <4394, 4383, 4390>,
    <4394, 4390, 4393>,
    <4394, 4393, 4395>,
    <4394, 4395, 4396>,
    <4394, 4396, 4397>,
    <4394, 4398, 4399>,
    <4394, 4399, 4384>,
    <4400, 4401, 4402>,
    <4400, 4402, 4403>,
    <4400, 4403, 4404>,
    <4400, 4404, 4405>,
    <4400, 4406, 4407>,
    <4400, 4407, 4408>,
    <4400, 4408, 4409>,
    <4400, 4409, 4401>,
    <4410, 4411, 4402>,
    <4410, 4402, 4401>,
    <4410, 4401, 4409>,
    <4410, 4409, 4412>,
    <4410, 4412, 4413>,
    <4410, 4413, 4376>,
    <4410, 4376, 4374>,
    <4410, 4374, 4411>,
    <4414, 4403, 4402>,
    <4414, 4402, 4411>,
    <4414, 4411, 4374>,
    <4414, 4374, 4373>,
    <4414, 4373, 4415>,
    <4414, 4415, 4416>,
    <4414, 4417, 4418>,
    <4414, 4418, 4403>,
    <4419, 4420, 4421>,
    <4419, 4421, 4422>,
    <4419, 4422, 4423>,
    <4419, 4423, 4424>,
    <4419, 4424, 4425>,
    <4419, 4425, 4426>,
    <4419, 4427, 4428>,
    <4419, 4428, 4420>,
    <4429, 4430, 4421>,
    <4429, 4421, 4420>,
    <4429, 4420, 4431>,
    <4429, 4431, 4432>,
    <4429, 4433, 4434>,
    <4429, 4434, 4395>,
    <4429, 4395, 4393>,
    <4429, 4393, 4430>,
    <4435, 4422, 4421>,
    <4435, 4421, 4430>,
    <4435, 4430, 4393>,
    <4435, 4393, 4392>,
    <4435, 4392, 4436>,
    <4435, 4436, 4437>,
    <4435, 4437, 4423>,
    <4435, 4423, 4422>,
    <4438, 4439, 4440>,
    <4438, 4440, 4441>,
    <4438, 4441, 4442>,
    <4438, 4442, 4443>,
    <4438, 4443, 4444>,
    <4438, 4444, 4445>,
    <4438, 4446, 4447>,
    <4438, 4447, 4439>,
    <4448, 4449, 4440>,
    <4448, 4440, 4439>,
    <4448, 4439, 4450>,
    <4448, 4450, 4451>,
    <4448, 4452, 4453>,
    <4448, 4453, 4243>,
    <4448, 4243, 4241>,
    <4448, 4241, 4449>,
    <4454, 4441, 4440>,
    <4454, 4440, 4449>,
    <4454, 4449, 4241>,
    <4454, 4241, 4240>,
    <4454, 4240, 4455>,
    <4454, 4455, 4456>,
    <4454, 4456, 4442>,
    <4454, 4442, 4441>,
    <4457, 4458, 4459>,
    <4457, 4459, 4460>,
    <4457, 4460, 4461>,
    <4457, 4461, 4462>,
    <4457, 4463, 4464>,
    <4457, 4464, 4465>,
    <4457, 4465, 4466>,
    <4457, 4466, 4458>,
    <4467, 4468, 4459>,
    <4467, 4459, 4458>,
    <4467, 4458, 4466>,
    <4467, 4466, 4469>,
    <4467, 4469, 4470>,
    <4467, 4470, 4412>,
    <4467, 4412, 4409>,
    <4467, 4409, 4468>,
    <4471, 4460, 4459>,
    <4471, 4459, 4468>,
    <4471, 4468, 4409>,
    <4471, 4409, 4408>,
    <4471, 4408, 4472>,
    <4471, 4472, 4473>,
    <4471, 4474, 4475>,
    <4471, 4475, 4460>,
    <4476, 4477, 4478>,
    <4476, 4478, 4479>,
    <4476, 4479, 4480>,
    <4476, 4480, 4481>,
    <4476, 4482, 4483>,
    <4476, 4483, 4484>,
    <4476, 4484, 4485>,
    <4476, 4485, 4477>,
    <4486, 4487, 4478>,
    <4486, 4478, 4477>,
    <4486, 4477, 4485>,
    <4486, 4485, 4488>,
    <4486, 4488, 4489>,
    <4486, 4489, 4184>,
    <4486, 4184, 4181>,
    <4486, 4181, 4487>,
    <4490, 4479, 4478>,
    <4490, 4478, 4487>,
    <4490, 4487, 4181>,
    <4490, 4181, 4180>,
    <4490, 4180, 4491>,
    <4490, 4491, 4492>,
    <4490, 4493, 4494>,
    <4490, 4494, 4479>,
    <4495, 4496, 4497>,
    <4495, 4497, 4498>,
    <4495, 4498, 4499>,
    <4495, 4499, 4500>,
    <4495, 4501, 4502>,
    <4495, 4502, 4503>,
    <4495, 4504, 4505>,
    <4495, 4505, 4496>,
    <4506, 4507, 4497>,
    <4506, 4497, 4496>,
    <4506, 4496, 4508>,
    <4506, 4508, 4509>,
    <4506, 4510, 4511>,
    <4506, 4511, 4424>,
    <4506, 4424, 4423>,
    <4506, 4423, 4507>,
    <4512, 4498, 4497>,
    <4512, 4497, 4507>,
    <4512, 4507, 4423>,
    <4512, 4423, 4437>,
    <4512, 4437, 4513>,
    <4512, 4513, 4514>,
    <4512, 4515, 4516>,
    <4512, 4516, 4498>,
    <4517, 4518, 4519>,
    <4517, 4519, 4520>,
    <4517, 4520, 4485>,
    <4517, 4485, 4484>,
    <4517, 4484, 4521>,
    <4517, 4521, 4522>,
    <4517, 4522, 4523>,
    <4517, 4523, 4518>,
    <4524, 4525, 4519>,
    <4524, 4519, 4518>,
    <4524, 4518, 4523>,
    <4524, 4523, 4526>,
    <4524, 4526, 4527>,
    <4524, 4527, 4528>,
    <4524, 4529, 4530>,
    <4524, 4530, 4525>,
    <4531, 4520, 4519>,
    <4531, 4519, 4525>,
    <4531, 4525, 4532>,
    <4531, 4532, 4533>,
    <4531, 4534, 4535>,
    <4531, 4535, 4488>,
    <4531, 4488, 4485>,
    <4531, 4485, 4520>,
    <4536, 4537, 4538>,
    <4536, 4538, 4539>,
    <4536, 4539, 4540>,
    <4536, 4540, 4541>,
    <4536, 4542, 4543>,
    <4536, 4543, 4544>,
    <4536, 4544, 4545>,
    <4536, 4545, 4537>,
    <4546, 4547, 4538>,
    <4546, 4538, 4537>,
    <4546, 4537, 4545>,
    <4546, 4545, 4548>,
    <4546, 4548, 4549>,
    <4546, 4549, 4526>,
    <4546, 4526, 4523>,
    <4546, 4523, 4547>,
    <4550, 4539, 4538>,
    <4550, 4538, 4547>,
    <4550, 4547, 4523>,
    <4550, 4523, 4522>,
    <4550, 4522, 4551>,
    <4550, 4551, 4552>,
    <4550, 4553, 4554>,
    <4550, 4554, 4539>,
    <4555, 4556, 4557>,
    <4555, 4557, 4558>,
    <4555, 4558, 4559>,
    <4555, 4559, 4560>,
    <4555, 4560, 4561>,
    <4555, 4561, 4562>,
    <4555, 4563, 4564>,
    <4555, 4564, 4556>,
    <4565, 4566, 4557>,
    <4565, 4557, 4556>,
    <4565, 4556, 4567>,
    <4565, 4567, 4568>,
    <4565, 4569, 4570>,
    <4565, 4570, 4571>,
    <4565, 4571, 4572>,
    <4565, 4572, 4566>,
    <4573, 4558, 4557>,
    <4573, 4557, 4566>,
    <4573, 4566, 4572>,
    <4573, 4572, 4574>,
    <4573, 4574, 4575>,
    <4573, 4575, 4576>,
    <4573, 4576, 4559>,
    <4573, 4559, 4558>,
    <4577, 4578, 4579>,
    <4577, 4579, 4580>,
    <4577, 4580, 4572>,
    <4577, 4572, 4571>,
    <4577, 4571, 4581>,
    <4577, 4581, 4443>,
    <4577, 4443, 4442>,
    <4577, 4442, 4578>,
    <4582, 4583, 4579>,
    <4582, 4579, 4578>,
    <4582, 4578, 4442>,
    <4582, 4442, 4456>,
    <4582, 4456, 4584>,
    <4582, 4584, 4585>,
    <4582, 4586, 4587>,
    <4582, 4587, 4583>,
    <4588, 4580, 4579>,
    <4588, 4579, 4583>,
    <4588, 4583, 4589>,
    <4588, 4589, 4590>,
    <4588, 4591, 4592>,
    <4588, 4592, 4574>,
    <4588, 4574, 4572>,
    <4588, 4572, 4580>,
    <4593, 4594, 4595>,
    <4593, 4595, 4596>,
    <4593, 4596, 4597>,
    <4593, 4597, 4598>,
    <4593, 4599, 4600>,
    <4593, 4600, 4560>,
    <4593, 4560, 4559>,
    <4593, 4559, 4594>,
    <4601, 4602, 4595>,
    <4601, 4595, 4594>,
    <4601, 4594, 4559>,
    <4601, 4559, 4576>,
    <4601, 4576, 4603>,
    <4601, 4603, 4604>,
    <4601, 4604, 4605>,
    <4601, 4605, 4602>,
    <4606, 4596, 4595>,
    <4606, 4595, 4602>,
    <4606, 4602, 4605>,
    <4606, 4605, 4607>,
    <4606, 4607, 4608>,
    <4606, 4608, 4609>,
    <4606, 4610, 4611>,
    <4606, 4611, 4596>,
    <4612, 4613, 4614>,
    <4612, 4614, 4615>,
    <4612, 4615, 4616>,
    <4612, 4616, 4617>,
    <4612, 4618, 4619>,
    <4612, 4619, 4620>,
    <4612, 4620, 4621>,
    <4612, 4621, 4613>,
    <4622, 4623, 4614>,
    <4622, 4614, 4613>,
    <4622, 4613, 4621>,
    <4622, 4621, 4624>,
    <4622, 4624, 4625>,
    <4622, 4625, 4626>,
    <4622, 4627, 4628>,
    <4622, 4628, 4623>,
    <4629, 4615, 4614>,
    <4629, 4614, 4623>,
    <4629, 4623, 4630>,
    <4629, 4630, 4631>,
    <4629, 4632, 4633>,
    <4629, 4633, 4634>,
    <4629, 4635, 4636>,
    <4629, 4636, 4615>,
    <4637, 4638, 4639>,
    <4637, 4639, 4640>,
    <4637, 4640, 4466>,
    <4637, 4466, 4465>,
    <4637, 4465, 4641>,
    <4637, 4641, 4642>,
    <4637, 4643, 4644>,
    <4637, 4644, 4638>,
    <4645, 4646, 4639>,
    <4645, 4639, 4638>,
    <4645, 4638, 4647>,
    <4645, 4647, 4648>,
    <4645, 4649, 4650>,
    <4645, 4650, 4651>,
    <4645, 4651, 4652>,
    <4645, 4652, 4646>,
    <4653, 4640, 4639>,
    <4653, 4639, 4646>,
    <4653, 4646, 4652>,
    <4653, 4652, 4654>,
    <4653, 4654, 4655>,
    <4653, 4655, 4469>,
    <4653, 4469, 4466>,
    <4653, 4466, 4640>,
    <4656, 4657, 4658>,
    <4656, 4658, 4659>,
    <4656, 4659, 4652>,
    <4656, 4652, 4651>,
    <4656, 4651, 4660>,
    <4656, 4660, 4661>,
    <4656, 4661, 4662>,
    <4656, 4662, 4657>,
    <4663, 4664, 4658>,
    <4663, 4658, 4657>,
    <4663, 4657, 4662>,
    <4663, 4662, 4665>,
    <4663, 4665, 4666>,
    <4663, 4666, 4667>,
    <4663, 4668, 4669>,
    <4663, 4669, 4664>,
    <4670, 4659, 4658>,
    <4670, 4658, 4664>,
    <4670, 4664, 4671>,
    <4670, 4671, 4672>,
    <4670, 4673, 4674>,
    <4670, 4674, 4654>,
    <4670, 4654, 4652>,
    <4670, 4652, 4659>,
    <4675, 4676, 4677>,
    <4675, 4677, 4678>,
    <4675, 4678, 4679>,
    <4675, 4679, 4680>,
    <4675, 4680, 4681>,
    <4675, 4681, 4682>,
    <4675, 4683, 4684>,
    <4675, 4684, 4676>,
    <4685, 4686, 4677>,
    <4685, 4677, 4676>,
    <4685, 4676, 4687>,
    <4685, 4687, 4688>,
    <4685, 4689, 4690>,
    <4685, 4690, 4691>,
    <4685, 4691, 4692>,
    <4685, 4692, 4686>,
    <4693, 4678, 4677>,
    <4693, 4677, 4686>,
    <4693, 4686, 4692>,
    <4693, 4692, 4694>,
    <4693, 4694, 4695>,
    <4693, 4695, 4696>,
    <4693, 4696, 4679>,
    <4693, 4679, 4678>,
    <4697, 4698, 4699>,
    <4697, 4699, 4700>,
    <4697, 4700, 4692>,
    <4697, 4692, 4691>,
    <4697, 4691, 4701>,
    <4697, 4701, 4624>,
    <4697, 4624, 4621>,
    <4697, 4621, 4698>,
    <4702, 4703, 4699>,
    <4702, 4699, 4698>,
    <4702, 4698, 4621>,
    <4702, 4621, 4620>,
    <4702, 4620, 4704>,
    <4702, 4704, 4705>,
    <4702, 4706, 4707>,
    <4702, 4707, 4703>,
    <4708, 4700, 4699>,
    <4708, 4699, 4703>,
    <4708, 4703, 4709>,
    <4708, 4709, 4710>,
    <4708, 4711, 4712>,
    <4708, 4712, 4694>,
    <4708, 4694, 4692>,
    <4708, 4692, 4700>,
    <4713, 4714, 4715>,
    <4713, 4715, 4716>,
    <4713, 4716, 4717>,
    <4713, 4717, 4718>,
    <4713, 4719, 4720>,
    <4713, 4720, 4721>,
    <4713, 4721, 4722>,
    <4713, 4722, 4714>,
    <4723, 4724, 4715>,
    <4723, 4715, 4714>,
    <4723, 4714, 4722>,
    <4723, 4722, 4725>,
    <4723, 4725, 4726>,
    <4723, 4726, 4727>,
    <4723, 4727, 4728>,
    <4723, 4728, 4724>,
    <4729, 4716, 4715>,
    <4729, 4715, 4724>,
    <4729, 4724, 4728>,
    <4729, 4728, 4730>,
    <4729, 4730, 4731>,
    <4729, 4731, 4732>,
    <4729, 4733, 4734>,
    <4729, 4734, 4716>,
    <4735, 4736, 4737>,
    <4735, 4737, 4738>,
    <4735, 4738, 4739>,
    <4735, 4739, 4740>,
    <4735, 4741, 4742>,
    <4735, 4742, 4665>,
    <4735, 4665, 4662>,
    <4735, 4662, 4736>,
    <4743, 4744, 4737>,
    <4743, 4737, 4736>,
    <4743, 4736, 4662>,
    <4743, 4662, 4661>,
    <4743, 4661, 4745>,
    <4743, 4745, 4730>,
    <4743, 4730, 4728>,
    <4743, 4728, 4744>,
    <4746, 4738, 4737>,
    <4746, 4737, 4744>,
    <4746, 4744, 4728>,
    <4746, 4728, 4727>,
    <4746, 4727, 4747>,
    <4746, 4747, 4748>,
    <4746, 4749, 4750>,
    <4746, 4750, 4738>,
    <4751, 4752, 4753>,
    <4751, 4753, 4754>,
    <4751, 4754, 4755>,
    <4751, 4755, 4756>,
    <4751, 4757, 4758>,
    <4751, 4758, 4680>,
    <4751, 4680, 4679>,
    <4751, 4679, 4752>,
    <4759, 4760, 4753>,
    <4759, 4753, 4752>,
    <4759, 4752, 4679>,
    <4759, 4679, 4696>,
    <4759, 4696, 4761>,
    <4759, 4761, 4762>,
    <4759, 4762, 4763>,
    <4759, 4763, 4760>,
    <4764, 4754, 4753>,
    <4764, 4753, 4760>,
    <4764, 4760, 4763>,
    <4764, 4763, 4765>,
    <4764, 4765, 4766>,
    <4764, 4766, 4767>,
    <4764, 4768, 4769>,
    <4764, 4769, 4754>,
    <4770, 4771, 4772>,
    <4770, 4772, 4773>,
    <4770, 4773, 4774>,
    <4770, 4774, 4775>,
    <4770, 4776, 4777>,
    <4770, 4777, 4778>,
    <4770, 4778, 4779>,
    <4770, 4779, 4771>,
    <4780, 4781, 4772>,
    <4780, 4772, 4771>,
    <4780, 4771, 4779>,
    <4780, 4779, 4782>,
    <4780, 4782, 4783>,
    <4780, 4783, 4725>,
    <4780, 4725, 4722>,
    <4780, 4722, 4781>,
    <4784, 4773, 4772>,
    <4784, 4772, 4781>,
    <4784, 4781, 4722>,
    <4784, 4722, 4721>,
    <4784, 4721, 4785>,
    <4784, 4785, 4786>,
    <4784, 4787, 4788>,
    <4784, 4788, 4773>,
    <4789, 4790, 4791>,
    <4789, 4791, 4792>,
    <4789, 4792, 4793>,
    <4789, 4793, 4794>,
    <4789, 4794, 4795>,
    <4789, 4795, 4796>,
    <4789, 4797, 4798>,
    <4789, 4798, 4790>,
    <4799, 4800, 4791>,
    <4799, 4791, 4790>,
    <4799, 4790, 4801>,
    <4799, 4801, 4802>,
    <4799, 4803, 4804>,
    <4799, 4804, 4765>,
    <4799, 4765, 4763>,
    <4799, 4763, 4800>,
    <4805, 4792, 4791>,
    <4805, 4791, 4800>,
    <4805, 4800, 4763>,
    <4805, 4763, 4762>,
    <4805, 4762, 4806>,
    <4805, 4806, 4807>,
    <4805, 4807, 4793>,
    <4805, 4793, 4792>,
    <4808, 4809, 4810>,
    <4808, 4810, 4811>,
    <4808, 4811, 4812>,
    <4808, 4812, 4813>,
    <4808, 4814, 4815>,
    <4808, 4815, 4816>,
    <4808, 4816, 4817>,
    <4808, 4817, 4809>,
    <4818, 4819, 4810>,
    <4818, 4810, 4809>,
    <4818, 4809, 4817>,
    <4818, 4817, 4820>,
    <4818, 4820, 4821>,
    <4818, 4821, 4782>,
    <4818, 4782, 4779>,
    <4818, 4779, 4819>,
    <4822, 4811, 4810>,
    <4822, 4810, 4819>,
    <4822, 4819, 4779>,
    <4822, 4779, 4778>,
    <4822, 4778, 4823>,
    <4822, 4823, 4824>,
    <4822, 4825, 4826>,
    <4822, 4826, 4811>,
    <4827, 4828, 4829>,
    <4827, 4829, 4830>,
    <4827, 4830, 4831>,
    <4827, 4831, 4832>,
    <4827, 4832, 4833>,
    <4827, 4833, 4834>,
    <4827, 4835, 4836>,
    <4827, 4836, 4828>,
    <4837, 4838, 4829>,
    <4837, 4829, 4828>,
    <4837, 4828, 4839>,
    <4837, 4839, 4840>,
    <4837, 4841, 4842>,
    <4837, 4842, 4607>,
    <4837, 4607, 4605>,
    <4837, 4605, 4838>,
    <4843, 4830, 4829>,
    <4843, 4829, 4838>,
    <4843, 4838, 4605>,
    <4843, 4605, 4604>,
    <4843, 4604, 4844>,
    <4843, 4844, 4845>,
    <4843, 4845, 4831>,
    <4843, 4831, 4830>,
    <4846, 4847, 4848>,
    <4846, 4848, 4849>,
    <4846, 4849, 4850>,
    <4846, 4850, 4851>,
    <4846, 4851, 4852>,
    <4846, 4852, 4853>,
    <4846, 4853, 4854>,
    <4846, 4854, 4847>,
    <4855, 4856, 4848>,
    <4855, 4848, 4847>,
    <4855, 4847, 4854>,
    <4855, 4854, 4857>,
    <4855, 4857, 4858>,
    <4855, 4858, 4859>,
    <4855, 4860, 4861>,
    <4855, 4861, 4856>,
    <4862, 4849, 4848>,
    <4862, 4848, 4856>,
    <4862, 4856, 4863>,
    <4862, 4863, 4864>,
    <4862, 4865, 4866>,
    <4862, 4866, 4867>,
    <4862, 4867, 4850>,
    <4862, 4850, 4849>,
    <4868, 4869, 4870>,
    <4868, 4870, 4871>,
    <4868, 4871, 4817>,
    <4868, 4817, 4816>,
    <4868, 4816, 4872>,
    <4868, 4872, 4873>,
    <4868, 4874, 4875>,
    <4868, 4875, 4869>,
    <4876, 4877, 4870>,
    <4876, 4870, 4869>,
    <4876, 4869, 4878>,
    <4876, 4878, 4879>,
    <4876, 4880, 4881>,
    <4876, 4881, 4851>,
    <4876, 4851, 4850>,
    <4876, 4850, 4877>,
    <4882, 4871, 4870>,
    <4882, 4870, 4877>,
    <4882, 4877, 4850>,
    <4882, 4850, 4867>,
    <4882, 4867, 4883>,
    <4882, 4883, 4820>,
    <4882, 4820, 4817>,
    <4882, 4817, 4871>,
    <4884, 4885, 4886>,
    <4884, 4886, 4887>,
    <4884, 4887, 4888>,
    <4884, 4888, 4889>,
    <4884, 4890, 4891>,
    <4884, 4891, 4794>,
    <4884, 4794, 4793>,
    <4884, 4793, 4885>,
    <4892, 4893, 4886>,
    <4892, 4886, 4885>,
    <4892, 4885, 4793>,
    <4892, 4793, 4807>,
    <4892, 4807, 4894>,
    <4892, 4894, 4895>,
    <4892, 4895, 4896>,
    <4892, 4896, 4893>,
    <4897, 4887, 4886>,
    <4897, 4886, 4893>,
    <4897, 4893, 4896>,
    <4897, 4896, 4898>,
    <4897, 4898, 4899>,
    <4897, 4899, 4900>,
    <4897, 4901, 4902>,
    <4897, 4902, 4887>,
    <4903, 4904, 4905>,
    <4903, 4905, 4906>,
    <4903, 4906, 4907>,
    <4903, 4907, 4908>,
    <4903, 4909, 4910>,
    <4903, 4910, 4857>,
    <4903, 4857, 4854>,
    <4903, 4854, 4904>,
    <4911, 4912, 4905>,
    <4911, 4905, 4904>,
    <4911, 4904, 4854>,
    <4911, 4854, 4853>,
    <4911, 4853, 4913>,
    <4911, 4913, 4914>,
    <4911, 4914, 4915>,
    <4911, 4915, 4912>,
    <4916, 4906, 4905>,
    <4916, 4905, 4912>,
    <4916, 4912, 4915>,
    <4916, 4915, 4917>,
    <4916, 4917, 4918>,
    <4916, 4918, 4919>,
    <4916, 4920, 4921>,
    <4916, 4921, 4906>,
    <4922, 4923, 4924>,
    <4922, 4924, 4925>,
    <4922, 4925, 4926>,
    <4922, 4926, 4927>,
    <4922, 4928, 4929>,
    <4922, 4929, 4930>,
    <4922, 4930, 4931>,
    <4922, 4931, 4923>,
    <4932, 4933, 4924>,
    <4932, 4924, 4923>,
    <4932, 4923, 4931>,
    <4932, 4931, 4934>,
    <4932, 4934, 4935>,
    <4932, 4935, 4548>,
    <4932, 4548, 4545>,
    <4932, 4545, 4933>,
    <4936, 4925, 4924>,
    <4936, 4924, 4933>,
    <4936, 4933, 4545>,
    <4936, 4545, 4544>,
    <4936, 4544, 4937>,
    <4936, 4937, 4938>,
    <4936, 4939, 4940>,
    <4936, 4940, 4925>,
    <4941, 4942, 4943>,
    <4941, 4943, 4944>,
    <4941, 4944, 4931>,
    <4941, 4931, 4930>,
    <4941, 4930, 4945>,
    <4941, 4945, 4946>,
    <4941, 4946, 4947>,
    <4941, 4947, 4942>,
    <4948, 4949, 4943>,
    <4948, 4943, 4942>,
    <4948, 4942, 4947>,
    <4948, 4947, 4950>,
    <4948, 4950, 4951>,
    <4948, 4951, 4952>,
    <4948, 4953, 4954>,
    <4948, 4954, 4949>,
    <4955, 4944, 4943>,
    <4955, 4943, 4949>,
    <4955, 4949, 4956>,
    <4955, 4956, 4957>,
    <4955, 4958, 4959>,
    <4955, 4959, 4934>,
    <4955, 4934, 4931>,
    <4955, 4931, 4944>,
    <4960, 4961, 4962>,
    <4960, 4962, 4963>,
    <4960, 4963, 4964>,
    <4960, 4964, 4965>,
    <4960, 4966, 4967>,
    <4960, 4967, 4968>,
    <4960, 4968, 4969>,
    <4960, 4969, 4961>,
    <4970, 4971, 4962>,
    <4970, 4962, 4961>,
    <4970, 4961, 4969>,
    <4970, 4969, 4972>,
    <4970, 4972, 4973>,
    <4970, 4973, 4950>,
    <4970, 4950, 4947>,
    <4970, 4947, 4971>,
    <4974, 4963, 4962>,
    <4974, 4962, 4971>,
    <4974, 4971, 4947>,
    <4974, 4947, 4946>,
    <4974, 4946, 4975>,
    <4974, 4975, 4976>,
    <4974, 4977, 4978>,
    <4974, 4978, 4963>,
    <4979, 4980, 4981>,
    <4979, 4981, 4982>,
    <4979, 4982, 4983>,
    <4979, 4983, 4984>,
    <4979, 4984, 4985>,
    <4979, 4985, 4986>,
    <4979, 4987, 4988>,
    <4979, 4988, 4980>,
    <4989, 4990, 4981>,
    <4989, 4981, 4980>,
    <4989, 4980, 4991>,
    <4989, 4991, 4992>,
    <4989, 4993, 4994>,
    <4989, 4994, 4995>,
    <4989, 4995, 4996>,
    <4989, 4996, 4990>,
    <4997, 4982, 4981>,
    <4997, 4981, 4990>,
    <4997, 4990, 4996>,
    <4997, 4996, 4998>,
    <4997, 4998, 4999>,
    <4997, 4999, 5000>,
    <4997, 5000, 4983>,
    <4997, 4983, 4982>,
    <5001, 5002, 5003>,
    <5001, 5003, 5004>,
    <5001, 5004, 4996>,
    <5001, 4996, 4995>,
    <5001, 4995, 5005>,
    <5001, 5005, 4832>,
    <5001, 4832, 4831>,
    <5001, 4831, 5002>,
    <5006, 5007, 5003>,
    <5006, 5003, 5002>,
    <5006, 5002, 4831>,
    <5006, 4831, 4845>,
    <5006, 4845, 5008>,
    <5006, 5008, 5009>,
    <5006, 5010, 5011>,
    <5006, 5011, 5007>,
    <5012, 5004, 5003>,
    <5012, 5003, 5007>,
    <5012, 5007, 5013>,
    <5012, 5013, 5014>,
    <5012, 5015, 5016>,
    <5012, 5016, 4998>,
    <5012, 4998, 4996>,
    <5012, 4996, 5004>,
    <5017, 5018, 5019>,
    <5017, 5019, 5020>,
    <5017, 5020, 5021>,
    <5017, 5021, 5022>,
    <5017, 5023, 5024>,
    <5017, 5024, 4984>,
    <5017, 4984, 4983>,
    <5017, 4983, 5018>,
    <5025, 5026, 5019>,
    <5025, 5019, 5018>,
    <5025, 5018, 4983>,
    <5025, 4983, 5000>,
    <5025, 5000, 5027>,
    <5025, 5027, 5028>,
    <5025, 5028, 5029>,
    <5025, 5029, 5026>,
    <5030, 5020, 5019>,
    <5030, 5019, 5026>,
    <5030, 5026, 5029>,
    <5030, 5029, 5031>,
    <5030, 5031, 5032>,
    <5030, 5032, 5033>,
    <5030, 5034, 5035>,
    <5030, 5035, 5020>,
    <5036, 5037, 5038>,
    <5036, 5038, 5039>,
    <5036, 5039, 5040>,
    <5036, 5040, 5041>,
    <5036, 5041, 5042>,
    <5036, 5042, 5043>,
    <5036, 5044, 5045>,
    <5036, 5045, 5037>,
    <5046, 5047, 5038>,
    <5046, 5038, 5037>,
    <5046, 5037, 5048>,
    <5046, 5048, 5049>,
    <5046, 5050, 5051>,
    <5046, 5051, 5052>,
    <5046, 5052, 5053>,
    <5046, 5053, 5047>,
    <5054, 5039, 5038>,
    <5054, 5038, 5047>,
    <5054, 5047, 5053>,
    <5054, 5053, 5055>,
    <5054, 5055, 5056>,
    <5054, 5056, 5057>,
    <5054, 5057, 5040>,
    <5054, 5040, 5039>,
    <5058, 5059, 5060>,
    <5058, 5060, 5061>,
    <5058, 5061, 5062>,
    <5058, 5062, 5063>,
    <5058, 5064, 5065>,
    <5058, 5065, 5066>,
    <5058, 5066, 5067>,
    <5058, 5067, 5059>,
    <5068, 5069, 5060>,
    <5068, 5060, 5059>,
    <5068, 5059, 5067>,
    <5068, 5067, 5070>,
    <5068, 5070, 5071>,
    <5068, 5071, 4917>,
    <5068, 4917, 4915>,
    <5068, 4915, 5069>,
    <5072, 5061, 5060>,
    <5072, 5060, 5069>,
    <5072, 5069, 4915>,
    <5072, 4915, 4914>,
    <5072, 4914, 5073>,
    <5072, 5073, 5074>,
    <5072, 5075, 5076>,
    <5072, 5076, 5061>,
    <5077, 5078, 5079>,
    <5077, 5079, 5080>,
    <5077, 5080, 5081>,
    <5077, 5081, 5082>,
    <5077, 5082, 5083>,
    <5077, 5083, 5084>,
    <5077, 5085, 5086>,
    <5077, 5086, 5078>,
    <5087, 5088, 5079>,
    <5087, 5079, 5078>,
    <5087, 5078, 5089>,
    <5087, 5089, 5090>,
    <5087, 5091, 5092>,
    <5087, 5092, 5055>,
    <5087, 5055, 5053>,
    <5087, 5053, 5088>,
    <5093, 5080, 5079>,
    <5093, 5079, 5088>,
    <5093, 5088, 5053>,
    <5093, 5053, 5052>,
    <5093, 5052, 5094>,
    <5093, 5094, 5095>,
    <5093, 5095, 5081>,
    <5093, 5081, 5080>,
    <5096, 5097, 5098>,
    <5096, 5098, 5099>,
    <5096, 5099, 5100>,
    <5096, 5100, 5101>,
    <5096, 5102, 5103>,
    <5096, 5103, 5104>,
    <5096, 5104, 5105>,
    <5096, 5105, 5097>,
    <5106, 5107, 5098>,
    <5106, 5098, 5097>,
    <5106, 5097, 5105>,
    <5106, 5105, 5108>,
    <5106, 5108, 5109>,
    <5106, 5109, 5070>,
    <5106, 5070, 5067>,
    <5106, 5067, 5107>,
    <5110, 5099, 5098>,
    <5110, 5098, 5107>,
    <5110, 5107, 5067>,
    <5110, 5067, 5066>,
    <5110, 5066, 5111>,
    <5110, 5111, 5112>,
    <5110, 5113, 5114>,
    <5110, 5114, 5099>,
    <5115, 5116, 5117>,
    <5115, 5117, 5118>,
    <5115, 5118, 5119>,
    <5115, 5119, 5120>,
    <5115, 5121, 5122>,
    <5115, 5122, 5123>,
    <5115, 5124, 5125>,
    <5115, 5125, 5116>,
    <5126, 5127, 5117>,
    <5126, 5117, 5116>,
    <5126, 5116, 5128>,
    <5126, 5128, 5129>,
    <5126, 5130, 5131>,
    <5126, 5131, 5082>,
    <5126, 5082, 5081>,
    <5126, 5081, 5127>,
    <5132, 5118, 5117>,
    <5132, 5117, 5127>,
    <5132, 5127, 5081>,
    <5132, 5081, 5095>,
    <5132, 5095, 5133>,
    <5132, 5133, 5134>,
    <5132, 5135, 5136>,
    <5132, 5136, 5118>,
    <5137, 5138, 5139>,
    <5137, 5139, 5140>,
    <5137, 5140, 5105>,
    <5137, 5105, 5104>,
    <5137, 5104, 5141>,
    <5137, 5141, 5142>,
    <5137, 5143, 5144>,
    <5137, 5144, 5138>,
    <5145, 5146, 5139>,
    <5145, 5139, 5138>,
    <5145, 5138, 5147>,
    <5145, 5147, 5148>,
    <5145, 5149, 5150>,
    <5145, 5150, 5151>,
    <5145, 5151, 5152>,
    <5145, 5152, 5146>,
    <5153, 5140, 5139>,
    <5153, 5139, 5146>,
    <5153, 5146, 5152>,
    <5153, 5152, 5154>,
    <5153, 5154, 5155>,
    <5153, 5155, 5108>,
    <5153, 5108, 5105>,
    <5153, 5105, 5140>,
    <5156, 5157, 5158>,
    <5156, 5158, 5159>,
    <5156, 5159, 5152>,
    <5156, 5152, 5151>,
    <5156, 5151, 5160>,
    <5156, 5160, 5161>,
    <5156, 5161, 5162>,
    <5156, 5162, 5157>,
    <5163, 5164, 5158>,
    <5163, 5158, 5157>,
    <5163, 5157, 5162>,
    <5163, 5162, 5165>,
    <5163, 5165, 5166>,
    <5163, 5166, 5167>,
    <5163, 5168, 5169>,
    <5163, 5169, 5164>,
    <5170, 5159, 5158>,
    <5170, 5158, 5164>,
    <5170, 5164, 5171>,
    <5170, 5171, 5172>,
    <5170, 5173, 5174>,
    <5170, 5174, 5154>,
    <5170, 5154, 5152>,
    <5170, 5152, 5159>,
    <5175, 5176, 5177>,
    <5175, 5177, 5178>,
    <5175, 5178, 5179>,
    <5175, 5179, 5180>,
    <5175, 5181, 5182>,
    <5175, 5182, 5183>,
    <5175, 5183, 5184>,
    <5175, 5184, 5176>,
    <5185, 5186, 5177>,
    <5185, 5177, 5176>,
    <5185, 5176, 5184>,
    <5185, 5184, 5187>,
    <5185, 5187, 5188>,
    <5185, 5188, 5189>,
    <5185, 5190, 5191>,
    <5185, 5191, 5186>,
    <5192, 5178, 5177>,
    <5192, 5177, 5186>,
    <5192, 5186, 5193>,
    <5192, 5193, 5194>,
    <5192, 5195, 5196>,
    <5192, 5196, 5197>,
    <5192, 5198, 5199>,
    <5192, 5199, 5178>,
    <5200, 5201, 5202>,
    <5200, 5202, 5203>,
    <5200, 5203, 5204>,
    <5200, 5204, 5205>,
    <5200, 5205, 5206>,
    <5200, 5206, 5187>,
    <5200, 5187, 5184>,
    <5200, 5184, 5201>,
    <5207, 5208, 5202>,
    <5207, 5202, 5201>,
    <5207, 5201, 5184>,
    <5207, 5184, 5183>,
    <5207, 5183, 5209>,
    <5207, 5209, 5210>,
    <5207, 5211, 5212>,
    <5207, 5212, 5208>,
    <5213, 5203, 5202>,
    <5213, 5202, 5208>,
    <5213, 5208, 5214>,
    <5213, 5214, 5215>,
    <5213, 5216, 5217>,
    <5213, 5217, 5218>,
    <5213, 5218, 5204>,
    <5213, 5204, 5203>,
    <5219, 5220, 5221>,
    <5219, 5221, 5222>,
    <5219, 5222, 5223>,
    <5219, 5223, 5224>,
    <5219, 5225, 5226>,
    <5219, 5226, 5165>,
    <5219, 5165, 5162>,
    <5219, 5162, 5220>,
    <5227, 5228, 5221>,
    <5227, 5221, 5220>,
    <5227, 5220, 5162>,
    <5227, 5162, 5161>,
    <5227, 5161, 5229>,
    <5227, 5229, 5230>,
    <5227, 5230, 5231>,
    <5227, 5231, 5228>,
    <5232, 5222, 5221>,
    <5232, 5221, 5228>,
    <5232, 5228, 5231>,
    <5232, 5231, 5233>,
    <5232, 5233, 5234>,
    <5232, 5234, 5235>,
    <5232, 5236, 5237>,
    <5232, 5237, 5222>,
    <5238, 5239, 5240>,
    <5238, 5240, 5241>,
    <5238, 5241, 5242>,
    <5238, 5242, 5243>,
    <5238, 5244, 5245>,
    <5238, 5245, 5205>,
    <5238, 5205, 5204>,
    <5238, 5204, 5239>,
    <5246, 5247, 5240>,
    <5246, 5240, 5239>,
    <5246, 5239, 5204>,
    <5246, 5204, 5218>,
    <5246, 5218, 5248>,
    <5246, 5248, 5249>,
    <5246, 5249, 5250>,
    <5246, 5250, 5247>,
    <5251, 5241, 5240>,
    <5251, 5240, 5247>,
    <5251, 5247, 5250>,
    <5251, 5250, 5252>,
    <5251, 5252, 5253>,
    <5251, 5253, 5254>,
    <5251, 5255, 5256>,
    <5251, 5256, 5241>,
    <5257, 5258, 5259>,
    <5257, 5259, 5260>,
    <5257, 5260, 5261>,
    <5257, 5261, 5262>,
    <5257, 5263, 5264>,
    <5257, 5264, 5265>,
    <5257, 5265, 5266>,
    <5257, 5266, 5258>,
    <5267, 5268, 5259>,
    <5267, 5259, 5258>,
    <5267, 5258, 5266>,
    <5267, 5266, 5269>,
    <5267, 5269, 5270>,
    <5267, 5270, 5233>,
    <5267, 5233, 5231>,
    <5267, 5231, 5268>,
    <5271, 5260, 5259>,
    <5271, 5259, 5268>,
    <5271, 5268, 5231>,
    <5271, 5231, 5230>,
    <5271, 5230, 5272>,
    <5271, 5272, 5273>,
    <5271, 5274, 5275>,
    <5271, 5275, 5260>,
    <5276, 5277, 5278>,
    <5276, 5278, 5279>,
    <5276, 5279, 5280>,
    <5276, 5280, 5281>,
    <5276, 5281, 5282>,
    <5276, 5282, 5252>,
    <5276, 5252, 5250>,
    <5276, 5250, 5277>,
    <5283, 5284, 5278>,
    <5283, 5278, 5277>,
    <5283, 5277, 5250>,
    <5283, 5250, 5249>,
    <5283, 5249, 5285>,
    <5283, 5285, 5286>,
    <5283, 5286, 5287>,
    <5283, 5287, 5284>,
    <5288, 5279, 5278>,
    <5288, 5278, 5284>,
    <5288, 5284, 5287>,
    <5288, 5287, 5289>,
    <5288, 5289, 5290>,
    <5288, 5290, 5291>,
    <5288, 5291, 5280>,
    <5288, 5280, 5279>,
    <5292, 5293, 5294>,
    <5292, 5294, 5295>,
    <5292, 5295, 5296>,
    <5292, 5296, 5297>,
    <5292, 5298, 5299>,
    <5292, 5299, 5300>,
    <5292, 5300, 5301>,
    <5292, 5301, 5293>,
    <5302, 5303, 5294>,
    <5302, 5294, 5293>,
    <5302, 5293, 5301>,
    <5302, 5301, 5304>,
    <5302, 5304, 5305>,
    <5302, 5305, 5269>,
    <5302, 5269, 5266>,
    <5302, 5266, 5303>,
    <5306, 5295, 5294>,
    <5306, 5294, 5303>,
    <5306, 5303, 5266>,
    <5306, 5266, 5265>,
    <5306, 5265, 5307>,
    <5306, 5307, 5308>,
    <5306, 5309, 5310>,
    <5306, 5310, 5295>,
    <5311, 5312, 5313>,
    <5311, 5313, 5314>,
    <5311, 5314, 5315>,
    <5311, 5315, 5316>,
    <5311, 5316, 5317>,
    <5311, 5317, 5318>,
    <5311, 5319, 5320>,
    <5311, 5320, 5312>,
    <5321, 5322, 5313>,
    <5321, 5313, 5312>,
    <5321, 5312, 5323>,
    <5321, 5323, 5324>,
    <5321, 5325, 5326>,
    <5321, 5326, 5031>,
    <5321, 5031, 5029>,
    <5321, 5029, 5322>,
    <5327, 5314, 5313>,
    <5327, 5313, 5322>,
    <5327, 5322, 5029>,
    <5327, 5029, 5028>,
    <5327, 5028, 5328>,
    <5327, 5328, 5329>,
    <5327, 5329, 5315>,
    <5327, 5315, 5314>,
    <5330, 5331, 5332>,
    <5330, 5332, 5333>,
    <5330, 5333, 5334>,
    <5330, 5334, 5335>,
    <5330, 5336, 5337>,
    <5330, 5337, 5338>,
    <5330, 5338, 5339>,
    <5330, 5339, 5331>,
    <5340, 5341, 5332>,
    <5340, 5332, 5331>,
    <5340, 5331, 5339>,
    <5340, 5339, 5342>,
    <5340, 5342, 5290>,
    <5340, 5290, 5343>,
    <5340, 5343, 5344>,
    <5340, 5344, 5341>,
    <5345, 5333, 5332>,
    <5345, 5332, 5341>,
    <5345, 5341, 5344>,
    <5345, 5344, 5346>,
    <5345, 5346, 5347>,
    <5345, 5347, 5348>,
    <5345, 5349, 5350>,
    <5345, 5350, 5333>,
    <5351, 5352, 5353>,
    <5351, 5353, 5354>,
    <5351, 5354, 5355>,
    <5351, 5355, 5356>,
    <5351, 5357, 5358>,
    <5351, 5358, 5359>,
    <5351, 5360, 5361>,
    <5351, 5361, 5352>,
    <5362, 5363, 5353>,
    <5362, 5353, 5352>,
    <5362, 5352, 5364>,
    <5362, 5364, 5365>,
    <5362, 5366, 5367>,
    <5362, 5367, 5368>,
    <5362, 5369, 5370>,
    <5362, 5370, 5363>,
    <5371, 5354, 5353>,
    <5371, 5353, 5363>,
    <5371, 5363, 5372>,
    <5371, 5372, 5373>,
    <5371, 5374, 5375>,
    <5371, 5375, 5376>,
    <5371, 5377, 5378>,
    <5371, 5378, 5354>,
    <5379, 5380, 5381>,
    <5379, 5381, 5382>,
    <5379, 5382, 5383>,
    <5379, 5383, 5384>,
    <5379, 5384, 5385>,
    <5379, 5385, 5281>,
    <5379, 5281, 5280>,
    <5379, 5280, 5380>,
    <5386, 5387, 5381>,
    <5386, 5381, 5380>,
    <5386, 5380, 5280>,
    <5386, 5280, 5291>,
    <5386, 5291, 5290>,
    <5386, 5290, 5388>,
    <5386, 5388, 5389>,
    <5386, 5389, 5387>,
    <5390, 5382, 5381>,
    <5390, 5381, 5387>,
    <5390, 5387, 5389>,
    <5390, 5389, 5391>,
    <5390, 5391, 5392>,
    <5390, 5392, 5393>,
    <5390, 5393, 5383>,
    <5390, 5383, 5382>,
    <5394, 5395, 5396>,
    <5394, 5396, 5397>,
    <5394, 5397, 5339>,
    <5394, 5339, 5338>,
    <5394, 5338, 5398>,
    <5394, 5398, 5399>,
    <5394, 5400, 5401>,
    <5394, 5401, 5395>,
    <5402, 5403, 5396>,
    <5402, 5396, 5395>,
    <5402, 5395, 5404>,
    <5402, 5404, 5405>,
    <5402, 5406, 5407>,
    <5402, 5407, 5391>,
    <5402, 5391, 5389>,
    <5402, 5389, 5403>,
    <5408, 5397, 5396>,
    <5408, 5396, 5403>,
    <5408, 5403, 5389>,
    <5408, 5389, 5388>,
    <5408, 5388, 5290>,
    <5408, 5290, 5342>,
    <5408, 5342, 5339>,
    <5408, 5339, 5397>,
    <5409, 5410, 5411>,
    <5409, 5411, 5412>,
    <5409, 5412, 5301>,
    <5409, 5301, 5300>,
    <5409, 5300, 5413>,
    <5409, 5413, 5414>,
    <5409, 5415, 5416>,
    <5409, 5416, 5410>,
    <5417, 5418, 5411>,
    <5417, 5411, 5410>,
    <5417, 5410, 5419>,
    <5417, 5419, 5420>,
    <5417, 5421, 5422>,
    <5417, 5422, 5423>,
    <5417, 5424, 5425>,
    <5417, 5425, 5418>,
    <5426, 5412, 5411>,
    <5426, 5411, 5418>,
    <5426, 5418, 5427>,
    <5426, 5427, 5428>,
    <5426, 5429, 5430>,
    <5426, 5430, 5304>,
    <5426, 5304, 5301>,
    <5426, 5301, 5412>,
    <5431, 5432, 5433>,
    <5431, 5433, 5434>,
    <5431, 5434, 5435>,
    <5431, 5435, 5436>,
    <5431, 5437, 5438>,
    <5431, 5438, 5439>,
    <5431, 5439, 5440>,
    <5431, 5440, 5432>,
    <5441, 5442, 5433>,
    <5441, 5433, 5432>,
    <5441, 5432, 5440>,
    <5441, 5440, 5443>,
    <5441, 5443, 5444>,
    <5441, 5444, 4972>,
    <5441, 4972, 4969>,
    <5441, 4969, 5442>,
    <5445, 5434, 5433>,
    <5445, 5433, 5442>,
    <5445, 5442, 4969>,
    <5445, 4969, 4968>,
    <5445, 4968, 5446>,
    <5445, 5446, 5447>,
    <5445, 5448, 5449>,
    <5445, 5449, 5434>,
    <5450, 5451, 5452>,
    <5450, 5452, 5453>,
    <5450, 5453, 5440>,
    <5450, 5440, 5439>,
    <5450, 5439, 5454>,
    <5450, 5454, 5455>,
    <5450, 5455, 5456>,
    <5450, 5456, 5451>,
    <5457, 5458, 5452>,
    <5457, 5452, 5451>,
    <5457, 5451, 5456>,
    <5457, 5456, 5459>,
    <5457, 5459, 5460>,
    <5457, 5460, 5461>,
    <5457, 5462, 5463>,
    <5457, 5463, 5458>,
    <5464, 5453, 5452>,
    <5464, 5452, 5458>,
    <5464, 5458, 5465>,
    <5464, 5465, 5466>,
    <5464, 5467, 5468>,
    <5464, 5468, 5443>,
    <5464, 5443, 5440>,
    <5464, 5440, 5453>,
    <5469, 5470, 5471>,
    <5469, 5471, 5472>,
    <5469, 5472, 5473>,
    <5469, 5473, 5474>,
    <5469, 5475, 5476>,
    <5469, 5476, 5477>,
    <5469, 5477, 5478>,
    <5469, 5478, 5470>,
    <5479, 5480, 5471>,
    <5479, 5471, 5470>,
    <5479, 5470, 5478>,
    <5479, 5478, 5481>,
    <5479, 5481, 5482>,
    <5479, 5482, 5459>,
    <5479, 5459, 5456>,
    <5479, 5456, 5480>,
    <5483, 5472, 5471>,
    <5483, 5471, 5480>,
    <5483, 5480, 5456>,
    <5483, 5456, 5455>,
    <5483, 5455, 5484>,
    <5483, 5484, 5485>,
    <5483, 5486, 5487>,
    <5483, 5487, 5472>,
    <5488, 5489, 5490>,
    <5488, 5490, 5491>,
    <5488, 5491, 5492>,
    <5488, 5492, 5493>,
    <5488, 5494, 5495>,
    <5488, 5495, 5496>,
    <5488, 5496, 5497>,
    <5488, 5497, 5489>,
    <5498, 5499, 5490>,
    <5498, 5490, 5489>,
    <5498, 5489, 5497>,
    <5498, 5497, 5500>,
    <5498, 5500, 5501>,
    <5498, 5501, 5502>,
    <5498, 5502, 5503>,
    <5498, 5503, 5499>,
    <5504, 5491, 5490>,
    <5504, 5490, 5499>,
    <5504, 5499, 5503>,
    <5504, 5503, 5505>,
    <5504, 5505, 5506>,
    <5504, 5506, 5507>,
    <5504, 5508, 5509>,
    <5504, 5509, 5491>,
    <5510, 5511, 5512>,
    <5510, 5512, 5513>,
    <5510, 5513, 5514>,
    <5510, 5514, 5515>,
    <5510, 5516, 5517>,
    <5510, 5517, 5518>,
    <5510, 5519, 5520>,
    <5510, 5520, 5511>,
    <5521, 5522, 5512>,
    <5521, 5512, 5511>,
    <5521, 5511, 5523>,
    <5521, 5523, 5524>,
    <5521, 5525, 5526>,
    <5521, 5526, 5527>,
    <5521, 5528, 5529>,
    <5521, 5529, 5522>,
    <5530, 5513, 5512>,
    <5530, 5512, 5522>,
    <5530, 5522, 5531>,
    <5530, 5531, 5532>,
    <5530, 5533, 5534>,
    <5530, 5534, 5535>,
    <5530, 5536, 5537>,
    <5530, 5537, 5513>,
    <5538, 5539, 5540>,
    <5538, 5540, 5541>,
    <5538, 5541, 5497>,
    <5538, 5497, 5496>,
    <5538, 5496, 5542>,
    <5538, 5542, 5316>,
    <5538, 5316, 5315>,
    <5538, 5315, 5539>,
    <5543, 5544, 5540>,
    <5543, 5540, 5539>,
    <5543, 5539, 5315>,
    <5543, 5315, 5329>,
    <5543, 5329, 5545>,
    <5543, 5545, 5546>,
    <5543, 5547, 5548>,
    <5543, 5548, 5544>,
    <5549, 5541, 5540>,
    <5549, 5540, 5544>,
    <5549, 5544, 5550>,
    <5549, 5550, 5551>,
    <5549, 5552, 5553>,
    <5549, 5553, 5500>,
    <5549, 5500, 5497>,
    <5549, 5497, 5541>,
    <5554, 5555, 5556>,
    <5554, 5556, 5557>,
    <5554, 5557, 5558>,
    <5554, 5558, 5559>,
    <5554, 5560, 5561>,
    <5554, 5561, 5505>,
    <5554, 5505, 5503>,
    <5554, 5503, 5555>,
    <5562, 5563, 5556>,
    <5562, 5556, 5555>,
    <5562, 5555, 5503>,
    <5562, 5503, 5502>,
    <5562, 5502, 5564>,
    <5562, 5564, 5565>,
    <5562, 5565, 5566>,
    <5562, 5566, 5563>,
    <5567, 5557, 5556>,
    <5567, 5556, 5563>,
    <5567, 5563, 5566>,
    <5567, 5566, 5568>,
    <5567, 5568, 5569>,
    <5567, 5569, 5570>,
    <5567, 5571, 5572>,
    <5567, 5572, 5557>,
    <5573, 5574, 5575>,
    <5573, 5575, 5576>,
    <5573, 5576, 5577>,
    <5573, 5577, 5578>,
    <5573, 5579, 5580>,
    <5573, 5580, 5581>,
    <5573, 5582, 5583>,
    <5573, 5583, 5574>,
    <5584, 5585, 5575>,
    <5584, 5575, 5574>,
    <5584, 5574, 5586>,
    <5584, 5586, 5587>,
    <5584, 5588, 5589>,
    <5584, 5589, 5590>,
    <5584, 5591, 5592>,
    <5584, 5592, 5585>,
    <5593, 5576, 5575>,
    <5593, 5575, 5585>,
    <5593, 5585, 5594>,
    <5593, 5594, 5595>,
    <5593, 5596, 5597>,
    <5593, 5597, 5598>,
    <5593, 5599, 5600>,
    <5593, 5600, 5576>,
    <5601, 5602, 5603>,
    <5601, 5603, 5604>,
    <5601, 5604, 5605>,
    <5601, 5605, 5606>,
    <5601, 5606, 5607>,
    <5601, 5607, 5608>,
    <5601, 5609, 5610>,
    <5601, 5610, 5602>,
    <5611, 5612, 5603>,
    <5611, 5603, 5602>,
    <5611, 5602, 5613>,
    <5611, 5613, 5614>,
    <5611, 5615, 5616>,
    <5611, 5616, 5568>,
    <5611, 5568, 5566>,
    <5611, 5566, 5612>,
    <5617, 5604, 5603>,
    <5617, 5603, 5612>,
    <5617, 5612, 5566>,
    <5617, 5566, 5565>,
    <5617, 5565, 5618>,
    <5617, 5618, 5619>,
    <5617, 5619, 5605>,
    <5617, 5605, 5604>,
    <5620, 5621, 5622>,
    <5620, 5622, 5623>,
    <5620, 5623, 5624>,
    <5620, 5624, 5625>,
    <5620, 5626, 5627>,
    <5620, 5627, 5628>,
    <5620, 5628, 5629>,
    <5620, 5629, 5621>,
    <5630, 5631, 5622>,
    <5630, 5622, 5621>,
    <5630, 5621, 5629>,
    <5630, 5629, 5632>,
    <5630, 5632, 5633>,
    <5630, 5633, 5481>,
    <5630, 5481, 5478>,
    <5630, 5478, 5631>,
    <5634, 5623, 5622>,
    <5634, 5622, 5631>,
    <5634, 5631, 5478>,
    <5634, 5478, 5477>,
    <5634, 5477, 5635>,
    <5634, 5635, 5636>,
    <5634, 5637, 5638>,
    <5634, 5638, 5623>,
    <5639, 5640, 5641>,
    <5639, 5641, 5642>,
    <5639, 5642, 5629>,
    <5639, 5629, 5628>,
    <5639, 5628, 5643>,
    <5639, 5643, 5644>,
    <5639, 5644, 5645>,
    <5639, 5645, 5640>,
    <5646, 5647, 5641>,
    <5646, 5641, 5640>,
    <5646, 5640, 5645>,
    <5646, 5645, 5648>,
    <5646, 5648, 5649>,
    <5646, 5649, 5650>,
    <5646, 5651, 5652>,
    <5646, 5652, 5647>,
    <5653, 5642, 5641>,
    <5653, 5641, 5647>,
    <5653, 5647, 5654>,
    <5653, 5654, 5655>,
    <5653, 5656, 5657>,
    <5653, 5657, 5632>,
    <5653, 5632, 5629>,
    <5653, 5629, 5642>,
    <5658, 5659, 5660>,
    <5658, 5660, 5661>,
    <5658, 5661, 5662>,
    <5658, 5662, 5663>,
    <5658, 5664, 5665>,
    <5658, 5665, 5666>,
    <5658, 5666, 5667>,
    <5658, 5667, 5659>,
    <5668, 5669, 5660>,
    <5668, 5660, 5659>,
    <5668, 5659, 5667>,
    <5668, 5667, 5670>,
    <5668, 5670, 5671>,
    <5668, 5671, 5648>,
    <5668, 5648, 5645>,
    <5668, 5645, 5669>,
    <5672, 5661, 5660>,
    <5672, 5660, 5669>,
    <5672, 5669, 5645>,
    <5672, 5645, 5644>,
    <5672, 5644, 5673>,
    <5672, 5673, 5674>,
    <5672, 5675, 5676>,
    <5672, 5676, 5661>,
    <5677, 5678, 5679>,
    <5677, 5679, 5680>,
    <5677, 5680, 5681>,
    <5677, 5681, 5682>,
    <5677, 5682, 5683>,
    <5677, 5683, 5684>,
    <5677, 5685, 5686>,
    <5677, 5686, 5678>,
    <5687, 5688, 5679>,
    <5687, 5679, 5678>,
    <5687, 5678, 5689>,
    <5687, 5689, 5690>,
    <5687, 5691, 5692>,
    <5687, 5692, 5693>,
    <5687, 5693, 5694>,
    <5687, 5694, 5688>,
    <5695, 5680, 5679>,
    <5695, 5679, 5688>,
    <5695, 5688, 5694>,
    <5695, 5694, 5696>,
    <5695, 5696, 5697>,
    <5695, 5697, 5698>,
    <5695, 5698, 5681>,
    <5695, 5681, 5680>,
    <5699, 5700, 5701>,
    <5699, 5701, 5702>,
    <5699, 5702, 5703>,
    <5699, 5703, 5704>,
    <5699, 5705, 5706>,
    <5699, 5706, 5707>,
    <5699, 5708, 5709>,
    <5699, 5709, 5700>,
    <5710, 5711, 5701>,
    <5710, 5701, 5700>,
    <5710, 5700, 5712>,
    <5710, 5712, 5713>,
    <5710, 5714, 5715>,
    <5710, 5715, 5716>,
    <5710, 5717, 5718>,
    <5710, 5718, 5711>,
    <5719, 5702, 5701>,
    <5719, 5701, 5711>,
    <5719, 5711, 5720>,
    <5719, 5720, 5721>,
    <5719, 5722, 5723>,
    <5719, 5723, 5724>,
    <5719, 5725, 5726>,
    <5719, 5726, 5702>,
    <5727, 5728, 5729>,
    <5727, 5729, 5730>,
    <5727, 5730, 5694>,
    <5727, 5694, 5693>,
    <5727, 5693, 5731>,
    <5727, 5731, 5606>,
    <5727, 5606, 5605>,
    <5727, 5605, 5728>,
    <5732, 5733, 5729>,
    <5732, 5729, 5728>,
    <5732, 5728, 5605>,
    <5732, 5605, 5619>,
    <5732, 5619, 5734>,
    <5732, 5734, 5735>,
    <5732, 5736, 5737>,
    <5732, 5737, 5733>,
    <5738, 5730, 5729>,
    <5738, 5729, 5733>,
    <5738, 5733, 5739>,
    <5738, 5739, 5740>,
    <5738, 5741, 5742>,
    <5738, 5742, 5696>,
    <5738, 5696, 5694>,
    <5738, 5694, 5730>,
    <5743, 5744, 5745>,
    <5743, 5745, 5746>,
    <5743, 5746, 5747>,
    <5743, 5747, 5748>,
    <5743, 5749, 5750>,
    <5743, 5750, 5682>,
    <5743, 5682, 5681>,
    <5743, 5681, 5744>,
    <5751, 5752, 5745>,
    <5751, 5745, 5744>,
    <5751, 5744, 5681>,
    <5751, 5681, 5698>,
    <5751, 5698, 5753>,
    <5751, 5753, 5754>,
    <5751, 5754, 5755>,
    <5751, 5755, 5752>,
    <5756, 5746, 5745>,
    <5756, 5745, 5752>,
    <5756, 5752, 5755>,
    <5756, 5755, 5757>,
    <5756, 5757, 5758>,
    <5756, 5758, 5759>,
    <5756, 5760, 5761>,
    <5756, 5761, 5746>,
    <5762, 5763, 5764>,
    <5762, 5764, 5765>,
    <5762, 5765, 5766>,
    <5762, 5766, 5767>,
    <5762, 5768, 5769>,
    <5762, 5769, 5770>,
    <5762, 5770, 5771>,
    <5762, 5771, 5763>,
    <5772, 5773, 5764>,
    <5772, 5764, 5763>,
    <5772, 5763, 5771>,
    <5772, 5771, 5774>,
    <5772, 5774, 5775>,
    <5772, 5775, 5670>,
    <5772, 5670, 5667>,
    <5772, 5667, 5773>,
    <5776, 5765, 5764>,
    <5776, 5764, 5773>,
    <5776, 5773, 5667>,
    <5776, 5667, 5666>,
    <5776, 5666, 5777>,
    <5776, 5777, 5778>,
    <5776, 5779, 5780>,
    <5776, 5780, 5765>,
    <5781, 5782, 5783>,
    <5781, 5783, 5784>,
    <5781, 5784, 5771>,
    <5781, 5771, 5770>,
    <5781, 5770, 5785>,
    <5781, 5785, 5786>,
    <5781, 5786, 5787>,
    <5781, 5787, 5782>,
    <5788, 5789, 5783>,
    <5788, 5783, 5782>,
    <5788, 5782, 5787>,
    <5788, 5787, 5790>,
    <5788, 5790, 5791>,
    <5788, 5791, 5792>,
    <5788, 5793, 5794>,
    <5788, 5794, 5789>,
    <5795, 5784, 5783>,
    <5795, 5783, 5789>,
    <5795, 5789, 5796>,
    <5795, 5796, 5797>,
    <5795, 5798, 5799>,
    <5795, 5799, 5774>,
    <5795, 5774, 5771>,
    <5795, 5771, 5784>,
    <5800, 5801, 5802>,
    <5800, 5802, 5803>,
    <5800, 5803, 5804>,
    <5800, 5804, 5805>,
    <5800, 5806, 5807>,
    <5800, 5807, 5808>,
    <5800, 5808, 5809>,
    <5800, 5809, 5801>,
    <5810, 5811, 5802>,
    <5810, 5802, 5801>,
    <5810, 5801, 5809>,
    <5810, 5809, 5812>,
    <5810, 5812, 5813>,
    <5810, 5813, 5790>,
    <5810, 5790, 5787>,
    <5810, 5787, 5811>,
    <5814, 5803, 5802>,
    <5814, 5802, 5811>,
    <5814, 5811, 5787>,
    <5814, 5787, 5786>,
    <5814, 5786, 5815>,
    <5814, 5815, 5816>,
    <5814, 5817, 5818>,
    <5814, 5818, 5803>,
    <5819, 5820, 5821>,
    <5819, 5821, 5822>,
    <5819, 5822, 5823>,
    <5819, 5823, 5824>,
    <5819, 5825, 5826>,
    <5819, 5826, 5827>,
    <5819, 5827, 5828>,
    <5819, 5828, 5820>,
    <5829, 5830, 5821>,
    <5829, 5821, 5820>,
    <5829, 5820, 5828>,
    <5829, 5828, 5831>,
    <5829, 5831, 5832>,
    <5829, 5832, 5812>,
    <5829, 5812, 5809>,
    <5829, 5809, 5830>,
    <5833, 5822, 5821>,
    <5833, 5821, 5830>,
    <5833, 5830, 5809>,
    <5833, 5809, 5808>,
    <5833, 5808, 5834>,
    <5833, 5834, 5835>,
    <5833, 5836, 5837>,
    <5833, 5837, 5822>,
    <5838, 5839, 5840>,
    <5838, 5840, 5841>,
    <5838, 5841, 5842>,
    <5838, 5842, 5843>,
    <5838, 5844, 5845>,
    <5838, 5845, 5846>,
    <5838, 5847, 5848>,
    <5838, 5848, 5839>,
    <5849, 5850, 5840>,
    <5849, 5840, 5839>,
    <5849, 5839, 5851>,
    <5849, 5851, 5852>,
    <5849, 5853, 5854>,
    <5849, 5854, 5855>,
    <5849, 5856, 5857>,
    <5849, 5857, 5850>,
    <5858, 5841, 5840>,
    <5858, 5840, 5850>,
    <5858, 5850, 5859>,
    <5858, 5859, 5860>,
    <5858, 5861, 5862>,
    <5858, 5862, 5863>,
    <5858, 5864, 5865>,
    <5858, 5865, 5841>,
    <5866, 5867, 5868>,
    <5866, 5868, 5869>,
    <5866, 5869, 5828>,
    <5866, 5828, 5827>,
    <5866, 5827, 5870>,
    <5866, 5870, 5757>,
    <5866, 5757, 5755>,
    <5866, 5755, 5867>,
    <5871, 5872, 5868>,
    <5871, 5868, 5867>,
    <5871, 5867, 5755>,
    <5871, 5755, 5754>,
    <5871, 5754, 5873>,
    <5871, 5873, 5874>,
    <5871, 5875, 5876>,
    <5871, 5876, 5872>,
    <5877, 5869, 5868>,
    <5877, 5868, 5872>,
    <5877, 5872, 5878>,
    <5877, 5878, 5879>,
    <5877, 5880, 5881>,
    <5877, 5881, 5831>,
    <5877, 5831, 5828>,
    <5877, 5828, 5869>,
    <5882, 5883, 5884>,
    <5882, 5884, 5885>,
    <5882, 5885, 5886>,
    <5882, 5886, 5887>,
    <5882, 5887, 5888>,
    <5882, 5888, 5889>,
    <5882, 5890, 5891>,
    <5882, 5891, 5883>,
    <5892, 5893, 5884>,
    <5892, 5884, 5883>,
    <5892, 5883, 5894>,
    <5892, 5894, 5895>,
    <5892, 5896, 5897>,
    <5892, 5897, 5898>,
    <5892, 5898, 5899>,
    <5892, 5899, 5893>,
    <5900, 5885, 5884>,
    <5900, 5884, 5893>,
    <5900, 5893, 5899>,
    <5900, 5899, 5901>,
    <5900, 5901, 5902>,
    <5900, 5902, 5903>,
    <5900, 5903, 5886>,
    <5900, 5886, 5885>,
    <5904, 5905, 5906>,
    <5904, 5906, 5907>,
    <5904, 5907, 5908>,
    <5904, 5908, 5909>,
    <5904, 5910, 5911>,
    <5904, 5911, 5912>,
    <5904, 5912, 5913>,
    <5904, 5913, 5905>,
    <5914, 5915, 5906>,
    <5914, 5906, 5905>,
    <5914, 5905, 5913>,
    <5914, 5913, 5916>,
    <5914, 5916, 5902>,
    <5914, 5902, 5901>,
    <5914, 5901, 5899>,
    <5914, 5899, 5915>,
    <5917, 5907, 5906>,
    <5917, 5906, 5915>,
    <5917, 5915, 5899>,
    <5917, 5899, 5898>,
    <5917, 5898, 5918>,
    <5917, 5918, 5919>,
    <5917, 5920, 5921>,
    <5917, 5921, 5907>,
    <5922, 5923, 5924>,
    <5922, 5924, 5925>,
    <5922, 5925, 5926>,
    <5922, 5926, 5927>,
    <5922, 5928, 5929>,
    <5922, 5929, 5930>,
    <5922, 5930, 5931>,
    <5922, 5931, 5923>,
    <5932, 5933, 5924>,
    <5932, 5924, 5923>,
    <5932, 5923, 5931>,
    <5932, 5931, 5934>,
    <5932, 5934, 5935>,
    <5932, 5935, 5936>,
    <5932, 5936, 5937>,
    <5932, 5937, 5933>,
    <5938, 5925, 5924>,
    <5938, 5924, 5933>,
    <5938, 5933, 5937>,
    <5938, 5937, 5939>,
    <5938, 5939, 5940>,
    <5938, 5940, 5941>,
    <5938, 5942, 5943>,
    <5938, 5943, 5925>,
    <5944, 5945, 5946>,
    <5944, 5946, 5947>,
    <5944, 5947, 5931>,
    <5944, 5931, 5930>,
    <5944, 5930, 5948>,
    <5944, 5948, 5949>,
    <5944, 5950, 5951>,
    <5944, 5951, 5945>,
    <5952, 5953, 5946>,
    <5952, 5946, 5945>,
    <5952, 5945, 5954>,
    <5952, 5954, 5955>,
    <5952, 5956, 5957>,
    <5952, 5957, 5958>,
    <5952, 5958, 5959>,
    <5952, 5959, 5953>,
    <5960, 5947, 5946>,
    <5960, 5946, 5953>,
    <5960, 5953, 5959>,
    <5960, 5959, 5961>,
    <5960, 5961, 5935>,
    <5960, 5935, 5934>,
    <5960, 5934, 5931>,
    <5960, 5931, 5947>,
    <5962, 5963, 5964>,
    <5962, 5964, 5965>,
    <5962, 5965, 5959>,
    <5962, 5959, 5958>,
    <5962, 5958, 5966>,
    <5962, 5966, 5887>,
    <5962, 5887, 5886>,
    <5962, 5886, 5963>,
    <5967, 5968, 5964>,
    <5967, 5964, 5963>,
    <5967, 5963, 5886>,
    <5967, 5886, 5903>,
    <5967, 5903, 5902>,
    <5967, 5902, 5969>,
    <5967, 5969, 5970>,
    <5967, 5970, 5968>,
    <5971, 5965, 5964>,
    <5971, 5964, 5968>,
    <5971, 5968, 5970>,
    <5971, 5970, 5972>,
    <5971, 5972, 5935>,
    <5971, 5935, 5961>,
    <5971, 5961, 5959>,
    <5971, 5959, 5965>,
    <5973, 5974, 5975>,
    <5973, 5975, 5976>,
    <5973, 5976, 5913>,
    <5973, 5913, 5912>,
    <5973, 5912, 5977>,
    <5973, 5977, 5978>,
    <5973, 5978, 5979>,
    <5973, 5979, 5974>,
    <5980, 5981, 5975>,
    <5980, 5975, 5974>,
    <5980, 5974, 5979>,
    <5980, 5979, 5982>,
    <5980, 5982, 5983>,
    <5980, 5983, 5984>,
    <5980, 5984, 5985>,
    <5980, 5985, 5981>,
    <5986, 5976, 5975>,
    <5986, 5975, 5981>,
    <5986, 5981, 5985>,
    <5986, 5985, 5987>,
    <5986, 5987, 5902>,
    <5986, 5902, 5916>,
    <5986, 5916, 5913>,
    <5986, 5913, 5976>,
    <5988, 5989, 5990>,
    <5988, 5990, 5991>,
    <5988, 5991, 5979>,
    <5988, 5979, 5978>,
    <5988, 5978, 5992>,
    <5988, 5992, 5993>,
    <5988, 5994, 5995>,
    <5988, 5995, 5989>,
    <5996, 5997, 5990>,
    <5996, 5990, 5989>,
    <5996, 5989, 5998>,
    <5996, 5998, 5999>,
    <5996, 6000, 6001>,
    <5996, 6001, 6002>,
    <5996, 6002, 6003>,
    <5996, 6003, 5997>,
    <6004, 5991, 5990>,
    <6004, 5990, 5997>,
    <6004, 5997, 6003>,
    <6004, 6003, 6005>,
    <6004, 6005, 5983>,
    <6004, 5983, 5982>,
    <6004, 5982, 5979>,
    <6004, 5979, 5991>,
    <6006, 6007, 6008>,
    <6006, 6008, 6009>,
    <6006, 6009, 6003>,
    <6006, 6003, 6002>,
    <6006, 6002, 6010>,
    <6006, 6010, 6011>,
    <6006, 6012, 6013>,
    <6006, 6013, 6007>,
    <6014, 6015, 6008>,
    <6014, 6008, 6007>,
    <6014, 6007, 6016>,
    <6014, 6016, 6017>,
    <6014, 6018, 6019>,
    <6014, 6019, 6020>,
    <6014, 6020, 6021>,
    <6014, 6021, 6015>,
    <6022, 6009, 6008>,
    <6022, 6008, 6015>,
    <6022, 6015, 6021>,
    <6022, 6021, 6023>,
    <6022, 6023, 5983>,
    <6022, 5983, 6005>,
    <6022, 6005, 6003>,
    <6022, 6003, 6009>,
    <6024, 6025, 6026>,
    <6024, 6026, 6027>,
    <6024, 6027, 5985>,
    <6024, 5985, 5984>,
    <6024, 5984, 5983>,
    <6024, 5983, 6028>,
    <6024, 6028, 6029>,
    <6024, 6029, 6025>,
    <6030, 6031, 6026>,
    <6030, 6026, 6025>,
    <6030, 6025, 6029>,
    <6030, 6029, 6032>,
    <6030, 6032, 6033>,
    <6030, 6033, 6034>,
    <6030, 6034, 6035>,
    <6030, 6035, 6031>,
    <6036, 6027, 6026>,
    <6036, 6026, 6031>,
    <6036, 6031, 6035>,
    <6036, 6035, 6037>,
    <6036, 6037, 5902>,
    <6036, 5902, 5987>,
    <6036, 5987, 5985>,
    <6036, 5985, 6027>,
    <6038, 6039, 6040>,
    <6038, 6040, 6041>,
    <6038, 6041, 6042>,
    <6038, 6042, 6043>,
    <6038, 6043, 6044>,
    <6038, 6044, 6045>,
    <6038, 6046, 6047>,
    <6038, 6047, 6039>,
    <6048, 6049, 6040>,
    <6048, 6040, 6039>,
    <6048, 6039, 6050>,
    <6048, 6050, 6051>,
    <6048, 6052, 6053>,
    <6048, 6053, 6054>,
    <6048, 6054, 6055>,
    <6048, 6055, 6049>,
    <6056, 6041, 6040>,
    <6056, 6040, 6049>,
    <6056, 6049, 6055>,
    <6056, 6055, 6057>,
    <6056, 6057, 6058>,
    <6056, 6058, 6059>,
    <6056, 6059, 6042>,
    <6056, 6042, 6041>,
    <6060, 6061, 6062>,
    <6060, 6062, 6063>,
    <6060, 6063, 6064>,
    <6060, 6064, 6065>,
    <6060, 6065, 6066>,
    <6060, 6066, 6067>,
    <6060, 6068, 6069>,
    <6060, 6069, 6061>,
    <6070, 6071, 6062>,
    <6070, 6062, 6061>,
    <6070, 6061, 6072>,
    <6070, 6072, 6073>,
    <6070, 6074, 6075>,
    <6070, 6075, 6043>,
    <6070, 6043, 6042>,
    <6070, 6042, 6071>,
    <6076, 6063, 6062>,
    <6076, 6062, 6071>,
    <6076, 6071, 6042>,
    <6076, 6042, 6059>,
    <6076, 6059, 6058>,
    <6076, 6058, 6077>,
    <6076, 6077, 6064>,
    <6076, 6064, 6063>,
    <6078, 6079, 6080>,
    <6078, 6080, 6081>,
    <6078, 6081, 6082>,
    <6078, 6082, 6083>,
    <6078, 6083, 6084>,
    <6078, 6084, 6085>,
    <6078, 6086, 6087>,
    <6078, 6087, 6079>,
    <6088, 6089, 6080>,
    <6088, 6080, 6079>,
    <6088, 6079, 6090>,
    <6088, 6090, 6091>,
    <6088, 6092, 6093>,
    <6088, 6093, 5939>,
    <6088, 5939, 5937>,
    <6088, 5937, 6089>,
    <6094, 6081, 6080>,
    <6094, 6080, 6089>,
    <6094, 6089, 5937>,
    <6094, 5937, 5936>,
    <6094, 5936, 5935>,
    <6094, 5935, 6095>,
    <6094, 6095, 6082>,
    <6094, 6082, 6081>,
    <6096, 6097, 6098>,
    <6096, 6098, 6099>,
    <6096, 6099, 5970>,
    <6096, 5970, 5969>,
    <6096, 5969, 5902>,
    <6096, 5902, 6100>,
    <6096, 6100, 6101>,
    <6096, 6101, 6097>,
    <6102, 6103, 6098>,
    <6102, 6098, 6097>,
    <6102, 6097, 6101>,
    <6102, 6101, 6104>,
    <6102, 6104, 6105>,
    <6102, 6105, 6106>,
    <6102, 6106, 6107>,
    <6102, 6107, 6103>,
    <6108, 6099, 6098>,
    <6108, 6098, 6103>,
    <6108, 6103, 6107>,
    <6108, 6107, 6109>,
    <6108, 6109, 5935>,
    <6108, 5935, 5972>,
    <6108, 5972, 5970>,
    <6108, 5970, 6099>,
    <6110, 6111, 6112>,
    <6110, 6112, 6113>,
    <6110, 6113, 6101>,
    <6110, 6101, 6100>,
    <6110, 6100, 5902>,
    <6110, 5902, 6037>,
    <6110, 6037, 6035>,
    <6110, 6035, 6111>,
    <6114, 6115, 6112>,
    <6114, 6112, 6111>,
    <6114, 6111, 6035>,
    <6114, 6035, 6034>,
    <6114, 6034, 6033>,
    <6114, 6033, 6116>,
    <6114, 6116, 6117>,
    <6114, 6117, 6115>,
    <6118, 6113, 6112>,
    <6118, 6112, 6115>,
    <6118, 6115, 6117>,
    <6118, 6117, 6119>,
    <6118, 6119, 6105>,
    <6118, 6105, 6104>,
    <6118, 6104, 6101>,
    <6118, 6101, 6113>,
    <6120, 6121, 6122>,
    <6120, 6122, 6123>,
    <6120, 6123, 6124>,
    <6120, 6124, 6125>,
    <6120, 6125, 6126>,
    <6120, 6126, 6127>,
    <6120, 6127, 6128>,
    <6120, 6128, 6121>,
    <6129, 6130, 6122>,
    <6129, 6122, 6121>,
    <6129, 6121, 6128>,
    <6129, 6128, 6131>,
    <6129, 6131, 6132>,
    <6129, 6132, 6133>,
    <6129, 6133, 6134>,
    <6129, 6134, 6130>,
    <6135, 6123, 6122>,
    <6135, 6122, 6130>,
    <6135, 6130, 6134>,
    <6135, 6134, 6136>,
    <6135, 6136, 6033>,
    <6135, 6033, 6137>,
    <6135, 6137, 6124>,
    <6135, 6124, 6123>,
    <6138, 6139, 6140>,
    <6138, 6140, 6141>,
    <6138, 6141, 6029>,
    <6138, 6029, 6028>,
    <6138, 6028, 5983>,
    <6138, 5983, 6142>,
    <6138, 6142, 6143>,
    <6138, 6143, 6139>,
    <6144, 6145, 6140>,
    <6144, 6140, 6139>,
    <6144, 6139, 6143>,
    <6144, 6143, 6146>,
    <6144, 6146, 6126>,
    <6144, 6126, 6125>,
    <6144, 6125, 6124>,
    <6144, 6124, 6145>,
    <6147, 6141, 6140>,
    <6147, 6140, 6145>,
    <6147, 6145, 6124>,
    <6147, 6124, 6137>,
    <6147, 6137, 6033>,
    <6147, 6033, 6032>,
    <6147, 6032, 6029>,
    <6147, 6029, 6141>,
    <6148, 6149, 6150>,
    <6148, 6150, 6151>,
    <6148, 6151, 6152>,
    <6148, 6152, 6153>,
    <6148, 6154, 6155>,
    <6148, 6155, 6156>,
    <6148, 6156, 6157>,
    <6148, 6157, 6149>,
    <6158, 6159, 6150>,
    <6158, 6150, 6149>,
    <6158, 6149, 6157>,
    <6158, 6157, 6160>,
    <6158, 6160, 5983>,
    <6158, 5983, 6023>,
    <6158, 6023, 6021>,
    <6158, 6021, 6159>,
    <6161, 6151, 6150>,
    <6161, 6150, 6159>,
    <6161, 6159, 6021>,
    <6161, 6021, 6020>,
    <6161, 6020, 6162>,
    <6161, 6162, 6163>,
    <6161, 6164, 6165>,
    <6161, 6165, 6151>,
    <6166, 6167, 6168>,
    <6166, 6168, 6169>,
    <6166, 6169, 6170>,
    <6166, 6170, 6171>,
    <6166, 6171, 6172>,
    <6166, 6172, 6173>,
    <6166, 6174, 6175>,
    <6166, 6175, 6167>,
    <6176, 6177, 6168>,
    <6176, 6168, 6167>,
    <6176, 6167, 6178>,
    <6176, 6178, 6179>,
    <6176, 6180, 6181>,
    <6176, 6181, 6182>,
    <6176, 6182, 6183>,
    <6176, 6183, 6177>,
    <6184, 6169, 6168>,
    <6184, 6168, 6177>,
    <6184, 6177, 6183>,
    <6184, 6183, 6185>,
    <6184, 6185, 6186>,
    <6184, 6186, 6187>,
    <6184, 6187, 6170>,
    <6184, 6170, 6169>,
    <6188, 6189, 6190>,
    <6188, 6190, 6191>,
    <6188, 6191, 6192>,
    <6188, 6192, 6193>,
    <6188, 6193, 6194>,
    <6188, 6194, 6195>,
    <6188, 6196, 6197>,
    <6188, 6197, 6189>,
    <6198, 6199, 6190>,
    <6198, 6190, 6189>,
    <6198, 6189, 6200>,
    <6198, 6200, 6201>,
    <6198, 6202, 6203>,
    <6198, 6203, 6171>,
    <6198, 6171, 6170>,
    <6198, 6170, 6199>,
    <6204, 6191, 6190>,
    <6204, 6190, 6199>,
    <6204, 6199, 6170>,
    <6204, 6170, 6187>,
    <6204, 6187, 6186>,
    <6204, 6186, 6205>,
    <6204, 6205, 6192>,
    <6204, 6192, 6191>,
    <6206, 6207, 6208>,
    <6206, 6208, 6209>,
    <6206, 6209, 6055>,
    <6206, 6055, 6054>,
    <6206, 6054, 6210>,
    <6206, 6210, 6193>,
    <6206, 6193, 6192>,
    <6206, 6192, 6207>,
    <6211, 6212, 6208>,
    <6211, 6208, 6207>,
    <6211, 6207, 6192>,
    <6211, 6192, 6205>,
    <6211, 6205, 6186>,
    <6211, 6186, 6213>,
    <6211, 6213, 6214>,
    <6211, 6214, 6212>,
    <6215, 6209, 6208>,
    <6215, 6208, 6212>,
    <6215, 6212, 6214>,
    <6215, 6214, 6216>,
    <6215, 6216, 6058>,
    <6215, 6058, 6057>,
    <6215, 6057, 6055>,
    <6215, 6055, 6209>,
    <6217, 6218, 6219>,
    <6217, 6219, 6220>,
    <6217, 6220, 6221>,
    <6217, 6221, 6222>,
    <6217, 6222, 6223>,
    <6217, 6223, 6065>,
    <6217, 6065, 6064>,
    <6217, 6064, 6218>,
    <6224, 6225, 6219>,
    <6224, 6219, 6218>,
    <6224, 6218, 6064>,
    <6224, 6064, 6077>,
    <6224, 6077, 6058>,
    <6224, 6058, 6226>,
    <6224, 6226, 6227>,
    <6224, 6227, 6225>,
    <6228, 6220, 6219>,
    <6228, 6219, 6225>,
    <6228, 6225, 6227>,
    <6228, 6227, 6229>,
    <6228, 6229, 6230>,
    <6228, 6230, 6231>,
    <6228, 6231, 6221>,
    <6228, 6221, 6220>,
    <6232, 6233, 6234>,
    <6232, 6234, 6235>,
    <6232, 6235, 6236>,
    <6232, 6236, 6237>,
    <6232, 6237, 6230>,
    <6232, 6230, 6229>,
    <6232, 6229, 6227>,
    <6232, 6227, 6233>,
    <6238, 6239, 6234>,
    <6238, 6234, 6233>,
    <6238, 6233, 6227>,
    <6238, 6227, 6226>,
    <6238, 6226, 6058>,
    <6238, 6058, 6240>,
    <6238, 6240, 6241>,
    <6238, 6241, 6239>,
    <6242, 6235, 6234>,
    <6242, 6234, 6239>,
    <6242, 6239, 6241>,
    <6242, 6241, 6243>,
    <6242, 6243, 6244>,
    <6242, 6244, 6245>,
    <6242, 6245, 6236>,
    <6242, 6236, 6235>,
    <6246, 6247, 6248>,
    <6246, 6248, 6249>,
    <6246, 6249, 6117>,
    <6246, 6117, 6116>,
    <6246, 6116, 6033>,
    <6246, 6033, 6250>,
    <6246, 6250, 6251>,
    <6246, 6251, 6247>,
    <6252, 6253, 6248>,
    <6252, 6248, 6247>,
    <6252, 6247, 6251>,
    <6252, 6251, 6254>,
    <6252, 6254, 6255>,
    <6252, 6255, 6256>,
    <6252, 6256, 6257>,
    <6252, 6257, 6253>,
    <6258, 6249, 6248>,
    <6258, 6248, 6253>,
    <6258, 6253, 6257>,
    <6258, 6257, 6259>,
    <6258, 6259, 6105>,
    <6258, 6105, 6119>,
    <6258, 6119, 6117>,
    <6258, 6117, 6249>,
    <6260, 6261, 6262>,
    <6260, 6262, 6263>,
    <6260, 6263, 6251>,
    <6260, 6251, 6250>,
    <6260, 6250, 6033>,
    <6260, 6033, 6136>,
    <6260, 6136, 6134>,
    <6260, 6134, 6261>,
    <6264, 6265, 6262>,
    <6264, 6262, 6261>,
    <6264, 6261, 6134>,
    <6264, 6134, 6133>,
    <6264, 6133, 6132>,
    <6264, 6132, 6266>,
    <6264, 6266, 6267>,
    <6264, 6267, 6265>,
    <6268, 6263, 6262>,
    <6268, 6262, 6265>,
    <6268, 6265, 6267>,
    <6268, 6267, 6269>,
    <6268, 6269, 6255>,
    <6268, 6255, 6254>,
    <6268, 6254, 6251>,
    <6268, 6251, 6263>,
    <6270, 6271, 6272>,
    <6270, 6272, 6273>,
    <6270, 6273, 6274>,
    <6270, 6274, 6275>,
    <6270, 6275, 6276>,
    <6270, 6276, 6277>,
    <6270, 6277, 6278>,
    <6270, 6278, 6271>,
    <6279, 6280, 6272>,
    <6279, 6272, 6271>,
    <6279, 6271, 6278>,
    <6279, 6278, 6281>,
    <6279, 6281, 6282>,
    <6279, 6282, 6283>,
    <6279, 6283, 6284>,
    <6279, 6284, 6280>,
    <6285, 6273, 6272>,
    <6285, 6272, 6280>,
    <6285, 6280, 6284>,
    <6285, 6284, 6286>,
    <6285, 6286, 6132>,
    <6285, 6132, 6287>,
    <6285, 6287, 6274>,
    <6285, 6274, 6273>,
    <6288, 6289, 6290>,
    <6288, 6290, 6291>,
    <6288, 6291, 6128>,
    <6288, 6128, 6127>,
    <6288, 6127, 6126>,
    <6288, 6126, 6292>,
    <6288, 6292, 6293>,
    <6288, 6293, 6289>,
    <6294, 6295, 6290>,
    <6294, 6290, 6289>,
    <6294, 6289, 6293>,
    <6294, 6293, 6296>,
    <6294, 6296, 6276>,
    <6294, 6276, 6275>,
    <6294, 6275, 6274>,
    <6294, 6274, 6295>,
    <6297, 6291, 6290>,
    <6297, 6290, 6295>,
    <6297, 6295, 6274>,
    <6297, 6274, 6287>,
    <6297, 6287, 6132>,
    <6297, 6132, 6131>,
    <6297, 6131, 6128>,
    <6297, 6128, 6291>,
    <6298, 6299, 6300>,
    <6298, 6300, 6301>,
    <6298, 6301, 6302>,
    <6298, 6302, 6303>,
    <6298, 6303, 6058>,
    <6298, 6058, 6216>,
    <6298, 6216, 6214>,
    <6298, 6214, 6299>,
    <6304, 6305, 6300>,
    <6304, 6300, 6299>,
    <6304, 6299, 6214>,
    <6304, 6214, 6213>,
    <6304, 6213, 6186>,
    <6304, 6186, 6306>,
    <6304, 6306, 6307>,
    <6304, 6307, 6305>,
    <6308, 6301, 6300>,
    <6308, 6300, 6305>,
    <6308, 6305, 6307>,
    <6308, 6307, 6309>,
    <6308, 6309, 6310>,
    <6308, 6310, 6311>,
    <6308, 6311, 6302>,
    <6308, 6302, 6301>,
    <6312, 6313, 6314>,
    <6312, 6314, 6315>,
    <6312, 6315, 6241>,
    <6312, 6241, 6240>,
    <6312, 6240, 6058>,
    <6312, 6058, 6303>,
    <6312, 6303, 6302>,
    <6312, 6302, 6313>,
    <6316, 6317, 6314>,
    <6316, 6314, 6313>,
    <6316, 6313, 6302>,
    <6316, 6302, 6311>,
    <6316, 6311, 6310>,
    <6316, 6310, 6318>,
    <6316, 6318, 6319>,
    <6316, 6319, 6317>,
    <6320, 6315, 6314>,
    <6320, 6314, 6317>,
    <6320, 6317, 6319>,
    <6320, 6319, 6321>,
    <6320, 6321, 6244>,
    <6320, 6244, 6243>,
    <6320, 6243, 6241>,
    <6320, 6241, 6315>,
    <6322, 6323, 6324>,
    <6322, 6324, 6325>,
    <6322, 6325, 6326>,
    <6322, 6326, 6327>,
    <6322, 6327, 6328>,
    <6322, 6328, 6329>,
    <6322, 6329, 6330>,
    <6322, 6330, 6323>,
    <6331, 6332, 6324>,
    <6331, 6324, 6323>,
    <6331, 6323, 6330>,
    <6331, 6330, 6333>,
    <6331, 6333, 6244>,
    <6331, 6244, 6334>,
    <6331, 6334, 6335>,
    <6331, 6335, 6332>,
    <6336, 6325, 6324>,
    <6336, 6324, 6332>,
    <6336, 6332, 6335>,
    <6336, 6335, 6337>,
    <6336, 6337, 6338>,
    <6336, 6338, 6339>,
    <6336, 6339, 6326>,
    <6336, 6326, 6325>,
    <6340, 6341, 6342>,
    <6340, 6342, 6343>,
    <6340, 6343, 6344>,
    <6340, 6344, 6345>,
    <6340, 6345, 6230>,
    <6340, 6230, 6237>,
    <6340, 6237, 6236>,
    <6340, 6236, 6341>,
    <6346, 6347, 6342>,
    <6346, 6342, 6341>,
    <6346, 6341, 6236>,
    <6346, 6236, 6245>,
    <6346, 6245, 6244>,
    <6346, 6244, 6333>,
    <6346, 6333, 6330>,
    <6346, 6330, 6347>,
    <6348, 6343, 6342>,
    <6348, 6342, 6347>,
    <6348, 6347, 6330>,
    <6348, 6330, 6329>,
    <6348, 6329, 6328>,
    <6348, 6328, 6349>,
    <6348, 6349, 6344>,
    <6348, 6344, 6343>,
    <6350, 6351, 6352>,
    <6350, 6352, 6353>,
    <6350, 6353, 6354>,
    <6350, 6354, 6355>,
    <6350, 6355, 6356>,
    <6350, 6356, 6357>,
    <6350, 6358, 6359>,
    <6350, 6359, 6351>,
    <6360, 6361, 6352>,
    <6360, 6352, 6351>,
    <6360, 6351, 6362>,
    <6360, 6362, 6363>,
    <6360, 6364, 6365>,
    <6360, 6365, 6222>,
    <6360, 6222, 6221>,
    <6360, 6221, 6361>,
    <6366, 6353, 6352>,
    <6366, 6352, 6361>,
    <6366, 6361, 6221>,
    <6366, 6221, 6231>,
    <6366, 6231, 6230>,
    <6366, 6230, 6367>,
    <6366, 6367, 6354>,
    <6366, 6354, 6353>,
    <6368, 6369, 6370>,
    <6368, 6370, 6371>,
    <6368, 6371, 6267>,
    <6368, 6267, 6266>,
    <6368, 6266, 6132>,
    <6368, 6132, 6372>,
    <6368, 6372, 6373>,
    <6368, 6373, 6369>,
    <6374, 6375, 6370>,
    <6374, 6370, 6369>,
    <6374, 6369, 6373>,
    <6374, 6373, 6376>,
    <6374, 6376, 6377>,
    <6374, 6377, 6378>,
    <6374, 6378, 6379>,
    <6374, 6379, 6375>,
    <6380, 6371, 6370>,
    <6380, 6370, 6375>,
    <6380, 6375, 6379>,
    <6380, 6379, 6381>,
    <6380, 6381, 6255>,
    <6380, 6255, 6269>,
    <6380, 6269, 6267>,
    <6380, 6267, 6371>,
    <6382, 6383, 6384>,
    <6382, 6384, 6385>,
    <6382, 6385, 6373>,
    <6382, 6373, 6372>,
    <6382, 6372, 6132>,
    <6382, 6132, 6286>,
    <6382, 6286, 6284>,
    <6382, 6284, 6383>,
    <6386, 6387, 6384>,
    <6386, 6384, 6383>,
    <6386, 6383, 6284>,
    <6386, 6284, 6283>,
    <6386, 6283, 6282>,
    <6386, 6282, 6388>,
    <6386, 6388, 6389>,
    <6386, 6389, 6387>,
    <6390, 6385, 6384>,
    <6390, 6384, 6387>,
    <6390, 6387, 6389>,
    <6390, 6389, 6391>,
    <6390, 6391, 6377>,
    <6390, 6377, 6376>,
    <6390, 6376, 6373>,
    <6390, 6373, 6385>,
    <6392, 6393, 6394>,
    <6392, 6394, 6395>,
    <6392, 6395, 6396>,
    <6392, 6396, 6397>,
    <6392, 6397, 6398>,
    <6392, 6398, 6399>,
    <6392, 6399, 6400>,
    <6392, 6400, 6393>,
    <6401, 6402, 6394>,
    <6401, 6394, 6393>,
    <6401, 6393, 6400>,
    <6401, 6400, 6403>,
    <6401, 6403, 6404>,
    <6401, 6404, 6405>,
    <6401, 6405, 6406>,
    <6401, 6406, 6402>,
    <6407, 6395, 6394>,
    <6407, 6394, 6402>,
    <6407, 6402, 6406>,
    <6407, 6406, 6408>,
    <6407, 6408, 6282>,
    <6407, 6282, 6409>,
    <6407, 6409, 6396>,
    <6407, 6396, 6395>,
    <6410, 6411, 6412>,
    <6410, 6412, 6413>,
    <6410, 6413, 6278>,
    <6410, 6278, 6277>,
    <6410, 6277, 6276>,
    <6410, 6276, 6414>,
    <6410, 6414, 6415>,
    <6410, 6415, 6411>,
    <6416, 6417, 6412>,
    <6416, 6412, 6411>,
    <6416, 6411, 6415>,
    <6416, 6415, 6418>,
    <6416, 6418, 6398>,
    <6416, 6398, 6397>,
    <6416, 6397, 6396>,
    <6416, 6396, 6417>,
    <6419, 6413, 6412>,
    <6419, 6412, 6417>,
    <6419, 6417, 6396>,
    <6419, 6396, 6409>,
    <6419, 6409, 6282>,
    <6419, 6282, 6281>,
    <6419, 6281, 6278>,
    <6419, 6278, 6413>,
    <6420, 6421, 6422>,
    <6420, 6422, 6423>,
    <6420, 6423, 6424>,
    <6420, 6424, 6425>,
    <6420, 6426, 6427>,
    <6420, 6427, 6428>,
    <6420, 6428, 6429>,
    <6420, 6429, 6421>,
    <6430, 6431, 6422>,
    <6430, 6422, 6421>,
    <6430, 6421, 6429>,
    <6430, 6429, 6432>,
    <6430, 6432, 6433>,
    <6430, 6433, 6434>,
    <6430, 6434, 6435>,
    <6430, 6435, 6431>,
    <6436, 6423, 6422>,
    <6436, 6422, 6431>,
    <6436, 6431, 6435>,
    <6436, 6435, 6437>,
    <6436, 6437, 6438>,
    <6436, 6438, 6439>,
    <6436, 6440, 6441>,
    <6436, 6441, 6423>,
    <6442, 6443, 6444>,
    <6442, 6444, 6445>,
    <6442, 6445, 6429>,
    <6442, 6429, 6428>,
    <6442, 6428, 6446>,
    <6442, 6446, 6447>,
    <6442, 6448, 6449>,
    <6442, 6449, 6443>,
    <6450, 6451, 6444>,
    <6450, 6444, 6443>,
    <6450, 6443, 6452>,
    <6450, 6452, 6453>,
    <6450, 6454, 6455>,
    <6450, 6455, 6456>,
    <6450, 6456, 6457>,
    <6450, 6457, 6451>,
    <6458, 6445, 6444>,
    <6458, 6444, 6451>,
    <6458, 6451, 6457>,
    <6458, 6457, 6459>,
    <6458, 6459, 6433>,
    <6458, 6433, 6432>,
    <6458, 6432, 6429>,
    <6458, 6429, 6445>,
    <6460, 6461, 6462>,
    <6460, 6462, 6463>,
    <6460, 6463, 6457>,
    <6460, 6457, 6456>,
    <6460, 6456, 6464>,
    <6460, 6464, 6083>,
    <6460, 6083, 6082>,
    <6460, 6082, 6461>,
    <6465, 6466, 6462>,
    <6465, 6462, 6461>,
    <6465, 6461, 6082>,
    <6465, 6082, 6095>,
    <6465, 6095, 5935>,
    <6465, 5935, 6467>,
    <6465, 6467, 6468>,
    <6465, 6468, 6466>,
    <6469, 6463, 6462>,
    <6469, 6462, 6466>,
    <6469, 6466, 6468>,
    <6469, 6468, 6470>,
    <6469, 6470, 6433>,
    <6469, 6433, 6459>,
    <6469, 6459, 6457>,
    <6469, 6457, 6463>,
    <6471, 6472, 6473>,
    <6471, 6473, 6474>,
    <6471, 6474, 6157>,
    <6471, 6157, 6156>,
    <6471, 6156, 6475>,
    <6471, 6475, 6476>,
    <6471, 6476, 6477>,
    <6471, 6477, 6472>,
    <6478, 6479, 6473>,
    <6478, 6473, 6472>,
    <6478, 6472, 6477>,
    <6478, 6477, 6480>,
    <6478, 6480, 6481>,
    <6478, 6481, 6482>,
    <6478, 6482, 6483>,
    <6478, 6483, 6479>,
    <6484, 6474, 6473>,
    <6484, 6473, 6479>,
    <6484, 6479, 6483>,
    <6484, 6483, 6485>,
    <6484, 6485, 5983>,
    <6484, 5983, 6160>,
    <6484, 6160, 6157>,
    <6484, 6157, 6474>,
    <6486, 6487, 6488>,
    <6486, 6488, 6489>,
    <6486, 6489, 6477>,
    <6486, 6477, 6476>,
    <6486, 6476, 6490>,
    <6486, 6490, 6491>,
    <6486, 6492, 6493>,
    <6486, 6493, 6487>,
    <6494, 6495, 6488>,
    <6494, 6488, 6487>,
    <6494, 6487, 6496>,
    <6494, 6496, 6497>,
    <6494, 6498, 6499>,
    <6494, 6499, 6500>,
    <6494, 6500, 6501>,
    <6494, 6501, 6495>,
    <6502, 6489, 6488>,
    <6502, 6488, 6495>,
    <6502, 6495, 6501>,
    <6502, 6501, 6503>,
    <6502, 6503, 6481>,
    <6502, 6481, 6480>,
    <6502, 6480, 6477>,
    <6502, 6477, 6489>,
    <6504, 6505, 6506>,
    <6504, 6506, 6507>,
    <6504, 6507, 6483>,
    <6504, 6483, 6482>,
    <6504, 6482, 6481>,
    <6504, 6481, 6508>,
    <6504, 6508, 6509>,
    <6504, 6509, 6505>,
    <6510, 6511, 6506>,
    <6510, 6506, 6505>,
    <6510, 6505, 6509>,
    <6510, 6509, 6512>,
    <6510, 6512, 6126>,
    <6510, 6126, 6146>,
    <6510, 6146, 6143>,
    <6510, 6143, 6511>,
    <6513, 6507, 6506>,
    <6513, 6506, 6511>,
    <6513, 6511, 6143>,
    <6513, 6143, 6142>,
    <6513, 6142, 5983>,
    <6513, 5983, 6485>,
    <6513, 6485, 6483>,
    <6513, 6483, 6507>,
    <6514, 6515, 6516>,
    <6514, 6516, 6517>,
    <6514, 6517, 6501>,
    <6514, 6501, 6500>,
    <6514, 6500, 6518>,
    <6514, 6518, 6519>,
    <6514, 6520, 6521>,
    <6514, 6521, 6515>,
    <6522, 6523, 6516>,
    <6522, 6516, 6515>,
    <6522, 6515, 6524>,
    <6522, 6524, 6525>,
    <6522, 6526, 6527>,
    <6522, 6527, 6528>,
    <6522, 6528, 6529>,
    <6522, 6529, 6523>,
    <6530, 6517, 6516>,
    <6530, 6516, 6523>,
    <6530, 6523, 6529>,
    <6530, 6529, 6531>,
    <6530, 6531, 6481>,
    <6530, 6481, 6503>,
    <6530, 6503, 6501>,
    <6530, 6501, 6517>,
    <6532, 6533, 6534>,
    <6532, 6534, 6535>,
    <6532, 6535, 6536>,
    <6532, 6536, 6537>,
    <6532, 6537, 6244>,
    <6532, 6244, 6321>,
    <6532, 6321, 6319>,
    <6532, 6319, 6533>,
    <6538, 6539, 6534>,
    <6538, 6534, 6533>,
    <6538, 6533, 6319>,
    <6538, 6319, 6318>,
    <6538, 6318, 6310>,
    <6538, 6310, 6540>,
    <6538, 6540, 6541>,
    <6538, 6541, 6539>,
    <6542, 6535, 6534>,
    <6542, 6534, 6539>,
    <6542, 6539, 6541>,
    <6542, 6541, 6543>,
    <6542, 6543, 6544>,
    <6542, 6544, 6545>,
    <6542, 6545, 6536>,
    <6542, 6536, 6535>,
    <6546, 6547, 6548>,
    <6546, 6548, 6549>,
    <6546, 6549, 6335>,
    <6546, 6335, 6334>,
    <6546, 6334, 6244>,
    <6546, 6244, 6537>,
    <6546, 6537, 6536>,
    <6546, 6536, 6547>,
    <6550, 6551, 6548>,
    <6550, 6548, 6547>,
    <6550, 6547, 6536>,
    <6550, 6536, 6545>,
    <6550, 6545, 6544>,
    <6550, 6544, 6552>,
    <6550, 6552, 6553>,
    <6550, 6553, 6551>,
    <6554, 6549, 6548>,
    <6554, 6548, 6551>,
    <6554, 6551, 6553>,
    <6554, 6553, 6555>,
    <6554, 6555, 6338>,
    <6554, 6338, 6337>,
    <6554, 6337, 6335>,
    <6554, 6335, 6549>,
    <6556, 6557, 6558>,
    <6556, 6558, 6559>,
    <6556, 6559, 6560>,
    <6556, 6560, 6561>,
    <6556, 6561, 6562>,
    <6556, 6562, 6563>,
    <6556, 6563, 6564>,
    <6556, 6564, 6557>,
    <6565, 6566, 6558>,
    <6565, 6558, 6557>,
    <6565, 6557, 6564>,
    <6565, 6564, 6567>,
    <6565, 6567, 6338>,
    <6565, 6338, 6568>,
    <6565, 6568, 6569>,
    <6565, 6569, 6566>,
    <6570, 6559, 6558>,
    <6570, 6558, 6566>,
    <6570, 6566, 6569>,
    <6570, 6569, 6571>,
    <6570, 6571, 6572>,
    <6570, 6572, 6573>,
    <6570, 6573, 6560>,
    <6570, 6560, 6559>,
    <6574, 6575, 6576>,
    <6574, 6576, 6577>,
    <6574, 6577, 6578>,
    <6574, 6578, 6579>,
    <6574, 6579, 6328>,
    <6574, 6328, 6327>,
    <6574, 6327, 6326>,
    <6574, 6326, 6575>,
    <6580, 6581, 6576>,
    <6580, 6576, 6575>,
    <6580, 6575, 6326>,
    <6580, 6326, 6339>,
    <6580, 6339, 6338>,
    <6580, 6338, 6567>,
    <6580, 6567, 6564>,
    <6580, 6564, 6581>,
    <6582, 6577, 6576>,
    <6582, 6576, 6581>,
    <6582, 6581, 6564>,
    <6582, 6564, 6563>,
    <6582, 6563, 6562>,
    <6582, 6562, 6583>,
    <6582, 6583, 6578>,
    <6582, 6578, 6577>,
    <6584, 6585, 6586>,
    <6584, 6586, 6587>,
    <6584, 6587, 6389>,
    <6584, 6389, 6388>,
    <6584, 6388, 6282>,
    <6584, 6282, 6588>,
    <6584, 6588, 6589>,
    <6584, 6589, 6585>,
    <6590, 6591, 6586>,
    <6590, 6586, 6585>,
    <6590, 6585, 6589>,
    <6590, 6589, 6592>,
    <6590, 6592, 6593>,
    <6590, 6593, 6594>,
    <6590, 6594, 6595>,
    <6590, 6595, 6591>,
    <6596, 6587, 6586>,
    <6596, 6586, 6591>,
    <6596, 6591, 6595>,
    <6596, 6595, 6597>,
    <6596, 6597, 6377>,
    <6596, 6377, 6391>,
    <6596, 6391, 6389>,
    <6596, 6389, 6587>,
    <6598, 6599, 6600>,
    <6598, 6600, 6601>,
    <6598, 6601, 6589>,
    <6598, 6589, 6588>,
    <6598, 6588, 6282>,
    <6598, 6282, 6408>,
    <6598, 6408, 6406>,
    <6598, 6406, 6599>,
    <6602, 6603, 6600>,
    <6602, 6600, 6599>,
    <6602, 6599, 6406>,
    <6602, 6406, 6405>,
    <6602, 6405, 6404>,
    <6602, 6404, 6604>,
    <6602, 6604, 6605>,
    <6602, 6605, 6603>,
    <6606, 6601, 6600>,
    <6606, 6600, 6603>,
    <6606, 6603, 6605>,
    <6606, 6605, 6607>,
    <6606, 6607, 6593>,
    <6606, 6593, 6592>,
    <6606, 6592, 6589>,
    <6606, 6589, 6601>,
    <6608, 6609, 6610>,
    <6608, 6610, 6611>,
    <6608, 6611, 6612>,
    <6608, 6612, 6613>,
    <6608, 6613, 6614>,
    <6608, 6614, 6615>,
    <6608, 6615, 6616>,
    <6608, 6616, 6609>,
    <6617, 6618, 6610>,
    <6617, 6610, 6609>,
    <6617, 6609, 6616>,
    <6617, 6616, 6619>,
    <6617, 6619, 6620>,
    <6617, 6620, 6621>,
    <6617, 6621, 6622>,
    <6617, 6622, 6618>,
    <6623, 6611, 6610>,
    <6623, 6610, 6618>,
    <6623, 6618, 6622>,
    <6623, 6622, 6624>,
    <6623, 6624, 6404>,
    <6623, 6404, 6625>,
    <6623, 6625, 6612>,
    <6623, 6612, 6611>,
    <6626, 6627, 6628>,
    <6626, 6628, 6629>,
    <6626, 6629, 6400>,
    <6626, 6400, 6399>,
    <6626, 6399, 6398>,
    <6626, 6398, 6630>,
    <6626, 6630, 6631>,
    <6626, 6631, 6627>,
    <6632, 6633, 6628>,
    <6632, 6628, 6627>,
    <6632, 6627, 6631>,
    <6632, 6631, 6634>,
    <6632, 6634, 6614>,
    <6632, 6614, 6613>,
    <6632, 6613, 6612>,
    <6632, 6612, 6633>,
    <6635, 6629, 6628>,
    <6635, 6628, 6633>,
    <6635, 6633, 6612>,
    <6635, 6612, 6625>,
    <6635, 6625, 6404>,
    <6635, 6404, 6403>,
    <6635, 6403, 6400>,
    <6635, 6400, 6629>,
    <6636, 6637, 6638>,
    <6636, 6638, 6639>,
    <6636, 6639, 6640>,
    <6636, 6640, 6641>,
    <6636, 6641, 6642>,
    <6636, 6642, 6643>,
    <6636, 6644, 6645>,
    <6636, 6645, 6637>,
    <6646, 6647, 6638>,
    <6646, 6638, 6637>,
    <6646, 6637, 6648>,
    <6646, 6648, 6649>,
    <6646, 6650, 6651>,
    <6646, 6651, 6355>,
    <6646, 6355, 6354>,
    <6646, 6354, 6647>,
    <6652, 6639, 6638>,
    <6652, 6638, 6647>,
    <6652, 6647, 6354>,
    <6652, 6354, 6367>,
    <6652, 6367, 6230>,
    <6652, 6230, 6653>,
    <6652, 6653, 6640>,
    <6652, 6640, 6639>,
    <6654, 6655, 6656>,
    <6654, 6656, 6657>,
    <6654, 6657, 6605>,
    <6654, 6605, 6604>,
    <6654, 6604, 6404>,
    <6654, 6404, 6658>,
    <6654, 6658, 6659>,
    <6654, 6659, 6655>,
    <6660, 6661, 6656>,
    <6660, 6656, 6655>,
    <6660, 6655, 6659>,
    <6660, 6659, 6662>,
    <6660, 6662, 6663>,
    <6660, 6663, 6664>,
    <6660, 6664, 6665>,
    <6660, 6665, 6661>,
    <6666, 6657, 6656>,
    <6666, 6656, 6661>,
    <6666, 6661, 6665>,
    <6666, 6665, 6667>,
    <6666, 6667, 6593>,
    <6666, 6593, 6607>,
    <6666, 6607, 6605>,
    <6666, 6605, 6657>,
    <6668, 6669, 6670>,
    <6668, 6670, 6671>,
    <6668, 6671, 6659>,
    <6668, 6659, 6658>,
    <6668, 6658, 6404>,
    <6668, 6404, 6624>,
    <6668, 6624, 6622>,
    <6668, 6622, 6669>,
    <6672, 6673, 6670>,
    <6672, 6670, 6669>,
    <6672, 6669, 6622>,
    <6672, 6622, 6621>,
    <6672, 6621, 6620>,
    <6672, 6620, 6674>,
    <6672, 6674, 6675>,
    <6672, 6675, 6673>,
    <6676, 6671, 6670>,
    <6676, 6670, 6673>,
    <6676, 6673, 6675>,
    <6676, 6675, 6677>,
    <6676, 6677, 6663>,
    <6676, 6663, 6662>,
    <6676, 6662, 6659>,
    <6676, 6659, 6671>,
    <6678, 6679, 6680>,
    <6678, 6680, 6681>,
    <6678, 6681, 6682>,
    <6678, 6682, 6683>,
    <6678, 6683, 6684>,
    <6678, 6684, 6685>,
    <6678, 6685, 6686>,
    <6678, 6686, 6679>,
    <6687, 6688, 6680>,
    <6687, 6680, 6679>,
    <6687, 6679, 6686>,
    <6687, 6686, 6689>,
    <6687, 6689, 6690>,
    <6687, 6690, 6691>,
    <6687, 6691, 6692>,
    <6687, 6692, 6688>,
    <6693, 6681, 6680>,
    <6693, 6680, 6688>,
    <6693, 6688, 6692>,
    <6693, 6692, 6694>,
    <6693, 6694, 6620>,
    <6693, 6620, 6695>,
    <6693, 6695, 6682>,
    <6693, 6682, 6681>,
    <6696, 6697, 6698>,
    <6696, 6698, 6699>,
    <6696, 6699, 6616>,
    <6696, 6616, 6615>,
    <6696, 6615, 6614>,
    <6696, 6614, 6700>,
    <6696, 6700, 6701>,
    <6696, 6701, 6697>,
    <6702, 6703, 6698>,
    <6702, 6698, 6697>,
    <6702, 6697, 6701>,
    <6702, 6701, 6704>,
    <6702, 6704, 6684>,
    <6702, 6684, 6683>,
    <6702, 6683, 6682>,
    <6702, 6682, 6703>,
    <6705, 6699, 6698>,
    <6705, 6698, 6703>,
    <6705, 6703, 6682>,
    <6705, 6682, 6695>,
    <6705, 6695, 6620>,
    <6705, 6620, 6619>,
    <6705, 6619, 6616>,
    <6705, 6616, 6699>,
    <6706, 6707, 6708>,
    <6706, 6708, 6709>,
    <6706, 6709, 6710>,
    <6706, 6710, 6711>,
    <6706, 6711, 6338>,
    <6706, 6338, 6555>,
    <6706, 6555, 6553>,
    <6706, 6553, 6707>,
    <6712, 6713, 6708>,
    <6712, 6708, 6707>,
    <6712, 6707, 6553>,
    <6712, 6553, 6552>,
    <6712, 6552, 6544>,
    <6712, 6544, 6714>,
    <6712, 6714, 6715>,
    <6712, 6715, 6713>,
    <6716, 6709, 6708>,
    <6716, 6708, 6713>,
    <6716, 6713, 6715>,
    <6716, 6715, 6717>,
    <6716, 6717, 6718>,
    <6716, 6718, 6719>,
    <6716, 6719, 6710>,
    <6716, 6710, 6709>,
    <6720, 6721, 6722>,
    <6720, 6722, 6723>,
    <6720, 6723, 6569>,
    <6720, 6569, 6568>,
    <6720, 6568, 6338>,
    <6720, 6338, 6711>,
    <6720, 6711, 6710>,
    <6720, 6710, 6721>,
    <6724, 6725, 6722>,
    <6724, 6722, 6721>,
    <6724, 6721, 6710>,
    <6724, 6710, 6719>,
    <6724, 6719, 6718>,
    <6724, 6718, 6726>,
    <6724, 6726, 6727>,
    <6724, 6727, 6725>,
    <6728, 6723, 6722>,
    <6728, 6722, 6725>,
    <6728, 6725, 6727>,
    <6728, 6727, 6729>,
    <6728, 6729, 6572>,
    <6728, 6572, 6571>,
    <6728, 6571, 6569>,
    <6728, 6569, 6723>,
    <6730, 6731, 6732>,
    <6730, 6732, 6733>,
    <6730, 6733, 6734>,
    <6730, 6734, 6735>,
    <6730, 6735, 6736>,
    <6730, 6736, 6737>,
    <6730, 6737, 6738>,
    <6730, 6738, 6731>,
    <6739, 6740, 6732>,
    <6739, 6732, 6731>,
    <6739, 6731, 6738>,
    <6739, 6738, 6741>,
    <6739, 6741, 6572>,
    <6739, 6572, 6742>,
    <6739, 6742, 6743>,
    <6739, 6743, 6740>,
    <6744, 6733, 6732>,
    <6744, 6732, 6740>,
    <6744, 6740, 6743>,
    <6744, 6743, 6745>,
    <6744, 6745, 6746>,
    <6744, 6746, 6747>,
    <6744, 6747, 6734>,
    <6744, 6734, 6733>,
    <6748, 6749, 6750>,
    <6748, 6750, 6751>,
    <6748, 6751, 6752>,
    <6748, 6752, 6753>,
    <6748, 6753, 6562>,
    <6748, 6562, 6561>,
    <6748, 6561, 6560>,
    <6748, 6560, 6749>,
    <6754, 6755, 6750>,
    <6754, 6750, 6749>,
    <6754, 6749, 6560>,
    <6754, 6560, 6573>,
    <6754, 6573, 6572>,
    <6754, 6572, 6741>,
    <6754, 6741, 6738>,
    <6754, 6738, 6755>,
    <6756, 6751, 6750>,
    <6756, 6750, 6755>,
    <6756, 6755, 6738>,
    <6756, 6738, 6737>,
    <6756, 6737, 6736>,
    <6756, 6736, 6757>,
    <6756, 6757, 6752>,
    <6756, 6752, 6751>,
    <6758, 6759, 6760>,
    <6758, 6760, 6761>,
    <6758, 6761, 6468>,
    <6758, 6468, 6467>,
    <6758, 6467, 5935>,
    <6758, 5935, 6762>,
    <6758, 6762, 6763>,
    <6758, 6763, 6759>,
    <6764, 6765, 6760>,
    <6764, 6760, 6759>,
    <6764, 6759, 6763>,
    <6764, 6763, 6766>,
    <6764, 6766, 6767>,
    <6764, 6767, 6768>,
    <6764, 6768, 6769>,
    <6764, 6769, 6765>,
    <6770, 6761, 6760>,
    <6770, 6760, 6765>,
    <6770, 6765, 6769>,
    <6770, 6769, 6771>,
    <6770, 6771, 6433>,
    <6770, 6433, 6470>,
    <6770, 6470, 6468>,
    <6770, 6468, 6761>,
    <6772, 6773, 6774>,
    <6772, 6774, 6775>,
    <6772, 6775, 6763>,
    <6772, 6763, 6762>,
    <6772, 6762, 5935>,
    <6772, 5935, 6109>,
    <6772, 6109, 6107>,
    <6772, 6107, 6773>,
    <6776, 6777, 6774>,
    <6776, 6774, 6773>,
    <6776, 6773, 6107>,
    <6776, 6107, 6106>,
    <6776, 6106, 6105>,
    <6776, 6105, 6778>,
    <6776, 6778, 6779>,
    <6776, 6779, 6777>,
    <6780, 6775, 6774>,
    <6780, 6774, 6777>,
    <6780, 6777, 6779>,
    <6780, 6779, 6781>,
    <6780, 6781, 6767>,
    <6780, 6767, 6766>,
    <6780, 6766, 6763>,
    <6780, 6763, 6775>,
    <6782, 6783, 6784>,
    <6782, 6784, 6785>,
    <6782, 6785, 6786>,
    <6782, 6786, 6787>,
    <6782, 6787, 6788>,
    <6782, 6788, 6789>,
    <6782, 6789, 6790>,
    <6782, 6790, 6783>,
    <6791, 6792, 6784>,
    <6791, 6784, 6783>,
    <6791, 6783, 6790>,
    <6791, 6790, 6793>,
    <6791, 6793, 6276>,
    <6791, 6276, 6296>,
    <6791, 6296, 6293>,
    <6791, 6293, 6792>,
    <6794, 6785, 6784>,
    <6794, 6784, 6792>,
    <6794, 6792, 6293>,
    <6794, 6293, 6292>,
    <6794, 6292, 6126>,
    <6794, 6126, 6795>,
    <6794, 6795, 6786>,
    <6794, 6786, 6785>,
    <6796, 6797, 6798>,
    <6796, 6798, 6799>,
    <6796, 6799, 6509>,
    <6796, 6509, 6508>,
    <6796, 6508, 6481>,
    <6796, 6481, 6800>,
    <6796, 6800, 6801>,
    <6796, 6801, 6797>,
    <6802, 6803, 6798>,
    <6802, 6798, 6797>,
    <6802, 6797, 6801>,
    <6802, 6801, 6804>,
    <6802, 6804, 6788>,
    <6802, 6788, 6787>,
    <6802, 6787, 6786>,
    <6802, 6786, 6803>,
    <6805, 6799, 6798>,
    <6805, 6798, 6803>,
    <6805, 6803, 6786>,
    <6805, 6786, 6795>,
    <6805, 6795, 6126>,
    <6805, 6126, 6512>,
    <6805, 6512, 6509>,
    <6805, 6509, 6799>,
    <6806, 6807, 6808>,
    <6806, 6808, 6809>,
    <6806, 6809, 6675>,
    <6806, 6675, 6674>,
    <6806, 6674, 6620>,
    <6806, 6620, 6810>,
    <6806, 6810, 6811>,
    <6806, 6811, 6807>,
    <6812, 6813, 6808>,
    <6812, 6808, 6807>,
    <6812, 6807, 6811>,
    <6812, 6811, 6814>,
    <6812, 6814, 6815>,
    <6812, 6815, 6816>,
    <6812, 6816, 6817>,
    <6812, 6817, 6813>,
    <6818, 6809, 6808>,
    <6818, 6808, 6813>,
    <6818, 6813, 6817>,
    <6818, 6817, 6819>,
    <6818, 6819, 6663>,
    <6818, 6663, 6677>,
    <6818, 6677, 6675>,
    <6818, 6675, 6809>,
    <6820, 6821, 6822>,
    <6820, 6822, 6823>,
    <6820, 6823, 6811>,
    <6820, 6811, 6810>,
    <6820, 6810, 6620>,
    <6820, 6620, 6694>,
    <6820, 6694, 6692>,
    <6820, 6692, 6821>,
    <6824, 6825, 6822>,
    <6824, 6822, 6821>,
    <6824, 6821, 6692>,
    <6824, 6692, 6691>,
    <6824, 6691, 6690>,
    <6824, 6690, 6826>,
    <6824, 6826, 6827>,
    <6824, 6827, 6825>,
    <6828, 6823, 6822>,
    <6828, 6822, 6825>,
    <6828, 6825, 6827>,
    <6828, 6827, 6829>,
    <6828, 6829, 6815>,
    <6828, 6815, 6814>,
    <6828, 6814, 6811>,
    <6828, 6811, 6823>,
    <6830, 6831, 6832>,
    <6830, 6832, 6833>,
    <6830, 6833, 6834>,
    <6830, 6834, 6835>,
    <6830, 6835, 6836>,
    <6830, 6836, 6837>,
    <6830, 6837, 6838>,
    <6830, 6838, 6831>,
    <6839, 6840, 6832>,
    <6839, 6832, 6831>,
    <6839, 6831, 6838>,
    <6839, 6838, 6841>,
    <6839, 6841, 6842>,
    <6839, 6842, 6843>,
    <6839, 6843, 6844>,
    <6839, 6844, 6840>,
    <6845, 6833, 6832>,
    <6845, 6832, 6840>,
    <6845, 6840, 6844>,
    <6845, 6844, 6846>,
    <6845, 6846, 6690>,
    <6845, 6690, 6847>,
    <6845, 6847, 6834>,
    <6845, 6834, 6833>,
    <6848, 6849, 6850>,
    <6848, 6850, 6851>,
    <6848, 6851, 6686>,
    <6848, 6686, 6685>,
    <6848, 6685, 6684>,
    <6848, 6684, 6852>,
    <6848, 6852, 6853>,
    <6848, 6853, 6849>,
    <6854, 6855, 6850>,
    <6854, 6850, 6849>,
    <6854, 6849, 6853>,
    <6854, 6853, 6856>,
    <6854, 6856, 6836>,
    <6854, 6836, 6835>,
    <6854, 6835, 6834>,
    <6854, 6834, 6855>,
    <6857, 6851, 6850>,
    <6857, 6850, 6855>,
    <6857, 6855, 6834>,
    <6857, 6834, 6847>,
    <6857, 6847, 6690>,
    <6857, 6690, 6689>,
    <6857, 6689, 6686>,
    <6857, 6686, 6851>,
    <6858, 6859, 6860>,
    <6858, 6860, 6861>,
    <6858, 6861, 6827>,
    <6858, 6827, 6826>,
    <6858, 6826, 6690>,
    <6858, 6690, 6862>,
    <6858, 6862, 6863>,
    <6858, 6863, 6859>,
    <6864, 6865, 6860>,
    <6864, 6860, 6859>,
    <6864, 6859, 6863>,
    <6864, 6863, 6866>,
    <6864, 6866, 6867>,
    <6864, 6867, 6868>,
    <6864, 6868, 6869>,
    <6864, 6869, 6865>,
    <6870, 6861, 6860>,
    <6870, 6860, 6865>,
    <6870, 6865, 6869>,
    <6870, 6869, 6871>,
    <6870, 6871, 6815>,
    <6870, 6815, 6829>,
    <6870, 6829, 6827>,
    <6870, 6827, 6861>,
    <6872, 6873, 6874>,
    <6872, 6874, 6875>,
    <6872, 6875, 6863>,
    <6872, 6863, 6862>,
    <6872, 6862, 6690>,
    <6872, 6690, 6846>,
    <6872, 6846, 6844>,
    <6872, 6844, 6873>,
    <6876, 6877, 6874>,
    <6876, 6874, 6873>,
    <6876, 6873, 6844>,
    <6876, 6844, 6843>,
    <6876, 6843, 6878>,
    <6876, 6878, 6879>,
    <6876, 6880, 6881>,
    <6876, 6881, 6877>,
    <6882, 6875, 6874>,
    <6882, 6874, 6877>,
    <6882, 6877, 6883>,
    <6882, 6883, 6884>,
    <6882, 6885, 6886>,
    <6882, 6886, 6866>,
    <6882, 6866, 6863>,
    <6882, 6863, 6875>,
    <6887, 6888, 6889>,
    <6887, 6889, 6890>,
    <6887, 6890, 6838>,
    <6887, 6838, 6837>,
    <6887, 6837, 6836>,
    <6887, 6836, 6891>,
    <6887, 6891, 6892>,
    <6887, 6892, 6888>,
    <6893, 6894, 6889>,
    <6893, 6889, 6888>,
    <6893, 6888, 6892>,
    <6893, 6892, 6895>,
    <6893, 6895, 6896>,
    <6893, 6896, 6897>,
    <6893, 6898, 6899>,
    <6893, 6899, 6894>,
    <6900, 6890, 6889>,
    <6900, 6889, 6894>,
    <6900, 6894, 6901>,
    <6900, 6901, 6902>,
    <6900, 6903, 6904>,
    <6900, 6904, 6841>,
    <6900, 6841, 6838>,
    <6900, 6838, 6890>,
    <6905, 6906, 6907>,
    <6905, 6907, 6908>,
    <6905, 6908, 6909>,
    <6905, 6909, 6910>,
    <6905, 6910, 6911>,
    <6905, 6911, 6912>,
    <6905, 6913, 6914>,
    <6905, 6914, 6906>,
    <6915, 6916, 6907>,
    <6915, 6907, 6906>,
    <6915, 6906, 6917>,
    <6915, 6917, 6918>,
    <6915, 6919, 6920>,
    <6915, 6920, 6921>,
    <6915, 6921, 6922>,
    <6915, 6922, 6916>,
    <6923, 6908, 6907>,
    <6923, 6907, 6916>,
    <6923, 6916, 6922>,
    <6923, 6922, 6924>,
    <6923, 6924, 6925>,
    <6923, 6925, 6926>,
    <6923, 6926, 6909>,
    <6923, 6909, 6908>,
    <6927, 6928, 6929>,
    <6927, 6929, 6930>,
    <6927, 6930, 6931>,
    <6927, 6931, 6932>,
    <6927, 6932, 6933>,
    <6927, 6933, 6934>,
    <6927, 6935, 6936>,
    <6927, 6936, 6928>,
    <6937, 6938, 6929>,
    <6937, 6929, 6928>,
    <6937, 6928, 6939>,
    <6937, 6939, 6940>,
    <6937, 6941, 6942>,
    <6937, 6942, 6910>,
    <6937, 6910, 6909>,
    <6937, 6909, 6938>,
    <6943, 6930, 6929>,
    <6943, 6929, 6938>,
    <6943, 6938, 6909>,
    <6943, 6909, 6926>,
    <6943, 6926, 6925>,
    <6943, 6925, 6944>,
    <6943, 6944, 6931>,
    <6943, 6931, 6930>,
    <6945, 6946, 6947>,
    <6945, 6947, 6948>,
    <6945, 6948, 6183>,
    <6945, 6183, 6182>,
    <6945, 6182, 6949>,
    <6945, 6949, 6932>,
    <6945, 6932, 6931>,
    <6945, 6931, 6946>,
    <6950, 6951, 6947>,
    <6950, 6947, 6946>,
    <6950, 6946, 6931>,
    <6950, 6931, 6944>,
    <6950, 6944, 6925>,
    <6950, 6925, 6952>,
    <6950, 6952, 6953>,
    <6950, 6953, 6951>,
    <6954, 6948, 6947>,
    <6954, 6947, 6951>,
    <6954, 6951, 6953>,
    <6954, 6953, 6955>,
    <6954, 6955, 6186>,
    <6954, 6186, 6185>,
    <6954, 6185, 6183>,
    <6954, 6183, 6948>,
    <6956, 6957, 6958>,
    <6956, 6958, 6959>,
    <6956, 6959, 6960>,
    <6956, 6960, 6961>,
    <6956, 6961, 6962>,
    <6956, 6962, 6963>,
    <6956, 6963, 6964>,
    <6956, 6964, 6957>,
    <6965, 6966, 6958>,
    <6965, 6958, 6957>,
    <6965, 6957, 6964>,
    <6965, 6964, 6967>,
    <6965, 6967, 6230>,
    <6965, 6230, 6345>,
    <6965, 6345, 6344>,
    <6965, 6344, 6966>,
    <6968, 6959, 6958>,
    <6968, 6958, 6966>,
    <6968, 6966, 6344>,
    <6968, 6344, 6349>,
    <6968, 6349, 6328>,
    <6968, 6328, 6969>,
    <6968, 6969, 6960>,
    <6968, 6960, 6959>,
    <6970, 6971, 6972>,
    <6970, 6972, 6973>,
    <6970, 6973, 6974>,
    <6970, 6974, 6975>,
    <6970, 6975, 6976>,
    <6970, 6976, 6641>,
    <6970, 6641, 6640>,
    <6970, 6640, 6971>,
    <6977, 6978, 6972>,
    <6977, 6972, 6971>,
    <6977, 6971, 6640>,
    <6977, 6640, 6653>,
    <6977, 6653, 6230>,
    <6977, 6230, 6967>,
    <6977, 6967, 6964>,
    <6977, 6964, 6978>,
    <6979, 6973, 6972>,
    <6979, 6972, 6978>,
    <6979, 6978, 6964>,
    <6979, 6964, 6963>,
    <6979, 6963, 6962>,
    <6979, 6962, 6980>,
    <6979, 6980, 6974>,
    <6979, 6974, 6973>,
    <6981, 6982, 6983>,
    <6981, 6983, 6984>,
    <6981, 6984, 6985>,
    <6981, 6985, 6986>,
    <6981, 6986, 6572>,
    <6981, 6572, 6729>,
    <6981, 6729, 6727>,
    <6981, 6727, 6982>,
    <6987, 6988, 6983>,
    <6987, 6983, 6982>,
    <6987, 6982, 6727>,
    <6987, 6727, 6726>,
    <6987, 6726, 6718>,
    <6987, 6718, 6989>,
    <6987, 6989, 6990>,
    <6987, 6990, 6988>,
    <6991, 6984, 6983>,
    <6991, 6983, 6988>,
    <6991, 6988, 6990>,
    <6991, 6990, 6992>,
    <6991, 6992, 6993>,
    <6991, 6993, 6994>,
    <6991, 6994, 6985>,
    <6991, 6985, 6984>,
    <6995, 6996, 6997>,
    <6995, 6997, 6998>,
    <6995, 6998, 6743>,
    <6995, 6743, 6742>,
    <6995, 6742, 6572>,
    <6995, 6572, 6986>,
    <6995, 6986, 6985>,
    <6995, 6985, 6996>,
    <6999, 7000, 6997>,
    <6999, 6997, 6996>,
    <6999, 6996, 6985>,
    <6999, 6985, 6994>,
    <6999, 6994, 6993>,
    <6999, 6993, 7001>,
    <6999, 7001, 7002>,
    <6999, 7002, 7000>,
    <7003, 6998, 6997>,
    <7003, 6997, 7000>,
    <7003, 7000, 7002>,
    <7003, 7002, 7004>,
    <7003, 7004, 6746>,
    <7003, 6746, 6745>,
    <7003, 6745, 6743>,
    <7003, 6743, 6998>,
    <7005, 7006, 7007>,
    <7005, 7007, 7008>,
    <7005, 7008, 7009>,
    <7005, 7009, 7010>,
    <7005, 7010, 7011>,
    <7005, 7011, 7012>,
    <7005, 7012, 7013>,
    <7005, 7013, 7006>,
    <7014, 7015, 7007>,
    <7014, 7007, 7006>,
    <7014, 7006, 7013>,
    <7014, 7013, 7016>,
    <7014, 7016, 6746>,
    <7014, 6746, 7017>,
    <7014, 7017, 7018>,
    <7014, 7018, 7015>,
    <7019, 7008, 7007>,
    <7019, 7007, 7015>,
    <7019, 7015, 7018>,
    <7019, 7018, 7020>,
    <7019, 7020, 7021>,
    <7019, 7021, 7022>,
    <7019, 7022, 7009>,
    <7019, 7009, 7008>,
    <7023, 7024, 7025>,
    <7023, 7025, 7026>,
    <7023, 7026, 7027>,
    <7023, 7027, 7028>,
    <7023, 7028, 6736>,
    <7023, 6736, 6735>,
    <7023, 6735, 6734>,
    <7023, 6734, 7024>,
    <7029, 7030, 7025>,
    <7029, 7025, 7024>,
    <7029, 7024, 6734>,
    <7029, 6734, 6747>,
    <7029, 6747, 6746>,
    <7029, 6746, 7016>,
    <7029, 7016, 7013>,
    <7029, 7013, 7030>,
    <7031, 7026, 7025>,
    <7031, 7025, 7030>,
    <7031, 7030, 7013>,
    <7031, 7013, 7012>,
    <7031, 7012, 7011>,
    <7031, 7011, 7032>,
    <7031, 7032, 7027>,
    <7031, 7027, 7026>,
    <7033, 7034, 7035>,
    <7033, 7035, 7036>,
    <7033, 7036, 7037>,
    <7033, 7037, 7038>,
    <7033, 7038, 7039>,
    <7033, 7039, 7040>,
    <7033, 7041, 7042>,
    <7033, 7042, 7034>,
    <7043, 7044, 7035>,
    <7043, 7035, 7034>,
    <7043, 7034, 7045>,
    <7043, 7045, 7046>,
    <7043, 7047, 7048>,
    <7043, 7048, 6437>,
    <7043, 6437, 6435>,
    <7043, 6435, 7044>,
    <7049, 7036, 7035>,
    <7049, 7035, 7044>,
    <7049, 7044, 6435>,
    <7049, 6435, 6434>,
    <7049, 6434, 6433>,
    <7049, 6433, 7050>,
    <7049, 7050, 7037>,
    <7049, 7037, 7036>,
    <7051, 7052, 7053>,
    <7051, 7053, 7054>,
    <7051, 7054, 7055>,
    <7051, 7055, 7056>,
    <7051, 7056, 6746>,
    <7051, 6746, 7004>,
    <7051, 7004, 7002>,
    <7051, 7002, 7052>,
    <7057, 7058, 7053>,
    <7057, 7053, 7052>,
    <7057, 7052, 7002>,
    <7057, 7002, 7001>,
    <7057, 7001, 6993>,
    <7057, 6993, 7059>,
    <7057, 7059, 7060>,
    <7057, 7060, 7058>,
    <7061, 7054, 7053>,
    <7061, 7053, 7058>,
    <7061, 7058, 7060>,
    <7061, 7060, 7062>,
    <7061, 7062, 7063>,
    <7061, 7063, 7064>,
    <7061, 7064, 7055>,
    <7061, 7055, 7054>,
    <7065, 7066, 7067>,
    <7065, 7067, 7068>,
    <7065, 7068, 7018>,
    <7065, 7018, 7017>,
    <7065, 7017, 6746>,
    <7065, 6746, 7056>,
    <7065, 7056, 7055>,
    <7065, 7055, 7066>,
    <7069, 7070, 7067>,
    <7069, 7067, 7066>,
    <7069, 7066, 7055>,
    <7069, 7055, 7064>,
    <7069, 7064, 7063>,
    <7069, 7063, 7071>,
    <7069, 7071, 7072>,
    <7069, 7072, 7070>,
    <7073, 7068, 7067>,
    <7073, 7067, 7070>,
    <7073, 7070, 7072>,
    <7073, 7072, 7074>,
    <7073, 7074, 7021>,
    <7073, 7021, 7020>,
    <7073, 7020, 7018>,
    <7073, 7018, 7068>,
    <7075, 7076, 7077>,
    <7075, 7077, 7078>,
    <7075, 7078, 7079>,
    <7075, 7079, 7080>,
    <7075, 7080, 7081>,
    <7075, 7081, 7082>,
    <7075, 7082, 7083>,
    <7075, 7083, 7076>,
    <7084, 7085, 7077>,
    <7084, 7077, 7076>,
    <7084, 7076, 7083>,
    <7084, 7083, 7086>,
    <7084, 7086, 7021>,
    <7084, 7021, 7087>,
    <7084, 7087, 7088>,
    <7084, 7088, 7085>,
    <7089, 7078, 7077>,
    <7089, 7077, 7085>,
    <7089, 7085, 7088>,
    <7089, 7088, 7090>,
    <7089, 7090, 7091>,
    <7089, 7091, 7092>,
    <7089, 7092, 7079>,
    <7089, 7079, 7078>,
    <7093, 7094, 7095>,
    <7093, 7095, 7096>,
    <7093, 7096, 7097>,
    <7093, 7097, 7098>,
    <7093, 7098, 7011>,
    <7093, 7011, 7010>,
    <7093, 7010, 7009>,
    <7093, 7009, 7094>,
    <7099, 7100, 7095>,
    <7099, 7095, 7094>,
    <7099, 7094, 7009>,
    <7099, 7009, 7022>,
    <7099, 7022, 7021>,
    <7099, 7021, 7086>,
    <7099, 7086, 7083>,
    <7099, 7083, 7100>,
    <7101, 7096, 7095>,
    <7101, 7095, 7100>,
    <7101, 7100, 7083>,
    <7101, 7083, 7082>,
    <7101, 7082, 7081>,
    <7101, 7081, 7102>,
    <7101, 7102, 7097>,
    <7101, 7097, 7096>,
    <7103, 7104, 7105>,
    <7103, 7105, 7106>,
    <7103, 7106, 6779>,
    <7103, 6779, 6778>,
    <7103, 6778, 6105>,
    <7103, 6105, 7107>,
    <7103, 7107, 7108>,
    <7103, 7108, 7104>,
    <7109, 7110, 7105>,
    <7109, 7105, 7104>,
    <7109, 7104, 7108>,
    <7109, 7108, 7111>,
    <7109, 7111, 7112>,
    <7109, 7112, 7113>,
    <7109, 7113, 7114>,
    <7109, 7114, 7110>,
    <7115, 7106, 7105>,
    <7115, 7105, 7110>,
    <7115, 7110, 7114>,
    <7115, 7114, 7116>,
    <7115, 7116, 6767>,
    <7115, 6767, 6781>,
    <7115, 6781, 6779>,
    <7115, 6779, 7106>,
    <7117, 7118, 7119>,
    <7117, 7119, 7120>,
    <7117, 7120, 7108>,
    <7117, 7108, 7107>,
    <7117, 7107, 6105>,
    <7117, 6105, 6259>,
    <7117, 6259, 6257>,
    <7117, 6257, 7118>,
    <7121, 7122, 7119>,
    <7121, 7119, 7118>,
    <7121, 7118, 6257>,
    <7121, 6257, 6256>,
    <7121, 6256, 6255>,
    <7121, 6255, 7123>,
    <7121, 7123, 7124>,
    <7121, 7124, 7122>,
    <7125, 7120, 7119>,
    <7125, 7119, 7122>,
    <7125, 7122, 7124>,
    <7125, 7124, 7126>,
    <7125, 7126, 7112>,
    <7125, 7112, 7111>,
    <7125, 7111, 7108>,
    <7125, 7108, 7120>,
    <7127, 7128, 7129>,
    <7127, 7129, 7130>,
    <7127, 7130, 7131>,
    <7127, 7131, 7132>,
    <7127, 7132, 7133>,
    <7127, 7133, 7134>,
    <7127, 7134, 7135>,
    <7127, 7135, 7128>,
    <7136, 7137, 7129>,
    <7136, 7129, 7128>,
    <7136, 7128, 7135>,
    <7136, 7135, 7138>,
    <7136, 7138, 6398>,
    <7136, 6398, 6418>,
    <7136, 6418, 6415>,
    <7136, 6415, 7137>,
    <7139, 7130, 7129>,
    <7139, 7129, 7137>,
    <7139, 7137, 6415>,
    <7139, 6415, 6414>,
    <7139, 6414, 6276>,
    <7139, 6276, 7140>,
    <7139, 7140, 7131>,
    <7139, 7131, 7130>,
    <7141, 7142, 7143>,
    <7141, 7143, 7144>,
    <7141, 7144, 6790>,
    <7141, 6790, 6789>,
    <7141, 6789, 6788>,
    <7141, 6788, 7145>,
    <7141, 7145, 7146>,
    <7141, 7146, 7142>,
    <7147, 7148, 7143>,
    <7147, 7143, 7142>,
    <7147, 7142, 7146>,
    <7147, 7146, 7149>,
    <7147, 7149, 7133>,
    <7147, 7133, 7132>,
    <7147, 7132, 7131>,
    <7147, 7131, 7148>,
    <7150, 7144, 7143>,
    <7150, 7143, 7148>,
    <7150, 7148, 7131>,
    <7150, 7131, 7140>,
    <7150, 7140, 6276>,
    <7150, 6276, 6793>,
    <7150, 6793, 6790>,
    <7150, 6790, 7144>,
    <7151, 7152, 7153>,
    <7151, 7153, 7154>,
    <7151, 7154, 7155>,
    <7151, 7155, 7156>,
    <7151, 7156, 7021>,
    <7151, 7021, 7074>,
    <7151, 7074, 7072>,
    <7151, 7072, 7152>,
    <7157, 7158, 7153>,
    <7157, 7153, 7152>,
    <7157, 7152, 7072>,
    <7157, 7072, 7071>,
    <7157, 7071, 7063>,
    <7157, 7063, 7159>,
    <7157, 7159, 7160>,
    <7157, 7160, 7158>,
    <7161, 7154, 7153>,
    <7161, 7153, 7158>,
    <7161, 7158, 7160>,
    <7161, 7160, 7162>,
    <7161, 7162, 7163>,
    <7161, 7163, 7164>,
    <7161, 7164, 7155>,
    <7161, 7155, 7154>,
    <7165, 7166, 7167>,
    <7165, 7167, 7168>,
    <7165, 7168, 7088>,
    <7165, 7088, 7087>,
    <7165, 7087, 7021>,
    <7165, 7021, 7156>,
    <7165, 7156, 7155>,
    <7165, 7155, 7166>,
    <7169, 7170, 7167>,
    <7169, 7167, 7166>,
    <7169, 7166, 7155>,
    <7169, 7155, 7164>,
    <7169, 7164, 7171>,
    <7169, 7171, 7172>,
    <7169, 7173, 7174>,
    <7169, 7174, 7170>,
    <7175, 7168, 7167>,
    <7175, 7167, 7170>,
    <7175, 7170, 7176>,
    <7175, 7176, 7177>,
    <7175, 7178, 7179>,
    <7175, 7179, 7090>,
    <7175, 7090, 7088>,
    <7175, 7088, 7168>,
    <7180, 7181, 7182>,
    <7180, 7182, 7183>,
    <7180, 7183, 7184>,
    <7180, 7184, 7185>,
    <7180, 7185, 7081>,
    <7180, 7081, 7080>,
    <7180, 7080, 7079>,
    <7180, 7079, 7181>,
    <7186, 7187, 7182>,
    <7186, 7182, 7181>,
    <7186, 7181, 7079>,
    <7186, 7079, 7092>,
    <7186, 7092, 7188>,
    <7186, 7188, 522>,
    <7186, 522, 520>,
    <7186, 520, 7187>,
    <7189, 7183, 7182>,
    <7189, 7182, 7187>,
    <7189, 7187, 520>,
    <7189, 520, 519>,
    <7189, 519, 518>,
    <7189, 518, 7190>,
    <7189, 7190, 7184>,
    <7189, 7184, 7183>,
    <7191, 7192, 7193>,
    <7191, 7193, 7194>,
    <7191, 7194, 7195>,
    <7191, 7195, 7196>,
    <7191, 7197, 7198>,
    <7191, 7198, 7199>,
    <7191, 7199, 7200>,
    <7191, 7200, 7192>,
    <7201, 7202, 7193>,
    <7201, 7193, 7192>,
    <7201, 7192, 7200>,
    <7201, 7200, 7203>,
    <7201, 7203, 6481>,
    <7201, 6481, 6531>,
    <7201, 6531, 6529>,
    <7201, 6529, 7202>,
    <7204, 7194, 7193>,
    <7204, 7193, 7202>,
    <7204, 7202, 6529>,
    <7204, 6529, 6528>,
    <7204, 6528, 7205>,
    <7204, 7205, 7206>,
    <7204, 7207, 7208>,
    <7204, 7208, 7194>,
    <7209, 7210, 7211>,
    <7209, 7211, 7212>,
    <7209, 7212, 7213>,
    <7209, 7213, 7214>,
    <7209, 7214, 6186>,
    <7209, 6186, 6955>,
    <7209, 6955, 6953>,
    <7209, 6953, 7210>,
    <7215, 7216, 7211>,
    <7215, 7211, 7210>,
    <7215, 7210, 6953>,
    <7215, 6953, 6952>,
    <7215, 6952, 6925>,
    <7215, 6925, 7217>,
    <7215, 7217, 7218>,
    <7215, 7218, 7216>,
    <7219, 7212, 7211>,
    <7219, 7211, 7216>,
    <7219, 7216, 7218>,
    <7219, 7218, 7220>,
    <7219, 7220, 7221>,
    <7219, 7221, 7222>,
    <7219, 7222, 7213>,
    <7219, 7213, 7212>,
    <7223, 7224, 7225>,
    <7223, 7225, 7226>,
    <7223, 7226, 6307>,
    <7223, 6307, 6306>,
    <7223, 6306, 6186>,
    <7223, 6186, 7214>,
    <7223, 7214, 7213>,
    <7223, 7213, 7224>,
    <7227, 7228, 7225>,
    <7227, 7225, 7224>,
    <7227, 7224, 7213>,
    <7227, 7213, 7222>,
    <7227, 7222, 7221>,
    <7227, 7221, 7229>,
    <7227, 7229, 7230>,
    <7227, 7230, 7228>,
    <7231, 7226, 7225>,
    <7231, 7225, 7228>,
    <7231, 7228, 7230>,
    <7231, 7230, 7232>,
    <7231, 7232, 6310>,
    <7231, 6310, 6309>,
    <7231, 6309, 6307>,
    <7231, 6307, 7226>,
    <7233, 7234, 7235>,
    <7233, 7235, 7236>,
    <7233, 7236, 7237>,
    <7233, 7237, 7238>,
    <7233, 7238, 7239>,
    <7233, 7239, 7240>,
    <7233, 7240, 7241>,
    <7233, 7241, 7234>,
    <7242, 7243, 7235>,
    <7242, 7235, 7234>,
    <7242, 7234, 7241>,
    <7242, 7241, 7244>,
    <7242, 7244, 6328>,
    <7242, 6328, 6579>,
    <7242, 6579, 6578>,
    <7242, 6578, 7243>,
    <7245, 7236, 7235>,
    <7245, 7235, 7243>,
    <7245, 7243, 6578>,
    <7245, 6578, 6583>,
    <7245, 6583, 6562>,
    <7245, 6562, 7246>,
    <7245, 7246, 7237>,
    <7245, 7237, 7236>,
    <7247, 7248, 7249>,
    <7247, 7249, 7250>,
    <7247, 7250, 7251>,
    <7247, 7251, 7252>,
    <7247, 7252, 6962>,
    <7247, 6962, 6961>,
    <7247, 6961, 6960>,
    <7247, 6960, 7248>,
    <7253, 7254, 7249>,
    <7253, 7249, 7248>,
    <7253, 7248, 6960>,
    <7253, 6960, 6969>,
    <7253, 6969, 6328>,
    <7253, 6328, 7244>,
    <7253, 7244, 7241>,
    <7253, 7241, 7254>,
    <7255, 7250, 7249>,
    <7255, 7249, 7254>,
    <7255, 7254, 7241>,
    <7255, 7241, 7240>,
    <7255, 7240, 7239>,
    <7255, 7239, 7256>,
    <7255, 7256, 7251>,
    <7255, 7251, 7250>,
    <7257, 7258, 7259>,
    <7257, 7259, 7260>,
    <7257, 7260, 7124>,
    <7257, 7124, 7123>,
    <7257, 7123, 6255>,
    <7257, 6255, 7261>,
    <7257, 7261, 7262>,
    <7257, 7262, 7258>,
    <7263, 7264, 7259>,
    <7263, 7259, 7258>,
    <7263, 7258, 7262>,
    <7263, 7262, 7265>,
    <7263, 7265, 7266>,
    <7263, 7266, 7267>,
    <7263, 7267, 7268>,
    <7263, 7268, 7264>,
    <7269, 7260, 7259>,
    <7269, 7259, 7264>,
    <7269, 7264, 7268>,
    <7269, 7268, 7270>,
    <7269, 7270, 7112>,
    <7269, 7112, 7126>,
    <7269, 7126, 7124>,
    <7269, 7124, 7260>,
    <7271, 7272, 7273>,
    <7271, 7273, 7274>,
    <7271, 7274, 7262>,
    <7271, 7262, 7261>,
    <7271, 7261, 6255>,
    <7271, 6255, 6381>,
    <7271, 6381, 6379>,
    <7271, 6379, 7272>,
    <7275, 7276, 7273>,
    <7275, 7273, 7272>,
    <7275, 7272, 6379>,
    <7275, 6379, 6378>,
    <7275, 6378, 6377>,
    <7275, 6377, 7277>,
    <7275, 7277, 7278>,
    <7275, 7278, 7276>,
    <7279, 7274, 7273>,
    <7279, 7273, 7276>,
    <7279, 7276, 7278>,
    <7279, 7278, 7280>,
    <7279, 7280, 7266>,
    <7279, 7266, 7265>,
    <7279, 7265, 7262>,
    <7279, 7262, 7274>,
    <7281, 7282, 7283>,
    <7281, 7283, 7284>,
    <7281, 7284, 7285>,
    <7281, 7285, 7286>,
    <7281, 7286, 7287>,
    <7281, 7287, 7288>,
    <7281, 7288, 7289>,
    <7281, 7289, 7282>,
    <7290, 7291, 7283>,
    <7290, 7283, 7282>,
    <7290, 7282, 7289>,
    <7290, 7289, 7292>,
    <7290, 7292, 6614>,
    <7290, 6614, 6634>,
    <7290, 6634, 6631>,
    <7290, 6631, 7291>,
    <7293, 7284, 7283>,
    <7293, 7283, 7291>,
    <7293, 7291, 6631>,
    <7293, 6631, 6630>,
    <7293, 6630, 6398>,
    <7293, 6398, 7294>,
    <7293, 7294, 7285>,
    <7293, 7285, 7284>,
    <7295, 7296, 7297>,
    <7295, 7297, 7298>,
    <7295, 7298, 7135>,
    <7295, 7135, 7134>,
    <7295, 7134, 7133>,
    <7295, 7133, 7299>,
    <7295, 7299, 7300>,
    <7295, 7300, 7296>,
    <7301, 7302, 7297>,
    <7301, 7297, 7296>,
    <7301, 7296, 7300>,
    <7301, 7300, 7303>,
    <7301, 7303, 7287>,
    <7301, 7287, 7286>,
    <7301, 7286, 7285>,
    <7301, 7285, 7302>,
    <7304, 7298, 7297>,
    <7304, 7297, 7302>,
    <7304, 7302, 7285>,
    <7304, 7285, 7294>,
    <7304, 7294, 6398>,
    <7304, 6398, 7138>,
    <7304, 7138, 7135>,
    <7304, 7135, 7298>,
    <7305, 7306, 7307>,
    <7305, 7307, 7308>,
    <7305, 7308, 7309>,
    <7305, 7309, 7310>,
    <7305, 7310, 6310>,
    <7305, 6310, 7232>,
    <7305, 7232, 7230>,
    <7305, 7230, 7306>,
    <7311, 7312, 7307>,
    <7311, 7307, 7306>,
    <7311, 7306, 7230>,
    <7311, 7230, 7229>,
    <7311, 7229, 7221>,
    <7311, 7221, 7313>,
    <7311, 7313, 7314>,
    <7311, 7314, 7312>,
    <7315, 7308, 7307>,
    <7315, 7307, 7312>,
    <7315, 7312, 7314>,
    <7315, 7314, 7316>,
    <7315, 7316, 7317>,
    <7315, 7317, 7318>,
    <7315, 7318, 7309>,
    <7315, 7309, 7308>,
    <7319, 7320, 7321>,
    <7319, 7321, 7322>,
    <7319, 7322, 6541>,
    <7319, 6541, 6540>,
    <7319, 6540, 6310>,
    <7319, 6310, 7310>,
    <7319, 7310, 7309>,
    <7319, 7309, 7320>,
    <7323, 7324, 7321>,
    <7323, 7321, 7320>,
    <7323, 7320, 7309>,
    <7323, 7309, 7318>,
    <7323, 7318, 7317>,
    <7323, 7317, 7325>,
    <7323, 7325, 7326>,
    <7323, 7326, 7324>,
    <7327, 7322, 7321>,
    <7327, 7321, 7324>,
    <7327, 7324, 7326>,
    <7327, 7326, 7328>,
    <7327, 7328, 6544>,
    <7327, 6544, 6543>,
    <7327, 6543, 6541>,
    <7327, 6541, 7322>,
    <7329, 7330, 7331>,
    <7329, 7331, 7332>,
    <7329, 7332, 7333>,
    <7329, 7333, 7334>,
    <7329, 7334, 7335>,
    <7329, 7335, 7336>,
    <7329, 7336, 7337>,
    <7329, 7337, 7330>,
    <7338, 7339, 7331>,
    <7338, 7331, 7330>,
    <7338, 7330, 7337>,
    <7338, 7337, 7340>,
    <7338, 7340, 6562>,
    <7338, 6562, 6753>,
    <7338, 6753, 6752>,
    <7338, 6752, 7339>,
    <7341, 7332, 7331>,
    <7341, 7331, 7339>,
    <7341, 7339, 6752>,
    <7341, 6752, 6757>,
    <7341, 6757, 6736>,
    <7341, 6736, 7342>,
    <7341, 7342, 7333>,
    <7341, 7333, 7332>,
    <7343, 7344, 7345>,
    <7343, 7345, 7346>,
    <7343, 7346, 7347>,
    <7343, 7347, 7348>,
    <7343, 7348, 7239>,
    <7343, 7239, 7238>,
    <7343, 7238, 7237>,
    <7343, 7237, 7344>,
    <7349, 7350, 7345>,
    <7349, 7345, 7344>,
    <7349, 7344, 7237>,
    <7349, 7237, 7246>,
    <7349, 7246, 6562>,
    <7349, 6562, 7340>,
    <7349, 7340, 7337>,
    <7349, 7337, 7350>,
    <7351, 7346, 7345>,
    <7351, 7345, 7350>,
    <7351, 7350, 7337>,
    <7351, 7337, 7336>,
    <7351, 7336, 7335>,
    <7351, 7335, 7352>,
    <7351, 7352, 7347>,
    <7351, 7347, 7346>,
    <7353, 7354, 7355>,
    <7353, 7355, 7356>,
    <7353, 7356, 7278>,
    <7353, 7278, 7277>,
    <7353, 7277, 6377>,
    <7353, 6377, 7357>,
    <7353, 7357, 7358>,
    <7353, 7358, 7354>,
    <7359, 7360, 7355>,
    <7359, 7355, 7354>,
    <7359, 7354, 7358>,
    <7359, 7358, 7361>,
    <7359, 7361, 7362>,
    <7359, 7362, 7363>,
    <7359, 7363, 7364>,
    <7359, 7364, 7360>,
    <7365, 7356, 7355>,
    <7365, 7355, 7360>,
    <7365, 7360, 7364>,
    <7365, 7364, 7366>,
    <7365, 7366, 7266>,
    <7365, 7266, 7280>,
    <7365, 7280, 7278>,
    <7365, 7278, 7356>,
    <7367, 7368, 7369>,
    <7367, 7369, 7370>,
    <7367, 7370, 7358>,
    <7367, 7358, 7357>,
    <7367, 7357, 6377>,
    <7367, 6377, 6597>,
    <7367, 6597, 6595>,
    <7367, 6595, 7368>,
    <7371, 7372, 7369>,
    <7371, 7369, 7368>,
    <7371, 7368, 6595>,
    <7371, 6595, 6594>,
    <7371, 6594, 6593>,
    <7371, 6593, 7373>,
    <7371, 7373, 7374>,
    <7371, 7374, 7372>,
    <7375, 7370, 7369>,
    <7375, 7369, 7372>,
    <7375, 7372, 7374>,
    <7375, 7374, 7376>,
    <7375, 7376, 7362>,
    <7375, 7362, 7361>,
    <7375, 7361, 7358>,
    <7375, 7358, 7370>,
    <7377, 7378, 7379>,
    <7377, 7379, 7380>,
    <7377, 7380, 7381>,
    <7377, 7381, 7382>,
    <7377, 7382, 7383>,
    <7377, 7383, 7384>,
    <7377, 7384, 7385>,
    <7377, 7385, 7378>,
    <7386, 7387, 7379>,
    <7386, 7379, 7378>,
    <7386, 7378, 7385>,
    <7386, 7385, 7388>,
    <7386, 7388, 6684>,
    <7386, 6684, 6704>,
    <7386, 6704, 6701>,
    <7386, 6701, 7387>,
    <7389, 7380, 7379>,
    <7389, 7379, 7387>,
    <7389, 7387, 6701>,
    <7389, 6701, 6700>,
    <7389, 6700, 6614>,
    <7389, 6614, 7390>,
    <7389, 7390, 7381>,
    <7389, 7381, 7380>,
    <7391, 7392, 7393>,
    <7391, 7393, 7394>,
    <7391, 7394, 7289>,
    <7391, 7289, 7288>,
    <7391, 7288, 7287>,
    <7391, 7287, 7395>,
    <7391, 7395, 7396>,
    <7391, 7396, 7392>,
    <7397, 7398, 7393>,
    <7397, 7393, 7392>,
    <7397, 7392, 7396>,
    <7397, 7396, 7399>,
    <7397, 7399, 7383>,
    <7397, 7383, 7382>,
    <7397, 7382, 7381>,
    <7397, 7381, 7398>,
    <7400, 7394, 7393>,
    <7400, 7393, 7398>,
    <7400, 7398, 7381>,
    <7400, 7381, 7390>,
    <7400, 7390, 6614>,
    <7400, 6614, 7292>,
    <7400, 7292, 7289>,
    <7400, 7289, 7394>,
    <7401, 7402, 7403>,
    <7401, 7403, 7404>,
    <7401, 7404, 7405>,
    <7401, 7405, 7406>,
    <7401, 7406, 7407>,
    <7401, 7407, 7408>,
    <7401, 7409, 7410>,
    <7401, 7410, 7402>,
    <7411, 7412, 7403>,
    <7411, 7403, 7402>,
    <7411, 7402, 7413>,
    <7411, 7413, 7414>,
    <7411, 7415, 7416>,
    <7411, 7416, 6975>,
    <7411, 6975, 6974>,
    <7411, 6974, 7412>,
    <7417, 7404, 7403>,
    <7417, 7403, 7412>,
    <7417, 7412, 6974>,
    <7417, 6974, 6980>,
    <7417, 6980, 6962>,
    <7417, 6962, 7418>,
    <7417, 7418, 7405>,
    <7417, 7405, 7404>,
    <7419, 7420, 7421>,
    <7419, 7421, 7422>,
    <7419, 7422, 7374>,
    <7419, 7374, 7373>,
    <7419, 7373, 6593>,
    <7419, 6593, 7423>,
    <7419, 7423, 7424>,
    <7419, 7424, 7420>,
    <7425, 7426, 7421>,
    <7425, 7421, 7420>,
    <7425, 7420, 7424>,
    <7425, 7424, 7427>,
    <7425, 7427, 7428>,
    <7425, 7428, 7429>,
    <7425, 7429, 7430>,
    <7425, 7430, 7426>,
    <7431, 7422, 7421>,
    <7431, 7421, 7426>,
    <7431, 7426, 7430>,
    <7431, 7430, 7432>,
    <7431, 7432, 7362>,
    <7431, 7362, 7376>,
    <7431, 7376, 7374>,
    <7431, 7374, 7422>,
    <7433, 7434, 7435>,
    <7433, 7435, 7436>,
    <7433, 7436, 7424>,
    <7433, 7424, 7423>,
    <7433, 7423, 6593>,
    <7433, 6593, 6667>,
    <7433, 6667, 6665>,
    <7433, 6665, 7434>,
    <7437, 7438, 7435>,
    <7437, 7435, 7434>,
    <7437, 7434, 6665>,
    <7437, 6665, 6664>,
    <7437, 6664, 6663>,
    <7437, 6663, 7439>,
    <7437, 7439, 7440>,
    <7437, 7440, 7438>,
    <7441, 7436, 7435>,
    <7441, 7435, 7438>,
    <7441, 7438, 7440>,
    <7441, 7440, 7442>,
    <7441, 7442, 7428>,
    <7441, 7428, 7427>,
    <7441, 7427, 7424>,
    <7441, 7424, 7436>,
    <7443, 7444, 7445>,
    <7443, 7445, 7446>,
    <7443, 7446, 7447>,
    <7443, 7447, 7448>,
    <7443, 7448, 7449>,
    <7443, 7449, 7450>,
    <7443, 7450, 7451>,
    <7443, 7451, 7444>,
    <7452, 7453, 7445>,
    <7452, 7445, 7444>,
    <7452, 7444, 7451>,
    <7452, 7451, 7454>,
    <7452, 7454, 6836>,
    <7452, 6836, 6856>,
    <7452, 6856, 6853>,
    <7452, 6853, 7453>,
    <7455, 7446, 7445>,
    <7455, 7445, 7453>,
    <7455, 7453, 6853>,
    <7455, 6853, 6852>,
    <7455, 6852, 6684>,
    <7455, 6684, 7456>,
    <7455, 7456, 7447>,
    <7455, 7447, 7446>,
    <7457, 7458, 7459>,
    <7457, 7459, 7460>,
    <7457, 7460, 7385>,
    <7457, 7385, 7384>,
    <7457, 7384, 7383>,
    <7457, 7383, 7461>,
    <7457, 7461, 7462>,
    <7457, 7462, 7458>,
    <7463, 7464, 7459>,
    <7463, 7459, 7458>,
    <7463, 7458, 7462>,
    <7463, 7462, 7465>,
    <7463, 7465, 7449>,
    <7463, 7449, 7448>,
    <7463, 7448, 7447>,
    <7463, 7447, 7464>,
    <7466, 7460, 7459>,
    <7466, 7459, 7464>,
    <7466, 7464, 7447>,
    <7466, 7447, 7456>,
    <7466, 7456, 6684>,
    <7466, 6684, 7388>,
    <7466, 7388, 7385>,
    <7466, 7385, 7460>,
    <7467, 7468, 7469>,
    <7467, 7469, 7470>,
    <7467, 7470, 7471>,
    <7467, 7471, 7472>,
    <7467, 7472, 6544>,
    <7467, 6544, 7328>,
    <7467, 7328, 7326>,
    <7467, 7326, 7468>,
    <7473, 7474, 7469>,
    <7473, 7469, 7468>,
    <7473, 7468, 7326>,
    <7473, 7326, 7325>,
    <7473, 7325, 7317>,
    <7473, 7317, 7475>,
    <7473, 7475, 7476>,
    <7473, 7476, 7474>,
    <7477, 7470, 7469>,
    <7477, 7469, 7474>,
    <7477, 7474, 7476>,
    <7477, 7476, 7478>,
    <7477, 7478, 7479>,
    <7477, 7479, 7480>,
    <7477, 7480, 7471>,
    <7477, 7471, 7470>,
    <7481, 7482, 7483>,
    <7481, 7483, 7484>,
    <7481, 7484, 6715>,
    <7481, 6715, 6714>,
    <7481, 6714, 6544>,
    <7481, 6544, 7472>,
    <7481, 7472, 7471>,
    <7481, 7471, 7482>,
    <7485, 7486, 7483>,
    <7485, 7483, 7482>,
    <7485, 7482, 7471>,
    <7485, 7471, 7480>,
    <7485, 7480, 7479>,
    <7485, 7479, 7487>,
    <7485, 7487, 7488>,
    <7485, 7488, 7486>,
    <7489, 7484, 7483>,
    <7489, 7483, 7486>,
    <7489, 7486, 7488>,
    <7489, 7488, 7490>,
    <7489, 7490, 6718>,
    <7489, 6718, 6717>,
    <7489, 6717, 6715>,
    <7489, 6715, 7484>,
    <7491, 7492, 7493>,
    <7491, 7493, 7494>,
    <7491, 7494, 7495>,
    <7491, 7495, 7496>,
    <7491, 7496, 7497>,
    <7491, 7497, 7498>,
    <7491, 7498, 7499>,
    <7491, 7499, 7492>,
    <7500, 7501, 7493>,
    <7500, 7493, 7492>,
    <7500, 7492, 7499>,
    <7500, 7499, 7502>,
    <7500, 7502, 6736>,
    <7500, 6736, 7028>,
    <7500, 7028, 7027>,
    <7500, 7027, 7501>,
    <7503, 7494, 7493>,
    <7503, 7493, 7501>,
    <7503, 7501, 7027>,
    <7503, 7027, 7032>,
    <7503, 7032, 7011>,
    <7503, 7011, 7504>,
    <7503, 7504, 7495>,
    <7503, 7495, 7494>,
    <7505, 7506, 7507>,
    <7505, 7507, 7508>,
    <7505, 7508, 7509>,
    <7505, 7509, 7510>,
    <7505, 7510, 7335>,
    <7505, 7335, 7334>,
    <7505, 7334, 7333>,
    <7505, 7333, 7506>,
    <7511, 7512, 7507>,
    <7511, 7507, 7506>,
    <7511, 7506, 7333>,
    <7511, 7333, 7342>,
    <7511, 7342, 6736>,
    <7511, 6736, 7502>,
    <7511, 7502, 7499>,
    <7511, 7499, 7512>,
    <7513, 7508, 7507>,
    <7513, 7507, 7512>,
    <7513, 7512, 7499>,
    <7513, 7499, 7498>,
    <7513, 7498, 7497>,
    <7513, 7497, 7514>,
    <7513, 7514, 7509>,
    <7513, 7509, 7508>,
    <7515, 7516, 7517>,
    <7515, 7517, 7518>,
    <7515, 7518, 7440>,
    <7515, 7440, 7439>,
    <7515, 7439, 6663>,
    <7515, 6663, 7519>,
    <7515, 7519, 7520>,
    <7515, 7520, 7516>,
    <7521, 7522, 7517>,
    <7521, 7517, 7516>,
    <7521, 7516, 7520>,
    <7521, 7520, 7523>,
    <7521, 7523, 7524>,
    <7521, 7524, 7525>,
    <7521, 7525, 7526>,
    <7521, 7526, 7522>,
    <7527, 7518, 7517>,
    <7527, 7517, 7522>,
    <7527, 7522, 7526>,
    <7527, 7526, 7528>,
    <7527, 7528, 7428>,
    <7527, 7428, 7442>,
    <7527, 7442, 7440>,
    <7527, 7440, 7518>,
    <7529, 7530, 7531>,
    <7529, 7531, 7532>,
    <7529, 7532, 7520>,
    <7529, 7520, 7519>,
    <7529, 7519, 6663>,
    <7529, 6663, 6819>,
    <7529, 6819, 6817>,
    <7529, 6817, 7530>,
    <7533, 7534, 7531>,
    <7533, 7531, 7530>,
    <7533, 7530, 6817>,
    <7533, 6817, 6816>,
    <7533, 6816, 6815>,
    <7533, 6815, 7535>,
    <7533, 7535, 7536>,
    <7533, 7536, 7534>,
    <7537, 7532, 7531>,
    <7537, 7531, 7534>,
    <7537, 7534, 7536>,
    <7537, 7536, 7538>,
    <7537, 7538, 7524>,
    <7537, 7524, 7523>,
    <7537, 7523, 7520>,
    <7537, 7520, 7532>,
    <7539, 7540, 7541>,
    <7539, 7541, 7542>,
    <7539, 7542, 7543>,
    <7539, 7543, 7544>,
    <7539, 7544, 7545>,
    <7539, 7545, 7546>,
    <7539, 7546, 7547>,
    <7539, 7547, 7540>,
    <7548, 7549, 7541>,
    <7548, 7541, 7540>,
    <7548, 7540, 7547>,
    <7548, 7547, 7550>,
    <7548, 7550, 7551>,
    <7548, 7551, 6895>,
    <7548, 6895, 6892>,
    <7548, 6892, 7549>,
    <7552, 7542, 7541>,
    <7552, 7541, 7549>,
    <7552, 7549, 6892>,
    <7552, 6892, 6891>,
    <7552, 6891, 6836>,
    <7552, 6836, 7553>,
    <7552, 7553, 7543>,
    <7552, 7543, 7542>,
    <7554, 7555, 7556>,
    <7554, 7556, 7557>,
    <7554, 7557, 7451>,
    <7554, 7451, 7450>,
    <7554, 7450, 7449>,
    <7554, 7449, 7558>,
    <7554, 7558, 7559>,
    <7554, 7559, 7555>,
    <7560, 7561, 7556>,
    <7560, 7556, 7555>,
    <7560, 7555, 7559>,
    <7560, 7559, 7562>,
    <7560, 7562, 7545>,
    <7560, 7545, 7544>,
    <7560, 7544, 7543>,
    <7560, 7543, 7561>,
    <7563, 7557, 7556>,
    <7563, 7556, 7561>,
    <7563, 7561, 7543>,
    <7563, 7543, 7553>,
    <7563, 7553, 6836>,
    <7563, 6836, 7454>,
    <7563, 7454, 7451>,
    <7563, 7451, 7557>,
    <7564, 7565, 7566>,
    <7564, 7566, 7567>,
    <7564, 7567, 7536>,
    <7564, 7536, 7535>,
    <7564, 7535, 6815>,
    <7564, 6815, 7568>,
    <7564, 7568, 7569>,
    <7564, 7569, 7565>,
    <7570, 7571, 7566>,
    <7570, 7566, 7565>,
    <7570, 7565, 7569>,
    <7570, 7569, 7572>,
    <7570, 7572, 7573>,
    <7570, 7573, 7574>,
    <7570, 7574, 7575>,
    <7570, 7575, 7571>,
    <7576, 7567, 7566>,
    <7576, 7566, 7571>,
    <7576, 7571, 7575>,
    <7576, 7575, 7577>,
    <7576, 7577, 7524>,
    <7576, 7524, 7538>,
    <7576, 7538, 7536>,
    <7576, 7536, 7567>,
    <7578, 7579, 7580>,
    <7578, 7580, 7581>,
    <7578, 7581, 7569>,
    <7578, 7569, 7568>,
    <7578, 7568, 6815>,
    <7578, 6815, 6871>,
    <7578, 6871, 6869>,
    <7578, 6869, 7579>,
    <7582, 7583, 7580>,
    <7582, 7580, 7579>,
    <7582, 7579, 6869>,
    <7582, 6869, 6868>,
    <7582, 6868, 7584>,
    <7582, 7584, 7585>,
    <7582, 7586, 7587>,
    <7582, 7587, 7583>,
    <7588, 7581, 7580>,
    <7588, 7580, 7583>,
    <7588, 7583, 7589>,
    <7588, 7589, 7590>,
    <7588, 7591, 7592>,
    <7588, 7592, 7572>,
    <7588, 7572, 7569>,
    <7588, 7569, 7581>,
    <7593, 7594, 7595>,
    <7593, 7595, 7596>,
    <7593, 7596, 7547>,
    <7593, 7547, 7546>,
    <7593, 7546, 7545>,
    <7593, 7545, 7597>,
    <7593, 7597, 7598>,
    <7593, 7598, 7594>,
    <7599, 7600, 7595>,
    <7599, 7595, 7594>,
    <7599, 7594, 7598>,
    <7599, 7598, 7601>,
    <7599, 7601, 7602>,
    <7599, 7602, 7603>,
    <7599, 7604, 7605>,
    <7599, 7605, 7600>,
    <7606, 7596, 7595>,
    <7606, 7595, 7600>,
    <7606, 7600, 7607>,
    <7606, 7607, 7608>,
    <7606, 7609, 7610>,
    <7606, 7610, 7550>,
    <7606, 7550, 7547>,
    <7606, 7547, 7596>,
    <7611, 7612, 7613>,
    <7611, 7613, 7614>,
    <7611, 7614, 7615>,
    <7611, 7615, 7616>,
    <7611, 7616, 6718>,
    <7611, 6718, 7490>,
    <7611, 7490, 7488>,
    <7611, 7488, 7612>,
    <7617, 7618, 7613>,
    <7617, 7613, 7612>,
    <7617, 7612, 7488>,
    <7617, 7488, 7487>,
    <7617, 7487, 7479>,
    <7617, 7479, 7619>,
    <7617, 7619, 7620>,
    <7617, 7620, 7618>,
    <7621, 7614, 7613>,
    <7621, 7613, 7618>,
    <7621, 7618, 7620>,
    <7621, 7620, 7622>,
    <7621, 7622, 7623>,
    <7621, 7623, 7624>,
    <7621, 7624, 7615>,
    <7621, 7615, 7614>,
    <7625, 7626, 7627>,
    <7625, 7627, 7628>,
    <7625, 7628, 6990>,
    <7625, 6990, 6989>,
    <7625, 6989, 6718>,
    <7625, 6718, 7616>,
    <7625, 7616, 7615>,
    <7625, 7615, 7626>,
    <7629, 7630, 7627>,
    <7629, 7627, 7626>,
    <7629, 7626, 7615>,
    <7629, 7615, 7624>,
    <7629, 7624, 7623>,
    <7629, 7623, 7631>,
    <7629, 7631, 7632>,
    <7629, 7632, 7630>,
    <7633, 7628, 7627>,
    <7633, 7627, 7630>,
    <7633, 7630, 7632>,
    <7633, 7632, 7634>,
    <7633, 7634, 6993>,
    <7633, 6993, 6992>,
    <7633, 6992, 6990>,
    <7633, 6990, 7628>,
    <7635, 7636, 7637>,
    <7635, 7637, 7638>,
    <7635, 7638, 7639>,
    <7635, 7639, 7640>,
    <7635, 7640, 7641>,
    <7635, 7641, 7642>,
    <7635, 7642, 7643>,
    <7635, 7643, 7636>,
    <7644, 7645, 7637>,
    <7644, 7637, 7636>,
    <7644, 7636, 7643>,
    <7644, 7643, 7646>,
    <7644, 7646, 7011>,
    <7644, 7011, 7098>,
    <7644, 7098, 7097>,
    <7644, 7097, 7645>,
    <7647, 7638, 7637>,
    <7647, 7637, 7645>,
    <7647, 7645, 7097>,
    <7647, 7097, 7102>,
    <7647, 7102, 7081>,
    <7647, 7081, 7648>,
    <7647, 7648, 7639>,
    <7647, 7639, 7638>,
    <7649, 7650, 7651>,
    <7649, 7651, 7652>,
    <7649, 7652, 7653>,
    <7649, 7653, 7654>,
    <7649, 7654, 7497>,
    <7649, 7497, 7496>,
    <7649, 7496, 7495>,
    <7649, 7495, 7650>,
    <7655, 7656, 7651>,
    <7655, 7651, 7650>,
    <7655, 7650, 7495>,
    <7655, 7495, 7504>,
    <7655, 7504, 7011>,
    <7655, 7011, 7646>,
    <7655, 7646, 7643>,
    <7655, 7643, 7656>,
    <7657, 7652, 7651>,
    <7657, 7651, 7656>,
    <7657, 7656, 7643>,
    <7657, 7643, 7642>,
    <7657, 7642, 7641>,
    <7657, 7641, 7658>,
    <7657, 7658, 7653>,
    <7657, 7653, 7652>,
    <7659, 7660, 7661>,
    <7659, 7661, 7662>,
    <7659, 7662, 7663>,
    <7659, 7663, 7664>,
    <7659, 7664, 6993>,
    <7659, 6993, 7634>,
    <7659, 7634, 7632>,
    <7659, 7632, 7660>,
    <7665, 7666, 7661>,
    <7665, 7661, 7660>,
    <7665, 7660, 7632>,
    <7665, 7632, 7631>,
    <7665, 7631, 7623>,
    <7665, 7623, 7667>,
    <7665, 7667, 7668>,
    <7665, 7668, 7666>,
    <7669, 7662, 7661>,
    <7669, 7661, 7666>,
    <7669, 7666, 7668>,
    <7669, 7668, 7670>,
    <7669, 7670, 7671>,
    <7669, 7671, 7672>,
    <7669, 7672, 7663>,
    <7669, 7663, 7662>,
    <7673, 7674, 7675>,
    <7673, 7675, 7676>,
    <7673, 7676, 7060>,
    <7673, 7060, 7059>,
    <7673, 7059, 6993>,
    <7673, 6993, 7664>,
    <7673, 7664, 7663>,
    <7673, 7663, 7674>,
    <7677, 7678, 7675>,
    <7677, 7675, 7674>,
    <7677, 7674, 7663>,
    <7677, 7663, 7672>,
    <7677, 7672, 7671>,
    <7677, 7671, 7679>,
    <7677, 7679, 7680>,
    <7677, 7680, 7678>,
    <7681, 7676, 7675>,
    <7681, 7675, 7678>,
    <7681, 7678, 7680>,
    <7681, 7680, 7682>,
    <7681, 7682, 7063>,
    <7681, 7063, 7062>,
    <7681, 7062, 7060>,
    <7681, 7060, 7676>,
    <7683, 7684, 7685>,
    <7683, 7685, 7686>,
    <7683, 7686, 7687>,
    <7683, 7687, 7688>,
    <7683, 7688, 7689>,
    <7683, 7689, 7690>,
    <7683, 7690, 7691>,
    <7683, 7691, 7684>,
    <7692, 7693, 7685>,
    <7692, 7685, 7684>,
    <7692, 7684, 7691>,
    <7692, 7691, 7694>,
    <7692, 7694, 7081>,
    <7692, 7081, 7185>,
    <7692, 7185, 7184>,
    <7692, 7184, 7693>,
    <7695, 7686, 7685>,
    <7695, 7685, 7693>,
    <7695, 7693, 7184>,
    <7695, 7184, 7190>,
    <7695, 7190, 518>,
    <7695, 518, 7696>,
    <7695, 7696, 7687>,
    <7695, 7687, 7686>,
    <7697, 7698, 7699>,
    <7697, 7699, 7700>,
    <7697, 7700, 7701>,
    <7697, 7701, 7702>,
    <7697, 7702, 7641>,
    <7697, 7641, 7640>,
    <7697, 7640, 7639>,
    <7697, 7639, 7698>,
    <7703, 7704, 7699>,
    <7703, 7699, 7698>,
    <7703, 7698, 7639>,
    <7703, 7639, 7648>,
    <7703, 7648, 7081>,
    <7703, 7081, 7694>,
    <7703, 7694, 7691>,
    <7703, 7691, 7704>,
    <7705, 7700, 7699>,
    <7705, 7699, 7704>,
    <7705, 7704, 7691>,
    <7705, 7691, 7690>,
    <7705, 7690, 7689>,
    <7705, 7689, 7706>,
    <7705, 7706, 7701>,
    <7705, 7701, 7700>,
    <7707, 7708, 7709>,
    <7707, 7709, 7710>,
    <7707, 7710, 7711>,
    <7707, 7711, 7712>,
    <7707, 7712, 7063>,
    <7707, 7063, 7682>,
    <7707, 7682, 7680>,
    <7707, 7680, 7708>,
    <7713, 7714, 7709>,
    <7713, 7709, 7708>,
    <7713, 7708, 7680>,
    <7713, 7680, 7679>,
    <7713, 7679, 7671>,
    <7713, 7671, 7715>,
    <7713, 7715, 7716>,
    <7713, 7716, 7714>,
    <7717, 7710, 7709>,
    <7717, 7709, 7714>,
    <7717, 7714, 7716>,
    <7717, 7716, 7718>,
    <7717, 7718, 762>,
    <7717, 762, 7719>,
    <7717, 7719, 7711>,
    <7717, 7711, 7710>,
    <7720, 7721, 7722>,
    <7720, 7722, 7723>,
    <7720, 7723, 7160>,
    <7720, 7160, 7159>,
    <7720, 7159, 7063>,
    <7720, 7063, 7712>,
    <7720, 7712, 7711>,
    <7720, 7711, 7721>,
    <7724, 7725, 7722>,
    <7724, 7722, 7721>,
    <7724, 7721, 7711>,
    <7724, 7711, 7719>,
    <7724, 7719, 762>,
    <7724, 762, 800>,
    <7724, 800, 798>,
    <7724, 798, 7725>,
    <7726, 7723, 7722>,
    <7726, 7722, 7725>,
    <7726, 7725, 798>,
    <7726, 798, 797>,
    <7726, 797, 7727>,
    <7726, 7727, 7162>,
    <7726, 7162, 7160>,
    <7726, 7160, 7723>,
    <7728, 7729, 7730>,
    <7728, 7730, 7731>,
    <7728, 7731, 7732>,
    <7728, 7732, 7733>,
    <7728, 7733, 7689>,
    <7728, 7689, 7688>,
    <7728, 7688, 7687>,
    <7728, 7687, 7729>,
    <7734, 7735, 7730>,
    <7734, 7730, 7729>,
    <7734, 7729, 7687>,
    <7734, 7687, 7696>,
    <7734, 7696, 518>,
    <7734, 518, 833>,
    <7734, 833, 831>,
    <7734, 831, 7735>,
    <7736, 7731, 7730>,
    <7736, 7730, 7735>,
    <7736, 7735, 831>,
    <7736, 831, 830>,
    <7736, 830, 814>,
    <7736, 814, 7737>,
    <7736, 7737, 7732>,
    <7736, 7732, 7731>,
    <7738, 7739, 7740>,
    <7738, 7740, 7741>,
    <7738, 7741, 7742>,
    <7738, 7742, 7743>,
    <7738, 7744, 7745>,
    <7738, 7745, 7746>,
    <7738, 7746, 7747>,
    <7738, 7747, 7739>,
    <7748, 7749, 7740>,
    <7748, 7740, 7739>,
    <7748, 7739, 7747>,
    <7748, 7747, 7750>,
    <7748, 7750, 7751>,
    <7748, 7751, 7752>,
    <7748, 7752, 7753>,
    <7748, 7753, 7749>,
    <7754, 7741, 7740>,
    <7754, 7740, 7749>,
    <7754, 7749, 7753>,
    <7754, 7753, 7755>,
    <7754, 7755, 7756>,
    <7754, 7756, 7757>,
    <7754, 7758, 7759>,
    <7754, 7759, 7741>,
    <7760, 7761, 7762>,
    <7760, 7762, 7763>,
    <7760, 7763, 7747>,
    <7760, 7747, 7746>,
    <7760, 7746, 7764>,
    <7760, 7764, 7765>,
    <7760, 7766, 7767>,
    <7760, 7767, 7761>,
    <7768, 7769, 7762>,
    <7768, 7762, 7761>,
    <7768, 7761, 7770>,
    <7768, 7770, 7771>,
    <7768, 7772, 7773>,
    <7768, 7773, 7774>,
    <7768, 7774, 7775>,
    <7768, 7775, 7769>,
    <7776, 7763, 7762>,
    <7776, 7762, 7769>,
    <7776, 7769, 7775>,
    <7776, 7775, 7777>,
    <7776, 7777, 7751>,
    <7776, 7751, 7750>,
    <7776, 7750, 7747>,
    <7776, 7747, 7763>,
    <7778, 7779, 7780>,
    <7778, 7780, 7781>,
    <7778, 7781, 7775>,
    <7778, 7775, 7774>,
    <7778, 7774, 7782>,
    <7778, 7782, 7038>,
    <7778, 7038, 7037>,
    <7778, 7037, 7779>,
    <7783, 7784, 7780>,
    <7783, 7780, 7779>,
    <7783, 7779, 7037>,
    <7783, 7037, 7050>,
    <7783, 7050, 6433>,
    <7783, 6433, 7785>,
    <7783, 7785, 7786>,
    <7783, 7786, 7784>,
    <7787, 7781, 7780>,
    <7787, 7780, 7784>,
    <7787, 7784, 7786>,
    <7787, 7786, 7788>,
    <7787, 7788, 7751>,
    <7787, 7751, 7777>,
    <7787, 7777, 7775>,
    <7787, 7775, 7781>,
    <7789, 7790, 7791>,
    <7789, 7791, 7792>,
    <7789, 7792, 7200>,
    <7789, 7200, 7199>,
    <7789, 7199, 7793>,
    <7789, 7793, 7794>,
    <7789, 7794, 7795>,
    <7789, 7795, 7790>,
    <7796, 7797, 7791>,
    <7796, 7791, 7790>,
    <7796, 7790, 7795>,
    <7796, 7795, 7798>,
    <7796, 7798, 7799>,
    <7796, 7799, 7800>,
    <7796, 7800, 7801>,
    <7796, 7801, 7797>,
    <7802, 7792, 7791>,
    <7802, 7791, 7797>,
    <7802, 7797, 7801>,
    <7802, 7801, 7803>,
    <7802, 7803, 6481>,
    <7802, 6481, 7203>,
    <7802, 7203, 7200>,
    <7802, 7200, 7792>,
    <7804, 7805, 7806>,
    <7804, 7806, 7807>,
    <7804, 7807, 7795>,
    <7804, 7795, 7794>,
    <7804, 7794, 7808>,
    <7804, 7808, 7809>,
    <7804, 7810, 7811>,
    <7804, 7811, 7805>,
    <7812, 7813, 7806>,
    <7812, 7806, 7805>,
    <7812, 7805, 7814>,
    <7812, 7814, 7815>,
    <7812, 7816, 7817>,
    <7812, 7817, 7818>,
    <7812, 7818, 7819>,
    <7812, 7819, 7813>,
    <7820, 7807, 7806>,
    <7820, 7806, 7813>,
    <7820, 7813, 7819>,
    <7820, 7819, 7821>,
    <7820, 7821, 7799>,
    <7820, 7799, 7798>,
    <7820, 7798, 7795>,
    <7820, 7795, 7807>,
    <7822, 7823, 7824>,
    <7822, 7824, 7825>,
    <7822, 7825, 7801>,
    <7822, 7801, 7800>,
    <7822, 7800, 7799>,
    <7822, 7799, 7826>,
    <7822, 7826, 7827>,
    <7822, 7827, 7823>,
    <7828, 7829, 7824>,
    <7828, 7824, 7823>,
    <7828, 7823, 7827>,
    <7828, 7827, 7830>,
    <7828, 7830, 6788>,
    <7828, 6788, 6804>,
    <7828, 6804, 6801>,
    <7828, 6801, 7829>,
    <7831, 7825, 7824>,
    <7831, 7824, 7829>,
    <7831, 7829, 6801>,
    <7831, 6801, 6800>,
    <7831, 6800, 6481>,
    <7831, 6481, 7803>,
    <7831, 7803, 7801>,
    <7831, 7801, 7825>,
    <7832, 7833, 7834>,
    <7832, 7834, 7835>,
    <7832, 7835, 7819>,
    <7832, 7819, 7818>,
    <7832, 7818, 7836>,
    <7832, 7836, 7837>,
    <7832, 7838, 7839>,
    <7832, 7839, 7833>,
    <7840, 7841, 7834>,
    <7840, 7834, 7833>,
    <7840, 7833, 7842>,
    <7840, 7842, 7843>,
    <7840, 7844, 7845>,
    <7840, 7845, 7846>,
    <7840, 7846, 7847>,
    <7840, 7847, 7841>,
    <7848, 7835, 7834>,
    <7848, 7834, 7841>,
    <7848, 7841, 7847>,
    <7848, 7847, 7849>,
    <7848, 7849, 7799>,
    <7848, 7799, 7821>,
    <7848, 7821, 7819>,
    <7848, 7819, 7835>,
    <7850, 7851, 7852>,
    <7850, 7852, 7853>,
    <7850, 7853, 7854>,
    <7850, 7854, 7855>,
    <7850, 7855, 7856>,
    <7850, 7856, 7857>,
    <7850, 7858, 7859>,
    <7850, 7859, 7851>,
    <7860, 7861, 7852>,
    <7860, 7852, 7851>,
    <7860, 7851, 7862>,
    <7860, 7862, 7863>,
    <7860, 7864, 7865>,
    <7860, 7865, 7406>,
    <7860, 7406, 7405>,
    <7860, 7405, 7861>,
    <7866, 7853, 7852>,
    <7866, 7852, 7861>,
    <7866, 7861, 7405>,
    <7866, 7405, 7418>,
    <7866, 7418, 6962>,
    <7866, 6962, 7867>,
    <7866, 7867, 7854>,
    <7866, 7854, 7853>,
    <7868, 7869, 7870>,
    <7868, 7870, 7871>,
    <7868, 7871, 7786>,
    <7868, 7786, 7785>,
    <7868, 7785, 6433>,
    <7868, 6433, 7872>,
    <7868, 7872, 7873>,
    <7868, 7873, 7869>,
    <7874, 7875, 7870>,
    <7874, 7870, 7869>,
    <7874, 7869, 7873>,
    <7874, 7873, 7876>,
    <7874, 7876, 7877>,
    <7874, 7877, 7878>,
    <7874, 7878, 7879>,
    <7874, 7879, 7875>,
    <7880, 7871, 7870>,
    <7880, 7870, 7875>,
    <7880, 7875, 7879>,
    <7880, 7879, 7881>,
    <7880, 7881, 7751>,
    <7880, 7751, 7788>,
    <7880, 7788, 7786>,
    <7880, 7786, 7871>,
    <7882, 7883, 7884>,
    <7882, 7884, 7885>,
    <7882, 7885, 7873>,
    <7882, 7873, 7872>,
    <7882, 7872, 6433>,
    <7882, 6433, 6771>,
    <7882, 6771, 6769>,
    <7882, 6769, 7883>,
    <7886, 7887, 7884>,
    <7886, 7884, 7883>,
    <7886, 7883, 6769>,
    <7886, 6769, 6768>,
    <7886, 6768, 6767>,
    <7886, 6767, 7888>,
    <7886, 7888, 7889>,
    <7886, 7889, 7887>,
    <7890, 7885, 7884>,
    <7890, 7884, 7887>,
    <7890, 7887, 7889>,
    <7890, 7889, 7891>,
    <7890, 7891, 7877>,
    <7890, 7877, 7876>,
    <7890, 7876, 7873>,
    <7890, 7873, 7885>,
    <7892, 7893, 7894>,
    <7892, 7894, 7895>,
    <7892, 7895, 7896>,
    <7892, 7896, 7897>,
    <7892, 7897, 7898>,
    <7892, 7898, 7899>,
    <7892, 7899, 7900>,
    <7892, 7900, 7893>,
    <7901, 7902, 7894>,
    <7901, 7894, 7893>,
    <7901, 7893, 7900>,
    <7901, 7900, 7903>,
    <7901, 7903, 7133>,
    <7901, 7133, 7149>,
    <7901, 7149, 7146>,
    <7901, 7146, 7902>,
    <7904, 7895, 7894>,
    <7904, 7894, 7902>,
    <7904, 7902, 7146>,
    <7904, 7146, 7145>,
    <7904, 7145, 6788>,
    <7904, 6788, 7905>,
    <7904, 7905, 7896>,
    <7904, 7896, 7895>,
    <7906, 7907, 7908>,
    <7906, 7908, 7909>,
    <7906, 7909, 7827>,
    <7906, 7827, 7826>,
    <7906, 7826, 7799>,
    <7906, 7799, 7910>,
    <7906, 7910, 7911>,
    <7906, 7911, 7907>,
    <7912, 7913, 7908>,
    <7912, 7908, 7907>,
    <7912, 7907, 7911>,
    <7912, 7911, 7914>,
    <7912, 7914, 7898>,
    <7912, 7898, 7897>,
    <7912, 7897, 7896>,
    <7912, 7896, 7913>,
    <7915, 7909, 7908>,
    <7915, 7908, 7913>,
    <7915, 7913, 7896>,
    <7915, 7896, 7905>,
    <7915, 7905, 6788>,
    <7915, 6788, 7830>,
    <7915, 7830, 7827>,
    <7915, 7827, 7909>,
    <7916, 7917, 7918>,
    <7916, 7918, 7919>,
    <7916, 7919, 7920>,
    <7916, 7920, 7921>,
    <7916, 7921, 7922>,
    <7916, 7922, 7923>,
    <7916, 7924, 7925>,
    <7916, 7925, 7917>,
    <7926, 7927, 7918>,
    <7926, 7918, 7917>,
    <7926, 7917, 7928>,
    <7926, 7928, 7929>,
    <7926, 7930, 7931>,
    <7926, 7931, 7932>,
    <7926, 7932, 7933>,
    <7926, 7933, 7927>,
    <7934, 7919, 7918>,
    <7934, 7918, 7927>,
    <7934, 7927, 7933>,
    <7934, 7933, 7935>,
    <7934, 7935, 7936>,
    <7934, 7936, 7937>,
    <7934, 7937, 7920>,
    <7934, 7920, 7919>,
    <7938, 7939, 7940>,
    <7938, 7940, 7941>,
    <7938, 7941, 7942>,
    <7938, 7942, 7943>,
    <7938, 7943, 7944>,
    <7938, 7944, 7945>,
    <7938, 7946, 7947>,
    <7938, 7947, 7939>,
    <7948, 7949, 7940>,
    <7948, 7940, 7939>,
    <7948, 7939, 7950>,
    <7948, 7950, 7951>,
    <7948, 7952, 7953>,
    <7948, 7953, 7921>,
    <7948, 7921, 7920>,
    <7948, 7920, 7949>,
    <7954, 7941, 7940>,
    <7954, 7940, 7949>,
    <7954, 7949, 7920>,
    <7954, 7920, 7937>,
    <7954, 7937, 7936>,
    <7954, 7936, 7955>,
    <7954, 7955, 7942>,
    <7954, 7942, 7941>,
    <7956, 7957, 7958>,
    <7956, 7958, 7959>,
    <7956, 7959, 6922>,
    <7956, 6922, 6921>,
    <7956, 6921, 7960>,
    <7956, 7960, 7943>,
    <7956, 7943, 7942>,
    <7956, 7942, 7957>,
    <7961, 7962, 7958>,
    <7961, 7958, 7957>,
    <7961, 7957, 7942>,
    <7961, 7942, 7955>,
    <7961, 7955, 7936>,
    <7961, 7936, 7963>,
    <7961, 7963, 7964>,
    <7961, 7964, 7962>,
    <7965, 7959, 7958>,
    <7965, 7958, 7962>,
    <7965, 7962, 7964>,
    <7965, 7964, 7966>,
    <7965, 7966, 6925>,
    <7965, 6925, 6924>,
    <7965, 6924, 6922>,
    <7965, 6922, 7959>,
    <7967, 7968, 7969>,
    <7967, 7969, 7970>,
    <7967, 7970, 7971>,
    <7967, 7971, 7972>,
    <7967, 7972, 7973>,
    <7967, 7973, 7974>,
    <7967, 7974, 7975>,
    <7967, 7975, 7968>,
    <7976, 7977, 7969>,
    <7976, 7969, 7968>,
    <7976, 7968, 7975>,
    <7976, 7975, 7978>,
    <7976, 7978, 6962>,
    <7976, 6962, 7252>,
    <7976, 7252, 7251>,
    <7976, 7251, 7977>,
    <7979, 7970, 7969>,
    <7979, 7969, 7977>,
    <7979, 7977, 7251>,
    <7979, 7251, 7256>,
    <7979, 7256, 7239>,
    <7979, 7239, 7980>,
    <7979, 7980, 7971>,
    <7979, 7971, 7970>,
    <7981, 7982, 7983>,
    <7981, 7983, 7984>,
    <7981, 7984, 7985>,
    <7981, 7985, 7986>,
    <7981, 7986, 7987>,
    <7981, 7987, 7855>,
    <7981, 7855, 7854>,
    <7981, 7854, 7982>,
    <7988, 7989, 7983>,
    <7988, 7983, 7982>,
    <7988, 7982, 7854>,
    <7988, 7854, 7867>,
    <7988, 7867, 6962>,
    <7988, 6962, 7978>,
    <7988, 7978, 7975>,
    <7988, 7975, 7989>,
    <7990, 7984, 7983>,
    <7990, 7983, 7989>,
    <7990, 7989, 7975>,
    <7990, 7975, 7974>,
    <7990, 7974, 7973>,
    <7990, 7973, 7991>,
    <7990, 7991, 7985>,
    <7990, 7985, 7984>,
    <7992, 7993, 7994>,
    <7992, 7994, 7995>,
    <7992, 7995, 7889>,
    <7992, 7889, 7888>,
    <7992, 7888, 6767>,
    <7992, 6767, 7996>,
    <7992, 7996, 7997>,
    <7992, 7997, 7993>,
    <7998, 7999, 7994>,
    <7998, 7994, 7993>,
    <7998, 7993, 7997>,
    <7998, 7997, 8000>,
    <7998, 8000, 8001>,
    <7998, 8001, 8002>,
    <7998, 8002, 8003>,
    <7998, 8003, 7999>,
    <8004, 7995, 7994>,
    <8004, 7994, 7999>,
    <8004, 7999, 8003>,
    <8004, 8003, 8005>,
    <8004, 8005, 7877>,
    <8004, 7877, 7891>,
    <8004, 7891, 7889>,
    <8004, 7889, 7995>,
    <8006, 8007, 8008>,
    <8006, 8008, 8009>,
    <8006, 8009, 7997>,
    <8006, 7997, 7996>,
    <8006, 7996, 6767>,
    <8006, 6767, 7116>,
    <8006, 7116, 7114>,
    <8006, 7114, 8007>,
    <8010, 8011, 8008>,
    <8010, 8008, 8007>,
    <8010, 8007, 7114>,
    <8010, 7114, 7113>,
    <8010, 7113, 7112>,
    <8010, 7112, 8012>,
    <8010, 8012, 8013>,
    <8010, 8013, 8011>,
    <8014, 8009, 8008>,
    <8014, 8008, 8011>,
    <8014, 8011, 8013>,
    <8014, 8013, 8015>,
    <8014, 8015, 8001>,
    <8014, 8001, 8000>,
    <8014, 8000, 7997>,
    <8014, 7997, 8009>,
    <8016, 8017, 8018>,
    <8016, 8018, 8019>,
    <8016, 8019, 8020>,
    <8016, 8020, 8021>,
    <8016, 8021, 8022>,
    <8016, 8022, 8023>,
    <8016, 8023, 8024>,
    <8016, 8024, 8017>,
    <8025, 8026, 8018>,
    <8025, 8018, 8017>,
    <8025, 8017, 8024>,
    <8025, 8024, 8027>,
    <8025, 8027, 7287>,
    <8025, 7287, 7303>,
    <8025, 7303, 7300>,
    <8025, 7300, 8026>,
    <8028, 8019, 8018>,
    <8028, 8018, 8026>,
    <8028, 8026, 7300>,
    <8028, 7300, 7299>,
    <8028, 7299, 7133>,
    <8028, 7133, 8029>,
    <8028, 8029, 8020>,
    <8028, 8020, 8019>,
    <8030, 8031, 8032>,
    <8030, 8032, 8033>,
    <8030, 8033, 7900>,
    <8030, 7900, 7899>,
    <8030, 7899, 7898>,
    <8030, 7898, 8034>,
    <8030, 8034, 8035>,
    <8030, 8035, 8031>,
    <8036, 8037, 8032>,
    <8036, 8032, 8031>,
    <8036, 8031, 8035>,
    <8036, 8035, 8038>,
    <8036, 8038, 8022>,
    <8036, 8022, 8021>,
    <8036, 8021, 8020>,
    <8036, 8020, 8037>,
    <8039, 8033, 8032>,
    <8039, 8032, 8037>,
    <8039, 8037, 8020>,
    <8039, 8020, 8029>,
    <8039, 8029, 7133>,
    <8039, 7133, 7903>,
    <8039, 7903, 7900>,
    <8039, 7900, 8033>,
    <8040, 8041, 8042>,
    <8040, 8042, 8043>,
    <8040, 8043, 8044>,
    <8040, 8044, 8045>,
    <8040, 8045, 6925>,
    <8040, 6925, 7966>,
    <8040, 7966, 7964>,
    <8040, 7964, 8041>,
    <8046, 8047, 8042>,
    <8046, 8042, 8041>,
    <8046, 8041, 7964>,
    <8046, 7964, 7963>,
    <8046, 7963, 7936>,
    <8046, 7936, 8048>,
    <8046, 8048, 8049>,
    <8046, 8049, 8047>,
    <8050, 8043, 8042>,
    <8050, 8042, 8047>,
    <8050, 8047, 8049>,
    <8050, 8049, 8051>,
    <8050, 8051, 8052>,
    <8050, 8052, 8053>,
    <8050, 8053, 8044>,
    <8050, 8044, 8043>,
    <8054, 8055, 8056>,
    <8054, 8056, 8057>,
    <8054, 8057, 7218>,
    <8054, 7218, 7217>,
    <8054, 7217, 6925>,
    <8054, 6925, 8045>,
    <8054, 8045, 8044>,
    <8054, 8044, 8055>,
    <8058, 8059, 8056>,
    <8058, 8056, 8055>,
    <8058, 8055, 8044>,
    <8058, 8044, 8053>,
    <8058, 8053, 8052>,
    <8058, 8052, 8060>,
    <8058, 8060, 8061>,
    <8058, 8061, 8059>,
    <8062, 8057, 8056>,
    <8062, 8056, 8059>,
    <8062, 8059, 8061>,
    <8062, 8061, 8063>,
    <8062, 8063, 7221>,
    <8062, 7221, 7220>,
    <8062, 7220, 7218>,
    <8062, 7218, 8057>,
    <8064, 8065, 8066>,
    <8064, 8066, 8067>,
    <8064, 8067, 8068>,
    <8064, 8068, 8069>,
    <8064, 8069, 8070>,
    <8064, 8070, 8071>,
    <8064, 8071, 8072>,
    <8064, 8072, 8065>,
    <8073, 8074, 8066>,
    <8073, 8066, 8065>,
    <8073, 8065, 8072>,
    <8073, 8072, 8075>,
    <8073, 8075, 7239>,
    <8073, 7239, 7348>,
    <8073, 7348, 7347>,
    <8073, 7347, 8074>,
    <8076, 8067, 8066>,
    <8076, 8066, 8074>,
    <8076, 8074, 7347>,
    <8076, 7347, 7352>,
    <8076, 7352, 7335>,
    <8076, 7335, 8077>,
    <8076, 8077, 8068>,
    <8076, 8068, 8067>,
    <8078, 8079, 8080>,
    <8078, 8080, 8081>,
    <8078, 8081, 8082>,
    <8078, 8082, 8083>,
    <8078, 8083, 7973>,
    <8078, 7973, 7972>,
    <8078, 7972, 7971>,
    <8078, 7971, 8079>,
    <8084, 8085, 8080>,
    <8084, 8080, 8079>,
    <8084, 8079, 7971>,
    <8084, 7971, 7980>,
    <8084, 7980, 7239>,
    <8084, 7239, 8075>,
    <8084, 8075, 8072>,
    <8084, 8072, 8085>,
    <8086, 8081, 8080>,
    <8086, 8080, 8085>,
    <8086, 8085, 8072>,
    <8086, 8072, 8071>,
    <8086, 8071, 8070>,
    <8086, 8070, 8087>,
    <8086, 8087, 8082>,
    <8086, 8082, 8081>,
    <8088, 8089, 8090>,
    <8088, 8090, 8091>,
    <8088, 8091, 8013>,
    <8088, 8013, 8012>,
    <8088, 8012, 7112>,
    <8088, 7112, 8092>,
    <8088, 8092, 8093>,
    <8088, 8093, 8089>,
    <8094, 8095, 8090>,
    <8094, 8090, 8089>,
    <8094, 8089, 8093>,
    <8094, 8093, 8096>,
    <8094, 8096, 8097>,
    <8094, 8097, 8098>,
    <8094, 8098, 8099>,
    <8094, 8099, 8095>,
    <8100, 8091, 8090>,
    <8100, 8090, 8095>,
    <8100, 8095, 8099>,
    <8100, 8099, 8101>,
    <8100, 8101, 8001>,
    <8100, 8001, 8015>,
    <8100, 8015, 8013>,
    <8100, 8013, 8091>,
    <8102, 8103, 8104>,
    <8102, 8104, 8105>,
    <8102, 8105, 8093>,
    <8102, 8093, 8092>,
    <8102, 8092, 7112>,
    <8102, 7112, 7270>,
    <8102, 7270, 7268>,
    <8102, 7268, 8103>,
    <8106, 8107, 8104>,
    <8106, 8104, 8103>,
    <8106, 8103, 7268>,
    <8106, 7268, 7267>,
    <8106, 7267, 7266>,
    <8106, 7266, 8108>,
    <8106, 8108, 8109>,
    <8106, 8109, 8107>,
    <8110, 8105, 8104>,
    <8110, 8104, 8107>,
    <8110, 8107, 8109>,
    <8110, 8109, 8111>,
    <8110, 8111, 8097>,
    <8110, 8097, 8096>,
    <8110, 8096, 8093>,
    <8110, 8093, 8105>,
    <8112, 8113, 8114>,
    <8112, 8114, 8115>,
    <8112, 8115, 8116>,
    <8112, 8116, 8117>,
    <8112, 8117, 8118>,
    <8112, 8118, 8119>,
    <8112, 8119, 8120>,
    <8112, 8120, 8113>,
    <8121, 8122, 8114>,
    <8121, 8114, 8113>,
    <8121, 8113, 8120>,
    <8121, 8120, 8123>,
    <8121, 8123, 7383>,
    <8121, 7383, 7399>,
    <8121, 7399, 7396>,
    <8121, 7396, 8122>,
    <8124, 8115, 8114>,
    <8124, 8114, 8122>,
    <8124, 8122, 7396>,
    <8124, 7396, 7395>,
    <8124, 7395, 7287>,
    <8124, 7287, 8125>,
    <8124, 8125, 8116>,
    <8124, 8116, 8115>,
    <8126, 8127, 8128>,
    <8126, 8128, 8129>,
    <8126, 8129, 8024>,
    <8126, 8024, 8023>,
    <8126, 8023, 8022>,
    <8126, 8022, 8130>,
    <8126, 8130, 8131>,
    <8126, 8131, 8127>,
    <8132, 8133, 8128>,
    <8132, 8128, 8127>,
    <8132, 8127, 8131>,
    <8132, 8131, 8134>,
    <8132, 8134, 8118>,
    <8132, 8118, 8117>,
    <8132, 8117, 8116>,
    <8132, 8116, 8133>,
    <8135, 8129, 8128>,
    <8135, 8128, 8133>,
    <8135, 8133, 8116>,
    <8135, 8116, 8125>,
    <8135, 8125, 7287>,
    <8135, 7287, 8027>,
    <8135, 8027, 8024>,
    <8135, 8024, 8129>,
    <8136, 8137, 8138>,
    <8136, 8138, 8139>,
    <8136, 8139, 8140>,
    <8136, 8140, 8141>,
    <8136, 8141, 8142>,
    <8136, 8142, 8143>,
    <8136, 8144, 8145>,
    <8136, 8145, 8137>,
    <8146, 8147, 8138>,
    <8146, 8138, 8137>,
    <8146, 8137, 8148>,
    <8146, 8148, 8149>,
    <8146, 8150, 8151>,
    <8146, 8151, 7755>,
    <8146, 7755, 7753>,
    <8146, 7753, 8147>,
    <8152, 8139, 8138>,
    <8152, 8138, 8147>,
    <8152, 8147, 7753>,
    <8152, 7753, 7752>,
    <8152, 7752, 7751>,
    <8152, 7751, 8153>,
    <8152, 8153, 8140>,
    <8152, 8140, 8139>,
    <8154, 8155, 8156>,
    <8154, 8156, 8157>,
    <8154, 8157, 8158>,
    <8154, 8158, 8159>,
    <8154, 8159, 7221>,
    <8154, 7221, 8063>,
    <8154, 8063, 8061>,
    <8154, 8061, 8155>,
    <8160, 8161, 8156>,
    <8160, 8156, 8155>,
    <8160, 8155, 8061>,
    <8160, 8061, 8060>,
    <8160, 8060, 8052>,
    <8160, 8052, 8162>,
    <8160, 8162, 8163>,
    <8160, 8163, 8161>,
    <8164, 8157, 8156>,
    <8164, 8156, 8161>,
    <8164, 8161, 8163>,
    <8164, 8163, 8165>,
    <8164, 8165, 8166>,
    <8164, 8166, 8167>,
    <8164, 8167, 8158>,
    <8164, 8158, 8157>,
    <8168, 8169, 8170>,
    <8168, 8170, 8171>,
    <8168, 8171, 7314>,
    <8168, 7314, 7313>,
    <8168, 7313, 7221>,
    <8168, 7221, 8159>,
    <8168, 8159, 8158>,
    <8168, 8158, 8169>,
    <8172, 8173, 8170>,
    <8172, 8170, 8169>,
    <8172, 8169, 8158>,
    <8172, 8158, 8167>,
    <8172, 8167, 8166>,
    <8172, 8166, 8174>,
    <8172, 8174, 8175>,
    <8172, 8175, 8173>,
    <8176, 8171, 8170>,
    <8176, 8170, 8173>,
    <8176, 8173, 8175>,
    <8176, 8175, 8177>,
    <8176, 8177, 7317>,
    <8176, 7317, 7316>,
    <8176, 7316, 7314>,
    <8176, 7314, 8171>,
    <8178, 8179, 8180>,
    <8178, 8180, 8181>,
    <8178, 8181, 8182>,
    <8178, 8182, 8183>,
    <8178, 8183, 8184>,
    <8178, 8184, 8185>,
    <8178, 8185, 8186>,
    <8178, 8186, 8179>,
    <8187, 8188, 8180>,
    <8187, 8180, 8179>,
    <8187, 8179, 8186>,
    <8187, 8186, 8189>,
    <8187, 8189, 7335>,
    <8187, 7335, 7510>,
    <8187, 7510, 7509>,
    <8187, 7509, 8188>,
    <8190, 8181, 8180>,
    <8190, 8180, 8188>,
    <8190, 8188, 7509>,
    <8190, 7509, 7514>,
    <8190, 7514, 7497>,
    <8190, 7497, 8191>,
    <8190, 8191, 8182>,
    <8190, 8182, 8181>,
    <8192, 8193, 8194>,
    <8192, 8194, 8195>,
    <8192, 8195, 8196>,
    <8192, 8196, 8197>,
    <8192, 8197, 8070>,
    <8192, 8070, 8069>,
    <8192, 8069, 8068>,
    <8192, 8068, 8193>,
    <8198, 8199, 8194>,
    <8198, 8194, 8193>,
    <8198, 8193, 8068>,
    <8198, 8068, 8077>,
    <8198, 8077, 7335>,
    <8198, 7335, 8189>,
    <8198, 8189, 8186>,
    <8198, 8186, 8199>,
    <8200, 8195, 8194>,
    <8200, 8194, 8199>,
    <8200, 8199, 8186>,
    <8200, 8186, 8185>,
    <8200, 8185, 8184>,
    <8200, 8184, 8201>,
    <8200, 8201, 8196>,
    <8200, 8196, 8195>,
    <8202, 8203, 8204>,
    <8202, 8204, 8205>,
    <8202, 8205, 8109>,
    <8202, 8109, 8108>,
    <8202, 8108, 7266>,
    <8202, 7266, 8206>,
    <8202, 8206, 8207>,
    <8202, 8207, 8203>,
    <8208, 8209, 8204>,
    <8208, 8204, 8203>,
    <8208, 8203, 8207>,
    <8208, 8207, 8210>,
    <8208, 8210, 8211>,
    <8208, 8211, 8212>,
    <8208, 8212, 8213>,
    <8208, 8213, 8209>,
    <8214, 8205, 8204>,
    <8214, 8204, 8209>,
    <8214, 8209, 8213>,
    <8214, 8213, 8215>,
    <8214, 8215, 8097>,
    <8214, 8097, 8111>,
    <8214, 8111, 8109>,
    <8214, 8109, 8205>,
    <8216, 8217, 8218>,
    <8216, 8218, 8219>,
    <8216, 8219, 8207>,
    <8216, 8207, 8206>,
    <8216, 8206, 7266>,
    <8216, 7266, 7366>,
    <8216, 7366, 7364>,
    <8216, 7364, 8217>,
    <8220, 8221, 8218>,
    <8220, 8218, 8217>,
    <8220, 8217, 7364>,
    <8220, 7364, 7363>,
    <8220, 7363, 7362>,
    <8220, 7362, 8222>,
    <8220, 8222, 8223>,
    <8220, 8223, 8221>,
    <8224, 8219, 8218>,
    <8224, 8218, 8221>,
    <8224, 8221, 8223>,
    <8224, 8223, 8225>,
    <8224, 8225, 8211>,
    <8224, 8211, 8210>,
    <8224, 8210, 8207>,
    <8224, 8207, 8219>,
    <8226, 8227, 8228>,
    <8226, 8228, 8229>,
    <8226, 8229, 8230>,
    <8226, 8230, 8231>,
    <8226, 8231, 8232>,
    <8226, 8232, 8233>,
    <8226, 8233, 8234>,
    <8226, 8234, 8227>,
    <8235, 8236, 8228>,
    <8235, 8228, 8227>,
    <8235, 8227, 8234>,
    <8235, 8234, 8237>,
    <8235, 8237, 7449>,
    <8235, 7449, 7465>,
    <8235, 7465, 7462>,
    <8235, 7462, 8236>,
    <8238, 8229, 8228>,
    <8238, 8228, 8236>,
    <8238, 8236, 7462>,
    <8238, 7462, 7461>,
    <8238, 7461, 7383>,
    <8238, 7383, 8239>,
    <8238, 8239, 8230>,
    <8238, 8230, 8229>,
    <8240, 8241, 8242>,
    <8240, 8242, 8243>,
    <8240, 8243, 8120>,
    <8240, 8120, 8119>,
    <8240, 8119, 8118>,
    <8240, 8118, 8244>,
    <8240, 8244, 8245>,
    <8240, 8245, 8241>,
    <8246, 8247, 8242>,
    <8246, 8242, 8241>,
    <8246, 8241, 8245>,
    <8246, 8245, 8248>,
    <8246, 8248, 8232>,
    <8246, 8232, 8231>,
    <8246, 8231, 8230>,
    <8246, 8230, 8247>,
    <8249, 8243, 8242>,
    <8249, 8242, 8247>,
    <8249, 8247, 8230>,
    <8249, 8230, 8239>,
    <8249, 8239, 7383>,
    <8249, 7383, 8123>,
    <8249, 8123, 8120>,
    <8249, 8120, 8243>,
    <8250, 8251, 8252>,
    <8250, 8252, 8253>,
    <8250, 8253, 8254>,
    <8250, 8254, 8255>,
    <8250, 8256, 8257>,
    <8250, 8257, 8258>,
    <8250, 8258, 8259>,
    <8250, 8259, 8251>,
    <8260, 8261, 8252>,
    <8260, 8252, 8251>,
    <8260, 8251, 8259>,
    <8260, 8259, 8262>,
    <8260, 8262, 7799>,
    <8260, 7799, 7849>,
    <8260, 7849, 7847>,
    <8260, 7847, 8261>,
    <8263, 8253, 8252>,
    <8263, 8252, 8261>,
    <8263, 8261, 7847>,
    <8263, 7847, 7846>,
    <8263, 7846, 8264>,
    <8263, 8264, 8265>,
    <8263, 8266, 8267>,
    <8263, 8267, 8253>,
    <8268, 8269, 8270>,
    <8268, 8270, 8271>,
    <8268, 8271, 8223>,
    <8268, 8223, 8222>,
    <8268, 8222, 7362>,
    <8268, 7362, 8272>,
    <8268, 8272, 8273>,
    <8268, 8273, 8269>,
    <8274, 8275, 8270>,
    <8274, 8270, 8269>,
    <8274, 8269, 8273>,
    <8274, 8273, 8276>,
    <8274, 8276, 8277>,
    <8274, 8277, 8278>,
    <8274, 8278, 8279>,
    <8274, 8279, 8275>,
    <8280, 8271, 8270>,
    <8280, 8270, 8275>,
    <8280, 8275, 8279>,
    <8280, 8279, 8281>,
    <8280, 8281, 8211>,
    <8280, 8211, 8225>,
    <8280, 8225, 8223>,
    <8280, 8223, 8271>,
    <8282, 8283, 8284>,
    <8282, 8284, 8285>,
    <8282, 8285, 8273>,
    <8282, 8273, 8272>,
    <8282, 8272, 7362>,
    <8282, 7362, 7432>,
    <8282, 7432, 7430>,
    <8282, 7430, 8283>,
    <8286, 8287, 8284>,
    <8286, 8284, 8283>,
    <8286, 8283, 7430>,
    <8286, 7430, 7429>,
    <8286, 7429, 7428>,
    <8286, 7428, 8288>,
    <8286, 8288, 8289>,
    <8286, 8289, 8287>,
    <8290, 8285, 8284>,
    <8290, 8284, 8287>,
    <8290, 8287, 8289>,
    <8290, 8289, 8291>,
    <8290, 8291, 8277>,
    <8290, 8277, 8276>,
    <8290, 8276, 8273>,
    <8290, 8273, 8285>,
    <8292, 8293, 8294>,
    <8292, 8294, 8295>,
    <8292, 8295, 8296>,
    <8292, 8296, 8297>,
    <8292, 8297, 8298>,
    <8292, 8298, 8299>,
    <8292, 8299, 8300>,
    <8292, 8300, 8293>,
    <8301, 8302, 8294>,
    <8301, 8294, 8293>,
    <8301, 8293, 8300>,
    <8301, 8300, 8303>,
    <8301, 8303, 7545>,
    <8301, 7545, 7562>,
    <8301, 7562, 7559>,
    <8301, 7559, 8302>,
    <8304, 8295, 8294>,
    <8304, 8294, 8302>,
    <8304, 8302, 7559>,
    <8304, 7559, 7558>,
    <8304, 7558, 7449>,
    <8304, 7449, 8305>,
    <8304, 8305, 8296>,
    <8304, 8296, 8295>,
    <8306, 8307, 8308>,
    <8306, 8308, 8309>,
    <8306, 8309, 8234>,
    <8306, 8234, 8233>,
    <8306, 8233, 8232>,
    <8306, 8232, 8310>,
    <8306, 8310, 8311>,
    <8306, 8311, 8307>,
    <8312, 8313, 8308>,
    <8312, 8308, 8307>,
    <8312, 8307, 8311>,
    <8312, 8311, 8314>,
    <8312, 8314, 8298>,
    <8312, 8298, 8297>,
    <8312, 8297, 8296>,
    <8312, 8296, 8313>,
    <8315, 8309, 8308>,
    <8315, 8308, 8313>,
    <8315, 8313, 8296>,
    <8315, 8296, 8305>,
    <8315, 8305, 7449>,
    <8315, 7449, 8237>,
    <8315, 8237, 8234>,
    <8315, 8234, 8309>,
    <8316, 8317, 8318>,
    <8316, 8318, 8319>,
    <8316, 8319, 8320>,
    <8316, 8320, 8321>,
    <8316, 8321, 7317>,
    <8316, 7317, 8177>,
    <8316, 8177, 8175>,
    <8316, 8175, 8317>,
    <8322, 8323, 8318>,
    <8322, 8318, 8317>,
    <8322, 8317, 8175>,
    <8322, 8175, 8174>,
    <8322, 8174, 8166>,
    <8322, 8166, 8324>,
    <8322, 8324, 8325>,
    <8322, 8325, 8323>,
    <8326, 8319, 8318>,
    <8326, 8318, 8323>,
    <8326, 8323, 8325>,
    <8326, 8325, 8327>,
    <8326, 8327, 8328>,
    <8326, 8328, 8329>,
    <8326, 8329, 8320>,
    <8326, 8320, 8319>,
    <8330, 8331, 8332>,
    <8330, 8332, 8333>,
    <8330, 8333, 7476>,
    <8330, 7476, 7475>,
    <8330, 7475, 7317>,
    <8330, 7317, 8321>,
    <8330, 8321, 8320>,
    <8330, 8320, 8331>,
    <8334, 8335, 8332>,
    <8334, 8332, 8331>,
    <8334, 8331, 8320>,
    <8334, 8320, 8329>,
    <8334, 8329, 8328>,
    <8334, 8328, 8336>,
    <8334, 8336, 8337>,
    <8334, 8337, 8335>,
    <8338, 8333, 8332>,
    <8338, 8332, 8335>,
    <8338, 8335, 8337>,
    <8338, 8337, 8339>,
    <8338, 8339, 7479>,
    <8338, 7479, 7478>,
    <8338, 7478, 7476>,
    <8338, 7476, 8333>,
    <8340, 8341, 8342>,
    <8340, 8342, 8343>,
    <8340, 8343, 8344>,
    <8340, 8344, 8345>,
    <8340, 8345, 8346>,
    <8340, 8346, 8347>,
    <8340, 8347, 8348>,
    <8340, 8348, 8341>,
    <8349, 8350, 8342>,
    <8349, 8342, 8341>,
    <8349, 8341, 8348>,
    <8349, 8348, 8351>,
    <8349, 8351, 7497>,
    <8349, 7497, 7654>,
    <8349, 7654, 7653>,
    <8349, 7653, 8350>,
    <8352, 8343, 8342>,
    <8352, 8342, 8350>,
    <8352, 8350, 7653>,
    <8352, 7653, 7658>,
    <8352, 7658, 7641>,
    <8352, 7641, 8353>,
    <8352, 8353, 8344>,
    <8352, 8344, 8343>,
    <8354, 8355, 8356>,
    <8354, 8356, 8357>,
    <8354, 8357, 8358>,
    <8354, 8358, 8359>,
    <8354, 8359, 8184>,
    <8354, 8184, 8183>,
    <8354, 8183, 8182>,
    <8354, 8182, 8355>,
    <8360, 8361, 8356>,
    <8360, 8356, 8355>,
    <8360, 8355, 8182>,
    <8360, 8182, 8191>,
    <8360, 8191, 7497>,
    <8360, 7497, 8351>,
    <8360, 8351, 8348>,
    <8360, 8348, 8361>,
    <8362, 8357, 8356>,
    <8362, 8356, 8361>,
    <8362, 8361, 8348>,
    <8362, 8348, 8347>,
    <8362, 8347, 8346>,
    <8362, 8346, 8363>,
    <8362, 8363, 8358>,
    <8362, 8358, 8357>,
    <8364, 8365, 8366>,
    <8364, 8366, 8367>,
    <8364, 8367, 8289>,
    <8364, 8289, 8288>,
    <8364, 8288, 7428>,
    <8364, 7428, 8368>,
    <8364, 8368, 8369>,
    <8364, 8369, 8365>,
    <8370, 8371, 8366>,
    <8370, 8366, 8365>,
    <8370, 8365, 8369>,
    <8370, 8369, 8372>,
    <8370, 8372, 8373>,
    <8370, 8373, 8374>,
    <8370, 8374, 8375>,
    <8370, 8375, 8371>,
    <8376, 8367, 8366>,
    <8376, 8366, 8371>,
    <8376, 8371, 8375>,
    <8376, 8375, 8377>,
    <8376, 8377, 8277>,
    <8376, 8277, 8291>,
    <8376, 8291, 8289>,
    <8376, 8289, 8367>,
    <8378, 8379, 8380>,
    <8378, 8380, 8381>,
    <8378, 8381, 8369>,
    <8378, 8369, 8368>,
    <8378, 8368, 7428>,
    <8378, 7428, 7528>,
    <8378, 7528, 7526>,
    <8378, 7526, 8379>,
    <8382, 8383, 8380>,
    <8382, 8380, 8379>,
    <8382, 8379, 7526>,
    <8382, 7526, 7525>,
    <8382, 7525, 7524>,
    <8382, 7524, 8384>,
    <8382, 8384, 8385>,
    <8382, 8385, 8383>,
    <8386, 8381, 8380>,
    <8386, 8380, 8383>,
    <8386, 8383, 8385>,
    <8386, 8385, 8387>,
    <8386, 8387, 8373>,
    <8386, 8373, 8372>,
    <8386, 8372, 8369>,
    <8386, 8369, 8381>,
    <8388, 8389, 8390>,
    <8388, 8390, 8391>,
    <8388, 8391, 8392>,
    <8388, 8392, 8393>,
    <8388, 8393, 8394>,
    <8388, 8394, 8395>,
    <8388, 8395, 8396>,
    <8388, 8396, 8389>,
    <8397, 8398, 8390>,
    <8397, 8390, 8389>,
    <8397, 8389, 8396>,
    <8397, 8396, 8399>,
    <8397, 8399, 8400>,
    <8397, 8400, 7601>,
    <8397, 7601, 7598>,
    <8397, 7598, 8398>,
    <8401, 8391, 8390>,
    <8401, 8390, 8398>,
    <8401, 8398, 7598>,
    <8401, 7598, 7597>,
    <8401, 7597, 7545>,
    <8401, 7545, 8402>,
    <8401, 8402, 8392>,
    <8401, 8392, 8391>,
    <8403, 8404, 8405>,
    <8403, 8405, 8406>,
    <8403, 8406, 8300>,
    <8403, 8300, 8299>,
    <8403, 8299, 8298>,
    <8403, 8298, 8407>,
    <8403, 8407, 8408>,
    <8403, 8408, 8404>,
    <8409, 8410, 8405>,
    <8409, 8405, 8404>,
    <8409, 8404, 8408>,
    <8409, 8408, 8411>,
    <8409, 8411, 8394>,
    <8409, 8394, 8393>,
    <8409, 8393, 8392>,
    <8409, 8392, 8410>,
    <8412, 8406, 8405>,
    <8412, 8405, 8410>,
    <8412, 8410, 8392>,
    <8412, 8392, 8402>,
    <8412, 8402, 7545>,
    <8412, 7545, 8303>,
    <8412, 8303, 8300>,
    <8412, 8300, 8406>,
    <8413, 8414, 8415>,
    <8413, 8415, 8416>,
    <8413, 8416, 8385>,
    <8413, 8385, 8384>,
    <8413, 8384, 7524>,
    <8413, 7524, 8417>,
    <8413, 8417, 8418>,
    <8413, 8418, 8414>,
    <8419, 8420, 8415>,
    <8419, 8415, 8414>,
    <8419, 8414, 8418>,
    <8419, 8418, 8421>,
    <8419, 8421, 8422>,
    <8419, 8422, 8423>,
    <8419, 8423, 8424>,
    <8419, 8424, 8420>,
    <8425, 8416, 8415>,
    <8425, 8415, 8420>,
    <8425, 8420, 8424>,
    <8425, 8424, 8426>,
    <8425, 8426, 8373>,
    <8425, 8373, 8387>,
    <8425, 8387, 8385>,
    <8425, 8385, 8416>,
    <8427, 8428, 8429>,
    <8427, 8429, 8430>,
    <8427, 8430, 8418>,
    <8427, 8418, 8417>,
    <8427, 8417, 7524>,
    <8427, 7524, 7577>,
    <8427, 7577, 7575>,
    <8427, 7575, 8428>,
    <8431, 8432, 8429>,
    <8431, 8429, 8428>,
    <8431, 8428, 7575>,
    <8431, 7575, 7574>,
    <8431, 7574, 8433>,
    <8431, 8433, 8434>,
    <8431, 8435, 8436>,
    <8431, 8436, 8432>,
    <8437, 8430, 8429>,
    <8437, 8429, 8432>,
    <8437, 8432, 8438>,
    <8437, 8438, 8439>,
    <8437, 8440, 8441>,
    <8437, 8441, 8421>,
    <8437, 8421, 8418>,
    <8437, 8418, 8430>,
    <8442, 8443, 8444>,
    <8442, 8444, 8445>,
    <8442, 8445, 8396>,
    <8442, 8396, 8395>,
    <8442, 8395, 8394>,
    <8442, 8394, 8446>,
    <8442, 8446, 8447>,
    <8442, 8447, 8443>,
    <8448, 8449, 8444>,
    <8448, 8444, 8443>,
    <8448, 8443, 8447>,
    <8448, 8447, 8450>,
    <8448, 8450, 8451>,
    <8448, 8451, 8452>,
    <8448, 8453, 8454>,
    <8448, 8454, 8449>,
    <8455, 8445, 8444>,
    <8455, 8444, 8449>,
    <8455, 8449, 8456>,
    <8455, 8456, 8457>,
    <8455, 8458, 8459>,
    <8455, 8459, 8399>,
    <8455, 8399, 8396>,
    <8455, 8396, 8445>,
    <8460, 8461, 8462>,
    <8460, 8462, 8463>,
    <8460, 8463, 8464>,
    <8460, 8464, 8465>,
    <8460, 8465, 7479>,
    <8460, 7479, 8339>,
    <8460, 8339, 8337>,
    <8460, 8337, 8461>,
    <8466, 8467, 8462>,
    <8466, 8462, 8461>,
    <8466, 8461, 8337>,
    <8466, 8337, 8336>,
    <8466, 8336, 8328>,
    <8466, 8328, 8468>,
    <8466, 8468, 8469>,
    <8466, 8469, 8467>,
    <8470, 8463, 8462>,
    <8470, 8462, 8467>,
    <8470, 8467, 8469>,
    <8470, 8469, 8471>,
    <8470, 8471, 8472>,
    <8470, 8472, 8473>,
    <8470, 8473, 8464>,
    <8470, 8464, 8463>,
    <8474, 8475, 8476>,
    <8474, 8476, 8477>,
    <8474, 8477, 7620>,
    <8474, 7620, 7619>,
    <8474, 7619, 7479>,
    <8474, 7479, 8465>,
    <8474, 8465, 8464>,
    <8474, 8464, 8475>,
    <8478, 8479, 8476>,
    <8478, 8476, 8475>,
    <8478, 8475, 8464>,
    <8478, 8464, 8473>,
    <8478, 8473, 8472>,
    <8478, 8472, 8480>,
    <8478, 8480, 8481>,
    <8478, 8481, 8479>,
    <8482, 8477, 8476>,
    <8482, 8476, 8479>,
    <8482, 8479, 8481>,
    <8482, 8481, 8483>,
    <8482, 8483, 7623>,
    <8482, 7623, 7622>,
    <8482, 7622, 7620>,
    <8482, 7620, 8477>,
    <8484, 8485, 8486>,
    <8484, 8486, 8487>,
    <8484, 8487, 8488>,
    <8484, 8488, 8489>,
    <8484, 8489, 8490>,
    <8484, 8490, 8491>,
    <8484, 8491, 8492>,
    <8484, 8492, 8485>,
    <8493, 8494, 8486>,
    <8493, 8486, 8485>,
    <8493, 8485, 8492>,
    <8493, 8492, 8495>,
    <8493, 8495, 7641>,
    <8493, 7641, 7702>,
    <8493, 7702, 7701>,
    <8493, 7701, 8494>,
    <8496, 8487, 8486>,
    <8496, 8486, 8494>,
    <8496, 8494, 7701>,
    <8496, 7701, 7706>,
    <8496, 7706, 7689>,
    <8496, 7689, 8497>,
    <8496, 8497, 8488>,
    <8496, 8488, 8487>,
    <8498, 8499, 8500>,
    <8498, 8500, 8501>,
    <8498, 8501, 8502>,
    <8498, 8502, 8503>,
    <8498, 8503, 8346>,
    <8498, 8346, 8345>,
    <8498, 8345, 8344>,
    <8498, 8344, 8499>,
    <8504, 8505, 8500>,
    <8504, 8500, 8499>,
    <8504, 8499, 8344>,
    <8504, 8344, 8353>,
    <8504, 8353, 7641>,
    <8504, 7641, 8495>,
    <8504, 8495, 8492>,
    <8504, 8492, 8505>,
    <8506, 8501, 8500>,
    <8506, 8500, 8505>,
    <8506, 8505, 8492>,
    <8506, 8492, 8491>,
    <8506, 8491, 8490>,
    <8506, 8490, 8507>,
    <8506, 8507, 8502>,
    <8506, 8502, 8501>,
    <8508, 8509, 8510>,
    <8508, 8510, 8511>,
    <8508, 8511, 8512>,
    <8508, 8512, 8513>,
    <8508, 8513, 7623>,
    <8508, 7623, 8483>,
    <8508, 8483, 8481>,
    <8508, 8481, 8509>,
    <8514, 8515, 8510>,
    <8514, 8510, 8509>,
    <8514, 8509, 8481>,
    <8514, 8481, 8480>,
    <8514, 8480, 8472>,
    <8514, 8472, 8516>,
    <8514, 8516, 8517>,
    <8514, 8517, 8515>,
    <8518, 8511, 8510>,
    <8518, 8510, 8515>,
    <8518, 8515, 8517>,
    <8518, 8517, 8519>,
    <8518, 8519, 8520>,
    <8518, 8520, 8521>,
    <8518, 8521, 8512>,
    <8518, 8512, 8511>,
    <8522, 8523, 8524>,
    <8522, 8524, 8525>,
    <8522, 8525, 7668>,
    <8522, 7668, 7667>,
    <8522, 7667, 7623>,
    <8522, 7623, 8513>,
    <8522, 8513, 8512>,
    <8522, 8512, 8523>,
    <8526, 8527, 8524>,
    <8526, 8524, 8523>,
    <8526, 8523, 8512>,
    <8526, 8512, 8521>,
    <8526, 8521, 8520>,
    <8526, 8520, 8528>,
    <8526, 8528, 8529>,
    <8526, 8529, 8527>,
    <8530, 8525, 8524>,
    <8530, 8524, 8527>,
    <8530, 8527, 8529>,
    <8530, 8529, 8531>,
    <8530, 8531, 7671>,
    <8530, 7671, 7670>,
    <8530, 7670, 7668>,
    <8530, 7668, 8525>,
    <8532, 8533, 8534>,
    <8532, 8534, 8535>,
    <8532, 8535, 8536>,
    <8532, 8536, 8537>,
    <8532, 8537, 8538>,
    <8532, 8538, 8539>,
    <8532, 8539, 8540>,
    <8532, 8540, 8533>,
    <8541, 8542, 8534>,
    <8541, 8534, 8533>,
    <8541, 8533, 8540>,
    <8541, 8540, 8543>,
    <8541, 8543, 7689>,
    <8541, 7689, 7733>,
    <8541, 7733, 7732>,
    <8541, 7732, 8542>,
    <8544, 8535, 8534>,
    <8544, 8534, 8542>,
    <8544, 8542, 7732>,
    <8544, 7732, 7737>,
    <8544, 7737, 814>,
    <8544, 814, 8545>,
    <8544, 8545, 8536>,
    <8544, 8536, 8535>,
    <8546, 8547, 8548>,
    <8546, 8548, 8549>,
    <8546, 8549, 8550>,
    <8546, 8550, 8551>,
    <8546, 8551, 8490>,
    <8546, 8490, 8489>,
    <8546, 8489, 8488>,
    <8546, 8488, 8547>,
    <8552, 8553, 8548>,
    <8552, 8548, 8547>,
    <8552, 8547, 8488>,
    <8552, 8488, 8497>,
    <8552, 8497, 7689>,
    <8552, 7689, 8543>,
    <8552, 8543, 8540>,
    <8552, 8540, 8553>,
    <8554, 8549, 8548>,
    <8554, 8548, 8553>,
    <8554, 8553, 8540>,
    <8554, 8540, 8539>,
    <8554, 8539, 8538>,
    <8554, 8538, 8555>,
    <8554, 8555, 8550>,
    <8554, 8550, 8549>,
    <8556, 8557, 8558>,
    <8556, 8558, 8559>,
    <8556, 8559, 8560>,
    <8556, 8560, 8561>,
    <8556, 8561, 7671>,
    <8556, 7671, 8531>,
    <8556, 8531, 8529>,
    <8556, 8529, 8557>,
    <8562, 8563, 8558>,
    <8562, 8558, 8557>,
    <8562, 8557, 8529>,
    <8562, 8529, 8528>,
    <8562, 8528, 8520>,
    <8562, 8520, 8564>,
    <8562, 8564, 8565>,
    <8562, 8565, 8563>,
    <8566, 8559, 8558>,
    <8566, 8558, 8563>,
    <8566, 8563, 8565>,
    <8566, 8565, 8567>,
    <8566, 8567, 966>,
    <8566, 966, 8568>,
    <8566, 8568, 8560>,
    <8566, 8560, 8559>,
    <8569, 8570, 8571>,
    <8569, 8571, 8572>,
    <8569, 8572, 7716>,
    <8569, 7716, 7715>,
    <8569, 7715, 7671>,
    <8569, 7671, 8561>,
    <8569, 8561, 8560>,
    <8569, 8560, 8570>,
    <8573, 8574, 8571>,
    <8573, 8571, 8570>,
    <8573, 8570, 8560>,
    <8573, 8560, 8568>,
    <8573, 8568, 966>,
    <8573, 966, 1003>,
    <8573, 1003, 1001>,
    <8573, 1001, 8574>,
    <8575, 8572, 8571>,
    <8575, 8571, 8574>,
    <8575, 8574, 1001>,
    <8575, 1001, 1000>,
    <8575, 1000, 762>,
    <8575, 762, 7718>,
    <8575, 7718, 7716>,
    <8575, 7716, 8572>,
    <8576, 8577, 8578>,
    <8576, 8578, 8579>,
    <8576, 8579, 8580>,
    <8576, 8580, 8581>,
    <8576, 8581, 8538>,
    <8576, 8538, 8537>,
    <8576, 8537, 8536>,
    <8576, 8536, 8577>,
    <8582, 8583, 8578>,
    <8582, 8578, 8577>,
    <8582, 8577, 8536>,
    <8582, 8536, 8545>,
    <8582, 8545, 814>,
    <8582, 814, 1036>,
    <8582, 1036, 1034>,
    <8582, 1034, 8583>,
    <8584, 8579, 8578>,
    <8584, 8578, 8583>,
    <8584, 8583, 1034>,
    <8584, 1034, 1033>,
    <8584, 1033, 1017>,
    <8584, 1017, 8585>,
    <8584, 8585, 8580>,
    <8584, 8580, 8579>,
    <8586, 8587, 8588>,
    <8586, 8588, 8589>,
    <8586, 8589, 8590>,
    <8586, 8590, 8591>,
    <8586, 8591, 8592>,
    <8586, 8592, 8593>,
    <8586, 8594, 8595>,
    <8586, 8595, 8587>,
    <8596, 8597, 8588>,
    <8596, 8588, 8587>,
    <8596, 8587, 8598>,
    <8596, 8598, 8599>,
    <8596, 8600, 8601>,
    <8596, 8601, 7986>,
    <8596, 7986, 7985>,
    <8596, 7985, 8597>,
    <8602, 8589, 8588>,
    <8602, 8588, 8597>,
    <8602, 8597, 7985>,
    <8602, 7985, 7991>,
    <8602, 7991, 7973>,
    <8602, 7973, 8603>,
    <8602, 8603, 8590>,
    <8602, 8590, 8589>,
    <8604, 8605, 8606>,
    <8604, 8606, 8607>,
    <8604, 8607, 8608>,
    <8604, 8608, 8609>,
    <8604, 8610, 8611>,
    <8604, 8611, 8612>,
    <8604, 8612, 8613>,
    <8604, 8613, 8605>,
    <8614, 8615, 8606>,
    <8614, 8606, 8605>,
    <8614, 8605, 8613>,
    <8614, 8613, 8616>,
    <8614, 8616, 8617>,
    <8614, 8617, 8618>,
    <8614, 8618, 8619>,
    <8614, 8619, 8615>,
    <8620, 8607, 8606>,
    <8620, 8606, 8615>,
    <8620, 8615, 8619>,
    <8620, 8619, 8621>,
    <8620, 8621, 8622>,
    <8620, 8622, 8623>,
    <8620, 8624, 8625>,
    <8620, 8625, 8607>,
    <8626, 8627, 8628>,
    <8626, 8628, 8629>,
    <8626, 8629, 8613>,
    <8626, 8613, 8612>,
    <8626, 8612, 8630>,
    <8626, 8630, 8631>,
    <8626, 8632, 8633>,
    <8626, 8633, 8627>,
    <8634, 8635, 8628>,
    <8634, 8628, 8627>,
    <8634, 8627, 8636>,
    <8634, 8636, 8637>,
    <8634, 8638, 8639>,
    <8634, 8639, 8640>,
    <8634, 8640, 8641>,
    <8634, 8641, 8635>,
    <8642, 8629, 8628>,
    <8642, 8628, 8635>,
    <8642, 8635, 8641>,
    <8642, 8641, 8643>,
    <8642, 8643, 8617>,
    <8642, 8617, 8616>,
    <8642, 8616, 8613>,
    <8642, 8613, 8629>,
    <8644, 8645, 8646>,
    <8644, 8646, 8647>,
    <8644, 8647, 8641>,
    <8644, 8641, 8640>,
    <8644, 8640, 8648>,
    <8644, 8648, 8141>,
    <8644, 8141, 8140>,
    <8644, 8140, 8645>,
    <8649, 8650, 8646>,
    <8649, 8646, 8645>,
    <8649, 8645, 8140>,
    <8649, 8140, 8153>,
    <8649, 8153, 7751>,
    <8649, 7751, 8651>,
    <8649, 8651, 8652>,
    <8649, 8652, 8650>,
    <8653, 8647, 8646>,
    <8653, 8646, 8650>,
    <8653, 8650, 8652>,
    <8653, 8652, 8654>,
    <8653, 8654, 8617>,
    <8653, 8617, 8643>,
    <8653, 8643, 8641>,
    <8653, 8641, 8647>,
    <8655, 8656, 8657>,
    <8655, 8657, 8658>,
    <8655, 8658, 8259>,
    <8655, 8259, 8258>,
    <8655, 8258, 8659>,
    <8655, 8659, 8660>,
    <8655, 8660, 8661>,
    <8655, 8661, 8656>,
    <8662, 8663, 8657>,
    <8662, 8657, 8656>,
    <8662, 8656, 8661>,
    <8662, 8661, 8664>,
    <8662, 8664, 8665>,
    <8662, 8665, 8666>,
    <8662, 8666, 8667>,
    <8662, 8667, 8663>,
    <8668, 8658, 8657>,
    <8668, 8657, 8663>,
    <8668, 8663, 8667>,
    <8668, 8667, 8669>,
    <8668, 8669, 7799>,
    <8668, 7799, 8262>,
    <8668, 8262, 8259>,
    <8668, 8259, 8658>,
    <8670, 8671, 8672>,
    <8670, 8672, 8673>,
    <8670, 8673, 8667>,
    <8670, 8667, 8666>,
    <8670, 8666, 8665>,
    <8670, 8665, 8674>,
    <8670, 8674, 8675>,
    <8670, 8675, 8671>,
    <8676, 8677, 8672>,
    <8676, 8672, 8671>,
    <8676, 8671, 8675>,
    <8676, 8675, 8678>,
    <8676, 8678, 7898>,
    <8676, 7898, 7914>,
    <8676, 7914, 7911>,
    <8676, 7911, 8677>,
    <8679, 8673, 8672>,
    <8679, 8672, 8677>,
    <8679, 8677, 7911>,
    <8679, 7911, 7910>,
    <8679, 7910, 7799>,
    <8679, 7799, 8669>,
    <8679, 8669, 8667>,
    <8679, 8667, 8673>,
    <8680, 8681, 8682>,
    <8680, 8682, 8683>,
    <8680, 8683, 8661>,
    <8680, 8661, 8660>,
    <8680, 8660, 8684>,
    <8680, 8684, 8685>,
    <8680, 8686, 8687>,
    <8680, 8687, 8681>,
    <8688, 8689, 8682>,
    <8688, 8682, 8681>,
    <8688, 8681, 8690>,
    <8688, 8690, 8691>,
    <8688, 8692, 8693>,
    <8688, 8693, 8694>,
    <8688, 8694, 8695>,
    <8688, 8695, 8689>,
    <8696, 8683, 8682>,
    <8696, 8682, 8689>,
    <8696, 8689, 8695>,
    <8696, 8695, 8697>,
    <8696, 8697, 8665>,
    <8696, 8665, 8664>,
    <8696, 8664, 8661>,
    <8696, 8661, 8683>,
    <8698, 8699, 8700>,
    <8698, 8700, 8701>,
    <8698, 8701, 8702>,
    <8698, 8702, 8703>,
    <8698, 8703, 8704>,
    <8698, 8704, 8705>,
    <8698, 8706, 8707>,
    <8698, 8707, 8699>,
    <8708, 8709, 8700>,
    <8708, 8700, 8699>,
    <8708, 8699, 8710>,
    <8708, 8710, 8711>,
    <8708, 8712, 8713>,
    <8708, 8713, 8591>,
    <8708, 8591, 8590>,
    <8708, 8590, 8709>,
    <8714, 8701, 8700>,
    <8714, 8700, 8709>,
    <8714, 8709, 8590>,
    <8714, 8590, 8603>,
    <8714, 8603, 7973>,
    <8714, 7973, 8715>,
    <8714, 8715, 8702>,
    <8714, 8702, 8701>,
    <8716, 8717, 8718>,
    <8716, 8718, 8719>,
    <8716, 8719, 8652>,
    <8716, 8652, 8651>,
    <8716, 8651, 7751>,
    <8716, 7751, 8720>,
    <8716, 8720, 8721>,
    <8716, 8721, 8717>,
    <8722, 8723, 8718>,
    <8722, 8718, 8717>,
    <8722, 8717, 8721>,
    <8722, 8721, 8724>,
    <8722, 8724, 8725>,
    <8722, 8725, 8726>,
    <8722, 8726, 8727>,
    <8722, 8727, 8723>,
    <8728, 8719, 8718>,
    <8728, 8718, 8723>,
    <8728, 8723, 8727>,
    <8728, 8727, 8729>,
    <8728, 8729, 8617>,
    <8728, 8617, 8654>,
    <8728, 8654, 8652>,
    <8728, 8652, 8719>,
    <8730, 8731, 8732>,
    <8730, 8732, 8733>,
    <8730, 8733, 8721>,
    <8730, 8721, 8720>,
    <8730, 8720, 7751>,
    <8730, 7751, 7881>,
    <8730, 7881, 7879>,
    <8730, 7879, 8731>,
    <8734, 8735, 8732>,
    <8734, 8732, 8731>,
    <8734, 8731, 7879>,
    <8734, 7879, 7878>,
    <8734, 7878, 7877>,
    <8734, 7877, 8736>,
    <8734, 8736, 8737>,
    <8734, 8737, 8735>,
    <8738, 8733, 8732>,
    <8738, 8732, 8735>,
    <8738, 8735, 8737>,
    <8738, 8737, 8739>,
    <8738, 8739, 8725>,
    <8738, 8725, 8724>,
    <8738, 8724, 8721>,
    <8738, 8721, 8733>,
    <8740, 8741, 8742>,
    <8740, 8742, 8743>,
    <8740, 8743, 8744>,
    <8740, 8744, 8745>,
    <8740, 8745, 8746>,
    <8740, 8746, 8747>,
    <8740, 8747, 8748>,
    <8740, 8748, 8741>,
    <8749, 8750, 8742>,
    <8749, 8742, 8741>,
    <8749, 8741, 8748>,
    <8749, 8748, 8751>,
    <8749, 8751, 8022>,
    <8749, 8022, 8038>,
    <8749, 8038, 8035>,
    <8749, 8035, 8750>,
    <8752, 8743, 8742>,
    <8752, 8742, 8750>,
    <8752, 8750, 8035>,
    <8752, 8035, 8034>,
    <8752, 8034, 7898>,
    <8752, 7898, 8753>,
    <8752, 8753, 8744>,
    <8752, 8744, 8743>,
    <8754, 8755, 8756>,
    <8754, 8756, 8757>,
    <8754, 8757, 8675>,
    <8754, 8675, 8674>,
    <8754, 8674, 8665>,
    <8754, 8665, 8758>,
    <8754, 8758, 8759>,
    <8754, 8759, 8755>,
    <8760, 8761, 8756>,
    <8760, 8756, 8755>,
    <8760, 8755, 8759>,
    <8760, 8759, 8762>,
    <8760, 8762, 8746>,
    <8760, 8746, 8745>,
    <8760, 8745, 8744>,
    <8760, 8744, 8761>,
    <8763, 8757, 8756>,
    <8763, 8756, 8761>,
    <8763, 8761, 8744>,
    <8763, 8744, 8753>,
    <8763, 8753, 7898>,
    <8763, 7898, 8678>,
    <8763, 8678, 8675>,
    <8763, 8675, 8757>,
    <8764, 8765, 8766>,
    <8764, 8766, 8767>,
    <8764, 8767, 8768>,
    <8764, 8768, 8769>,
    <8764, 8769, 8770>,
    <8764, 8770, 8771>,
    <8764, 8772, 8773>,
    <8764, 8773, 8765>,
    <8774, 8775, 8766>,
    <8774, 8766, 8765>,
    <8774, 8765, 8776>,
    <8774, 8776, 8777>,
    <8774, 8778, 8779>,
    <8774, 8779, 8780>,
    <8774, 8780, 8781>,
    <8774, 8781, 8775>,
    <8782, 8767, 8766>,
    <8782, 8766, 8775>,
    <8782, 8775, 8781>,
    <8782, 8781, 8783>,
    <8782, 8783, 8784>,
    <8782, 8784, 8785>,
    <8782, 8785, 8768>,
    <8782, 8768, 8767>,
    <8786, 8787, 8788>,
    <8786, 8788, 8789>,
    <8786, 8789, 8790>,
    <8786, 8790, 8791>,
    <8786, 8791, 8792>,
    <8786, 8792, 8793>,
    <8786, 8794, 8795>,
    <8786, 8795, 8787>,
    <8796, 8797, 8788>,
    <8796, 8788, 8787>,
    <8796, 8787, 8798>,
    <8796, 8798, 8799>,
    <8796, 8800, 8801>,
    <8796, 8801, 8769>,
    <8796, 8769, 8768>,
    <8796, 8768, 8797>,
    <8802, 8789, 8788>,
    <8802, 8788, 8797>,
    <8802, 8797, 8768>,
    <8802, 8768, 8785>,
    <8802, 8785, 8784>,
    <8802, 8784, 8803>,
    <8802, 8803, 8790>,
    <8802, 8790, 8789>,
    <8804, 8805, 8806>,
    <8804, 8806, 8807>,
    <8804, 8807, 7933>,
    <8804, 7933, 7932>,
    <8804, 7932, 8808>,
    <8804, 8808, 8791>,
    <8804, 8791, 8790>,
    <8804, 8790, 8805>,
    <8809, 8810, 8806>,
    <8809, 8806, 8805>,
    <8809, 8805, 8790>,
    <8809, 8790, 8803>,
    <8809, 8803, 8784>,
    <8809, 8784, 8811>,
    <8809, 8811, 8812>,
    <8809, 8812, 8810>,
    <8813, 8807, 8806>,
    <8813, 8806, 8810>,
    <8813, 8810, 8812>,
    <8813, 8812, 8814>,
    <8813, 8814, 7936>,
    <8813, 7936, 7935>,
    <8813, 7935, 7933>,
    <8813, 7933, 8807>,
    <8815, 8816, 8817>,
    <8815, 8817, 8818>,
    <8815, 8818, 8819>,
    <8815, 8819, 8820>,
    <8815, 8820, 8821>,
    <8815, 8821, 8822>,
    <8815, 8822, 8823>,
    <8815, 8823, 8816>,
    <8824, 8825, 8817>,
    <8824, 8817, 8816>,
    <8824, 8816, 8823>,
    <8824, 8823, 8826>,
    <8824, 8826, 7973>,
    <8824, 7973, 8083>,
    <8824, 8083, 8082>,
    <8824, 8082, 8825>,
    <8827, 8818, 8817>,
    <8827, 8817, 8825>,
    <8827, 8825, 8082>,
    <8827, 8082, 8087>,
    <8827, 8087, 8070>,
    <8827, 8070, 8828>,
    <8827, 8828, 8819>,
    <8827, 8819, 8818>,
    <8829, 8830, 8831>,
    <8829, 8831, 8832>,
    <8829, 8832, 8833>,
    <8829, 8833, 8834>,
    <8829, 8834, 8835>,
    <8829, 8835, 8703>,
    <8829, 8703, 8702>,
    <8829, 8702, 8830>,
    <8836, 8837, 8831>,
    <8836, 8831, 8830>,
    <8836, 8830, 8702>,
    <8836, 8702, 8715>,
    <8836, 8715, 7973>,
    <8836, 7973, 8826>,
    <8836, 8826, 8823>,
    <8836, 8823, 8837>,
    <8838, 8832, 8831>,
    <8838, 8831, 8837>,
    <8838, 8837, 8823>,
    <8838, 8823, 8822>,
    <8838, 8822, 8821>,
    <8838, 8821, 8839>,
    <8838, 8839, 8833>,
    <8838, 8833, 8832>,
    <8840, 8841, 8842>,
    <8840, 8842, 8843>,
    <8840, 8843, 8737>,
    <8840, 8737, 8736>,
    <8840, 8736, 7877>,
    <8840, 7877, 8844>,
    <8840, 8844, 8845>,
    <8840, 8845, 8841>,
    <8846, 8847, 8842>,
    <8846, 8842, 8841>,
    <8846, 8841, 8845>,
    <8846, 8845, 8848>,
    <8846, 8848, 8849>,
    <8846, 8849, 8850>,
    <8846, 8850, 8851>,
    <8846, 8851, 8847>,
    <8852, 8843, 8842>,
    <8852, 8842, 8847>,
    <8852, 8847, 8851>,
    <8852, 8851, 8853>,
    <8852, 8853, 8725>,
    <8852, 8725, 8739>,
    <8852, 8739, 8737>,
    <8852, 8737, 8843>,
    <8854, 8855, 8856>,
    <8854, 8856, 8857>,
    <8854, 8857, 8845>,
    <8854, 8845, 8844>,
    <8854, 8844, 7877>,
    <8854, 7877, 8005>,
    <8854, 8005, 8003>,
    <8854, 8003, 8855>,
    <8858, 8859, 8856>,
    <8858, 8856, 8855>,
    <8858, 8855, 8003>,
    <8858, 8003, 8002>,
    <8858, 8002, 8001>,
    <8858, 8001, 8860>,
    <8858, 8860, 8861>,
    <8858, 8861, 8859>,
    <8862, 8857, 8856>,
    <8862, 8856, 8859>,
    <8862, 8859, 8861>,
    <8862, 8861, 8863>,
    <8862, 8863, 8849>,
    <8862, 8849, 8848>,
    <8862, 8848, 8845>,
    <8862, 8845, 8857>,
    <8864, 8865, 8866>,
    <8864, 8866, 8867>,
    <8864, 8867, 8868>,
    <8864, 8868, 8869>,
    <8864, 8869, 8870>,
    <8864, 8870, 8871>,
    <8864, 8871, 8872>,
    <8864, 8872, 8865>,
    <8873, 8874, 8866>,
    <8873, 8866, 8865>,
    <8873, 8865, 8872>,
    <8873, 8872, 8875>,
    <8873, 8875, 8118>,
    <8873, 8118, 8134>,
    <8873, 8134, 8131>,
    <8873, 8131, 8874>,
    <8876, 8867, 8866>,
    <8876, 8866, 8874>,
    <8876, 8874, 8131>,
    <8876, 8131, 8130>,
    <8876, 8130, 8022>,
    <8876, 8022, 8877>,
    <8876, 8877, 8868>,
    <8876, 8868, 8867>,
    <8878, 8879, 8880>,
    <8878, 8880, 8881>,
    <8878, 8881, 8748>,
    <8878, 8748, 8747>,
    <8878, 8747, 8746>,
    <8878, 8746, 8882>,
    <8878, 8882, 8883>,
    <8878, 8883, 8879>,
    <8884, 8885, 8880>,
    <8884, 8880, 8879>,
    <8884, 8879, 8883>,
    <8884, 8883, 8886>,
    <8884, 8886, 8870>,
    <8884, 8870, 8869>,
    <8884, 8869, 8868>,
    <8884, 8868, 8885>,
    <8887, 8881, 8880>,
    <8887, 8880, 8885>,
    <8887, 8885, 8868>,
    <8887, 8868, 8877>,
    <8887, 8877, 8022>,
    <8887, 8022, 8751>,
    <8887, 8751, 8748>,
    <8887, 8748, 8881>,
    <8888, 8889, 8890>,
    <8888, 8890, 8891>,
    <8888, 8891, 8892>,
    <8888, 8892, 8893>,
    <8888, 8893, 7936>,
    <8888, 7936, 8814>,
    <8888, 8814, 8812>,
    <8888, 8812, 8889>,
    <8894, 8895, 8890>,
    <8894, 8890, 8889>,
    <8894, 8889, 8812>,
    <8894, 8812, 8811>,
    <8894, 8811, 8784>,
    <8894, 8784, 8896>,
    <8894, 8896, 8897>,
    <8894, 8897, 8895>,
    <8898, 8891, 8890>,
    <8898, 8890, 8895>,
    <8898, 8895, 8897>,
    <8898, 8897, 8899>,
    <8898, 8899, 8900>,
    <8898, 8900, 8901>,
    <8898, 8901, 8892>,
    <8898, 8892, 8891>,
    <8902, 8903, 8904>,
    <8902, 8904, 8905>,
    <8902, 8905, 8049>,
    <8902, 8049, 8048>,
    <8902, 8048, 7936>,
    <8902, 7936, 8893>,
    <8902, 8893, 8892>,
    <8902, 8892, 8903>,
    <8906, 8907, 8904>,
    <8906, 8904, 8903>,
    <8906, 8903, 8892>,
    <8906, 8892, 8901>,
    <8906, 8901, 8900>,
    <8906, 8900, 8908>,
    <8906, 8908, 8909>,
    <8906, 8909, 8907>,
    <8910, 8905, 8904>,
    <8910, 8904, 8907>,
    <8910, 8907, 8909>,
    <8910, 8909, 8911>,
    <8910, 8911, 8052>,
    <8910, 8052, 8051>,
    <8910, 8051, 8049>,
    <8910, 8049, 8905>,
    <8912, 8913, 8914>,
    <8912, 8914, 8915>,
    <8912, 8915, 8916>,
    <8912, 8916, 8917>,
    <8912, 8917, 8918>,
    <8912, 8918, 8919>,
    <8912, 8919, 8920>,
    <8912, 8920, 8913>,
    <8921, 8922, 8914>,
    <8921, 8914, 8913>,
    <8921, 8913, 8920>,
    <8921, 8920, 8923>,
    <8921, 8923, 8070>,
    <8921, 8070, 8197>,
    <8921, 8197, 8196>,
    <8921, 8196, 8922>,
    <8924, 8915, 8914>,
    <8924, 8914, 8922>,
    <8924, 8922, 8196>,
    <8924, 8196, 8201>,
    <8924, 8201, 8184>,
    <8924, 8184, 8925>,
    <8924, 8925, 8916>,
    <8924, 8916, 8915>,
    <8926, 8927, 8928>,
    <8926, 8928, 8929>,
    <8926, 8929, 8930>,
    <8926, 8930, 8931>,
    <8926, 8931, 8821>,
    <8926, 8821, 8820>,
    <8926, 8820, 8819>,
    <8926, 8819, 8927>,
    <8932, 8933, 8928>,
    <8932, 8928, 8927>,
    <8932, 8927, 8819>,
    <8932, 8819, 8828>,
    <8932, 8828, 8070>,
    <8932, 8070, 8923>,
    <8932, 8923, 8920>,
    <8932, 8920, 8933>,
    <8934, 8929, 8928>,
    <8934, 8928, 8933>,
    <8934, 8933, 8920>,
    <8934, 8920, 8919>,
    <8934, 8919, 8918>,
    <8934, 8918, 8935>,
    <8934, 8935, 8930>,
    <8934, 8930, 8929>,
    <8936, 8937, 8938>,
    <8936, 8938, 8939>,
    <8936, 8939, 8861>,
    <8936, 8861, 8860>,
    <8936, 8860, 8001>,
    <8936, 8001, 8940>,
    <8936, 8940, 8941>,
    <8936, 8941, 8937>,
    <8942, 8943, 8938>,
    <8942, 8938, 8937>,
    <8942, 8937, 8941>,
    <8942, 8941, 8944>,
    <8942, 8944, 8945>,
    <8942, 8945, 8946>,
    <8942, 8946, 8947>,
    <8942, 8947, 8943>,
    <8948, 8939, 8938>,
    <8948, 8938, 8943>,
    <8948, 8943, 8947>,
    <8948, 8947, 8949>,
    <8948, 8949, 8849>,
    <8948, 8849, 8863>,
    <8948, 8863, 8861>,
    <8948, 8861, 8939>,
    <8950, 8951, 8952>,
    <8950, 8952, 8953>,
    <8950, 8953, 8941>,
    <8950, 8941, 8940>,
    <8950, 8940, 8001>,
    <8950, 8001, 8101>,
    <8950, 8101, 8099>,
    <8950, 8099, 8951>,
    <8954, 8955, 8952>,
    <8954, 8952, 8951>,
    <8954, 8951, 8099>,
    <8954, 8099, 8098>,
    <8954, 8098, 8097>,
    <8954, 8097, 8956>,
    <8954, 8956, 8957>,
    <8954, 8957, 8955>,
    <8958, 8953, 8952>,
    <8958, 8952, 8955>,
    <8958, 8955, 8957>,
    <8958, 8957, 8959>,
    <8958, 8959, 8945>,
    <8958, 8945, 8944>,
    <8958, 8944, 8941>,
    <8958, 8941, 8953>,
    <8960, 8961, 8962>,
    <8960, 8962, 8963>,
    <8960, 8963, 8964>,
    <8960, 8964, 8965>,
    <8960, 8965, 8966>,
    <8960, 8966, 8967>,
    <8960, 8967, 8968>,
    <8960, 8968, 8961>,
    <8969, 8970, 8962>,
    <8969, 8962, 8961>,
    <8969, 8961, 8968>,
    <8969, 8968, 8971>,
    <8969, 8971, 8232>,
    <8969, 8232, 8248>,
    <8969, 8248, 8245>,
    <8969, 8245, 8970>,
    <8972, 8963, 8962>,
    <8972, 8962, 8970>,
    <8972, 8970, 8245>,
    <8972, 8245, 8244>,
    <8972, 8244, 8118>,
    <8972, 8118, 8973>,
    <8972, 8973, 8964>,
    <8972, 8964, 8963>,
    <8974, 8975, 8976>,
    <8974, 8976, 8977>,
    <8974, 8977, 8872>,
    <8974, 8872, 8871>,
    <8974, 8871, 8870>,
    <8974, 8870, 8978>,
    <8974, 8978, 8979>,
    <8974, 8979, 8975>,
    <8980, 8981, 8976>,
    <8980, 8976, 8975>,
    <8980, 8975, 8979>,
    <8980, 8979, 8982>,
    <8980, 8982, 8966>,
    <8980, 8966, 8965>,
    <8980, 8965, 8964>,
    <8980, 8964, 8981>,
    <8983, 8977, 8976>,
    <8983, 8976, 8981>,
    <8983, 8981, 8964>,
    <8983, 8964, 8973>,
    <8983, 8973, 8118>,
    <8983, 8118, 8875>,
    <8983, 8875, 8872>,
    <8983, 8872, 8977>,
    <8984, 8985, 8986>,
    <8984, 8986, 8987>,
    <8984, 8987, 8988>,
    <8984, 8988, 8989>,
    <8984, 8989, 8052>,
    <8984, 8052, 8911>,
    <8984, 8911, 8909>,
    <8984, 8909, 8985>,
    <8990, 8991, 8986>,
    <8990, 8986, 8985>,
    <8990, 8985, 8909>,
    <8990, 8909, 8908>,
    <8990, 8908, 8900>,
    <8990, 8900, 8992>,
    <8990, 8992, 8993>,
    <8990, 8993, 8991>,
    <8994, 8987, 8986>,
    <8994, 8986, 8991>,
    <8994, 8991, 8993>,
    <8994, 8993, 8995>,
    <8994, 8995, 8996>,
    <8994, 8996, 8997>,
    <8994, 8997, 8988>,
    <8994, 8988, 8987>,
    <8998, 8999, 9000>,
    <8998, 9000, 9001>,
    <8998, 9001, 8163>,
    <8998, 8163, 8162>,
    <8998, 8162, 8052>,
    <8998, 8052, 8989>,
    <8998, 8989, 8988>,
    <8998, 8988, 8999>,
    <9002, 9003, 9000>,
    <9002, 9000, 8999>,
    <9002, 8999, 8988>,
    <9002, 8988, 8997>,
    <9002, 8997, 8996>,
    <9002, 8996, 9004>,
    <9002, 9004, 9005>,
    <9002, 9005, 9003>,
    <9006, 9001, 9000>,
    <9006, 9000, 9003>,
    <9006, 9003, 9005>,
    <9006, 9005, 9007>,
    <9006, 9007, 8166>,
    <9006, 8166, 8165>,
    <9006, 8165, 8163>,
    <9006, 8163, 9001>,
    <9008, 9009, 9010>,
    <9008, 9010, 9011>,
    <9008, 9011, 9012>,
    <9008, 9012, 9013>,
    <9008, 9013, 9014>,
    <9008, 9014, 9015>,
    <9008, 9015, 9016>,
    <9008, 9016, 9009>,
    <9017, 9018, 9010>,
    <9017, 9010, 9009>,
    <9017, 9009, 9016>,
    <9017, 9016, 9019>,
    <9017, 9019, 8184>,
    <9017, 8184, 8359>,
    <9017, 8359, 8358>,
    <9017, 8358, 9018>,
    <9020, 9011, 9010>,
    <9020, 9010, 9018>,
    <9020, 9018, 8358>,
    <9020, 8358, 8363>,
    <9020, 8363, 8346>,
    <9020, 8346, 9021>,
    <9020, 9021, 9012>,
    <9020, 9012, 9011>,
    <9022, 9023, 9024>,
    <9022, 9024, 9025>,
    <9022, 9025, 9026>,
    <9022, 9026, 9027>,
    <9022, 9027, 8918>,
    <9022, 8918, 8917>,
    <9022, 8917, 8916>,
    <9022, 8916, 9023>,
    <9028, 9029, 9024>,
    <9028, 9024, 9023>,
    <9028, 9023, 8916>,
    <9028, 8916, 8925>,
    <9028, 8925, 8184>,
    <9028, 8184, 9019>,
    <9028, 9019, 9016>,
    <9028, 9016, 9029>,
    <9030, 9025, 9024>,
    <9030, 9024, 9029>,
    <9030, 9029, 9016>,
    <9030, 9016, 9015>,
    <9030, 9015, 9014>,
    <9030, 9014, 9031>,
    <9030, 9031, 9026>,
    <9030, 9026, 9025>,
    <9032, 9033, 9034>,
    <9032, 9034, 9035>,
    <9032, 9035, 8957>,
    <9032, 8957, 8956>,
    <9032, 8956, 8097>,
    <9032, 8097, 9036>,
    <9032, 9036, 9037>,
    <9032, 9037, 9033>,
    <9038, 9039, 9034>,
    <9038, 9034, 9033>,
    <9038, 9033, 9037>,
    <9038, 9037, 9040>,
    <9038, 9040, 9041>,
    <9038, 9041, 9042>,
    <9038, 9042, 9043>,
    <9038, 9043, 9039>,
    <9044, 9035, 9034>,
    <9044, 9034, 9039>,
    <9044, 9039, 9043>,
    <9044, 9043, 9045>,
    <9044, 9045, 8945>,
    <9044, 8945, 8959>,
    <9044, 8959, 8957>,
    <9044, 8957, 9035>,
    <9046, 9047, 9048>,
    <9046, 9048, 9049>,
    <9046, 9049, 9037>,
    <9046, 9037, 9036>,
    <9046, 9036, 8097>,
    <9046, 8097, 8215>,
    <9046, 8215, 8213>,
    <9046, 8213, 9047>,
    <9050, 9051, 9048>,
    <9050, 9048, 9047>,
    <9050, 9047, 8213>,
    <9050, 8213, 8212>,
    <9050, 8212, 8211>,
    <9050, 8211, 9052>,
    <9050, 9052, 9053>,
    <9050, 9053, 9051>,
    <9054, 9049, 9048>,
    <9054, 9048, 9051>,
    <9054, 9051, 9053>,
    <9054, 9053, 9055>,
    <9054, 9055, 9041>,
    <9054, 9041, 9040>,
    <9054, 9040, 9037>,
    <9054, 9037, 9049>,
    <9056, 9057, 9058>,
    <9056, 9058, 9059>,
    <9056, 9059, 9060>,
    <9056, 9060, 9061>,
    <9056, 9061, 9062>,
    <9056, 9062, 9063>,
    <9056, 9063, 9064>,
    <9056, 9064, 9057>,
    <9065, 9066, 9058>,
    <9065, 9058, 9057>,
    <9065, 9057, 9064>,
    <9065, 9064, 9067>,
    <9065, 9067, 8298>,
    <9065, 8298, 8314>,
    <9065, 8314, 8311>,
    <9065, 8311, 9066>,
    <9068, 9059, 9058>,
    <9068, 9058, 9066>,
    <9068, 9066, 8311>,
    <9068, 8311, 8310>,
    <9068, 8310, 8232>,
    <9068, 8232, 9069>,
    <9068, 9069, 9060>,
    <9068, 9060, 9059>,
    <9070, 9071, 9072>,
    <9070, 9072, 9073>,
    <9070, 9073, 8968>,
    <9070, 8968, 8967>,
    <9070, 8967, 8966>,
    <9070, 8966, 9074>,
    <9070, 9074, 9075>,
    <9070, 9075, 9071>,
    <9076, 9077, 9072>,
    <9076, 9072, 9071>,
    <9076, 9071, 9075>,
    <9076, 9075, 9078>,
    <9076, 9078, 9062>,
    <9076, 9062, 9061>,
    <9076, 9061, 9060>,
    <9076, 9060, 9077>,
    <9079, 9073, 9072>,
    <9079, 9072, 9077>,
    <9079, 9077, 9060>,
    <9079, 9060, 9069>,
    <9079, 9069, 8232>,
    <9079, 8232, 8971>,
    <9079, 8971, 8968>,
    <9079, 8968, 9073>,
    <9080, 9081, 9082>,
    <9080, 9082, 9083>,
    <9080, 9083, 9053>,
    <9080, 9053, 9052>,
    <9080, 9052, 8211>,
    <9080, 8211, 9084>,
    <9080, 9084, 9085>,
    <9080, 9085, 9081>,
    <9086, 9087, 9082>,
    <9086, 9082, 9081>,
    <9086, 9081, 9085>,
    <9086, 9085, 9088>,
    <9086, 9088, 9089>,
    <9086, 9089, 9090>,
    <9086, 9090, 9091>,
    <9086, 9091, 9087>,
    <9092, 9083, 9082>,
    <9092, 9082, 9087>,
    <9092, 9087, 9091>,
    <9092, 9091, 9093>,
    <9092, 9093, 9041>,
    <9092, 9041, 9055>,
    <9092, 9055, 9053>,
    <9092, 9053, 9083>,
    <9094, 9095, 9096>,
    <9094, 9096, 9097>,
    <9094, 9097, 9085>,
    <9094, 9085, 9084>,
    <9094, 9084, 8211>,
    <9094, 8211, 8281>,
    <9094, 8281, 8279>,
    <9094, 8279, 9095>,
    <9098, 9099, 9096>,
    <9098, 9096, 9095>,
    <9098, 9095, 8279>,
    <9098, 8279, 8278>,
    <9098, 8278, 8277>,
    <9098, 8277, 9100>,
    <9098, 9100, 9101>,
    <9098, 9101, 9099>,
    <9102, 9097, 9096>,
    <9102, 9096, 9099>,
    <9102, 9099, 9101>,
    <9102, 9101, 9103>,
    <9102, 9103, 9089>,
    <9102, 9089, 9088>,
    <9102, 9088, 9085>,
    <9102, 9085, 9097>,
    <9104, 9105, 9106>,
    <9104, 9106, 9107>,
    <9104, 9107, 9108>,
    <9104, 9108, 9109>,
    <9104, 9109, 9110>,
    <9104, 9110, 9111>,
    <9104, 9111, 9112>,
    <9104, 9112, 9105>,
    <9113, 9114, 9106>,
    <9113, 9106, 9105>,
    <9113, 9105, 9112>,
    <9113, 9112, 9115>,
    <9113, 9115, 8394>,
    <9113, 8394, 8411>,
    <9113, 8411, 8408>,
    <9113, 8408, 9114>,
    <9116, 9107, 9106>,
    <9116, 9106, 9114>,
    <9116, 9114, 8408>,
    <9116, 8408, 8407>,
    <9116, 8407, 8298>,
    <9116, 8298, 9117>,
    <9116, 9117, 9108>,
    <9116, 9108, 9107>,
    <9118, 9119, 9120>,
    <9118, 9120, 9121>,
    <9118, 9121, 9064>,
    <9118, 9064, 9063>,
    <9118, 9063, 9062>,
    <9118, 9062, 9122>,
    <9118, 9122, 9123>,
    <9118, 9123, 9119>,
    <9124, 9125, 9120>,
    <9124, 9120, 9119>,
    <9124, 9119, 9123>,
    <9124, 9123, 9126>,
    <9124, 9126, 9110>,
    <9124, 9110, 9109>,
    <9124, 9109, 9108>,
    <9124, 9108, 9125>,
    <9127, 9121, 9120>,
    <9127, 9120, 9125>,
    <9127, 9125, 9108>,
    <9127, 9108, 9117>,
    <9127, 9117, 8298>,
    <9127, 8298, 9067>,
    <9127, 9067, 9064>,
    <9127, 9064, 9121>,
    <9128, 9129, 9130>,
    <9128, 9130, 9131>,
    <9128, 9131, 9132>,
    <9128, 9132, 9133>,
    <9128, 9133, 8166>,
    <9128, 8166, 9007>,
    <9128, 9007, 9005>,
    <9128, 9005, 9129>,
    <9134, 9135, 9130>,
    <9134, 9130, 9129>,
    <9134, 9129, 9005>,
    <9134, 9005, 9004>,
    <9134, 9004, 8996>,
    <9134, 8996, 9136>,
    <9134, 9136, 9137>,
    <9134, 9137, 9135>,
    <9138, 9131, 9130>,
    <9138, 9130, 9135>,
    <9138, 9135, 9137>,
    <9138, 9137, 9139>,
    <9138, 9139, 9140>,
    <9138, 9140, 9141>,
    <9138, 9141, 9132>,
    <9138, 9132, 9131>,
    <9142, 9143, 9144>,
    <9142, 9144, 9145>,
    <9142, 9145, 8325>,
    <9142, 8325, 8324>,
    <9142, 8324, 8166>,
    <9142, 8166, 9133>,
    <9142, 9133, 9132>,
    <9142, 9132, 9143>,
    <9146, 9147, 9144>,
    <9146, 9144, 9143>,
    <9146, 9143, 9132>,
    <9146, 9132, 9141>,
    <9146, 9141, 9140>,
    <9146, 9140, 9148>,
    <9146, 9148, 9149>,
    <9146, 9149, 9147>,
    <9150, 9145, 9144>,
    <9150, 9144, 9147>,
    <9150, 9147, 9149>,
    <9150, 9149, 9151>,
    <9150, 9151, 8328>,
    <9150, 8328, 8327>,
    <9150, 8327, 8325>,
    <9150, 8325, 9145>,
    <9152, 9153, 9154>,
    <9152, 9154, 9155>,
    <9152, 9155, 9156>,
    <9152, 9156, 9157>,
    <9152, 9157, 9158>,
    <9152, 9158, 9159>,
    <9152, 9159, 9160>,
    <9152, 9160, 9153>,
    <9161, 9162, 9154>,
    <9161, 9154, 9153>,
    <9161, 9153, 9160>,
    <9161, 9160, 9163>,
    <9161, 9163, 8346>,
    <9161, 8346, 8503>,
    <9161, 8503, 8502>,
    <9161, 8502, 9162>,
    <9164, 9155, 9154>,
    <9164, 9154, 9162>,
    <9164, 9162, 8502>,
    <9164, 8502, 8507>,
    <9164, 8507, 8490>,
    <9164, 8490, 9165>,
    <9164, 9165, 9156>,
    <9164, 9156, 9155>,
    <9166, 9167, 9168>,
    <9166, 9168, 9169>,
    <9166, 9169, 9170>,
    <9166, 9170, 9171>,
    <9166, 9171, 9014>,
    <9166, 9014, 9013>,
    <9166, 9013, 9012>,
    <9166, 9012, 9167>,
    <9172, 9173, 9168>,
    <9172, 9168, 9167>,
    <9172, 9167, 9012>,
    <9172, 9012, 9021>,
    <9172, 9021, 8346>,
    <9172, 8346, 9163>,
    <9172, 9163, 9160>,
    <9172, 9160, 9173>,
    <9174, 9169, 9168>,
    <9174, 9168, 9173>,
    <9174, 9173, 9160>,
    <9174, 9160, 9159>,
    <9174, 9159, 9158>,
    <9174, 9158, 9175>,
    <9174, 9175, 9170>,
    <9174, 9170, 9169>,
    <9176, 9177, 9178>,
    <9176, 9178, 9179>,
    <9176, 9179, 9101>,
    <9176, 9101, 9100>,
    <9176, 9100, 8277>,
    <9176, 8277, 9180>,
    <9176, 9180, 9181>,
    <9176, 9181, 9177>,
    <9182, 9183, 9178>,
    <9182, 9178, 9177>,
    <9182, 9177, 9181>,
    <9182, 9181, 9184>,
    <9182, 9184, 9185>,
    <9182, 9185, 9186>,
    <9182, 9186, 9187>,
    <9182, 9187, 9183>,
    <9188, 9179, 9178>,
    <9188, 9178, 9183>,
    <9188, 9183, 9187>,
    <9188, 9187, 9189>,
    <9188, 9189, 9089>,
    <9188, 9089, 9103>,
    <9188, 9103, 9101>,
    <9188, 9101, 9179>,
    <9190, 9191, 9192>,
    <9190, 9192, 9193>,
    <9190, 9193, 9181>,
    <9190, 9181, 9180>,
    <9190, 9180, 8277>,
    <9190, 8277, 8377>,
    <9190, 8377, 8375>,
    <9190, 8375, 9191>,
    <9194, 9195, 9192>,
    <9194, 9192, 9191>,
    <9194, 9191, 8375>,
    <9194, 8375, 8374>,
    <9194, 8374, 8373>,
    <9194, 8373, 9196>,
    <9194, 9196, 9197>,
    <9194, 9197, 9195>,
    <9198, 9193, 9192>,
    <9198, 9192, 9195>,
    <9198, 9195, 9197>,
    <9198, 9197, 9199>,
    <9198, 9199, 9185>,
    <9198, 9185, 9184>,
    <9198, 9184, 9181>,
    <9198, 9181, 9193>,
    <9200, 9201, 9202>,
    <9200, 9202, 9203>,
    <9200, 9203, 9204>,
    <9200, 9204, 9205>,
    <9200, 9205, 9206>,
    <9200, 9206, 9207>,
    <9200, 9207, 9208>,
    <9200, 9208, 9201>,
    <9209, 9210, 9202>,
    <9209, 9202, 9201>,
    <9209, 9201, 9208>,
    <9209, 9208, 9211>,
    <9209, 9211, 9212>,
    <9209, 9212, 8450>,
    <9209, 8450, 8447>,
    <9209, 8447, 9210>,
    <9213, 9203, 9202>,
    <9213, 9202, 9210>,
    <9213, 9210, 8447>,
    <9213, 8447, 8446>,
    <9213, 8446, 8394>,
    <9213, 8394, 9214>,
    <9213, 9214, 9204>,
    <9213, 9204, 9203>,
    <9215, 9216, 9217>,
    <9215, 9217, 9218>,
    <9215, 9218, 9112>,
    <9215, 9112, 9111>,
    <9215, 9111, 9110>,
    <9215, 9110, 9219>,
    <9215, 9219, 9220>,
    <9215, 9220, 9216>,
    <9221, 9222, 9217>,
    <9221, 9217, 9216>,
    <9221, 9216, 9220>,
    <9221, 9220, 9223>,
    <9221, 9223, 9206>,
    <9221, 9206, 9205>,
    <9221, 9205, 9204>,
    <9221, 9204, 9222>,
    <9224, 9218, 9217>,
    <9224, 9217, 9222>,
    <9224, 9222, 9204>,
    <9224, 9204, 9214>,
    <9224, 9214, 8394>,
    <9224, 8394, 9115>,
    <9224, 9115, 9112>,
    <9224, 9112, 9218>,
    <9225, 9226, 9227>,
    <9225, 9227, 9228>,
    <9225, 9228, 9229>,
    <9225, 9229, 9230>,
    <9225, 9230, 9231>,
    <9225, 9231, 9232>,
    <9225, 9233, 9234>,
    <9225, 9234, 9226>,
    <9235, 9236, 9227>,
    <9235, 9227, 9226>,
    <9235, 9226, 9237>,
    <9235, 9237, 9238>,
    <9235, 9239, 9240>,
    <9235, 9240, 8621>,
    <9235, 8621, 8619>,
    <9235, 8619, 9236>,
    <9241, 9228, 9227>,
    <9241, 9227, 9236>,
    <9241, 9236, 8619>,
    <9241, 8619, 8618>,
    <9241, 8618, 8617>,
    <9241, 8617, 9242>,
    <9241, 9242, 9229>,
    <9241, 9229, 9228>,
    <9243, 9244, 9245>,
    <9243, 9245, 9246>,
    <9243, 9246, 9197>,
    <9243, 9197, 9196>,
    <9243, 9196, 8373>,
    <9243, 8373, 9247>,
    <9243, 9247, 9248>,
    <9243, 9248, 9244>,
    <9249, 9250, 9245>,
    <9249, 9245, 9244>,
    <9249, 9244, 9248>,
    <9249, 9248, 9251>,
    <9249, 9251, 9252>,
    <9249, 9252, 9253>,
    <9249, 9253, 9254>,
    <9249, 9254, 9250>,
    <9255, 9246, 9245>,
    <9255, 9245, 9250>,
    <9255, 9250, 9254>,
    <9255, 9254, 9256>,
    <9255, 9256, 9185>,
    <9255, 9185, 9199>,
    <9255, 9199, 9197>,
    <9255, 9197, 9246>,
    <9257, 9258, 9259>,
    <9257, 9259, 9260>,
    <9257, 9260, 9248>,
    <9257, 9248, 9247>,
    <9257, 9247, 8373>,
    <9257, 8373, 8426>,
    <9257, 8426, 8424>,
    <9257, 8424, 9258>,
    <9261, 9262, 9259>,
    <9261, 9259, 9258>,
    <9261, 9258, 8424>,
    <9261, 8424, 8423>,
    <9261, 8423, 9263>,
    <9261, 9263, 9264>,
    <9261, 9265, 9266>,
    <9261, 9266, 9262>,
    <9267, 9260, 9259>,
    <9267, 9259, 9262>,
    <9267, 9262, 9268>,
    <9267, 9268, 9269>,
    <9267, 9270, 9271>,
    <9267, 9271, 9251>,
    <9267, 9251, 9248>,
    <9267, 9248, 9260>,
    <9272, 9273, 9274>,
    <9272, 9274, 9275>,
    <9272, 9275, 9208>,
    <9272, 9208, 9207>,
    <9272, 9207, 9206>,
    <9272, 9206, 9276>,
    <9272, 9276, 9277>,
    <9272, 9277, 9273>,
    <9278, 9279, 9274>,
    <9278, 9274, 9273>,
    <9278, 9273, 9277>,
    <9278, 9277, 9280>,
    <9278, 9280, 9281>,
    <9278, 9281, 9282>,
    <9278, 9283, 9284>,
    <9278, 9284, 9279>,
    <9285, 9275, 9274>,
    <9285, 9274, 9279>,
    <9285, 9279, 9286>,
    <9285, 9286, 9287>,
    <9285, 9288, 9289>,
    <9285, 9289, 9211>,
    <9285, 9211, 9208>,
    <9285, 9208, 9275>,
    <9290, 9291, 9292>,
    <9290, 9292, 9293>,
    <9290, 9293, 9294>,
    <9290, 9294, 9295>,
    <9290, 9295, 8328>,
    <9290, 8328, 9151>,
    <9290, 9151, 9149>,
    <9290, 9149, 9291>,
    <9296, 9297, 9292>,
    <9296, 9292, 9291>,
    <9296, 9291, 9149>,
    <9296, 9149, 9148>,
    <9296, 9148, 9140>,
    <9296, 9140, 9298>,
    <9296, 9298, 9299>,
    <9296, 9299, 9297>,
    <9300, 9293, 9292>,
    <9300, 9292, 9297>,
    <9300, 9297, 9299>,
    <9300, 9299, 9301>,
    <9300, 9301, 9302>,
    <9300, 9302, 9303>,
    <9300, 9303, 9294>,
    <9300, 9294, 9293>,
    <9304, 9305, 9306>,
    <9304, 9306, 9307>,
    <9304, 9307, 8469>,
    <9304, 8469, 8468>,
    <9304, 8468, 8328>,
    <9304, 8328, 9295>,
    <9304, 9295, 9294>,
    <9304, 9294, 9305>,
    <9308, 9309, 9306>,
    <9308, 9306, 9305>,
    <9308, 9305, 9294>,
    <9308, 9294, 9303>,
    <9308, 9303, 9302>,
    <9308, 9302, 9310>,
    <9308, 9310, 9311>,
    <9308, 9311, 9309>,
    <9312, 9307, 9306>,
    <9312, 9306, 9309>,
    <9312, 9309, 9311>,
    <9312, 9311, 9313>,
    <9312, 9313, 8472>,
    <9312, 8472, 8471>,
    <9312, 8471, 8469>,
    <9312, 8469, 9307>,
    <9314, 9315, 9316>,
    <9314, 9316, 9317>,
    <9314, 9317, 9318>,
    <9314, 9318, 9319>,
    <9314, 9319, 9320>,
    <9314, 9320, 9321>,
    <9314, 9321, 9322>,
    <9314, 9322, 9315>,
    <9323, 9324, 9316>,
    <9323, 9316, 9315>,
    <9323, 9315, 9322>,
    <9323, 9322, 9325>,
    <9323, 9325, 8490>,
    <9323, 8490, 8551>,
    <9323, 8551, 8550>,
    <9323, 8550, 9324>,
    <9326, 9317, 9316>,
    <9326, 9316, 9324>,
    <9326, 9324, 8550>,
    <9326, 8550, 8555>,
    <9326, 8555, 8538>,
    <9326, 8538, 9327>,
    <9326, 9327, 9318>,
    <9326, 9318, 9317>,
    <9328, 9329, 9330>,
    <9328, 9330, 9331>,
    <9328, 9331, 9332>,
    <9328, 9332, 9333>,
    <9328, 9333, 9158>,
    <9328, 9158, 9157>,
    <9328, 9157, 9156>,
    <9328, 9156, 9329>,
    <9334, 9335, 9330>,
    <9334, 9330, 9329>,
    <9334, 9329, 9156>,
    <9334, 9156, 9165>,
    <9334, 9165, 8490>,
    <9334, 8490, 9325>,
    <9334, 9325, 9322>,
    <9334, 9322, 9335>,
    <9336, 9331, 9330>,
    <9336, 9330, 9335>,
    <9336, 9335, 9322>,
    <9336, 9322, 9321>,
    <9336, 9321, 9320>,
    <9336, 9320, 9337>,
    <9336, 9337, 9332>,
    <9336, 9332, 9331>,
    <9338, 9339, 9340>,
    <9338, 9340, 9341>,
    <9338, 9341, 9342>,
    <9338, 9342, 9343>,
    <9338, 9343, 8472>,
    <9338, 8472, 9313>,
    <9338, 9313, 9311>,
    <9338, 9311, 9339>,
    <9344, 9345, 9340>,
    <9344, 9340, 9339>,
    <9344, 9339, 9311>,
    <9344, 9311, 9310>,
    <9344, 9310, 9302>,
    <9344, 9302, 9346>,
    <9344, 9346, 9347>,
    <9344, 9347, 9345>,
    <9348, 9341, 9340>,
    <9348, 9340, 9345>,
    <9348, 9345, 9347>,
    <9348, 9347, 9349>,
    <9348, 9349, 9350>,
    <9348, 9350, 9351>,
    <9348, 9351, 9342>,
    <9348, 9342, 9341>,
    <9352, 9353, 9354>,
    <9352, 9354, 9355>,
    <9352, 9355, 8517>,
    <9352, 8517, 8516>,
    <9352, 8516, 8472>,
    <9352, 8472, 9343>,
    <9352, 9343, 9342>,
    <9352, 9342, 9353>,
    <9356, 9357, 9354>,
    <9356, 9354, 9353>,
    <9356, 9353, 9342>,
    <9356, 9342, 9351>,
    <9356, 9351, 9350>,
    <9356, 9350, 9358>,
    <9356, 9358, 9359>,
    <9356, 9359, 9357>,
    <9360, 9355, 9354>,
    <9360, 9354, 9357>,
    <9360, 9357, 9359>,
    <9360, 9359, 9361>,
    <9360, 9361, 8520>,
    <9360, 8520, 8519>,
    <9360, 8519, 8517>,
    <9360, 8517, 9355>,
    <9362, 9363, 9364>,
    <9362, 9364, 9365>,
    <9362, 9365, 9366>,
    <9362, 9366, 9367>,
    <9362, 9367, 9368>,
    <9362, 9368, 9369>,
    <9362, 9369, 9370>,
    <9362, 9370, 9363>,
    <9371, 9372, 9364>,
    <9371, 9364, 9363>,
    <9371, 9363, 9370>,
    <9371, 9370, 9373>,
    <9371, 9373, 8538>,
    <9371, 8538, 8581>,
    <9371, 8581, 8580>,
    <9371, 8580, 9372>,
    <9374, 9365, 9364>,
    <9374, 9364, 9372>,
    <9374, 9372, 8580>,
    <9374, 8580, 8585>,
    <9374, 8585, 1017>,
    <9374, 1017, 9375>,
    <9374, 9375, 9366>,
    <9374, 9366, 9365>,
    <9376, 9377, 9378>,
    <9376, 9378, 9379>,
    <9376, 9379, 9380>,
    <9376, 9380, 9381>,
    <9376, 9381, 9320>,
    <9376, 9320, 9319>,
    <9376, 9319, 9318>,
    <9376, 9318, 9377>,
    <9382, 9383, 9378>,
    <9382, 9378, 9377>,
    <9382, 9377, 9318>,
    <9382, 9318, 9327>,
    <9382, 9327, 8538>,
    <9382, 8538, 9373>,
    <9382, 9373, 9370>,
    <9382, 9370, 9383>,
    <9384, 9379, 9378>,
    <9384, 9378, 9383>,
    <9384, 9383, 9370>,
    <9384, 9370, 9369>,
    <9384, 9369, 9368>,
    <9384, 9368, 9385>,
    <9384, 9385, 9380>,
    <9384, 9380, 9379>,
    <9386, 9387, 9388>,
    <9386, 9388, 9389>,
    <9386, 9389, 9390>,
    <9386, 9390, 9391>,
    <9386, 9391, 8520>,
    <9386, 8520, 9361>,
    <9386, 9361, 9359>,
    <9386, 9359, 9387>,
    <9392, 9393, 9388>,
    <9392, 9388, 9387>,
    <9392, 9387, 9359>,
    <9392, 9359, 9358>,
    <9392, 9358, 9350>,
    <9392, 9350, 9394>,
    <9392, 9394, 9395>,
    <9392, 9395, 9393>,
    <9396, 9389, 9388>,
    <9396, 9388, 9393>,
    <9396, 9393, 9395>,
    <9396, 9395, 9397>,
    <9396, 9397, 1254>,
    <9396, 1254, 9398>,
    <9396, 9398, 9390>,
    <9396, 9390, 9389>,
    <9399, 9400, 9401>,
    <9399, 9401, 9402>,
    <9399, 9402, 8565>,
    <9399, 8565, 8564>,
    <9399, 8564, 8520>,
    <9399, 8520, 9391>,
    <9399, 9391, 9390>,
    <9399, 9390, 9400>,
    <9403, 9404, 9401>,
    <9403, 9401, 9400>,
    <9403, 9400, 9390>,
    <9403, 9390, 9398>,
    <9403, 9398, 1254>,
    <9403, 1254, 1291>,
    <9403, 1291, 1289>,
    <9403, 1289, 9404>,
    <9405, 9402, 9401>,
    <9405, 9401, 9404>,
    <9405, 9404, 1289>,
    <9405, 1289, 1288>,
    <9405, 1288, 966>,
    <9405, 966, 8567>,
    <9405, 8567, 8565>,
    <9405, 8565, 9402>,
    <9406, 9407, 9408>,
    <9406, 9408, 9409>,
    <9406, 9409, 9410>,
    <9406, 9410, 9411>,
    <9406, 9411, 9368>,
    <9406, 9368, 9367>,
    <9406, 9367, 9366>,
    <9406, 9366, 9407>,
    <9412, 9413, 9408>,
    <9412, 9408, 9407>,
    <9412, 9407, 9366>,
    <9412, 9366, 9375>,
    <9412, 9375, 1017>,
    <9412, 1017, 1324>,
    <9412, 1324, 1322>,
    <9412, 1322, 9413>,
    <9414, 9409, 9408>,
    <9414, 9408, 9413>,
    <9414, 9413, 1322>,
    <9414, 1322, 1321>,
    <9414, 1321, 1305>,
    <9414, 1305, 9415>,
    <9414, 9415, 9410>,
    <9414, 9410, 9409>,
    <9416, 9417, 9418>,
    <9416, 9418, 9419>,
    <9416, 9419, 9420>,
    <9416, 9420, 9421>,
    <9416, 9422, 9423>,
    <9416, 9423, 9424>,
    <9416, 9424, 9425>,
    <9416, 9425, 9417>,
    <9426, 9427, 9418>,
    <9426, 9418, 9417>,
    <9426, 9417, 9425>,
    <9426, 9425, 9428>,
    <9426, 9428, 8665>,
    <9426, 8665, 8697>,
    <9426, 8697, 8695>,
    <9426, 8695, 9427>,
    <9429, 9419, 9418>,
    <9429, 9418, 9427>,
    <9429, 9427, 8695>,
    <9429, 8695, 8694>,
    <9429, 8694, 9430>,
    <9429, 9430, 9431>,
    <9429, 9432, 9433>,
    <9429, 9433, 9419>,
    <9434, 9435, 9436>,
    <9434, 9436, 9437>,
    <9434, 9437, 9438>,
    <9434, 9438, 9439>,
    <9434, 9439, 9440>,
    <9434, 9440, 9441>,
    <9434, 9442, 9443>,
    <9434, 9443, 9435>,
    <9444, 9445, 9436>,
    <9444, 9436, 9435>,
    <9444, 9435, 9446>,
    <9444, 9446, 9447>,
    <9444, 9448, 9449>,
    <9444, 9449, 8834>,
    <9444, 8834, 8833>,
    <9444, 8833, 9445>,
    <9450, 9437, 9436>,
    <9450, 9436, 9445>,
    <9450, 9445, 8833>,
    <9450, 8833, 8839>,
    <9450, 8839, 8821>,
    <9450, 8821, 9451>,
    <9450, 9451, 9438>,
    <9450, 9438, 9437>,
    <9452, 9453, 9454>,
    <9452, 9454, 9455>,
    <9452, 9455, 9456>,
    <9452, 9456, 9457>,
    <9452, 9458, 9459>,
    <9452, 9459, 9460>,
    <9452, 9460, 9461>,
    <9452, 9461, 9453>,
    <9462, 9463, 9454>,
    <9462, 9454, 9453>,
    <9462, 9453, 9461>,
    <9462, 9461, 9464>,
    <9462, 9464, 9465>,
    <9462, 9465, 9466>,
    <9462, 9466, 9467>,
    <9462, 9467, 9463>,
    <9468, 9455, 9454>,
    <9468, 9454, 9463>,
    <9468, 9463, 9467>,
    <9468, 9467, 9469>,
    <9468, 9469, 9470>,
    <9468, 9470, 9471>,
    <9468, 9472, 9473>,
    <9468, 9473, 9455>,
    <9474, 9475, 9476>,
    <9474, 9476, 9477>,
    <9474, 9477, 9461>,
    <9474, 9461, 9460>,
    <9474, 9460, 9478>,
    <9474, 9478, 9230>,
    <9474, 9230, 9229>,
    <9474, 9229, 9475>,
    <9479, 9480, 9476>,
    <9479, 9476, 9475>,
    <9479, 9475, 9229>,
    <9479, 9229, 9242>,
    <9479, 9242, 8617>,
    <9479, 8617, 9481>,
    <9479, 9481, 9482>,
    <9479, 9482, 9480>,
    <9483, 9477, 9476>,
    <9483, 9476, 9480>,
    <9483, 9480, 9482>,
    <9483, 9482, 9484>,
    <9483, 9484, 9465>,
    <9483, 9465, 9464>,
    <9483, 9464, 9461>,
    <9483, 9461, 9477>,
    <9485, 9486, 9487>,
    <9485, 9487, 9488>,
    <9485, 9488, 9425>,
    <9485, 9425, 9424>,
    <9485, 9424, 9489>,
    <9485, 9489, 9490>,
    <9485, 9490, 9491>,
    <9485, 9491, 9486>,
    <9492, 9493, 9487>,
    <9492, 9487, 9486>,
    <9492, 9486, 9491>,
    <9492, 9491, 9494>,
    <9492, 9494, 9495>,
    <9492, 9495, 9496>,
    <9492, 9496, 9497>,
    <9492, 9497, 9493>,
    <9498, 9488, 9487>,
    <9498, 9487, 9493>,
    <9498, 9493, 9497>,
    <9498, 9497, 9499>,
    <9498, 9499, 8665>,
    <9498, 8665, 9428>,
    <9498, 9428, 9425>,
    <9498, 9425, 9488>,
    <9500, 9501, 9502>,
    <9500, 9502, 9503>,
    <9500, 9503, 9497>,
    <9500, 9497, 9496>,
    <9500, 9496, 9495>,
    <9500, 9495, 9504>,
    <9500, 9504, 9505>,
    <9500, 9505, 9501>,
    <9506, 9507, 9502>,
    <9506, 9502, 9501>,
    <9506, 9501, 9505>,
    <9506, 9505, 9508>,
    <9506, 9508, 8746>,
    <9506, 8746, 8762>,
    <9506, 8762, 8759>,
    <9506, 8759, 9507>,
    <9509, 9503, 9502>,
    <9509, 9502, 9507>,
    <9509, 9507, 8759>,
    <9509, 8759, 8758>,
    <9509, 8758, 8665>,
    <9509, 8665, 9499>,
    <9509, 9499, 9497>,
    <9509, 9497, 9503>,
    <9510, 9511, 9512>,
    <9510, 9512, 9513>,
    <9510, 9513, 9491>,
    <9510, 9491, 9490>,
    <9510, 9490, 9514>,
    <9510, 9514, 9515>,
    <9510, 9516, 9517>,
    <9510, 9517, 9511>,
    <9518, 9519, 9512>,
    <9518, 9512, 9511>,
    <9518, 9511, 9520>,
    <9518, 9520, 9521>,
    <9518, 9522, 9523>,
    <9518, 9523, 9524>,
    <9518, 9524, 9525>,
    <9518, 9525, 9519>,
    <9526, 9513, 9512>,
    <9526, 9512, 9519>,
    <9526, 9519, 9525>,
    <9526, 9525, 9527>,
    <9526, 9527, 9495>,
    <9526, 9495, 9494>,
    <9526, 9494, 9491>,
    <9526, 9491, 9513>,
    <9528, 9529, 9530>,
    <9528, 9530, 9531>,
    <9528, 9531, 9532>,
    <9528, 9532, 9533>,
    <9528, 9533, 9534>,
    <9528, 9534, 9535>,
    <9528, 9536, 9537>,
    <9528, 9537, 9529>,
    <9538, 9539, 9530>,
    <9538, 9530, 9529>,
    <9538, 9529, 9540>,
    <9538, 9540, 9541>,
    <9538, 9542, 9543>,
    <9538, 9543, 9439>,
    <9538, 9439, 9438>,
    <9538, 9438, 9539>,
    <9544, 9531, 9530>,
    <9544, 9530, 9539>,
    <9544, 9539, 9438>,
    <9544, 9438, 9451>,
    <9544, 9451, 8821>,
    <9544, 8821, 9545>,
    <9544, 9545, 9532>,
    <9544, 9532, 9531>,
    <9546, 9547, 9548>,
    <9546, 9548, 9549>,
    <9546, 9549, 9482>,
    <9546, 9482, 9481>,
    <9546, 9481, 8617>,
    <9546, 8617, 9550>,
    <9546, 9550, 9551>,
    <9546, 9551, 9547>,
    <9552, 9553, 9548>,
    <9552, 9548, 9547>,
    <9552, 9547, 9551>,
    <9552, 9551, 9554>,
    <9552, 9554, 9555>,
    <9552, 9555, 9556>,
    <9552, 9556, 9557>,
    <9552, 9557, 9553>,
    <9558, 9549, 9548>,
    <9558, 9548, 9553>,
    <9558, 9553, 9557>,
    <9558, 9557, 9559>,
    <9558, 9559, 9465>,
    <9558, 9465, 9484>,
    <9558, 9484, 9482>,
    <9558, 9482, 9549>,
    <9560, 9561, 9562>,
    <9560, 9562, 9563>,
    <9560, 9563, 9551>,
    <9560, 9551, 9550>,
    <9560, 9550, 8617>,
    <9560, 8617, 8729>,
    <9560, 8729, 8727>,
    <9560, 8727, 9561>,
    <9564, 9565, 9562>,
    <9564, 9562, 9561>,
    <9564, 9561, 8727>,
    <9564, 8727, 8726>,
    <9564, 8726, 8725>,
    <9564, 8725, 9566>,
    <9564, 9566, 9567>,
    <9564, 9567, 9565>,
    <9568, 9563, 9562>,
    <9568, 9562, 9565>,
    <9568, 9565, 9567>,
    <9568, 9567, 9569>,
    <9568, 9569, 9555>,
    <9568, 9555, 9554>,
    <9568, 9554, 9551>,
    <9568, 9551, 9563>,
    <9570, 9571, 9572>,
    <9570, 9572, 9573>,
    <9570, 9573, 9574>,
    <9570, 9574, 9575>,
    <9570, 9575, 9576>,
    <9570, 9576, 9577>,
    <9570, 9577, 9578>,
    <9570, 9578, 9571>,
    <9579, 9580, 9572>,
    <9579, 9572, 9571>,
    <9579, 9571, 9578>,
    <9579, 9578, 9581>,
    <9579, 9581, 8870>,
    <9579, 8870, 8886>,
    <9579, 8886, 8883>,
    <9579, 8883, 9580>,
    <9582, 9573, 9572>,
    <9582, 9572, 9580>,
    <9582, 9580, 8883>,
    <9582, 8883, 8882>,
    <9582, 8882, 8746>,
    <9582, 8746, 9583>,
    <9582, 9583, 9574>,
    <9582, 9574, 9573>,
    <9584, 9585, 9586>,
    <9584, 9586, 9587>,
    <9584, 9587, 9505>,
    <9584, 9505, 9504>,
    <9584, 9504, 9495>,
    <9584, 9495, 9588>,
    <9584, 9588, 9589>,
    <9584, 9589, 9585>,
    <9590, 9591, 9586>,
    <9590, 9586, 9585>,
    <9590, 9585, 9589>,
    <9590, 9589, 9592>,
    <9590, 9592, 9576>,
    <9590, 9576, 9575>,
    <9590, 9575, 9574>,
    <9590, 9574, 9591>,
    <9593, 9587, 9586>,
    <9593, 9586, 9591>,
    <9593, 9591, 9574>,
    <9593, 9574, 9583>,
    <9593, 9583, 8746>,
    <9593, 8746, 9508>,
    <9593, 9508, 9505>,
    <9593, 9505, 9587>,
    <9594, 9595, 9596>,
    <9594, 9596, 9597>,
    <9594, 9597, 9598>,
    <9594, 9598, 9599>,
    <9594, 9599, 9600>,
    <9594, 9600, 9601>,
    <9594, 9602, 9603>,
    <9594, 9603, 9595>,
    <9604, 9605, 9596>,
    <9604, 9596, 9595>,
    <9604, 9595, 9606>,
    <9604, 9606, 9607>,
    <9604, 9608, 9609>,
    <9604, 9609, 9610>,
    <9604, 9610, 9611>,
    <9604, 9611, 9605>,
    <9612, 9597, 9596>,
    <9612, 9596, 9605>,
    <9612, 9605, 9611>,
    <9612, 9611, 9613>,
    <9612, 9613, 9614>,
    <9612, 9614, 9615>,
    <9612, 9615, 9598>,
    <9612, 9598, 9597>,
    <9616, 9617, 9618>,
    <9616, 9618, 9619>,
    <9616, 9619, 9620>,
    <9616, 9620, 9621>,
    <9616, 9621, 9622>,
    <9616, 9622, 9623>,
    <9616, 9624, 9625>,
    <9616, 9625, 9617>,
    <9626, 9627, 9618>,
    <9626, 9618, 9617>,
    <9626, 9617, 9628>,
    <9626, 9628, 9629>,
    <9626, 9630, 9631>,
    <9626, 9631, 9599>,
    <9626, 9599, 9598>,
    <9626, 9598, 9627>,
    <9632, 9619, 9618>,
    <9632, 9618, 9627>,
    <9632, 9627, 9598>,
    <9632, 9598, 9615>,
    <9632, 9615, 9614>,
    <9632, 9614, 9633>,
    <9632, 9633, 9620>,
    <9632, 9620, 9619>,
    <9634, 9635, 9636>,
    <9634, 9636, 9637>,
    <9634, 9637, 8781>,
    <9634, 8781, 8780>,
    <9634, 8780, 9638>,
    <9634, 9638, 9621>,
    <9634, 9621, 9620>,
    <9634, 9620, 9635>,
    <9639, 9640, 9636>,
    <9639, 9636, 9635>,
    <9639, 9635, 9620>,
    <9639, 9620, 9633>,
    <9639, 9633, 9614>,
    <9639, 9614, 9641>,
    <9639, 9641, 9642>,
    <9639, 9642, 9640>,
    <9643, 9637, 9636>,
    <9643, 9636, 9640>,
    <9643, 9640, 9642>,
    <9643, 9642, 9644>,
    <9643, 9644, 8784>,
    <9643, 8784, 8783>,
    <9643, 8783, 8781>,
    <9643, 8781, 9637>,
    <9645, 9646, 9647>,
    <9645, 9647, 9648>,
    <9645, 9648, 9649>,
    <9645, 9649, 9650>,
    <9645, 9650, 9651>,
    <9645, 9651, 9652>,
    <9645, 9652, 9653>,
    <9645, 9653, 9646>,
    <9654, 9655, 9647>,
    <9654, 9647, 9646>,
    <9654, 9646, 9653>,
    <9654, 9653, 9656>,
    <9654, 9656, 8821>,
    <9654, 8821, 8931>,
    <9654, 8931, 8930>,
    <9654, 8930, 9655>,
    <9657, 9648, 9647>,
    <9657, 9647, 9655>,
    <9657, 9655, 8930>,
    <9657, 8930, 8935>,
    <9657, 8935, 8918>,
    <9657, 8918, 9658>,
    <9657, 9658, 9649>,
    <9657, 9649, 9648>,
    <9659, 9660, 9661>,
    <9659, 9661, 9662>,
    <9659, 9662, 9663>,
    <9659, 9663, 9664>,
    <9659, 9664, 9665>,
    <9659, 9665, 9533>,
    <9659, 9533, 9532>,
    <9659, 9532, 9660>,
    <9666, 9667, 9661>,
    <9666, 9661, 9660>,
    <9666, 9660, 9532>,
    <9666, 9532, 9545>,
    <9666, 9545, 8821>,
    <9666, 8821, 9656>,
    <9666, 9656, 9653>,
    <9666, 9653, 9667>,
    <9668, 9662, 9661>,
    <9668, 9661, 9667>,
    <9668, 9667, 9653>,
    <9668, 9653, 9652>,
    <9668, 9652, 9651>,
    <9668, 9651, 9669>,
    <9668, 9669, 9663>,
    <9668, 9663, 9662>,
    <9670, 9671, 9672>,
    <9670, 9672, 9673>,
    <9670, 9673, 9567>,
    <9670, 9567, 9566>,
    <9670, 9566, 8725>,
    <9670, 8725, 9674>,
    <9670, 9674, 9675>,
    <9670, 9675, 9671>,
    <9676, 9677, 9672>,
    <9676, 9672, 9671>,
    <9676, 9671, 9675>,
    <9676, 9675, 9678>,
    <9676, 9678, 9679>,
    <9676, 9679, 9680>,
    <9676, 9680, 9681>,
    <9676, 9681, 9677>,
    <9682, 9673, 9672>,
    <9682, 9672, 9677>,
    <9682, 9677, 9681>,
    <9682, 9681, 9683>,
    <9682, 9683, 9555>,
    <9682, 9555, 9569>,
    <9682, 9569, 9567>,
    <9682, 9567, 9673>,
    <9684, 9685, 9686>,
    <9684, 9686, 9687>,
    <9684, 9687, 9675>,
    <9684, 9675, 9674>,
    <9684, 9674, 8725>,
    <9684, 8725, 8853>,
    <9684, 8853, 8851>,
    <9684, 8851, 9685>,
    <9688, 9689, 9686>,
    <9688, 9686, 9685>,
    <9688, 9685, 8851>,
    <9688, 8851, 8850>,
    <9688, 8850, 8849>,
    <9688, 8849, 9690>,
    <9688, 9690, 9691>,
    <9688, 9691, 9689>,
    <9692, 9687, 9686>,
    <9692, 9686, 9689>,
    <9692, 9689, 9691>,
    <9692, 9691, 9693>,
    <9692, 9693, 9679>,
    <9692, 9679, 9678>,
    <9692, 9678, 9675>,
    <9692, 9675, 9687>,
    <9694, 9695, 9696>,
    <9694, 9696, 9697>,
    <9694, 9697, 9698>,
    <9694, 9698, 9699>,
    <9694, 9699, 9700>,
    <9694, 9700, 9701>,
    <9694, 9701, 9702>,
    <9694, 9702, 9695>,
    <9703, 9704, 9696>,
    <9703, 9696, 9695>,
    <9703, 9695, 9702>,
    <9703, 9702, 9705>,
    <9703, 9705, 8966>,
    <9703, 8966, 8982>,
    <9703, 8982, 8979>,
    <9703, 8979, 9704>,
    <9706, 9697, 9696>,
    <9706, 9696, 9704>,
    <9706, 9704, 8979>,
    <9706, 8979, 8978>,
    <9706, 8978, 8870>,
    <9706, 8870, 9707>,
    <9706, 9707, 9698>,
    <9706, 9698, 9697>,
    <9708, 9709, 9710>,
    <9708, 9710, 9711>,
    <9708, 9711, 9578>,
    <9708, 9578, 9577>,
    <9708, 9577, 9576>,
    <9708, 9576, 9712>,
    <9708, 9712, 9713>,
    <9708, 9713, 9709>,
    <9714, 9715, 9710>,
    <9714, 9710, 9709>,
    <9714, 9709, 9713>,
    <9714, 9713, 9716>,
    <9714, 9716, 9700>,
    <9714, 9700, 9699>,
    <9714, 9699, 9698>,
    <9714, 9698, 9715>,
    <9717, 9711, 9710>,
    <9717, 9710, 9715>,
    <9717, 9715, 9698>,
    <9717, 9698, 9707>,
    <9717, 9707, 8870>,
    <9717, 8870, 9581>,
    <9717, 9581, 9578>,
    <9717, 9578, 9711>,
    <9718, 9719, 9720>,
    <9718, 9720, 9721>,
    <9718, 9721, 9722>,
    <9718, 9722, 9723>,
    <9718, 9723, 8784>,
    <9718, 8784, 9644>,
    <9718, 9644, 9642>,
    <9718, 9642, 9719>,
    <9724, 9725, 9720>,
    <9724, 9720, 9719>,
    <9724, 9719, 9642>,
    <9724, 9642, 9641>,
    <9724, 9641, 9614>,
    <9724, 9614, 9726>,
    <9724, 9726, 9727>,
    <9724, 9727, 9725>,
    <9728, 9721, 9720>,
    <9728, 9720, 9725>,
    <9728, 9725, 9727>,
    <9728, 9727, 9729>,
    <9728, 9729, 9730>,
    <9728, 9730, 9731>,
    <9728, 9731, 9722>,
    <9728, 9722, 9721>,
    <9732, 9733, 9734>,
    <9732, 9734, 9735>,
    <9732, 9735, 8897>,
    <9732, 8897, 8896>,
    <9732, 8896, 8784>,
    <9732, 8784, 9723>,
    <9732, 9723, 9722>,
    <9732, 9722, 9733>,
    <9736, 9737, 9734>,
    <9736, 9734, 9733>,
    <9736, 9733, 9722>,
    <9736, 9722, 9731>,
    <9736, 9731, 9730>,
    <9736, 9730, 9738>,
    <9736, 9738, 9739>,
    <9736, 9739, 9737>,
    <9740, 9735, 9734>,
    <9740, 9734, 9737>,
    <9740, 9737, 9739>,
    <9740, 9739, 9741>,
    <9740, 9741, 8900>,
    <9740, 8900, 8899>,
    <9740, 8899, 8897>,
    <9740, 8897, 9735>,
    <9742, 9743, 9744>,
    <9742, 9744, 9745>,
    <9742, 9745, 9746>,
    <9742, 9746, 9747>,
    <9742, 9747, 9748>,
    <9742, 9748, 9749>,
    <9742, 9749, 9750>,
    <9742, 9750, 9743>,
    <9751, 9752, 9744>,
    <9751, 9744, 9743>,
    <9751, 9743, 9750>,
    <9751, 9750, 9753>,
    <9751, 9753, 8918>,
    <9751, 8918, 9027>,
    <9751, 9027, 9026>,
    <9751, 9026, 9752>,
    <9754, 9745, 9744>,
    <9754, 9744, 9752>,
    <9754, 9752, 9026>,
    <9754, 9026, 9031>,
    <9754, 9031, 9014>,
    <9754, 9014, 9755>,
    <9754, 9755, 9746>,
    <9754, 9746, 9745>,
    <9756, 9757, 9758>,
    <9756, 9758, 9759>,
    <9756, 9759, 9760>,
    <9756, 9760, 9761>,
    <9756, 9761, 9651>,
    <9756, 9651, 9650>,
    <9756, 9650, 9649>,
    <9756, 9649, 9757>,
    <9762, 9763, 9758>,
    <9762, 9758, 9757>,
    <9762, 9757, 9649>,
    <9762, 9649, 9658>,
    <9762, 9658, 8918>,
    <9762, 8918, 9753>,
    <9762, 9753, 9750>,
    <9762, 9750, 9763>,
    <9764, 9759, 9758>,
    <9764, 9758, 9763>,
    <9764, 9763, 9750>,
    <9764, 9750, 9749>,
    <9764, 9749, 9748>,
    <9764, 9748, 9765>,
    <9764, 9765, 9760>,
    <9764, 9760, 9759>,
    <9766, 9767, 9768>,
    <9766, 9768, 9769>,
    <9766, 9769, 9691>,
    <9766, 9691, 9690>,
    <9766, 9690, 8849>,
    <9766, 8849, 9770>,
    <9766, 9770, 9771>,
    <9766, 9771, 9767>,
    <9772, 9773, 9768>,
    <9772, 9768, 9767>,
    <9772, 9767, 9771>,
    <9772, 9771, 9774>,
    <9772, 9774, 9775>,
    <9772, 9775, 9776>,
    <9772, 9776, 9777>,
    <9772, 9777, 9773>,
    <9778, 9769, 9768>,
    <9778, 9768, 9773>,
    <9778, 9773, 9777>,
    <9778, 9777, 9779>,
    <9778, 9779, 9679>,
    <9778, 9679, 9693>,
    <9778, 9693, 9691>,
    <9778, 9691, 9769>,
    <9780, 9781, 9782>,
    <9780, 9782, 9783>,
    <9780, 9783, 9771>,
    <9780, 9771, 9770>,
    <9780, 9770, 8849>,
    <9780, 8849, 8949>,
    <9780, 8949, 8947>,
    <9780, 8947, 9781>,
    <9784, 9785, 9782>,
    <9784, 9782, 9781>,
    <9784, 9781, 8947>,
    <9784, 8947, 8946>,
    <9784, 8946, 8945>,
    <9784, 8945, 9786>,
    <9784, 9786, 9787>,
    <9784, 9787, 9785>,
    <9788, 9783, 9782>,
    <9788, 9782, 9785>,
    <9788, 9785, 9787>,
    <9788, 9787, 9789>,
    <9788, 9789, 9775>,
    <9788, 9775, 9774>,
    <9788, 9774, 9771>,
    <9788, 9771, 9783>,
    <9790, 9791, 9792>,
    <9790, 9792, 9793>,
    <9790, 9793, 9794>,
    <9790, 9794, 9795>,
    <9790, 9795, 9796>,
    <9790, 9796, 9797>,
    <9790, 9797, 9798>,
    <9790, 9798, 9791>,
    <9799, 9800, 9792>,
    <9799, 9792, 9791>,
    <9799, 9791, 9798>,
    <9799, 9798, 9801>,
    <9799, 9801, 9062>,
    <9799, 9062, 9078>,
    <9799, 9078, 9075>,
    <9799, 9075, 9800>,
    <9802, 9793, 9792>,
    <9802, 9792, 9800>,
    <9802, 9800, 9075>,
    <9802, 9075, 9074>,
    <9802, 9074, 8966>,
    <9802, 8966, 9803>,
    <9802, 9803, 9794>,
    <9802, 9794, 9793>,
    <9804, 9805, 9806>,
    <9804, 9806, 9807>,
    <9804, 9807, 9702>,
    <9804, 9702, 9701>,
    <9804, 9701, 9700>,
    <9804, 9700, 9808>,
    <9804, 9808, 9809>,
    <9804, 9809, 9805>,
    <9810, 9811, 9806>,
    <9810, 9806, 9805>,
    <9810, 9805, 9809>,
    <9810, 9809, 9812>,
    <9810, 9812, 9796>,
    <9810, 9796, 9795>,
    <9810, 9795, 9794>,
    <9810, 9794, 9811>,
    <9813, 9807, 9806>,
    <9813, 9806, 9811>,
    <9813, 9811, 9794>,
    <9813, 9794, 9803>,
    <9813, 9803, 8966>,
    <9813, 8966, 9705>,
    <9813, 9705, 9702>,
    <9813, 9702, 9807>,
    <9814, 9815, 9816>,
    <9814, 9816, 9817>,
    <9814, 9817, 9818>,
    <9814, 9818, 9819>,
    <9814, 9819, 8900>,
    <9814, 8900, 9741>,
    <9814, 9741, 9739>,
    <9814, 9739, 9815>,
    <9820, 9821, 9816>,
    <9820, 9816, 9815>,
    <9820, 9815, 9739>,
    <9820, 9739, 9738>,
    <9820, 9738, 9730>,
    <9820, 9730, 9822>,
    <9820, 9822, 9823>,
    <9820, 9823, 9821>,
    <9824, 9817, 9816>,
    <9824, 9816, 9821>,
    <9824, 9821, 9823>,
    <9824, 9823, 9825>,
    <9824, 9825, 9826>,
    <9824, 9826, 9827>,
    <9824, 9827, 9818>,
    <9824, 9818, 9817>,
    <9828, 9829, 9830>,
    <9828, 9830, 9831>,
    <9828, 9831, 8993>,
    <9828, 8993, 8992>,
    <9828, 8992, 8900>,
    <9828, 8900, 9819>,
    <9828, 9819, 9818>,
    <9828, 9818, 9829>,
    <9832, 9833, 9830>,
    <9832, 9830, 9829>,
    <9832, 9829, 9818>,
    <9832, 9818, 9827>,
    <9832, 9827, 9826>,
    <9832, 9826, 9834>,
    <9832, 9834, 9835>,
    <9832, 9835, 9833>,
    <9836, 9831, 9830>,
    <9836, 9830, 9833>,
    <9836, 9833, 9835>,
    <9836, 9835, 9837>,
    <9836, 9837, 8996>,
    <9836, 8996, 8995>,
    <9836, 8995, 8993>,
    <9836, 8993, 9831>,
    <9838, 9839, 9840>,
    <9838, 9840, 9841>,
    <9838, 9841, 9842>,
    <9838, 9842, 9843>,
    <9838, 9843, 9844>,
    <9838, 9844, 9845>,
    <9838, 9845, 9846>,
    <9838, 9846, 9839>,
    <9847, 9848, 9840>,
    <9847, 9840, 9839>,
    <9847, 9839, 9846>,
    <9847, 9846, 9849>,
    <9847, 9849, 9014>,
    <9847, 9014, 9171>,
    <9847, 9171, 9170>,
    <9847, 9170, 9848>,
    <9850, 9841, 9840>,
    <9850, 9840, 9848>,
    <9850, 9848, 9170>,
    <9850, 9170, 9175>,
    <9850, 9175, 9158>,
    <9850, 9158, 9851>,
    <9850, 9851, 9842>,
    <9850, 9842, 9841>,
    <9852, 9853, 9854>,
    <9852, 9854, 9855>,
    <9852, 9855, 9856>,
    <9852, 9856, 9857>,
    <9852, 9857, 9748>,
    <9852, 9748, 9747>,
    <9852, 9747, 9746>,
    <9852, 9746, 9853>,
    <9858, 9859, 9854>,
    <9858, 9854, 9853>,
    <9858, 9853, 9746>,
    <9858, 9746, 9755>,
    <9858, 9755, 9014>,
    <9858, 9014, 9849>,
    <9858, 9849, 9846>,
    <9858, 9846, 9859>,
    <9860, 9855, 9854>,
    <9860, 9854, 9859>,
    <9860, 9859, 9846>,
    <9860, 9846, 9845>,
    <9860, 9845, 9844>,
    <9860, 9844, 9861>,
    <9860, 9861, 9856>,
    <9860, 9856, 9855>,
    <9862, 9863, 9864>,
    <9862, 9864, 9865>,
    <9862, 9865, 9787>,
    <9862, 9787, 9786>,
    <9862, 9786, 8945>,
    <9862, 8945, 9866>,
    <9862, 9866, 9867>,
    <9862, 9867, 9863>,
    <9868, 9869, 9864>,
    <9868, 9864, 9863>,
    <9868, 9863, 9867>,
    <9868, 9867, 9870>,
    <9868, 9870, 9871>,
    <9868, 9871, 9872>,
    <9868, 9872, 9873>,
    <9868, 9873, 9869>,
    <9874, 9865, 9864>,
    <9874, 9864, 9869>,
    <9874, 9869, 9873>,
    <9874, 9873, 9875>,
    <9874, 9875, 9775>,
    <9874, 9775, 9789>,
    <9874, 9789, 9787>,
    <9874, 9787, 9865>,
    <9876, 9877, 9878>,
    <9876, 9878, 9879>,
    <9876, 9879, 9867>,
    <9876, 9867, 9866>,
    <9876, 9866, 8945>,
    <9876, 8945, 9045>,
    <9876, 9045, 9043>,
    <9876, 9043, 9877>,
    <9880, 9881, 9878>,
    <9880, 9878, 9877>,
    <9880, 9877, 9043>,
    <9880, 9043, 9042>,
    <9880, 9042, 9041>,
    <9880, 9041, 9882>,
    <9880, 9882, 9883>,
    <9880, 9883, 9881>,
    <9884, 9879, 9878>,
    <9884, 9878, 9881>,
    <9884, 9881, 9883>,
    <9884, 9883, 9885>,
    <9884, 9885, 9871>,
    <9884, 9871, 9870>,
    <9884, 9870, 9867>,
    <9884, 9867, 9879>,
    <9886, 9887, 9888>,
    <9886, 9888, 9889>,
    <9886, 9889, 9890>,
    <9886, 9890, 9891>,
    <9886, 9891, 9892>,
    <9886, 9892, 9893>,
    <9886, 9893, 9894>,
    <9886, 9894, 9887>,
    <9895, 9896, 9888>,
    <9895, 9888, 9887>,
    <9895, 9887, 9894>,
    <9895, 9894, 9897>,
    <9895, 9897, 9110>,
    <9895, 9110, 9126>,
    <9895, 9126, 9123>,
    <9895, 9123, 9896>,
    <9898, 9889, 9888>,
    <9898, 9888, 9896>,
    <9898, 9896, 9123>,
    <9898, 9123, 9122>,
    <9898, 9122, 9062>,
    <9898, 9062, 9899>,
    <9898, 9899, 9890>,
    <9898, 9890, 9889>,
    <9900, 9901, 9902>,
    <9900, 9902, 9903>,
    <9900, 9903, 9798>,
    <9900, 9798, 9797>,
    <9900, 9797, 9796>,
    <9900, 9796, 9904>,
    <9900, 9904, 9905>,
    <9900, 9905, 9901>,
    <9906, 9907, 9902>,
    <9906, 9902, 9901>,
    <9906, 9901, 9905>,
    <9906, 9905, 9908>,
    <9906, 9908, 9892>,
    <9906, 9892, 9891>,
    <9906, 9891, 9890>,
    <9906, 9890, 9907>,
    <9909, 9903, 9902>,
    <9909, 9902, 9907>,
    <9909, 9907, 9890>,
    <9909, 9890, 9899>,
    <9909, 9899, 9062>,
    <9909, 9062, 9801>,
    <9909, 9801, 9798>,
    <9909, 9798, 9903>,
    <9910, 9911, 9912>,
    <9910, 9912, 9913>,
    <9910, 9913, 9883>,
    <9910, 9883, 9882>,
    <9910, 9882, 9041>,
    <9910, 9041, 9914>,
    <9910, 9914, 9915>,
    <9910, 9915, 9911>,
    <9916, 9917, 9912>,
    <9916, 9912, 9911>,
    <9916, 9911, 9915>,
    <9916, 9915, 9918>,
    <9916, 9918, 9919>,
    <9916, 9919, 9920>,
    <9916, 9920, 9921>,
    <9916, 9921, 9917>,
    <9922, 9913, 9912>,
    <9922, 9912, 9917>,
    <9922, 9917, 9921>,
    <9922, 9921, 9923>,
    <9922, 9923, 9871>,
    <9922, 9871, 9885>,
    <9922, 9885, 9883>,
    <9922, 9883, 9913>,
    <9924, 9925, 9926>,
    <9924, 9926, 9927>,
    <9924, 9927, 9915>,
    <9924, 9915, 9914>,
    <9924, 9914, 9041>,
    <9924, 9041, 9093>,
    <9924, 9093, 9091>,
    <9924, 9091, 9925>,
    <9928, 9929, 9926>,
    <9928, 9926, 9925>,
    <9928, 9925, 9091>,
    <9928, 9091, 9090>,
    <9928, 9090, 9089>,
    <9928, 9089, 9930>,
    <9928, 9930, 9931>,
    <9928, 9931, 9929>,
    <9932, 9927, 9926>,
    <9932, 9926, 9929>,
    <9932, 9929, 9931>,
    <9932, 9931, 9933>,
    <9932, 9933, 9919>,
    <9932, 9919, 9918>,
    <9932, 9918, 9915>,
    <9932, 9915, 9927>,
    <9934, 9935, 9936>,
    <9934, 9936, 9937>,
    <9934, 9937, 9938>,
    <9934, 9938, 9939>,
    <9934, 9939, 9940>,
    <9934, 9940, 9941>,
    <9934, 9941, 9942>,
    <9934, 9942, 9935>,
    <9943, 9944, 9936>,
    <9943, 9936, 9935>,
    <9943, 9935, 9942>,
    <9943, 9942, 9945>,
    <9943, 9945, 9206>,
    <9943, 9206, 9223>,
    <9943, 9223, 9220>,
    <9943, 9220, 9944>,
    <9946, 9937, 9936>,
    <9946, 9936, 9944>,
    <9946, 9944, 9220>,
    <9946, 9220, 9219>,
    <9946, 9219, 9110>,
    <9946, 9110, 9947>,
    <9946, 9947, 9938>,
    <9946, 9938, 9937>,
    <9948, 9949, 9950>,
    <9948, 9950, 9951>,
    <9948, 9951, 9894>,
    <9948, 9894, 9893>,
    <9948, 9893, 9892>,
    <9948, 9892, 9952>,
    <9948, 9952, 9953>,
    <9948, 9953, 9949>,
    <9954, 9955, 9950>,
    <9954, 9950, 9949>,
    <9954, 9949, 9953>,
    <9954, 9953, 9956>,
    <9954, 9956, 9940>,
    <9954, 9940, 9939>,
    <9954, 9939, 9938>,
    <9954, 9938, 9955>,
    <9957, 9951, 9950>,
    <9957, 9950, 9955>,
    <9957, 9955, 9938>,
    <9957, 9938, 9947>,
    <9957, 9947, 9110>,
    <9957, 9110, 9897>,
    <9957, 9897, 9894>,
    <9957, 9894, 9951>,
    <9958, 9959, 9960>,
    <9958, 9960, 9961>,
    <9958, 9961, 9962>,
    <9958, 9962, 9963>,
    <9958, 9963, 8996>,
    <9958, 8996, 9837>,
    <9958, 9837, 9835>,
    <9958, 9835, 9959>,
    <9964, 9965, 9960>,
    <9964, 9960, 9959>,
    <9964, 9959, 9835>,
    <9964, 9835, 9834>,
    <9964, 9834, 9826>,
    <9964, 9826, 9966>,
    <9964, 9966, 9967>,
    <9964, 9967, 9965>,
    <9968, 9961, 9960>,
    <9968, 9960, 9965>,
    <9968, 9965, 9967>,
    <9968, 9967, 9969>,
    <9968, 9969, 9970>,
    <9968, 9970, 9971>,
    <9968, 9971, 9962>,
    <9968, 9962, 9961>,
    <9972, 9973, 9974>,
    <9972, 9974, 9975>,
    <9972, 9975, 9137>,
    <9972, 9137, 9136>,
    <9972, 9136, 8996>,
    <9972, 8996, 9963>,
    <9972, 9963, 9962>,
    <9972, 9962, 9973>,
    <9976, 9977, 9974>,
    <9976, 9974, 9973>,
    <9976, 9973, 9962>,
    <9976, 9962, 9971>,
    <9976, 9971, 9970>,
    <9976, 9970, 9978>,
    <9976, 9978, 9979>,
    <9976, 9979, 9977>,
    <9980, 9975, 9974>,
    <9980, 9974, 9977>,
    <9980, 9977, 9979>,
    <9980, 9979, 9981>,
    <9980, 9981, 9140>,
    <9980, 9140, 9139>,
    <9980, 9139, 9137>,
    <9980, 9137, 9975>,
    <9982, 9983, 9984>,
    <9982, 9984, 9985>,
    <9982, 9985, 9986>,
    <9982, 9986, 9987>,
    <9982, 9987, 9988>,
    <9982, 9988, 9989>,
    <9982, 9989, 9990>,
    <9982, 9990, 9983>,
    <9991, 9992, 9984>,
    <9991, 9984, 9983>,
    <9991, 9983, 9990>,
    <9991, 9990, 9993>,
    <9991, 9993, 9158>,
    <9991, 9158, 9333>,
    <9991, 9333, 9332>,
    <9991, 9332, 9992>,
    <9994, 9985, 9984>,
    <9994, 9984, 9992>,
    <9994, 9992, 9332>,
    <9994, 9332, 9337>,
    <9994, 9337, 9320>,
    <9994, 9320, 9995>,
    <9994, 9995, 9986>,
    <9994, 9986, 9985>,
    <9996, 9997, 9998>,
    <9996, 9998, 9999>,
    <9996, 9999, 10000>,
    <9996, 10000, 10001>,
    <9996, 10001, 9844>,
    <9996, 9844, 9843>,
    <9996, 9843, 9842>,
    <9996, 9842, 9997>,
    <10002, 10003, 9998>,
    <10002, 9998, 9997>,
    <10002, 9997, 9842>,
    <10002, 9842, 9851>,
    <10002, 9851, 9158>,
    <10002, 9158, 9993>,
    <10002, 9993, 9990>,
    <10002, 9990, 10003>,
    <10004, 9999, 9998>,
    <10004, 9998, 10003>,
    <10004, 10003, 9990>,
    <10004, 9990, 9989>,
    <10004, 9989, 9988>,
    <10004, 9988, 10005>,
    <10004, 10005, 10000>,
    <10004, 10000, 9999>,
    <10006, 10007, 10008>,
    <10006, 10008, 10009>,
    <10006, 10009, 9931>,
    <10006, 9931, 9930>,
    <10006, 9930, 9089>,
    <10006, 9089, 10010>,
    <10006, 10010, 10011>,
    <10006, 10011, 10007>,
    <10012, 10013, 10008>,
    <10012, 10008, 10007>,
    <10012, 10007, 10011>,
    <10012, 10011, 10014>,
    <10012, 10014, 10015>,
    <10012, 10015, 10016>,
    <10012, 10016, 10017>,
    <10012, 10017, 10013>,
    <10018, 10009, 10008>,
    <10018, 10008, 10013>,
    <10018, 10013, 10017>,
    <10018, 10017, 10019>,
    <10018, 10019, 9919>,
    <10018, 9919, 9933>,
    <10018, 9933, 9931>,
    <10018, 9931, 10009>,
    <10020, 10021, 10022>,
    <10020, 10022, 10023>,
    <10020, 10023, 10011>,
    <10020, 10011, 10010>,
    <10020, 10010, 9089>,
    <10020, 9089, 9189>,
    <10020, 9189, 9187>,
    <10020, 9187, 10021>,
    <10024, 10025, 10022>,
    <10024, 10022, 10021>,
    <10024, 10021, 9187>,
    <10024, 9187, 9186>,
    <10024, 9186, 9185>,
    <10024, 9185, 10026>,
    <10024, 10026, 10027>,
    <10024, 10027, 10025>,
    <10028, 10023, 10022>,
    <10028, 10022, 10025>,
    <10028, 10025, 10027>,
    <10028, 10027, 10029>,
    <10028, 10029, 10015>,
    <10028, 10015, 10014>,
    <10028, 10014, 10011>,
    <10028, 10011, 10023>,
    <10030, 10031, 10032>,
    <10030, 10032, 10033>,
    <10030, 10033, 10034>,
    <10030, 10034, 10035>,
    <10030, 10035, 10036>,
    <10030, 10036, 10037>,
    <10030, 10037, 10038>,
    <10030, 10038, 10031>,
    <10039, 10040, 10032>,
    <10039, 10032, 10031>,
    <10039, 10031, 10038>,
    <10039, 10038, 10041>,
    <10039, 10041, 10042>,
    <10039, 10042, 9280>,
    <10039, 9280, 9277>,
    <10039, 9277, 10040>,
    <10043, 10033, 10032>,
    <10043, 10032, 10040>,
    <10043, 10040, 9277>,
    <10043, 9277, 9276>,
    <10043, 9276, 9206>,
    <10043, 9206, 10044>,
    <10043, 10044, 10034>,
    <10043, 10034, 10033>,
    <10045, 10046, 10047>,
    <10045, 10047, 10048>,
    <10045, 10048, 9942>,
    <10045, 9942, 9941>,
    <10045, 9941, 9940>,
    <10045, 9940, 10049>,
    <10045, 10049, 10050>,
    <10045, 10050, 10046>,
    <10051, 10052, 10047>,
    <10051, 10047, 10046>,
    <10051, 10046, 10050>,
    <10051, 10050, 10053>,
    <10051, 10053, 10036>,
    <10051, 10036, 10035>,
    <10051, 10035, 10034>,
    <10051, 10034, 10052>,
    <10054, 10048, 10047>,
    <10054, 10047, 10052>,
    <10054, 10052, 10034>,
    <10054, 10034, 10044>,
    <10054, 10044, 9206>,
    <10054, 9206, 9945>,
    <10054, 9945, 9942>,
    <10054, 9942, 10048>,
    <10055, 10056, 10057>,
    <10055, 10057, 10058>,
    <10055, 10058, 10027>,
    <10055, 10027, 10026>,
    <10055, 10026, 9185>,
    <10055, 9185, 10059>,
    <10055, 10059, 10060>,
    <10055, 10060, 10056>,
    <10061, 10062, 10057>,
    <10061, 10057, 10056>,
    <10061, 10056, 10060>,
    <10061, 10060, 10063>,
    <10061, 10063, 10064>,
    <10061, 10064, 10065>,
    <10061, 10065, 10066>,
    <10061, 10066, 10062>,
    <10067, 10058, 10057>,
    <10067, 10057, 10062>,
    <10067, 10062, 10066>,
    <10067, 10066, 10068>,
    <10067, 10068, 10015>,
    <10067, 10015, 10029>,
    <10067, 10029, 10027>,
    <10067, 10027, 10058>,
    <10069, 10070, 10071>,
    <10069, 10071, 10072>,
    <10069, 10072, 10060>,
    <10069, 10060, 10059>,
    <10069, 10059, 9185>,
    <10069, 9185, 9256>,
    <10069, 9256, 9254>,
    <10069, 9254, 10070>,
    <10073, 10074, 10071>,
    <10073, 10071, 10070>,
    <10073, 10070, 9254>,
    <10073, 9254, 9253>,
    <10073, 9253, 10075>,
    <10073, 10075, 10076>,
    <10073, 10077, 10078>,
    <10073, 10078, 10074>,
    <10079, 10072, 10071>,
    <10079, 10071, 10074>,
    <10079, 10074, 10080>,
    <10079, 10080, 10081>,
    <10079, 10082, 10083>,
    <10079, 10083, 10063>,
    <10079, 10063, 10060>,
    <10079, 10060, 10072>,
    <10084, 10085, 10086>,
    <10084, 10086, 10087>,
    <10084, 10087, 10038>,
    <10084, 10038, 10037>,
    <10084, 10037, 10036>,
    <10084, 10036, 10088>,
    <10084, 10088, 10089>,
    <10084, 10089, 10085>,
    <10090, 10091, 10086>,
    <10090, 10086, 10085>,
    <10090, 10085, 10089>,
    <10090, 10089, 10092>,
    <10090, 10092, 10093>,
    <10090, 10093, 10094>,
    <10090, 10095, 10096>,
    <10090, 10096, 10091>,
    <10097, 10087, 10086>,
    <10097, 10086, 10091>,
    <10097, 10091, 10098>,
    <10097, 10098, 10099>,
    <10097, 10100, 10101>,
    <10097, 10101, 10041>,
    <10097, 10041, 10038>,
    <10097, 10038, 10087>,
    <10102, 10103, 10104>,
    <10102, 10104, 10105>,
    <10102, 10105, 10106>,
    <10102, 10106, 10107>,
    <10102, 10107, 9140>,
    <10102, 9140, 9981>,
    <10102, 9981, 9979>,
    <10102, 9979, 10103>,
    <10108, 10109, 10104>,
    <10108, 10104, 10103>,
    <10108, 10103, 9979>,
    <10108, 9979, 9978>,
    <10108, 9978, 9970>,
    <10108, 9970, 10110>,
    <10108, 10110, 10111>,
    <10108, 10111, 10109>,
    <10112, 10105, 10104>,
    <10112, 10104, 10109>,
    <10112, 10109, 10111>,
    <10112, 10111, 10113>,
    <10112, 10113, 10114>,
    <10112, 10114, 10115>,
    <10112, 10115, 10106>,
    <10112, 10106, 10105>,
    <10116, 10117, 10118>,
    <10116, 10118, 10119>,
    <10116, 10119, 9299>,
    <10116, 9299, 9298>,
    <10116, 9298, 9140>,
    <10116, 9140, 10107>,
    <10116, 10107, 10106>,
    <10116, 10106, 10117>,
    <10120, 10121, 10118>,
    <10120, 10118, 10117>,
    <10120, 10117, 10106>,
    <10120, 10106, 10115>,
    <10120, 10115, 10114>,
    <10120, 10114, 10122>,
    <10120, 10122, 10123>,
    <10120, 10123, 10121>,
    <10124, 10119, 10118>,
    <10124, 10118, 10121>,
    <10124, 10121, 10123>,
    <10124, 10123, 10125>,
    <10124, 10125, 9302>,
    <10124, 9302, 9301>,
    <10124, 9301, 9299>,
    <10124, 9299, 10119>,
    <10126, 10127, 10128>,
    <10126, 10128, 10129>,
    <10126, 10129, 10130>,
    <10126, 10130, 10131>,
    <10126, 10131, 10132>,
    <10126, 10132, 10133>,
    <10126, 10133, 10134>,
    <10126, 10134, 10127>,
    <10135, 10136, 10128>,
    <10135, 10128, 10127>,
    <10135, 10127, 10134>,
    <10135, 10134, 10137>,
    <10135, 10137, 9320>,
    <10135, 9320, 9381>,
    <10135, 9381, 9380>,
    <10135, 9380, 10136>,
    <10138, 10129, 10128>,
    <10138, 10128, 10136>,
    <10138, 10136, 9380>,
    <10138, 9380, 9385>,
    <10138, 9385, 9368>,
    <10138, 9368, 10139>,
    <10138, 10139, 10130>,
    <10138, 10130, 10129>,
    <10140, 10141, 10142>,
    <10140, 10142, 10143>,
    <10140, 10143, 10144>,
    <10140, 10144, 10145>,
    <10140, 10145, 9988>,
    <10140, 9988, 9987>,
    <10140, 9987, 9986>,
    <10140, 9986, 10141>,
    <10146, 10147, 10142>,
    <10146, 10142, 10141>,
    <10146, 10141, 9986>,
    <10146, 9986, 9995>,
    <10146, 9995, 9320>,
    <10146, 9320, 10137>,
    <10146, 10137, 10134>,
    <10146, 10134, 10147>,
    <10148, 10143, 10142>,
    <10148, 10142, 10147>,
    <10148, 10147, 10134>,
    <10148, 10134, 10133>,
    <10148, 10133, 10132>,
    <10148, 10132, 10149>,
    <10148, 10149, 10144>,
    <10148, 10144, 10143>,
    <10150, 10151, 10152>,
    <10150, 10152, 10153>,
    <10150, 10153, 10154>,
    <10150, 10154, 10155>,
    <10150, 10155, 9302>,
    <10150, 9302, 10125>,
    <10150, 10125, 10123>,
    <10150, 10123, 10151>,
    <10156, 10157, 10152>,
    <10156, 10152, 10151>,
    <10156, 10151, 10123>,
    <10156, 10123, 10122>,
    <10156, 10122, 10114>,
    <10156, 10114, 10158>,
    <10156, 10158, 10159>,
    <10156, 10159, 10157>,
    <10160, 10153, 10152>,
    <10160, 10152, 10157>,
    <10160, 10157, 10159>,
    <10160, 10159, 10161>,
    <10160, 10161, 10162>,
    <10160, 10162, 10163>,
    <10160, 10163, 10154>,
    <10160, 10154, 10153>,
    <10164, 10165, 10166>,
    <10164, 10166, 10167>,
    <10164, 10167, 9347>,
    <10164, 9347, 9346>,
    <10164, 9346, 9302>,
    <10164, 9302, 10155>,
    <10164, 10155, 10154>,
    <10164, 10154, 10165>,
    <10168, 10169, 10166>,
    <10168, 10166, 10165>,
    <10168, 10165, 10154>,
    <10168, 10154, 10163>,
    <10168, 10163, 10162>,
    <10168, 10162, 10170>,
    <10168, 10170, 10171>,
    <10168, 10171, 10169>,
    <10172, 10167, 10166>,
    <10172, 10166, 10169>,
    <10172, 10169, 10171>,
    <10172, 10171, 10173>,
    <10172, 10173, 9350>,
    <10172, 9350, 9349>,
    <10172, 9349, 9347>,
    <10172, 9347, 10167>,
    <10174, 10175, 10176>,
    <10174, 10176, 10177>,
    <10174, 10177, 10178>,
    <10174, 10178, 10179>,
    <10174, 10179, 10180>,
    <10174, 10180, 10181>,
    <10174, 10181, 10182>,
    <10174, 10182, 10175>,
    <10183, 10184, 10176>,
    <10183, 10176, 10175>,
    <10183, 10175, 10182>,
    <10183, 10182, 10185>,
    <10183, 10185, 9368>,
    <10183, 9368, 9411>,
    <10183, 9411, 9410>,
    <10183, 9410, 10184>,
    <10186, 10177, 10176>,
    <10186, 10176, 10184>,
    <10186, 10184, 9410>,
    <10186, 9410, 9415>,
    <10186, 9415, 1305>,
    <10186, 1305, 10187>,
    <10186, 10187, 10178>,
    <10186, 10178, 10177>,
    <10188, 10189, 10190>,
    <10188, 10190, 10191>,
    <10188, 10191, 10192>,
    <10188, 10192, 10193>,
    <10188, 10193, 10132>,
    <10188, 10132, 10131>,
    <10188, 10131, 10130>,
    <10188, 10130, 10189>,
    <10194, 10195, 10190>,
    <10194, 10190, 10189>,
    <10194, 10189, 10130>,
    <10194, 10130, 10139>,
    <10194, 10139, 9368>,
    <10194, 9368, 10185>,
    <10194, 10185, 10182>,
    <10194, 10182, 10195>,
    <10196, 10191, 10190>,
    <10196, 10190, 10195>,
    <10196, 10195, 10182>,
    <10196, 10182, 10181>,
    <10196, 10181, 10180>,
    <10196, 10180, 10197>,
    <10196, 10197, 10192>,
    <10196, 10192, 10191>,
    <10198, 10199, 10200>,
    <10198, 10200, 10201>,
    <10198, 10201, 10202>,
    <10198, 10202, 10203>,
    <10198, 10203, 9350>,
    <10198, 9350, 10173>,
    <10198, 10173, 10171>,
    <10198, 10171, 10199>,
    <10204, 10205, 10200>,
    <10204, 10200, 10199>,
    <10204, 10199, 10171>,
    <10204, 10171, 10170>,
    <10204, 10170, 10162>,
    <10204, 10162, 10206>,
    <10204, 10206, 10207>,
    <10204, 10207, 10205>,
    <10208, 10201, 10200>,
    <10208, 10200, 10205>,
    <10208, 10205, 10207>,
    <10208, 10207, 10209>,
    <10208, 10209, 1525>,
    <10208, 1525, 10210>,
    <10208, 10210, 10202>,
    <10208, 10202, 10201>,
    <10211, 10212, 10213>,
    <10211, 10213, 10214>,
    <10211, 10214, 9395>,
    <10211, 9395, 9394>,
    <10211, 9394, 9350>,
    <10211, 9350, 10203>,
    <10211, 10203, 10202>,
    <10211, 10202, 10212>,
    <10215, 10216, 10213>,
    <10215, 10213, 10212>,
    <10215, 10212, 10202>,
    <10215, 10202, 10210>,
    <10215, 10210, 1525>,
    <10215, 1525, 1562>,
    <10215, 1562, 1560>,
    <10215, 1560, 10216>,
    <10217, 10214, 10213>,
    <10217, 10213, 10216>,
    <10217, 10216, 1560>,
    <10217, 1560, 1559>,
    <10217, 1559, 1254>,
    <10217, 1254, 9397>,
    <10217, 9397, 9395>,
    <10217, 9395, 10214>,
    <10218, 10219, 10220>,
    <10218, 10220, 10221>,
    <10218, 10221, 10222>,
    <10218, 10222, 10223>,
    <10218, 10223, 10180>,
    <10218, 10180, 10179>,
    <10218, 10179, 10178>,
    <10218, 10178, 10219>,
    <10224, 10225, 10220>,
    <10224, 10220, 10219>,
    <10224, 10219, 10178>,
    <10224, 10178, 10187>,
    <10224, 10187, 1305>,
    <10224, 1305, 1595>,
    <10224, 1595, 1593>,
    <10224, 1593, 10225>,
    <10226, 10221, 10220>,
    <10226, 10220, 10225>,
    <10226, 10225, 1593>,
    <10226, 1593, 1592>,
    <10226, 1592, 1576>,
    <10226, 1576, 10227>,
    <10226, 10227, 10222>,
    <10226, 10222, 10221>,
    <10228, 10229, 10230>,
    <10228, 10230, 10231>,
    <10228, 10231, 10232>,
    <10228, 10232, 10233>,
    <10228, 10233, 10234>,
    <10228, 10234, 10235>,
    <10228, 10236, 10237>,
    <10228, 10237, 10229>,
    <10238, 10239, 10230>,
    <10238, 10230, 10229>,
    <10238, 10229, 10240>,
    <10238, 10240, 10241>,
    <10238, 10242, 10243>,
    <10238, 10243, 9469>,
    <10238, 9469, 9467>,
    <10238, 9467, 10239>,
    <10244, 10231, 10230>,
    <10244, 10230, 10239>,
    <10244, 10239, 9467>,
    <10244, 9467, 9466>,
    <10244, 9466, 9465>,
    <10244, 9465, 10245>,
    <10244, 10245, 10232>,
    <10244, 10232, 10231>,
    <10246, 10247, 10248>,
    <10246, 10248, 10249>,
    <10246, 10249, 10250>,
    <10246, 10250, 10251>,
    <10246, 10252, 10253>,
    <10246, 10253, 10254>,
    <10246, 10254, 10255>,
    <10246, 10255, 10247>,
    <10256, 10257, 10248>,
    <10256, 10248, 10247>,
    <10256, 10247, 10255>,
    <10256, 10255, 10258>,
    <10256, 10258, 9495>,
    <10256, 9495, 9527>,
    <10256, 9527, 9525>,
    <10256, 9525, 10257>,
    <10259, 10249, 10248>,
    <10259, 10248, 10257>,
    <10259, 10257, 9525>,
    <10259, 9525, 9524>,
    <10259, 9524, 10260>,
    <10259, 10260, 10261>,
    <10259, 10262, 10263>,
    <10259, 10263, 10249>,
    <10264, 10265, 10266>,
    <10264, 10266, 10267>,
    <10264, 10267, 10268>,
    <10264, 10268, 10269>,
    <10264, 10269, 10270>,
    <10264, 10270, 10271>,
    <10264, 10272, 10273>,
    <10264, 10273, 10265>,
    <10274, 10275, 10266>,
    <10274, 10266, 10265>,
    <10274, 10265, 10276>,
    <10274, 10276, 10277>,
    <10274, 10278, 10279>,
    <10274, 10279, 9664>,
    <10274, 9664, 9663>,
    <10274, 9663, 10275>,
    <10280, 10267, 10266>,
    <10280, 10266, 10275>,
    <10280, 10275, 9663>,
    <10280, 9663, 9669>,
    <10280, 9669, 9651>,
    <10280, 9651, 10281>,
    <10280, 10281, 10268>,
    <10280, 10268, 10267>,
    <10282, 10283, 10284>,
    <10282, 10284, 10285>,
    <10282, 10285, 10286>,
    <10282, 10286, 10287>,
    <10282, 10288, 10289>,
    <10282, 10289, 10290>,
    <10282, 10290, 10291>,
    <10282, 10291, 10283>,
    <10292, 10293, 10284>,
    <10292, 10284, 10283>,
    <10292, 10283, 10291>,
    <10292, 10291, 10294>,
    <10292, 10294, 10295>,
    <10292, 10295, 10296>,
    <10292, 10296, 10297>,
    <10292, 10297, 10293>,
    <10298, 10285, 10284>,
    <10298, 10284, 10293>,
    <10298, 10293, 10297>,
    <10298, 10297, 10299>,
    <10298, 10299, 10300>,
    <10298, 10300, 10301>,
    <10298, 10302, 10303>,
    <10298, 10303, 10285>,
    <10304, 10305, 10306>,
    <10304, 10306, 10307>,
    <10304, 10307, 10291>,
    <10304, 10291, 10290>,
    <10304, 10290, 10308>,
    <10304, 10308, 10309>,
    <10304, 10310, 10311>,
    <10304, 10311, 10305>,
    <10312, 10313, 10306>,
    <10312, 10306, 10305>,
    <10312, 10305, 10314>,
    <10312, 10314, 10315>,
    <10312, 10316, 10317>,
    <10312, 10317, 10318>,
    <10312, 10318, 10319>,
    <10312, 10319, 10313>,
    <10320, 10307, 10306>,
    <10320, 10306, 10313>,
    <10320, 10313, 10319>,
    <10320, 10319, 10321>,
    <10320, 10321, 10295>,
    <10320, 10295, 10294>,
    <10320, 10294, 10291>,
    <10320, 10291, 10307>,
    <10322, 10323, 10324>,
    <10322, 10324, 10325>,
    <10322, 10325, 10319>,
    <10322, 10319, 10318>,
    <10322, 10318, 10326>,
    <10322, 10326, 10233>,
    <10322, 10233, 10232>,
    <10322, 10232, 10323>,
    <10327, 10328, 10324>,
    <10327, 10324, 10323>,
    <10327, 10323, 10232>,
    <10327, 10232, 10245>,
    <10327, 10245, 9465>,
    <10327, 9465, 10329>,
    <10327, 10329, 10330>,
    <10327, 10330, 10328>,
    <10331, 10325, 10324>,
    <10331, 10324, 10328>,
    <10331, 10328, 10330>,
    <10331, 10330, 10332>,
    <10331, 10332, 10295>,
    <10331, 10295, 10321>,
    <10331, 10321, 10319>,
    <10331, 10319, 10325>,
    <10333, 10334, 10335>,
    <10333, 10335, 10336>,
    <10333, 10336, 10255>,
    <10333, 10255, 10254>,
    <10333, 10254, 10337>,
    <10333, 10337, 10338>,
    <10333, 10338, 10339>,
    <10333, 10339, 10334>,
    <10340, 10341, 10335>,
    <10340, 10335, 10334>,
    <10340, 10334, 10339>,
    <10340, 10339, 10342>,
    <10340, 10342, 10343>,
    <10340, 10343, 10344>,
    <10340, 10344, 10345>,
    <10340, 10345, 10341>,
    <10346, 10336, 10335>,
    <10346, 10335, 10341>,
    <10346, 10341, 10345>,
    <10346, 10345, 10347>,
    <10346, 10347, 9495>,
    <10346, 9495, 10258>,
    <10346, 10258, 10255>,
    <10346, 10255, 10336>,
    <10348, 10349, 10350>,
    <10348, 10350, 10351>,
    <10348, 10351, 10339>,
    <10348, 10339, 10338>,
    <10348, 10338, 10352>,
    <10348, 10352, 10353>,
    <10348, 10354, 10355>,
    <10348, 10355, 10349>,
    <10356, 10357, 10350>,
    <10356, 10350, 10349>,
    <10356, 10349, 10358>,
    <10356, 10358, 10359>,
    <10356, 10360, 10361>,
    <10356, 10361, 10362>,
    <10356, 10362, 10363>,
    <10356, 10363, 10357>,
    <10364, 10351, 10350>,
    <10364, 10350, 10357>,
    <10364, 10357, 10363>,
    <10364, 10363, 10365>,
    <10364, 10365, 10343>,
    <10364, 10343, 10342>,
    <10364, 10342, 10339>,
    <10364, 10339, 10351>,
    <10366, 10367, 10368>,
    <10366, 10368, 10369>,
    <10366, 10369, 10345>,
    <10366, 10345, 10344>,
    <10366, 10344, 10343>,
    <10366, 10343, 10370>,
    <10366, 10370, 10371>,
    <10366, 10371, 10367>,
    <10372, 10373, 10368>,
    <10372, 10368, 10367>,
    <10372, 10367, 10371>,
    <10372, 10371, 10374>,
    <10372, 10374, 9576>,
    <10372, 9576, 9592>,
    <10372, 9592, 9589>,
    <10372, 9589, 10373>,
    <10375, 10369, 10368>,
    <10375, 10368, 10373>,
    <10375, 10373, 9589>,
    <10375, 9589, 9588>,
    <10375, 9588, 9495>,
    <10375, 9495, 10347>,
    <10375, 10347, 10345>,
    <10375, 10345, 10369>,
    <10376, 10377, 10378>,
    <10376, 10378, 10379>,
    <10376, 10379, 10363>,
    <10376, 10363, 10362>,
    <10376, 10362, 10380>,
    <10376, 10380, 10381>,
    <10376, 10382, 10383>,
    <10376, 10383, 10377>,
    <10384, 10385, 10378>,
    <10384, 10378, 10377>,
    <10384, 10377, 10386>,
    <10384, 10386, 10387>,
    <10384, 10388, 10389>,
    <10384, 10389, 10390>,
    <10384, 10390, 10391>,
    <10384, 10391, 10385>,
    <10392, 10379, 10378>,
    <10392, 10378, 10385>,
    <10392, 10385, 10391>,
    <10392, 10391, 10393>,
    <10392, 10393, 10343>,
    <10392, 10343, 10365>,
    <10392, 10365, 10363>,
    <10392, 10363, 10379>,
    <10394, 10395, 10396>,
    <10394, 10396, 10397>,
    <10394, 10397, 10398>,
    <10394, 10398, 10399>,
    <10394, 10399, 10400>,
    <10394, 10400, 10401>,
    <10394, 10402, 10403>,
    <10394, 10403, 10395>,
    <10404, 10405, 10396>,
    <10404, 10396, 10395>,
    <10404, 10395, 10406>,
    <10404, 10406, 10407>,
    <10404, 10408, 10409>,
    <10404, 10409, 10269>,
    <10404, 10269, 10268>,
    <10404, 10268, 10405>,
    <10410, 10397, 10396>,
    <10410, 10396, 10405>,
    <10410, 10405, 10268>,
    <10410, 10268, 10281>,
    <10410, 10281, 9651>,
    <10410, 9651, 10411>,
    <10410, 10411, 10398>,
    <10410, 10398, 10397>,
    <10412, 10413, 10414>,
    <10412, 10414, 10415>,
    <10412, 10415, 10330>,
    <10412, 10330, 10329>,
    <10412, 10329, 9465>,
    <10412, 9465, 10416>,
    <10412, 10416, 10417>,
    <10412, 10417, 10413>,
    <10418, 10419, 10414>,
    <10418, 10414, 10413>,
    <10418, 10413, 10417>,
    <10418, 10417, 10420>,
    <10418, 10420, 10421>,
    <10418, 10421, 10422>,
    <10418, 10422, 10423>,
    <10418, 10423, 10419>,
    <10424, 10415, 10414>,
    <10424, 10414, 10419>,
    <10424, 10419, 10423>,
    <10424, 10423, 10425>,
    <10424, 10425, 10295>,
    <10424, 10295, 10332>,
    <10424, 10332, 10330>,
    <10424, 10330, 10415>,
    <10426, 10427, 10428>,
    <10426, 10428, 10429>,
    <10426, 10429, 10417>,
    <10426, 10417, 10416>,
    <10426, 10416, 9465>,
    <10426, 9465, 9559>,
    <10426, 9559, 9557>,
    <10426, 9557, 10427>,
    <10430, 10431, 10428>,
    <10430, 10428, 10427>,
    <10430, 10427, 9557>,
    <10430, 9557, 9556>,
    <10430, 9556, 9555>,
    <10430, 9555, 10432>,
    <10430, 10432, 10433>,
    <10430, 10433, 10431>,
    <10434, 10429, 10428>,
    <10434, 10428, 10431>,
    <10434, 10431, 10433>,
    <10434, 10433, 10435>,
    <10434, 10435, 10421>,
    <10434, 10421, 10420>,
    <10434, 10420, 10417>,
    <10434, 10417, 10429>,
    <10436, 10437, 10438>,
    <10436, 10438, 10439>,
    <10436, 10439, 10440>,
    <10436, 10440, 10441>,
    <10436, 10441, 10442>,
    <10436, 10442, 10443>,
    <10436, 10443, 10444>,
    <10436, 10444, 10437>,
    <10445, 10446, 10438>,
    <10445, 10438, 10437>,
    <10445, 10437, 10444>,
    <10445, 10444, 10447>,
    <10445, 10447, 9700>,
    <10445, 9700, 9716>,
    <10445, 9716, 9713>,
    <10445, 9713, 10446>,
    <10448, 10439, 10438>,
    <10448, 10438, 10446>,
    <10448, 10446, 9713>,
    <10448, 9713, 9712>,
    <10448, 9712, 9576>,
    <10448, 9576, 10449>,
    <10448, 10449, 10440>,
    <10448, 10440, 10439>,
    <10450, 10451, 10452>,
    <10450, 10452, 10453>,
    <10450, 10453, 10371>,
    <10450, 10371, 10370>,
    <10450, 10370, 10343>,
    <10450, 10343, 10454>,
    <10450, 10454, 10455>,
    <10450, 10455, 10451>,
    <10456, 10457, 10452>,
    <10456, 10452, 10451>,
    <10456, 10451, 10455>,
    <10456, 10455, 10458>,
    <10456, 10458, 10442>,
    <10456, 10442, 10441>,
    <10456, 10441, 10440>,
    <10456, 10440, 10457>,
    <10459, 10453, 10452>,
    <10459, 10452, 10457>,
    <10459, 10457, 10440>,
    <10459, 10440, 10449>,
    <10459, 10449, 9576>,
    <10459, 9576, 10374>,
    <10459, 10374, 10371>,
    <10459, 10371, 10453>,
    <10460, 10461, 10462>,
    <10460, 10462, 10463>,
    <10460, 10463, 10464>,
    <10460, 10464, 10465>,
    <10460, 10465, 10466>,
    <10460, 10466, 10467>,
    <10460, 10468, 10469>,
    <10460, 10469, 10461>,
    <10470, 10471, 10462>,
    <10470, 10462, 10461>,
    <10470, 10461, 10472>,
    <10470, 10472, 10473>,
    <10470, 10474, 10475>,
    <10470, 10475, 10476>,
    <10470, 10476, 10477>,
    <10470, 10477, 10471>,
    <10478, 10463, 10462>,
    <10478, 10462, 10471>,
    <10478, 10471, 10477>,
    <10478, 10477, 10479>,
    <10478, 10479, 10480>,
    <10478, 10480, 10481>,
    <10478, 10481, 10464>,
    <10478, 10464, 10463>,
    <10482, 10483, 10484>,
    <10482, 10484, 10485>,
    <10482, 10485, 10486>,
    <10482, 10486, 10487>,
    <10482, 10487, 10488>,
    <10482, 10488, 10489>,
    <10482, 10490, 10491>,
    <10482, 10491, 10483>,
    <10492, 10493, 10484>,
    <10492, 10484, 10483>,
    <10492, 10483, 10494>,
    <10492, 10494, 10495>,
    <10492, 10496, 10497>,
    <10492, 10497, 10465>,
    <10492, 10465, 10464>,
    <10492, 10464, 10493>,
    <10498, 10485, 10484>,
    <10498, 10484, 10493>,
    <10498, 10493, 10464>,
    <10498, 10464, 10481>,
    <10498, 10481, 10480>,
    <10498, 10480, 10499>,
    <10498, 10499, 10486>,
    <10498, 10486, 10485>,
    <10500, 10501, 10502>,
    <10500, 10502, 10503>,
    <10500, 10503, 9611>,
    <10500, 9611, 9610>,
    <10500, 9610, 10504>,
    <10500, 10504, 10487>,
    <10500, 10487, 10486>,
    <10500, 10486, 10501>,
    <10505, 10506, 10502>,
    <10505, 10502, 10501>,
    <10505, 10501, 10486>,
    <10505, 10486, 10499>,
    <10505, 10499, 10480>,
    <10505, 10480, 10507>,
    <10505, 10507, 10508>,
    <10505, 10508, 10506>,
    <10509, 10503, 10502>,
    <10509, 10502, 10506>,
    <10509, 10506, 10508>,
    <10509, 10508, 10510>,
    <10509, 10510, 9614>,
    <10509, 9614, 9613>,
    <10509, 9613, 9611>,
    <10509, 9611, 10503>,
    <10511, 10512, 10513>,
    <10511, 10513, 10514>,
    <10511, 10514, 10515>,
    <10511, 10515, 10516>,
    <10511, 10516, 10517>,
    <10511, 10517, 10518>,
    <10511, 10518, 10519>,
    <10511, 10519, 10512>,
    <10520, 10521, 10513>,
    <10520, 10513, 10512>,
    <10520, 10512, 10519>,
    <10520, 10519, 10522>,
    <10520, 10522, 9651>,
    <10520, 9651, 9761>,
    <10520, 9761, 9760>,
    <10520, 9760, 10521>,
    <10523, 10514, 10513>,
    <10523, 10513, 10521>,
    <10523, 10521, 9760>,
    <10523, 9760, 9765>,
    <10523, 9765, 9748>,
    <10523, 9748, 10524>,
    <10523, 10524, 10515>,
    <10523, 10515, 10514>,
    <10525, 10526, 10527>,
    <10525, 10527, 10528>,
    <10525, 10528, 10529>,
    <10525, 10529, 10530>,
    <10525, 10530, 10531>,
    <10525, 10531, 10399>,
    <10525, 10399, 10398>,
    <10525, 10398, 10526>,
    <10532, 10533, 10527>,
    <10532, 10527, 10526>,
    <10532, 10526, 10398>,
    <10532, 10398, 10411>,
    <10532, 10411, 9651>,
    <10532, 9651, 10522>,
    <10532, 10522, 10519>,
    <10532, 10519, 10533>,
    <10534, 10528, 10527>,
    <10534, 10527, 10533>,
    <10534, 10533, 10519>,
    <10534, 10519, 10518>,
    <10534, 10518, 10517>,
    <10534, 10517, 10535>,
    <10534, 10535, 10529>,
    <10534, 10529, 10528>,
    <10536, 10537, 10538>,
    <10536, 10538, 10539>,
    <10536, 10539, 10433>,
    <10536, 10433, 10432>,
    <10536, 10432, 9555>,
    <10536, 9555, 10540>,
    <10536, 10540, 10541>,
    <10536, 10541, 10537>,
    <10542, 10543, 10538>,
    <10542, 10538, 10537>,
    <10542, 10537, 10541>,
    <10542, 10541, 10544>,
    <10542, 10544, 10545>,
    <10542, 10545, 10546>,
    <10542, 10546, 10547>,
    <10542, 10547, 10543>,
    <10548, 10539, 10538>,
    <10548, 10538, 10543>,
    <10548, 10543, 10547>,
    <10548, 10547, 10549>,
    <10548, 10549, 10421>,
    <10548, 10421, 10435>,
    <10548, 10435, 10433>,
    <10548, 10433, 10539>,
    <10550, 10551, 10552>,
    <10550, 10552, 10553>,
    <10550, 10553, 10541>,
    <10550, 10541, 10540>,
    <10550, 10540, 9555>,
    <10550, 9555, 9683>,
    <10550, 9683, 9681>,
    <10550, 9681, 10551>,
    <10554, 10555, 10552>,
    <10554, 10552, 10551>,
    <10554, 10551, 9681>,
    <10554, 9681, 9680>,
    <10554, 9680, 9679>,
    <10554, 9679, 10556>,
    <10554, 10556, 10557>,
    <10554, 10557, 10555>,
    <10558, 10553, 10552>,
    <10558, 10552, 10555>,
    <10558, 10555, 10557>,
    <10558, 10557, 10559>,
    <10558, 10559, 10545>,
    <10558, 10545, 10544>,
    <10558, 10544, 10541>,
    <10558, 10541, 10553>,
    <10560, 10561, 10562>,
    <10560, 10562, 10563>,
    <10560, 10563, 10564>,
    <10560, 10564, 10565>,
    <10560, 10565, 10566>,
    <10560, 10566, 10567>,
    <10560, 10567, 10568>,
    <10560, 10568, 10561>,
    <10569, 10570, 10562>,
    <10569, 10562, 10561>,
    <10569, 10561, 10568>,
    <10569, 10568, 10571>,
    <10569, 10571, 9796>,
    <10569, 9796, 9812>,
    <10569, 9812, 9809>,
    <10569, 9809, 10570>,
    <10572, 10563, 10562>,
    <10572, 10562, 10570>,
    <10572, 10570, 9809>,
    <10572, 9809, 9808>,
    <10572, 9808, 9700>,
    <10572, 9700, 10573>,
    <10572, 10573, 10564>,
    <10572, 10564, 10563>,
    <10574, 10575, 10576>,
    <10574, 10576, 10577>,
    <10574, 10577, 10444>,
    <10574, 10444, 10443>,
    <10574, 10443, 10442>,
    <10574, 10442, 10578>,
    <10574, 10578, 10579>,
    <10574, 10579, 10575>,
    <10580, 10581, 10576>,
    <10580, 10576, 10575>,
    <10580, 10575, 10579>,
    <10580, 10579, 10582>,
    <10580, 10582, 10566>,
    <10580, 10566, 10565>,
    <10580, 10565, 10564>,
    <10580, 10564, 10581>,
    <10583, 10577, 10576>,
    <10583, 10576, 10581>,
    <10583, 10581, 10564>,
    <10583, 10564, 10573>,
    <10583, 10573, 9700>,
    <10583, 9700, 10447>,
    <10583, 10447, 10444>,
    <10583, 10444, 10577>,
    <10584, 10585, 10586>,
    <10584, 10586, 10587>,
    <10584, 10587, 10588>,
    <10584, 10588, 10589>,
    <10584, 10589, 9614>,
    <10584, 9614, 10510>,
    <10584, 10510, 10508>,
    <10584, 10508, 10585>,
    <10590, 10591, 10586>,
    <10590, 10586, 10585>,
    <10590, 10585, 10508>,
    <10590, 10508, 10507>,
    <10590, 10507, 10480>,
    <10590, 10480, 10592>,
    <10590, 10592, 10593>,
    <10590, 10593, 10591>,
    <10594, 10587, 10586>,
    <10594, 10586, 10591>,
    <10594, 10591, 10593>,
    <10594, 10593, 10595>,
    <10594, 10595, 10596>,
    <10594, 10596, 10597>,
    <10594, 10597, 10588>,
    <10594, 10588, 10587>,
    <10598, 10599, 10600>,
    <10598, 10600, 10601>,
    <10598, 10601, 9727>,
    <10598, 9727, 9726>,
    <10598, 9726, 9614>,
    <10598, 9614, 10589>,
    <10598, 10589, 10588>,
    <10598, 10588, 10599>,
    <10602, 10603, 10600>,
    <10602, 10600, 10599>,
    <10602, 10599, 10588>,
    <10602, 10588, 10597>,
    <10602, 10597, 10596>,
    <10602, 10596, 10604>,
    <10602, 10604, 10605>,
    <10602, 10605, 10603>,
    <10606, 10601, 10600>,
    <10606, 10600, 10603>,
    <10606, 10603, 10605>,
    <10606, 10605, 10607>,
    <10606, 10607, 9730>,
    <10606, 9730, 9729>,
    <10606, 9729, 9727>,
    <10606, 9727, 10601>,
    <10608, 10609, 10610>,
    <10608, 10610, 10611>,
    <10608, 10611, 10612>,
    <10608, 10612, 10613>,
    <10608, 10613, 10614>,
    <10608, 10614, 10615>,
    <10608, 10615, 10616>,
    <10608, 10616, 10609>,
    <10617, 10618, 10610>,
    <10617, 10610, 10609>,
    <10617, 10609, 10616>,
    <10617, 10616, 10619>,
    <10617, 10619, 9748>,
    <10617, 9748, 9857>,
    <10617, 9857, 9856>,
    <10617, 9856, 10618>,
    <10620, 10611, 10610>,
    <10620, 10610, 10618>,
    <10620, 10618, 9856>,
    <10620, 9856, 9861>,
    <10620, 9861, 9844>,
    <10620, 9844, 10621>,
    <10620, 10621, 10612>,
    <10620, 10612, 10611>,
    <10622, 10623, 10624>,
    <10622, 10624, 10625>,
    <10622, 10625, 10626>,
    <10622, 10626, 10627>,
    <10622, 10627, 10517>,
    <10622, 10517, 10516>,
    <10622, 10516, 10515>,
    <10622, 10515, 10623>,
    <10628, 10629, 10624>,
    <10628, 10624, 10623>,
    <10628, 10623, 10515>,
    <10628, 10515, 10524>,
    <10628, 10524, 9748>,
    <10628, 9748, 10619>,
    <10628, 10619, 10616>,
    <10628, 10616, 10629>,
    <10630, 10625, 10624>,
    <10630, 10624, 10629>,
    <10630, 10629, 10616>,
    <10630, 10616, 10615>,
    <10630, 10615, 10614>,
    <10630, 10614, 10631>,
    <10630, 10631, 10626>,
    <10630, 10626, 10625>,
    <10632, 10633, 10634>,
    <10632, 10634, 10635>,
    <10632, 10635, 10557>,
    <10632, 10557, 10556>,
    <10632, 10556, 9679>,
    <10632, 9679, 10636>,
    <10632, 10636, 10637>,
    <10632, 10637, 10633>,
    <10638, 10639, 10634>,
    <10638, 10634, 10633>,
    <10638, 10633, 10637>,
    <10638, 10637, 10640>,
    <10638, 10640, 10641>,
    <10638, 10641, 10642>,
    <10638, 10642, 10643>,
    <10638, 10643, 10639>,
    <10644, 10635, 10634>,
    <10644, 10634, 10639>,
    <10644, 10639, 10643>,
    <10644, 10643, 10645>,
    <10644, 10645, 10545>,
    <10644, 10545, 10559>,
    <10644, 10559, 10557>,
    <10644, 10557, 10635>,
    <10646, 10647, 10648>,
    <10646, 10648, 10649>,
    <10646, 10649, 10637>,
    <10646, 10637, 10636>,
    <10646, 10636, 9679>,
    <10646, 9679, 9779>,
    <10646, 9779, 9777>,
    <10646, 9777, 10647>,
    <10650, 10651, 10648>,
    <10650, 10648, 10647>,
    <10650, 10647, 9777>,
    <10650, 9777, 9776>,
    <10650, 9776, 9775>,
    <10650, 9775, 10652>,
    <10650, 10652, 10653>,
    <10650, 10653, 10651>,
    <10654, 10649, 10648>,
    <10654, 10648, 10651>,
    <10654, 10651, 10653>,
    <10654, 10653, 10655>,
    <10654, 10655, 10641>,
    <10654, 10641, 10640>,
    <10654, 10640, 10637>,
    <10654, 10637, 10649>,
    <10656, 10657, 10658>,
    <10656, 10658, 10659>,
    <10656, 10659, 10660>,
    <10656, 10660, 10661>,
    <10656, 10661, 10662>,
    <10656, 10662, 10663>,
    <10656, 10663, 10664>,
    <10656, 10664, 10657>,
    <10665, 10666, 10658>,
    <10665, 10658, 10657>,
    <10665, 10657, 10664>,
    <10665, 10664, 10667>,
    <10665, 10667, 9892>,
    <10665, 9892, 9908>,
    <10665, 9908, 9905>,
    <10665, 9905, 10666>,
    <10668, 10659, 10658>,
    <10668, 10658, 10666>,
    <10668, 10666, 9905>,
    <10668, 9905, 9904>,
    <10668, 9904, 9796>,
    <10668, 9796, 10669>,
    <10668, 10669, 10660>,
    <10668, 10660, 10659>,
    <10670, 10671, 10672>,
    <10670, 10672, 10673>,
    <10670, 10673, 10568>,
    <10670, 10568, 10567>,
    <10670, 10567, 10566>,
    <10670, 10566, 10674>,
    <10670, 10674, 10675>,
    <10670, 10675, 10671>,
    <10676, 10677, 10672>,
    <10676, 10672, 10671>,
    <10676, 10671, 10675>,
    <10676, 10675, 10678>,
    <10676, 10678, 10662>,
    <10676, 10662, 10661>,
    <10676, 10661, 10660>,
    <10676, 10660, 10677>,
    <10679, 10673, 10672>,
    <10679, 10672, 10677>,
    <10679, 10677, 10660>,
    <10679, 10660, 10669>,
    <10679, 10669, 9796>,
    <10679, 9796, 10571>,
    <10679, 10571, 10568>,
    <10679, 10568, 10673>,
    <10680, 10681, 10682>,
    <10680, 10682, 10683>,
    <10680, 10683, 10684>,
    <10680, 10684, 10685>,
    <10680, 10685, 9730>,
    <10680, 9730, 10607>,
    <10680, 10607, 10605>,
    <10680, 10605, 10681>,
    <10686, 10687, 10682>,
    <10686, 10682, 10681>,
    <10686, 10681, 10605>,
    <10686, 10605, 10604>,
    <10686, 10604, 10596>,
    <10686, 10596, 10688>,
    <10686, 10688, 10689>,
    <10686, 10689, 10687>,
    <10690, 10683, 10682>,
    <10690, 10682, 10687>,
    <10690, 10687, 10689>,
    <10690, 10689, 10691>,
    <10690, 10691, 10692>,
    <10690, 10692, 10693>,
    <10690, 10693, 10684>,
    <10690, 10684, 10683>,
    <10694, 10695, 10696>,
    <10694, 10696, 10697>,
    <10694, 10697, 9823>,
    <10694, 9823, 9822>,
    <10694, 9822, 9730>,
    <10694, 9730, 10685>,
    <10694, 10685, 10684>,
    <10694, 10684, 10695>,
    <10698, 10699, 10696>,
    <10698, 10696, 10695>,
    <10698, 10695, 10684>,
    <10698, 10684, 10693>,
    <10698, 10693, 10692>,
    <10698, 10692, 10700>,
    <10698, 10700, 10701>,
    <10698, 10701, 10699>,
    <10702, 10697, 10696>,
    <10702, 10696, 10699>,
    <10702, 10699, 10701>,
    <10702, 10701, 10703>,
    <10702, 10703, 9826>,
    <10702, 9826, 9825>,
    <10702, 9825, 9823>,
    <10702, 9823, 10697>,
    <10704, 10705, 10706>,
    <10704, 10706, 10707>,
    <10704, 10707, 10708>,
    <10704, 10708, 10709>,
    <10704, 10709, 10710>,
    <10704, 10710, 10711>,
    <10704, 10711, 10712>,
    <10704, 10712, 10705>,
    <10713, 10714, 10706>,
    <10713, 10706, 10705>,
    <10713, 10705, 10712>,
    <10713, 10712, 10715>,
    <10713, 10715, 9844>,
    <10713, 9844, 10001>,
    <10713, 10001, 10000>,
    <10713, 10000, 10714>,
    <10716, 10707, 10706>,
    <10716, 10706, 10714>,
    <10716, 10714, 10000>,
    <10716, 10000, 10005>,
    <10716, 10005, 9988>,
    <10716, 9988, 10717>,
    <10716, 10717, 10708>,
    <10716, 10708, 10707>,
    <10718, 10719, 10720>,
    <10718, 10720, 10721>,
    <10718, 10721, 10722>,
    <10718, 10722, 10723>,
    <10718, 10723, 10614>,
    <10718, 10614, 10613>,
    <10718, 10613, 10612>,
    <10718, 10612, 10719>,
    <10724, 10725, 10720>,
    <10724, 10720, 10719>,
    <10724, 10719, 10612>,
    <10724, 10612, 10621>,
    <10724, 10621, 9844>,
    <10724, 9844, 10715>,
    <10724, 10715, 10712>,
    <10724, 10712, 10725>,
    <10726, 10721, 10720>,
    <10726, 10720, 10725>,
    <10726, 10725, 10712>,
    <10726, 10712, 10711>,
    <10726, 10711, 10710>,
    <10726, 10710, 10727>,
    <10726, 10727, 10722>,
    <10726, 10722, 10721>,
    <10728, 10729, 10730>,
    <10728, 10730, 10731>,
    <10728, 10731, 10653>,
    <10728, 10653, 10652>,
    <10728, 10652, 9775>,
    <10728, 9775, 10732>,
    <10728, 10732, 10733>,
    <10728, 10733, 10729>,
    <10734, 10735, 10730>,
    <10734, 10730, 10729>,
    <10734, 10729, 10733>,
    <10734, 10733, 10736>,
    <10734, 10736, 10737>,
    <10734, 10737, 10738>,
    <10734, 10738, 10739>,
    <10734, 10739, 10735>,
    <10740, 10731, 10730>,
    <10740, 10730, 10735>,
    <10740, 10735, 10739>,
    <10740, 10739, 10741>,
    <10740, 10741, 10641>,
    <10740, 10641, 10655>,
    <10740, 10655, 10653>,
    <10740, 10653, 10731>,
    <10742, 10743, 10744>,
    <10742, 10744, 10745>,
    <10742, 10745, 10733>,
    <10742, 10733, 10732>,
    <10742, 10732, 9775>,
    <10742, 9775, 9875>,
    <10742, 9875, 9873>,
    <10742, 9873, 10743>,
    <10746, 10747, 10744>,
    <10746, 10744, 10743>,
    <10746, 10743, 9873>,
    <10746, 9873, 9872>,
    <10746, 9872, 9871>,
    <10746, 9871, 10748>,
    <10746, 10748, 10749>,
    <10746, 10749, 10747>,
    <10750, 10745, 10744>,
    <10750, 10744, 10747>,
    <10750, 10747, 10749>,
    <10750, 10749, 10751>,
    <10750, 10751, 10737>,
    <10750, 10737, 10736>,
    <10750, 10736, 10733>,
    <10750, 10733, 10745>,
    <10752, 10753, 10754>,
    <10752, 10754, 10755>,
    <10752, 10755, 10756>,
    <10752, 10756, 10757>,
    <10752, 10757, 10758>,
    <10752, 10758, 10759>,
    <10752, 10759, 10760>,
    <10752, 10760, 10753>,
    <10761, 10762, 10754>,
    <10761, 10754, 10753>,
    <10761, 10753, 10760>,
    <10761, 10760, 10763>,
    <10761, 10763, 9940>,
    <10761, 9940, 9956>,
    <10761, 9956, 9953>,
    <10761, 9953, 10762>,
    <10764, 10755, 10754>,
    <10764, 10754, 10762>,
    <10764, 10762, 9953>,
    <10764, 9953, 9952>,
    <10764, 9952, 9892>,
    <10764, 9892, 10765>,
    <10764, 10765, 10756>,
    <10764, 10756, 10755>,
    <10766, 10767, 10768>,
    <10766, 10768, 10769>,
    <10766, 10769, 10664>,
    <10766, 10664, 10663>,
    <10766, 10663, 10662>,
    <10766, 10662, 10770>,
    <10766, 10770, 10771>,
    <10766, 10771, 10767>,
    <10772, 10773, 10768>,
    <10772, 10768, 10767>,
    <10772, 10767, 10771>,
    <10772, 10771, 10774>,
    <10772, 10774, 10758>,
    <10772, 10758, 10757>,
    <10772, 10757, 10756>,
    <10772, 10756, 10773>,
    <10775, 10769, 10768>,
    <10775, 10768, 10773>,
    <10775, 10773, 10756>,
    <10775, 10756, 10765>,
    <10775, 10765, 9892>,
    <10775, 9892, 10667>,
    <10775, 10667, 10664>,
    <10775, 10664, 10769>,
    <10776, 10777, 10778>,
    <10776, 10778, 10779>,
    <10776, 10779, 10749>,
    <10776, 10749, 10748>,
    <10776, 10748, 9871>,
    <10776, 9871, 10780>,
    <10776, 10780, 10781>,
    <10776, 10781, 10777>,
    <10782, 10783, 10778>,
    <10782, 10778, 10777>,
    <10782, 10777, 10781>,
    <10782, 10781, 10784>,
    <10782, 10784, 10785>,
    <10782, 10785, 10786>,
    <10782, 10786, 10787>,
    <10782, 10787, 10783>,
    <10788, 10779, 10778>,
    <10788, 10778, 10783>,
    <10788, 10783, 10787>,
    <10788, 10787, 10789>,
    <10788, 10789, 10737>,
    <10788, 10737, 10751>,
    <10788, 10751, 10749>,
    <10788, 10749, 10779>,
    <10790, 10791, 10792>,
    <10790, 10792, 10793>,
    <10790, 10793, 10781>,
    <10790, 10781, 10780>,
    <10790, 10780, 9871>,
    <10790, 9871, 9923>,
    <10790, 9923, 9921>,
    <10790, 9921, 10791>,
    <10794, 10795, 10792>,
    <10794, 10792, 10791>,
    <10794, 10791, 9921>,
    <10794, 9921, 9920>,
    <10794, 9920, 9919>,
    <10794, 9919, 10796>,
    <10794, 10796, 10797>,
    <10794, 10797, 10795>,
    <10798, 10793, 10792>,
    <10798, 10792, 10795>,
    <10798, 10795, 10797>,
    <10798, 10797, 10799>,
    <10798, 10799, 10785>,
    <10798, 10785, 10784>,
    <10798, 10784, 10781>,
    <10798, 10781, 10793>,
    <10800, 10801, 10802>,
    <10800, 10802, 10803>,
    <10800, 10803, 10804>,
    <10800, 10804, 10805>,
    <10800, 10805, 10806>,
    <10800, 10806, 10807>,
    <10800, 10807, 10808>,
    <10800, 10808, 10801>,
    <10809, 10810, 10802>,
    <10809, 10802, 10801>,
    <10809, 10801, 10808>,
    <10809, 10808, 10811>,
    <10809, 10811, 10036>,
    <10809, 10036, 10053>,
    <10809, 10053, 10050>,
    <10809, 10050, 10810>,
    <10812, 10803, 10802>,
    <10812, 10802, 10810>,
    <10812, 10810, 10050>,
    <10812, 10050, 10049>,
    <10812, 10049, 9940>,
    <10812, 9940, 10813>,
    <10812, 10813, 10804>,
    <10812, 10804, 10803>,
    <10814, 10815, 10816>,
    <10814, 10816, 10817>,
    <10814, 10817, 10760>,
    <10814, 10760, 10759>,
    <10814, 10759, 10758>,
    <10814, 10758, 10818>,
    <10814, 10818, 10819>,
    <10814, 10819, 10815>,
    <10820, 10821, 10816>,
    <10820, 10816, 10815>,
    <10820, 10815, 10819>,
    <10820, 10819, 10822>,
    <10820, 10822, 10806>,
    <10820, 10806, 10805>,
    <10820, 10805, 10804>,
    <10820, 10804, 10821>,
    <10823, 10817, 10816>,
    <10823, 10816, 10821>,
    <10823, 10821, 10804>,
    <10823, 10804, 10813>,
    <10823, 10813, 9940>,
    <10823, 9940, 10763>,
    <10823, 10763, 10760>,
    <10823, 10760, 10817>,
    <10824, 10825, 10826>,
    <10824, 10826, 10827>,
    <10824, 10827, 10828>,
    <10824, 10828, 10829>,
    <10824, 10829, 9826>,
    <10824, 9826, 10703>,
    <10824, 10703, 10701>,
    <10824, 10701, 10825>,
    <10830, 10831, 10826>,
    <10830, 10826, 10825>,
    <10830, 10825, 10701>,
    <10830, 10701, 10700>,
    <10830, 10700, 10692>,
    <10830, 10692, 10832>,
    <10830, 10832, 10833>,
    <10830, 10833, 10831>,
    <10834, 10827, 10826>,
    <10834, 10826, 10831>,
    <10834, 10831, 10833>,
    <10834, 10833, 10835>,
    <10834, 10835, 10836>,
    <10834, 10836, 10837>,
    <10834, 10837, 10828>,
    <10834, 10828, 10827>,
    <10838, 10839, 10840>,
    <10838, 10840, 10841>,
    <10838, 10841, 9967>,
    <10838, 9967, 9966>,
    <10838, 9966, 9826>,
    <10838, 9826, 10829>,
    <10838, 10829, 10828>,
    <10838, 10828, 10839>,
    <10842, 10843, 10840>,
    <10842, 10840, 10839>,
    <10842, 10839, 10828>,
    <10842, 10828, 10837>,
    <10842, 10837, 10836>,
    <10842, 10836, 10844>,
    <10842, 10844, 10845>,
    <10842, 10845, 10843>,
    <10846, 10841, 10840>,
    <10846, 10840, 10843>,
    <10846, 10843, 10845>,
    <10846, 10845, 10847>,
    <10846, 10847, 9970>,
    <10846, 9970, 9969>,
    <10846, 9969, 9967>,
    <10846, 9967, 10841>,
    <10848, 10849, 10850>,
    <10848, 10850, 10851>,
    <10848, 10851, 10852>,
    <10848, 10852, 10853>,
    <10848, 10853, 10854>,
    <10848, 10854, 10855>,
    <10848, 10855, 10856>,
    <10848, 10856, 10849>,
    <10857, 10858, 10850>,
    <10857, 10850, 10849>,
    <10857, 10849, 10856>,
    <10857, 10856, 10859>,
    <10857, 10859, 9988>,
    <10857, 9988, 10145>,
    <10857, 10145, 10144>,
    <10857, 10144, 10858>,
    <10860, 10851, 10850>,
    <10860, 10850, 10858>,
    <10860, 10858, 10144>,
    <10860, 10144, 10149>,
    <10860, 10149, 10132>,
    <10860, 10132, 10861>,
    <10860, 10861, 10852>,
    <10860, 10852, 10851>,
    <10862, 10863, 10864>,
    <10862, 10864, 10865>,
    <10862, 10865, 10866>,
    <10862, 10866, 10867>,
    <10862, 10867, 10710>,
    <10862, 10710, 10709>,
    <10862, 10709, 10708>,
    <10862, 10708, 10863>,
    <10868, 10869, 10864>,
    <10868, 10864, 10863>,
    <10868, 10863, 10708>,
    <10868, 10708, 10717>,
    <10868, 10717, 9988>,
    <10868, 9988, 10859>,
    <10868, 10859, 10856>,
    <10868, 10856, 10869>,
    <10870, 10865, 10864>,
    <10870, 10864, 10869>,
    <10870, 10869, 10856>,
    <10870, 10856, 10855>,
    <10870, 10855, 10854>,
    <10870, 10854, 10871>,
    <10870, 10871, 10866>,
    <10870, 10866, 10865>,
    <10872, 10873, 10874>,
    <10872, 10874, 10875>,
    <10872, 10875, 10797>,
    <10872, 10797, 10796>,
    <10872, 10796, 9919>,
    <10872, 9919, 10876>,
    <10872, 10876, 10877>,
    <10872, 10877, 10873>,
    <10878, 10879, 10874>,
    <10878, 10874, 10873>,
    <10878, 10873, 10877>,
    <10878, 10877, 10880>,
    <10878, 10880, 10881>,
    <10878, 10881, 10882>,
    <10878, 10882, 10883>,
    <10878, 10883, 10879>,
    <10884, 10875, 10874>,
    <10884, 10874, 10879>,
    <10884, 10879, 10883>,
    <10884, 10883, 10885>,
    <10884, 10885, 10785>,
    <10884, 10785, 10799>,
    <10884, 10799, 10797>,
    <10884, 10797, 10875>,
    <10886, 10887, 10888>,
    <10886, 10888, 10889>,
    <10886, 10889, 10877>,
    <10886, 10877, 10876>,
    <10886, 10876, 9919>,
    <10886, 9919, 10019>,
    <10886, 10019, 10017>,
    <10886, 10017, 10887>,
    <10890, 10891, 10888>,
    <10890, 10888, 10887>,
    <10890, 10887, 10017>,
    <10890, 10017, 10016>,
    <10890, 10016, 10015>,
    <10890, 10015, 10892>,
    <10890, 10892, 10893>,
    <10890, 10893, 10891>,
    <10894, 10889, 10888>,
    <10894, 10888, 10891>,
    <10894, 10891, 10893>,
    <10894, 10893, 10895>,
    <10894, 10895, 10881>,
    <10894, 10881, 10880>,
    <10894, 10880, 10877>,
    <10894, 10877, 10889>,
    <10896, 10897, 10898>,
    <10896, 10898, 10899>,
    <10896, 10899, 10900>,
    <10896, 10900, 10901>,
    <10896, 10901, 10902>,
    <10896, 10902, 10903>,
    <10896, 10903, 10904>,
    <10896, 10904, 10897>,
    <10905, 10906, 10898>,
    <10905, 10898, 10897>,
    <10905, 10897, 10904>,
    <10905, 10904, 10907>,
    <10905, 10907, 10908>,
    <10905, 10908, 10092>,
    <10905, 10092, 10089>,
    <10905, 10089, 10906>,
    <10909, 10899, 10898>,
    <10909, 10898, 10906>,
    <10909, 10906, 10089>,
    <10909, 10089, 10088>,
    <10909, 10088, 10036>,
    <10909, 10036, 10910>,
    <10909, 10910, 10900>,
    <10909, 10900, 10899>,
    <10911, 10912, 10913>,
    <10911, 10913, 10914>,
    <10911, 10914, 10808>,
    <10911, 10808, 10807>,
    <10911, 10807, 10806>,
    <10911, 10806, 10915>,
    <10911, 10915, 10916>,
    <10911, 10916, 10912>,
    <10917, 10918, 10913>,
    <10917, 10913, 10912>,
    <10917, 10912, 10916>,
    <10917, 10916, 10919>,
    <10917, 10919, 10902>,
    <10917, 10902, 10901>,
    <10917, 10901, 10900>,
    <10917, 10900, 10918>,
    <10920, 10914, 10913>,
    <10920, 10913, 10918>,
    <10920, 10918, 10900>,
    <10920, 10900, 10910>,
    <10920, 10910, 10036>,
    <10920, 10036, 10811>,
    <10920, 10811, 10808>,
    <10920, 10808, 10914>,
    <10921, 10922, 10923>,
    <10921, 10923, 10924>,
    <10921, 10924, 10893>,
    <10921, 10893, 10892>,
    <10921, 10892, 10015>,
    <10921, 10015, 10925>,
    <10921, 10925, 10926>,
    <10921, 10926, 10922>,
    <10927, 10928, 10923>,
    <10927, 10923, 10922>,
    <10927, 10922, 10926>,
    <10927, 10926, 10929>,
    <10927, 10929, 10930>,
    <10927, 10930, 10931>,
    <10927, 10931, 10932>,
    <10927, 10932, 10928>,
    <10933, 10924, 10923>,
    <10933, 10923, 10928>,
    <10933, 10928, 10932>,
    <10933, 10932, 10934>,
    <10933, 10934, 10881>,
    <10933, 10881, 10895>,
    <10933, 10895, 10893>,
    <10933, 10893, 10924>,
    <10935, 10936, 10937>,
    <10935, 10937, 10938>,
    <10935, 10938, 10926>,
    <10935, 10926, 10925>,
    <10935, 10925, 10015>,
    <10935, 10015, 10068>,
    <10935, 10068, 10066>,
    <10935, 10066, 10936>,
    <10939, 10940, 10937>,
    <10939, 10937, 10936>,
    <10939, 10936, 10066>,
    <10939, 10066, 10065>,
    <10939, 10065, 10941>,
    <10939, 10941, 10942>,
    <10939, 10943, 10944>,
    <10939, 10944, 10940>,
    <10945, 10938, 10937>,
    <10945, 10937, 10940>,
    <10945, 10940, 10946>,
    <10945, 10946, 10947>,
    <10945, 10948, 10949>,
    <10945, 10949, 10929>,
    <10945, 10929, 10926>,
    <10945, 10926, 10938>,
    <10950, 10951, 10952>,
    <10950, 10952, 10953>,
    <10950, 10953, 10904>,
    <10950, 10904, 10903>,
    <10950, 10903, 10902>,
    <10950, 10902, 10954>,
    <10950, 10954, 10955>,
    <10950, 10955, 10951>,
    <10956, 10957, 10952>,
    <10956, 10952, 10951>,
    <10956, 10951, 10955>,
    <10956, 10955, 10958>,
    <10956, 10958, 10959>,
    <10956, 10959, 10960>,
    <10956, 10961, 10962>,
    <10956, 10962, 10957>,
    <10963, 10953, 10952>,
    <10963, 10952, 10957>,
    <10963, 10957, 10964>,
    <10963, 10964, 10965>,
    <10963, 10966, 10967>,
    <10963, 10967, 10907>,
    <10963, 10907, 10904>,
    <10963, 10904, 10953>,
    <10968, 10969, 10970>,
    <10968, 10970, 10971>,
    <10968, 10971, 10972>,
    <10968, 10972, 10973>,
    <10968, 10973, 9970>,
    <10968, 9970, 10847>,
    <10968, 10847, 10845>,
    <10968, 10845, 10969>,
    <10974, 10975, 10970>,
    <10974, 10970, 10969>,
    <10974, 10969, 10845>,
    <10974, 10845, 10844>,
    <10974, 10844, 10836>,
    <10974, 10836, 10976>,
    <10974, 10976, 10977>,
    <10974, 10977, 10975>,
    <10978, 10971, 10970>,
    <10978, 10970, 10975>,
    <10978, 10975, 10977>,
    <10978, 10977, 10979>,
    <10978, 10979, 10980>,
    <10978, 10980, 10981>,
    <10978, 10981, 10972>,
    <10978, 10972, 10971>,
    <10982, 10983, 10984>,
    <10982, 10984, 10985>,
    <10982, 10985, 10111>,
    <10982, 10111, 10110>,
    <10982, 10110, 9970>,
    <10982, 9970, 10973>,
    <10982, 10973, 10972>,
    <10982, 10972, 10983>,
    <10986, 10987, 10984>,
    <10986, 10984, 10983>,
    <10986, 10983, 10972>,
    <10986, 10972, 10981>,
    <10986, 10981, 10980>,
    <10986, 10980, 10988>,
    <10986, 10988, 10989>,
    <10986, 10989, 10987>,
    <10990, 10985, 10984>,
    <10990, 10984, 10987>,
    <10990, 10987, 10989>,
    <10990, 10989, 10991>,
    <10990, 10991, 10114>,
    <10990, 10114, 10113>,
    <10990, 10113, 10111>,
    <10990, 10111, 10985>,
    <10992, 10993, 10994>,
    <10992, 10994, 10995>,
    <10992, 10995, 10996>,
    <10992, 10996, 10997>,
    <10992, 10997, 10998>,
    <10992, 10998, 10999>,
    <10992, 10999, 11000>,
    <10992, 11000, 10993>,
    <11001, 11002, 10994>,
    <11001, 10994, 10993>,
    <11001, 10993, 11000>,
    <11001, 11000, 11003>,
    <11001, 11003, 10132>,
    <11001, 10132, 10193>,
    <11001, 10193, 10192>,
    <11001, 10192, 11002>,
    <11004, 10995, 10994>,
    <11004, 10994, 11002>,
    <11004, 11002, 10192>,
    <11004, 10192, 10197>,
    <11004, 10197, 10180>,
    <11004, 10180, 11005>,
    <11004, 11005, 10996>,
    <11004, 10996, 10995>,
    <11006, 11007, 11008>,
    <11006, 11008, 11009>,
    <11006, 11009, 11010>,
    <11006, 11010, 11011>,
    <11006, 11011, 10854>,
    <11006, 10854, 10853>,
    <11006, 10853, 10852>,
    <11006, 10852, 11007>,
    <11012, 11013, 11008>,
    <11012, 11008, 11007>,
    <11012, 11007, 10852>,
    <11012, 10852, 10861>,
    <11012, 10861, 10132>,
    <11012, 10132, 11003>,
    <11012, 11003, 11000>,
    <11012, 11000, 11013>,
    <11014, 11009, 11008>,
    <11014, 11008, 11013>,
    <11014, 11013, 11000>,
    <11014, 11000, 10999>,
    <11014, 10999, 10998>,
    <11014, 10998, 11015>,
    <11014, 11015, 11010>,
    <11014, 11010, 11009>,
    <11016, 11017, 11018>,
    <11016, 11018, 11019>,
    <11016, 11019, 11020>,
    <11016, 11020, 11021>,
    <11016, 11021, 10114>,
    <11016, 10114, 10991>,
    <11016, 10991, 10989>,
    <11016, 10989, 11017>,
    <11022, 11023, 11018>,
    <11022, 11018, 11017>,
    <11022, 11017, 10989>,
    <11022, 10989, 10988>,
    <11022, 10988, 10980>,
    <11022, 10980, 11024>,
    <11022, 11024, 11025>,
    <11022, 11025, 11023>,
    <11026, 11019, 11018>,
    <11026, 11018, 11023>,
    <11026, 11023, 11025>,
    <11026, 11025, 11027>,
    <11026, 11027, 11028>,
    <11026, 11028, 11029>,
    <11026, 11029, 11020>,
    <11026, 11020, 11019>,
    <11030, 11031, 11032>,
    <11030, 11032, 11033>,
    <11030, 11033, 10159>,
    <11030, 10159, 10158>,
    <11030, 10158, 10114>,
    <11030, 10114, 11021>,
    <11030, 11021, 11020>,
    <11030, 11020, 11031>,
    <11034, 11035, 11032>,
    <11034, 11032, 11031>,
    <11034, 11031, 11020>,
    <11034, 11020, 11029>,
    <11034, 11029, 11028>,
    <11034, 11028, 11036>,
    <11034, 11036, 11037>,
    <11034, 11037, 11035>,
    <11038, 11033, 11032>,
    <11038, 11032, 11035>,
    <11038, 11035, 11037>,
    <11038, 11037, 11039>,
    <11038, 11039, 10162>,
    <11038, 10162, 10161>,
    <11038, 10161, 10159>,
    <11038, 10159, 11033>,
    <11040, 11041, 11042>,
    <11040, 11042, 11043>,
    <11040, 11043, 11044>,
    <11040, 11044, 11045>,
    <11040, 11045, 11046>,
    <11040, 11046, 11047>,
    <11040, 11047, 11048>,
    <11040, 11048, 11041>,
    <11049, 11050, 11042>,
    <11049, 11042, 11041>,
    <11049, 11041, 11048>,
    <11049, 11048, 11051>,
    <11049, 11051, 10180>,
    <11049, 10180, 10223>,
    <11049, 10223, 10222>,
    <11049, 10222, 11050>,
    <11052, 11043, 11042>,
    <11052, 11042, 11050>,
    <11052, 11050, 10222>,
    <11052, 10222, 10227>,
    <11052, 10227, 1576>,
    <11052, 1576, 11053>,
    <11052, 11053, 11044>,
    <11052, 11044, 11043>,
    <11054, 11055, 11056>,
    <11054, 11056, 11057>,
    <11054, 11057, 11058>,
    <11054, 11058, 11059>,
    <11054, 11059, 10998>,
    <11054, 10998, 10997>,
    <11054, 10997, 10996>,
    <11054, 10996, 11055>,
    <11060, 11061, 11056>,
    <11060, 11056, 11055>,
    <11060, 11055, 10996>,
    <11060, 10996, 11005>,
    <11060, 11005, 10180>,
    <11060, 10180, 11051>,
    <11060, 11051, 11048>,
    <11060, 11048, 11061>,
    <11062, 11057, 11056>,
    <11062, 11056, 11061>,
    <11062, 11061, 11048>,
    <11062, 11048, 11047>,
    <11062, 11047, 11046>,
    <11062, 11046, 11063>,
    <11062, 11063, 11058>,
    <11062, 11058, 11057>,
    <11064, 11065, 11066>,
    <11064, 11066, 11067>,
    <11064, 11067, 11068>,
    <11064, 11068, 11069>,
    <11064, 11069, 10162>,
    <11064, 10162, 11039>,
    <11064, 11039, 11037>,
    <11064, 11037, 11065>,
    <11070, 11071, 11066>,
    <11070, 11066, 11065>,
    <11070, 11065, 11037>,
    <11070, 11037, 11036>,
    <11070, 11036, 11028>,
    <11070, 11028, 11072>,
    <11070, 11072, 11073>,
    <11070, 11073, 11071>,
    <11074, 11067, 11066>,
    <11074, 11066, 11071>,
    <11074, 11071, 11073>,
    <11074, 11073, 11075>,
    <11074, 11075, 1888>,
    <11074, 1888, 11076>,
    <11074, 11076, 11068>,
    <11074, 11068, 11067>,
    <11077, 11078, 11079>,
    <11077, 11079, 11080>,
    <11077, 11080, 10207>,
    <11077, 10207, 10206>,
    <11077, 10206, 10162>,
    <11077, 10162, 11069>,
    <11077, 11069, 11068>,
    <11077, 11068, 11078>,
    <11081, 11082, 11079>,
    <11081, 11079, 11078>,
    <11081, 11078, 11068>,
    <11081, 11068, 11076>,
    <11081, 11076, 1888>,
    <11081, 1888, 1925>,
    <11081, 1925, 1923>,
    <11081, 1923, 11082>,
    <11083, 11080, 11079>,
    <11083, 11079, 11082>,
    <11083, 11082, 1923>,
    <11083, 1923, 1922>,
    <11083, 1922, 1525>,
    <11083, 1525, 10209>,
    <11083, 10209, 10207>,
    <11083, 10207, 11080>,
    <11084, 11085, 11086>,
    <11084, 11086, 11087>,
    <11084, 11087, 11088>,
    <11084, 11088, 11089>,
    <11084, 11089, 11046>,
    <11084, 11046, 11045>,
    <11084, 11045, 11044>,
    <11084, 11044, 11085>,
    <11090, 11091, 11086>,
    <11090, 11086, 11085>,
    <11090, 11085, 11044>,
    <11090, 11044, 11053>,
    <11090, 11053, 1576>,
    <11090, 1576, 1958>,
    <11090, 1958, 1956>,
    <11090, 1956, 11091>,
    <11092, 11087, 11086>,
    <11092, 11086, 11091>,
    <11092, 11091, 1956>,
    <11092, 1956, 1955>,
    <11092, 1955, 1939>,
    <11092, 1939, 11093>,
    <11092, 11093, 11088>,
    <11092, 11088, 11087>,
    <11094, 11095, 11096>,
    <11094, 11096, 11097>,
    <11094, 11097, 11098>,
    <11094, 11098, 11099>,
    <11094, 11099, 11100>,
    <11094, 11100, 11101>,
    <11094, 11102, 11103>,
    <11094, 11103, 11095>,
    <11104, 11105, 11096>,
    <11104, 11096, 11095>,
    <11104, 11095, 11106>,
    <11104, 11106, 11107>,
    <11104, 11108, 11109>,
    <11104, 11109, 10299>,
    <11104, 10299, 10297>,
    <11104, 10297, 11105>,
    <11110, 11097, 11096>,
    <11110, 11096, 11105>,
    <11110, 11105, 10297>,
    <11110, 10297, 10296>,
    <11110, 10296, 10295>,
    <11110, 10295, 11111>,
    <11110, 11111, 11098>,
    <11110, 11098, 11097>,
    <11112, 11113, 11114>,
    <11112, 11114, 11115>,
    <11112, 11115, 11116>,
    <11112, 11116, 11117>,
    <11112, 11118, 11119>,
    <11112, 11119, 11120>,
    <11112, 11120, 11121>,
    <11112, 11121, 11113>,
    <11122, 11123, 11114>,
    <11122, 11114, 11113>,
    <11122, 11113, 11121>,
    <11122, 11121, 11124>,
    <11122, 11124, 10343>,
    <11122, 10343, 10393>,
    <11122, 10393, 10391>,
    <11122, 10391, 11123>,
    <11125, 11115, 11114>,
    <11125, 11114, 11123>,
    <11125, 11123, 10391>,
    <11125, 10391, 10390>,
    <11125, 10390, 11126>,
    <11125, 11126, 11127>,
    <11125, 11128, 11129>,
    <11125, 11129, 11115>,
    <11130, 11131, 11132>,
    <11130, 11132, 11133>,
    <11130, 11133, 11134>,
    <11130, 11134, 11135>,
    <11130, 11135, 11136>,
    <11130, 11136, 11137>,
    <11130, 11138, 11139>,
    <11130, 11139, 11131>,
    <11140, 11141, 11132>,
    <11140, 11132, 11131>,
    <11140, 11131, 11142>,
    <11140, 11142, 11143>,
    <11140, 11144, 11145>,
    <11140, 11145, 10530>,
    <11140, 10530, 10529>,
    <11140, 10529, 11141>,
    <11146, 11133, 11132>,
    <11146, 11132, 11141>,
    <11146, 11141, 10529>,
    <11146, 10529, 10535>,
    <11146, 10535, 10517>,
    <11146, 10517, 11147>,
    <11146, 11147, 11134>,
    <11146, 11134, 11133>,
    <11148, 11149, 11150>,
    <11148, 11150, 11151>,
    <11148, 11151, 11152>,
    <11148, 11152, 11153>,
    <11148, 11154, 11155>,
    <11148, 11155, 11156>,
    <11148, 11156, 11157>,
    <11148, 11157, 11149>,
    <11158, 11159, 11150>,
    <11158, 11150, 11149>,
    <11158, 11149, 11157>,
    <11158, 11157, 11160>,
    <11158, 11160, 11161>,
    <11158, 11161, 11162>,
    <11158, 11162, 11163>,
    <11158, 11163, 11159>,
    <11164, 11151, 11150>,
    <11164, 11150, 11159>,
    <11164, 11159, 11163>,
    <11164, 11163, 11165>,
    <11164, 11165, 11166>,
    <11164, 11166, 11167>,
    <11164, 11168, 11169>,
    <11164, 11169, 11151>,
    <11170, 11171, 11172>,
    <11170, 11172, 11173>,
    <11170, 11173, 11157>,
    <11170, 11157, 11156>,
    <11170, 11156, 11174>,
    <11170, 11174, 11175>,
    <11170, 11176, 11177>,
    <11170, 11177, 11171>,
    <11178, 11179, 11172>,
    <11178, 11172, 11171>,
    <11178, 11171, 11180>,
    <11178, 11180, 11181>,
    <11178, 11182, 11183>,
    <11178, 11183, 11184>,
    <11178, 11184, 11185>,
    <11178, 11185, 11179>,
    <11186, 11173, 11172>,
    <11186, 11172, 11179>,
    <11186, 11179, 11185>,
    <11186, 11185, 11187>,
    <11186, 11187, 11161>,
    <11186, 11161, 11160>,
    <11186, 11160, 11157>,
    <11186, 11157, 11173>,
    <11188, 11189, 11190>,
    <11188, 11190, 11191>,
    <11188, 11191, 11185>,
    <11188, 11185, 11184>,
    <11188, 11184, 11192>,
    <11188, 11192, 11099>,
    <11188, 11099, 11098>,
    <11188, 11098, 11189>,
    <11193, 11194, 11190>,
    <11193, 11190, 11189>,
    <11193, 11189, 11098>,
    <11193, 11098, 11111>,
    <11193, 11111, 10295>,
    <11193, 10295, 11195>,
    <11193, 11195, 11196>,
    <11193, 11196, 11194>,
    <11197, 11191, 11190>,
    <11197, 11190, 11194>,
    <11197, 11194, 11196>,
    <11197, 11196, 11198>,
    <11197, 11198, 11161>,
    <11197, 11161, 11187>,
    <11197, 11187, 11185>,
    <11197, 11185, 11191>,
    <11199, 11200, 11201>,
    <11199, 11201, 11202>,
    <11199, 11202, 11121>,
    <11199, 11121, 11120>,
    <11199, 11120, 11203>,
    <11199, 11203, 11204>,
    <11199, 11204, 11205>,
    <11199, 11205, 11200>,
    <11206, 11207, 11201>,
    <11206, 11201, 11200>,
    <11206, 11200, 11205>,
    <11206, 11205, 11208>,
    <11206, 11208, 11209>,
    <11206, 11209, 11210>,
    <11206, 11210, 11211>,
    <11206, 11211, 11207>,
    <11212, 11202, 11201>,
    <11212, 11201, 11207>,
    <11212, 11207, 11211>,
    <11212, 11211, 11213>,
    <11212, 11213, 10343>,
    <11212, 10343, 11124>,
    <11212, 11124, 11121>,
    <11212, 11121, 11202>,
    <11214, 11215, 11216>,
    <11214, 11216, 11217>,
    <11214, 11217, 11211>,
    <11214, 11211, 11210>,
    <11214, 11210, 11209>,
    <11214, 11209, 11218>,
    <11214, 11218, 11219>,
    <11214, 11219, 11215>,
    <11220, 11221, 11216>,
    <11220, 11216, 11215>,
    <11220, 11215, 11219>,
    <11220, 11219, 11222>,
    <11220, 11222, 10442>,
    <11220, 10442, 10458>,
    <11220, 10458, 10455>,
    <11220, 10455, 11221>,
    <11223, 11217, 11216>,
    <11223, 11216, 11221>,
    <11223, 11221, 10455>,
    <11223, 10455, 10454>,
    <11223, 10454, 10343>,
    <11223, 10343, 11213>,
    <11223, 11213, 11211>,
    <11223, 11211, 11217>,
    <11224, 11225, 11226>,
    <11224, 11226, 11227>,
    <11224, 11227, 11205>,
    <11224, 11205, 11204>,
    <11224, 11204, 11228>,
    <11224, 11228, 11229>,
    <11224, 11230, 11231>,
    <11224, 11231, 11225>,
    <11232, 11233, 11226>,
    <11232, 11226, 11225>,
    <11232, 11225, 11234>,
    <11232, 11234, 11235>,
    <11232, 11236, 11237>,
    <11232, 11237, 11238>,
    <11232, 11238, 11239>,
    <11232, 11239, 11233>,
    <11240, 11227, 11226>,
    <11240, 11226, 11233>,
    <11240, 11233, 11239>,
    <11240, 11239, 11241>,
    <11240, 11241, 11209>,
    <11240, 11209, 11208>,
    <11240, 11208, 11205>,
    <11240, 11205, 11227>,
    <11242, 11243, 11244>,
    <11242, 11244, 11245>,
    <11242, 11245, 11239>,
    <11242, 11239, 11238>,
    <11242, 11238, 11246>,
    <11242, 11246, 11247>,
    <11242, 11248, 11249>,
    <11242, 11249, 11243>,
    <11250, 11251, 11244>,
    <11250, 11244, 11243>,
    <11250, 11243, 11252>,
    <11250, 11252, 11253>,
    <11250, 11254, 11255>,
    <11250, 11255, 11256>,
    <11250, 11256, 11257>,
    <11250, 11257, 11251>,
    <11258, 11245, 11244>,
    <11258, 11244, 11251>,
    <11258, 11251, 11257>,
    <11258, 11257, 11259>,
    <11258, 11259, 11209>,
    <11258, 11209, 11241>,
    <11258, 11241, 11239>,
    <11258, 11239, 11245>,
    <11260, 11261, 11262>,
    <11260, 11262, 11263>,
    <11260, 11263, 11264>,
    <11260, 11264, 11265>,
    <11260, 11265, 11266>,
    <11260, 11266, 11267>,
    <11260, 11268, 11269>,
    <11260, 11269, 11261>,
    <11270, 11271, 11262>,
    <11270, 11262, 11261>,
    <11270, 11261, 11272>,
    <11270, 11272, 11273>,
    <11270, 11274, 11275>,
    <11270, 11275, 11135>,
    <11270, 11135, 11134>,
    <11270, 11134, 11271>,
    <11276, 11263, 11262>,
    <11276, 11262, 11271>,
    <11276, 11271, 11134>,
    <11276, 11134, 11147>,
    <11276, 11147, 10517>,
    <11276, 10517, 11277>,
    <11276, 11277, 11264>,
    <11276, 11264, 11263>,
    <11278, 11279, 11280>,
    <11278, 11280, 11281>,
    <11278, 11281, 11196>,
    <11278, 11196, 11195>,
    <11278, 11195, 10295>,
    <11278, 10295, 11282>,
    <11278, 11282, 11283>,
    <11278, 11283, 11279>,
    <11284, 11285, 11280>,
    <11284, 11280, 11279>,
    <11284, 11279, 11283>,
    <11284, 11283, 11286>,
    <11284, 11286, 11287>,
    <11284, 11287, 11288>,
    <11284, 11288, 11289>,
    <11284, 11289, 11285>,
    <11290, 11281, 11280>,
    <11290, 11280, 11285>,
    <11290, 11285, 11289>,
    <11290, 11289, 11291>,
    <11290, 11291, 11161>,
    <11290, 11161, 11198>,
    <11290, 11198, 11196>,
    <11290, 11196, 11281>,
    <11292, 11293, 11294>,
    <11292, 11294, 11295>,
    <11292, 11295, 11283>,
    <11292, 11283, 11282>,
    <11292, 11282, 10295>,
    <11292, 10295, 10425>,
    <11292, 10425, 10423>,
    <11292, 10423, 11293>,
    <11296, 11297, 11294>,
    <11296, 11294, 11293>,
    <11296, 11293, 10423>,
    <11296, 10423, 10422>,
    <11296, 10422, 10421>,
    <11296, 10421, 11298>,
    <11296, 11298, 11299>,
    <11296, 11299, 11297>,
    <11300, 11295, 11294>,
    <11300, 11294, 11297>,
    <11300, 11297, 11299>,
    <11300, 11299, 11301>,
    <11300, 11301, 11287>,
    <11300, 11287, 11286>,
    <11300, 11286, 11283>,
    <11300, 11283, 11295>,
    <11302, 11303, 11304>,
    <11302, 11304, 11305>,
    <11302, 11305, 11306>,
    <11302, 11306, 11307>,
    <11302, 11307, 11308>,
    <11302, 11308, 11309>,
    <11302, 11309, 11310>,
    <11302, 11310, 11303>,
    <11311, 11312, 11304>,
    <11311, 11304, 11303>,
    <11311, 11303, 11310>,
    <11311, 11310, 11313>,
    <11311, 11313, 10566>,
    <11311, 10566, 10582>,
    <11311, 10582, 10579>,
    <11311, 10579, 11312>,
    <11314, 11305, 11304>,
    <11314, 11304, 11312>,
    <11314, 11312, 10579>,
    <11314, 10579, 10578>,
    <11314, 10578, 10442>,
    <11314, 10442, 11315>,
    <11314, 11315, 11306>,
    <11314, 11306, 11305>,
    <11316, 11317, 11318>,
    <11316, 11318, 11319>,
    <11316, 11319, 11219>,
    <11316, 11219, 11218>,
    <11316, 11218, 11209>,
    <11316, 11209, 11320>,
    <11316, 11320, 11321>,
    <11316, 11321, 11317>,
    <11322, 11323, 11318>,
    <11322, 11318, 11317>,
    <11322, 11317, 11321>,
    <11322, 11321, 11324>,
    <11322, 11324, 11308>,
    <11322, 11308, 11307>,
    <11322, 11307, 11306>,
    <11322, 11306, 11323>,
    <11325, 11319, 11318>,
    <11325, 11318, 11323>,
    <11325, 11323, 11306>,
    <11325, 11306, 11315>,
    <11325, 11315, 10442>,
    <11325, 10442, 11222>,
    <11325, 11222, 11219>,
    <11325, 11219, 11319>,
    <11326, 11327, 11328>,
    <11326, 11328, 11329>,
    <11326, 11329, 11330>,
    <11326, 11330, 11331>,
    <11326, 11331, 11332>,
    <11326, 11332, 11333>,
    <11326, 11334, 11335>,
    <11326, 11335, 11327>,
    <11336, 11337, 11328>,
    <11336, 11328, 11327>,
    <11336, 11327, 11338>,
    <11336, 11338, 11339>,
    <11336, 11340, 11341>,
    <11336, 11341, 11342>,
    <11336, 11342, 11343>,
    <11336, 11343, 11337>,
    <11344, 11329, 11328>,
    <11344, 11328, 11337>,
    <11344, 11337, 11343>,
    <11344, 11343, 11345>,
    <11344, 11345, 11346>,
    <11344, 11346, 11347>,
    <11344, 11347, 11330>,
    <11344, 11330, 11329>,
    <11348, 11349, 11350>,
    <11348, 11350, 11351>,
    <11348, 11351, 11352>,
    <11348, 11352, 11353>,
    <11348, 11353, 11354>,
    <11348, 11354, 11355>,
    <11348, 11356, 11357>,
    <11348, 11357, 11349>,
    <11358, 11359, 11350>,
    <11358, 11350, 11349>,
    <11358, 11349, 11360>,
    <11358, 11360, 11361>,
    <11358, 11362, 11363>,
    <11358, 11363, 11331>,
    <11358, 11331, 11330>,
    <11358, 11330, 11359>,
    <11364, 11351, 11350>,
    <11364, 11350, 11359>,
    <11364, 11359, 11330>,
    <11364, 11330, 11347>,
    <11364, 11347, 11346>,
    <11364, 11346, 11365>,
    <11364, 11365, 11352>,
    <11364, 11352, 11351>,
    <11366, 11367, 11368>,
    <11366, 11368, 11369>,
    <11366, 11369, 10477>,
    <11366, 10477, 10476>,
    <11366, 10476, 11370>,
    <11366, 11370, 11353>,
    <11366, 11353, 11352>,
    <11366, 11352, 11367>,
    <11371, 11372, 11368>,
    <11371, 11368, 11367>,
    <11371, 11367, 11352>,
    <11371, 11352, 11365>,
    <11371, 11365, 11346>,
    <11371, 11346, 11373>,
    <11371, 11373, 11374>,
    <11371, 11374, 11372>,
    <11375, 11369, 11368>,
    <11375, 11368, 11372>,
    <11375, 11372, 11374>,
    <11375, 11374, 11376>,
    <11375, 11376, 10480>,
    <11375, 10480, 10479>,
    <11375, 10479, 10477>,
    <11375, 10477, 11369>,
    <11377, 11378, 11379>,
    <11377, 11379, 11380>,
    <11377, 11380, 11381>,
    <11377, 11381, 11382>,
    <11377, 11382, 11383>,
    <11377, 11383, 11384>,
    <11377, 11384, 11385>,
    <11377, 11385, 11378>,
    <11386, 11387, 11379>,
    <11386, 11379, 11378>,
    <11386, 11378, 11385>,
    <11386, 11385, 11388>,
    <11386, 11388, 10517>,
    <11386, 10517, 10627>,
    <11386, 10627, 10626>,
    <11386, 10626, 11387>,
    <11389, 11380, 11379>,
    <11389, 11379, 11387>,
    <11389, 11387, 10626>,
    <11389, 10626, 10631>,
    <11389, 10631, 10614>,
    <11389, 10614, 11390>,
    <11389, 11390, 11381>,
    <11389, 11381, 11380>,
    <11391, 11392, 11393>,
    <11391, 11393, 11394>,
    <11391, 11394, 11395>,
    <11391, 11395, 11396>,
    <11391, 11396, 11397>,
    <11391, 11397, 11265>,
    <11391, 11265, 11264>,
    <11391, 11264, 11392>,
    <11398, 11399, 11393>,
    <11398, 11393, 11392>,
    <11398, 11392, 11264>,
    <11398, 11264, 11277>,
    <11398, 11277, 10517>,
    <11398, 10517, 11388>,
    <11398, 11388, 11385>,
    <11398, 11385, 11399>,
    <11400, 11394, 11393>,
    <11400, 11393, 11399>,
    <11400, 11399, 11385>,
    <11400, 11385, 11384>,
    <11400, 11384, 11383>,
    <11400, 11383, 11401>,
    <11400, 11401, 11395>,
    <11400, 11395, 11394>,
    <11402, 11403, 11404>,
    <11402, 11404, 11405>,
    <11402, 11405, 11299>,
    <11402, 11299, 11298>,
    <11402, 11298, 10421>,
    <11402, 10421, 11406>,
    <11402, 11406, 11407>,
    <11402, 11407, 11403>,
    <11408, 11409, 11404>,
    <11408, 11404, 11403>,
    <11408, 11403, 11407>,
    <11408, 11407, 11410>,
    <11408, 11410, 11411>,
    <11408, 11411, 11412>,
    <11408, 11412, 11413>,
    <11408, 11413, 11409>,
    <11414, 11405, 11404>,
    <11414, 11404, 11409>,
    <11414, 11409, 11413>,
    <11414, 11413, 11415>,
    <11414, 11415, 11287>,
    <11414, 11287, 11301>,
    <11414, 11301, 11299>,
    <11414, 11299, 11405>,
    <11416, 11417, 11418>,
    <11416, 11418, 11419>,
    <11416, 11419, 11407>,
    <11416, 11407, 11406>,
    <11416, 11406, 10421>,
    <11416, 10421, 10549>,
    <11416, 10549, 10547>,
    <11416, 10547, 11417>,
    <11420, 11421, 11418>,
    <11420, 11418, 11417>,
    <11420, 11417, 10547>,
    <11420, 10547, 10546>,
    <11420, 10546, 10545>,
    <11420, 10545, 11422>,
    <11420, 11422, 11423>,
    <11420, 11423, 11421>,
    <11424, 11419, 11418>,
    <11424, 11418, 11421>,
    <11424, 11421, 11423>,
    <11424, 11423, 11425>,
    <11424, 11425, 11411>,
    <11424, 11411, 11410>,
    <11424, 11410, 11407>,
    <11424, 11407, 11419>,
    <11426, 11427, 11428>,
    <11426, 11428, 11429>,
    <11426, 11429, 11430>,
    <11426, 11430, 11431>,
    <11426, 11431, 11432>,
    <11426, 11432, 11433>,
    <11426, 11433, 11434>,
    <11426, 11434, 11427>,
    <11435, 11436, 11428>,
    <11435, 11428, 11427>,
    <11435, 11427, 11434>,
    <11435, 11434, 11437>,
    <11435, 11437, 10662>,
    <11435, 10662, 10678>,
    <11435, 10678, 10675>,
    <11435, 10675, 11436>,
    <11438, 11429, 11428>,
    <11438, 11428, 11436>,
    <11438, 11436, 10675>,
    <11438, 10675, 10674>,
    <11438, 10674, 10566>,
    <11438, 10566, 11439>,
    <11438, 11439, 11430>,
    <11438, 11430, 11429>,
    <11440, 11441, 11442>,
    <11440, 11442, 11443>,
    <11440, 11443, 11310>,
    <11440, 11310, 11309>,
    <11440, 11309, 11308>,
    <11440, 11308, 11444>,
    <11440, 11444, 11445>,
    <11440, 11445, 11441>,
    <11446, 11447, 11442>,
    <11446, 11442, 11441>,
    <11446, 11441, 11445>,
    <11446, 11445, 11448>,
    <11446, 11448, 11432>,
    <11446, 11432, 11431>,
    <11446, 11431, 11430>,
    <11446, 11430, 11447>,
    <11449, 11443, 11442>,
    <11449, 11442, 11447>,
    <11449, 11447, 11430>,
    <11449, 11430, 11439>,
    <11449, 11439, 10566>,
    <11449, 10566, 11313>,
    <11449, 11313, 11310>,
    <11449, 11310, 11443>,
    <11450, 11451, 11452>,
    <11450, 11452, 11453>,
    <11450, 11453, 11454>,
    <11450, 11454, 11455>,
    <11450, 11455, 10480>,
    <11450, 10480, 11376>,
    <11450, 11376, 11374>,
    <11450, 11374, 11451>,
    <11456, 11457, 11452>,
    <11456, 11452, 11451>,
    <11456, 11451, 11374>,
    <11456, 11374, 11373>,
    <11456, 11373, 11346>,
    <11456, 11346, 11458>,
    <11456, 11458, 11459>,
    <11456, 11459, 11457>,
    <11460, 11453, 11452>,
    <11460, 11452, 11457>,
    <11460, 11457, 11459>,
    <11460, 11459, 11461>,
    <11460, 11461, 11462>,
    <11460, 11462, 11463>,
    <11460, 11463, 11454>,
    <11460, 11454, 11453>,
    <11464, 11465, 11466>,
    <11464, 11466, 11467>,
    <11464, 11467, 10593>,
    <11464, 10593, 10592>,
    <11464, 10592, 10480>,
    <11464, 10480, 11455>,
    <11464, 11455, 11454>,
    <11464, 11454, 11465>,
    <11468, 11469, 11466>,
    <11468, 11466, 11465>,
    <11468, 11465, 11454>,
    <11468, 11454, 11463>,
    <11468, 11463, 11462>,
    <11468, 11462, 11470>,
    <11468, 11470, 11471>,
    <11468, 11471, 11469>,
    <11472, 11467, 11466>,
    <11472, 11466, 11469>,
    <11472, 11469, 11471>,
    <11472, 11471, 11473>,
    <11472, 11473, 10596>,
    <11472, 10596, 10595>,
    <11472, 10595, 10593>,
    <11472, 10593, 11467>,
    <11474, 11475, 11476>,
    <11474, 11476, 11477>,
    <11474, 11477, 11478>,
    <11474, 11478, 11479>,
    <11474, 11479, 11480>,
    <11474, 11480, 11481>,
    <11474, 11481, 11482>,
    <11474, 11482, 11475>,
    <11483, 11484, 11476>,
    <11483, 11476, 11475>,
    <11483, 11475, 11482>,
    <11483, 11482, 11485>,
    <11483, 11485, 10614>,
    <11483, 10614, 10723>,
    <11483, 10723, 10722>,
    <11483, 10722, 11484>,
    <11486, 11477, 11476>,
    <11486, 11476, 11484>,
    <11486, 11484, 10722>,
    <11486, 10722, 10727>,
    <11486, 10727, 10710>,
    <11486, 10710, 11487>,
    <11486, 11487, 11478>,
    <11486, 11478, 11477>,
    <11488, 11489, 11490>,
    <11488, 11490, 11491>,
    <11488, 11491, 11492>,
    <11488, 11492, 11493>,
    <11488, 11493, 11383>,
    <11488, 11383, 11382>,
    <11488, 11382, 11381>,
    <11488, 11381, 11489>,
    <11494, 11495, 11490>,
    <11494, 11490, 11489>,
    <11494, 11489, 11381>,
    <11494, 11381, 11390>,
    <11494, 11390, 10614>,
    <11494, 10614, 11485>,
    <11494, 11485, 11482>,
    <11494, 11482, 11495>,
    <11496, 11491, 11490>,
    <11496, 11490, 11495>,
    <11496, 11495, 11482>,
    <11496, 11482, 11481>,
    <11496, 11481, 11480>,
    <11496, 11480, 11497>,
    <11496, 11497, 11492>,
    <11496, 11492, 11491>,
    <11498, 11499, 11500>,
    <11498, 11500, 11501>,
    <11498, 11501, 11423>,
    <11498, 11423, 11422>,
    <11498, 11422, 10545>,
    <11498, 10545, 11502>,
    <11498, 11502, 11503>,
    <11498, 11503, 11499>,
    <11504, 11505, 11500>,
    <11504, 11500, 11499>,
    <11504, 11499, 11503>,
    <11504, 11503, 11506>,
    <11504, 11506, 11507>,
    <11504, 11507, 11508>,
    <11504, 11508, 11509>,
    <11504, 11509, 11505>,
    <11510, 11501, 11500>,
    <11510, 11500, 11505>,
    <11510, 11505, 11509>,
    <11510, 11509, 11511>,
    <11510, 11511, 11411>,
    <11510, 11411, 11425>,
    <11510, 11425, 11423>,
    <11510, 11423, 11501>,
    <11512, 11513, 11514>,
    <11512, 11514, 11515>,
    <11512, 11515, 11503>,
    <11512, 11503, 11502>,
    <11512, 11502, 10545>,
    <11512, 10545, 10645>,
    <11512, 10645, 10643>,
    <11512, 10643, 11513>,
    <11516, 11517, 11514>,
    <11516, 11514, 11513>,
    <11516, 11513, 10643>,
    <11516, 10643, 10642>,
    <11516, 10642, 10641>,
    <11516, 10641, 11518>,
    <11516, 11518, 11519>,
    <11516, 11519, 11517>,
    <11520, 11515, 11514>,
    <11520, 11514, 11517>,
    <11520, 11517, 11519>,
    <11520, 11519, 11521>,
    <11520, 11521, 11507>,
    <11520, 11507, 11506>,
    <11520, 11506, 11503>,
    <11520, 11503, 11515>,
    <11522, 11523, 11524>,
    <11522, 11524, 11525>,
    <11522, 11525, 11526>,
    <11522, 11526, 11527>,
    <11522, 11527, 11528>,
    <11522, 11528, 11529>,
    <11522, 11529, 11530>,
    <11522, 11530, 11523>,
    <11531, 11532, 11524>,
    <11531, 11524, 11523>,
    <11531, 11523, 11530>,
    <11531, 11530, 11533>,
    <11531, 11533, 10758>,
    <11531, 10758, 10774>,
    <11531, 10774, 10771>,
    <11531, 10771, 11532>,
    <11534, 11525, 11524>,
    <11534, 11524, 11532>,
    <11534, 11532, 10771>,
    <11534, 10771, 10770>,
    <11534, 10770, 10662>,
    <11534, 10662, 11535>,
    <11534, 11535, 11526>,
    <11534, 11526, 11525>,
    <11536, 11537, 11538>,
    <11536, 11538, 11539>,
    <11536, 11539, 11434>,
    <11536, 11434, 11433>,
    <11536, 11433, 11432>,
    <11536, 11432, 11540>,
    <11536, 11540, 11541>,
    <11536, 11541, 11537>,
    <11542, 11543, 11538>,
    <11542, 11538, 11537>,
    <11542, 11537, 11541>,
    <11542, 11541, 11544>,
    <11542, 11544, 11528>,
    <11542, 11528, 11527>,
    <11542, 11527, 11526>,
    <11542, 11526, 11543>,
    <11545, 11539, 11538>,
    <11545, 11538, 11543>,
    <11545, 11543, 11526>,
    <11545, 11526, 11535>,
    <11545, 11535, 10662>,
    <11545, 10662, 11437>,
    <11545, 11437, 11434>,
    <11545, 11434, 11539>,
    <11546, 11547, 11548>,
    <11546, 11548, 11549>,
    <11546, 11549, 11550>,
    <11546, 11550, 11551>,
    <11546, 11551, 10596>,
    <11546, 10596, 11473>,
    <11546, 11473, 11471>,
    <11546, 11471, 11547>,
    <11552, 11553, 11548>,
    <11552, 11548, 11547>,
    <11552, 11547, 11471>,
    <11552, 11471, 11470>,
    <11552, 11470, 11462>,
    <11552, 11462, 11554>,
    <11552, 11554, 11555>,
    <11552, 11555, 11553>,
    <11556, 11549, 11548>,
    <11556, 11548, 11553>,
    <11556, 11553, 11555>,
    <11556, 11555, 11557>,
    <11556, 11557, 11558>,
    <11556, 11558, 11559>,
    <11556, 11559, 11550>,
    <11556, 11550, 11549>,
    <11560, 11561, 11562>,
    <11560, 11562, 11563>,
    <11560, 11563, 10689>,
    <11560, 10689, 10688>,
    <11560, 10688, 10596>,
    <11560, 10596, 11551>,
    <11560, 11551, 11550>,
    <11560, 11550, 11561>,
    <11564, 11565, 11562>,
    <11564, 11562, 11561>,
    <11564, 11561, 11550>,
    <11564, 11550, 11559>,
    <11564, 11559, 11558>,
    <11564, 11558, 11566>,
    <11564, 11566, 11567>,
    <11564, 11567, 11565>,
    <11568, 11563, 11562>,
    <11568, 11562, 11565>,
    <11568, 11565, 11567>,
    <11568, 11567, 11569>,
    <11568, 11569, 10692>,
    <11568, 10692, 10691>,
    <11568, 10691, 10689>,
    <11568, 10689, 11563>,
    <11570, 11571, 11572>,
    <11570, 11572, 11573>,
    <11570, 11573, 11574>,
    <11570, 11574, 11575>,
    <11570, 11575, 11576>,
    <11570, 11576, 11577>,
    <11570, 11577, 11578>,
    <11570, 11578, 11571>,
    <11579, 11580, 11572>,
    <11579, 11572, 11571>,
    <11579, 11571, 11578>,
    <11579, 11578, 11581>,
    <11579, 11581, 10710>,
    <11579, 10710, 10867>,
    <11579, 10867, 10866>,
    <11579, 10866, 11580>,
    <11582, 11573, 11572>,
    <11582, 11572, 11580>,
    <11582, 11580, 10866>,
    <11582, 10866, 10871>,
    <11582, 10871, 10854>,
    <11582, 10854, 11583>,
    <11582, 11583, 11574>,
    <11582, 11574, 11573>,
    <11584, 11585, 11586>,
    <11584, 11586, 11587>,
    <11584, 11587, 11588>,
    <11584, 11588, 11589>,
    <11584, 11589, 11480>,
    <11584, 11480, 11479>,
    <11584, 11479, 11478>,
    <11584, 11478, 11585>,
    <11590, 11591, 11586>,
    <11590, 11586, 11585>,
    <11590, 11585, 11478>,
    <11590, 11478, 11487>,
    <11590, 11487, 10710>,
    <11590, 10710, 11581>,
    <11590, 11581, 11578>,
    <11590, 11578, 11591>,
    <11592, 11587, 11586>,
    <11592, 11586, 11591>,
    <11592, 11591, 11578>,
    <11592, 11578, 11577>,
    <11592, 11577, 11576>,
    <11592, 11576, 11593>,
    <11592, 11593, 11588>,
    <11592, 11588, 11587>,
    <11594, 11595, 11596>,
    <11594, 11596, 11597>,
    <11594, 11597, 11519>,
    <11594, 11519, 11518>,
    <11594, 11518, 10641>,
    <11594, 10641, 11598>,
    <11594, 11598, 11599>,
    <11594, 11599, 11595>,
    <11600, 11601, 11596>,
    <11600, 11596, 11595>,
    <11600, 11595, 11599>,
    <11600, 11599, 11602>,
    <11600, 11602, 11603>,
    <11600, 11603, 11604>,
    <11600, 11604, 11605>,
    <11600, 11605, 11601>,
    <11606, 11597, 11596>,
    <11606, 11596, 11601>,
    <11606, 11601, 11605>,
    <11606, 11605, 11607>,
    <11606, 11607, 11507>,
    <11606, 11507, 11521>,
    <11606, 11521, 11519>,
    <11606, 11519, 11597>,
    <11608, 11609, 11610>,
    <11608, 11610, 11611>,
    <11608, 11611, 11599>,
    <11608, 11599, 11598>,
    <11608, 11598, 10641>,
    <11608, 10641, 10741>,
    <11608, 10741, 10739>,
    <11608, 10739, 11609>,
    <11612, 11613, 11610>,
    <11612, 11610, 11609>,
    <11612, 11609, 10739>,
    <11612, 10739, 10738>,
    <11612, 10738, 10737>,
    <11612, 10737, 11614>,
    <11612, 11614, 11615>,
    <11612, 11615, 11613>,
    <11616, 11611, 11610>,
    <11616, 11610, 11613>,
    <11616, 11613, 11615>,
    <11616, 11615, 11617>,
    <11616, 11617, 11603>,
    <11616, 11603, 11602>,
    <11616, 11602, 11599>,
    <11616, 11599, 11611>,
    <11618, 11619, 11620>,
    <11618, 11620, 11621>,
    <11618, 11621, 11622>,
    <11618, 11622, 11623>,
    <11618, 11623, 11624>,
    <11618, 11624, 11625>,
    <11618, 11625, 11626>,
    <11618, 11626, 11619>,
    <11627, 11628, 11620>,
    <11627, 11620, 11619>,
    <11627, 11619, 11626>,
    <11627, 11626, 11629>,
    <11627, 11629, 10806>,
    <11627, 10806, 10822>,
    <11627, 10822, 10819>,
    <11627, 10819, 11628>,
    <11630, 11621, 11620>,
    <11630, 11620, 11628>,
    <11630, 11628, 10819>,
    <11630, 10819, 10818>,
    <11630, 10818, 10758>,
    <11630, 10758, 11631>,
    <11630, 11631, 11622>,
    <11630, 11622, 11621>,
    <11632, 11633, 11634>,
    <11632, 11634, 11635>,
    <11632, 11635, 11530>,
    <11632, 11530, 11529>,
    <11632, 11529, 11528>,
    <11632, 11528, 11636>,
    <11632, 11636, 11637>,
    <11632, 11637, 11633>,
    <11638, 11639, 11634>,
    <11638, 11634, 11633>,
    <11638, 11633, 11637>,
    <11638, 11637, 11640>,
    <11638, 11640, 11624>,
    <11638, 11624, 11623>,
    <11638, 11623, 11622>,
    <11638, 11622, 11639>,
    <11641, 11635, 11634>,
    <11641, 11634, 11639>,
    <11641, 11639, 11622>,
    <11641, 11622, 11631>,
    <11641, 11631, 10758>,
    <11641, 10758, 11533>,
    <11641, 11533, 11530>,
    <11641, 11530, 11635>,
    <11642, 11643, 11644>,
    <11642, 11644, 11645>,
    <11642, 11645, 11615>,
    <11642, 11615, 11614>,
    <11642, 11614, 10737>,
    <11642, 10737, 11646>,
    <11642, 11646, 11647>,
    <11642, 11647, 11643>,
    <11648, 11649, 11644>,
    <11648, 11644, 11643>,
    <11648, 11643, 11647>,
    <11648, 11647, 11650>,
    <11648, 11650, 11651>,
    <11648, 11651, 11652>,
    <11648, 11652, 11653>,
    <11648, 11653, 11649>,
    <11654, 11645, 11644>,
    <11654, 11644, 11649>,
    <11654, 11649, 11653>,
    <11654, 11653, 11655>,
    <11654, 11655, 11603>,
    <11654, 11603, 11617>,
    <11654, 11617, 11615>,
    <11654, 11615, 11645>,
    <11656, 11657, 11658>,
    <11656, 11658, 11659>,
    <11656, 11659, 11647>,
    <11656, 11647, 11646>,
    <11656, 11646, 10737>,
    <11656, 10737, 10789>,
    <11656, 10789, 10787>,
    <11656, 10787, 11657>,
    <11660, 11661, 11658>,
    <11660, 11658, 11657>,
    <11660, 11657, 10787>,
    <11660, 10787, 10786>,
    <11660, 10786, 10785>,
    <11660, 10785, 11662>,
    <11660, 11662, 11663>,
    <11660, 11663, 11661>,
    <11664, 11659, 11658>,
    <11664, 11658, 11661>,
    <11664, 11661, 11663>,
    <11664, 11663, 11665>,
    <11664, 11665, 11651>,
    <11664, 11651, 11650>,
    <11664, 11650, 11647>,
    <11664, 11647, 11659>,
    <11666, 11667, 11668>,
    <11666, 11668, 11669>,
    <11666, 11669, 11670>,
    <11666, 11670, 11671>,
    <11666, 11671, 11672>,
    <11666, 11672, 11673>,
    <11666, 11673, 11674>,
    <11666, 11674, 11667>,
    <11675, 11676, 11668>,
    <11675, 11668, 11667>,
    <11675, 11667, 11674>,
    <11675, 11674, 11677>,
    <11675, 11677, 10902>,
    <11675, 10902, 10919>,
    <11675, 10919, 10916>,
    <11675, 10916, 11676>,
    <11678, 11669, 11668>,
    <11678, 11668, 11676>,
    <11678, 11676, 10916>,
    <11678, 10916, 10915>,
    <11678, 10915, 10806>,
    <11678, 10806, 11679>,
    <11678, 11679, 11670>,
    <11678, 11670, 11669>,
    <11680, 11681, 11682>,
    <11680, 11682, 11683>,
    <11680, 11683, 11626>,
    <11680, 11626, 11625>,
    <11680, 11625, 11624>,
    <11680, 11624, 11684>,
    <11680, 11684, 11685>,
    <11680, 11685, 11681>,
    <11686, 11687, 11682>,
    <11686, 11682, 11681>,
    <11686, 11681, 11685>,
    <11686, 11685, 11688>,
    <11686, 11688, 11672>,
    <11686, 11672, 11671>,
    <11686, 11671, 11670>,
    <11686, 11670, 11687>,
    <11689, 11683, 11682>,
    <11689, 11682, 11687>,
    <11689, 11687, 11670>,
    <11689, 11670, 11679>,
    <11689, 11679, 10806>,
    <11689, 10806, 11629>,
    <11689, 11629, 11626>,
    <11689, 11626, 11683>,
    <11690, 11691, 11692>,
    <11690, 11692, 11693>,
    <11690, 11693, 11694>,
    <11690, 11694, 11695>,
    <11690, 11695, 10692>,
    <11690, 10692, 11569>,
    <11690, 11569, 11567>,
    <11690, 11567, 11691>,
    <11696, 11697, 11692>,
    <11696, 11692, 11691>,
    <11696, 11691, 11567>,
    <11696, 11567, 11566>,
    <11696, 11566, 11558>,
    <11696, 11558, 11698>,
    <11696, 11698, 11699>,
    <11696, 11699, 11697>,
    <11700, 11693, 11692>,
    <11700, 11692, 11697>,
    <11700, 11697, 11699>,
    <11700, 11699, 11701>,
    <11700, 11701, 11702>,
    <11700, 11702, 11703>,
    <11700, 11703, 11694>,
    <11700, 11694, 11693>,
    <11704, 11705, 11706>,
    <11704, 11706, 11707>,
    <11704, 11707, 10833>,
    <11704, 10833, 10832>,
    <11704, 10832, 10692>,
    <11704, 10692, 11695>,
    <11704, 11695, 11694>,
    <11704, 11694, 11705>,
    <11708, 11709, 11706>,
    <11708, 11706, 11705>,
    <11708, 11705, 11694>,
    <11708, 11694, 11703>,
    <11708, 11703, 11702>,
    <11708, 11702, 11710>,
    <11708, 11710, 11711>,
    <11708, 11711, 11709>,
    <11712, 11707, 11706>,
    <11712, 11706, 11709>,
    <11712, 11709, 11711>,
    <11712, 11711, 11713>,
    <11712, 11713, 10836>,
    <11712, 10836, 10835>,
    <11712, 10835, 10833>,
    <11712, 10833, 11707>,
    <11714, 11715, 11716>,
    <11714, 11716, 11717>,
    <11714, 11717, 11718>,
    <11714, 11718, 11719>,
    <11714, 11719, 11720>,
    <11714, 11720, 11721>,
    <11714, 11721, 11722>,
    <11714, 11722, 11715>,
    <11723, 11724, 11716>,
    <11723, 11716, 11715>,
    <11723, 11715, 11722>,
    <11723, 11722, 11725>,
    <11723, 11725, 10854>,
    <11723, 10854, 11011>,
    <11723, 11011, 11010>,
    <11723, 11010, 11724>,
    <11726, 11717, 11716>,
    <11726, 11716, 11724>,
    <11726, 11724, 11010>,
    <11726, 11010, 11015>,
    <11726, 11015, 10998>,
    <11726, 10998, 11727>,
    <11726, 11727, 11718>,
    <11726, 11718, 11717>,
    <11728, 11729, 11730>,
    <11728, 11730, 11731>,
    <11728, 11731, 11732>,
    <11728, 11732, 11733>,
    <11728, 11733, 11576>,
    <11728, 11576, 11575>,
    <11728, 11575, 11574>,
    <11728, 11574, 11729>,
    <11734, 11735, 11730>,
    <11734, 11730, 11729>,
    <11734, 11729, 11574>,
    <11734, 11574, 11583>,
    <11734, 11583, 10854>,
    <11734, 10854, 11725>,
    <11734, 11725, 11722>,
    <11734, 11722, 11735>,
    <11736, 11731, 11730>,
    <11736, 11730, 11735>,
    <11736, 11735, 11722>,
    <11736, 11722, 11721>,
    <11736, 11721, 11720>,
    <11736, 11720, 11737>,
    <11736, 11737, 11732>,
    <11736, 11732, 11731>,
    <11738, 11739, 11740>,
    <11738, 11740, 11741>,
    <11738, 11741, 11663>,
    <11738, 11663, 11662>,
    <11738, 11662, 10785>,
    <11738, 10785, 11742>,
    <11738, 11742, 11743>,
    <11738, 11743, 11739>,
    <11744, 11745, 11740>,
    <11744, 11740, 11739>,
    <11744, 11739, 11743>,
    <11744, 11743, 11746>,
    <11744, 11746, 11747>,
    <11744, 11747, 11748>,
    <11744, 11748, 11749>,
    <11744, 11749, 11745>,
    <11750, 11741, 11740>,
    <11750, 11740, 11745>,
    <11750, 11745, 11749>,
    <11750, 11749, 11751>,
    <11750, 11751, 11651>,
    <11750, 11651, 11665>,
    <11750, 11665, 11663>,
    <11750, 11663, 11741>,
    <11752, 11753, 11754>,
    <11752, 11754, 11755>,
    <11752, 11755, 11743>,
    <11752, 11743, 11742>,
    <11752, 11742, 10785>,
    <11752, 10785, 10885>,
    <11752, 10885, 10883>,
    <11752, 10883, 11753>,
    <11756, 11757, 11754>,
    <11756, 11754, 11753>,
    <11756, 11753, 10883>,
    <11756, 10883, 10882>,
    <11756, 10882, 10881>,
    <11756, 10881, 11758>,
    <11756, 11758, 11759>,
    <11756, 11759, 11757>,
    <11760, 11755, 11754>,
    <11760, 11754, 11757>,
    <11760, 11757, 11759>,
    <11760, 11759, 11761>,
    <11760, 11761, 11747>,
    <11760, 11747, 11746>,
    <11760, 11746, 11743>,
    <11760, 11743, 11755>,
    <11762, 11763, 11764>,
    <11762, 11764, 11765>,
    <11762, 11765, 11766>,
    <11762, 11766, 11767>,
    <11762, 11767, 11768>,
    <11762, 11768, 11769>,
    <11762, 11769, 11770>,
    <11762, 11770, 11763>,
    <11771, 11772, 11764>,
    <11771, 11764, 11763>,
    <11771, 11763, 11770>,
    <11771, 11770, 11773>,
    <11771, 11773, 11774>,
    <11771, 11774, 10958>,
    <11771, 10958, 10955>,
    <11771, 10955, 11772>,
    <11775, 11765, 11764>,
    <11775, 11764, 11772>,
    <11775, 11772, 10955>,
    <11775, 10955, 10954>,
    <11775, 10954, 10902>,
    <11775, 10902, 11776>,
    <11775, 11776, 11766>,
    <11775, 11766, 11765>,
    <11777, 11778, 11779>,
    <11777, 11779, 11780>,
    <11777, 11780, 11674>,
    <11777, 11674, 11673>,
    <11777, 11673, 11672>,
    <11777, 11672, 11781>,
    <11777, 11781, 11782>,
    <11777, 11782, 11778>,
    <11783, 11784, 11779>,
    <11783, 11779, 11778>,
    <11783, 11778, 11782>,
    <11783, 11782, 11785>,
    <11783, 11785, 11768>,
    <11783, 11768, 11767>,
    <11783, 11767, 11766>,
    <11783, 11766, 11784>,
    <11786, 11780, 11779>,
    <11786, 11779, 11784>,
    <11786, 11784, 11766>,
    <11786, 11766, 11776>,
    <11786, 11776, 10902>,
    <11786, 10902, 11677>,
    <11786, 11677, 11674>,
    <11786, 11674, 11780>,
    <11787, 11788, 11789>,
    <11787, 11789, 11790>,
    <11787, 11790, 11759>,
    <11787, 11759, 11758>,
    <11787, 11758, 10881>,
    <11787, 10881, 11791>,
    <11787, 11791, 11792>,
    <11787, 11792, 11788>,
    <11793, 11794, 11789>,
    <11793, 11789, 11788>,
    <11793, 11788, 11792>,
    <11793, 11792, 11795>,
    <11793, 11795, 11796>,
    <11793, 11796, 11797>,
    <11793, 11797, 11798>,
    <11793, 11798, 11794>,
    <11799, 11790, 11789>,
    <11799, 11789, 11794>,
    <11799, 11794, 11798>,
    <11799, 11798, 11800>,
    <11799, 11800, 11747>,
    <11799, 11747, 11761>,
    <11799, 11761, 11759>,
    <11799, 11759, 11790>,
    <11801, 11802, 11803>,
    <11801, 11803, 11804>,
    <11801, 11804, 11792>,
    <11801, 11792, 11791>,
    <11801, 11791, 10881>,
    <11801, 10881, 10934>,
    <11801, 10934, 10932>,
    <11801, 10932, 11802>,
    <11805, 11806, 11803>,
    <11805, 11803, 11802>,
    <11805, 11802, 10932>,
    <11805, 10932, 10931>,
    <11805, 10931, 11807>,
    <11805, 11807, 11808>,
    <11805, 11809, 11810>,
    <11805, 11810, 11806>,
    <11811, 11804, 11803>,
    <11811, 11803, 11806>,
    <11811, 11806, 11812>,
    <11811, 11812, 11813>,
    <11811, 11814, 11815>,
    <11811, 11815, 11795>,
    <11811, 11795, 11792>,
    <11811, 11792, 11804>,
    <11816, 11817, 11818>,
    <11816, 11818, 11819>,
    <11816, 11819, 11770>,
    <11816, 11770, 11769>,
    <11816, 11769, 11768>,
    <11816, 11768, 11820>,
    <11816, 11820, 11821>,
    <11816, 11821, 11817>,
    <11822, 11823, 11818>,
    <11822, 11818, 11817>,
    <11822, 11817, 11821>,
    <11822, 11821, 11824>,
    <11822, 11824, 11825>,
    <11822, 11825, 11826>,
    <11822, 11827, 11828>,
    <11822, 11828, 11823>,
    <11829, 11819, 11818>,
    <11829, 11818, 11823>,
    <11829, 11823, 11830>,
    <11829, 11830, 11831>,
    <11829, 11832, 11833>,
    <11829, 11833, 11773>,
    <11829, 11773, 11770>,
    <11829, 11770, 11819>,
    <11834, 11835, 11836>,
    <11834, 11836, 11837>,
    <11834, 11837, 11838>,
    <11834, 11838, 11839>,
    <11834, 11839, 10836>,
    <11834, 10836, 11713>,
    <11834, 11713, 11711>,
    <11834, 11711, 11835>,
    <11840, 11841, 11836>,
    <11840, 11836, 11835>,
    <11840, 11835, 11711>,
    <11840, 11711, 11710>,
    <11840, 11710, 11702>,
    <11840, 11702, 11842>,
    <11840, 11842, 11843>,
    <11840, 11843, 11841>,
    <11844, 11837, 11836>,
    <11844, 11836, 11841>,
    <11844, 11841, 11843>,
    <11844, 11843, 11845>,
    <11844, 11845, 11846>,
    <11844, 11846, 11847>,
    <11844, 11847, 11838>,
    <11844, 11838, 11837>,
    <11848, 11849, 11850>,
    <11848, 11850, 11851>,
    <11848, 11851, 10977>,
    <11848, 10977, 10976>,
    <11848, 10976, 10836>,
    <11848, 10836, 11839>,
    <11848, 11839, 11838>,
    <11848, 11838, 11849>,
    <11852, 11853, 11850>,
    <11852, 11850, 11849>,
    <11852, 11849, 11838>,
    <11852, 11838, 11847>,
    <11852, 11847, 11846>,
    <11852, 11846, 11854>,
    <11852, 11854, 11855>,
    <11852, 11855, 11853>,
    <11856, 11851, 11850>,
    <11856, 11850, 11853>,
    <11856, 11853, 11855>,
    <11856, 11855, 11857>,
    <11856, 11857, 10980>,
    <11856, 10980, 10979>,
    <11856, 10979, 10977>,
    <11856, 10977, 11851>,
    <11858, 11859, 11860>,
    <11858, 11860, 11861>,
    <11858, 11861, 11862>,
    <11858, 11862, 11863>,
    <11858, 11863, 11864>,
    <11858, 11864, 11865>,
    <11858, 11865, 11866>,
    <11858, 11866, 11859>,
    <11867, 11868, 11860>,
    <11867, 11860, 11859>,
    <11867, 11859, 11866>,
    <11867, 11866, 11869>,
    <11867, 11869, 10998>,
    <11867, 10998, 11059>,
    <11867, 11059, 11058>,
    <11867, 11058, 11868>,
    <11870, 11861, 11860>,
    <11870, 11860, 11868>,
    <11870, 11868, 11058>,
    <11870, 11058, 11063>,
    <11870, 11063, 11046>,
    <11870, 11046, 11871>,
    <11870, 11871, 11862>,
    <11870, 11862, 11861>,
    <11872, 11873, 11874>,
    <11872, 11874, 11875>,
    <11872, 11875, 11876>,
    <11872, 11876, 11877>,
    <11872, 11877, 11720>,
    <11872, 11720, 11719>,
    <11872, 11719, 11718>,
    <11872, 11718, 11873>,
    <11878, 11879, 11874>,
    <11878, 11874, 11873>,
    <11878, 11873, 11718>,
    <11878, 11718, 11727>,
    <11878, 11727, 10998>,
    <11878, 10998, 11869>,
    <11878, 11869, 11866>,
    <11878, 11866, 11879>,
    <11880, 11875, 11874>,
    <11880, 11874, 11879>,
    <11880, 11879, 11866>,
    <11880, 11866, 11865>,
    <11880, 11865, 11864>,
    <11880, 11864, 11881>,
    <11880, 11881, 11876>,
    <11880, 11876, 11875>,
    <11882, 11883, 11884>,
    <11882, 11884, 11885>,
    <11882, 11885, 11886>,
    <11882, 11886, 11887>,
    <11882, 11887, 10980>,
    <11882, 10980, 11857>,
    <11882, 11857, 11855>,
    <11882, 11855, 11883>,
    <11888, 11889, 11884>,
    <11888, 11884, 11883>,
    <11888, 11883, 11855>,
    <11888, 11855, 11854>,
    <11888, 11854, 11846>,
    <11888, 11846, 11890>,
    <11888, 11890, 11891>,
    <11888, 11891, 11889>,
    <11892, 11885, 11884>,
    <11892, 11884, 11889>,
    <11892, 11889, 11891>,
    <11892, 11891, 11893>,
    <11892, 11893, 11894>,
    <11892, 11894, 11895>,
    <11892, 11895, 11886>,
    <11892, 11886, 11885>,
    <11896, 11897, 11898>,
    <11896, 11898, 11899>,
    <11896, 11899, 11025>,
    <11896, 11025, 11024>,
    <11896, 11024, 10980>,
    <11896, 10980, 11887>,
    <11896, 11887, 11886>,
    <11896, 11886, 11897>,
    <11900, 11901, 11898>,
    <11900, 11898, 11897>,
    <11900, 11897, 11886>,
    <11900, 11886, 11895>,
    <11900, 11895, 11894>,
    <11900, 11894, 11902>,
    <11900, 11902, 11903>,
    <11900, 11903, 11901>,
    <11904, 11899, 11898>,
    <11904, 11898, 11901>,
    <11904, 11901, 11903>,
    <11904, 11903, 11905>,
    <11904, 11905, 11028>,
    <11904, 11028, 11027>,
    <11904, 11027, 11025>,
    <11904, 11025, 11899>,
    <11906, 11907, 11908>,
    <11906, 11908, 11909>,
    <11906, 11909, 11910>,
    <11906, 11910, 11911>,
    <11906, 11911, 11912>,
    <11906, 11912, 11913>,
    <11906, 11913, 11914>,
    <11906, 11914, 11907>,
    <11915, 11916, 11908>,
    <11915, 11908, 11907>,
    <11915, 11907, 11914>,
    <11915, 11914, 11917>,
    <11915, 11917, 11046>,
    <11915, 11046, 11089>,
    <11915, 11089, 11088>,
    <11915, 11088, 11916>,
    <11918, 11909, 11908>,
    <11918, 11908, 11916>,
    <11918, 11916, 11088>,
    <11918, 11088, 11093>,
    <11918, 11093, 1939>,
    <11918, 1939, 11919>,
    <11918, 11919, 11910>,
    <11918, 11910, 11909>,
    <11920, 11921, 11922>,
    <11920, 11922, 11923>,
    <11920, 11923, 11924>,
    <11920, 11924, 11925>,
    <11920, 11925, 11864>,
    <11920, 11864, 11863>,
    <11920, 11863, 11862>,
    <11920, 11862, 11921>,
    <11926, 11927, 11922>,
    <11926, 11922, 11921>,
    <11926, 11921, 11862>,
    <11926, 11862, 11871>,
    <11926, 11871, 11046>,
    <11926, 11046, 11917>,
    <11926, 11917, 11914>,
    <11926, 11914, 11927>,
    <11928, 11923, 11922>,
    <11928, 11922, 11927>,
    <11928, 11927, 11914>,
    <11928, 11914, 11913>,
    <11928, 11913, 11912>,
    <11928, 11912, 11929>,
    <11928, 11929, 11924>,
    <11928, 11924, 11923>,
    <11930, 11931, 11932>,
    <11930, 11932, 11933>,
    <11930, 11933, 11934>,
    <11930, 11934, 11935>,
    <11930, 11935, 11028>,
    <11930, 11028, 11905>,
    <11930, 11905, 11903>,
    <11930, 11903, 11931>,
    <11936, 11937, 11932>,
    <11936, 11932, 11931>,
    <11936, 11931, 11903>,
    <11936, 11903, 11902>,
    <11936, 11902, 11894>,
    <11936, 11894, 11938>,
    <11936, 11938, 11939>,
    <11936, 11939, 11937>,
    <11940, 11933, 11932>,
    <11940, 11932, 11937>,
    <11940, 11937, 11939>,
    <11940, 11939, 11941>,
    <11940, 11941, 2251>,
    <11940, 2251, 11942>,
    <11940, 11942, 11934>,
    <11940, 11934, 11933>,
    <11943, 11944, 11945>,
    <11943, 11945, 11946>,
    <11943, 11946, 11073>,
    <11943, 11073, 11072>,
    <11943, 11072, 11028>,
    <11943, 11028, 11935>,
    <11943, 11935, 11934>,
    <11943, 11934, 11944>,
    <11947, 11948, 11945>,
    <11947, 11945, 11944>,
    <11947, 11944, 11934>,
    <11947, 11934, 11942>,
    <11947, 11942, 2251>,
    <11947, 2251, 2270>,
    <11947, 2270, 2268>,
    <11947, 2268, 11948>,
    <11949, 11946, 11945>,
    <11949, 11945, 11948>,
    <11949, 11948, 2268>,
    <11949, 2268, 2267>,
    <11949, 2267, 1888>,
    <11949, 1888, 11075>,
    <11949, 11075, 11073>,
    <11949, 11073, 11946>,
    <11950, 11951, 11952>,
    <11950, 11952, 11953>,
    <11950, 11953, 11954>,
    <11950, 11954, 11955>,
    <11950, 11955, 11912>,
    <11950, 11912, 11911>,
    <11950, 11911, 11910>,
    <11950, 11910, 11951>,
    <11956, 11957, 11952>,
    <11956, 11952, 11951>,
    <11956, 11951, 11910>,
    <11956, 11910, 11919>,
    <11956, 11919, 1939>,
    <11956, 1939, 2285>,
    <11956, 2285, 2283>,
    <11956, 2283, 11957>,
    <11958, 11953, 11952>,
    <11958, 11952, 11957>,
    <11958, 11957, 2283>,
    <11958, 2283, 2282>,
    <11958, 2282, 2281>,
    <11958, 2281, 11959>,
    <11958, 11959, 11954>,
    <11958, 11954, 11953>,
    <11960, 11961, 11962>,
    <11960, 11962, 11963>,
    <11960, 11963, 11964>,
    <11960, 11964, 11965>,
    <11960, 11965, 11966>,
    <11960, 11966, 11967>,
    <11960, 11968, 11969>,
    <11960, 11969, 11961>,
    <11970, 11971, 11962>,
    <11970, 11962, 11961>,
    <11970, 11961, 11972>,
    <11970, 11972, 11973>,
    <11970, 11974, 11975>,
    <11970, 11975, 11165>,
    <11970, 11165, 11163>,
    <11970, 11163, 11971>,
    <11976, 11963, 11962>,
    <11976, 11962, 11971>,
    <11976, 11971, 11163>,
    <11976, 11163, 11162>,
    <11976, 11162, 11161>,
    <11976, 11161, 11977>,
    <11976, 11977, 11964>,
    <11976, 11964, 11963>,
    <11978, 11979, 11980>,
    <11978, 11980, 11981>,
    <11978, 11981, 11982>,
    <11978, 11982, 11983>,
    <11978, 11984, 11985>,
    <11978, 11985, 11986>,
    <11978, 11986, 11987>,
    <11978, 11987, 11979>,
    <11988, 11989, 11980>,
    <11988, 11980, 11979>,
    <11988, 11979, 11987>,
    <11988, 11987, 11990>,
    <11988, 11990, 11209>,
    <11988, 11209, 11259>,
    <11988, 11259, 11257>,
    <11988, 11257, 11989>,
    <11991, 11981, 11980>,
    <11991, 11980, 11989>,
    <11991, 11989, 11257>,
    <11991, 11257, 11256>,
    <11991, 11256, 11992>,
    <11991, 11992, 11993>,
    <11991, 11994, 11995>,
    <11991, 11995, 11981>,
    <11996, 11997, 11998>,
    <11996, 11998, 11999>,
    <11996, 11999, 12000>,
    <11996, 12000, 12001>,
    <11996, 12001, 12002>,
    <11996, 12002, 12003>,
    <11996, 12004, 12005>,
    <11996, 12005, 11997>,
    <12006, 12007, 11998>,
    <12006, 11998, 11997>,
    <12006, 11997, 12008>,
    <12006, 12008, 12009>,
    <12006, 12010, 12011>,
    <12006, 12011, 11396>,
    <12006, 11396, 11395>,
    <12006, 11395, 12007>,
    <12012, 11999, 11998>,
    <12012, 11998, 12007>,
    <12012, 12007, 11395>,
    <12012, 11395, 11401>,
    <12012, 11401, 11383>,
    <12012, 11383, 12013>,
    <12012, 12013, 12000>,
    <12012, 12000, 11999>,
    <12014, 12015, 12016>,
    <12014, 12016, 12017>,
    <12014, 12017, 12018>,
    <12014, 12018, 12019>,
    <12014, 12020, 12021>,
    <12014, 12021, 12022>,
    <12014, 12022, 12023>,
    <12014, 12023, 12015>,
    <12024, 12025, 12016>,
    <12024, 12016, 12015>,
    <12024, 12015, 12023>,
    <12024, 12023, 12026>,
    <12024, 12026, 12027>,
    <12024, 12027, 12028>,
    <12024, 12028, 12029>,
    <12024, 12029, 12025>,
    <12030, 12017, 12016>,
    <12030, 12016, 12025>,
    <12030, 12025, 12029>,
    <12030, 12029, 12031>,
    <12030, 12031, 12032>,
    <12030, 12032, 12033>,
    <12030, 12034, 12035>,
    <12030, 12035, 12017>,
    <12036, 12037, 12038>,
    <12036, 12038, 12039>,
    <12036, 12039, 12023>,
    <12036, 12023, 12022>,
    <12036, 12022, 12040>,
    <12036, 12040, 12041>,
    <12036, 12042, 12043>,
    <12036, 12043, 12037>,
    <12044, 12045, 12038>,
    <12044, 12038, 12037>,
    <12044, 12037, 12046>,
    <12044, 12046, 12047>,
    <12044, 12048, 12049>,
    <12044, 12049, 12050>,
    <12044, 12050, 12051>,
    <12044, 12051, 12045>,
    <12052, 12039, 12038>,
    <12052, 12038, 12045>,
    <12052, 12045, 12051>,
    <12052, 12051, 12053>,
    <12052, 12053, 12027>,
    <12052, 12027, 12026>,
    <12052, 12026, 12023>,
    <12052, 12023, 12039>,
    <12054, 12055, 12056>,
    <12054, 12056, 12057>,
    <12054, 12057, 12051>,
    <12054, 12051, 12050>,
    <12054, 12050, 12058>,
    <12054, 12058, 11965>,
    <12054, 11965, 11964>,
    <12054, 11964, 12055>,
    <12059, 12060, 12056>,
    <12059, 12056, 12055>,
    <12059, 12055, 11964>,
    <12059, 11964, 11977>,
    <12059, 11977, 11161>,
    <12059, 11161, 12061>,
    <12059, 12061, 12062>,
    <12059, 12062, 12060>,
    <12063, 12057, 12056>,
    <12063, 12056, 12060>,
    <12063, 12060, 12062>,
    <12063, 12062, 12064>,
    <12063, 12064, 12027>,
    <12063, 12027, 12053>,
    <12063, 12053, 12051>,
    <12063, 12051, 12057>,
    <12065, 12066, 12067>,
    <12065, 12067, 12068>,
    <12065, 12068, 11987>,
    <12065, 11987, 11986>,
    <12065, 11986, 12069>,
    <12065, 12069, 12070>,
    <12065, 12070, 12071>,
    <12065, 12071, 12066>,
    <12072, 12073, 12067>,
    <12072, 12067, 12066>,
    <12072, 12066, 12071>,
    <12072, 12071, 12074>,
    <12072, 12074, 12075>,
    <12072, 12075, 12076>,
    <12072, 12076, 12077>,
    <12072, 12077, 12073>,
    <12078, 12068, 12067>,
    <12078, 12067, 12073>,
    <12078, 12073, 12077>,
    <12078, 12077, 12079>,
    <12078, 12079, 11209>,
    <12078, 11209, 11990>,
    <12078, 11990, 11987>,
    <12078, 11987, 12068>,
    <12080, 12081, 12082>,
    <12080, 12082, 12083>,
    <12080, 12083, 12077>,
    <12080, 12077, 12076>,
    <12080, 12076, 12075>,
    <12080, 12075, 12084>,
    <12080, 12084, 12085>,
    <12080, 12085, 12081>,
    <12086, 12087, 12082>,
    <12086, 12082, 12081>,
    <12086, 12081, 12085>,
    <12086, 12085, 12088>,
    <12086, 12088, 11308>,
    <12086, 11308, 11324>,
    <12086, 11324, 11321>,
    <12086, 11321, 12087>,
    <12089, 12083, 12082>,
    <12089, 12082, 12087>,
    <12089, 12087, 11321>,
    <12089, 11321, 11320>,
    <12089, 11320, 11209>,
    <12089, 11209, 12079>,
    <12089, 12079, 12077>,
    <12089, 12077, 12083>,
    <12090, 12091, 12092>,
    <12090, 12092, 12093>,
    <12090, 12093, 12071>,
    <12090, 12071, 12070>,
    <12090, 12070, 12094>,
    <12090, 12094, 12095>,
    <12090, 12096, 12097>,
    <12090, 12097, 12091>,
    <12098, 12099, 12092>,
    <12098, 12092, 12091>,
    <12098, 12091, 12100>,
    <12098, 12100, 12101>,
    <12098, 12102, 12103>,
    <12098, 12103, 12104>,
    <12098, 12104, 12105>,
    <12098, 12105, 12099>,
    <12106, 12093, 12092>,
    <12106, 12092, 12099>,
    <12106, 12099, 12105>,
    <12106, 12105, 12107>,
    <12106, 12107, 12075>,
    <12106, 12075, 12074>,
    <12106, 12074, 12071>,
    <12106, 12071, 12093>,
    <12108, 12109, 12110>,
    <12108, 12110, 12111>,
    <12108, 12111, 12105>,
    <12108, 12105, 12104>,
    <12108, 12104, 12112>,
    <12108, 12112, 12113>,
    <12108, 12114, 12115>,
    <12108, 12115, 12109>,
    <12116, 12117, 12110>,
    <12116, 12110, 12109>,
    <12116, 12109, 12118>,
    <12116, 12118, 12119>,
    <12116, 12120, 12121>,
    <12116, 12121, 12122>,
    <12116, 12122, 12123>,
    <12116, 12123, 12117>,
    <12124, 12111, 12110>,
    <12124, 12110, 12117>,
    <12124, 12117, 12123>,
    <12124, 12123, 12125>,
    <12124, 12125, 12075>,
    <12124, 12075, 12107>,
    <12124, 12107, 12105>,
    <12124, 12105, 12111>,
    <12126, 12127, 12128>,
    <12126, 12128, 12129>,
    <12126, 12129, 12130>,
    <12126, 12130, 12131>,
    <12126, 12131, 12132>,
    <12126, 12132, 12133>,
    <12126, 12134, 12135>,
    <12126, 12135, 12127>,
    <12136, 12137, 12128>,
    <12136, 12128, 12127>,
    <12136, 12127, 12138>,
    <12136, 12138, 12139>,
    <12136, 12140, 12141>,
    <12136, 12141, 12001>,
    <12136, 12001, 12000>,
    <12136, 12000, 12137>,
    <12142, 12129, 12128>,
    <12142, 12128, 12137>,
    <12142, 12137, 12000>,
    <12142, 12000, 12013>,
    <12142, 12013, 11383>,
    <12142, 11383, 12143>,
    <12142, 12143, 12130>,
    <12142, 12130, 12129>,
    <12144, 12145, 12146>,
    <12144, 12146, 12147>,
    <12144, 12147, 12062>,
    <12144, 12062, 12061>,
    <12144, 12061, 11161>,
    <12144, 11161, 12148>,
    <12144, 12148, 12149>,
    <12144, 12149, 12145>,
    <12150, 12151, 12146>,
    <12150, 12146, 12145>,
    <12150, 12145, 12149>,
    <12150, 12149, 12152>,
    <12150, 12152, 12153>,
    <12150, 12153, 12154>,
    <12150, 12154, 12155>,
    <12150, 12155, 12151>,
    <12156, 12147, 12146>,
    <12156, 12146, 12151>,
    <12156, 12151, 12155>,
    <12156, 12155, 12157>,
    <12156, 12157, 12027>,
    <12156, 12027, 12064>,
    <12156, 12064, 12062>,
    <12156, 12062, 12147>,
    <12158, 12159, 12160>,
    <12158, 12160, 12161>,
    <12158, 12161, 12149>,
    <12158, 12149, 12148>,
    <12158, 12148, 11161>,
    <12158, 11161, 11291>,
    <12158, 11291, 11289>,
    <12158, 11289, 12159>,
    <12162, 12163, 12160>,
    <12162, 12160, 12159>,
    <12162, 12159, 11289>,
    <12162, 11289, 11288>,
    <12162, 11288, 11287>,
    <12162, 11287, 12164>,
    <12162, 12164, 12165>,
    <12162, 12165, 12163>,
    <12166, 12161, 12160>,
    <12166, 12160, 12163>,
    <12166, 12163, 12165>,
    <12166, 12165, 12167>,
    <12166, 12167, 12153>,
    <12166, 12153, 12152>,
    <12166, 12152, 12149>,
    <12166, 12149, 12161>,
    <12168, 12169, 12170>,
    <12168, 12170, 12171>,
    <12168, 12171, 12172>,
    <12168, 12172, 12173>,
    <12168, 12173, 12174>,
    <12168, 12174, 12175>,
    <12168, 12175, 12176>,
    <12168, 12176, 12169>,
    <12177, 12178, 12170>,
    <12177, 12170, 12169>,
    <12177, 12169, 12176>,
    <12177, 12176, 12179>,
    <12177, 12179, 11432>,
    <12177, 11432, 11448>,
    <12177, 11448, 11445>,
    <12177, 11445, 12178>,
    <12180, 12171, 12170>,
    <12180, 12170, 12178>,
    <12180, 12178, 11445>,
    <12180, 11445, 11444>,
    <12180, 11444, 11308>,
    <12180, 11308, 12181>,
    <12180, 12181, 12172>,
    <12180, 12172, 12171>,
    <12182, 12183, 12184>,
    <12182, 12184, 12185>,
    <12182, 12185, 12085>,
    <12182, 12085, 12084>,
    <12182, 12084, 12075>,
    <12182, 12075, 12186>,
    <12182, 12186, 12187>,
    <12182, 12187, 12183>,
    <12188, 12189, 12184>,
    <12188, 12184, 12183>,
    <12188, 12183, 12187>,
    <12188, 12187, 12190>,
    <12188, 12190, 12174>,
    <12188, 12174, 12173>,
    <12188, 12173, 12172>,
    <12188, 12172, 12189>,
    <12191, 12185, 12184>,
    <12191, 12184, 12189>,
    <12191, 12189, 12172>,
    <12191, 12172, 12181>,
    <12191, 12181, 11308>,
    <12191, 11308, 12088>,
    <12191, 12088, 12085>,
    <12191, 12085, 12185>,
    <12192, 12193, 12194>,
    <12192, 12194, 12195>,
    <12192, 12195, 12196>,
    <12192, 12196, 12197>,
    <12192, 12197, 12198>,
    <12192, 12198, 12199>,
    <12192, 12200, 12201>,
    <12192, 12201, 12193>,
    <12202, 12203, 12194>,
    <12202, 12194, 12193>,
    <12202, 12193, 12204>,
    <12202, 12204, 12205>,
    <12202, 12206, 12207>,
    <12202, 12207, 12208>,
    <12202, 12208, 12209>,
    <12202, 12209, 12203>,
    <12210, 12195, 12194>,
    <12210, 12194, 12203>,
    <12210, 12203, 12209>,
    <12210, 12209, 12211>,
    <12210, 12211, 12212>,
    <12210, 12212, 12213>,
    <12210, 12213, 12196>,
    <12210, 12196, 12195>,
    <12214, 12215, 12216>,
    <12214, 12216, 12217>,
    <12214, 12217, 12218>,
    <12214, 12218, 12219>,
    <12214, 12219, 12220>,
    <12214, 12220, 12221>,
    <12214, 12222, 12223>,
    <12214, 12223, 12215>,
    <12224, 12225, 12216>,
    <12224, 12216, 12215>,
    <12224, 12215, 12226>,
    <12224, 12226, 12227>,
    <12224, 12228, 12229>,
    <12224, 12229, 12197>,
    <12224, 12197, 12196>,
    <12224, 12196, 12225>,
    <12230, 12217, 12216>,
    <12230, 12216, 12225>,
    <12230, 12225, 12196>,
    <12230, 12196, 12213>,
    <12230, 12213, 12212>,
    <12230, 12212, 12231>,
    <12230, 12231, 12218>,
    <12230, 12218, 12217>,
    <12232, 12233, 12234>,
    <12232, 12234, 12235>,
    <12232, 12235, 11343>,
    <12232, 11343, 11342>,
    <12232, 11342, 12236>,
    <12232, 12236, 12219>,
    <12232, 12219, 12218>,
    <12232, 12218, 12233>,
    <12237, 12238, 12234>,
    <12237, 12234, 12233>,
    <12237, 12233, 12218>,
    <12237, 12218, 12231>,
    <12237, 12231, 12212>,
    <12237, 12212, 12239>,
    <12237, 12239, 12240>,
    <12237, 12240, 12238>,
    <12241, 12235, 12234>,
    <12241, 12234, 12238>,
    <12241, 12238, 12240>,
    <12241, 12240, 12242>,
    <12241, 12242, 11346>,
    <12241, 11346, 11345>,
    <12241, 11345, 11343>,
    <12241, 11343, 12235>,
    <12243, 12244, 12245>,
    <12243, 12245, 12246>,
    <12243, 12246, 12247>,
    <12243, 12247, 12248>,
    <12243, 12248, 12249>,
    <12243, 12249, 12250>,
    <12243, 12250, 12251>,
    <12243, 12251, 12244>,
    <12252, 12253, 12245>,
    <12252, 12245, 12244>,
    <12252, 12244, 12251>,
    <12252, 12251, 12254>,
    <12252, 12254, 11383>,
    <12252, 11383, 11493>,
    <12252, 11493, 11492>,
    <12252, 11492, 12253>,
    <12255, 12246, 12245>,
    <12255, 12245, 12253>,
    <12255, 12253, 11492>,
    <12255, 11492, 11497>,
    <12255, 11497, 11480>,
    <12255, 11480, 12256>,
    <12255, 12256, 12247>,
    <12255, 12247, 12246>,
    <12257, 12258, 12259>,
    <12257, 12259, 12260>,
    <12257, 12260, 12261>,
    <12257, 12261, 12262>,
    <12257, 12262, 12263>,
    <12257, 12263, 12131>,
    <12257, 12131, 12130>,
    <12257, 12130, 12258>,
    <12264, 12265, 12259>,
    <12264, 12259, 12258>,
    <12264, 12258, 12130>,
    <12264, 12130, 12143>,
    <12264, 12143, 11383>,
    <12264, 11383, 12254>,
    <12264, 12254, 12251>,
    <12264, 12251, 12265>,
    <12266, 12260, 12259>,
    <12266, 12259, 12265>,
    <12266, 12265, 12251>,
    <12266, 12251, 12250>,
    <12266, 12250, 12249>,
    <12266, 12249, 12267>,
    <12266, 12267, 12261>,
    <12266, 12261, 12260>,
    <12268, 12269, 12270>,
    <12268, 12270, 12271>,
    <12268, 12271, 12165>,
    <12268, 12165, 12164>,
    <12268, 12164, 11287>,
    <12268, 11287, 12272>,
    <12268, 12272, 12273>,
    <12268, 12273, 12269>,
    <12274, 12275, 12270>,
    <12274, 12270, 12269>,
    <12274, 12269, 12273>,
    <12274, 12273, 12276>,
    <12274, 12276, 12277>,
    <12274, 12277, 12278>,
    <12274, 12278, 12279>,
    <12274, 12279, 12275>,
    <12280, 12271, 12270>,
    <12280, 12270, 12275>,
    <12280, 12275, 12279>,
    <12280, 12279, 12281>,
    <12280, 12281, 12153>,
    <12280, 12153, 12167>,
    <12280, 12167, 12165>,
    <12280, 12165, 12271>,
    <12282, 12283, 12284>,
    <12282, 12284, 12285>,
    <12282, 12285, 12273>,
    <12282, 12273, 12272>,
    <12282, 12272, 11287>,
    <12282, 11287, 11415>,
    <12282, 11415, 11413>,
    <12282, 11413, 12283>,
    <12286, 12287, 12284>,
    <12286, 12284, 12283>,
    <12286, 12283, 11413>,
    <12286, 11413, 11412>,
    <12286, 11412, 11411>,
    <12286, 11411, 12288>,
    <12286, 12288, 12289>,
    <12286, 12289, 12287>,
    <12290, 12285, 12284>,
    <12290, 12284, 12287>,
    <12290, 12287, 12289>,
    <12290, 12289, 12291>,
    <12290, 12291, 12277>,
    <12290, 12277, 12276>,
    <12290, 12276, 12273>,
    <12290, 12273, 12285>,
    <12292, 12293, 12294>,
    <12292, 12294, 12295>,
    <12292, 12295, 12296>,
    <12292, 12296, 12297>,
    <12292, 12297, 12298>,
    <12292, 12298, 12299>,
    <12292, 12299, 12300>,
    <12292, 12300, 12293>,
    <12301, 12302, 12294>,
    <12301, 12294, 12293>,
    <12301, 12293, 12300>,
    <12301, 12300, 12303>,
    <12301, 12303, 11528>,
    <12301, 11528, 11544>,
    <12301, 11544, 11541>,
    <12301, 11541, 12302>,
    <12304, 12295, 12294>,
    <12304, 12294, 12302>,
    <12304, 12302, 11541>,
    <12304, 11541, 11540>,
    <12304, 11540, 11432>,
    <12304, 11432, 12305>,
    <12304, 12305, 12296>,
    <12304, 12296, 12295>,
    <12306, 12307, 12308>,
    <12306, 12308, 12309>,
    <12306, 12309, 12176>,
    <12306, 12176, 12175>,
    <12306, 12175, 12174>,
    <12306, 12174, 12310>,
    <12306, 12310, 12311>,
    <12306, 12311, 12307>,
    <12312, 12313, 12308>,
    <12312, 12308, 12307>,
    <12312, 12307, 12311>,
    <12312, 12311, 12314>,
    <12312, 12314, 12298>,
    <12312, 12298, 12297>,
    <12312, 12297, 12296>,
    <12312, 12296, 12313>,
    <12315, 12309, 12308>,
    <12315, 12308, 12313>,
    <12315, 12313, 12296>,
    <12315, 12296, 12305>,
    <12315, 12305, 11432>,
    <12315, 11432, 12179>,
    <12315, 12179, 12176>,
    <12315, 12176, 12309>,
    <12316, 12317, 12318>,
    <12316, 12318, 12319>,
    <12316, 12319, 12320>,
    <12316, 12320, 12321>,
    <12316, 12321, 11346>,
    <12316, 11346, 12242>,
    <12316, 12242, 12240>,
    <12316, 12240, 12317>,
    <12322, 12323, 12318>,
    <12322, 12318, 12317>,
    <12322, 12317, 12240>,
    <12322, 12240, 12239>,
    <12322, 12239, 12212>,
    <12322, 12212, 12324>,
    <12322, 12324, 12325>,
    <12322, 12325, 12323>,
    <12326, 12319, 12318>,
    <12326, 12318, 12323>,
    <12326, 12323, 12325>,
    <12326, 12325, 12327>,
    <12326, 12327, 12328>,
    <12326, 12328, 12329>,
    <12326, 12329, 12320>,
    <12326, 12320, 12319>,
    <12330, 12331, 12332>,
    <12330, 12332, 12333>,
    <12330, 12333, 11459>,
    <12330, 11459, 11458>,
    <12330, 11458, 11346>,
    <12330, 11346, 12321>,
    <12330, 12321, 12320>,
    <12330, 12320, 12331>,
    <12334, 12335, 12332>,
    <12334, 12332, 12331>,
    <12334, 12331, 12320>,
    <12334, 12320, 12329>,
    <12334, 12329, 12328>,
    <12334, 12328, 12336>,
    <12334, 12336, 12337>,
    <12334, 12337, 12335>,
    <12338, 12333, 12332>,
    <12338, 12332, 12335>,
    <12338, 12335, 12337>,
    <12338, 12337, 12339>,
    <12338, 12339, 11462>,
    <12338, 11462, 11461>,
    <12338, 11461, 11459>,
    <12338, 11459, 12333>,
    <12340, 12341, 12342>,
    <12340, 12342, 12343>,
    <12340, 12343, 12344>,
    <12340, 12344, 12345>,
    <12340, 12345, 12346>,
    <12340, 12346, 12347>,
    <12340, 12347, 12348>,
    <12340, 12348, 12341>,
    <12349, 12350, 12342>,
    <12349, 12342, 12341>,
    <12349, 12341, 12348>,
    <12349, 12348, 12351>,
    <12349, 12351, 11480>,
    <12349, 11480, 11589>,
    <12349, 11589, 11588>,
    <12349, 11588, 12350>,
    <12352, 12343, 12342>,
    <12352, 12342, 12350>,
    <12352, 12350, 11588>,
    <12352, 11588, 11593>,
    <12352, 11593, 11576>,
    <12352, 11576, 12353>,
    <12352, 12353, 12344>,
    <12352, 12344, 12343>,
    <12354, 12355, 12356>,
    <12354, 12356, 12357>,
    <12354, 12357, 12358>,
    <12354, 12358, 12359>,
    <12354, 12359, 12249>,
    <12354, 12249, 12248>,
    <12354, 12248, 12247>,
    <12354, 12247, 12355>,
    <12360, 12361, 12356>,
    <12360, 12356, 12355>,
    <12360, 12355, 12247>,
    <12360, 12247, 12256>,
    <12360, 12256, 11480>,
    <12360, 11480, 12351>,
    <12360, 12351, 12348>,
    <12360, 12348, 12361>,
    <12362, 12357, 12356>,
    <12362, 12356, 12361>,
    <12362, 12361, 12348>,
    <12362, 12348, 12347>,
    <12362, 12347, 12346>,
    <12362, 12346, 12363>,
    <12362, 12363, 12358>,
    <12362, 12358, 12357>,
    <12364, 12365, 12366>,
    <12364, 12366, 12367>,
    <12364, 12367, 12289>,
    <12364, 12289, 12288>,
    <12364, 12288, 11411>,
    <12364, 11411, 12368>,
    <12364, 12368, 12369>,
    <12364, 12369, 12365>,
    <12370, 12371, 12366>,
    <12370, 12366, 12365>,
    <12370, 12365, 12369>,
    <12370, 12369, 12372>,
    <12370, 12372, 12373>,
    <12370, 12373, 12374>,
    <12370, 12374, 12375>,
    <12370, 12375, 12371>,
    <12376, 12367, 12366>,
    <12376, 12366, 12371>,
    <12376, 12371, 12375>,
    <12376, 12375, 12377>,
    <12376, 12377, 12277>,
    <12376, 12277, 12291>,
    <12376, 12291, 12289>,
    <12376, 12289, 12367>,
    <12378, 12379, 12380>,
    <12378, 12380, 12381>,
    <12378, 12381, 12369>,
    <12378, 12369, 12368>,
    <12378, 12368, 11411>,
    <12378, 11411, 11511>,
    <12378, 11511, 11509>,
    <12378, 11509, 12379>,
    <12382, 12383, 12380>,
    <12382, 12380, 12379>,
    <12382, 12379, 11509>,
    <12382, 11509, 11508>,
    <12382, 11508, 11507>,
    <12382, 11507, 12384>,
    <12382, 12384, 12385>,
    <12382, 12385, 12383>,
    <12386, 12381, 12380>,
    <12386, 12380, 12383>,
    <12386, 12383, 12385>,
    <12386, 12385, 12387>,
    <12386, 12387, 12373>,
    <12386, 12373, 12372>,
    <12386, 12372, 12369>,
    <12386, 12369, 12381>,
    <12388, 12389, 12390>,
    <12388, 12390, 12391>,
    <12388, 12391, 12392>,
    <12388, 12392, 12393>,
    <12388, 12393, 12394>,
    <12388, 12394, 12395>,
    <12388, 12395, 12396>,
    <12388, 12396, 12389>,
    <12397, 12398, 12390>,
    <12397, 12390, 12389>,
    <12397, 12389, 12396>,
    <12397, 12396, 12399>,
    <12397, 12399, 11624>,
    <12397, 11624, 11640>,
    <12397, 11640, 11637>,
    <12397, 11637, 12398>,
    <12400, 12391, 12390>,
    <12400, 12390, 12398>,
    <12400, 12398, 11637>,
    <12400, 11637, 11636>,
    <12400, 11636, 11528>,
    <12400, 11528, 12401>,
    <12400, 12401, 12392>,
    <12400, 12392, 12391>,
    <12402, 12403, 12404>,
    <12402, 12404, 12405>,
    <12402, 12405, 12300>,
    <12402, 12300, 12299>,
    <12402, 12299, 12298>,
    <12402, 12298, 12406>,
    <12402, 12406, 12407>,
    <12402, 12407, 12403>,
    <12408, 12409, 12404>,
    <12408, 12404, 12403>,
    <12408, 12403, 12407>,
    <12408, 12407, 12410>,
    <12408, 12410, 12394>,
    <12408, 12394, 12393>,
    <12408, 12393, 12392>,
    <12408, 12392, 12409>,
    <12411, 12405, 12404>,
    <12411, 12404, 12409>,
    <12411, 12409, 12392>,
    <12411, 12392, 12401>,
    <12411, 12401, 11528>,
    <12411, 11528, 12303>,
    <12411, 12303, 12300>,
    <12411, 12300, 12405>,
    <12412, 12413, 12414>,
    <12412, 12414, 12415>,
    <12412, 12415, 12416>,
    <12412, 12416, 12417>,
    <12412, 12417, 11462>,
    <12412, 11462, 12339>,
    <12412, 12339, 12337>,
    <12412, 12337, 12413>,
    <12418, 12419, 12414>,
    <12418, 12414, 12413>,
    <12418, 12413, 12337>,
    <12418, 12337, 12336>,
    <12418, 12336, 12328>,
    <12418, 12328, 12420>,
    <12418, 12420, 12421>,
    <12418, 12421, 12419>,
    <12422, 12415, 12414>,
    <12422, 12414, 12419>,
    <12422, 12419, 12421>,
    <12422, 12421, 12423>,
    <12422, 12423, 12424>,
    <12422, 12424, 12425>,
    <12422, 12425, 12416>,
    <12422, 12416, 12415>,
    <12426, 12427, 12428>,
    <12426, 12428, 12429>,
    <12426, 12429, 11555>,
    <12426, 11555, 11554>,
    <12426, 11554, 11462>,
    <12426, 11462, 12417>,
    <12426, 12417, 12416>,
    <12426, 12416, 12427>,
    <12430, 12431, 12428>,
    <12430, 12428, 12427>,
    <12430, 12427, 12416>,
    <12430, 12416, 12425>,
    <12430, 12425, 12424>,
    <12430, 12424, 12432>,
    <12430, 12432, 12433>,
    <12430, 12433, 12431>,
    <12434, 12429, 12428>,
    <12434, 12428, 12431>,
    <12434, 12431, 12433>,
    <12434, 12433, 12435>,
    <12434, 12435, 11558>,
    <12434, 11558, 11557>,
    <12434, 11557, 11555>,
    <12434, 11555, 12429>,
    <12436, 12437, 12438>,
    <12436, 12438, 12439>,
    <12436, 12439, 12440>,
    <12436, 12440, 12441>,
    <12436, 12441, 12442>,
    <12436, 12442, 12443>,
    <12436, 12443, 12444>,
    <12436, 12444, 12437>,
    <12445, 12446, 12438>,
    <12445, 12438, 12437>,
    <12445, 12437, 12444>,
    <12445, 12444, 12447>,
    <12445, 12447, 11576>,
    <12445, 11576, 11733>,
    <12445, 11733, 11732>,
    <12445, 11732, 12446>,
    <12448, 12439, 12438>,
    <12448, 12438, 12446>,
    <12448, 12446, 11732>,
    <12448, 11732, 11737>,
    <12448, 11737, 11720>,
    <12448, 11720, 12449>,
    <12448, 12449, 12440>,
    <12448, 12440, 12439>,
    <12450, 12451, 12452>,
    <12450, 12452, 12453>,
    <12450, 12453, 12454>,
    <12450, 12454, 12455>,
    <12450, 12455, 12346>,
    <12450, 12346, 12345>,
    <12450, 12345, 12344>,
    <12450, 12344, 12451>,
    <12456, 12457, 12452>,
    <12456, 12452, 12451>,
    <12456, 12451, 12344>,
    <12456, 12344, 12353>,
    <12456, 12353, 11576>,
    <12456, 11576, 12447>,
    <12456, 12447, 12444>,
    <12456, 12444, 12457>,
    <12458, 12453, 12452>,
    <12458, 12452, 12457>,
    <12458, 12457, 12444>,
    <12458, 12444, 12443>,
    <12458, 12443, 12442>,
    <12458, 12442, 12459>,
    <12458, 12459, 12454>,
    <12458, 12454, 12453>,
    <12460, 12461, 12462>,
    <12460, 12462, 12463>,
    <12460, 12463, 12385>,
    <12460, 12385, 12384>,
    <12460, 12384, 11507>,
    <12460, 11507, 12464>,
    <12460, 12464, 12465>,
    <12460, 12465, 12461>,
    <12466, 12467, 12462>,
    <12466, 12462, 12461>,
    <12466, 12461, 12465>,
    <12466, 12465, 12468>,
    <12466, 12468, 12469>,
    <12466, 12469, 12470>,
    <12466, 12470, 12471>,
    <12466, 12471, 12467>,
    <12472, 12463, 12462>,
    <12472, 12462, 12467>,
    <12472, 12467, 12471>,
    <12472, 12471, 12473>,
    <12472, 12473, 12373>,
    <12472, 12373, 12387>,
    <12472, 12387, 12385>,
    <12472, 12385, 12463>,
    <12474, 12475, 12476>,
    <12474, 12476, 12477>,
    <12474, 12477, 12465>,
    <12474, 12465, 12464>,
    <12474, 12464, 11507>,
    <12474, 11507, 11607>,
    <12474, 11607, 11605>,
    <12474, 11605, 12475>,
    <12478, 12479, 12476>,
    <12478, 12476, 12475>,
    <12478, 12475, 11605>,
    <12478, 11605, 11604>,
    <12478, 11604, 11603>,
    <12478, 11603, 12480>,
    <12478, 12480, 12481>,
    <12478, 12481, 12479>,
    <12482, 12477, 12476>,
    <12482, 12476, 12479>,
    <12482, 12479, 12481>,
    <12482, 12481, 12483>,
    <12482, 12483, 12469>,
    <12482, 12469, 12468>,
    <12482, 12468, 12465>,
    <12482, 12465, 12477>,
    <12484, 12485, 12486>,
    <12484, 12486, 12487>,
    <12484, 12487, 12488>,
    <12484, 12488, 12489>,
    <12484, 12489, 12490>,
    <12484, 12490, 12491>,
    <12484, 12491, 12492>,
    <12484, 12492, 12485>,
    <12493, 12494, 12486>,
    <12493, 12486, 12485>,
    <12493, 12485, 12492>,
    <12493, 12492, 12495>,
    <12493, 12495, 11672>,
    <12493, 11672, 11688>,
    <12493, 11688, 11685>,
    <12493, 11685, 12494>,
    <12496, 12487, 12486>,
    <12496, 12486, 12494>,
    <12496, 12494, 11685>,
    <12496, 11685, 11684>,
    <12496, 11684, 11624>,
    <12496, 11624, 12497>,
    <12496, 12497, 12488>,
    <12496, 12488, 12487>,
    <12498, 12499, 12500>,
    <12498, 12500, 12501>,
    <12498, 12501, 12396>,
    <12498, 12396, 12395>,
    <12498, 12395, 12394>,
    <12498, 12394, 12502>,
    <12498, 12502, 12503>,
    <12498, 12503, 12499>,
    <12504, 12505, 12500>,
    <12504, 12500, 12499>,
    <12504, 12499, 12503>,
    <12504, 12503, 12506>,
    <12504, 12506, 12490>,
    <12504, 12490, 12489>,
    <12504, 12489, 12488>,
    <12504, 12488, 12505>,
    <12507, 12501, 12500>,
    <12507, 12500, 12505>,
    <12507, 12505, 12488>,
    <12507, 12488, 12497>,
    <12507, 12497, 11624>,
    <12507, 11624, 12399>,
    <12507, 12399, 12396>,
    <12507, 12396, 12501>,
    <12508, 12509, 12510>,
    <12508, 12510, 12511>,
    <12508, 12511, 12481>,
    <12508, 12481, 12480>,
    <12508, 12480, 11603>,
    <12508, 11603, 12512>,
    <12508, 12512, 12513>,
    <12508, 12513, 12509>,
    <12514, 12515, 12510>,
    <12514, 12510, 12509>,
    <12514, 12509, 12513>,
    <12514, 12513, 12516>,
    <12514, 12516, 12517>,
    <12514, 12517, 12518>,
    <12514, 12518, 12519>,
    <12514, 12519, 12515>,
    <12520, 12511, 12510>,
    <12520, 12510, 12515>,
    <12520, 12515, 12519>,
    <12520, 12519, 12521>,
    <12520, 12521, 12469>,
    <12520, 12469, 12483>,
    <12520, 12483, 12481>,
    <12520, 12481, 12511>,
    <12522, 12523, 12524>,
    <12522, 12524, 12525>,
    <12522, 12525, 12513>,
    <12522, 12513, 12512>,
    <12522, 12512, 11603>,
    <12522, 11603, 11655>,
    <12522, 11655, 11653>,
    <12522, 11653, 12523>,
    <12526, 12527, 12524>,
    <12526, 12524, 12523>,
    <12526, 12523, 11653>,
    <12526, 11653, 11652>,
    <12526, 11652, 11651>,
    <12526, 11651, 12528>,
    <12526, 12528, 12529>,
    <12526, 12529, 12527>,
    <12530, 12525, 12524>,
    <12530, 12524, 12527>,
    <12530, 12527, 12529>,
    <12530, 12529, 12531>,
    <12530, 12531, 12517>,
    <12530, 12517, 12516>,
    <12530, 12516, 12513>,
    <12530, 12513, 12525>,
    <12532, 12533, 12534>,
    <12532, 12534, 12535>,
    <12532, 12535, 12536>,
    <12532, 12536, 12537>,
    <12532, 12537, 12538>,
    <12532, 12538, 12539>,
    <12532, 12539, 12540>,
    <12532, 12540, 12533>,
    <12541, 12542, 12534>,
    <12541, 12534, 12533>,
    <12541, 12533, 12540>,
    <12541, 12540, 12543>,
    <12541, 12543, 11768>,
    <12541, 11768, 11785>,
    <12541, 11785, 11782>,
    <12541, 11782, 12542>,
    <12544, 12535, 12534>,
    <12544, 12534, 12542>,
    <12544, 12542, 11782>,
    <12544, 11782, 11781>,
    <12544, 11781, 11672>,
    <12544, 11672, 12545>,
    <12544, 12545, 12536>,
    <12544, 12536, 12535>,
    <12546, 12547, 12548>,
    <12546, 12548, 12549>,
    <12546, 12549, 12492>,
    <12546, 12492, 12491>,
    <12546, 12491, 12490>,
    <12546, 12490, 12550>,
    <12546, 12550, 12551>,
    <12546, 12551, 12547>,
    <12552, 12553, 12548>,
    <12552, 12548, 12547>,
    <12552, 12547, 12551>,
    <12552, 12551, 12554>,
    <12552, 12554, 12538>,
    <12552, 12538, 12537>,
    <12552, 12537, 12536>,
    <12552, 12536, 12553>,
    <12555, 12549, 12548>,
    <12555, 12548, 12553>,
    <12555, 12553, 12536>,
    <12555, 12536, 12545>,
    <12555, 12545, 11672>,
    <12555, 11672, 12495>,
    <12555, 12495, 12492>,
    <12555, 12492, 12549>,
    <12556, 12557, 12558>,
    <12556, 12558, 12559>,
    <12556, 12559, 12560>,
    <12556, 12560, 12561>,
    <12556, 12561, 11558>,
    <12556, 11558, 12435>,
    <12556, 12435, 12433>,
    <12556, 12433, 12557>,
    <12562, 12563, 12558>,
    <12562, 12558, 12557>,
    <12562, 12557, 12433>,
    <12562, 12433, 12432>,
    <12562, 12432, 12424>,
    <12562, 12424, 12564>,
    <12562, 12564, 12565>,
    <12562, 12565, 12563>,
    <12566, 12559, 12558>,
    <12566, 12558, 12563>,
    <12566, 12563, 12565>,
    <12566, 12565, 12567>,
    <12566, 12567, 12568>,
    <12566, 12568, 12569>,
    <12566, 12569, 12560>,
    <12566, 12560, 12559>,
    <12570, 12571, 12572>,
    <12570, 12572, 12573>,
    <12570, 12573, 11699>,
    <12570, 11699, 11698>,
    <12570, 11698, 11558>,
    <12570, 11558, 12561>,
    <12570, 12561, 12560>,
    <12570, 12560, 12571>,
    <12574, 12575, 12572>,
    <12574, 12572, 12571>,
    <12574, 12571, 12560>,
    <12574, 12560, 12569>,
    <12574, 12569, 12568>,
    <12574, 12568, 12576>,
    <12574, 12576, 12577>,
    <12574, 12577, 12575>,
    <12578, 12573, 12572>,
    <12578, 12572, 12575>,
    <12578, 12575, 12577>,
    <12578, 12577, 12579>,
    <12578, 12579, 11702>,
    <12578, 11702, 11701>,
    <12578, 11701, 11699>,
    <12578, 11699, 12573>,
    <12580, 12581, 12582>,
    <12580, 12582, 12583>,
    <12580, 12583, 12584>,
    <12580, 12584, 12585>,
    <12580, 12585, 12586>,
    <12580, 12586, 12587>,
    <12580, 12587, 12588>,
    <12580, 12588, 12581>,
    <12589, 12590, 12582>,
    <12589, 12582, 12581>,
    <12589, 12581, 12588>,
    <12589, 12588, 12591>,
    <12589, 12591, 11720>,
    <12589, 11720, 11877>,
    <12589, 11877, 11876>,
    <12589, 11876, 12590>,
    <12592, 12583, 12582>,
    <12592, 12582, 12590>,
    <12592, 12590, 11876>,
    <12592, 11876, 11881>,
    <12592, 11881, 11864>,
    <12592, 11864, 12593>,
    <12592, 12593, 12584>,
    <12592, 12584, 12583>,
    <12594, 12595, 12596>,
    <12594, 12596, 12597>,
    <12594, 12597, 12598>,
    <12594, 12598, 12599>,
    <12594, 12599, 12442>,
    <12594, 12442, 12441>,
    <12594, 12441, 12440>,
    <12594, 12440, 12595>,
    <12600, 12601, 12596>,
    <12600, 12596, 12595>,
    <12600, 12595, 12440>,
    <12600, 12440, 12449>,
    <12600, 12449, 11720>,
    <12600, 11720, 12591>,
    <12600, 12591, 12588>,
    <12600, 12588, 12601>,
    <12602, 12597, 12596>,
    <12602, 12596, 12601>,
    <12602, 12601, 12588>,
    <12602, 12588, 12587>,
    <12602, 12587, 12586>,
    <12602, 12586, 12603>,
    <12602, 12603, 12598>,
    <12602, 12598, 12597>,
    <12604, 12605, 12606>,
    <12604, 12606, 12607>,
    <12604, 12607, 12529>,
    <12604, 12529, 12528>,
    <12604, 12528, 11651>,
    <12604, 11651, 12608>,
    <12604, 12608, 12609>,
    <12604, 12609, 12605>,
    <12610, 12611, 12606>,
    <12610, 12606, 12605>,
    <12610, 12605, 12609>,
    <12610, 12609, 12612>,
    <12610, 12612, 12613>,
    <12610, 12613, 12614>,
    <12610, 12614, 12615>,
    <12610, 12615, 12611>,
    <12616, 12607, 12606>,
    <12616, 12606, 12611>,
    <12616, 12611, 12615>,
    <12616, 12615, 12617>,
    <12616, 12617, 12517>,
    <12616, 12517, 12531>,
    <12616, 12531, 12529>,
    <12616, 12529, 12607>,
    <12618, 12619, 12620>,
    <12618, 12620, 12621>,
    <12618, 12621, 12609>,
    <12618, 12609, 12608>,
    <12618, 12608, 11651>,
    <12618, 11651, 11751>,
    <12618, 11751, 11749>,
    <12618, 11749, 12619>,
    <12622, 12623, 12620>,
    <12622, 12620, 12619>,
    <12622, 12619, 11749>,
    <12622, 11749, 11748>,
    <12622, 11748, 11747>,
    <12622, 11747, 12624>,
    <12622, 12624, 12625>,
    <12622, 12625, 12623>,
    <12626, 12621, 12620>,
    <12626, 12620, 12623>,
    <12626, 12623, 12625>,
    <12626, 12625, 12627>,
    <12626, 12627, 12613>,
    <12626, 12613, 12612>,
    <12626, 12612, 12609>,
    <12626, 12609, 12621>,
    <12628, 12629, 12630>,
    <12628, 12630, 12631>,
    <12628, 12631, 12632>,
    <12628, 12632, 12633>,
    <12628, 12633, 12634>,
    <12628, 12634, 12635>,
    <12628, 12635, 12636>,
    <12628, 12636, 12629>,
    <12637, 12638, 12630>,
    <12637, 12630, 12629>,
    <12637, 12629, 12636>,
    <12637, 12636, 12639>,
    <12637, 12639, 12640>,
    <12637, 12640, 11824>,
    <12637, 11824, 11821>,
    <12637, 11821, 12638>,
    <12641, 12631, 12630>,
    <12641, 12630, 12638>,
    <12641, 12638, 11821>,
    <12641, 11821, 11820>,
    <12641, 11820, 11768>,
    <12641, 11768, 12642>,
    <12641, 12642, 12632>,
    <12641, 12632, 12631>,
    <12643, 12644, 12645>,
    <12643, 12645, 12646>,
    <12643, 12646, 12540>,
    <12643, 12540, 12539>,
    <12643, 12539, 12538>,
    <12643, 12538, 12647>,
    <12643, 12647, 12648>,
    <12643, 12648, 12644>,
    <12649, 12650, 12645>,
    <12649, 12645, 12644>,
    <12649, 12644, 12648>,
    <12649, 12648, 12651>,
    <12649, 12651, 12634>,
    <12649, 12634, 12633>,
    <12649, 12633, 12632>,
    <12649, 12632, 12650>,
    <12652, 12646, 12645>,
    <12652, 12645, 12650>,
    <12652, 12650, 12632>,
    <12652, 12632, 12642>,
    <12652, 12642, 11768>,
    <12652, 11768, 12543>,
    <12652, 12543, 12540>,
    <12652, 12540, 12646>,
    <12653, 12654, 12655>,
    <12653, 12655, 12656>,
    <12653, 12656, 12625>,
    <12653, 12625, 12624>,
    <12653, 12624, 11747>,
    <12653, 11747, 12657>,
    <12653, 12657, 12658>,
    <12653, 12658, 12654>,
    <12659, 12660, 12655>,
    <12659, 12655, 12654>,
    <12659, 12654, 12658>,
    <12659, 12658, 12661>,
    <12659, 12661, 12662>,
    <12659, 12662, 12663>,
    <12659, 12663, 12664>,
    <12659, 12664, 12660>,
    <12665, 12656, 12655>,
    <12665, 12655, 12660>,
    <12665, 12660, 12664>,
    <12665, 12664, 12666>,
    <12665, 12666, 12613>,
    <12665, 12613, 12627>,
    <12665, 12627, 12625>,
    <12665, 12625, 12656>,
    <12667, 12668, 12669>,
    <12667, 12669, 12670>,
    <12667, 12670, 12658>,
    <12667, 12658, 12657>,
    <12667, 12657, 11747>,
    <12667, 11747, 11800>,
    <12667, 11800, 11798>,
    <12667, 11798, 12668>,
    <12671, 12672, 12669>,
    <12671, 12669, 12668>,
    <12671, 12668, 11798>,
    <12671, 11798, 11797>,
    <12671, 11797, 12673>,
    <12671, 12673, 12674>,
    <12671, 12675, 12676>,
    <12671, 12676, 12672>,
    <12677, 12670, 12669>,
    <12677, 12669, 12672>,
    <12677, 12672, 12678>,
    <12677, 12678, 12679>,
    <12677, 12680, 12681>,
    <12677, 12681, 12661>,
    <12677, 12661, 12658>,
    <12677, 12658, 12670>,
    <12682, 12683, 12684>,
    <12682, 12684, 12685>,
    <12682, 12685, 12636>,
    <12682, 12636, 12635>,
    <12682, 12635, 12634>,
    <12682, 12634, 12686>,
    <12682, 12686, 12687>,
    <12682, 12687, 12683>,
    <12688, 12689, 12684>,
    <12688, 12684, 12683>,
    <12688, 12683, 12687>,
    <12688, 12687, 12690>,
    <12688, 12690, 12691>,
    <12688, 12691, 12692>,
    <12688, 12693, 12694>,
    <12688, 12694, 12689>,
    <12695, 12685, 12684>,
    <12695, 12684, 12689>,
    <12695, 12689, 12696>,
    <12695, 12696, 12697>,
    <12695, 12698, 12699>,
    <12695, 12699, 12639>,
    <12695, 12639, 12636>,
    <12695, 12636, 12685>,
    <12700, 12701, 12702>,
    <12700, 12702, 12703>,
    <12700, 12703, 12704>,
    <12700, 12704, 12705>,
    <12700, 12705, 11702>,
    <12700, 11702, 12579>,
    <12700, 12579, 12577>,
    <12700, 12577, 12701>,
    <12706, 12707, 12702>,
    <12706, 12702, 12701>,
    <12706, 12701, 12577>,
    <12706, 12577, 12576>,
    <12706, 12576, 12568>,
    <12706, 12568, 12708>,
    <12706, 12708, 12709>,
    <12706, 12709, 12707>,
    <12710, 12703, 12702>,
    <12710, 12702, 12707>,
    <12710, 12707, 12709>,
    <12710, 12709, 12711>,
    <12710, 12711, 12712>,
    <12710, 12712, 12713>,
    <12710, 12713, 12704>,
    <12710, 12704, 12703>,
    <12714, 12715, 12716>,
    <12714, 12716, 12717>,
    <12714, 12717, 11843>,
    <12714, 11843, 11842>,
    <12714, 11842, 11702>,
    <12714, 11702, 12705>,
    <12714, 12705, 12704>,
    <12714, 12704, 12715>,
    <12718, 12719, 12716>,
    <12718, 12716, 12715>,
    <12718, 12715, 12704>,
    <12718, 12704, 12713>,
    <12718, 12713, 12712>,
    <12718, 12712, 12720>,
    <12718, 12720, 12721>,
    <12718, 12721, 12719>,
    <12722, 12717, 12716>,
    <12722, 12716, 12719>,
    <12722, 12719, 12721>,
    <12722, 12721, 12723>,
    <12722, 12723, 11846>,
    <12722, 11846, 11845>,
    <12722, 11845, 11843>,
    <12722, 11843, 12717>,
    <12724, 12725, 12726>,
    <12724, 12726, 12727>,
    <12724, 12727, 12728>,
    <12724, 12728, 12729>,
    <12724, 12729, 12730>,
    <12724, 12730, 12731>,
    <12724, 12731, 12732>,
    <12724, 12732, 12725>,
    <12733, 12734, 12726>,
    <12733, 12726, 12725>,
    <12733, 12725, 12732>,
    <12733, 12732, 12735>,
    <12733, 12735, 11864>,
    <12733, 11864, 11925>,
    <12733, 11925, 11924>,
    <12733, 11924, 12734>,
    <12736, 12727, 12726>,
    <12736, 12726, 12734>,
    <12736, 12734, 11924>,
    <12736, 11924, 11929>,
    <12736, 11929, 11912>,
    <12736, 11912, 12737>,
    <12736, 12737, 12728>,
    <12736, 12728, 12727>,
    <12738, 12739, 12740>,
    <12738, 12740, 12741>,
    <12738, 12741, 12742>,
    <12738, 12742, 12743>,
    <12738, 12743, 12586>,
    <12738, 12586, 12585>,
    <12738, 12585, 12584>,
    <12738, 12584, 12739>,
    <12744, 12745, 12740>,
    <12744, 12740, 12739>,
    <12744, 12739, 12584>,
    <12744, 12584, 12593>,
    <12744, 12593, 11864>,
    <12744, 11864, 12735>,
    <12744, 12735, 12732>,
    <12744, 12732, 12745>,
    <12746, 12741, 12740>,
    <12746, 12740, 12745>,
    <12746, 12745, 12732>,
    <12746, 12732, 12731>,
    <12746, 12731, 12730>,
    <12746, 12730, 12747>,
    <12746, 12747, 12742>,
    <12746, 12742, 12741>,
    <12748, 12749, 12750>,
    <12748, 12750, 12751>,
    <12748, 12751, 12752>,
    <12748, 12752, 12753>,
    <12748, 12753, 11846>,
    <12748, 11846, 12723>,
    <12748, 12723, 12721>,
    <12748, 12721, 12749>,
    <12754, 12755, 12750>,
    <12754, 12750, 12749>,
    <12754, 12749, 12721>,
    <12754, 12721, 12720>,
    <12754, 12720, 12712>,
    <12754, 12712, 12756>,
    <12754, 12756, 12757>,
    <12754, 12757, 12755>,
    <12758, 12751, 12750>,
    <12758, 12750, 12755>,
    <12758, 12755, 12757>,
    <12758, 12757, 12759>,
    <12758, 12759, 12760>,
    <12758, 12760, 12761>,
    <12758, 12761, 12752>,
    <12758, 12752, 12751>,
    <12762, 12763, 12764>,
    <12762, 12764, 12765>,
    <12762, 12765, 11891>,
    <12762, 11891, 11890>,
    <12762, 11890, 11846>,
    <12762, 11846, 12753>,
    <12762, 12753, 12752>,
    <12762, 12752, 12763>,
    <12766, 12767, 12764>,
    <12766, 12764, 12763>,
    <12766, 12763, 12752>,
    <12766, 12752, 12761>,
    <12766, 12761, 12760>,
    <12766, 12760, 12768>,
    <12766, 12768, 12769>,
    <12766, 12769, 12767>,
    <12770, 12765, 12764>,
    <12770, 12764, 12767>,
    <12770, 12767, 12769>,
    <12770, 12769, 12771>,
    <12770, 12771, 11894>,
    <12770, 11894, 11893>,
    <12770, 11893, 11891>,
    <12770, 11891, 12765>,
    <12772, 12773, 12774>,
    <12772, 12774, 12775>,
    <12772, 12775, 12776>,
    <12772, 12776, 12777>,
    <12772, 12777, 12778>,
    <12772, 12778, 12779>,
    <12772, 12779, 12780>,
    <12772, 12780, 12773>,
    <12781, 12782, 12774>,
    <12781, 12774, 12773>,
    <12781, 12773, 12780>,
    <12781, 12780, 12783>,
    <12781, 12783, 11912>,
    <12781, 11912, 11955>,
    <12781, 11955, 11954>,
    <12781, 11954, 12782>,
    <12784, 12775, 12774>,
    <12784, 12774, 12782>,
    <12784, 12782, 11954>,
    <12784, 11954, 11959>,
    <12784, 11959, 2281>,
    <12784, 2281, 12785>,
    <12784, 12785, 12776>,
    <12784, 12776, 12775>,
    <12786, 12787, 12788>,
    <12786, 12788, 12789>,
    <12786, 12789, 12790>,
    <12786, 12790, 12791>,
    <12786, 12791, 12730>,
    <12786, 12730, 12729>,
    <12786, 12729, 12728>,
    <12786, 12728, 12787>,
    <12792, 12793, 12788>,
    <12792, 12788, 12787>,
    <12792, 12787, 12728>,
    <12792, 12728, 12737>,
    <12792, 12737, 11912>,
    <12792, 11912, 12783>,
    <12792, 12783, 12780>,
    <12792, 12780, 12793>,
    <12794, 12789, 12788>,
    <12794, 12788, 12793>,
    <12794, 12793, 12780>,
    <12794, 12780, 12779>,
    <12794, 12779, 12778>,
    <12794, 12778, 12795>,
    <12794, 12795, 12790>,
    <12794, 12790, 12789>,
    <12796, 12797, 12798>,
    <12796, 12798, 12799>,
    <12796, 12799, 12800>,
    <12796, 12800, 12801>,
    <12796, 12801, 11894>,
    <12796, 11894, 12771>,
    <12796, 12771, 12769>,
    <12796, 12769, 12797>,
    <12802, 12803, 12798>,
    <12802, 12798, 12797>,
    <12802, 12797, 12769>,
    <12802, 12769, 12768>,
    <12802, 12768, 12760>,
    <12802, 12760, 12804>,
    <12802, 12804, 12805>,
    <12802, 12805, 12803>,
    <12806, 12799, 12798>,
    <12806, 12798, 12803>,
    <12806, 12803, 12805>,
    <12806, 12805, 12807>,
    <12806, 12807, 2560>,
    <12806, 2560, 12808>,
    <12806, 12808, 12800>,
    <12806, 12800, 12799>,
    <12809, 12810, 12811>,
    <12809, 12811, 12812>,
    <12809, 12812, 11939>,
    <12809, 11939, 11938>,
    <12809, 11938, 11894>,
    <12809, 11894, 12801>,
    <12809, 12801, 12800>,
    <12809, 12800, 12810>,
    <12813, 12814, 12811>,
    <12813, 12811, 12810>,
    <12813, 12810, 12800>,
    <12813, 12800, 12808>,
    <12813, 12808, 2560>,
    <12813, 2560, 2597>,
    <12813, 2597, 2595>,
    <12813, 2595, 12814>,
    <12815, 12812, 12811>,
    <12815, 12811, 12814>,
    <12815, 12814, 2595>,
    <12815, 2595, 2594>,
    <12815, 2594, 2251>,
    <12815, 2251, 11941>,
    <12815, 11941, 11939>,
    <12815, 11939, 12812>,
    <12816, 12817, 12818>,
    <12816, 12818, 12819>,
    <12816, 12819, 12820>,
    <12816, 12820, 12821>,
    <12816, 12821, 12778>,
    <12816, 12778, 12777>,
    <12816, 12777, 12776>,
    <12816, 12776, 12817>,
    <12822, 12823, 12818>,
    <12822, 12818, 12817>,
    <12822, 12817, 12776>,
    <12822, 12776, 12785>,
    <12822, 12785, 2281>,
    <12822, 2281, 2612>,
    <12822, 2612, 2610>,
    <12822, 2610, 12823>,
    <12824, 12819, 12818>,
    <12824, 12818, 12823>,
    <12824, 12823, 2610>,
    <12824, 2610, 2609>,
    <12824, 2609, 2608>,
    <12824, 2608, 12825>,
    <12824, 12825, 12820>,
    <12824, 12820, 12819>,
    <12826, 12827, 12828>,
    <12826, 12828, 12829>,
    <12826, 12829, 12830>,
    <12826, 12830, 12831>,
    <12826, 12831, 12832>,
    <12826, 12832, 12833>,
    <12826, 12834, 12835>,
    <12826, 12835, 12827>,
    <12836, 12837, 12828>,
    <12836, 12828, 12827>,
    <12836, 12827, 12838>,
    <12836, 12838, 12839>,
    <12836, 12840, 12841>,
    <12836, 12841, 12031>,
    <12836, 12031, 12029>,
    <12836, 12029, 12837>,
    <12842, 12829, 12828>,
    <12842, 12828, 12837>,
    <12842, 12837, 12029>,
    <12842, 12029, 12028>,
    <12842, 12028, 12027>,
    <12842, 12027, 12843>,
    <12842, 12843, 12830>,
    <12842, 12830, 12829>,
    <12844, 12845, 12846>,
    <12844, 12846, 12847>,
    <12844, 12847, 12848>,
    <12844, 12848, 12849>,
    <12844, 12850, 12851>,
    <12844, 12851, 12852>,
    <12844, 12852, 12853>,
    <12844, 12853, 12845>,
    <12854, 12855, 12846>,
    <12854, 12846, 12845>,
    <12854, 12845, 12853>,
    <12854, 12853, 12856>,
    <12854, 12856, 12075>,
    <12854, 12075, 12125>,
    <12854, 12125, 12123>,
    <12854, 12123, 12855>,
    <12857, 12847, 12846>,
    <12857, 12846, 12855>,
    <12857, 12855, 12123>,
    <12857, 12123, 12122>,
    <12857, 12122, 12858>,
    <12857, 12858, 12859>,
    <12857, 12860, 12861>,
    <12857, 12861, 12847>,
    <12862, 12863, 12864>,
    <12862, 12864, 12865>,
    <12862, 12865, 12866>,
    <12862, 12866, 12867>,
    <12862, 12867, 12868>,
    <12862, 12868, 12869>,
    <12862, 12870, 12871>,
    <12862, 12871, 12863>,
    <12872, 12873, 12864>,
    <12872, 12864, 12863>,
    <12872, 12863, 12874>,
    <12872, 12874, 12875>,
    <12872, 12876, 12877>,
    <12872, 12877, 12262>,
    <12872, 12262, 12261>,
    <12872, 12261, 12873>,
    <12878, 12865, 12864>,
    <12878, 12864, 12873>,
    <12878, 12873, 12261>,
    <12878, 12261, 12267>,
    <12878, 12267, 12249>,
    <12878, 12249, 12879>,
    <12878, 12879, 12866>,
    <12878, 12866, 12865>,
    <12880, 12881, 12882>,
    <12880, 12882, 12883>,
    <12880, 12883, 12884>,
    <12880, 12884, 12885>,
    <12880, 12885, 12886>,
    <12880, 12886, 12887>,
    <12880, 12887, 12888>,
    <12880, 12888, 12881>,
    <12889, 12890, 12882>,
    <12889, 12882, 12881>,
    <12889, 12881, 12888>,
    <12889, 12888, 12891>,
    <12889, 12891, 12174>,
    <12889, 12174, 12190>,
    <12889, 12190, 12187>,
    <12889, 12187, 12890>,
    <12892, 12883, 12882>,
    <12892, 12882, 12890>,
    <12892, 12890, 12187>,
    <12892, 12187, 12186>,
    <12892, 12186, 12075>,
    <12892, 12075, 12893>,
    <12892, 12893, 12884>,
    <12892, 12884, 12883>,
    <12894, 12895, 12896>,
    <12894, 12896, 12897>,
    <12894, 12897, 12853>,
    <12894, 12853, 12852>,
    <12894, 12852, 12898>,
    <12894, 12898, 12899>,
    <12894, 12899, 12900>,
    <12894, 12900, 12895>,
    <12901, 12902, 12896>,
    <12901, 12896, 12895>,
    <12901, 12895, 12900>,
    <12901, 12900, 12903>,
    <12901, 12903, 12886>,
    <12901, 12886, 12885>,
    <12901, 12885, 12884>,
    <12901, 12884, 12902>,
    <12904, 12897, 12896>,
    <12904, 12896, 12902>,
    <12904, 12902, 12884>,
    <12904, 12884, 12893>,
    <12904, 12893, 12075>,
    <12904, 12075, 12856>,
    <12904, 12856, 12853>,
    <12904, 12853, 12897>,
    <12905, 12906, 12907>,
    <12905, 12907, 12908>,
    <12905, 12908, 12900>,
    <12905, 12900, 12899>,
    <12905, 12899, 12909>,
    <12905, 12909, 12910>,
    <12905, 12911, 12912>,
    <12905, 12912, 12906>,
    <12913, 12914, 12907>,
    <12913, 12907, 12906>,
    <12913, 12906, 12915>,
    <12913, 12915, 12916>,
    <12913, 12917, 12918>,
    <12913, 12918, 12919>,
    <12913, 12919, 12920>,
    <12913, 12920, 12914>,
    <12921, 12908, 12907>,
    <12921, 12907, 12914>,
    <12921, 12914, 12920>,
    <12921, 12920, 12922>,
    <12921, 12922, 12886>,
    <12921, 12886, 12903>,
    <12921, 12903, 12900>,
    <12921, 12900, 12908>,
    <12923, 12924, 12925>,
    <12923, 12925, 12926>,
    <12923, 12926, 12927>,
    <12923, 12927, 12928>,
    <12923, 12928, 12929>,
    <12923, 12929, 12930>,
    <12923, 12931, 12932>,
    <12923, 12932, 12924>,
    <12933, 12934, 12925>,
    <12933, 12925, 12924>,
    <12933, 12924, 12935>,
    <12933, 12935, 12936>,
    <12933, 12937, 12938>,
    <12933, 12938, 12867>,
    <12933, 12867, 12866>,
    <12933, 12866, 12934>,
    <12939, 12926, 12925>,
    <12939, 12925, 12934>,
    <12939, 12934, 12866>,
    <12939, 12866, 12879>,
    <12939, 12879, 12249>,
    <12939, 12249, 12940>,
    <12939, 12940, 12927>,
    <12939, 12927, 12926>,
    <12941, 12942, 12943>,
    <12941, 12943, 12944>,
    <12941, 12944, 12945>,
    <12941, 12945, 12946>,
    <12941, 12946, 12947>,
    <12941, 12947, 12948>,
    <12941, 12948, 12949>,
    <12941, 12949, 12942>,
    <12950, 12951, 12943>,
    <12950, 12943, 12942>,
    <12950, 12942, 12949>,
    <12950, 12949, 12952>,
    <12950, 12952, 12298>,
    <12950, 12298, 12314>,
    <12950, 12314, 12311>,
    <12950, 12311, 12951>,
    <12953, 12944, 12943>,
    <12953, 12943, 12951>,
    <12953, 12951, 12311>,
    <12953, 12311, 12310>,
    <12953, 12310, 12174>,
    <12953, 12174, 12954>,
    <12953, 12954, 12945>,
    <12953, 12945, 12944>,
    <12955, 12956, 12957>,
    <12955, 12957, 12958>,
    <12955, 12958, 12888>,
    <12955, 12888, 12887>,
    <12955, 12887, 12886>,
    <12955, 12886, 12959>,
    <12955, 12959, 12960>,
    <12955, 12960, 12956>,
    <12961, 12962, 12957>,
    <12961, 12957, 12956>,
    <12961, 12956, 12960>,
    <12961, 12960, 12963>,
    <12961, 12963, 12947>,
    <12961, 12947, 12946>,
    <12961, 12946, 12945>,
    <12961, 12945, 12962>,
    <12964, 12958, 12957>,
    <12964, 12957, 12962>,
    <12964, 12962, 12945>,
    <12964, 12945, 12954>,
    <12964, 12954, 12174>,
    <12964, 12174, 12891>,
    <12964, 12891, 12888>,
    <12964, 12888, 12958>,
    <12965, 12966, 12967>,
    <12965, 12967, 12968>,
    <12965, 12968, 12969>,
    <12965, 12969, 12970>,
    <12965, 12970, 12971>,
    <12965, 12971, 12972>,
    <12965, 12972, 12973>,
    <12965, 12973, 12966>,
    <12974, 12975, 12967>,
    <12974, 12967, 12966>,
    <12974, 12966, 12973>,
    <12974, 12973, 12976>,
    <12974, 12976, 12249>,
    <12974, 12249, 12359>,
    <12974, 12359, 12358>,
    <12974, 12358, 12975>,
    <12977, 12968, 12967>,
    <12977, 12967, 12975>,
    <12977, 12975, 12358>,
    <12977, 12358, 12363>,
    <12977, 12363, 12346>,
    <12977, 12346, 12978>,
    <12977, 12978, 12969>,
    <12977, 12969, 12968>,
    <12979, 12980, 12981>,
    <12979, 12981, 12982>,
    <12979, 12982, 12983>,
    <12979, 12983, 12984>,
    <12979, 12984, 12985>,
    <12979, 12985, 12928>,
    <12979, 12928, 12927>,
    <12979, 12927, 12980>,
    <12986, 12987, 12981>,
    <12986, 12981, 12980>,
    <12986, 12980, 12927>,
    <12986, 12927, 12940>,
    <12986, 12940, 12249>,
    <12986, 12249, 12976>,
    <12986, 12976, 12973>,
    <12986, 12973, 12987>,
    <12988, 12982, 12981>,
    <12988, 12981, 12987>,
    <12988, 12987, 12973>,
    <12988, 12973, 12972>,
    <12988, 12972, 12971>,
    <12988, 12971, 12989>,
    <12988, 12989, 12983>,
    <12988, 12983, 12982>,
    <12990, 12991, 12992>,
    <12990, 12992, 12993>,
    <12990, 12993, 12994>,
    <12990, 12994, 12995>,
    <12990, 12995, 12996>,
    <12990, 12996, 12997>,
    <12990, 12997, 12998>,
    <12990, 12998, 12991>,
    <12999, 13000, 12992>,
    <12999, 12992, 12991>,
    <12999, 12991, 12998>,
    <12999, 12998, 13001>,
    <12999, 13001, 12394>,
    <12999, 12394, 12410>,
    <12999, 12410, 12407>,
    <12999, 12407, 13000>,
    <13002, 12993, 12992>,
    <13002, 12992, 13000>,
    <13002, 13000, 12407>,
    <13002, 12407, 12406>,
    <13002, 12406, 12298>,
    <13002, 12298, 13003>,
    <13002, 13003, 12994>,
    <13002, 12994, 12993>,
    <13004, 13005, 13006>,
    <13004, 13006, 13007>,
    <13004, 13007, 12949>,
    <13004, 12949, 12948>,
    <13004, 12948, 12947>,
    <13004, 12947, 13008>,
    <13004, 13008, 13009>,
    <13004, 13009, 13005>,
    <13010, 13011, 13006>,
    <13010, 13006, 13005>,
    <13010, 13005, 13009>,
    <13010, 13009, 13012>,
    <13010, 13012, 12996>,
    <13010, 12996, 12995>,
    <13010, 12995, 12994>,
    <13010, 12994, 13011>,
    <13013, 13007, 13006>,
    <13013, 13006, 13011>,
    <13013, 13011, 12994>,
    <13013, 12994, 13003>,
    <13013, 13003, 12298>,
    <13013, 12298, 12952>,
    <13013, 12952, 12949>,
    <13013, 12949, 13007>,
    <13014, 13015, 13016>,
    <13014, 13016, 13017>,
    <13014, 13017, 13018>,
    <13014, 13018, 13019>,
    <13014, 13019, 13020>,
    <13014, 13020, 13021>,
    <13014, 13021, 13022>,
    <13014, 13022, 13015>,
    <13023, 13024, 13016>,
    <13023, 13016, 13015>,
    <13023, 13015, 13022>,
    <13023, 13022, 13025>,
    <13023, 13025, 12346>,
    <13023, 12346, 12455>,
    <13023, 12455, 12454>,
    <13023, 12454, 13024>,
    <13026, 13017, 13016>,
    <13026, 13016, 13024>,
    <13026, 13024, 12454>,
    <13026, 12454, 12459>,
    <13026, 12459, 12442>,
    <13026, 12442, 13027>,
    <13026, 13027, 13018>,
    <13026, 13018, 13017>,
    <13028, 13029, 13030>,
    <13028, 13030, 13031>,
    <13028, 13031, 13032>,
    <13028, 13032, 13033>,
    <13028, 13033, 12971>,
    <13028, 12971, 12970>,
    <13028, 12970, 12969>,
    <13028, 12969, 13029>,
    <13034, 13035, 13030>,
    <13034, 13030, 13029>,
    <13034, 13029, 12969>,
    <13034, 12969, 12978>,
    <13034, 12978, 12346>,
    <13034, 12346, 13025>,
    <13034, 13025, 13022>,
    <13034, 13022, 13035>,
    <13036, 13031, 13030>,
    <13036, 13030, 13035>,
    <13036, 13035, 13022>,
    <13036, 13022, 13021>,
    <13036, 13021, 13020>,
    <13036, 13020, 13037>,
    <13036, 13037, 13032>,
    <13036, 13032, 13031>,
    <13038, 13039, 13040>,
    <13038, 13040, 13041>,
    <13038, 13041, 13042>,
    <13038, 13042, 13043>,
    <13038, 13043, 13044>,
    <13038, 13044, 13045>,
    <13038, 13045, 13046>,
    <13038, 13046, 13039>,
    <13047, 13048, 13040>,
    <13047, 13040, 13039>,
    <13047, 13039, 13046>,
    <13047, 13046, 13049>,
    <13047, 13049, 12490>,
    <13047, 12490, 12506>,
    <13047, 12506, 12503>,
    <13047, 12503, 13048>,
    <13050, 13041, 13040>,
    <13050, 13040, 13048>,
    <13050, 13048, 12503>,
    <13050, 12503, 12502>,
    <13050, 12502, 12394>,
    <13050, 12394, 13051>,
    <13050, 13051, 13042>,
    <13050, 13042, 13041>,
    <13052, 13053, 13054>,
    <13052, 13054, 13055>,
    <13052, 13055, 12998>,
    <13052, 12998, 12997>,
    <13052, 12997, 12996>,
    <13052, 12996, 13056>,
    <13052, 13056, 13057>,
    <13052, 13057, 13053>,
    <13058, 13059, 13054>,
    <13058, 13054, 13053>,
    <13058, 13053, 13057>,
    <13058, 13057, 13060>,
    <13058, 13060, 13044>,
    <13058, 13044, 13043>,
    <13058, 13043, 13042>,
    <13058, 13042, 13059>,
    <13061, 13055, 13054>,
    <13061, 13054, 13059>,
    <13061, 13059, 13042>,
    <13061, 13042, 13051>,
    <13061, 13051, 12394>,
    <13061, 12394, 13001>,
    <13061, 13001, 12998>,
    <13061, 12998, 13055>,
    <13062, 13063, 13064>,
    <13062, 13064, 13065>,
    <13062, 13065, 13066>,
    <13062, 13066, 13067>,
    <13062, 13067, 13068>,
    <13062, 13068, 13069>,
    <13062, 13069, 13070>,
    <13062, 13070, 13063>,
    <13071, 13072, 13064>,
    <13071, 13064, 13063>,
    <13071, 13063, 13070>,
    <13071, 13070, 13073>,
    <13071, 13073, 12442>,
    <13071, 12442, 12599>,
    <13071, 12599, 12598>,
    <13071, 12598, 13072>,
    <13074, 13065, 13064>,
    <13074, 13064, 13072>,
    <13074, 13072, 12598>,
    <13074, 12598, 12603>,
    <13074, 12603, 12586>,
    <13074, 12586, 13075>,
    <13074, 13075, 13066>,
    <13074, 13066, 13065>,
    <13076, 13077, 13078>,
    <13076, 13078, 13079>,
    <13076, 13079, 13080>,
    <13076, 13080, 13081>,
    <13076, 13081, 13020>,
    <13076, 13020, 13019>,
    <13076, 13019, 13018>,
    <13076, 13018, 13077>,
    <13082, 13083, 13078>,
    <13082, 13078, 13077>,
    <13082, 13077, 13018>,
    <13082, 13018, 13027>,
    <13082, 13027, 12442>,
    <13082, 12442, 13073>,
    <13082, 13073, 13070>,
    <13082, 13070, 13083>,
    <13084, 13079, 13078>,
    <13084, 13078, 13083>,
    <13084, 13083, 13070>,
    <13084, 13070, 13069>,
    <13084, 13069, 13068>,
    <13084, 13068, 13085>,
    <13084, 13085, 13080>,
    <13084, 13080, 13079>,
    <13086, 13087, 13088>,
    <13086, 13088, 13089>,
    <13086, 13089, 13090>,
    <13086, 13090, 13091>,
    <13086, 13091, 13092>,
    <13086, 13092, 13093>,
    <13086, 13093, 13094>,
    <13086, 13094, 13087>,
    <13095, 13096, 13088>,
    <13095, 13088, 13087>,
    <13095, 13087, 13094>,
    <13095, 13094, 13097>,
    <13095, 13097, 12538>,
    <13095, 12538, 12554>,
    <13095, 12554, 12551>,
    <13095, 12551, 13096>,
    <13098, 13089, 13088>,
    <13098, 13088, 13096>,
    <13098, 13096, 12551>,
    <13098, 12551, 12550>,
    <13098, 12550, 12490>,
    <13098, 12490, 13099>,
    <13098, 13099, 13090>,
    <13098, 13090, 13089>,
    <13100, 13101, 13102>,
    <13100, 13102, 13103>,
    <13100, 13103, 13046>,
    <13100, 13046, 13045>,
    <13100, 13045, 13044>,
    <13100, 13044, 13104>,
    <13100, 13104, 13105>,
    <13100, 13105, 13101>,
    <13106, 13107, 13102>,
    <13106, 13102, 13101>,
    <13106, 13101, 13105>,
    <13106, 13105, 13108>,
    <13106, 13108, 13092>,
    <13106, 13092, 13091>,
    <13106, 13091, 13090>,
    <13106, 13090, 13107>,
    <13109, 13103, 13102>,
    <13109, 13102, 13107>,
    <13109, 13107, 13090>,
    <13109, 13090, 13099>,
    <13109, 13099, 12490>,
    <13109, 12490, 13049>,
    <13109, 13049, 13046>,
    <13109, 13046, 13103>,
    <13110, 13111, 13112>,
    <13110, 13112, 13113>,
    <13110, 13113, 13114>,
    <13110, 13114, 13115>,
    <13110, 13115, 13116>,
    <13110, 13116, 13117>,
    <13110, 13117, 13118>,
    <13110, 13118, 13111>,
    <13119, 13120, 13112>,
    <13119, 13112, 13111>,
    <13119, 13111, 13118>,
    <13119, 13118, 13121>,
    <13119, 13121, 12634>,
    <13119, 12634, 12651>,
    <13119, 12651, 12648>,
    <13119, 12648, 13120>,
    <13122, 13113, 13112>,
    <13122, 13112, 13120>,
    <13122, 13120, 12648>,
    <13122, 12648, 12647>,
    <13122, 12647, 12538>,
    <13122, 12538, 13123>,
    <13122, 13123, 13114>,
    <13122, 13114, 13113>,
    <13124, 13125, 13126>,
    <13124, 13126, 13127>,
    <13124, 13127, 13094>,
    <13124, 13094, 13093>,
    <13124, 13093, 13092>,
    <13124, 13092, 13128>,
    <13124, 13128, 13129>,
    <13124, 13129, 13125>,
    <13130, 13131, 13126>,
    <13130, 13126, 13125>,
    <13130, 13125, 13129>,
    <13130, 13129, 13132>,
    <13130, 13132, 13116>,
    <13130, 13116, 13115>,
    <13130, 13115, 13114>,
    <13130, 13114, 13131>,
    <13133, 13127, 13126>,
    <13133, 13126, 13131>,
    <13133, 13131, 13114>,
    <13133, 13114, 13123>,
    <13133, 13123, 12538>,
    <13133, 12538, 13097>,
    <13133, 13097, 13094>,
    <13133, 13094, 13127>,
    <13134, 13135, 13136>,
    <13134, 13136, 13137>,
    <13134, 13137, 13138>,
    <13134, 13138, 13139>,
    <13134, 13139, 13140>,
    <13134, 13140, 13141>,
    <13134, 13141, 13142>,
    <13134, 13142, 13135>,
    <13143, 13144, 13136>,
    <13143, 13136, 13135>,
    <13143, 13135, 13142>,
    <13143, 13142, 13145>,
    <13143, 13145, 12586>,
    <13143, 12586, 12743>,
    <13143, 12743, 12742>,
    <13143, 12742, 13144>,
    <13146, 13137, 13136>,
    <13146, 13136, 13144>,
    <13146, 13144, 12742>,
    <13146, 12742, 12747>,
    <13146, 12747, 12730>,
    <13146, 12730, 13147>,
    <13146, 13147, 13138>,
    <13146, 13138, 13137>,
    <13148, 13149, 13150>,
    <13148, 13150, 13151>,
    <13148, 13151, 13152>,
    <13148, 13152, 13153>,
    <13148, 13153, 13068>,
    <13148, 13068, 13067>,
    <13148, 13067, 13066>,
    <13148, 13066, 13149>,
    <13154, 13155, 13150>,
    <13154, 13150, 13149>,
    <13154, 13149, 13066>,
    <13154, 13066, 13075>,
    <13154, 13075, 12586>,
    <13154, 12586, 13145>,
    <13154, 13145, 13142>,
    <13154, 13142, 13155>,
    <13156, 13151, 13150>,
    <13156, 13150, 13155>,
    <13156, 13155, 13142>,
    <13156, 13142, 13141>,
    <13156, 13141, 13140>,
    <13156, 13140, 13157>,
    <13156, 13157, 13152>,
    <13156, 13152, 13151>,
    <13158, 13159, 13160>,
    <13158, 13160, 13161>,
    <13158, 13161, 13162>,
    <13158, 13162, 13163>,
    <13158, 13163, 13164>,
    <13158, 13164, 13165>,
    <13158, 13165, 13166>,
    <13158, 13166, 13159>,
    <13167, 13168, 13160>,
    <13167, 13160, 13159>,
    <13167, 13159, 13166>,
    <13167, 13166, 13169>,
    <13167, 13169, 13170>,
    <13167, 13170, 12690>,
    <13167, 12690, 12687>,
    <13167, 12687, 13168>,
    <13171, 13161, 13160>,
    <13171, 13160, 13168>,
    <13171, 13168, 12687>,
    <13171, 12687, 12686>,
    <13171, 12686, 12634>,
    <13171, 12634, 13172>,
    <13171, 13172, 13162>,
    <13171, 13162, 13161>,
    <13173, 13174, 13175>,
    <13173, 13175, 13176>,
    <13173, 13176, 13118>,
    <13173, 13118, 13117>,
    <13173, 13117, 13116>,
    <13173, 13116, 13177>,
    <13173, 13177, 13178>,
    <13173, 13178, 13174>,
    <13179, 13180, 13175>,
    <13179, 13175, 13174>,
    <13179, 13174, 13178>,
    <13179, 13178, 13181>,
    <13179, 13181, 13164>,
    <13179, 13164, 13163>,
    <13179, 13163, 13162>,
    <13179, 13162, 13180>,
    <13182, 13176, 13175>,
    <13182, 13175, 13180>,
    <13182, 13180, 13162>,
    <13182, 13162, 13172>,
    <13182, 13172, 12634>,
    <13182, 12634, 13121>,
    <13182, 13121, 13118>,
    <13182, 13118, 13176>,
    <13183, 13184, 13185>,
    <13183, 13185, 13186>,
    <13183, 13186, 13166>,
    <13183, 13166, 13165>,
    <13183, 13165, 13164>,
    <13183, 13164, 13187>,
    <13183, 13187, 13188>,
    <13183, 13188, 13184>,
    <13189, 13190, 13185>,
    <13189, 13185, 13184>,
    <13189, 13184, 13188>,
    <13189, 13188, 13191>,
    <13189, 13191, 13192>,
    <13189, 13192, 13193>,
    <13189, 13194, 13195>,
    <13189, 13195, 13190>,
    <13196, 13186, 13185>,
    <13196, 13185, 13190>,
    <13196, 13190, 13197>,
    <13196, 13197, 13198>,
    <13196, 13199, 13200>,
    <13196, 13200, 13169>,
    <13196, 13169, 13166>,
    <13196, 13166, 13186>,
    <13201, 13202, 13203>,
    <13201, 13203, 13204>,
    <13201, 13204, 13205>,
    <13201, 13205, 13206>,
    <13201, 13206, 13207>,
    <13201, 13207, 13208>,
    <13201, 13208, 13209>,
    <13201, 13209, 13202>,
    <13210, 13211, 13203>,
    <13210, 13203, 13202>,
    <13210, 13202, 13209>,
    <13210, 13209, 13212>,
    <13210, 13212, 12730>,
    <13210, 12730, 12791>,
    <13210, 12791, 12790>,
    <13210, 12790, 13211>,
    <13213, 13204, 13203>,
    <13213, 13203, 13211>,
    <13213, 13211, 12790>,
    <13213, 12790, 12795>,
    <13213, 12795, 12778>,
    <13213, 12778, 13214>,
    <13213, 13214, 13205>,
    <13213, 13205, 13204>,
    <13215, 13216, 13217>,
    <13215, 13217, 13218>,
    <13215, 13218, 13219>,
    <13215, 13219, 13220>,
    <13215, 13220, 13140>,
    <13215, 13140, 13139>,
    <13215, 13139, 13138>,
    <13215, 13138, 13216>,
    <13221, 13222, 13217>,
    <13221, 13217, 13216>,
    <13221, 13216, 13138>,
    <13221, 13138, 13147>,
    <13221, 13147, 12730>,
    <13221, 12730, 13212>,
    <13221, 13212, 13209>,
    <13221, 13209, 13222>,
    <13223, 13218, 13217>,
    <13223, 13217, 13222>,
    <13223, 13222, 13209>,
    <13223, 13209, 13208>,
    <13223, 13208, 13207>,
    <13223, 13207, 13224>,
    <13223, 13224, 13219>,
    <13223, 13219, 13218>,
    <13225, 13226, 13227>,
    <13225, 13227, 13228>,
    <13225, 13228, 13229>,
    <13225, 13229, 13230>,
    <13225, 13230, 13231>,
    <13225, 13231, 13232>,
    <13225, 13232, 13233>,
    <13225, 13233, 13226>,
    <13234, 13235, 13227>,
    <13234, 13227, 13226>,
    <13234, 13226, 13233>,
    <13234, 13233, 13236>,
    <13234, 13236, 12778>,
    <13234, 12778, 12821>,
    <13234, 12821, 12820>,
    <13234, 12820, 13235>,
    <13237, 13228, 13227>,
    <13237, 13227, 13235>,
    <13237, 13235, 12820>,
    <13237, 12820, 12825>,
    <13237, 12825, 2608>,
    <13237, 2608, 13238>,
    <13237, 13238, 13229>,
    <13237, 13229, 13228>,
    <13239, 13240, 13241>,
    <13239, 13241, 13242>,
    <13239, 13242, 13243>,
    <13239, 13243, 13244>,
    <13239, 13244, 13207>,
    <13239, 13207, 13206>,
    <13239, 13206, 13205>,
    <13239, 13205, 13240>,
    <13245, 13246, 13241>,
    <13245, 13241, 13240>,
    <13245, 13240, 13205>,
    <13245, 13205, 13214>,
    <13245, 13214, 12778>,
    <13245, 12778, 13236>,
    <13245, 13236, 13233>,
    <13245, 13233, 13246>,
    <13247, 13242, 13241>,
    <13247, 13241, 13246>,
    <13247, 13246, 13233>,
    <13247, 13233, 13232>,
    <13247, 13232, 13231>,
    <13247, 13231, 13248>,
    <13247, 13248, 13243>,
    <13247, 13243, 13242>,
    <13249, 13250, 13251>,
    <13249, 13251, 13252>,
    <13249, 13252, 13253>,
    <13249, 13253, 13254>,
    <13249, 13254, 13231>,
    <13249, 13231, 13230>,
    <13249, 13230, 13229>,
    <13249, 13229, 13250>,
    <13255, 13256, 13251>,
    <13255, 13251, 13250>,
    <13255, 13250, 13229>,
    <13255, 13229, 13238>,
    <13255, 13238, 2608>,
    <13255, 2608, 2806>,
    <13255, 2806, 2804>,
    <13255, 2804, 13256>,
    <13257, 13252, 13251>,
    <13257, 13251, 13256>,
    <13257, 13256, 2804>,
    <13257, 2804, 2803>,
    <13257, 2803, 2802>,
    <13257, 2802, 13258>,
    <13257, 13258, 13253>,
    <13257, 13253, 13252>,
    <13259, 13260, 13261>,
    <13259, 13261, 13262>,
    <13259, 13262, 12805>,
    <13259, 12805, 12804>,
    <13259, 12804, 12760>,
    <13259, 12760, 13263>,
    <13259, 13263, 13264>,
    <13259, 13264, 13260>,
    <13265, 13266, 13261>,
    <13265, 13261, 13260>,
    <13265, 13260, 13264>,
    <13265, 13264, 13267>,
    <13265, 13267, 13268>,
    <13265, 13268, 2790>,
    <13265, 2790, 2788>,
    <13265, 2788, 13266>,
    <13269, 13262, 13261>,
    <13269, 13261, 13266>,
    <13269, 13266, 2788>,
    <13269, 2788, 2787>,
    <13269, 2787, 2560>,
    <13269, 2560, 12807>,
    <13269, 12807, 12805>,
    <13269, 12805, 13262>,
    <13270, 13271, 13272>,
    <13270, 13272, 13273>,
    <13270, 13273, 12757>,
    <13270, 12757, 12756>,
    <13270, 12756, 12712>,
    <13270, 12712, 13274>,
    <13270, 13274, 13275>,
    <13270, 13275, 13271>,
    <13276, 13277, 13272>,
    <13276, 13272, 13271>,
    <13276, 13271, 13275>,
    <13276, 13275, 13278>,
    <13276, 13278, 13279>,
    <13276, 13279, 13280>,
    <13276, 13280, 13281>,
    <13276, 13281, 13277>,
    <13282, 13273, 13272>,
    <13282, 13272, 13277>,
    <13282, 13277, 13281>,
    <13282, 13281, 13283>,
    <13282, 13283, 12760>,
    <13282, 12760, 12759>,
    <13282, 12759, 12757>,
    <13282, 12757, 13273>,
    <13284, 13285, 13286>,
    <13284, 13286, 13287>,
    <13284, 13287, 13264>,
    <13284, 13264, 13263>,
    <13284, 13263, 12760>,
    <13284, 12760, 13283>,
    <13284, 13283, 13281>,
    <13284, 13281, 13285>,
    <13288, 13289, 13286>,
    <13288, 13286, 13285>,
    <13288, 13285, 13281>,
    <13288, 13281, 13280>,
    <13288, 13280, 13279>,
    <13288, 13279, 13290>,
    <13288, 13290, 13291>,
    <13288, 13291, 13289>,
    <13292, 13287, 13286>,
    <13292, 13286, 13289>,
    <13292, 13289, 13291>,
    <13292, 13291, 13293>,
    <13292, 13293, 13294>,
    <13292, 13294, 13267>,
    <13292, 13267, 13264>,
    <13292, 13264, 13287>,
    <13295, 13296, 13297>,
    <13295, 13297, 13298>,
    <13295, 13298, 12709>,
    <13295, 12709, 12708>,
    <13295, 12708, 12568>,
    <13295, 12568, 13299>,
    <13295, 13299, 13300>,
    <13295, 13300, 13296>,
    <13301, 13302, 13297>,
    <13301, 13297, 13296>,
    <13301, 13296, 13300>,
    <13301, 13300, 13303>,
    <13301, 13303, 13304>,
    <13301, 13304, 13305>,
    <13301, 13305, 13306>,
    <13301, 13306, 13302>,
    <13307, 13298, 13297>,
    <13307, 13297, 13302>,
    <13307, 13302, 13306>,
    <13307, 13306, 13308>,
    <13307, 13308, 12712>,
    <13307, 12712, 12711>,
    <13307, 12711, 12709>,
    <13307, 12709, 13298>,
    <13309, 13310, 13311>,
    <13309, 13311, 13312>,
    <13309, 13312, 13275>,
    <13309, 13275, 13274>,
    <13309, 13274, 12712>,
    <13309, 12712, 13308>,
    <13309, 13308, 13306>,
    <13309, 13306, 13310>,
    <13313, 13314, 13311>,
    <13313, 13311, 13310>,
    <13313, 13310, 13306>,
    <13313, 13306, 13305>,
    <13313, 13305, 13304>,
    <13313, 13304, 13315>,
    <13313, 13315, 13316>,
    <13313, 13316, 13314>,
    <13317, 13312, 13311>,
    <13317, 13311, 13314>,
    <13317, 13314, 13316>,
    <13317, 13316, 13318>,
    <13317, 13318, 13279>,
    <13317, 13279, 13278>,
    <13317, 13278, 13275>,
    <13317, 13275, 13312>,
    <13319, 13320, 13321>,
    <13319, 13321, 13322>,
    <13319, 13322, 13323>,
    <13319, 13323, 13324>,
    <13319, 13324, 12613>,
    <13319, 12613, 12666>,
    <13319, 12666, 12664>,
    <13319, 12664, 13320>,
    <13325, 13326, 13321>,
    <13325, 13321, 13320>,
    <13325, 13320, 12664>,
    <13325, 12664, 12663>,
    <13325, 12663, 13327>,
    <13325, 13327, 2766>,
    <13325, 2766, 2765>,
    <13325, 2765, 13326>,
    <13328, 13322, 13321>,
    <13328, 13321, 13326>,
    <13328, 13326, 2765>,
    <13328, 2765, 2779>,
    <13328, 2779, 13329>,
    <13328, 13329, 13330>,
    <13328, 13330, 13323>,
    <13328, 13323, 13322>,
    <13331, 13332, 13333>,
    <13331, 13333, 13334>,
    <13331, 13334, 13335>,
    <13331, 13335, 13336>,
    <13331, 13336, 12517>,
    <13331, 12517, 12617>,
    <13331, 12617, 12615>,
    <13331, 12615, 13332>,
    <13337, 13338, 13333>,
    <13337, 13333, 13332>,
    <13337, 13332, 12615>,
    <13337, 12615, 12614>,
    <13337, 12614, 12613>,
    <13337, 12613, 13339>,
    <13337, 13339, 13340>,
    <13337, 13340, 13338>,
    <13341, 13334, 13333>,
    <13341, 13333, 13338>,
    <13341, 13338, 13340>,
    <13341, 13340, 13342>,
    <13341, 13342, 13343>,
    <13341, 13343, 13344>,
    <13341, 13344, 13335>,
    <13341, 13335, 13334>,
    <13345, 13346, 13347>,
    <13345, 13347, 13348>,
    <13345, 13348, 13340>,
    <13345, 13340, 13339>,
    <13345, 13339, 12613>,
    <13345, 12613, 13324>,
    <13345, 13324, 13323>,
    <13345, 13323, 13346>,
    <13349, 13350, 13347>,
    <13349, 13347, 13346>,
    <13349, 13346, 13323>,
    <13349, 13323, 13330>,
    <13349, 13330, 13351>,
    <13349, 13351, 13352>,
    <13349, 13352, 13353>,
    <13349, 13353, 13350>,
    <13354, 13348, 13347>,
    <13354, 13347, 13350>,
    <13354, 13350, 13353>,
    <13354, 13353, 13355>,
    <13354, 13355, 13343>,
    <13354, 13343, 13342>,
    <13354, 13342, 13340>,
    <13354, 13340, 13348>,
    <13356, 13357, 13358>,
    <13356, 13358, 13359>,
    <13356, 13359, 12565>,
    <13356, 12565, 12564>,
    <13356, 12564, 12424>,
    <13356, 12424, 13360>,
    <13356, 13360, 13361>,
    <13356, 13361, 13357>,
    <13362, 13363, 13358>,
    <13362, 13358, 13357>,
    <13362, 13357, 13361>,
    <13362, 13361, 13364>,
    <13362, 13364, 13365>,
    <13362, 13365, 13366>,
    <13362, 13366, 13367>,
    <13362, 13367, 13363>,
    <13368, 13359, 13358>,
    <13368, 13358, 13363>,
    <13368, 13363, 13367>,
    <13368, 13367, 13369>,
    <13368, 13369, 12568>,
    <13368, 12568, 12567>,
    <13368, 12567, 12565>,
    <13368, 12565, 13359>,
    <13370, 13371, 13372>,
    <13370, 13372, 13373>,
    <13370, 13373, 13300>,
    <13370, 13300, 13299>,
    <13370, 13299, 12568>,
    <13370, 12568, 13369>,
    <13370, 13369, 13367>,
    <13370, 13367, 13371>,
    <13374, 13375, 13372>,
    <13374, 13372, 13371>,
    <13374, 13371, 13367>,
    <13374, 13367, 13366>,
    <13374, 13366, 13365>,
    <13374, 13365, 13376>,
    <13374, 13376, 13377>,
    <13374, 13377, 13375>,
    <13378, 13373, 13372>,
    <13378, 13372, 13375>,
    <13378, 13375, 13377>,
    <13378, 13377, 13379>,
    <13378, 13379, 13304>,
    <13378, 13304, 13303>,
    <13378, 13303, 13300>,
    <13378, 13300, 13373>,
    <13380, 13381, 13382>,
    <13380, 13382, 13383>,
    <13380, 13383, 13384>,
    <13380, 13384, 13385>,
    <13380, 13385, 12469>,
    <13380, 12469, 12521>,
    <13380, 12521, 12519>,
    <13380, 12519, 13381>,
    <13386, 13387, 13382>,
    <13386, 13382, 13381>,
    <13386, 13381, 12519>,
    <13386, 12519, 12518>,
    <13386, 12518, 12517>,
    <13386, 12517, 13388>,
    <13386, 13388, 13389>,
    <13386, 13389, 13387>,
    <13390, 13383, 13382>,
    <13390, 13382, 13387>,
    <13390, 13387, 13389>,
    <13390, 13389, 13391>,
    <13390, 13391, 13392>,
    <13390, 13392, 13393>,
    <13390, 13393, 13384>,
    <13390, 13384, 13383>,
    <13394, 13395, 13396>,
    <13394, 13396, 13397>,
    <13394, 13397, 13389>,
    <13394, 13389, 13388>,
    <13394, 13388, 12517>,
    <13394, 12517, 13336>,
    <13394, 13336, 13335>,
    <13394, 13335, 13395>,
    <13398, 13399, 13396>,
    <13398, 13396, 13395>,
    <13398, 13395, 13335>,
    <13398, 13335, 13344>,
    <13398, 13344, 13343>,
    <13398, 13343, 13400>,
    <13398, 13400, 13401>,
    <13398, 13401, 13399>,
    <13402, 13397, 13396>,
    <13402, 13396, 13399>,
    <13402, 13399, 13401>,
    <13402, 13401, 13403>,
    <13402, 13403, 13392>,
    <13402, 13392, 13391>,
    <13402, 13391, 13389>,
    <13402, 13389, 13397>,
    <13404, 13405, 13406>,
    <13404, 13406, 13407>,
    <13404, 13407, 13408>,
    <13404, 13408, 13409>,
    <13404, 13409, 12373>,
    <13404, 12373, 12473>,
    <13404, 12473, 12471>,
    <13404, 12471, 13405>,
    <13410, 13411, 13406>,
    <13410, 13406, 13405>,
    <13410, 13405, 12471>,
    <13410, 12471, 12470>,
    <13410, 12470, 12469>,
    <13410, 12469, 13412>,
    <13410, 13412, 13413>,
    <13410, 13413, 13411>,
    <13414, 13407, 13406>,
    <13414, 13406, 13411>,
    <13414, 13411, 13413>,
    <13414, 13413, 13415>,
    <13414, 13415, 13416>,
    <13414, 13416, 13417>,
    <13414, 13417, 13408>,
    <13414, 13408, 13407>,
    <13418, 13419, 13420>,
    <13418, 13420, 13421>,
    <13418, 13421, 13413>,
    <13418, 13413, 13412>,
    <13418, 13412, 12469>,
    <13418, 12469, 13385>,
    <13418, 13385, 13384>,
    <13418, 13384, 13419>,
    <13422, 13423, 13420>,
    <13422, 13420, 13419>,
    <13422, 13419, 13384>,
    <13422, 13384, 13393>,
    <13422, 13393, 13392>,
    <13422, 13392, 13424>,
    <13422, 13424, 13425>,
    <13422, 13425, 13423>,
    <13426, 13421, 13420>,
    <13426, 13420, 13423>,
    <13426, 13423, 13425>,
    <13426, 13425, 13427>,
    <13426, 13427, 13416>,
    <13426, 13416, 13415>,
    <13426, 13415, 13413>,
    <13426, 13413, 13421>,
    <13428, 13429, 13430>,
    <13428, 13430, 13431>,
    <13428, 13431, 12421>,
    <13428, 12421, 12420>,
    <13428, 12420, 12328>,
    <13428, 12328, 13432>,
    <13428, 13432, 13433>,
    <13428, 13433, 13429>,
    <13434, 13435, 13430>,
    <13434, 13430, 13429>,
    <13434, 13429, 13433>,
    <13434, 13433, 13436>,
    <13434, 13436, 13437>,
    <13434, 13437, 13438>,
    <13434, 13438, 13439>,
    <13434, 13439, 13435>,
    <13440, 13431, 13430>,
    <13440, 13430, 13435>,
    <13440, 13435, 13439>,
    <13440, 13439, 13441>,
    <13440, 13441, 12424>,
    <13440, 12424, 12423>,
    <13440, 12423, 12421>,
    <13440, 12421, 13431>,
    <13442, 13443, 13444>,
    <13442, 13444, 13445>,
    <13442, 13445, 13361>,
    <13442, 13361, 13360>,
    <13442, 13360, 12424>,
    <13442, 12424, 13441>,
    <13442, 13441, 13439>,
    <13442, 13439, 13443>,
    <13446, 13447, 13444>,
    <13446, 13444, 13443>,
    <13446, 13443, 13439>,
    <13446, 13439, 13438>,
    <13446, 13438, 13437>,
    <13446, 13437, 13448>,
    <13446, 13448, 13449>,
    <13446, 13449, 13447>,
    <13450, 13445, 13444>,
    <13450, 13444, 13447>,
    <13450, 13447, 13449>,
    <13450, 13449, 13451>,
    <13450, 13451, 13365>,
    <13450, 13365, 13364>,
    <13450, 13364, 13361>,
    <13450, 13361, 13445>,
    <13452, 13453, 13454>,
    <13452, 13454, 13455>,
    <13452, 13455, 13456>,
    <13452, 13456, 13457>,
    <13452, 13457, 12277>,
    <13452, 12277, 12377>,
    <13452, 12377, 12375>,
    <13452, 12375, 13453>,
    <13458, 13459, 13454>,
    <13458, 13454, 13453>,
    <13458, 13453, 12375>,
    <13458, 12375, 12374>,
    <13458, 12374, 12373>,
    <13458, 12373, 13460>,
    <13458, 13460, 13461>,
    <13458, 13461, 13459>,
    <13462, 13455, 13454>,
    <13462, 13454, 13459>,
    <13462, 13459, 13461>,
    <13462, 13461, 13463>,
    <13462, 13463, 13464>,
    <13462, 13464, 13465>,
    <13462, 13465, 13456>,
    <13462, 13456, 13455>,
    <13466, 13467, 13468>,
    <13466, 13468, 13469>,
    <13466, 13469, 13461>,
    <13466, 13461, 13460>,
    <13466, 13460, 12373>,
    <13466, 12373, 13409>,
    <13466, 13409, 13408>,
    <13466, 13408, 13467>,
    <13470, 13471, 13468>,
    <13470, 13468, 13467>,
    <13470, 13467, 13408>,
    <13470, 13408, 13417>,
    <13470, 13417, 13416>,
    <13470, 13416, 13472>,
    <13470, 13472, 13473>,
    <13470, 13473, 13471>,
    <13474, 13469, 13468>,
    <13474, 13468, 13471>,
    <13474, 13471, 13473>,
    <13474, 13473, 13475>,
    <13474, 13475, 13464>,
    <13474, 13464, 13463>,
    <13474, 13463, 13461>,
    <13474, 13461, 13469>,
    <13476, 13477, 13478>,
    <13476, 13478, 13479>,
    <13476, 13479, 12325>,
    <13476, 12325, 12324>,
    <13476, 12324, 12212>,
    <13476, 12212, 13480>,
    <13476, 13480, 13481>,
    <13476, 13481, 13477>,
    <13482, 13483, 13478>,
    <13482, 13478, 13477>,
    <13482, 13477, 13481>,
    <13482, 13481, 13484>,
    <13482, 13484, 13485>,
    <13482, 13485, 13486>,
    <13482, 13486, 13487>,
    <13482, 13487, 13483>,
    <13488, 13479, 13478>,
    <13488, 13478, 13483>,
    <13488, 13483, 13487>,
    <13488, 13487, 13489>,
    <13488, 13489, 12328>,
    <13488, 12328, 12327>,
    <13488, 12327, 12325>,
    <13488, 12325, 13479>,
    <13490, 13491, 13492>,
    <13490, 13492, 13493>,
    <13490, 13493, 13433>,
    <13490, 13433, 13432>,
    <13490, 13432, 12328>,
    <13490, 12328, 13489>,
    <13490, 13489, 13487>,
    <13490, 13487, 13491>,
    <13494, 13495, 13492>,
    <13494, 13492, 13491>,
    <13494, 13491, 13487>,
    <13494, 13487, 13486>,
    <13494, 13486, 13485>,
    <13494, 13485, 13496>,
    <13494, 13496, 13497>,
    <13494, 13497, 13495>,
    <13498, 13493, 13492>,
    <13498, 13492, 13495>,
    <13498, 13495, 13497>,
    <13498, 13497, 13499>,
    <13498, 13499, 13437>,
    <13498, 13437, 13436>,
    <13498, 13436, 13433>,
    <13498, 13433, 13493>,
    <13500, 13501, 13502>,
    <13500, 13502, 13503>,
    <13500, 13503, 13504>,
    <13500, 13504, 13505>,
    <13500, 13505, 12153>,
    <13500, 12153, 12281>,
    <13500, 12281, 12279>,
    <13500, 12279, 13501>,
    <13506, 13507, 13502>,
    <13506, 13502, 13501>,
    <13506, 13501, 12279>,
    <13506, 12279, 12278>,
    <13506, 12278, 12277>,
    <13506, 12277, 13508>,
    <13506, 13508, 13509>,
    <13506, 13509, 13507>,
    <13510, 13503, 13502>,
    <13510, 13502, 13507>,
    <13510, 13507, 13509>,
    <13510, 13509, 13511>,
    <13510, 13511, 13512>,
    <13510, 13512, 13513>,
    <13510, 13513, 13504>,
    <13510, 13504, 13503>,
    <13514, 13515, 13516>,
    <13514, 13516, 13517>,
    <13514, 13517, 13509>,
    <13514, 13509, 13508>,
    <13514, 13508, 12277>,
    <13514, 12277, 13457>,
    <13514, 13457, 13456>,
    <13514, 13456, 13515>,
    <13518, 13519, 13516>,
    <13518, 13516, 13515>,
    <13518, 13515, 13456>,
    <13518, 13456, 13465>,
    <13518, 13465, 13464>,
    <13518, 13464, 13520>,
    <13518, 13520, 13521>,
    <13518, 13521, 13519>,
    <13522, 13517, 13516>,
    <13522, 13516, 13519>,
    <13522, 13519, 13521>,
    <13522, 13521, 13523>,
    <13522, 13523, 13512>,
    <13522, 13512, 13511>,
    <13522, 13511, 13509>,
    <13522, 13509, 13517>,
    <13524, 13525, 13526>,
    <13524, 13526, 13527>,
    <13524, 13527, 13528>,
    <13524, 13528, 13529>,
    <13524, 13529, 13530>,
    <13524, 13530, 13531>,
    <13524, 13532, 13533>,
    <13524, 13533, 13525>,
    <13534, 13535, 13526>,
    <13534, 13526, 13525>,
    <13534, 13525, 13536>,
    <13534, 13536, 13537>,
    <13534, 13538, 13539>,
    <13534, 13539, 13540>,
    <13534, 13540, 13541>,
    <13534, 13541, 13535>,
    <13542, 13527, 13526>,
    <13542, 13526, 13535>,
    <13542, 13535, 13541>,
    <13542, 13541, 13543>,
    <13542, 13543, 13544>,
    <13542, 13544, 13545>,
    <13542, 13545, 13528>,
    <13542, 13528, 13527>,
    <13546, 13547, 13548>,
    <13546, 13548, 13549>,
    <13546, 13549, 12209>,
    <13546, 12209, 12208>,
    <13546, 12208, 13550>,
    <13546, 13550, 13529>,
    <13546, 13529, 13528>,
    <13546, 13528, 13547>,
    <13551, 13552, 13548>,
    <13551, 13548, 13547>,
    <13551, 13547, 13528>,
    <13551, 13528, 13545>,
    <13551, 13545, 13544>,
    <13551, 13544, 13553>,
    <13551, 13553, 13554>,
    <13551, 13554, 13552>,
    <13555, 13549, 13548>,
    <13555, 13548, 13552>,
    <13555, 13552, 13554>,
    <13555, 13554, 13556>,
    <13555, 13556, 12212>,
    <13555, 12212, 12211>,
    <13555, 12211, 12209>,
    <13555, 12209, 13549>,
    <13557, 13558, 13559>,
    <13557, 13559, 13560>,
    <13557, 13560, 13481>,
    <13557, 13481, 13480>,
    <13557, 13480, 12212>,
    <13557, 12212, 13556>,
    <13557, 13556, 13554>,
    <13557, 13554, 13558>,
    <13561, 13562, 13559>,
    <13561, 13559, 13558>,
    <13561, 13558, 13554>,
    <13561, 13554, 13553>,
    <13561, 13553, 13544>,
    <13561, 13544, 13563>,
    <13561, 13563, 13564>,
    <13561, 13564, 13562>,
    <13565, 13560, 13559>,
    <13565, 13559, 13562>,
    <13565, 13562, 13564>,
    <13565, 13564, 13566>,
    <13565, 13566, 13485>,
    <13565, 13485, 13484>,
    <13565, 13484, 13481>,
    <13565, 13481, 13560>,
    <13567, 13568, 13569>,
    <13567, 13569, 13570>,
    <13567, 13570, 13571>,
    <13567, 13571, 13572>,
    <13567, 13572, 12027>,
    <13567, 12027, 12157>,
    <13567, 12157, 12155>,
    <13567, 12155, 13568>,
    <13573, 13574, 13569>,
    <13573, 13569, 13568>,
    <13573, 13568, 12155>,
    <13573, 12155, 12154>,
    <13573, 12154, 12153>,
    <13573, 12153, 13575>,
    <13573, 13575, 13576>,
    <13573, 13576, 13574>,
    <13577, 13570, 13569>,
    <13577, 13569, 13574>,
    <13577, 13574, 13576>,
    <13577, 13576, 13578>,
    <13577, 13578, 13579>,
    <13577, 13579, 13580>,
    <13577, 13580, 13571>,
    <13577, 13571, 13570>,
    <13581, 13582, 13583>,
    <13581, 13583, 13584>,
    <13581, 13584, 13576>,
    <13581, 13576, 13575>,
    <13581, 13575, 12153>,
    <13581, 12153, 13505>,
    <13581, 13505, 13504>,
    <13581, 13504, 13582>,
    <13585, 13586, 13583>,
    <13585, 13583, 13582>,
    <13585, 13582, 13504>,
    <13585, 13504, 13513>,
    <13585, 13513, 13512>,
    <13585, 13512, 13587>,
    <13585, 13587, 13588>,
    <13585, 13588, 13586>,
    <13589, 13584, 13583>,
    <13589, 13583, 13586>,
    <13589, 13586, 13588>,
    <13589, 13588, 13590>,
    <13589, 13590, 13579>,
    <13589, 13579, 13578>,
    <13589, 13578, 13576>,
    <13589, 13576, 13584>,
    <13591, 13592, 13593>,
    <13591, 13593, 13594>,
    <13591, 13594, 13541>,
    <13591, 13541, 13540>,
    <13591, 13540, 13595>,
    <13591, 13595, 13596>,
    <13591, 13597, 13598>,
    <13591, 13598, 13592>,
    <13599, 13600, 13593>,
    <13599, 13593, 13592>,
    <13599, 13592, 13601>,
    <13599, 13601, 13602>,
    <13599, 13603, 13604>,
    <13599, 13604, 13605>,
    <13599, 13605, 13606>,
    <13599, 13606, 13600>,
    <13607, 13594, 13593>,
    <13607, 13593, 13600>,
    <13607, 13600, 13606>,
    <13607, 13606, 13608>,
    <13607, 13608, 13544>,
    <13607, 13544, 13543>,
    <13607, 13543, 13541>,
    <13607, 13541, 13594>,
    <13609, 13610, 13611>,
    <13609, 13611, 13612>,
    <13609, 13612, 13613>,
    <13609, 13613, 13614>,
    <13609, 13614, 13615>,
    <13609, 13615, 13616>,
    <13609, 13617, 13618>,
    <13609, 13618, 13610>,
    <13619, 13620, 13611>,
    <13619, 13611, 13610>,
    <13619, 13610, 13621>,
    <13619, 13621, 13622>,
    <13619, 13623, 13624>,
    <13619, 13624, 13625>,
    <13619, 13625, 13626>,
    <13619, 13626, 13620>,
    <13627, 13612, 13611>,
    <13627, 13611, 13620>,
    <13627, 13620, 13626>,
    <13627, 13626, 13628>,
    <13627, 13628, 13629>,
    <13627, 13629, 13630>,
    <13627, 13630, 13613>,
    <13627, 13613, 13612>,
    <13631, 13632, 13633>,
    <13631, 13633, 13634>,
    <13631, 13634, 13626>,
    <13631, 13626, 13625>,
    <13631, 13625, 13635>,
    <13631, 13635, 12831>,
    <13631, 12831, 12830>,
    <13631, 12830, 13632>,
    <13636, 13637, 13633>,
    <13636, 13633, 13632>,
    <13636, 13632, 12830>,
    <13636, 12830, 12843>,
    <13636, 12843, 12027>,
    <13636, 12027, 13638>,
    <13636, 13638, 13639>,
    <13636, 13639, 13637>,
    <13640, 13634, 13633>,
    <13640, 13633, 13637>,
    <13640, 13637, 13639>,
    <13640, 13639, 13641>,
    <13640, 13641, 13629>,
    <13640, 13629, 13628>,
    <13640, 13628, 13626>,
    <13640, 13626, 13634>,
    <13642, 13643, 13644>,
    <13642, 13644, 13645>,
    <13642, 13645, 13639>,
    <13642, 13639, 13638>,
    <13642, 13638, 12027>,
    <13642, 12027, 13572>,
    <13642, 13572, 13571>,
    <13642, 13571, 13643>,
    <13646, 13647, 13644>,
    <13646, 13644, 13643>,
    <13646, 13643, 13571>,
    <13646, 13571, 13580>,
    <13646, 13580, 13579>,
    <13646, 13579, 13648>,
    <13646, 13648, 13649>,
    <13646, 13649, 13647>,
    <13650, 13645, 13644>,
    <13650, 13644, 13647>,
    <13650, 13647, 13649>,
    <13650, 13649, 13651>,
    <13650, 13651, 13629>,
    <13650, 13629, 13641>,
    <13650, 13641, 13639>,
    <13650, 13639, 13645>,
    <13652, 13653, 13654>,
    <13652, 13654, 13655>,
    <13652, 13655, 13656>,
    <13652, 13656, 13657>,
    <13652, 13658, 13659>,
    <13652, 13659, 13614>,
    <13652, 13614, 13613>,
    <13652, 13613, 13653>,
    <13660, 13661, 13654>,
    <13660, 13654, 13653>,
    <13660, 13653, 13613>,
    <13660, 13613, 13630>,
    <13660, 13630, 13629>,
    <13660, 13629, 13662>,
    <13660, 13662, 13663>,
    <13660, 13663, 13661>,
    <13664, 13655, 13654>,
    <13664, 13654, 13661>,
    <13664, 13661, 13663>,
    <13664, 13663, 13665>,
    <13664, 13665, 13666>,
    <13664, 13666, 13667>,
    <13664, 13668, 13669>,
    <13664, 13669, 13655>,
    <13670, 13671, 13672>,
    <13670, 13672, 13673>,
    <13670, 13673, 13674>,
    <13670, 13674, 13675>,
    <13670, 13675, 13676>,
    <13670, 13676, 13677>,
    <13670, 13678, 13679>,
    <13670, 13679, 13671>,
    <13680, 13681, 13672>,
    <13680, 13672, 13671>,
    <13680, 13671, 13682>,
    <13680, 13682, 13683>,
    <13680, 13684, 13685>,
    <13680, 13685, 13665>,
    <13680, 13665, 13663>,
    <13680, 13663, 13681>,
    <13686, 13673, 13672>,
    <13686, 13672, 13681>,
    <13686, 13681, 13663>,
    <13686, 13663, 13662>,
    <13686, 13662, 13629>,
    <13686, 13629, 13687>,
    <13686, 13687, 13674>,
    <13686, 13674, 13673>,
    <13688, 13689, 13690>,
    <13688, 13690, 13691>,
    <13688, 13691, 13692>,
    <13688, 13692, 13693>,
    <13688, 13694, 13695>,
    <13688, 13695, 13696>,
    <13688, 13696, 13697>,
    <13688, 13697, 13689>,
    <13698, 13699, 13690>,
    <13698, 13690, 13689>,
    <13698, 13689, 13697>,
    <13698, 13697, 13700>,
    <13698, 13700, 12886>,
    <13698, 12886, 12922>,
    <13698, 12922, 12920>,
    <13698, 12920, 13699>,
    <13701, 13691, 13690>,
    <13701, 13690, 13699>,
    <13701, 13699, 12920>,
    <13701, 12920, 12919>,
    <13701, 12919, 13702>,
    <13701, 13702, 13703>,
    <13701, 13704, 13705>,
    <13701, 13705, 13691>,
    <13706, 13707, 13708>,
    <13706, 13708, 13709>,
    <13706, 13709, 13710>,
    <13706, 13710, 13711>,
    <13706, 13711, 13712>,
    <13706, 13712, 13713>,
    <13706, 13714, 13715>,
    <13706, 13715, 13707>,
    <13716, 13717, 13708>,
    <13716, 13708, 13707>,
    <13716, 13707, 13718>,
    <13716, 13718, 13719>,
    <13716, 13720, 13721>,
    <13716, 13721, 12984>,
    <13716, 12984, 12983>,
    <13716, 12983, 13717>,
    <13722, 13709, 13708>,
    <13722, 13708, 13717>,
    <13722, 13717, 12983>,
    <13722, 12983, 12989>,
    <13722, 12989, 12971>,
    <13722, 12971, 13723>,
    <13722, 13723, 13710>,
    <13722, 13710, 13709>,
    <13724, 13725, 13726>,
    <13724, 13726, 13727>,
    <13724, 13727, 13291>,
    <13724, 13291, 13290>,
    <13724, 13290, 13279>,
    <13724, 13279, 13728>,
    <13724, 13728, 13729>,
    <13724, 13729, 13725>,
    <13730, 13731, 13726>,
    <13730, 13726, 13725>,
    <13730, 13725, 13729>,
    <13730, 13729, 13732>,
    <13730, 13732, 13733>,
    <13730, 13733, 13734>,
    <13730, 13735, 13736>,
    <13730, 13736, 13731>,
    <13737, 13727, 13726>,
    <13737, 13726, 13731>,
    <13737, 13731, 13738>,
    <13737, 13738, 13739>,
    <13737, 13740, 13741>,
    <13737, 13741, 13293>,
    <13737, 13293, 13291>,
    <13737, 13291, 13727>,
    <13742, 13743, 13744>,
    <13742, 13744, 13745>,
    <13742, 13745, 13316>,
    <13742, 13316, 13315>,
    <13742, 13315, 13304>,
    <13742, 13304, 13746>,
    <13742, 13746, 13747>,
    <13742, 13747, 13743>,
    <13748, 13749, 13744>,
    <13748, 13744, 13743>,
    <13748, 13743, 13747>,
    <13748, 13747, 13750>,
    <13748, 13750, 13751>,
    <13748, 13751, 13752>,
    <13748, 13752, 13753>,
    <13748, 13753, 13749>,
    <13754, 13745, 13744>,
    <13754, 13744, 13749>,
    <13754, 13749, 13753>,
    <13754, 13753, 13755>,
    <13754, 13755, 13279>,
    <13754, 13279, 13318>,
    <13754, 13318, 13316>,
    <13754, 13316, 13745>,
    <13756, 13757, 13758>,
    <13756, 13758, 13759>,
    <13756, 13759, 13729>,
    <13756, 13729, 13728>,
    <13756, 13728, 13279>,
    <13756, 13279, 13755>,
    <13756, 13755, 13753>,
    <13756, 13753, 13757>,
    <13760, 13761, 13758>,
    <13760, 13758, 13757>,
    <13760, 13757, 13753>,
    <13760, 13753, 13752>,
    <13760, 13752, 13751>,
    <13760, 13751, 13762>,
    <13760, 13762, 13763>,
    <13760, 13763, 13761>,
    <13764, 13759, 13758>,
    <13764, 13758, 13761>,
    <13764, 13761, 13763>,
    <13764, 13763, 13765>,
    <13764, 13765, 13766>,
    <13764, 13766, 13732>,
    <13764, 13732, 13729>,
    <13764, 13729, 13759>,
    <13767, 13768, 13769>,
    <13767, 13769, 13770>,
    <13767, 13770, 13771>,
    <13767, 13771, 13772>,
    <13767, 13772, 13773>,
    <13767, 13773, 13774>,
    <13767, 13774, 13775>,
    <13767, 13775, 13768>,
    <13776, 13777, 13769>,
    <13776, 13769, 13768>,
    <13776, 13768, 13775>,
    <13776, 13775, 13778>,
    <13776, 13778, 2802>,
    <13776, 2802, 3021>,
    <13776, 3021, 3019>,
    <13776, 3019, 13777>,
    <13779, 13770, 13769>,
    <13779, 13769, 13777>,
    <13779, 13777, 3019>,
    <13779, 3019, 3018>,
    <13779, 3018, 13780>,
    <13779, 13780, 13781>,
    <13779, 13781, 13771>,
    <13779, 13771, 13770>,
    <13782, 13783, 13784>,
    <13782, 13784, 13785>,
    <13782, 13785, 13775>,
    <13782, 13775, 13774>,
    <13782, 13774, 13773>,
    <13782, 13773, 13786>,
    <13782, 13786, 13787>,
    <13782, 13787, 13783>,
    <13788, 13789, 13784>,
    <13788, 13784, 13783>,
    <13788, 13783, 13787>,
    <13788, 13787, 13790>,
    <13788, 13790, 13231>,
    <13788, 13231, 13254>,
    <13788, 13254, 13253>,
    <13788, 13253, 13789>,
    <13791, 13785, 13784>,
    <13791, 13784, 13789>,
    <13791, 13789, 13253>,
    <13791, 13253, 13258>,
    <13791, 13258, 2802>,
    <13791, 2802, 13778>,
    <13791, 13778, 13775>,
    <13791, 13775, 13785>,
    <13792, 13793, 13794>,
    <13792, 13794, 13795>,
    <13792, 13795, 13377>,
    <13792, 13377, 13376>,
    <13792, 13376, 13365>,
    <13792, 13365, 13796>,
    <13792, 13796, 13797>,
    <13792, 13797, 13793>,
    <13798, 13799, 13794>,
    <13798, 13794, 13793>,
    <13798, 13793, 13797>,
    <13798, 13797, 13800>,
    <13798, 13800, 13801>,
    <13798, 13801, 13802>,
    <13798, 13802, 13803>,
    <13798, 13803, 13799>,
    <13804, 13795, 13794>,
    <13804, 13794, 13799>,
    <13804, 13799, 13803>,
    <13804, 13803, 13805>,
    <13804, 13805, 13304>,
    <13804, 13304, 13379>,
    <13804, 13379, 13377>,
    <13804, 13377, 13795>,
    <13806, 13807, 13808>,
    <13806, 13808, 13809>,
    <13806, 13809, 13747>,
    <13806, 13747, 13746>,
    <13806, 13746, 13304>,
    <13806, 13304, 13805>,
    <13806, 13805, 13803>,
    <13806, 13803, 13807>,
    <13810, 13811, 13808>,
    <13810, 13808, 13807>,
    <13810, 13807, 13803>,
    <13810, 13803, 13802>,
    <13810, 13802, 13801>,
    <13810, 13801, 13812>,
    <13810, 13812, 13813>,
    <13810, 13813, 13811>,
    <13814, 13809, 13808>,
    <13814, 13808, 13811>,
    <13814, 13811, 13813>,
    <13814, 13813, 13815>,
    <13814, 13815, 13751>,
    <13814, 13751, 13750>,
    <13814, 13750, 13747>,
    <13814, 13747, 13809>,
    <13816, 13817, 13818>,
    <13816, 13818, 13819>,
    <13816, 13819, 13820>,
    <13816, 13820, 13821>,
    <13816, 13821, 13822>,
    <13816, 13822, 13823>,
    <13816, 13823, 13824>,
    <13816, 13824, 13817>,
    <13825, 13826, 13818>,
    <13825, 13818, 13817>,
    <13825, 13817, 13824>,
    <13825, 13824, 13827>,
    <13825, 13827, 13231>,
    <13825, 13231, 13790>,
    <13825, 13790, 13787>,
    <13825, 13787, 13826>,
    <13828, 13819, 13818>,
    <13828, 13818, 13826>,
    <13828, 13826, 13787>,
    <13828, 13787, 13786>,
    <13828, 13786, 13773>,
    <13828, 13773, 13829>,
    <13828, 13829, 13820>,
    <13828, 13820, 13819>,
    <13830, 13831, 13832>,
    <13830, 13832, 13833>,
    <13830, 13833, 13824>,
    <13830, 13824, 13823>,
    <13830, 13823, 13822>,
    <13830, 13822, 13834>,
    <13830, 13834, 13835>,
    <13830, 13835, 13831>,
    <13836, 13837, 13832>,
    <13836, 13832, 13831>,
    <13836, 13831, 13835>,
    <13836, 13835, 13838>,
    <13836, 13838, 13207>,
    <13836, 13207, 13244>,
    <13836, 13244, 13243>,
    <13836, 13243, 13837>,
    <13839, 13833, 13832>,
    <13839, 13832, 13837>,
    <13839, 13837, 13243>,
    <13839, 13243, 13248>,
    <13839, 13248, 13231>,
    <13839, 13231, 13827>,
    <13839, 13827, 13824>,
    <13839, 13824, 13833>,
    <13840, 13841, 13842>,
    <13840, 13842, 13843>,
    <13840, 13843, 13844>,
    <13840, 13844, 13845>,
    <13840, 13845, 13343>,
    <13840, 13343, 13355>,
    <13840, 13355, 13353>,
    <13840, 13353, 13841>,
    <13846, 13847, 13842>,
    <13846, 13842, 13841>,
    <13846, 13841, 13353>,
    <13846, 13353, 13352>,
    <13846, 13352, 13848>,
    <13846, 13848, 13849>,
    <13846, 13850, 13851>,
    <13846, 13851, 13847>,
    <13852, 13843, 13842>,
    <13852, 13842, 13847>,
    <13852, 13847, 13853>,
    <13852, 13853, 13854>,
    <13852, 13855, 13856>,
    <13852, 13856, 13857>,
    <13852, 13857, 13844>,
    <13852, 13844, 13843>,
    <13858, 13859, 13860>,
    <13858, 13860, 13861>,
    <13858, 13861, 13862>,
    <13858, 13862, 13863>,
    <13858, 13863, 13392>,
    <13858, 13392, 13403>,
    <13858, 13403, 13401>,
    <13858, 13401, 13859>,
    <13864, 13865, 13860>,
    <13864, 13860, 13859>,
    <13864, 13859, 13401>,
    <13864, 13401, 13400>,
    <13864, 13400, 13343>,
    <13864, 13343, 13866>,
    <13864, 13866, 13867>,
    <13864, 13867, 13865>,
    <13868, 13861, 13860>,
    <13868, 13860, 13865>,
    <13868, 13865, 13867>,
    <13868, 13867, 13869>,
    <13868, 13869, 13870>,
    <13868, 13870, 13871>,
    <13868, 13871, 13862>,
    <13868, 13862, 13861>,
    <13872, 13873, 13874>,
    <13872, 13874, 13875>,
    <13872, 13875, 13867>,
    <13872, 13867, 13866>,
    <13872, 13866, 13343>,
    <13872, 13343, 13845>,
    <13872, 13845, 13844>,
    <13872, 13844, 13873>,
    <13876, 13877, 13874>,
    <13876, 13874, 13873>,
    <13876, 13873, 13844>,
    <13876, 13844, 13857>,
    <13876, 13857, 13878>,
    <13876, 13878, 13879>,
    <13876, 13879, 13880>,
    <13876, 13880, 13877>,
    <13881, 13875, 13874>,
    <13881, 13874, 13877>,
    <13881, 13877, 13880>,
    <13881, 13880, 13882>,
    <13881, 13882, 13870>,
    <13881, 13870, 13869>,
    <13881, 13869, 13867>,
    <13881, 13867, 13875>,
    <13883, 13884, 13885>,
    <13883, 13885, 13886>,
    <13883, 13886, 13887>,
    <13883, 13887, 13888>,
    <13883, 13888, 13889>,
    <13883, 13889, 13890>,
    <13883, 13890, 13891>,
    <13883, 13891, 13884>,
    <13892, 13893, 13885>,
    <13892, 13885, 13884>,
    <13892, 13884, 13891>,
    <13892, 13891, 13894>,
    <13892, 13894, 13895>,
    <13892, 13895, 3028>,
    <13892, 3028, 3027>,
    <13892, 3027, 13893>,
    <13896, 13886, 13885>,
    <13896, 13885, 13893>,
    <13896, 13893, 3027>,
    <13896, 3027, 3034>,
    <13896, 3034, 13897>,
    <13896, 13897, 13898>,
    <13896, 13898, 13887>,
    <13896, 13887, 13886>,
    <13899, 13900, 13901>,
    <13899, 13901, 13902>,
    <13899, 13902, 13903>,
    <13899, 13903, 13904>,
    <13899, 13904, 13889>,
    <13899, 13889, 13888>,
    <13899, 13888, 13887>,
    <13899, 13887, 13900>,
    <13905, 13906, 13901>,
    <13905, 13901, 13900>,
    <13905, 13900, 13887>,
    <13905, 13887, 13898>,
    <13905, 13898, 13907>,
    <13905, 13907, 13191>,
    <13905, 13191, 13188>,
    <13905, 13188, 13906>,
    <13908, 13902, 13901>,
    <13908, 13901, 13906>,
    <13908, 13906, 13188>,
    <13908, 13188, 13187>,
    <13908, 13187, 13164>,
    <13908, 13164, 13909>,
    <13908, 13909, 13903>,
    <13908, 13903, 13902>,
    <13910, 13911, 13912>,
    <13910, 13912, 13913>,
    <13910, 13913, 13449>,
    <13910, 13449, 13448>,
    <13910, 13448, 13437>,
    <13910, 13437, 13914>,
    <13910, 13914, 13915>,
    <13910, 13915, 13911>,
    <13916, 13917, 13912>,
    <13916, 13912, 13911>,
    <13916, 13911, 13915>,
    <13916, 13915, 13918>,
    <13916, 13918, 13919>,
    <13916, 13919, 13920>,
    <13916, 13920, 13921>,
    <13916, 13921, 13917>,
    <13922, 13913, 13912>,
    <13922, 13912, 13917>,
    <13922, 13917, 13921>,
    <13922, 13921, 13923>,
    <13922, 13923, 13365>,
    <13922, 13365, 13451>,
    <13922, 13451, 13449>,
    <13922, 13449, 13913>,
    <13924, 13925, 13926>,
    <13924, 13926, 13927>,
    <13924, 13927, 13797>,
    <13924, 13797, 13796>,
    <13924, 13796, 13365>,
    <13924, 13365, 13923>,
    <13924, 13923, 13921>,
    <13924, 13921, 13925>,
    <13928, 13929, 13926>,
    <13928, 13926, 13925>,
    <13928, 13925, 13921>,
    <13928, 13921, 13920>,
    <13928, 13920, 13919>,
    <13928, 13919, 13930>,
    <13928, 13930, 13931>,
    <13928, 13931, 13929>,
    <13932, 13927, 13926>,
    <13932, 13926, 13929>,
    <13932, 13929, 13931>,
    <13932, 13931, 13933>,
    <13932, 13933, 13801>,
    <13932, 13801, 13800>,
    <13932, 13800, 13797>,
    <13932, 13797, 13927>,
    <13934, 13935, 13936>,
    <13934, 13936, 13937>,
    <13934, 13937, 13938>,
    <13934, 13938, 13939>,
    <13934, 13939, 13940>,
    <13934, 13940, 13941>,
    <13934, 13941, 13942>,
    <13934, 13942, 13935>,
    <13943, 13944, 13936>,
    <13943, 13936, 13935>,
    <13943, 13935, 13942>,
    <13943, 13942, 13945>,
    <13943, 13945, 13207>,
    <13943, 13207, 13838>,
    <13943, 13838, 13835>,
    <13943, 13835, 13944>,
    <13946, 13937, 13936>,
    <13946, 13936, 13944>,
    <13946, 13944, 13835>,
    <13946, 13835, 13834>,
    <13946, 13834, 13822>,
    <13946, 13822, 13947>,
    <13946, 13947, 13938>,
    <13946, 13938, 13937>,
    <13948, 13949, 13950>,
    <13948, 13950, 13951>,
    <13948, 13951, 13942>,
    <13948, 13942, 13941>,
    <13948, 13941, 13940>,
    <13948, 13940, 13952>,
    <13948, 13952, 13953>,
    <13948, 13953, 13949>,
    <13954, 13955, 13950>,
    <13954, 13950, 13949>,
    <13954, 13949, 13953>,
    <13954, 13953, 13956>,
    <13954, 13956, 13140>,
    <13954, 13140, 13220>,
    <13954, 13220, 13219>,
    <13954, 13219, 13955>,
    <13957, 13951, 13950>,
    <13957, 13950, 13955>,
    <13957, 13955, 13219>,
    <13957, 13219, 13224>,
    <13957, 13224, 13207>,
    <13957, 13207, 13945>,
    <13957, 13945, 13942>,
    <13957, 13942, 13951>,
    <13958, 13959, 13960>,
    <13958, 13960, 13961>,
    <13958, 13961, 13962>,
    <13958, 13962, 13963>,
    <13958, 13963, 13416>,
    <13958, 13416, 13427>,
    <13958, 13427, 13425>,
    <13958, 13425, 13959>,
    <13964, 13965, 13960>,
    <13964, 13960, 13959>,
    <13964, 13959, 13425>,
    <13964, 13425, 13424>,
    <13964, 13424, 13392>,
    <13964, 13392, 13966>,
    <13964, 13966, 13967>,
    <13964, 13967, 13965>,
    <13968, 13961, 13960>,
    <13968, 13960, 13965>,
    <13968, 13965, 13967>,
    <13968, 13967, 13969>,
    <13968, 13969, 13970>,
    <13968, 13970, 13971>,
    <13968, 13971, 13962>,
    <13968, 13962, 13961>,
    <13972, 13973, 13974>,
    <13972, 13974, 13975>,
    <13972, 13975, 13967>,
    <13972, 13967, 13966>,
    <13972, 13966, 13392>,
    <13972, 13392, 13863>,
    <13972, 13863, 13862>,
    <13972, 13862, 13973>,
    <13976, 13977, 13974>,
    <13976, 13974, 13973>,
    <13976, 13973, 13862>,
    <13976, 13862, 13871>,
    <13976, 13871, 13870>,
    <13976, 13870, 13978>,
    <13976, 13978, 13979>,
    <13976, 13979, 13977>,
    <13980, 13975, 13974>,
    <13980, 13974, 13977>,
    <13980, 13977, 13979>,
    <13980, 13979, 13981>,
    <13980, 13981, 13970>,
    <13980, 13970, 13969>,
    <13980, 13969, 13967>,
    <13980, 13967, 13975>,
    <13982, 13983, 13984>,
    <13982, 13984, 13985>,
    <13982, 13985, 13986>,
    <13982, 13986, 13987>,
    <13982, 13987, 13988>,
    <13982, 13988, 13989>,
    <13982, 13989, 13990>,
    <13982, 13990, 13983>,
    <13991, 13992, 13984>,
    <13991, 13984, 13983>,
    <13991, 13983, 13990>,
    <13991, 13990, 13993>,
    <13991, 13993, 13889>,
    <13991, 13889, 13904>,
    <13991, 13904, 13903>,
    <13991, 13903, 13992>,
    <13994, 13985, 13984>,
    <13994, 13984, 13992>,
    <13994, 13992, 13903>,
    <13994, 13903, 13909>,
    <13994, 13909, 13164>,
    <13994, 13164, 13995>,
    <13994, 13995, 13986>,
    <13994, 13986, 13985>,
    <13996, 13997, 13998>,
    <13996, 13998, 13999>,
    <13996, 13999, 14000>,
    <13996, 14000, 14001>,
    <13996, 14001, 13988>,
    <13996, 13988, 13987>,
    <13996, 13987, 13986>,
    <13996, 13986, 13997>,
    <14002, 14003, 13998>,
    <14002, 13998, 13997>,
    <14002, 13997, 13986>,
    <14002, 13986, 13995>,
    <14002, 13995, 13164>,
    <14002, 13164, 13181>,
    <14002, 13181, 13178>,
    <14002, 13178, 14003>,
    <14004, 13999, 13998>,
    <14004, 13998, 14003>,
    <14004, 14003, 13178>,
    <14004, 13178, 13177>,
    <14004, 13177, 13116>,
    <14004, 13116, 14005>,
    <14004, 14005, 14000>,
    <14004, 14000, 13999>,
    <14006, 14007, 14008>,
    <14006, 14008, 14009>,
    <14006, 14009, 14010>,
    <14006, 14010, 14011>,
    <14006, 14011, 13464>,
    <14006, 13464, 13475>,
    <14006, 13475, 13473>,
    <14006, 13473, 14007>,
    <14012, 14013, 14008>,
    <14012, 14008, 14007>,
    <14012, 14007, 13473>,
    <14012, 13473, 13472>,
    <14012, 13472, 13416>,
    <14012, 13416, 14014>,
    <14012, 14014, 14015>,
    <14012, 14015, 14013>,
    <14016, 14009, 14008>,
    <14016, 14008, 14013>,
    <14016, 14013, 14015>,
    <14016, 14015, 14017>,
    <14016, 14017, 14018>,
    <14016, 14018, 14019>,
    <14016, 14019, 14010>,
    <14016, 14010, 14009>,
    <14020, 14021, 14022>,
    <14020, 14022, 14023>,
    <14020, 14023, 14015>,
    <14020, 14015, 14014>,
    <14020, 14014, 13416>,
    <14020, 13416, 13963>,
    <14020, 13963, 13962>,
    <14020, 13962, 14021>,
    <14024, 14025, 14022>,
    <14024, 14022, 14021>,
    <14024, 14021, 13962>,
    <14024, 13962, 13971>,
    <14024, 13971, 13970>,
    <14024, 13970, 14026>,
    <14024, 14026, 14027>,
    <14024, 14027, 14025>,
    <14028, 14023, 14022>,
    <14028, 14022, 14025>,
    <14028, 14025, 14027>,
    <14028, 14027, 14029>,
    <14028, 14029, 14018>,
    <14028, 14018, 14017>,
    <14028, 14017, 14015>,
    <14028, 14015, 14023>,
    <14030, 14031, 14032>,
    <14030, 14032, 14033>,
    <14030, 14033, 14034>,
    <14030, 14034, 14035>,
    <14030, 14035, 14036>,
    <14030, 14036, 14037>,
    <14030, 14037, 14038>,
    <14030, 14038, 14031>,
    <14039, 14040, 14032>,
    <14039, 14032, 14031>,
    <14039, 14031, 14038>,
    <14039, 14038, 14041>,
    <14039, 14041, 13988>,
    <14039, 13988, 14001>,
    <14039, 14001, 14000>,
    <14039, 14000, 14040>,
    <14042, 14033, 14032>,
    <14042, 14032, 14040>,
    <14042, 14040, 14000>,
    <14042, 14000, 14005>,
    <14042, 14005, 13116>,
    <14042, 13116, 14043>,
    <14042, 14043, 14034>,
    <14042, 14034, 14033>,
    <14044, 14045, 14046>,
    <14044, 14046, 14047>,
    <14044, 14047, 14048>,
    <14044, 14048, 14049>,
    <14044, 14049, 14036>,
    <14044, 14036, 14035>,
    <14044, 14035, 14034>,
    <14044, 14034, 14045>,
    <14050, 14051, 14046>,
    <14050, 14046, 14045>,
    <14050, 14045, 14034>,
    <14050, 14034, 14043>,
    <14050, 14043, 13116>,
    <14050, 13116, 13132>,
    <14050, 13132, 13129>,
    <14050, 13129, 14051>,
    <14052, 14047, 14046>,
    <14052, 14046, 14051>,
    <14052, 14051, 13129>,
    <14052, 13129, 13128>,
    <14052, 13128, 13092>,
    <14052, 13092, 14053>,
    <14052, 14053, 14048>,
    <14052, 14048, 14047>,
    <14054, 14055, 14056>,
    <14054, 14056, 14057>,
    <14054, 14057, 13497>,
    <14054, 13497, 13496>,
    <14054, 13496, 13485>,
    <14054, 13485, 14058>,
    <14054, 14058, 14059>,
    <14054, 14059, 14055>,
    <14060, 14061, 14056>,
    <14060, 14056, 14055>,
    <14060, 14055, 14059>,
    <14060, 14059, 14062>,
    <14060, 14062, 14063>,
    <14060, 14063, 14064>,
    <14060, 14064, 14065>,
    <14060, 14065, 14061>,
    <14066, 14057, 14056>,
    <14066, 14056, 14061>,
    <14066, 14061, 14065>,
    <14066, 14065, 14067>,
    <14066, 14067, 13437>,
    <14066, 13437, 13499>,
    <14066, 13499, 13497>,
    <14066, 13497, 14057>,
    <14068, 14069, 14070>,
    <14068, 14070, 14071>,
    <14068, 14071, 13915>,
    <14068, 13915, 13914>,
    <14068, 13914, 13437>,
    <14068, 13437, 14067>,
    <14068, 14067, 14065>,
    <14068, 14065, 14069>,
    <14072, 14073, 14070>,
    <14072, 14070, 14069>,
    <14072, 14069, 14065>,
    <14072, 14065, 14064>,
    <14072, 14064, 14063>,
    <14072, 14063, 14074>,
    <14072, 14074, 14075>,
    <14072, 14075, 14073>,
    <14076, 14071, 14070>,
    <14076, 14070, 14073>,
    <14076, 14073, 14075>,
    <14076, 14075, 14077>,
    <14076, 14077, 13919>,
    <14076, 13919, 13918>,
    <14076, 13918, 13915>,
    <14076, 13915, 14071>,
    <14078, 14079, 14080>,
    <14078, 14080, 14081>,
    <14078, 14081, 14082>,
    <14078, 14082, 14083>,
    <14078, 14083, 14084>,
    <14078, 14084, 14085>,
    <14078, 14085, 14086>,
    <14078, 14086, 14079>,
    <14087, 14088, 14080>,
    <14087, 14080, 14079>,
    <14087, 14079, 14086>,
    <14087, 14086, 14089>,
    <14087, 14089, 13140>,
    <14087, 13140, 13956>,
    <14087, 13956, 13953>,
    <14087, 13953, 14088>,
    <14090, 14081, 14080>,
    <14090, 14080, 14088>,
    <14090, 14088, 13953>,
    <14090, 13953, 13952>,
    <14090, 13952, 13940>,
    <14090, 13940, 14091>,
    <14090, 14091, 14082>,
    <14090, 14082, 14081>,
    <14092, 14093, 14094>,
    <14092, 14094, 14095>,
    <14092, 14095, 14086>,
    <14092, 14086, 14085>,
    <14092, 14085, 14084>,
    <14092, 14084, 14096>,
    <14092, 14096, 14097>,
    <14092, 14097, 14093>,
    <14098, 14099, 14094>,
    <14098, 14094, 14093>,
    <14098, 14093, 14097>,
    <14098, 14097, 14100>,
    <14098, 14100, 13068>,
    <14098, 13068, 13153>,
    <14098, 13153, 13152>,
    <14098, 13152, 14099>,
    <14101, 14095, 14094>,
    <14101, 14094, 14099>,
    <14101, 14099, 13152>,
    <14101, 13152, 13157>,
    <14101, 13157, 13140>,
    <14101, 13140, 14089>,
    <14101, 14089, 14086>,
    <14101, 14086, 14095>,
    <14102, 14103, 14104>,
    <14102, 14104, 14105>,
    <14102, 14105, 14106>,
    <14102, 14106, 14107>,
    <14102, 14107, 13512>,
    <14102, 13512, 13523>,
    <14102, 13523, 13521>,
    <14102, 13521, 14103>,
    <14108, 14109, 14104>,
    <14108, 14104, 14103>,
    <14108, 14103, 13521>,
    <14108, 13521, 13520>,
    <14108, 13520, 13464>,
    <14108, 13464, 14110>,
    <14108, 14110, 14111>,
    <14108, 14111, 14109>,
    <14112, 14105, 14104>,
    <14112, 14104, 14109>,
    <14112, 14109, 14111>,
    <14112, 14111, 14113>,
    <14112, 14113, 14114>,
    <14112, 14114, 14115>,
    <14112, 14115, 14106>,
    <14112, 14106, 14105>,
    <14116, 14117, 14118>,
    <14116, 14118, 14119>,
    <14116, 14119, 14111>,
    <14116, 14111, 14110>,
    <14116, 14110, 13464>,
    <14116, 13464, 14011>,
    <14116, 14011, 14010>,
    <14116, 14010, 14117>,
    <14120, 14121, 14118>,
    <14120, 14118, 14117>,
    <14120, 14117, 14010>,
    <14120, 14010, 14019>,
    <14120, 14019, 14018>,
    <14120, 14018, 14122>,
    <14120, 14122, 14123>,
    <14120, 14123, 14121>,
    <14124, 14119, 14118>,
    <14124, 14118, 14121>,
    <14124, 14121, 14123>,
    <14124, 14123, 14125>,
    <14124, 14125, 14114>,
    <14124, 14114, 14113>,
    <14124, 14113, 14111>,
    <14124, 14111, 14119>,
    <14126, 14127, 14128>,
    <14126, 14128, 14129>,
    <14126, 14129, 14130>,
    <14126, 14130, 14131>,
    <14126, 14131, 14132>,
    <14126, 14132, 14133>,
    <14126, 14133, 14134>,
    <14126, 14134, 14127>,
    <14135, 14136, 14128>,
    <14135, 14128, 14127>,
    <14135, 14127, 14134>,
    <14135, 14134, 14137>,
    <14135, 14137, 14036>,
    <14135, 14036, 14049>,
    <14135, 14049, 14048>,
    <14135, 14048, 14136>,
    <14138, 14129, 14128>,
    <14138, 14128, 14136>,
    <14138, 14136, 14048>,
    <14138, 14048, 14053>,
    <14138, 14053, 13092>,
    <14138, 13092, 14139>,
    <14138, 14139, 14130>,
    <14138, 14130, 14129>,
    <14140, 14141, 14142>,
    <14140, 14142, 14143>,
    <14140, 14143, 14144>,
    <14140, 14144, 14145>,
    <14140, 14145, 14132>,
    <14140, 14132, 14131>,
    <14140, 14131, 14130>,
    <14140, 14130, 14141>,
    <14146, 14147, 14142>,
    <14146, 14142, 14141>,
    <14146, 14141, 14130>,
    <14146, 14130, 14139>,
    <14146, 14139, 13092>,
    <14146, 13092, 13108>,
    <14146, 13108, 13105>,
    <14146, 13105, 14147>,
    <14148, 14143, 14142>,
    <14148, 14142, 14147>,
    <14148, 14147, 13105>,
    <14148, 13105, 13104>,
    <14148, 13104, 13044>,
    <14148, 13044, 14149>,
    <14148, 14149, 14144>,
    <14148, 14144, 14143>,
    <14150, 14151, 14152>,
    <14150, 14152, 14153>,
    <14150, 14153, 13564>,
    <14150, 13564, 13563>,
    <14150, 13563, 13544>,
    <14150, 13544, 14154>,
    <14150, 14154, 14155>,
    <14150, 14155, 14151>,
    <14156, 14157, 14152>,
    <14156, 14152, 14151>,
    <14156, 14151, 14155>,
    <14156, 14155, 14158>,
    <14156, 14158, 14159>,
    <14156, 14159, 14160>,
    <14156, 14160, 14161>,
    <14156, 14161, 14157>,
    <14162, 14153, 14152>,
    <14162, 14152, 14157>,
    <14162, 14157, 14161>,
    <14162, 14161, 14163>,
    <14162, 14163, 13485>,
    <14162, 13485, 13566>,
    <14162, 13566, 13564>,
    <14162, 13564, 14153>,
    <14164, 14165, 14166>,
    <14164, 14166, 14167>,
    <14164, 14167, 14059>,
    <14164, 14059, 14058>,
    <14164, 14058, 13485>,
    <14164, 13485, 14163>,
    <14164, 14163, 14161>,
    <14164, 14161, 14165>,
    <14168, 14169, 14166>,
    <14168, 14166, 14165>,
    <14168, 14165, 14161>,
    <14168, 14161, 14160>,
    <14168, 14160, 14159>,
    <14168, 14159, 14170>,
    <14168, 14170, 14171>,
    <14168, 14171, 14169>,
    <14172, 14167, 14166>,
    <14172, 14166, 14169>,
    <14172, 14169, 14171>,
    <14172, 14171, 14173>,
    <14172, 14173, 14063>,
    <14172, 14063, 14062>,
    <14172, 14062, 14059>,
    <14172, 14059, 14167>,
    <14174, 14175, 14176>,
    <14174, 14176, 14177>,
    <14174, 14177, 14178>,
    <14174, 14178, 14179>,
    <14174, 14179, 14180>,
    <14174, 14180, 14181>,
    <14174, 14181, 14182>,
    <14174, 14182, 14175>,
    <14183, 14184, 14176>,
    <14183, 14176, 14175>,
    <14183, 14175, 14182>,
    <14183, 14182, 14185>,
    <14183, 14185, 13068>,
    <14183, 13068, 14100>,
    <14183, 14100, 14097>,
    <14183, 14097, 14184>,
    <14186, 14177, 14176>,
    <14186, 14176, 14184>,
    <14186, 14184, 14097>,
    <14186, 14097, 14096>,
    <14186, 14096, 14084>,
    <14186, 14084, 14187>,
    <14186, 14187, 14178>,
    <14186, 14178, 14177>,
    <14188, 14189, 14190>,
    <14188, 14190, 14191>,
    <14188, 14191, 14182>,
    <14188, 14182, 14181>,
    <14188, 14181, 14180>,
    <14188, 14180, 14192>,
    <14188, 14192, 14193>,
    <14188, 14193, 14189>,
    <14194, 14195, 14190>,
    <14194, 14190, 14189>,
    <14194, 14189, 14193>,
    <14194, 14193, 14196>,
    <14194, 14196, 13020>,
    <14194, 13020, 13081>,
    <14194, 13081, 13080>,
    <14194, 13080, 14195>,
    <14197, 14191, 14190>,
    <14197, 14190, 14195>,
    <14197, 14195, 13080>,
    <14197, 13080, 13085>,
    <14197, 13085, 13068>,
    <14197, 13068, 14185>,
    <14197, 14185, 14182>,
    <14197, 14182, 14191>,
    <14198, 14199, 14200>,
    <14198, 14200, 14201>,
    <14198, 14201, 14202>,
    <14198, 14202, 14203>,
    <14198, 14203, 13579>,
    <14198, 13579, 13590>,
    <14198, 13590, 13588>,
    <14198, 13588, 14199>,
    <14204, 14205, 14200>,
    <14204, 14200, 14199>,
    <14204, 14199, 13588>,
    <14204, 13588, 13587>,
    <14204, 13587, 13512>,
    <14204, 13512, 14206>,
    <14204, 14206, 14207>,
    <14204, 14207, 14205>,
    <14208, 14201, 14200>,
    <14208, 14200, 14205>,
    <14208, 14205, 14207>,
    <14208, 14207, 14209>,
    <14208, 14209, 14210>,
    <14208, 14210, 14211>,
    <14208, 14211, 14202>,
    <14208, 14202, 14201>,
    <14212, 14213, 14214>,
    <14212, 14214, 14215>,
    <14212, 14215, 14207>,
    <14212, 14207, 14206>,
    <14212, 14206, 13512>,
    <14212, 13512, 14107>,
    <14212, 14107, 14106>,
    <14212, 14106, 14213>,
    <14216, 14217, 14214>,
    <14216, 14214, 14213>,
    <14216, 14213, 14106>,
    <14216, 14106, 14115>,
    <14216, 14115, 14114>,
    <14216, 14114, 14218>,
    <14216, 14218, 14219>,
    <14216, 14219, 14217>,
    <14220, 14215, 14214>,
    <14220, 14214, 14217>,
    <14220, 14217, 14219>,
    <14220, 14219, 14221>,
    <14220, 14221, 14210>,
    <14220, 14210, 14209>,
    <14220, 14209, 14207>,
    <14220, 14207, 14215>,
    <14222, 14223, 14224>,
    <14222, 14224, 14225>,
    <14222, 14225, 14226>,
    <14222, 14226, 14227>,
    <14222, 14227, 14228>,
    <14222, 14228, 14229>,
    <14222, 14229, 14230>,
    <14222, 14230, 14223>,
    <14231, 14232, 14224>,
    <14231, 14224, 14223>,
    <14231, 14223, 14230>,
    <14231, 14230, 14233>,
    <14231, 14233, 14132>,
    <14231, 14132, 14145>,
    <14231, 14145, 14144>,
    <14231, 14144, 14232>,
    <14234, 14225, 14224>,
    <14234, 14224, 14232>,
    <14234, 14232, 14144>,
    <14234, 14144, 14149>,
    <14234, 14149, 13044>,
    <14234, 13044, 14235>,
    <14234, 14235, 14226>,
    <14234, 14226, 14225>,
    <14236, 14237, 14238>,
    <14236, 14238, 14239>,
    <14236, 14239, 14240>,
    <14236, 14240, 14241>,
    <14236, 14241, 14228>,
    <14236, 14228, 14227>,
    <14236, 14227, 14226>,
    <14236, 14226, 14237>,
    <14242, 14243, 14238>,
    <14242, 14238, 14237>,
    <14242, 14237, 14226>,
    <14242, 14226, 14235>,
    <14242, 14235, 13044>,
    <14242, 13044, 13060>,
    <14242, 13060, 13057>,
    <14242, 13057, 14243>,
    <14244, 14239, 14238>,
    <14244, 14238, 14243>,
    <14244, 14243, 13057>,
    <14244, 13057, 13056>,
    <14244, 13056, 12996>,
    <14244, 12996, 14245>,
    <14244, 14245, 14240>,
    <14244, 14240, 14239>,
    <14246, 14247, 14248>,
    <14246, 14248, 14249>,
    <14246, 14249, 13606>,
    <14246, 13606, 13605>,
    <14246, 13605, 14250>,
    <14246, 14250, 14251>,
    <14246, 14251, 14252>,
    <14246, 14252, 14247>,
    <14253, 14254, 14248>,
    <14253, 14248, 14247>,
    <14253, 14247, 14252>,
    <14253, 14252, 14255>,
    <14253, 14255, 14256>,
    <14253, 14256, 14257>,
    <14253, 14257, 14258>,
    <14253, 14258, 14254>,
    <14259, 14249, 14248>,
    <14259, 14248, 14254>,
    <14259, 14254, 14258>,
    <14259, 14258, 14260>,
    <14259, 14260, 13544>,
    <14259, 13544, 13608>,
    <14259, 13608, 13606>,
    <14259, 13606, 14249>,
    <14261, 14262, 14263>,
    <14261, 14263, 14264>,
    <14261, 14264, 14252>,
    <14261, 14252, 14251>,
    <14261, 14251, 14265>,
    <14261, 14265, 14266>,
    <14261, 14267, 14268>,
    <14261, 14268, 14262>,
    <14269, 14270, 14263>,
    <14269, 14263, 14262>,
    <14269, 14262, 14271>,
    <14269, 14271, 14272>,
    <14269, 14273, 14274>,
    <14269, 14274, 14275>,
    <14269, 14275, 14276>,
    <14269, 14276, 14270>,
    <14277, 14264, 14263>,
    <14277, 14263, 14270>,
    <14277, 14270, 14276>,
    <14277, 14276, 14278>,
    <14277, 14278, 14256>,
    <14277, 14256, 14255>,
    <14277, 14255, 14252>,
    <14277, 14252, 14264>,
    <14279, 14280, 14281>,
    <14279, 14281, 14282>,
    <14279, 14282, 14155>,
    <14279, 14155, 14154>,
    <14279, 14154, 13544>,
    <14279, 13544, 14260>,
    <14279, 14260, 14258>,
    <14279, 14258, 14280>,
    <14283, 14284, 14281>,
    <14283, 14281, 14280>,
    <14283, 14280, 14258>,
    <14283, 14258, 14257>,
    <14283, 14257, 14256>,
    <14283, 14256, 14285>,
    <14283, 14285, 14286>,
    <14283, 14286, 14284>,
    <14287, 14282, 14281>,
    <14287, 14281, 14284>,
    <14287, 14284, 14286>,
    <14287, 14286, 14288>,
    <14287, 14288, 14159>,
    <14287, 14159, 14158>,
    <14287, 14158, 14155>,
    <14287, 14155, 14282>,
    <14289, 14290, 14291>,
    <14289, 14291, 14292>,
    <14289, 14292, 14293>,
    <14289, 14293, 14294>,
    <14289, 14294, 14295>,
    <14289, 14295, 14296>,
    <14289, 14296, 14297>,
    <14289, 14297, 14290>,
    <14298, 14299, 14291>,
    <14298, 14291, 14290>,
    <14298, 14290, 14297>,
    <14298, 14297, 14300>,
    <14298, 14300, 13020>,
    <14298, 13020, 14196>,
    <14298, 14196, 14193>,
    <14298, 14193, 14299>,
    <14301, 14292, 14291>,
    <14301, 14291, 14299>,
    <14301, 14299, 14193>,
    <14301, 14193, 14192>,
    <14301, 14192, 14180>,
    <14301, 14180, 14302>,
    <14301, 14302, 14293>,
    <14301, 14293, 14292>,
    <14303, 14304, 14305>,
    <14303, 14305, 14306>,
    <14303, 14306, 14297>,
    <14303, 14297, 14296>,
    <14303, 14296, 14295>,
    <14303, 14295, 14307>,
    <14303, 14307, 14308>,
    <14303, 14308, 14304>,
    <14309, 14310, 14305>,
    <14309, 14305, 14304>,
    <14309, 14304, 14308>,
    <14309, 14308, 14311>,
    <14309, 14311, 12971>,
    <14309, 12971, 13033>,
    <14309, 13033, 13032>,
    <14309, 13032, 14310>,
    <14312, 14306, 14305>,
    <14312, 14305, 14310>,
    <14312, 14310, 13032>,
    <14312, 13032, 13037>,
    <14312, 13037, 13020>,
    <14312, 13020, 14300>,
    <14312, 14300, 14297>,
    <14312, 14297, 14306>,
    <14313, 14314, 14315>,
    <14313, 14315, 14316>,
    <14313, 14316, 14317>,
    <14313, 14317, 14318>,
    <14313, 14318, 13629>,
    <14313, 13629, 13651>,
    <14313, 13651, 13649>,
    <14313, 13649, 14314>,
    <14319, 14320, 14315>,
    <14319, 14315, 14314>,
    <14319, 14314, 13649>,
    <14319, 13649, 13648>,
    <14319, 13648, 13579>,
    <14319, 13579, 14321>,
    <14319, 14321, 14322>,
    <14319, 14322, 14320>,
    <14323, 14316, 14315>,
    <14323, 14315, 14320>,
    <14323, 14320, 14322>,
    <14323, 14322, 14324>,
    <14323, 14324, 14325>,
    <14323, 14325, 14326>,
    <14323, 14326, 14317>,
    <14323, 14317, 14316>,
    <14327, 14328, 14329>,
    <14327, 14329, 14330>,
    <14327, 14330, 14322>,
    <14327, 14322, 14321>,
    <14327, 14321, 13579>,
    <14327, 13579, 14203>,
    <14327, 14203, 14202>,
    <14327, 14202, 14328>,
    <14331, 14332, 14329>,
    <14331, 14329, 14328>,
    <14331, 14328, 14202>,
    <14331, 14202, 14211>,
    <14331, 14211, 14210>,
    <14331, 14210, 14333>,
    <14331, 14333, 14334>,
    <14331, 14334, 14332>,
    <14335, 14330, 14329>,
    <14335, 14329, 14332>,
    <14335, 14332, 14334>,
    <14335, 14334, 14336>,
    <14335, 14336, 14325>,
    <14335, 14325, 14324>,
    <14335, 14324, 14322>,
    <14335, 14322, 14330>,
    <14337, 14338, 14339>,
    <14337, 14339, 14340>,
    <14337, 14340, 14341>,
    <14337, 14341, 14342>,
    <14337, 14342, 14343>,
    <14337, 14343, 14344>,
    <14337, 14344, 14345>,
    <14337, 14345, 14338>,
    <14346, 14347, 14339>,
    <14346, 14339, 14338>,
    <14346, 14338, 14345>,
    <14346, 14345, 14348>,
    <14346, 14348, 14228>,
    <14346, 14228, 14241>,
    <14346, 14241, 14240>,
    <14346, 14240, 14347>,
    <14349, 14340, 14339>,
    <14349, 14339, 14347>,
    <14349, 14347, 14240>,
    <14349, 14240, 14245>,
    <14349, 14245, 12996>,
    <14349, 12996, 14350>,
    <14349, 14350, 14341>,
    <14349, 14341, 14340>,
    <14351, 14352, 14353>,
    <14351, 14353, 14354>,
    <14351, 14354, 14355>,
    <14351, 14355, 14356>,
    <14351, 14356, 14343>,
    <14351, 14343, 14342>,
    <14351, 14342, 14341>,
    <14351, 14341, 14352>,
    <14357, 14358, 14353>,
    <14357, 14353, 14352>,
    <14357, 14352, 14341>,
    <14357, 14341, 14350>,
    <14357, 14350, 12996>,
    <14357, 12996, 13012>,
    <14357, 13012, 13009>,
    <14357, 13009, 14358>,
    <14359, 14354, 14353>,
    <14359, 14353, 14358>,
    <14359, 14358, 13009>,
    <14359, 13009, 13008>,
    <14359, 13008, 12947>,
    <14359, 12947, 14360>,
    <14359, 14360, 14355>,
    <14359, 14355, 14354>,
    <14361, 14362, 14363>,
    <14361, 14363, 14364>,
    <14361, 14364, 14276>,
    <14361, 14276, 14275>,
    <14361, 14275, 14365>,
    <14361, 14365, 14366>,
    <14361, 14367, 14368>,
    <14361, 14368, 14362>,
    <14369, 14370, 14363>,
    <14369, 14363, 14362>,
    <14369, 14362, 14371>,
    <14369, 14371, 14372>,
    <14369, 14373, 14374>,
    <14369, 14374, 14375>,
    <14369, 14375, 14376>,
    <14369, 14376, 14370>,
    <14377, 14364, 14363>,
    <14377, 14363, 14370>,
    <14377, 14370, 14376>,
    <14377, 14376, 14378>,
    <14377, 14378, 14256>,
    <14377, 14256, 14278>,
    <14377, 14278, 14276>,
    <14377, 14276, 14364>,
    <14379, 14380, 14381>,
    <14379, 14381, 14382>,
    <14379, 14382, 14383>,
    <14379, 14383, 14384>,
    <14379, 14384, 14385>,
    <14379, 14385, 14386>,
    <14379, 14386, 14387>,
    <14379, 14387, 14380>,
    <14388, 14389, 14381>,
    <14388, 14381, 14380>,
    <14388, 14380, 14387>,
    <14388, 14387, 14390>,
    <14388, 14390, 12971>,
    <14388, 12971, 14311>,
    <14388, 14311, 14308>,
    <14388, 14308, 14389>,
    <14391, 14382, 14381>,
    <14391, 14381, 14389>,
    <14391, 14389, 14308>,
    <14391, 14308, 14307>,
    <14391, 14307, 14295>,
    <14391, 14295, 14392>,
    <14391, 14392, 14383>,
    <14391, 14383, 14382>,
    <14393, 14394, 14395>,
    <14393, 14395, 14396>,
    <14393, 14396, 14387>,
    <14393, 14387, 14386>,
    <14393, 14386, 14397>,
    <14393, 14397, 14398>,
    <14393, 14399, 14400>,
    <14393, 14400, 14394>,
    <14401, 14402, 14395>,
    <14401, 14395, 14394>,
    <14401, 14394, 14403>,
    <14401, 14403, 14404>,
    <14401, 14405, 14406>,
    <14401, 14406, 13711>,
    <14401, 13711, 13710>,
    <14401, 13710, 14402>,
    <14407, 14396, 14395>,
    <14407, 14395, 14402>,
    <14407, 14402, 13710>,
    <14407, 13710, 13723>,
    <14407, 13723, 12971>,
    <14407, 12971, 14390>,
    <14407, 14390, 14387>,
    <14407, 14387, 14396>,
    <14408, 14409, 14410>,
    <14408, 14410, 14411>,
    <14408, 14411, 14412>,
    <14408, 14412, 14413>,
    <14408, 14413, 14414>,
    <14408, 14414, 14415>,
    <14408, 14416, 14417>,
    <14408, 14417, 14409>,
    <14418, 14419, 14410>,
    <14418, 14410, 14409>,
    <14418, 14409, 14420>,
    <14418, 14420, 14421>,
    <14418, 14422, 14423>,
    <14418, 14423, 14424>,
    <14418, 14424, 14425>,
    <14418, 14425, 14419>,
    <14426, 14411, 14410>,
    <14426, 14410, 14419>,
    <14426, 14419, 14425>,
    <14426, 14425, 14427>,
    <14426, 14427, 14428>,
    <14426, 14428, 14429>,
    <14426, 14429, 14412>,
    <14426, 14412, 14411>,
    <14430, 14431, 14432>,
    <14430, 14432, 14433>,
    <14430, 14433, 14425>,
    <14430, 14425, 14424>,
    <14430, 14424, 14434>,
    <14430, 14434, 13675>,
    <14430, 13675, 13674>,
    <14430, 13674, 14431>,
    <14435, 14436, 14432>,
    <14435, 14432, 14431>,
    <14435, 14431, 13674>,
    <14435, 13674, 13687>,
    <14435, 13687, 13629>,
    <14435, 13629, 14437>,
    <14435, 14437, 14438>,
    <14435, 14438, 14436>,
    <14439, 14433, 14432>,
    <14439, 14432, 14436>,
    <14439, 14436, 14438>,
    <14439, 14438, 14440>,
    <14439, 14440, 14428>,
    <14439, 14428, 14427>,
    <14439, 14427, 14425>,
    <14439, 14425, 14433>,
    <14441, 14442, 14443>,
    <14441, 14443, 14444>,
    <14441, 14444, 14438>,
    <14441, 14438, 14437>,
    <14441, 14437, 13629>,
    <14441, 13629, 14318>,
    <14441, 14318, 14317>,
    <14441, 14317, 14442>,
    <14445, 14446, 14443>,
    <14445, 14443, 14442>,
    <14445, 14442, 14317>,
    <14445, 14317, 14326>,
    <14445, 14326, 14325>,
    <14445, 14325, 14447>,
    <14445, 14447, 14448>,
    <14445, 14448, 14446>,
    <14449, 14444, 14443>,
    <14449, 14443, 14446>,
    <14449, 14446, 14448>,
    <14449, 14448, 14450>,
    <14449, 14450, 14428>,
    <14449, 14428, 14440>,
    <14449, 14440, 14438>,
    <14449, 14438, 14444>,
    <14451, 14452, 14453>,
    <14451, 14453, 14454>,
    <14451, 14454, 14455>,
    <14451, 14455, 14456>,
    <14451, 14456, 14457>,
    <14451, 14457, 14458>,
    <14451, 14458, 14459>,
    <14451, 14459, 14452>,
    <14460, 14461, 14453>,
    <14460, 14453, 14452>,
    <14460, 14452, 14459>,
    <14460, 14459, 14462>,
    <14460, 14462, 14343>,
    <14460, 14343, 14356>,
    <14460, 14356, 14355>,
    <14460, 14355, 14461>,
    <14463, 14454, 14453>,
    <14463, 14453, 14461>,
    <14463, 14461, 14355>,
    <14463, 14355, 14360>,
    <14463, 14360, 12947>,
    <14463, 12947, 14464>,
    <14463, 14464, 14455>,
    <14463, 14455, 14454>,
    <14465, 14466, 14467>,
    <14465, 14467, 14468>,
    <14465, 14468, 14469>,
    <14465, 14469, 14470>,
    <14465, 14470, 14457>,
    <14465, 14457, 14456>,
    <14465, 14456, 14455>,
    <14465, 14455, 14466>,
    <14471, 14472, 14467>,
    <14471, 14467, 14466>,
    <14471, 14466, 14455>,
    <14471, 14455, 14464>,
    <14471, 14464, 12947>,
    <14471, 12947, 12963>,
    <14471, 12963, 12960>,
    <14471, 12960, 14472>,
    <14473, 14468, 14467>,
    <14473, 14467, 14472>,
    <14473, 14472, 12960>,
    <14473, 12960, 12959>,
    <14473, 12959, 12886>,
    <14473, 12886, 14474>,
    <14473, 14474, 14469>,
    <14473, 14469, 14468>,
    <14475, 14476, 14477>,
    <14475, 14477, 14478>,
    <14475, 14478, 13697>,
    <14475, 13697, 13696>,
    <14475, 13696, 14479>,
    <14475, 14479, 14480>,
    <14475, 14480, 14481>,
    <14475, 14481, 14476>,
    <14482, 14483, 14477>,
    <14482, 14477, 14476>,
    <14482, 14476, 14481>,
    <14482, 14481, 14484>,
    <14482, 14484, 14457>,
    <14482, 14457, 14470>,
    <14482, 14470, 14469>,
    <14482, 14469, 14483>,
    <14485, 14478, 14477>,
    <14485, 14477, 14483>,
    <14485, 14483, 14469>,
    <14485, 14469, 14474>,
    <14485, 14474, 12886>,
    <14485, 12886, 13700>,
    <14485, 13700, 13697>,
    <14485, 13697, 14478>,
    <14486, 14487, 14488>,
    <14486, 14488, 14489>,
    <14486, 14489, 14481>,
    <14486, 14481, 14480>,
    <14486, 14480, 14490>,
    <14486, 14490, 14491>,
    <14486, 14492, 14493>,
    <14486, 14493, 14487>,
    <14494, 14495, 14488>,
    <14494, 14488, 14487>,
    <14494, 14487, 14496>,
    <14494, 14496, 14497>,
    <14494, 14498, 14499>,
    <14494, 14499, 14500>,
    <14494, 14500, 14501>,
    <14494, 14501, 14495>,
    <14502, 14489, 14488>,
    <14502, 14488, 14495>,
    <14502, 14495, 14501>,
    <14502, 14501, 14503>,
    <14502, 14503, 14457>,
    <14502, 14457, 14484>,
    <14502, 14484, 14481>,
    <14502, 14481, 14489>,
    <14504, 14505, 14506>,
    <14504, 14506, 14507>,
    <14504, 14507, 14508>,
    <14504, 14508, 14509>,
    <14504, 14510, 14511>,
    <14504, 14511, 14413>,
    <14504, 14413, 14412>,
    <14504, 14412, 14505>,
    <14512, 14513, 14506>,
    <14512, 14506, 14505>,
    <14512, 14505, 14412>,
    <14512, 14412, 14429>,
    <14512, 14429, 14428>,
    <14512, 14428, 14514>,
    <14512, 14514, 14515>,
    <14512, 14515, 14513>,
    <14516, 14507, 14506>,
    <14516, 14506, 14513>,
    <14516, 14513, 14515>,
    <14516, 14515, 14517>,
    <14516, 14517, 14518>,
    <14516, 14518, 14519>,
    <14516, 14520, 14521>,
    <14516, 14521, 14507>,
    <14522, 14523, 14524>,
    <14522, 14524, 14525>,
    <14522, 14525, 14501>,
    <14522, 14501, 14500>,
    <14522, 14500, 14526>,
    <14522, 14526, 14527>,
    <14522, 14528, 14529>,
    <14522, 14529, 14523>,
    <14530, 14531, 14524>,
    <14530, 14524, 14523>,
    <14530, 14523, 14532>,
    <14530, 14532, 14533>,
    <14530, 14534, 14535>,
    <14530, 14535, 14536>,
    <14530, 14536, 14537>,
    <14530, 14537, 14531>,
    <14538, 14525, 14524>,
    <14538, 14524, 14531>,
    <14538, 14531, 14537>,
    <14538, 14537, 14539>,
    <14538, 14539, 14457>,
    <14538, 14457, 14503>,
    <14538, 14503, 14501>,
    <14538, 14501, 14525>,
    <14540, 14541, 14542>,
    <14540, 14542, 14543>,
    <14540, 14543, 14544>,
    <14540, 14544, 14545>,
    <14540, 14545, 14546>,
    <14540, 14546, 14547>,
    <14540, 14548, 14549>,
    <14540, 14549, 14541>,
    <14550, 14551, 14542>,
    <14550, 14542, 14541>,
    <14550, 14541, 14552>,
    <14550, 14552, 14553>,
    <14550, 14554, 14555>,
    <14550, 14555, 14517>,
    <14550, 14517, 14515>,
    <14550, 14515, 14551>,
    <14556, 14543, 14542>,
    <14556, 14542, 14551>,
    <14556, 14551, 14515>,
    <14556, 14515, 14514>,
    <14556, 14514, 14428>,
    <14556, 14428, 14557>,
    <14556, 14557, 14544>,
    <14556, 14544, 14543>,
    <14558, 14559, 14560>,
    <14558, 14560, 14561>,
    <14558, 14561, 14562>,
    <14558, 14562, 14563>,
    <14558, 14564, 14565>,
    <14558, 14565, 14566>,
    <14558, 14566, 14567>,
    <14558, 14567, 14559>,
    <14568, 14569, 14560>,
    <14568, 14560, 14559>,
    <14568, 14559, 14567>,
    <14568, 14567, 14570>,
    <14568, 14570, 14457>,
    <14568, 14457, 14539>,
    <14568, 14539, 14537>,
    <14568, 14537, 14569>,
    <14571, 14561, 14560>,
    <14571, 14560, 14569>,
    <14571, 14569, 14537>,
    <14571, 14537, 14536>,
    <14571, 14536, 14572>,
    <14571, 14572, 14573>,
    <14571, 14574, 14575>,
    <14571, 14575, 14561>,
    <14576, 14577, 14578>,
    <14576, 14578, 14579>,
    <14576, 14579, 14580>,
    <14576, 14580, 14581>,
    <14576, 14581, 14582>,
    <14576, 14582, 14583>,
    <14576, 14584, 14585>,
    <14576, 14585, 14577>,
    <14586, 14587, 14578>,
    <14586, 14578, 14577>,
    <14586, 14577, 14588>,
    <14586, 14588, 14589>,
    <14586, 14590, 14591>,
    <14586, 14591, 14384>,
    <14586, 14384, 14383>,
    <14586, 14383, 14587>,
    <14592, 14579, 14578>,
    <14592, 14578, 14587>,
    <14592, 14587, 14383>,
    <14592, 14383, 14392>,
    <14592, 14392, 14295>,
    <14592, 14295, 14593>,
    <14592, 14593, 14580>,
    <14592, 14580, 14579>,
    <14594, 14595, 14596>,
    <14594, 14596, 14597>,
    <14594, 14597, 13763>,
    <14594, 13763, 13762>,
    <14594, 13762, 13751>,
    <14594, 13751, 14598>,
    <14594, 14598, 14599>,
    <14594, 14599, 14595>,
    <14600, 14601, 14596>,
    <14600, 14596, 14595>,
    <14600, 14595, 14599>,
    <14600, 14599, 14602>,
    <14600, 14602, 14603>,
    <14600, 14603, 14604>,
    <14600, 14605, 14606>,
    <14600, 14606, 14601>,
    <14607, 14597, 14596>,
    <14607, 14596, 14601>,
    <14607, 14601, 14608>,
    <14607, 14608, 14609>,
    <14607, 14610, 14611>,
    <14607, 14611, 13765>,
    <14607, 13765, 13763>,
    <14607, 13763, 14597>,
    <14612, 14613, 14614>,
    <14612, 14614, 14615>,
    <14612, 14615, 13813>,
    <14612, 13813, 13812>,
    <14612, 13812, 13801>,
    <14612, 13801, 14616>,
    <14612, 14616, 14617>,
    <14612, 14617, 14613>,
    <14618, 14619, 14614>,
    <14618, 14614, 14613>,
    <14618, 14613, 14617>,
    <14618, 14617, 14620>,
    <14618, 14620, 14621>,
    <14618, 14621, 14622>,
    <14618, 14622, 14623>,
    <14618, 14623, 14619>,
    <14624, 14615, 14614>,
    <14624, 14614, 14619>,
    <14624, 14619, 14623>,
    <14624, 14623, 14625>,
    <14624, 14625, 13751>,
    <14624, 13751, 13815>,
    <14624, 13815, 13813>,
    <14624, 13813, 14615>,
    <14626, 14627, 14628>,
    <14626, 14628, 14629>,
    <14626, 14629, 14599>,
    <14626, 14599, 14598>,
    <14626, 14598, 13751>,
    <14626, 13751, 14625>,
    <14626, 14625, 14623>,
    <14626, 14623, 14627>,
    <14630, 14631, 14628>,
    <14630, 14628, 14627>,
    <14630, 14627, 14623>,
    <14630, 14623, 14622>,
    <14630, 14622, 14621>,
    <14630, 14621, 14632>,
    <14630, 14632, 14633>,
    <14630, 14633, 14631>,
    <14634, 14629, 14628>,
    <14634, 14628, 14631>,
    <14634, 14631, 14633>,
    <14634, 14633, 14635>,
    <14634, 14635, 14636>,
    <14634, 14636, 14602>,
    <14634, 14602, 14599>,
    <14634, 14599, 14629>,
    <14637, 14638, 14639>,
    <14637, 14639, 14640>,
    <14637, 14640, 14641>,
    <14637, 14641, 14642>,
    <14637, 14642, 14643>,
    <14637, 14643, 14644>,
    <14637, 14644, 14645>,
    <14637, 14645, 14638>,
    <14646, 14647, 14639>,
    <14646, 14639, 14638>,
    <14646, 14638, 14645>,
    <14646, 14645, 14648>,
    <14646, 14648, 14649>,
    <14646, 14649, 14650>,
    <14646, 14651, 14652>,
    <14646, 14652, 14647>,
    <14653, 14640, 14639>,
    <14653, 14639, 14647>,
    <14653, 14647, 14654>,
    <14653, 14654, 14655>,
    <14653, 14656, 14657>,
    <14653, 14657, 14658>,
    <14653, 14658, 14641>,
    <14653, 14641, 14640>,
    <14659, 14660, 14661>,
    <14659, 14661, 14662>,
    <14659, 14662, 14645>,
    <14659, 14645, 14644>,
    <14659, 14644, 14643>,
    <14659, 14643, 14663>,
    <14659, 14663, 14664>,
    <14659, 14664, 14660>,
    <14665, 14666, 14661>,
    <14665, 14661, 14660>,
    <14665, 14660, 14664>,
    <14665, 14664, 14667>,
    <14665, 14667, 13773>,
    <14665, 13773, 13772>,
    <14665, 13772, 13771>,
    <14665, 13771, 14666>,
    <14668, 14662, 14661>,
    <14668, 14661, 14666>,
    <14668, 14666, 13771>,
    <14668, 13771, 13781>,
    <14668, 13781, 14669>,
    <14668, 14669, 14648>,
    <14668, 14648, 14645>,
    <14668, 14645, 14662>,
    <14670, 14671, 14672>,
    <14670, 14672, 14673>,
    <14670, 14673, 13931>,
    <14670, 13931, 13930>,
    <14670, 13930, 13919>,
    <14670, 13919, 14674>,
    <14670, 14674, 14675>,
    <14670, 14675, 14671>,
    <14676, 14677, 14672>,
    <14676, 14672, 14671>,
    <14676, 14671, 14675>,
    <14676, 14675, 14678>,
    <14676, 14678, 14679>,
    <14676, 14679, 14680>,
    <14676, 14680, 14681>,
    <14676, 14681, 14677>,
    <14682, 14673, 14672>,
    <14682, 14672, 14677>,
    <14682, 14677, 14681>,
    <14682, 14681, 14683>,
    <14682, 14683, 13801>,
    <14682, 13801, 13933>,
    <14682, 13933, 13931>,
    <14682, 13931, 14673>,
    <14684, 14685, 14686>,
    <14684, 14686, 14687>,
    <14684, 14687, 14617>,
    <14684, 14617, 14616>,
    <14684, 14616, 13801>,
    <14684, 13801, 14683>,
    <14684, 14683, 14681>,
    <14684, 14681, 14685>,
    <14688, 14689, 14686>,
    <14688, 14686, 14685>,
    <14688, 14685, 14681>,
    <14688, 14681, 14680>,
    <14688, 14680, 14679>,
    <14688, 14679, 14690>,
    <14688, 14690, 14691>,
    <14688, 14691, 14689>,
    <14692, 14687, 14686>,
    <14692, 14686, 14689>,
    <14692, 14689, 14691>,
    <14692, 14691, 14693>,
    <14692, 14693, 14621>,
    <14692, 14621, 14620>,
    <14692, 14620, 14617>,
    <14692, 14617, 14687>,
    <14694, 14695, 14696>,
    <14694, 14696, 14697>,
    <14694, 14697, 14698>,
    <14694, 14698, 14699>,
    <14694, 14699, 14700>,
    <14694, 14700, 14701>,
    <14694, 14701, 14702>,
    <14694, 14702, 14695>,
    <14703, 14704, 14696>,
    <14703, 14696, 14695>,
    <14703, 14695, 14702>,
    <14703, 14702, 14705>,
    <14703, 14705, 13773>,
    <14703, 13773, 14667>,
    <14703, 14667, 14664>,
    <14703, 14664, 14704>,
    <14706, 14697, 14696>,
    <14706, 14696, 14704>,
    <14706, 14704, 14664>,
    <14706, 14664, 14663>,
    <14706, 14663, 14643>,
    <14706, 14643, 14707>,
    <14706, 14707, 14698>,
    <14706, 14698, 14697>,
    <14708, 14709, 14710>,
    <14708, 14710, 14711>,
    <14708, 14711, 14702>,
    <14708, 14702, 14701>,
    <14708, 14701, 14700>,
    <14708, 14700, 14712>,
    <14708, 14712, 14713>,
    <14708, 14713, 14709>,
    <14714, 14715, 14710>,
    <14714, 14710, 14709>,
    <14714, 14709, 14713>,
    <14714, 14713, 14716>,
    <14714, 14716, 13822>,
    <14714, 13822, 13821>,
    <14714, 13821, 13820>,
    <14714, 13820, 14715>,
    <14717, 14711, 14710>,
    <14717, 14710, 14715>,
    <14717, 14715, 13820>,
    <14717, 13820, 13829>,
    <14717, 13829, 13773>,
    <14717, 13773, 14705>,
    <14717, 14705, 14702>,
    <14717, 14702, 14711>,
    <14718, 14719, 14720>,
    <14718, 14720, 14721>,
    <14718, 14721, 14722>,
    <14718, 14722, 14723>,
    <14718, 14723, 13870>,
    <14718, 13870, 13882>,
    <14718, 13882, 13880>,
    <14718, 13880, 14719>,
    <14724, 14725, 14720>,
    <14724, 14720, 14719>,
    <14724, 14719, 13880>,
    <14724, 13880, 13879>,
    <14724, 13879, 14726>,
    <14724, 14726, 14727>,
    <14724, 14728, 14729>,
    <14724, 14729, 14725>,
    <14730, 14721, 14720>,
    <14730, 14720, 14725>,
    <14730, 14725, 14731>,
    <14730, 14731, 14732>,
    <14730, 14733, 14734>,
    <14730, 14734, 14735>,
    <14730, 14735, 14722>,
    <14730, 14722, 14721>,
    <14736, 14737, 14738>,
    <14736, 14738, 14739>,
    <14736, 14739, 14740>,
    <14736, 14740, 14741>,
    <14736, 14741, 13970>,
    <14736, 13970, 13981>,
    <14736, 13981, 13979>,
    <14736, 13979, 14737>,
    <14742, 14743, 14738>,
    <14742, 14738, 14737>,
    <14742, 14737, 13979>,
    <14742, 13979, 13978>,
    <14742, 13978, 13870>,
    <14742, 13870, 14744>,
    <14742, 14744, 14745>,
    <14742, 14745, 14743>,
    <14746, 14739, 14738>,
    <14746, 14738, 14743>,
    <14746, 14743, 14745>,
    <14746, 14745, 14747>,
    <14746, 14747, 14748>,
    <14746, 14748, 14749>,
    <14746, 14749, 14740>,
    <14746, 14740, 14739>,
    <14750, 14751, 14752>,
    <14750, 14752, 14753>,
    <14750, 14753, 14745>,
    <14750, 14745, 14744>,
    <14750, 14744, 13870>,
    <14750, 13870, 14723>,
    <14750, 14723, 14722>,
    <14750, 14722, 14751>,
    <14754, 14755, 14752>,
    <14754, 14752, 14751>,
    <14754, 14751, 14722>,
    <14754, 14722, 14735>,
    <14754, 14735, 14756>,
    <14754, 14756, 14757>,
    <14754, 14757, 14758>,
    <14754, 14758, 14755>,
    <14759, 14753, 14752>,
    <14759, 14752, 14755>,
    <14759, 14755, 14758>,
    <14759, 14758, 14760>,
    <14759, 14760, 14748>,
    <14759, 14748, 14747>,
    <14759, 14747, 14745>,
    <14759, 14745, 14753>,
    <14761, 14762, 14763>,
    <14761, 14763, 14764>,
    <14761, 14764, 14765>,
    <14761, 14765, 14766>,
    <14761, 14766, 14767>,
    <14761, 14767, 14768>,
    <14761, 14768, 14769>,
    <14761, 14769, 14762>,
    <14770, 14771, 14763>,
    <14770, 14763, 14762>,
    <14770, 14762, 14769>,
    <14770, 14769, 14772>,
    <14770, 14772, 14773>,
    <14770, 14773, 14774>,
    <14770, 14775, 14776>,
    <14770, 14776, 14771>,
    <14777, 14764, 14763>,
    <14777, 14763, 14771>,
    <14777, 14771, 14778>,
    <14777, 14778, 14779>,
    <14777, 14780, 14781>,
    <14777, 14781, 14782>,
    <14777, 14782, 14765>,
    <14777, 14765, 14764>,
    <14783, 14784, 14785>,
    <14783, 14785, 14786>,
    <14783, 14786, 14787>,
    <14783, 14787, 14788>,
    <14783, 14788, 14767>,
    <14783, 14767, 14766>,
    <14783, 14766, 14765>,
    <14783, 14765, 14784>,
    <14789, 14790, 14785>,
    <14789, 14785, 14784>,
    <14789, 14784, 14765>,
    <14789, 14765, 14782>,
    <14789, 14782, 14791>,
    <14789, 14791, 13894>,
    <14789, 13894, 13891>,
    <14789, 13891, 14790>,
    <14792, 14786, 14785>,
    <14792, 14785, 14790>,
    <14792, 14790, 13891>,
    <14792, 13891, 13890>,
    <14792, 13890, 13889>,
    <14792, 13889, 14793>,
    <14792, 14793, 14787>,
    <14792, 14787, 14786>,
    <14794, 14795, 14796>,
    <14794, 14796, 14797>,
    <14794, 14797, 14075>,
    <14794, 14075, 14074>,
    <14794, 14074, 14063>,
    <14794, 14063, 14798>,
    <14794, 14798, 14799>,
    <14794, 14799, 14795>,
    <14800, 14801, 14796>,
    <14800, 14796, 14795>,
    <14800, 14795, 14799>,
    <14800, 14799, 14802>,
    <14800, 14802, 14803>,
    <14800, 14803, 14804>,
    <14800, 14804, 14805>,
    <14800, 14805, 14801>,
    <14806, 14797, 14796>,
    <14806, 14796, 14801>,
    <14806, 14801, 14805>,
    <14806, 14805, 14807>,
    <14806, 14807, 13919>,
    <14806, 13919, 14077>,
    <14806, 14077, 14075>,
    <14806, 14075, 14797>,
    <14808, 14809, 14810>,
    <14808, 14810, 14811>,
    <14808, 14811, 14675>,
    <14808, 14675, 14674>,
    <14808, 14674, 13919>,
    <14808, 13919, 14807>,
    <14808, 14807, 14805>,
    <14808, 14805, 14809>,
    <14812, 14813, 14810>,
    <14812, 14810, 14809>,
    <14812, 14809, 14805>,
    <14812, 14805, 14804>,
    <14812, 14804, 14803>,
    <14812, 14803, 14814>,
    <14812, 14814, 14815>,
    <14812, 14815, 14813>,
    <14816, 14811, 14810>,
    <14816, 14810, 14813>,
    <14816, 14813, 14815>,
    <14816, 14815, 14817>,
    <14816, 14817, 14679>,
    <14816, 14679, 14678>,
    <14816, 14678, 14675>,
    <14816, 14675, 14811>,
    <14818, 14819, 14820>,
    <14818, 14820, 14821>,
    <14818, 14821, 14822>,
    <14818, 14822, 14823>,
    <14818, 14823, 14824>,
    <14818, 14824, 14825>,
    <14818, 14825, 14826>,
    <14818, 14826, 14819>,
    <14827, 14828, 14820>,
    <14827, 14820, 14819>,
    <14827, 14819, 14826>,
    <14827, 14826, 14829>,
    <14827, 14829, 13822>,
    <14827, 13822, 14716>,
    <14827, 14716, 14713>,
    <14827, 14713, 14828>,
    <14830, 14821, 14820>,
    <14830, 14820, 14828>,
    <14830, 14828, 14713>,
    <14830, 14713, 14712>,
    <14830, 14712, 14700>,
    <14830, 14700, 14831>,
    <14830, 14831, 14822>,
    <14830, 14822, 14821>,
    <14832, 14833, 14834>,
    <14832, 14834, 14835>,
    <14832, 14835, 14826>,
    <14832, 14826, 14825>,
    <14832, 14825, 14824>,
    <14832, 14824, 14836>,
    <14832, 14836, 14837>,
    <14832, 14837, 14833>,
    <14838, 14839, 14834>,
    <14838, 14834, 14833>,
    <14838, 14833, 14837>,
    <14838, 14837, 14840>,
    <14838, 14840, 13940>,
    <14838, 13940, 13939>,
    <14838, 13939, 13938>,
    <14838, 13938, 14839>,
    <14841, 14835, 14834>,
    <14841, 14834, 14839>,
    <14841, 14839, 13938>,
    <14841, 13938, 13947>,
    <14841, 13947, 13822>,
    <14841, 13822, 14829>,
    <14841, 14829, 14826>,
    <14841, 14826, 14835>,
    <14842, 14843, 14844>,
    <14842, 14844, 14845>,
    <14842, 14845, 14846>,
    <14842, 14846, 14847>,
    <14842, 14847, 14018>,
    <14842, 14018, 14029>,
    <14842, 14029, 14027>,
    <14842, 14027, 14843>,
    <14848, 14849, 14844>,
    <14848, 14844, 14843>,
    <14848, 14843, 14027>,
    <14848, 14027, 14026>,
    <14848, 14026, 13970>,
    <14848, 13970, 14850>,
    <14848, 14850, 14851>,
    <14848, 14851, 14849>,
    <14852, 14845, 14844>,
    <14852, 14844, 14849>,
    <14852, 14849, 14851>,
    <14852, 14851, 14853>,
    <14852, 14853, 14854>,
    <14852, 14854, 14855>,
    <14852, 14855, 14846>,
    <14852, 14846, 14845>,
    <14856, 14857, 14858>,
    <14856, 14858, 14859>,
    <14856, 14859, 14851>,
    <14856, 14851, 14850>,
    <14856, 14850, 13970>,
    <14856, 13970, 14741>,
    <14856, 14741, 14740>,
    <14856, 14740, 14857>,
    <14860, 14861, 14858>,
    <14860, 14858, 14857>,
    <14860, 14857, 14740>,
    <14860, 14740, 14749>,
    <14860, 14749, 14748>,
    <14860, 14748, 14862>,
    <14860, 14862, 14863>,
    <14860, 14863, 14861>,
    <14864, 14859, 14858>,
    <14864, 14858, 14861>,
    <14864, 14861, 14863>,
    <14864, 14863, 14865>,
    <14864, 14865, 14854>,
    <14864, 14854, 14853>,
    <14864, 14853, 14851>,
    <14864, 14851, 14859>,
    <14866, 14867, 14868>,
    <14866, 14868, 14869>,
    <14866, 14869, 14870>,
    <14866, 14870, 14871>,
    <14866, 14871, 14872>,
    <14866, 14872, 14873>,
    <14866, 14873, 14874>,
    <14866, 14874, 14867>,
    <14875, 14876, 14868>,
    <14875, 14868, 14867>,
    <14875, 14867, 14874>,
    <14875, 14874, 14877>,
    <14875, 14877, 14767>,
    <14875, 14767, 14788>,
    <14875, 14788, 14787>,
    <14875, 14787, 14876>,
    <14878, 14869, 14868>,
    <14878, 14868, 14876>,
    <14878, 14876, 14787>,
    <14878, 14787, 14793>,
    <14878, 14793, 13889>,
    <14878, 13889, 14879>,
    <14878, 14879, 14870>,
    <14878, 14870, 14869>,
    <14880, 14881, 14882>,
    <14880, 14882, 14883>,
    <14880, 14883, 14884>,
    <14880, 14884, 14885>,
    <14880, 14885, 14872>,
    <14880, 14872, 14871>,
    <14880, 14871, 14870>,
    <14880, 14870, 14881>,
    <14886, 14887, 14882>,
    <14886, 14882, 14881>,
    <14886, 14881, 14870>,
    <14886, 14870, 14879>,
    <14886, 14879, 13889>,
    <14886, 13889, 13993>,
    <14886, 13993, 13990>,
    <14886, 13990, 14887>,
    <14888, 14883, 14882>,
    <14888, 14882, 14887>,
    <14888, 14887, 13990>,
    <14888, 13990, 13989>,
    <14888, 13989, 13988>,
    <14888, 13988, 14889>,
    <14888, 14889, 14884>,
    <14888, 14884, 14883>,
    <14890, 14891, 14892>,
    <14890, 14892, 14893>,
    <14890, 14893, 14894>,
    <14890, 14894, 14895>,
    <14890, 14895, 14114>,
    <14890, 14114, 14125>,
    <14890, 14125, 14123>,
    <14890, 14123, 14891>,
    <14896, 14897, 14892>,
    <14896, 14892, 14891>,
    <14896, 14891, 14123>,
    <14896, 14123, 14122>,
    <14896, 14122, 14018>,
    <14896, 14018, 14898>,
    <14896, 14898, 14899>,
    <14896, 14899, 14897>,
    <14900, 14893, 14892>,
    <14900, 14892, 14897>,
    <14900, 14897, 14899>,
    <14900, 14899, 14901>,
    <14900, 14901, 14902>,
    <14900, 14902, 14903>,
    <14900, 14903, 14894>,
    <14900, 14894, 14893>,
    <14904, 14905, 14906>,
    <14904, 14906, 14907>,
    <14904, 14907, 14899>,
    <14904, 14899, 14898>,
    <14904, 14898, 14018>,
    <14904, 14018, 14847>,
    <14904, 14847, 14846>,
    <14904, 14846, 14905>,
    <14908, 14909, 14906>,
    <14908, 14906, 14905>,
    <14908, 14905, 14846>,
    <14908, 14846, 14855>,
    <14908, 14855, 14854>,
    <14908, 14854, 14910>,
    <14908, 14910, 14911>,
    <14908, 14911, 14909>,
    <14912, 14907, 14906>,
    <14912, 14906, 14909>,
    <14912, 14909, 14911>,
    <14912, 14911, 14913>,
    <14912, 14913, 14902>,
    <14912, 14902, 14901>,
    <14912, 14901, 14899>,
    <14912, 14899, 14907>,
    <14914, 14915, 14916>,
    <14914, 14916, 14917>,
    <14914, 14917, 14918>,
    <14914, 14918, 14919>,
    <14914, 14919, 14920>,
    <14914, 14920, 14921>,
    <14914, 14921, 14922>,
    <14914, 14922, 14915>,
    <14923, 14924, 14916>,
    <14923, 14916, 14915>,
    <14923, 14915, 14922>,
    <14923, 14922, 14925>,
    <14923, 14925, 14872>,
    <14923, 14872, 14885>,
    <14923, 14885, 14884>,
    <14923, 14884, 14924>,
    <14926, 14917, 14916>,
    <14926, 14916, 14924>,
    <14926, 14924, 14884>,
    <14926, 14884, 14889>,
    <14926, 14889, 13988>,
    <14926, 13988, 14927>,
    <14926, 14927, 14918>,
    <14926, 14918, 14917>,
    <14928, 14929, 14930>,
    <14928, 14930, 14931>,
    <14928, 14931, 14932>,
    <14928, 14932, 14933>,
    <14928, 14933, 14920>,
    <14928, 14920, 14919>,
    <14928, 14919, 14918>,
    <14928, 14918, 14929>,
    <14934, 14935, 14930>,
    <14934, 14930, 14929>,
    <14934, 14929, 14918>,
    <14934, 14918, 14927>,
    <14934, 14927, 13988>,
    <14934, 13988, 14041>,
    <14934, 14041, 14038>,
    <14934, 14038, 14935>,
    <14936, 14931, 14930>,
    <14936, 14930, 14935>,
    <14936, 14935, 14038>,
    <14936, 14038, 14037>,
    <14936, 14037, 14036>,
    <14936, 14036, 14937>,
    <14936, 14937, 14932>,
    <14936, 14932, 14931>,
    <14938, 14939, 14940>,
    <14938, 14940, 14941>,
    <14938, 14941, 14171>,
    <14938, 14171, 14170>,
    <14938, 14170, 14159>,
    <14938, 14159, 14942>,
    <14938, 14942, 14943>,
    <14938, 14943, 14939>,
    <14944, 14945, 14940>,
    <14944, 14940, 14939>,
    <14944, 14939, 14943>,
    <14944, 14943, 14946>,
    <14944, 14946, 14947>,
    <14944, 14947, 14948>,
    <14944, 14948, 14949>,
    <14944, 14949, 14945>,
    <14950, 14941, 14940>,
    <14950, 14940, 14945>,
    <14950, 14945, 14949>,
    <14950, 14949, 14951>,
    <14950, 14951, 14063>,
    <14950, 14063, 14173>,
    <14950, 14173, 14171>,
    <14950, 14171, 14941>,
    <14952, 14953, 14954>,
    <14952, 14954, 14955>,
    <14952, 14955, 14799>,
    <14952, 14799, 14798>,
    <14952, 14798, 14063>,
    <14952, 14063, 14951>,
    <14952, 14951, 14949>,
    <14952, 14949, 14953>,
    <14956, 14957, 14954>,
    <14956, 14954, 14953>,
    <14956, 14953, 14949>,
    <14956, 14949, 14948>,
    <14956, 14948, 14947>,
    <14956, 14947, 14958>,
    <14956, 14958, 14959>,
    <14956, 14959, 14957>,
    <14960, 14955, 14954>,
    <14960, 14954, 14957>,
    <14960, 14957, 14959>,
    <14960, 14959, 14961>,
    <14960, 14961, 14803>,
    <14960, 14803, 14802>,
    <14960, 14802, 14799>,
    <14960, 14799, 14955>,
    <14962, 14963, 14964>,
    <14962, 14964, 14965>,
    <14962, 14965, 14966>,
    <14962, 14966, 14967>,
    <14962, 14967, 14968>,
    <14962, 14968, 14969>,
    <14962, 14969, 14970>,
    <14962, 14970, 14963>,
    <14971, 14972, 14964>,
    <14971, 14964, 14963>,
    <14971, 14963, 14970>,
    <14971, 14970, 14973>,
    <14971, 14973, 13940>,
    <14971, 13940, 14840>,
    <14971, 14840, 14837>,
    <14971, 14837, 14972>,
    <14974, 14965, 14964>,
    <14974, 14964, 14972>,
    <14974, 14972, 14837>,
    <14974, 14837, 14836>,
    <14974, 14836, 14824>,
    <14974, 14824, 14975>,
    <14974, 14975, 14966>,
    <14974, 14966, 14965>,
    <14976, 14977, 14978>,
    <14976, 14978, 14979>,
    <14976, 14979, 14970>,
    <14976, 14970, 14969>,
    <14976, 14969, 14968>,
    <14976, 14968, 14980>,
    <14976, 14980, 14981>,
    <14976, 14981, 14977>,
    <14982, 14983, 14978>,
    <14982, 14978, 14977>,
    <14982, 14977, 14981>,
    <14982, 14981, 14984>,
    <14982, 14984, 14084>,
    <14982, 14084, 14083>,
    <14982, 14083, 14082>,
    <14982, 14082, 14983>,
    <14985, 14979, 14978>,
    <14985, 14978, 14983>,
    <14985, 14983, 14082>,
    <14985, 14082, 14091>,
    <14985, 14091, 13940>,
    <14985, 13940, 14973>,
    <14985, 14973, 14970>,
    <14985, 14970, 14979>,
    <14986, 14987, 14988>,
    <14986, 14988, 14989>,
    <14986, 14989, 14990>,
    <14986, 14990, 14991>,
    <14986, 14991, 14210>,
    <14986, 14210, 14221>,
    <14986, 14221, 14219>,
    <14986, 14219, 14987>,
    <14992, 14993, 14988>,
    <14992, 14988, 14987>,
    <14992, 14987, 14219>,
    <14992, 14219, 14218>,
    <14992, 14218, 14114>,
    <14992, 14114, 14994>,
    <14992, 14994, 14995>,
    <14992, 14995, 14993>,
    <14996, 14989, 14988>,
    <14996, 14988, 14993>,
    <14996, 14993, 14995>,
    <14996, 14995, 14997>,
    <14996, 14997, 14998>,
    <14996, 14998, 14999>,
    <14996, 14999, 14990>,
    <14996, 14990, 14989>,
    <15000, 15001, 15002>,
    <15000, 15002, 15003>,
    <15000, 15003, 14995>,
    <15000, 14995, 14994>,
    <15000, 14994, 14114>,
    <15000, 14114, 14895>,
    <15000, 14895, 14894>,
    <15000, 14894, 15001>,
    <15004, 15005, 15002>,
    <15004, 15002, 15001>,
    <15004, 15001, 14894>,
    <15004, 14894, 14903>,
    <15004, 14903, 14902>,
    <15004, 14902, 15006>,
    <15004, 15006, 15007>,
    <15004, 15007, 15005>,
    <15008, 15003, 15002>,
    <15008, 15002, 15005>,
    <15008, 15005, 15007>,
    <15008, 15007, 15009>,
    <15008, 15009, 14998>,
    <15008, 14998, 14997>,
    <15008, 14997, 14995>,
    <15008, 14995, 15003>,
    <15010, 15011, 15012>,
    <15010, 15012, 15013>,
    <15010, 15013, 15014>,
    <15010, 15014, 15015>,
    <15010, 15015, 15016>,
    <15010, 15016, 15017>,
    <15010, 15017, 15018>,
    <15010, 15018, 15011>,
    <15019, 15020, 15012>,
    <15019, 15012, 15011>,
    <15019, 15011, 15018>,
    <15019, 15018, 15021>,
    <15019, 15021, 14920>,
    <15019, 14920, 14933>,
    <15019, 14933, 14932>,
    <15019, 14932, 15020>,
    <15022, 15013, 15012>,
    <15022, 15012, 15020>,
    <15022, 15020, 14932>,
    <15022, 14932, 14937>,
    <15022, 14937, 14036>,
    <15022, 14036, 15023>,
    <15022, 15023, 15014>,
    <15022, 15014, 15013>,
    <15024, 15025, 15026>,
    <15024, 15026, 15027>,
    <15024, 15027, 15028>,
    <15024, 15028, 15029>,
    <15024, 15029, 15016>,
    <15024, 15016, 15015>,
    <15024, 15015, 15014>,
    <15024, 15014, 15025>,
    <15030, 15031, 15026>,
    <15030, 15026, 15025>,
    <15030, 15025, 15014>,
    <15030, 15014, 15023>,
    <15030, 15023, 14036>,
    <15030, 14036, 14137>,
    <15030, 14137, 14134>,
    <15030, 14134, 15031>,
    <15032, 15027, 15026>,
    <15032, 15026, 15031>,
    <15032, 15031, 14134>,
    <15032, 14134, 14133>,
    <15032, 14133, 14132>,
    <15032, 14132, 15033>,
    <15032, 15033, 15028>,
    <15032, 15028, 15027>,
    <15034, 15035, 15036>,
    <15034, 15036, 15037>,
    <15034, 15037, 14286>,
    <15034, 14286, 14285>,
    <15034, 14285, 14256>,
    <15034, 14256, 15038>,
    <15034, 15038, 15039>,
    <15034, 15039, 15035>,
    <15040, 15041, 15036>,
    <15040, 15036, 15035>,
    <15040, 15035, 15039>,
    <15040, 15039, 15042>,
    <15040, 15042, 15043>,
    <15040, 15043, 15044>,
    <15040, 15044, 15045>,
    <15040, 15045, 15041>,
    <15046, 15037, 15036>,
    <15046, 15036, 15041>,
    <15046, 15041, 15045>,
    <15046, 15045, 15047>,
    <15046, 15047, 14159>,
    <15046, 14159, 14288>,
    <15046, 14288, 14286>,
    <15046, 14286, 15037>,
    <15048, 15049, 15050>,
    <15048, 15050, 15051>,
    <15048, 15051, 14943>,
    <15048, 14943, 14942>,
    <15048, 14942, 14159>,
    <15048, 14159, 15047>,
    <15048, 15047, 15045>,
    <15048, 15045, 15049>,
    <15052, 15053, 15050>,
    <15052, 15050, 15049>,
    <15052, 15049, 15045>,
    <15052, 15045, 15044>,
    <15052, 15044, 15043>,
    <15052, 15043, 15054>,
    <15052, 15054, 15055>,
    <15052, 15055, 15053>,
    <15056, 15051, 15050>,
    <15056, 15050, 15053>,
    <15056, 15053, 15055>,
    <15056, 15055, 15057>,
    <15056, 15057, 14947>,
    <15056, 14947, 14946>,
    <15056, 14946, 14943>,
    <15056, 14943, 15051>,
    <15058, 15059, 15060>,
    <15058, 15060, 15061>,
    <15058, 15061, 15062>,
    <15058, 15062, 15063>,
    <15058, 15063, 15064>,
    <15058, 15064, 15065>,
    <15058, 15065, 15066>,
    <15058, 15066, 15059>,
    <15067, 15068, 15060>,
    <15067, 15060, 15059>,
    <15067, 15059, 15066>,
    <15067, 15066, 15069>,
    <15067, 15069, 14084>,
    <15067, 14084, 14984>,
    <15067, 14984, 14981>,
    <15067, 14981, 15068>,
    <15070, 15061, 15060>,
    <15070, 15060, 15068>,
    <15070, 15068, 14981>,
    <15070, 14981, 14980>,
    <15070, 14980, 14968>,
    <15070, 14968, 15071>,
    <15070, 15071, 15062>,
    <15070, 15062, 15061>,
    <15072, 15073, 15074>,
    <15072, 15074, 15075>,
    <15072, 15075, 15066>,
    <15072, 15066, 15065>,
    <15072, 15065, 15064>,
    <15072, 15064, 15076>,
    <15072, 15076, 15077>,
    <15072, 15077, 15073>,
    <15078, 15079, 15074>,
    <15078, 15074, 15073>,
    <15078, 15073, 15077>,
    <15078, 15077, 15080>,
    <15078, 15080, 14180>,
    <15078, 14180, 14179>,
    <15078, 14179, 14178>,
    <15078, 14178, 15079>,
    <15081, 15075, 15074>,
    <15081, 15074, 15079>,
    <15081, 15079, 14178>,
    <15081, 14178, 14187>,
    <15081, 14187, 14084>,
    <15081, 14084, 15069>,
    <15081, 15069, 15066>,
    <15081, 15066, 15075>,
    <15082, 15083, 15084>,
    <15082, 15084, 15085>,
    <15082, 15085, 15086>,
    <15082, 15086, 15087>,
    <15082, 15087, 14325>,
    <15082, 14325, 14336>,
    <15082, 14336, 14334>,
    <15082, 14334, 15083>,
    <15088, 15089, 15084>,
    <15088, 15084, 15083>,
    <15088, 15083, 14334>,
    <15088, 14334, 14333>,
    <15088, 14333, 14210>,
    <15088, 14210, 15090>,
    <15088, 15090, 15091>,
    <15088, 15091, 15089>,
    <15092, 15085, 15084>,
    <15092, 15084, 15089>,
    <15092, 15089, 15091>,
    <15092, 15091, 15093>,
    <15092, 15093, 15094>,
    <15092, 15094, 15095>,
    <15092, 15095, 15086>,
    <15092, 15086, 15085>,
    <15096, 15097, 15098>,
    <15096, 15098, 15099>,
    <15096, 15099, 15091>,
    <15096, 15091, 15090>,
    <15096, 15090, 14210>,
    <15096, 14210, 14991>,
    <15096, 14991, 14990>,
    <15096, 14990, 15097>,
    <15100, 15101, 15098>,
    <15100, 15098, 15097>,
    <15100, 15097, 14990>,
    <15100, 14990, 14999>,
    <15100, 14999, 14998>,
    <15100, 14998, 15102>,
    <15100, 15102, 15103>,
    <15100, 15103, 15101>,
    <15104, 15099, 15098>,
    <15104, 15098, 15101>,
    <15104, 15101, 15103>,
    <15104, 15103, 15105>,
    <15104, 15105, 15094>,
    <15104, 15094, 15093>,
    <15104, 15093, 15091>,
    <15104, 15091, 15099>,
    <15106, 15107, 15108>,
    <15106, 15108, 15109>,
    <15106, 15109, 15110>,
    <15106, 15110, 15111>,
    <15106, 15111, 15112>,
    <15106, 15112, 15113>,
    <15106, 15113, 15114>,
    <15106, 15114, 15107>,
    <15115, 15116, 15108>,
    <15115, 15108, 15107>,
    <15115, 15107, 15114>,
    <15115, 15114, 15117>,
    <15115, 15117, 15016>,
    <15115, 15016, 15029>,
    <15115, 15029, 15028>,
    <15115, 15028, 15116>,
    <15118, 15109, 15108>,
    <15118, 15108, 15116>,
    <15118, 15116, 15028>,
    <15118, 15028, 15033>,
    <15118, 15033, 14132>,
    <15118, 14132, 15119>,
    <15118, 15119, 15110>,
    <15118, 15110, 15109>,
    <15120, 15121, 15122>,
    <15120, 15122, 15123>,
    <15120, 15123, 15124>,
    <15120, 15124, 15125>,
    <15120, 15125, 15112>,
    <15120, 15112, 15111>,
    <15120, 15111, 15110>,
    <15120, 15110, 15121>,
    <15126, 15127, 15122>,
    <15126, 15122, 15121>,
    <15126, 15121, 15110>,
    <15126, 15110, 15119>,
    <15126, 15119, 14132>,
    <15126, 14132, 14233>,
    <15126, 14233, 14230>,
    <15126, 14230, 15127>,
    <15128, 15123, 15122>,
    <15128, 15122, 15127>,
    <15128, 15127, 14230>,
    <15128, 14230, 14229>,
    <15128, 14229, 14228>,
    <15128, 14228, 15129>,
    <15128, 15129, 15124>,
    <15128, 15124, 15123>,
    <15130, 15131, 15132>,
    <15130, 15132, 15133>,
    <15130, 15133, 15134>,
    <15130, 15134, 15135>,
    <15130, 15135, 15136>,
    <15130, 15136, 15137>,
    <15130, 15138, 15139>,
    <15130, 15139, 15131>,
    <15140, 15141, 15132>,
    <15140, 15132, 15131>,
    <15140, 15131, 15142>,
    <15140, 15142, 15143>,
    <15140, 15144, 15145>,
    <15140, 15145, 15146>,
    <15140, 15146, 15147>,
    <15140, 15147, 15141>,
    <15148, 15133, 15132>,
    <15148, 15132, 15141>,
    <15148, 15141, 15147>,
    <15148, 15147, 15149>,
    <15148, 15149, 15150>,
    <15148, 15150, 15151>,
    <15148, 15151, 15134>,
    <15148, 15134, 15133>,
    <15152, 15153, 15154>,
    <15152, 15154, 15155>,
    <15152, 15155, 14376>,
    <15152, 14376, 14375>,
    <15152, 14375, 15156>,
    <15152, 15156, 15135>,
    <15152, 15135, 15134>,
    <15152, 15134, 15153>,
    <15157, 15158, 15154>,
    <15157, 15154, 15153>,
    <15157, 15153, 15134>,
    <15157, 15134, 15151>,
    <15157, 15151, 15150>,
    <15157, 15150, 15159>,
    <15157, 15159, 15160>,
    <15157, 15160, 15158>,
    <15161, 15155, 15154>,
    <15161, 15154, 15158>,
    <15161, 15158, 15160>,
    <15161, 15160, 15162>,
    <15161, 15162, 14256>,
    <15161, 14256, 14378>,
    <15161, 14378, 14376>,
    <15161, 14376, 15155>,
    <15163, 15164, 15165>,
    <15163, 15165, 15166>,
    <15163, 15166, 15039>,
    <15163, 15039, 15038>,
    <15163, 15038, 14256>,
    <15163, 14256, 15162>,
    <15163, 15162, 15160>,
    <15163, 15160, 15164>,
    <15167, 15168, 15165>,
    <15167, 15165, 15164>,
    <15167, 15164, 15160>,
    <15167, 15160, 15159>,
    <15167, 15159, 15150>,
    <15167, 15150, 15169>,
    <15167, 15169, 15170>,
    <15167, 15170, 15168>,
    <15171, 15166, 15165>,
    <15171, 15165, 15168>,
    <15171, 15168, 15170>,
    <15171, 15170, 15172>,
    <15171, 15172, 15043>,
    <15171, 15043, 15042>,
    <15171, 15042, 15039>,
    <15171, 15039, 15166>,
    <15173, 15174, 15175>,
    <15173, 15175, 15176>,
    <15173, 15176, 15177>,
    <15173, 15177, 15178>,
    <15173, 15178, 15179>,
    <15173, 15179, 15180>,
    <15173, 15180, 15181>,
    <15173, 15181, 15174>,
    <15182, 15183, 15175>,
    <15182, 15175, 15174>,
    <15182, 15174, 15181>,
    <15182, 15181, 15184>,
    <15182, 15184, 14180>,
    <15182, 14180, 15080>,
    <15182, 15080, 15077>,
    <15182, 15077, 15183>,
    <15185, 15176, 15175>,
    <15185, 15175, 15183>,
    <15185, 15183, 15077>,
    <15185, 15077, 15076>,
    <15185, 15076, 15064>,
    <15185, 15064, 15186>,
    <15185, 15186, 15177>,
    <15185, 15177, 15176>,
    <15187, 15188, 15189>,
    <15187, 15189, 15190>,
    <15187, 15190, 15181>,
    <15187, 15181, 15180>,
    <15187, 15180, 15179>,
    <15187, 15179, 15191>,
    <15187, 15191, 15192>,
    <15187, 15192, 15188>,
    <15193, 15194, 15189>,
    <15193, 15189, 15188>,
    <15193, 15188, 15192>,
    <15193, 15192, 15195>,
    <15193, 15195, 14295>,
    <15193, 14295, 14294>,
    <15193, 14294, 14293>,
    <15193, 14293, 15194>,
    <15196, 15190, 15189>,
    <15196, 15189, 15194>,
    <15196, 15194, 14293>,
    <15196, 14293, 14302>,
    <15196, 14302, 14180>,
    <15196, 14180, 15184>,
    <15196, 15184, 15181>,
    <15196, 15181, 15190>,
    <15197, 15198, 15199>,
    <15197, 15199, 15200>,
    <15197, 15200, 15201>,
    <15197, 15201, 15202>,
    <15197, 15202, 14428>,
    <15197, 14428, 14450>,
    <15197, 14450, 14448>,
    <15197, 14448, 15198>,
    <15203, 15204, 15199>,
    <15203, 15199, 15198>,
    <15203, 15198, 14448>,
    <15203, 14448, 14447>,
    <15203, 14447, 14325>,
    <15203, 14325, 15205>,
    <15203, 15205, 15206>,
    <15203, 15206, 15204>,
    <15207, 15200, 15199>,
    <15207, 15199, 15204>,
    <15207, 15204, 15206>,
    <15207, 15206, 15208>,
    <15207, 15208, 15209>,
    <15207, 15209, 15210>,
    <15207, 15210, 15201>,
    <15207, 15201, 15200>,
    <15211, 15212, 15213>,
    <15211, 15213, 15214>,
    <15211, 15214, 15206>,
    <15211, 15206, 15205>,
    <15211, 15205, 14325>,
    <15211, 14325, 15087>,
    <15211, 15087, 15086>,
    <15211, 15086, 15212>,
    <15215, 15216, 15213>,
    <15215, 15213, 15212>,
    <15215, 15212, 15086>,
    <15215, 15086, 15095>,
    <15215, 15095, 15094>,
    <15215, 15094, 15217>,
    <15215, 15217, 15218>,
    <15215, 15218, 15216>,
    <15219, 15214, 15213>,
    <15219, 15213, 15216>,
    <15219, 15216, 15218>,
    <15219, 15218, 15220>,
    <15219, 15220, 15209>,
    <15219, 15209, 15208>,
    <15219, 15208, 15206>,
    <15219, 15206, 15214>,
    <15221, 15222, 15223>,
    <15221, 15223, 15224>,
    <15221, 15224, 15225>,
    <15221, 15225, 15226>,
    <15221, 15226, 15227>,
    <15221, 15227, 15228>,
    <15221, 15228, 15229>,
    <15221, 15229, 15222>,
    <15230, 15231, 15223>,
    <15230, 15223, 15222>,
    <15230, 15222, 15229>,
    <15230, 15229, 15232>,
    <15230, 15232, 15112>,
    <15230, 15112, 15125>,
    <15230, 15125, 15124>,
    <15230, 15124, 15231>,
    <15233, 15224, 15223>,
    <15233, 15223, 15231>,
    <15233, 15231, 15124>,
    <15233, 15124, 15129>,
    <15233, 15129, 14228>,
    <15233, 14228, 15234>,
    <15233, 15234, 15225>,
    <15233, 15225, 15224>,
    <15235, 15236, 15237>,
    <15235, 15237, 15238>,
    <15235, 15238, 15239>,
    <15235, 15239, 15240>,
    <15235, 15240, 15227>,
    <15235, 15227, 15226>,
    <15235, 15226, 15225>,
    <15235, 15225, 15236>,
    <15241, 15242, 15237>,
    <15241, 15237, 15236>,
    <15241, 15236, 15225>,
    <15241, 15225, 15234>,
    <15241, 15234, 14228>,
    <15241, 14228, 14348>,
    <15241, 14348, 14345>,
    <15241, 14345, 15242>,
    <15243, 15238, 15237>,
    <15243, 15237, 15242>,
    <15243, 15242, 14345>,
    <15243, 14345, 14344>,
    <15243, 14344, 14343>,
    <15243, 14343, 15244>,
    <15243, 15244, 15239>,
    <15243, 15239, 15238>,
    <15245, 15246, 15247>,
    <15245, 15247, 15248>,
    <15245, 15248, 15147>,
    <15245, 15147, 15146>,
    <15245, 15146, 15249>,
    <15245, 15249, 15250>,
    <15245, 15251, 15252>,
    <15245, 15252, 15246>,
    <15253, 15254, 15247>,
    <15253, 15247, 15246>,
    <15253, 15246, 15255>,
    <15253, 15255, 15256>,
    <15253, 15257, 15258>,
    <15253, 15258, 15259>,
    <15253, 15259, 15260>,
    <15253, 15260, 15254>,
    <15261, 15248, 15247>,
    <15261, 15247, 15254>,
    <15261, 15254, 15260>,
    <15261, 15260, 15262>,
    <15261, 15262, 15150>,
    <15261, 15150, 15149>,
    <15261, 15149, 15147>,
    <15261, 15147, 15248>,
    <15263, 15264, 15265>,
    <15263, 15265, 15266>,
    <15263, 15266, 15267>,
    <15263, 15267, 15268>,
    <15263, 15268, 15269>,
    <15263, 15269, 15270>,
    <15263, 15270, 15271>,
    <15263, 15271, 15264>,
    <15272, 15273, 15265>,
    <15272, 15265, 15264>,
    <15272, 15264, 15271>,
    <15272, 15271, 15274>,
    <15272, 15274, 14295>,
    <15272, 14295, 15195>,
    <15272, 15195, 15192>,
    <15272, 15192, 15273>,
    <15275, 15266, 15265>,
    <15275, 15265, 15273>,
    <15275, 15273, 15192>,
    <15275, 15192, 15191>,
    <15275, 15191, 15179>,
    <15275, 15179, 15276>,
    <15275, 15276, 15267>,
    <15275, 15267, 15266>,
    <15277, 15278, 15279>,
    <15277, 15279, 15280>,
    <15277, 15280, 15271>,
    <15277, 15271, 15270>,
    <15277, 15270, 15281>,
    <15277, 15281, 15282>,
    <15277, 15283, 15284>,
    <15277, 15284, 15278>,
    <15285, 15286, 15279>,
    <15285, 15279, 15278>,
    <15285, 15278, 15287>,
    <15285, 15287, 15288>,
    <15285, 15289, 15290>,
    <15285, 15290, 14581>,
    <15285, 14581, 14580>,
    <15285, 14580, 15286>,
    <15291, 15280, 15279>,
    <15291, 15279, 15286>,
    <15291, 15286, 14580>,
    <15291, 14580, 14593>,
    <15291, 14593, 14295>,
    <15291, 14295, 15274>,
    <15291, 15274, 15271>,
    <15291, 15271, 15280>,
    <15292, 15293, 15294>,
    <15292, 15294, 15295>,
    <15292, 15295, 15296>,
    <15292, 15296, 15297>,
    <15292, 15297, 15298>,
    <15292, 15298, 15299>,
    <15292, 15300, 15301>,
    <15292, 15301, 15293>,
    <15302, 15303, 15294>,
    <15302, 15294, 15293>,
    <15302, 15293, 15304>,
    <15302, 15304, 15305>,
    <15302, 15306, 15307>,
    <15302, 15307, 15308>,
    <15302, 15308, 15309>,
    <15302, 15309, 15303>,
    <15310, 15295, 15294>,
    <15310, 15294, 15303>,
    <15310, 15303, 15309>,
    <15310, 15309, 15311>,
    <15310, 15311, 15312>,
    <15310, 15312, 15313>,
    <15310, 15313, 15296>,
    <15310, 15296, 15295>,
    <15314, 15315, 15316>,
    <15314, 15316, 15317>,
    <15314, 15317, 15309>,
    <15314, 15309, 15308>,
    <15314, 15308, 15318>,
    <15314, 15318, 14545>,
    <15314, 14545, 14544>,
    <15314, 14544, 15315>,
    <15319, 15320, 15316>,
    <15319, 15316, 15315>,
    <15319, 15315, 14544>,
    <15319, 14544, 14557>,
    <15319, 14557, 14428>,
    <15319, 14428, 15321>,
    <15319, 15321, 15322>,
    <15319, 15322, 15320>,
    <15323, 15317, 15316>,
    <15323, 15316, 15320>,
    <15323, 15320, 15322>,
    <15323, 15322, 15324>,
    <15323, 15324, 15312>,
    <15323, 15312, 15311>,
    <15323, 15311, 15309>,
    <15323, 15309, 15317>,
    <15325, 15326, 15327>,
    <15325, 15327, 15328>,
    <15325, 15328, 15322>,
    <15325, 15322, 15321>,
    <15325, 15321, 14428>,
    <15325, 14428, 15202>,
    <15325, 15202, 15201>,
    <15325, 15201, 15326>,
    <15329, 15330, 15327>,
    <15329, 15327, 15326>,
    <15329, 15326, 15201>,
    <15329, 15201, 15210>,
    <15329, 15210, 15209>,
    <15329, 15209, 15331>,
    <15329, 15331, 15332>,
    <15329, 15332, 15330>,
    <15333, 15328, 15327>,
    <15333, 15327, 15330>,
    <15333, 15330, 15332>,
    <15333, 15332, 15334>,
    <15333, 15334, 15312>,
    <15333, 15312, 15324>,
    <15333, 15324, 15322>,
    <15333, 15322, 15328>,
    <15335, 15336, 15337>,
    <15335, 15337, 15338>,
    <15335, 15338, 15339>,
    <15335, 15339, 15340>,
    <15335, 15340, 15341>,
    <15335, 15341, 15342>,
    <15335, 15343, 15344>,
    <15335, 15344, 15336>,
    <15345, 15346, 15337>,
    <15345, 15337, 15336>,
    <15345, 15336, 15347>,
    <15345, 15347, 15348>,
    <15345, 15349, 15350>,
    <15345, 15350, 15351>,
    <15345, 15351, 15352>,
    <15345, 15352, 15346>,
    <15353, 15338, 15337>,
    <15353, 15337, 15346>,
    <15353, 15346, 15352>,
    <15353, 15352, 15354>,
    <15353, 15354, 15355>,
    <15353, 15355, 15356>,
    <15353, 15356, 15339>,
    <15353, 15339, 15338>,
    <15357, 15358, 15359>,
    <15357, 15359, 15360>,
    <15357, 15360, 15361>,
    <15357, 15361, 15362>,
    <15357, 15362, 15355>,
    <15357, 15355, 15363>,
    <15357, 15363, 15364>,
    <15357, 15364, 15358>,
    <15365, 15366, 15359>,
    <15365, 15359, 15358>,
    <15365, 15358, 15364>,
    <15365, 15364, 15367>,
    <15365, 15367, 15227>,
    <15365, 15227, 15240>,
    <15365, 15240, 15239>,
    <15365, 15239, 15366>,
    <15368, 15360, 15359>,
    <15368, 15359, 15366>,
    <15368, 15366, 15239>,
    <15368, 15239, 15244>,
    <15368, 15244, 14343>,
    <15368, 14343, 15369>,
    <15368, 15369, 15361>,
    <15368, 15361, 15360>,
    <15370, 15371, 15372>,
    <15370, 15372, 15373>,
    <15370, 15373, 14567>,
    <15370, 14567, 14566>,
    <15370, 14566, 15374>,
    <15370, 15374, 15340>,
    <15370, 15340, 15339>,
    <15370, 15339, 15371>,
    <15375, 15376, 15372>,
    <15375, 15372, 15371>,
    <15375, 15371, 15339>,
    <15375, 15339, 15356>,
    <15375, 15356, 15355>,
    <15375, 15355, 15377>,
    <15375, 15377, 15378>,
    <15375, 15378, 15376>,
    <15379, 15373, 15372>,
    <15379, 15372, 15376>,
    <15379, 15376, 15378>,
    <15379, 15378, 15380>,
    <15379, 15380, 14457>,
    <15379, 14457, 14570>,
    <15379, 14570, 14567>,
    <15379, 14567, 15373>,
    <15381, 15382, 15383>,
    <15381, 15383, 15384>,
    <15381, 15384, 15378>,
    <15381, 15378, 15377>,
    <15381, 15377, 15355>,
    <15381, 15355, 15362>,
    <15381, 15362, 15361>,
    <15381, 15361, 15382>,
    <15385, 15386, 15383>,
    <15385, 15383, 15382>,
    <15385, 15382, 15361>,
    <15385, 15361, 15369>,
    <15385, 15369, 14343>,
    <15385, 14343, 14462>,
    <15385, 14462, 14459>,
    <15385, 14459, 15386>,
    <15387, 15384, 15383>,
    <15387, 15383, 15386>,
    <15387, 15386, 14459>,
    <15387, 14459, 14458>,
    <15387, 14458, 14457>,
    <15387, 14457, 15380>,
    <15387, 15380, 15378>,
    <15387, 15378, 15384>,
    <15388, 15389, 15390>,
    <15388, 15390, 15391>,
    <15388, 15391, 15392>,
    <15388, 15392, 15393>,
    <15388, 15394, 15395>,
    <15388, 15395, 15297>,
    <15388, 15297, 15296>,
    <15388, 15296, 15389>,
    <15396, 15397, 15390>,
    <15396, 15390, 15389>,
    <15396, 15389, 15296>,
    <15396, 15296, 15313>,
    <15396, 15313, 15312>,
    <15396, 15312, 15398>,
    <15396, 15398, 15399>,
    <15396, 15399, 15397>,
    <15400, 15391, 15390>,
    <15400, 15390, 15397>,
    <15400, 15397, 15399>,
    <15400, 15399, 15401>,
    <15400, 15401, 15402>,
    <15400, 15402, 15403>,
    <15400, 15404, 15405>,
    <15400, 15405, 15391>,
    <15406, 15407, 15408>,
    <15406, 15408, 15409>,
    <15406, 15409, 15352>,
    <15406, 15352, 15351>,
    <15406, 15351, 15410>,
    <15406, 15410, 15411>,
    <15406, 15412, 15413>,
    <15406, 15413, 15407>,
    <15414, 15415, 15408>,
    <15414, 15408, 15407>,
    <15414, 15407, 15416>,
    <15414, 15416, 15417>,
    <15414, 15418, 15419>,
    <15414, 15419, 15420>,
    <15414, 15420, 15421>,
    <15414, 15421, 15415>,
    <15422, 15409, 15408>,
    <15422, 15408, 15415>,
    <15422, 15415, 15421>,
    <15422, 15421, 15423>,
    <15422, 15423, 15355>,
    <15422, 15355, 15354>,
    <15422, 15354, 15352>,
    <15422, 15352, 15409>,
    <15424, 15425, 15426>,
    <15424, 15426, 15427>,
    <15424, 15427, 15428>,
    <15424, 15428, 15429>,
    <15424, 15429, 15430>,
    <15424, 15430, 15431>,
    <15424, 15432, 15433>,
    <15424, 15433, 15425>,
    <15434, 15435, 15426>,
    <15434, 15426, 15425>,
    <15434, 15425, 15436>,
    <15434, 15436, 15437>,
    <15434, 15438, 15439>,
    <15434, 15439, 15401>,
    <15434, 15401, 15399>,
    <15434, 15399, 15435>,
    <15440, 15427, 15426>,
    <15440, 15426, 15435>,
    <15440, 15435, 15399>,
    <15440, 15399, 15398>,
    <15440, 15398, 15312>,
    <15440, 15312, 15441>,
    <15440, 15441, 15428>,
    <15440, 15428, 15427>,
    <15442, 15443, 15444>,
    <15442, 15444, 15445>,
    <15442, 15445, 15446>,
    <15442, 15446, 15447>,
    <15442, 15447, 15448>,
    <15442, 15448, 15449>,
    <15442, 15450, 15451>,
    <15442, 15451, 15443>,
    <15452, 15453, 15444>,
    <15452, 15444, 15443>,
    <15452, 15443, 15454>,
    <15452, 15454, 15455>,
    <15452, 15456, 15457>,
    <15452, 15457, 15268>,
    <15452, 15268, 15267>,
    <15452, 15267, 15453>,
    <15458, 15445, 15444>,
    <15458, 15444, 15453>,
    <15458, 15453, 15267>,
    <15458, 15267, 15276>,
    <15458, 15276, 15179>,
    <15458, 15179, 15459>,
    <15458, 15459, 15446>,
    <15458, 15446, 15445>,
    <15460, 15461, 15462>,
    <15460, 15462, 15463>,
    <15460, 15463, 15464>,
    <15460, 15464, 15465>,
    <15460, 15466, 15467>,
    <15460, 15467, 15468>,
    <15460, 15468, 15469>,
    <15460, 15469, 15461>,
    <15470, 15471, 15462>,
    <15470, 15462, 15461>,
    <15470, 15461, 15469>,
    <15470, 15469, 15472>,
    <15470, 15472, 15355>,
    <15470, 15355, 15423>,
    <15470, 15423, 15421>,
    <15470, 15421, 15471>,
    <15473, 15463, 15462>,
    <15473, 15462, 15471>,
    <15473, 15471, 15421>,
    <15473, 15421, 15420>,
    <15473, 15420, 15474>,
    <15473, 15474, 15475>,
    <15473, 15476, 15477>,
    <15473, 15477, 15463>,
    <15478, 15479, 15480>,
    <15478, 15480, 15481>,
    <15478, 15481, 14633>,
    <15478, 14633, 14632>,
    <15478, 14632, 14621>,
    <15478, 14621, 15482>,
    <15478, 15482, 15483>,
    <15478, 15483, 15479>,
    <15484, 15485, 15480>,
    <15484, 15480, 15479>,
    <15484, 15479, 15483>,
    <15484, 15483, 15486>,
    <15484, 15486, 15487>,
    <15484, 15487, 15488>,
    <15484, 15489, 15490>,
    <15484, 15490, 15485>,
    <15491, 15481, 15480>,
    <15491, 15480, 15485>,
    <15491, 15485, 15492>,
    <15491, 15492, 15493>,
    <15491, 15494, 15495>,
    <15491, 15495, 14635>,
    <15491, 14635, 14633>,
    <15491, 14633, 15481>,
    <15496, 15497, 15498>,
    <15496, 15498, 15499>,
    <15496, 15499, 14691>,
    <15496, 14691, 14690>,
    <15496, 14690, 14679>,
    <15496, 14679, 15500>,
    <15496, 15500, 15501>,
    <15496, 15501, 15497>,
    <15502, 15503, 15498>,
    <15502, 15498, 15497>,
    <15502, 15497, 15501>,
    <15502, 15501, 15504>,
    <15502, 15504, 15505>,
    <15502, 15505, 15506>,
    <15502, 15506, 15507>,
    <15502, 15507, 15503>,
    <15508, 15499, 15498>,
    <15508, 15498, 15503>,
    <15508, 15503, 15507>,
    <15508, 15507, 15509>,
    <15508, 15509, 14621>,
    <15508, 14621, 14693>,
    <15508, 14693, 14691>,
    <15508, 14691, 15499>,
    <15510, 15511, 15512>,
    <15510, 15512, 15513>,
    <15510, 15513, 15483>,
    <15510, 15483, 15482>,
    <15510, 15482, 14621>,
    <15510, 14621, 15509>,
    <15510, 15509, 15507>,
    <15510, 15507, 15511>,
    <15514, 15515, 15512>,
    <15514, 15512, 15511>,
    <15514, 15511, 15507>,
    <15514, 15507, 15506>,
    <15514, 15506, 15505>,
    <15514, 15505, 15516>,
    <15514, 15516, 15517>,
    <15514, 15517, 15515>,
    <15518, 15513, 15512>,
    <15518, 15512, 15515>,
    <15518, 15515, 15517>,
    <15518, 15517, 15519>,
    <15518, 15519, 15520>,
    <15518, 15520, 15486>,
    <15518, 15486, 15483>,
    <15518, 15483, 15513>,
    <15521, 15522, 15523>,
    <15521, 15523, 15524>,
    <15521, 15524, 15525>,
    <15521, 15525, 15526>,
    <15521, 15526, 15527>,
    <15521, 15527, 15528>,
    <15521, 15528, 15529>,
    <15521, 15529, 15522>,
    <15530, 15531, 15523>,
    <15530, 15523, 15522>,
    <15530, 15522, 15529>,
    <15530, 15529, 15532>,
    <15530, 15532, 15533>,
    <15530, 15533, 15534>,
    <15530, 15535, 15536>,
    <15530, 15536, 15531>,
    <15537, 15524, 15523>,
    <15537, 15523, 15531>,
    <15537, 15531, 15538>,
    <15537, 15538, 15539>,
    <15537, 15540, 15541>,
    <15537, 15541, 15542>,
    <15537, 15542, 15525>,
    <15537, 15525, 15524>,
    <15543, 15544, 15545>,
    <15543, 15545, 15546>,
    <15543, 15546, 15529>,
    <15543, 15529, 15528>,
    <15543, 15528, 15527>,
    <15543, 15527, 15547>,
    <15543, 15547, 15548>,
    <15543, 15548, 15544>,
    <15549, 15550, 15545>,
    <15549, 15545, 15544>,
    <15549, 15544, 15548>,
    <15549, 15548, 15551>,
    <15549, 15551, 14643>,
    <15549, 14643, 14642>,
    <15549, 14642, 14641>,
    <15549, 14641, 15550>,
    <15552, 15546, 15545>,
    <15552, 15545, 15550>,
    <15552, 15550, 14641>,
    <15552, 14641, 14658>,
    <15552, 14658, 15553>,
    <15552, 15553, 15532>,
    <15552, 15532, 15529>,
    <15552, 15529, 15546>,
    <15554, 15555, 15556>,
    <15554, 15556, 15557>,
    <15554, 15557, 14815>,
    <15554, 14815, 14814>,
    <15554, 14814, 14803>,
    <15554, 14803, 15558>,
    <15554, 15558, 15559>,
    <15554, 15559, 15555>,
    <15560, 15561, 15556>,
    <15560, 15556, 15555>,
    <15560, 15555, 15559>,
    <15560, 15559, 15562>,
    <15560, 15562, 15563>,
    <15560, 15563, 15564>,
    <15560, 15564, 15565>,
    <15560, 15565, 15561>,
    <15566, 15557, 15556>,
    <15566, 15556, 15561>,
    <15566, 15561, 15565>,
    <15566, 15565, 15567>,
    <15566, 15567, 14679>,
    <15566, 14679, 14817>,
    <15566, 14817, 14815>,
    <15566, 14815, 15557>,
    <15568, 15569, 15570>,
    <15568, 15570, 15571>,
    <15568, 15571, 15501>,
    <15568, 15501, 15500>,
    <15568, 15500, 14679>,
    <15568, 14679, 15567>,
    <15568, 15567, 15565>,
    <15568, 15565, 15569>,
    <15572, 15573, 15570>,
    <15572, 15570, 15569>,
    <15572, 15569, 15565>,
    <15572, 15565, 15564>,
    <15572, 15564, 15563>,
    <15572, 15563, 15574>,
    <15572, 15574, 15575>,
    <15572, 15575, 15573>,
    <15576, 15571, 15570>,
    <15576, 15570, 15573>,
    <15576, 15573, 15575>,
    <15576, 15575, 15577>,
    <15576, 15577, 15505>,
    <15576, 15505, 15504>,
    <15576, 15504, 15501>,
    <15576, 15501, 15571>,
    <15578, 15579, 15580>,
    <15578, 15580, 15581>,
    <15578, 15581, 15582>,
    <15578, 15582, 15583>,
    <15578, 15583, 15584>,
    <15578, 15584, 15585>,
    <15578, 15585, 15586>,
    <15578, 15586, 15579>,
    <15587, 15588, 15580>,
    <15587, 15580, 15579>,
    <15587, 15579, 15586>,
    <15587, 15586, 15589>,
    <15587, 15589, 14643>,
    <15587, 14643, 15551>,
    <15587, 15551, 15548>,
    <15587, 15548, 15588>,
    <15590, 15581, 15580>,
    <15590, 15580, 15588>,
    <15590, 15588, 15548>,
    <15590, 15548, 15547>,
    <15590, 15547, 15527>,
    <15590, 15527, 15591>,
    <15590, 15591, 15582>,
    <15590, 15582, 15581>,
    <15592, 15593, 15594>,
    <15592, 15594, 15595>,
    <15592, 15595, 15586>,
    <15592, 15586, 15585>,
    <15592, 15585, 15584>,
    <15592, 15584, 15596>,
    <15592, 15596, 15597>,
    <15592, 15597, 15593>,
    <15598, 15599, 15594>,
    <15598, 15594, 15593>,
    <15598, 15593, 15597>,
    <15598, 15597, 15600>,
    <15598, 15600, 14700>,
    <15598, 14700, 14699>,
    <15598, 14699, 14698>,
    <15598, 14698, 15599>,
    <15601, 15595, 15594>,
    <15601, 15594, 15599>,
    <15601, 15599, 14698>,
    <15601, 14698, 14707>,
    <15601, 14707, 14643>,
    <15601, 14643, 15589>,
    <15601, 15589, 15586>,
    <15601, 15586, 15595>,
    <15602, 15603, 15604>,
    <15602, 15604, 15605>,
    <15602, 15605, 15606>,
    <15602, 15606, 15607>,
    <15602, 15607, 14748>,
    <15602, 14748, 14760>,
    <15602, 14760, 14758>,
    <15602, 14758, 15603>,
    <15608, 15609, 15604>,
    <15608, 15604, 15603>,
    <15608, 15603, 14758>,
    <15608, 14758, 14757>,
    <15608, 14757, 15610>,
    <15608, 15610, 15611>,
    <15608, 15612, 15613>,
    <15608, 15613, 15609>,
    <15614, 15605, 15604>,
    <15614, 15604, 15609>,
    <15614, 15609, 15615>,
    <15614, 15615, 15616>,
    <15614, 15617, 15618>,
    <15614, 15618, 15619>,
    <15614, 15619, 15606>,
    <15614, 15606, 15605>,
    <15620, 15621, 15622>,
    <15620, 15622, 15623>,
    <15620, 15623, 15624>,
    <15620, 15624, 15625>,
    <15620, 15625, 14854>,
    <15620, 14854, 14865>,
    <15620, 14865, 14863>,
    <15620, 14863, 15621>,
    <15626, 15627, 15622>,
    <15626, 15622, 15621>,
    <15626, 15621, 14863>,
    <15626, 14863, 14862>,
    <15626, 14862, 14748>,
    <15626, 14748, 15628>,
    <15626, 15628, 15629>,
    <15626, 15629, 15627>,
    <15630, 15623, 15622>,
    <15630, 15622, 15627>,
    <15630, 15627, 15629>,
    <15630, 15629, 15631>,
    <15630, 15631, 15632>,
    <15630, 15632, 15633>,
    <15630, 15633, 15624>,
    <15630, 15624, 15623>,
    <15634, 15635, 15636>,
    <15634, 15636, 15637>,
    <15634, 15637, 15629>,
    <15634, 15629, 15628>,
    <15634, 15628, 14748>,
    <15634, 14748, 15607>,
    <15634, 15607, 15606>,
    <15634, 15606, 15635>,
    <15638, 15639, 15636>,
    <15638, 15636, 15635>,
    <15638, 15635, 15606>,
    <15638, 15606, 15619>,
    <15638, 15619, 15640>,
    <15638, 15640, 15641>,
    <15638, 15641, 15642>,
    <15638, 15642, 15639>,
    <15643, 15637, 15636>,
    <15643, 15636, 15639>,
    <15643, 15639, 15642>,
    <15643, 15642, 15644>,
    <15643, 15644, 15632>,
    <15643, 15632, 15631>,
    <15643, 15631, 15629>,
    <15643, 15629, 15637>,
    <15645, 15646, 15647>,
    <15645, 15647, 15648>,
    <15645, 15648, 15649>,
    <15645, 15649, 15650>,
    <15645, 15650, 15651>,
    <15645, 15651, 15652>,
    <15645, 15652, 15653>,
    <15645, 15653, 15646>,
    <15654, 15655, 15647>,
    <15654, 15647, 15646>,
    <15654, 15646, 15653>,
    <15654, 15653, 15656>,
    <15654, 15656, 15657>,
    <15654, 15657, 15658>,
    <15654, 15659, 15660>,
    <15654, 15660, 15655>,
    <15661, 15648, 15647>,
    <15661, 15647, 15655>,
    <15661, 15655, 15662>,
    <15661, 15662, 15663>,
    <15661, 15664, 15665>,
    <15661, 15665, 15666>,
    <15661, 15666, 15649>,
    <15661, 15649, 15648>,
    <15667, 15668, 15669>,
    <15667, 15669, 15670>,
    <15667, 15670, 15671>,
    <15667, 15671, 15672>,
    <15667, 15672, 15651>,
    <15667, 15651, 15650>,
    <15667, 15650, 15649>,
    <15667, 15649, 15668>,
    <15673, 15674, 15669>,
    <15673, 15669, 15668>,
    <15673, 15668, 15649>,
    <15673, 15649, 15666>,
    <15673, 15666, 15675>,
    <15673, 15675, 14772>,
    <15673, 14772, 14769>,
    <15673, 14769, 15674>,
    <15676, 15670, 15669>,
    <15676, 15669, 15674>,
    <15676, 15674, 14769>,
    <15676, 14769, 14768>,
    <15676, 14768, 14767>,
    <15676, 14767, 15677>,
    <15676, 15677, 15671>,
    <15676, 15671, 15670>,
    <15678, 15679, 15680>,
    <15678, 15680, 15681>,
    <15678, 15681, 14959>,
    <15678, 14959, 14958>,
    <15678, 14958, 14947>,
    <15678, 14947, 15682>,
    <15678, 15682, 15683>,
    <15678, 15683, 15679>,
    <15684, 15685, 15680>,
    <15684, 15680, 15679>,
    <15684, 15679, 15683>,
    <15684, 15683, 15686>,
    <15684, 15686, 15687>,
    <15684, 15687, 15688>,
    <15684, 15688, 15689>,
    <15684, 15689, 15685>,
    <15690, 15681, 15680>,
    <15690, 15680, 15685>,
    <15690, 15685, 15689>,
    <15690, 15689, 15691>,
    <15690, 15691, 14803>,
    <15690, 14803, 14961>,
    <15690, 14961, 14959>,
    <15690, 14959, 15681>,
    <15692, 15693, 15694>,
    <15692, 15694, 15695>,
    <15692, 15695, 15559>,
    <15692, 15559, 15558>,
    <15692, 15558, 14803>,
    <15692, 14803, 15691>,
    <15692, 15691, 15689>,
    <15692, 15689, 15693>,
    <15696, 15697, 15694>,
    <15696, 15694, 15693>,
    <15696, 15693, 15689>,
    <15696, 15689, 15688>,
    <15696, 15688, 15687>,
    <15696, 15687, 15698>,
    <15696, 15698, 15699>,
    <15696, 15699, 15697>,
    <15700, 15695, 15694>,
    <15700, 15694, 15697>,
    <15700, 15697, 15699>,
    <15700, 15699, 15701>,
    <15700, 15701, 15563>,
    <15700, 15563, 15562>,
    <15700, 15562, 15559>,
    <15700, 15559, 15695>,
    <15702, 15703, 15704>,
    <15702, 15704, 15705>,
    <15702, 15705, 15706>,
    <15702, 15706, 15707>,
    <15702, 15707, 15708>,
    <15702, 15708, 15709>,
    <15702, 15709, 15710>,
    <15702, 15710, 15703>,
    <15711, 15712, 15704>,
    <15711, 15704, 15703>,
    <15711, 15703, 15710>,
    <15711, 15710, 15713>,
    <15711, 15713, 14700>,
    <15711, 14700, 15600>,
    <15711, 15600, 15597>,
    <15711, 15597, 15712>,
    <15714, 15705, 15704>,
    <15714, 15704, 15712>,
    <15714, 15712, 15597>,
    <15714, 15597, 15596>,
    <15714, 15596, 15584>,
    <15714, 15584, 15715>,
    <15714, 15715, 15706>,
    <15714, 15706, 15705>,
    <15716, 15717, 15718>,
    <15716, 15718, 15719>,
    <15716, 15719, 15710>,
    <15716, 15710, 15709>,
    <15716, 15709, 15708>,
    <15716, 15708, 15720>,
    <15716, 15720, 15721>,
    <15716, 15721, 15717>,
    <15722, 15723, 15718>,
    <15722, 15718, 15717>,
    <15722, 15717, 15721>,
    <15722, 15721, 15724>,
    <15722, 15724, 14824>,
    <15722, 14824, 14823>,
    <15722, 14823, 14822>,
    <15722, 14822, 15723>,
    <15725, 15719, 15718>,
    <15725, 15718, 15723>,
    <15725, 15723, 14822>,
    <15725, 14822, 14831>,
    <15725, 14831, 14700>,
    <15725, 14700, 15713>,
    <15725, 15713, 15710>,
    <15725, 15710, 15719>,
    <15726, 15727, 15728>,
    <15726, 15728, 15729>,
    <15726, 15729, 15730>,
    <15726, 15730, 15731>,
    <15726, 15731, 14902>,
    <15726, 14902, 14913>,
    <15726, 14913, 14911>,
    <15726, 14911, 15727>,
    <15732, 15733, 15728>,
    <15732, 15728, 15727>,
    <15732, 15727, 14911>,
    <15732, 14911, 14910>,
    <15732, 14910, 14854>,
    <15732, 14854, 15734>,
    <15732, 15734, 15735>,
    <15732, 15735, 15733>,
    <15736, 15729, 15728>,
    <15736, 15728, 15733>,
    <15736, 15733, 15735>,
    <15736, 15735, 15737>,
    <15736, 15737, 15738>,
    <15736, 15738, 15739>,
    <15736, 15739, 15730>,
    <15736, 15730, 15729>,
    <15740, 15741, 15742>,
    <15740, 15742, 15743>,
    <15740, 15743, 15735>,
    <15740, 15735, 15734>,
    <15740, 15734, 14854>,
    <15740, 14854, 15625>,
    <15740, 15625, 15624>,
    <15740, 15624, 15741>,
    <15744, 15745, 15742>,
    <15744, 15742, 15741>,
    <15744, 15741, 15624>,
    <15744, 15624, 15633>,
    <15744, 15633, 15632>,
    <15744, 15632, 15746>,
    <15744, 15746, 15747>,
    <15744, 15747, 15745>,
    <15748, 15743, 15742>,
    <15748, 15742, 15745>,
    <15748, 15745, 15747>,
    <15748, 15747, 15749>,
    <15748, 15749, 15738>,
    <15748, 15738, 15737>,
    <15748, 15737, 15735>,
    <15748, 15735, 15743>,
    <15750, 15751, 15752>,
    <15750, 15752, 15753>,
    <15750, 15753, 15754>,
    <15750, 15754, 15755>,
    <15750, 15755, 15756>,
    <15750, 15756, 15757>,
    <15750, 15757, 15758>,
    <15750, 15758, 15751>,
    <15759, 15760, 15752>,
    <15759, 15752, 15751>,
    <15759, 15751, 15758>,
    <15759, 15758, 15761>,
    <15759, 15761, 15651>,
    <15759, 15651, 15672>,
    <15759, 15672, 15671>,
    <15759, 15671, 15760>,
    <15762, 15753, 15752>,
    <15762, 15752, 15760>,
    <15762, 15760, 15671>,
    <15762, 15671, 15677>,
    <15762, 15677, 14767>,
    <15762, 14767, 15763>,
    <15762, 15763, 15754>,
    <15762, 15754, 15753>,
    <15764, 15765, 15766>,
    <15764, 15766, 15767>,
    <15764, 15767, 15768>,
    <15764, 15768, 15769>,
    <15764, 15769, 15756>,
    <15764, 15756, 15755>,
    <15764, 15755, 15754>,
    <15764, 15754, 15765>,
    <15770, 15771, 15766>,
    <15770, 15766, 15765>,
    <15770, 15765, 15754>,
    <15770, 15754, 15763>,
    <15770, 15763, 14767>,
    <15770, 14767, 14877>,
    <15770, 14877, 14874>,
    <15770, 14874, 15771>,
    <15772, 15767, 15766>,
    <15772, 15766, 15771>,
    <15772, 15771, 14874>,
    <15772, 14874, 14873>,
    <15772, 14873, 14872>,
    <15772, 14872, 15773>,
    <15772, 15773, 15768>,
    <15772, 15768, 15767>,
    <15774, 15775, 15776>,
    <15774, 15776, 15777>,
    <15774, 15777, 15778>,
    <15774, 15778, 15779>,
    <15774, 15779, 14998>,
    <15774, 14998, 15009>,
    <15774, 15009, 15007>,
    <15774, 15007, 15775>,
    <15780, 15781, 15776>,
    <15780, 15776, 15775>,
    <15780, 15775, 15007>,
    <15780, 15007, 15006>,
    <15780, 15006, 14902>,
    <15780, 14902, 15782>,
    <15780, 15782, 15783>,
    <15780, 15783, 15781>,
    <15784, 15777, 15776>,
    <15784, 15776, 15781>,
    <15784, 15781, 15783>,
    <15784, 15783, 15785>,
    <15784, 15785, 15786>,
    <15784, 15786, 15787>,
    <15784, 15787, 15778>,
    <15784, 15778, 15777>,
    <15788, 15789, 15790>,
    <15788, 15790, 15791>,
    <15788, 15791, 15783>,
    <15788, 15783, 15782>,
    <15788, 15782, 14902>,
    <15788, 14902, 15731>,
    <15788, 15731, 15730>,
    <15788, 15730, 15789>,
    <15792, 15793, 15790>,
    <15792, 15790, 15789>,
    <15792, 15789, 15730>,
    <15792, 15730, 15739>,
    <15792, 15739, 15738>,
    <15792, 15738, 15794>,
    <15792, 15794, 15795>,
    <15792, 15795, 15793>,
    <15796, 15791, 15790>,
    <15796, 15790, 15793>,
    <15796, 15793, 15795>,
    <15796, 15795, 15797>,
    <15796, 15797, 15786>,
    <15796, 15786, 15785>,
    <15796, 15785, 15783>,
    <15796, 15783, 15791>,
    <15798, 15799, 15800>,
    <15798, 15800, 15801>,
    <15798, 15801, 15802>,
    <15798, 15802, 15803>,
    <15798, 15803, 15804>,
    <15798, 15804, 15805>,
    <15798, 15805, 15806>,
    <15798, 15806, 15799>,
    <15807, 15808, 15800>,
    <15807, 15800, 15799>,
    <15807, 15799, 15806>,
    <15807, 15806, 15809>,
    <15807, 15809, 15756>,
    <15807, 15756, 15769>,
    <15807, 15769, 15768>,
    <15807, 15768, 15808>,
    <15810, 15801, 15800>,
    <15810, 15800, 15808>,
    <15810, 15808, 15768>,
    <15810, 15768, 15773>,
    <15810, 15773, 14872>,
    <15810, 14872, 15811>,
    <15810, 15811, 15802>,
    <15810, 15802, 15801>,
    <15812, 15813, 15814>,
    <15812, 15814, 15815>,
    <15812, 15815, 15816>,
    <15812, 15816, 15817>,
    <15812, 15817, 15804>,
    <15812, 15804, 15803>,
    <15812, 15803, 15802>,
    <15812, 15802, 15813>,
    <15818, 15819, 15814>,
    <15818, 15814, 15813>,
    <15818, 15813, 15802>,
    <15818, 15802, 15811>,
    <15818, 15811, 14872>,
    <15818, 14872, 14925>,
    <15818, 14925, 14922>,
    <15818, 14922, 15819>,
    <15820, 15815, 15814>,
    <15820, 15814, 15819>,
    <15820, 15819, 14922>,
    <15820, 14922, 14921>,
    <15820, 14921, 14920>,
    <15820, 14920, 15821>,
    <15820, 15821, 15816>,
    <15820, 15816, 15815>,
    <15822, 15823, 15824>,
    <15822, 15824, 15825>,
    <15822, 15825, 15055>,
    <15822, 15055, 15054>,
    <15822, 15054, 15043>,
    <15822, 15043, 15826>,
    <15822, 15826, 15827>,
    <15822, 15827, 15823>,
    <15828, 15829, 15824>,
    <15828, 15824, 15823>,
    <15828, 15823, 15827>,
    <15828, 15827, 15830>,
    <15828, 15830, 15831>,
    <15828, 15831, 15832>,
    <15828, 15832, 15833>,
    <15828, 15833, 15829>,
    <15834, 15825, 15824>,
    <15834, 15824, 15829>,
    <15834, 15829, 15833>,
    <15834, 15833, 15835>,
    <15834, 15835, 14947>,
    <15834, 14947, 15057>,
    <15834, 15057, 15055>,
    <15834, 15055, 15825>,
    <15836, 15837, 15838>,
    <15836, 15838, 15839>,
    <15836, 15839, 15683>,
    <15836, 15683, 15682>,
    <15836, 15682, 14947>,
    <15836, 14947, 15835>,
    <15836, 15835, 15833>,
    <15836, 15833, 15837>,
    <15840, 15841, 15838>,
    <15840, 15838, 15837>,
    <15840, 15837, 15833>,
    <15840, 15833, 15832>,
    <15840, 15832, 15831>,
    <15840, 15831, 15842>,
    <15840, 15842, 15843>,
    <15840, 15843, 15841>,
    <15844, 15839, 15838>,
    <15844, 15838, 15841>,
    <15844, 15841, 15843>,
    <15844, 15843, 15845>,
    <15844, 15845, 15687>,
    <15844, 15687, 15686>,
    <15844, 15686, 15683>,
    <15844, 15683, 15839>,
    <15846, 15847, 15848>,
    <15846, 15848, 15849>,
    <15846, 15849, 15850>,
    <15846, 15850, 15851>,
    <15846, 15851, 15852>,
    <15846, 15852, 15853>,
    <15846, 15853, 15854>,
    <15846, 15854, 15847>,
    <15855, 15856, 15848>,
    <15855, 15848, 15847>,
    <15855, 15847, 15854>,
    <15855, 15854, 15857>,
    <15855, 15857, 14824>,
    <15855, 14824, 15724>,
    <15855, 15724, 15721>,
    <15855, 15721, 15856>,
    <15858, 15849, 15848>,
    <15858, 15848, 15856>,
    <15858, 15856, 15721>,
    <15858, 15721, 15720>,
    <15858, 15720, 15708>,
    <15858, 15708, 15859>,
    <15858, 15859, 15850>,
    <15858, 15850, 15849>,
    <15860, 15861, 15862>,
    <15860, 15862, 15863>,
    <15860, 15863, 15854>,
    <15860, 15854, 15853>,
    <15860, 15853, 15852>,
    <15860, 15852, 15864>,
    <15860, 15864, 15865>,
    <15860, 15865, 15861>,
    <15866, 15867, 15862>,
    <15866, 15862, 15861>,
    <15866, 15861, 15865>,
    <15866, 15865, 15868>,
    <15866, 15868, 14968>,
    <15866, 14968, 14967>,
    <15866, 14967, 14966>,
    <15866, 14966, 15867>,
    <15869, 15863, 15862>,
    <15869, 15862, 15867>,
    <15869, 15867, 14966>,
    <15869, 14966, 14975>,
    <15869, 14975, 14824>,
    <15869, 14824, 15857>,
    <15869, 15857, 15854>,
    <15869, 15854, 15863>,
    <15870, 15871, 15872>,
    <15870, 15872, 15873>,
    <15870, 15873, 15874>,
    <15870, 15874, 15875>,
    <15870, 15875, 15094>,
    <15870, 15094, 15105>,
    <15870, 15105, 15103>,
    <15870, 15103, 15871>,
    <15876, 15877, 15872>,
    <15876, 15872, 15871>,
    <15876, 15871, 15103>,
    <15876, 15103, 15102>,
    <15876, 15102, 14998>,
    <15876, 14998, 15878>,
    <15876, 15878, 15879>,
    <15876, 15879, 15877>,
    <15880, 15873, 15872>,
    <15880, 15872, 15877>,
    <15880, 15877, 15879>,
    <15880, 15879, 15881>,
    <15880, 15881, 15882>,
    <15880, 15882, 15883>,
    <15880, 15883, 15874>,
    <15880, 15874, 15873>,
    <15884, 15885, 15886>,
    <15884, 15886, 15887>,
    <15884, 15887, 15879>,
    <15884, 15879, 15878>,
    <15884, 15878, 14998>,
    <15884, 14998, 15779>,
    <15884, 15779, 15778>,
    <15884, 15778, 15885>,
    <15888, 15889, 15886>,
    <15888, 15886, 15885>,
    <15888, 15885, 15778>,
    <15888, 15778, 15787>,
    <15888, 15787, 15786>,
    <15888, 15786, 15890>,
    <15888, 15890, 15891>,
    <15888, 15891, 15889>,
    <15892, 15887, 15886>,
    <15892, 15886, 15889>,
    <15892, 15889, 15891>,
    <15892, 15891, 15893>,
    <15892, 15893, 15882>,
    <15892, 15882, 15881>,
    <15892, 15881, 15879>,
    <15892, 15879, 15887>,
    <15894, 15895, 15896>,
    <15894, 15896, 15897>,
    <15894, 15897, 15898>,
    <15894, 15898, 15899>,
    <15894, 15899, 15900>,
    <15894, 15900, 15901>,
    <15894, 15901, 15902>,
    <15894, 15902, 15895>,
    <15903, 15904, 15896>,
    <15903, 15896, 15895>,
    <15903, 15895, 15902>,
    <15903, 15902, 15905>,
    <15903, 15905, 15804>,
    <15903, 15804, 15817>,
    <15903, 15817, 15816>,
    <15903, 15816, 15904>,
    <15906, 15897, 15896>,
    <15906, 15896, 15904>,
    <15906, 15904, 15816>,
    <15906, 15816, 15821>,
    <15906, 15821, 14920>,
    <15906, 14920, 15907>,
    <15906, 15907, 15898>,
    <15906, 15898, 15897>,
    <15908, 15909, 15910>,
    <15908, 15910, 15911>,
    <15908, 15911, 15912>,
    <15908, 15912, 15913>,
    <15908, 15913, 15900>,
    <15908, 15900, 15899>,
    <15908, 15899, 15898>,
    <15908, 15898, 15909>,
    <15914, 15915, 15910>,
    <15914, 15910, 15909>,
    <15914, 15909, 15898>,
    <15914, 15898, 15907>,
    <15914, 15907, 14920>,
    <15914, 14920, 15021>,
    <15914, 15021, 15018>,
    <15914, 15018, 15915>,
    <15916, 15911, 15910>,
    <15916, 15910, 15915>,
    <15916, 15915, 15018>,
    <15916, 15018, 15017>,
    <15916, 15017, 15016>,
    <15916, 15016, 15917>,
    <15916, 15917, 15912>,
    <15916, 15912, 15911>,
    <15918, 15919, 15920>,
    <15918, 15920, 15921>,
    <15918, 15921, 15170>,
    <15918, 15170, 15169>,
    <15918, 15169, 15150>,
    <15918, 15150, 15922>,
    <15918, 15922, 15923>,
    <15918, 15923, 15919>,
    <15924, 15925, 15920>,
    <15924, 15920, 15919>,
    <15924, 15919, 15923>,
    <15924, 15923, 15926>,
    <15924, 15926, 15927>,
    <15924, 15927, 15928>,
    <15924, 15928, 15929>,
    <15924, 15929, 15925>,
    <15930, 15921, 15920>,
    <15930, 15920, 15925>,
    <15930, 15925, 15929>,
    <15930, 15929, 15931>,
    <15930, 15931, 15043>,
    <15930, 15043, 15172>,
    <15930, 15172, 15170>,
    <15930, 15170, 15921>,
    <15932, 15933, 15934>,
    <15932, 15934, 15935>,
    <15932, 15935, 15827>,
    <15932, 15827, 15826>,
    <15932, 15826, 15043>,
    <15932, 15043, 15931>,
    <15932, 15931, 15929>,
    <15932, 15929, 15933>,
    <15936, 15937, 15934>,
    <15936, 15934, 15933>,
    <15936, 15933, 15929>,
    <15936, 15929, 15928>,
    <15936, 15928, 15927>,
    <15936, 15927, 15938>,
    <15936, 15938, 15939>,
    <15936, 15939, 15937>,
    <15940, 15935, 15934>,
    <15940, 15934, 15937>,
    <15940, 15937, 15939>,
    <15940, 15939, 15941>,
    <15940, 15941, 15831>,
    <15940, 15831, 15830>,
    <15940, 15830, 15827>,
    <15940, 15827, 15935>,
    <15942, 15943, 15944>,
    <15942, 15944, 15945>,
    <15942, 15945, 15946>,
    <15942, 15946, 15947>,
    <15942, 15947, 15948>,
    <15942, 15948, 15949>,
    <15942, 15949, 15950>,
    <15942, 15950, 15943>,
    <15951, 15952, 15944>,
    <15951, 15944, 15943>,
    <15951, 15943, 15950>,
    <15951, 15950, 15953>,
    <15951, 15953, 14968>,
    <15951, 14968, 15868>,
    <15951, 15868, 15865>,
    <15951, 15865, 15952>,
    <15954, 15945, 15944>,
    <15954, 15944, 15952>,
    <15954, 15952, 15865>,
    <15954, 15865, 15864>,
    <15954, 15864, 15852>,
    <15954, 15852, 15955>,
    <15954, 15955, 15946>,
    <15954, 15946, 15945>,
    <15956, 15957, 15958>,
    <15956, 15958, 15959>,
    <15956, 15959, 15950>,
    <15956, 15950, 15949>,
    <15956, 15949, 15948>,
    <15956, 15948, 15960>,
    <15956, 15960, 15961>,
    <15956, 15961, 15957>,
    <15962, 15963, 15958>,
    <15962, 15958, 15957>,
    <15962, 15957, 15961>,
    <15962, 15961, 15964>,
    <15962, 15964, 15064>,
    <15962, 15064, 15063>,
    <15962, 15063, 15062>,
    <15962, 15062, 15963>,
    <15965, 15959, 15958>,
    <15965, 15958, 15963>,
    <15965, 15963, 15062>,
    <15965, 15062, 15071>,
    <15965, 15071, 14968>,
    <15965, 14968, 15953>,
    <15965, 15953, 15950>,
    <15965, 15950, 15959>,
    <15966, 15967, 15968>,
    <15966, 15968, 15969>,
    <15966, 15969, 15970>,
    <15966, 15970, 15971>,
    <15966, 15971, 15209>,
    <15966, 15209, 15220>,
    <15966, 15220, 15218>,
    <15966, 15218, 15967>,
    <15972, 15973, 15968>,
    <15972, 15968, 15967>,
    <15972, 15967, 15218>,
    <15972, 15218, 15217>,
    <15972, 15217, 15094>,
    <15972, 15094, 15974>,
    <15972, 15974, 15975>,
    <15972, 15975, 15973>,
    <15976, 15969, 15968>,
    <15976, 15968, 15973>,
    <15976, 15973, 15975>,
    <15976, 15975, 15977>,
    <15976, 15977, 15978>,
    <15976, 15978, 15979>,
    <15976, 15979, 15970>,
    <15976, 15970, 15969>,
    <15980, 15981, 15982>,
    <15980, 15982, 15983>,
    <15980, 15983, 15975>,
    <15980, 15975, 15974>,
    <15980, 15974, 15094>,
    <15980, 15094, 15875>,
    <15980, 15875, 15874>,
    <15980, 15874, 15981>,
    <15984, 15985, 15982>,
    <15984, 15982, 15981>,
    <15984, 15981, 15874>,
    <15984, 15874, 15883>,
    <15984, 15883, 15882>,
    <15984, 15882, 15986>,
    <15984, 15986, 15987>,
    <15984, 15987, 15985>,
    <15988, 15983, 15982>,
    <15988, 15982, 15985>,
    <15988, 15985, 15987>,
    <15988, 15987, 15989>,
    <15988, 15989, 15978>,
    <15988, 15978, 15977>,
    <15988, 15977, 15975>,
    <15988, 15975, 15983>,
    <15990, 15991, 15992>,
    <15990, 15992, 15993>,
    <15990, 15993, 15994>,
    <15990, 15994, 15995>,
    <15990, 15995, 15996>,
    <15990, 15996, 15997>,
    <15990, 15997, 15998>,
    <15990, 15998, 15991>,
    <15999, 16000, 15992>,
    <15999, 15992, 15991>,
    <15999, 15991, 15998>,
    <15999, 15998, 16001>,
    <15999, 16001, 15900>,
    <15999, 15900, 15913>,
    <15999, 15913, 15912>,
    <15999, 15912, 16000>,
    <16002, 15993, 15992>,
    <16002, 15992, 16000>,
    <16002, 16000, 15912>,
    <16002, 15912, 15917>,
    <16002, 15917, 15016>,
    <16002, 15016, 16003>,
    <16002, 16003, 15994>,
    <16002, 15994, 15993>,
    <16004, 16005, 16006>,
    <16004, 16006, 16007>,
    <16004, 16007, 16008>,
    <16004, 16008, 16009>,
    <16004, 16009, 15996>,
    <16004, 15996, 15995>,
    <16004, 15995, 15994>,
    <16004, 15994, 16005>,
    <16010, 16011, 16006>,
    <16010, 16006, 16005>,
    <16010, 16005, 15994>,
    <16010, 15994, 16003>,
    <16010, 16003, 15016>,
    <16010, 15016, 15117>,
    <16010, 15117, 15114>,
    <16010, 15114, 16011>,
    <16012, 16007, 16006>,
    <16012, 16006, 16011>,
    <16012, 16011, 15114>,
    <16012, 15114, 15113>,
    <16012, 15113, 15112>,
    <16012, 15112, 16013>,
    <16012, 16013, 16008>,
    <16012, 16008, 16007>,
    <16014, 16015, 16016>,
    <16014, 16016, 16017>,
    <16014, 16017, 15260>,
    <16014, 15260, 15259>,
    <16014, 15259, 16018>,
    <16014, 16018, 16019>,
    <16014, 16019, 16020>,
    <16014, 16020, 16015>,
    <16021, 16022, 16016>,
    <16021, 16016, 16015>,
    <16021, 16015, 16020>,
    <16021, 16020, 16023>,
    <16021, 16023, 16024>,
    <16021, 16024, 16025>,
    <16021, 16025, 16026>,
    <16021, 16026, 16022>,
    <16027, 16017, 16016>,
    <16027, 16016, 16022>,
    <16027, 16022, 16026>,
    <16027, 16026, 16028>,
    <16027, 16028, 15150>,
    <16027, 15150, 15262>,
    <16027, 15262, 15260>,
    <16027, 15260, 16017>,
    <16029, 16030, 16031>,
    <16029, 16031, 16032>,
    <16029, 16032, 16020>,
    <16029, 16020, 16019>,
    <16029, 16019, 16033>,
    <16029, 16033, 16034>,
    <16029, 16035, 16036>,
    <16029, 16036, 16030>,
    <16037, 16038, 16031>,
    <16037, 16031, 16030>,
    <16037, 16030, 16039>,
    <16037, 16039, 16040>,
    <16037, 16041, 16042>,
    <16037, 16042, 16043>,
    <16037, 16043, 16044>,
    <16037, 16044, 16038>,
    <16045, 16032, 16031>,
    <16045, 16031, 16038>,
    <16045, 16038, 16044>,
    <16045, 16044, 16046>,
    <16045, 16046, 16024>,
    <16045, 16024, 16023>,
    <16045, 16023, 16020>,
    <16045, 16020, 16032>,
    <16047, 16048, 16049>,
    <16047, 16049, 16050>,
    <16047, 16050, 15923>,
    <16047, 15923, 15922>,
    <16047, 15922, 15150>,
    <16047, 15150, 16028>,
    <16047, 16028, 16026>,
    <16047, 16026, 16048>,
    <16051, 16052, 16049>,
    <16051, 16049, 16048>,
    <16051, 16048, 16026>,
    <16051, 16026, 16025>,
    <16051, 16025, 16024>,
    <16051, 16024, 16053>,
    <16051, 16053, 16054>,
    <16051, 16054, 16052>,
    <16055, 16050, 16049>,
    <16055, 16049, 16052>,
    <16055, 16052, 16054>,
    <16055, 16054, 16056>,
    <16055, 16056, 15927>,
    <16055, 15927, 15926>,
    <16055, 15926, 15923>,
    <16055, 15923, 16050>,
    <16057, 16058, 16059>,
    <16057, 16059, 16060>,
    <16057, 16060, 16061>,
    <16057, 16061, 16062>,
    <16057, 16062, 16063>,
    <16057, 16063, 16064>,
    <16057, 16064, 16065>,
    <16057, 16065, 16058>,
    <16066, 16067, 16059>,
    <16066, 16059, 16058>,
    <16066, 16058, 16065>,
    <16066, 16065, 16068>,
    <16066, 16068, 15064>,
    <16066, 15064, 15964>,
    <16066, 15964, 15961>,
    <16066, 15961, 16067>,
    <16069, 16060, 16059>,
    <16069, 16059, 16067>,
    <16069, 16067, 15961>,
    <16069, 15961, 15960>,
    <16069, 15960, 15948>,
    <16069, 15948, 16070>,
    <16069, 16070, 16061>,
    <16069, 16061, 16060>,
    <16071, 16072, 16073>,
    <16071, 16073, 16074>,
    <16071, 16074, 16065>,
    <16071, 16065, 16064>,
    <16071, 16064, 16063>,
    <16071, 16063, 16075>,
    <16071, 16075, 16076>,
    <16071, 16076, 16072>,
    <16077, 16078, 16073>,
    <16077, 16073, 16072>,
    <16077, 16072, 16076>,
    <16077, 16076, 16079>,
    <16077, 16079, 15179>,
    <16077, 15179, 15178>,
    <16077, 15178, 15177>,
    <16077, 15177, 16078>,
    <16080, 16074, 16073>,
    <16080, 16073, 16078>,
    <16080, 16078, 15177>,
    <16080, 15177, 15186>,
    <16080, 15186, 15064>,
    <16080, 15064, 16068>,
    <16080, 16068, 16065>,
    <16080, 16065, 16074>,
    <16081, 16082, 16083>,
    <16081, 16083, 16084>,
    <16081, 16084, 16085>,
    <16081, 16085, 16086>,
    <16081, 16086, 15312>,
    <16081, 15312, 15334>,
    <16081, 15334, 15332>,
    <16081, 15332, 16082>,
    <16087, 16088, 16083>,
    <16087, 16083, 16082>,
    <16087, 16082, 15332>,
    <16087, 15332, 15331>,
    <16087, 15331, 15209>,
    <16087, 15209, 16089>,
    <16087, 16089, 16090>,
    <16087, 16090, 16088>,
    <16091, 16084, 16083>,
    <16091, 16083, 16088>,
    <16091, 16088, 16090>,
    <16091, 16090, 16092>,
    <16091, 16092, 16093>,
    <16091, 16093, 16094>,
    <16091, 16094, 16085>,
    <16091, 16085, 16084>,
    <16095, 16096, 16097>,
    <16095, 16097, 16098>,
    <16095, 16098, 16090>,
    <16095, 16090, 16089>,
    <16095, 16089, 15209>,
    <16095, 15209, 15971>,
    <16095, 15971, 15970>,
    <16095, 15970, 16096>,
    <16099, 16100, 16097>,
    <16099, 16097, 16096>,
    <16099, 16096, 15970>,
    <16099, 15970, 15979>,
    <16099, 15979, 15978>,
    <16099, 15978, 16101>,
    <16099, 16101, 16102>,
    <16099, 16102, 16100>,
    <16103, 16098, 16097>,
    <16103, 16097, 16100>,
    <16103, 16100, 16102>,
    <16103, 16102, 16104>,
    <16103, 16104, 16093>,
    <16103, 16093, 16092>,
    <16103, 16092, 16090>,
    <16103, 16090, 16098>,
    <16105, 16106, 16107>,
    <16105, 16107, 16108>,
    <16105, 16108, 16109>,
    <16105, 16109, 16110>,
    <16105, 16110, 16111>,
    <16105, 16111, 16112>,
    <16105, 16112, 16113>,
    <16105, 16113, 16106>,
    <16114, 16115, 16107>,
    <16114, 16107, 16106>,
    <16114, 16106, 16113>,
    <16114, 16113, 16116>,
    <16114, 16116, 15996>,
    <16114, 15996, 16009>,
    <16114, 16009, 16008>,
    <16114, 16008, 16115>,
    <16117, 16108, 16107>,
    <16117, 16107, 16115>,
    <16117, 16115, 16008>,
    <16117, 16008, 16013>,
    <16117, 16013, 15112>,
    <16117, 15112, 16118>,
    <16117, 16118, 16109>,
    <16117, 16109, 16108>,
    <16119, 16120, 16121>,
    <16119, 16121, 16122>,
    <16119, 16122, 16123>,
    <16119, 16123, 16124>,
    <16119, 16124, 16111>,
    <16119, 16111, 16110>,
    <16119, 16110, 16109>,
    <16119, 16109, 16120>,
    <16125, 16126, 16121>,
    <16125, 16121, 16120>,
    <16125, 16120, 16109>,
    <16125, 16109, 16118>,
    <16125, 16118, 15112>,
    <16125, 15112, 15232>,
    <16125, 15232, 15229>,
    <16125, 15229, 16126>,
    <16127, 16122, 16121>,
    <16127, 16121, 16126>,
    <16127, 16126, 15229>,
    <16127, 15229, 15228>,
    <16127, 15228, 15227>,
    <16127, 15227, 16128>,
    <16127, 16128, 16123>,
    <16127, 16123, 16122>,
    <16129, 16130, 16131>,
    <16129, 16131, 16132>,
    <16129, 16132, 16044>,
    <16129, 16044, 16043>,
    <16129, 16043, 16133>,
    <16129, 16133, 16134>,
    <16129, 16135, 16136>,
    <16129, 16136, 16130>,
    <16137, 16138, 16131>,
    <16137, 16131, 16130>,
    <16137, 16130, 16139>,
    <16137, 16139, 16140>,
    <16137, 16141, 16142>,
    <16137, 16142, 16143>,
    <16137, 16143, 16144>,
    <16137, 16144, 16138>,
    <16145, 16132, 16131>,
    <16145, 16131, 16138>,
    <16145, 16138, 16144>,
    <16145, 16144, 16146>,
    <16145, 16146, 16024>,
    <16145, 16024, 16046>,
    <16145, 16046, 16044>,
    <16145, 16044, 16132>,
    <16147, 16148, 16149>,
    <16147, 16149, 16150>,
    <16147, 16150, 16151>,
    <16147, 16151, 16152>,
    <16147, 16152, 16153>,
    <16147, 16153, 16154>,
    <16147, 16154, 16155>,
    <16147, 16155, 16148>,
    <16156, 16157, 16149>,
    <16156, 16149, 16148>,
    <16156, 16148, 16155>,
    <16156, 16155, 16158>,
    <16156, 16158, 15179>,
    <16156, 15179, 16079>,
    <16156, 16079, 16076>,
    <16156, 16076, 16157>,
    <16159, 16150, 16149>,
    <16159, 16149, 16157>,
    <16159, 16157, 16076>,
    <16159, 16076, 16075>,
    <16159, 16075, 16063>,
    <16159, 16063, 16160>,
    <16159, 16160, 16151>,
    <16159, 16151, 16150>,
    <16161, 16162, 16163>,
    <16161, 16163, 16164>,
    <16161, 16164, 16155>,
    <16161, 16155, 16154>,
    <16161, 16154, 16165>,
    <16161, 16165, 16166>,
    <16161, 16167, 16168>,
    <16161, 16168, 16162>,
    <16169, 16170, 16163>,
    <16169, 16163, 16162>,
    <16169, 16162, 16171>,
    <16169, 16171, 16172>,
    <16169, 16173, 16174>,
    <16169, 16174, 15447>,
    <16169, 15447, 15446>,
    <16169, 15446, 16170>,
    <16175, 16164, 16163>,
    <16175, 16163, 16170>,
    <16175, 16170, 15446>,
    <16175, 15446, 15459>,
    <16175, 15459, 15179>,
    <16175, 15179, 16158>,
    <16175, 16158, 16155>,
    <16175, 16155, 16164>,
    <16176, 16177, 16178>,
    <16176, 16178, 16179>,
    <16176, 16179, 16180>,
    <16176, 16180, 16181>,
    <16176, 16181, 16182>,
    <16176, 16182, 16183>,
    <16176, 16184, 16185>,
    <16176, 16185, 16177>,
    <16186, 16187, 16178>,
    <16186, 16178, 16177>,
    <16186, 16177, 16188>,
    <16186, 16188, 16189>,
    <16186, 16190, 16191>,
    <16186, 16191, 16192>,
    <16186, 16192, 16193>,
    <16186, 16193, 16187>,
    <16194, 16179, 16178>,
    <16194, 16178, 16187>,
    <16194, 16187, 16193>,
    <16194, 16193, 16195>,
    <16194, 16195, 16196>,
    <16194, 16196, 16197>,
    <16194, 16197, 16180>,
    <16194, 16180, 16179>,
    <16198, 16199, 16200>,
    <16198, 16200, 16201>,
    <16198, 16201, 16193>,
    <16198, 16193, 16192>,
    <16198, 16192, 16202>,
    <16198, 16202, 15429>,
    <16198, 15429, 15428>,
    <16198, 15428, 16199>,
    <16203, 16204, 16200>,
    <16203, 16200, 16199>,
    <16203, 16199, 15428>,
    <16203, 15428, 15441>,
    <16203, 15441, 15312>,
    <16203, 15312, 16205>,
    <16203, 16205, 16206>,
    <16203, 16206, 16204>,
    <16207, 16201, 16200>,
    <16207, 16200, 16204>,
    <16207, 16204, 16206>,
    <16207, 16206, 16208>,
    <16207, 16208, 16196>,
    <16207, 16196, 16195>,
    <16207, 16195, 16193>,
    <16207, 16193, 16201>,
    <16209, 16210, 16211>,
    <16209, 16211, 16212>,
    <16209, 16212, 16206>,
    <16209, 16206, 16205>,
    <16209, 16205, 15312>,
    <16209, 15312, 16086>,
    <16209, 16086, 16085>,
    <16209, 16085, 16210>,
    <16213, 16214, 16211>,
    <16213, 16211, 16210>,
    <16213, 16210, 16085>,
    <16213, 16085, 16094>,
    <16213, 16094, 16093>,
    <16213, 16093, 16215>,
    <16213, 16215, 16216>,
    <16213, 16216, 16214>,
    <16217, 16212, 16211>,
    <16217, 16211, 16214>,
    <16217, 16214, 16216>,
    <16217, 16216, 16218>,
    <16217, 16218, 16196>,
    <16217, 16196, 16208>,
    <16217, 16208, 16206>,
    <16217, 16206, 16212>,
    <16219, 16220, 16221>,
    <16219, 16221, 16222>,
    <16219, 16222, 16223>,
    <16219, 16223, 16224>,
    <16219, 16224, 16225>,
    <16219, 16225, 16226>,
    <16219, 16227, 16228>,
    <16219, 16228, 16220>,
    <16229, 16230, 16221>,
    <16229, 16221, 16220>,
    <16229, 16220, 16231>,
    <16229, 16231, 16232>,
    <16229, 16233, 16234>,
    <16229, 16234, 16235>,
    <16229, 16235, 16236>,
    <16229, 16236, 16230>,
    <16237, 16222, 16221>,
    <16237, 16221, 16230>,
    <16237, 16230, 16236>,
    <16237, 16236, 16238>,
    <16237, 16238, 16239>,
    <16237, 16239, 16240>,
    <16237, 16240, 16223>,
    <16237, 16223, 16222>,
    <16241, 16242, 16243>,
    <16241, 16243, 16244>,
    <16241, 16244, 16245>,
    <16241, 16245, 16246>,
    <16241, 16246, 16239>,
    <16241, 16239, 16247>,
    <16241, 16247, 16248>,
    <16241, 16248, 16242>,
    <16249, 16250, 16243>,
    <16249, 16243, 16242>,
    <16249, 16242, 16248>,
    <16249, 16248, 16251>,
    <16249, 16251, 16111>,
    <16249, 16111, 16124>,
    <16249, 16124, 16123>,
    <16249, 16123, 16250>,
    <16252, 16244, 16243>,
    <16252, 16243, 16250>,
    <16252, 16250, 16123>,
    <16252, 16123, 16128>,
    <16252, 16128, 15227>,
    <16252, 15227, 16253>,
    <16252, 16253, 16245>,
    <16252, 16245, 16244>,
    <16254, 16255, 16256>,
    <16254, 16256, 16257>,
    <16254, 16257, 15469>,
    <16254, 15469, 15468>,
    <16254, 15468, 16258>,
    <16254, 16258, 16224>,
    <16254, 16224, 16223>,
    <16254, 16223, 16255>,
    <16259, 16260, 16256>,
    <16259, 16256, 16255>,
    <16259, 16255, 16223>,
    <16259, 16223, 16240>,
    <16259, 16240, 16239>,
    <16259, 16239, 16261>,
    <16259, 16261, 16262>,
    <16259, 16262, 16260>,
    <16263, 16257, 16256>,
    <16263, 16256, 16260>,
    <16263, 16260, 16262>,
    <16263, 16262, 16264>,
    <16263, 16264, 15355>,
    <16263, 15355, 15472>,
    <16263, 15472, 15469>,
    <16263, 15469, 16257>,
    <16265, 16266, 16267>,
    <16265, 16267, 16268>,
    <16265, 16268, 16262>,
    <16265, 16262, 16261>,
    <16265, 16261, 16239>,
    <16265, 16239, 16246>,
    <16265, 16246, 16245>,
    <16265, 16245, 16266>,
    <16269, 16270, 16267>,
    <16269, 16267, 16266>,
    <16269, 16266, 16245>,
    <16269, 16245, 16253>,
    <16269, 16253, 15227>,
    <16269, 15227, 15367>,
    <16269, 15367, 15364>,
    <16269, 15364, 16270>,
    <16271, 16268, 16267>,
    <16271, 16267, 16270>,
    <16271, 16270, 15364>,
    <16271, 15364, 15363>,
    <16271, 15363, 15355>,
    <16271, 15355, 16264>,
    <16271, 16264, 16262>,
    <16271, 16262, 16268>,
    <16272, 16273, 16274>,
    <16272, 16274, 16275>,
    <16272, 16275, 16236>,
    <16272, 16236, 16235>,
    <16272, 16235, 16276>,
    <16272, 16276, 16277>,
    <16272, 16278, 16279>,
    <16272, 16279, 16273>,
    <16280, 16281, 16274>,
    <16280, 16274, 16273>,
    <16280, 16273, 16282>,
    <16280, 16282, 16283>,
    <16280, 16284, 16285>,
    <16280, 16285, 16286>,
    <16280, 16286, 16287>,
    <16280, 16287, 16281>,
    <16288, 16275, 16274>,
    <16288, 16274, 16281>,
    <16288, 16281, 16287>,
    <16288, 16287, 16289>,
    <16288, 16289, 16239>,
    <16288, 16239, 16238>,
    <16288, 16238, 16236>,
    <16288, 16236, 16275>,
    <16290, 16291, 16292>,
    <16290, 16292, 16293>,
    <16290, 16293, 16294>,
    <16290, 16294, 16295>,
    <16290, 16296, 16297>,
    <16290, 16297, 16181>,
    <16290, 16181, 16180>,
    <16290, 16180, 16291>,
    <16298, 16299, 16292>,
    <16298, 16292, 16291>,
    <16298, 16291, 16180>,
    <16298, 16180, 16197>,
    <16298, 16197, 16196>,
    <16298, 16196, 16300>,
    <16298, 16300, 16301>,
    <16298, 16301, 16299>,
    <16302, 16293, 16292>,
    <16302, 16292, 16299>,
    <16302, 16299, 16301>,
    <16302, 16301, 16303>,
    <16302, 16303, 16304>,
    <16302, 16304, 16305>,
    <16302, 16306, 16307>,
    <16302, 16307, 16293>,
    <16308, 16309, 16310>,
    <16308, 16310, 16311>,
    <16308, 16311, 16312>,
    <16308, 16312, 16313>,
    <16308, 16313, 16314>,
    <16308, 16314, 16315>,
    <16308, 16316, 16317>,
    <16308, 16317, 16309>,
    <16318, 16319, 16310>,
    <16318, 16310, 16309>,
    <16318, 16309, 16320>,
    <16318, 16320, 16321>,
    <16318, 16322, 16323>,
    <16318, 16323, 16303>,
    <16318, 16303, 16301>,
    <16318, 16301, 16319>,
    <16324, 16311, 16310>,
    <16324, 16310, 16319>,
    <16324, 16319, 16301>,
    <16324, 16301, 16300>,
    <16324, 16300, 16196>,
    <16324, 16196, 16325>,
    <16324, 16325, 16312>,
    <16324, 16312, 16311>,
    <16326, 16327, 16328>,
    <16326, 16328, 16329>,
    <16326, 16329, 16330>,
    <16326, 16330, 16331>,
    <16326, 16331, 16332>,
    <16326, 16332, 16333>,
    <16326, 16334, 16335>,
    <16326, 16335, 16327>,
    <16336, 16337, 16328>,
    <16336, 16328, 16327>,
    <16336, 16327, 16338>,
    <16336, 16338, 16339>,
    <16336, 16340, 16341>,
    <16336, 16341, 16152>,
    <16336, 16152, 16151>,
    <16336, 16151, 16337>,
    <16342, 16329, 16328>,
    <16342, 16328, 16337>,
    <16342, 16337, 16151>,
    <16342, 16151, 16160>,
    <16342, 16160, 16063>,
    <16342, 16063, 16343>,
    <16342, 16343, 16330>,
    <16342, 16330, 16329>,
    <16344, 16345, 16346>,
    <16344, 16346, 16347>,
    <16344, 16347, 16348>,
    <16344, 16348, 16349>,
    <16344, 16350, 16351>,
    <16344, 16351, 16352>,
    <16344, 16352, 16353>,
    <16344, 16353, 16345>,
    <16354, 16355, 16346>,
    <16354, 16346, 16345>,
    <16354, 16345, 16353>,
    <16354, 16353, 16356>,
    <16354, 16356, 16239>,
    <16354, 16239, 16289>,
    <16354, 16289, 16287>,
    <16354, 16287, 16355>,
    <16357, 16347, 16346>,
    <16357, 16346, 16355>,
    <16357, 16355, 16287>,
    <16357, 16287, 16286>,
    <16357, 16286, 16358>,
    <16357, 16358, 16359>,
    <16357, 16360, 16361>,
    <16357, 16361, 16347>,
    <16362, 16363, 16364>,
    <16362, 16364, 16365>,
    <16362, 16365, 15517>,
    <16362, 15517, 15516>,
    <16362, 15516, 15505>,
    <16362, 15505, 16366>,
    <16362, 16366, 16367>,
    <16362, 16367, 16363>,
    <16368, 16369, 16364>,
    <16368, 16364, 16363>,
    <16368, 16363, 16367>,
    <16368, 16367, 16370>,
    <16368, 16370, 16371>,
    <16368, 16371, 16372>,
    <16368, 16373, 16374>,
    <16368, 16374, 16369>,
    <16375, 16365, 16364>,
    <16375, 16364, 16369>,
    <16375, 16369, 16376>,
    <16375, 16376, 16377>,
    <16375, 16378, 16379>,
    <16375, 16379, 15519>,
    <16375, 15519, 15517>,
    <16375, 15517, 16365>,
    <16380, 16381, 16382>,
    <16380, 16382, 16383>,
    <16380, 16383, 15575>,
    <16380, 15575, 15574>,
    <16380, 15574, 15563>,
    <16380, 15563, 16384>,
    <16380, 16384, 16385>,
    <16380, 16385, 16381>,
    <16386, 16387, 16382>,
    <16386, 16382, 16381>,
    <16386, 16381, 16385>,
    <16386, 16385, 16388>,
    <16386, 16388, 16389>,
    <16386, 16389, 16390>,
    <16386, 16390, 16391>,
    <16386, 16391, 16387>,
    <16392, 16383, 16382>,
    <16392, 16382, 16387>,
    <16392, 16387, 16391>,
    <16392, 16391, 16393>,
    <16392, 16393, 15505>,
    <16392, 15505, 15577>,
    <16392, 15577, 15575>,
    <16392, 15575, 16383>,
    <16394, 16395, 16396>,
    <16394, 16396, 16397>,
    <16394, 16397, 16367>,
    <16394, 16367, 16366>,
    <16394, 16366, 15505>,
    <16394, 15505, 16393>,
    <16394, 16393, 16391>,
    <16394, 16391, 16395>,
    <16398, 16399, 16396>,
    <16398, 16396, 16395>,
    <16398, 16395, 16391>,
    <16398, 16391, 16390>,
    <16398, 16390, 16389>,
    <16398, 16389, 16400>,
    <16398, 16400, 16401>,
    <16398, 16401, 16399>,
    <16402, 16397, 16396>,
    <16402, 16396, 16399>,
    <16402, 16399, 16401>,
    <16402, 16401, 16403>,
    <16402, 16403, 16404>,
    <16402, 16404, 16370>,
    <16402, 16370, 16367>,
    <16402, 16367, 16397>,
    <16405, 16406, 16407>,
    <16405, 16407, 16408>,
    <16405, 16408, 16409>,
    <16405, 16409, 16410>,
    <16405, 16410, 16411>,
    <16405, 16411, 16412>,
    <16405, 16412, 16413>,
    <16405, 16413, 16406>,
    <16414, 16415, 16407>,
    <16414, 16407, 16406>,
    <16414, 16406, 16413>,
    <16414, 16413, 16416>,
    <16414, 16416, 16417>,
    <16414, 16417, 16418>,
    <16414, 16419, 16420>,
    <16414, 16420, 16415>,
    <16421, 16408, 16407>,
    <16421, 16407, 16415>,
    <16421, 16415, 16422>,
    <16421, 16422, 16423>,
    <16421, 16424, 16425>,
    <16421, 16425, 16426>,
    <16421, 16426, 16409>,
    <16421, 16409, 16408>,
    <16427, 16428, 16429>,
    <16427, 16429, 16430>,
    <16427, 16430, 16413>,
    <16427, 16413, 16412>,
    <16427, 16412, 16411>,
    <16427, 16411, 16431>,
    <16427, 16431, 16432>,
    <16427, 16432, 16428>,
    <16433, 16434, 16429>,
    <16433, 16429, 16428>,
    <16433, 16428, 16432>,
    <16433, 16432, 16435>,
    <16433, 16435, 15527>,
    <16433, 15527, 15526>,
    <16433, 15526, 15525>,
    <16433, 15525, 16434>,
    <16436, 16430, 16429>,
    <16436, 16429, 16434>,
    <16436, 16434, 15525>,
    <16436, 15525, 15542>,
    <16436, 15542, 16437>,
    <16436, 16437, 16416>,
    <16436, 16416, 16413>,
    <16436, 16413, 16430>,
    <16438, 16439, 16440>,
    <16438, 16440, 16441>,
    <16438, 16441, 15699>,
    <16438, 15699, 15698>,
    <16438, 15698, 15687>,
    <16438, 15687, 16442>,
    <16438, 16442, 16443>,
    <16438, 16443, 16439>,
    <16444, 16445, 16440>,
    <16444, 16440, 16439>,
    <16444, 16439, 16443>,
    <16444, 16443, 16446>,
    <16444, 16446, 16447>,
    <16444, 16447, 16448>,
    <16444, 16448, 16449>,
    <16444, 16449, 16445>,
    <16450, 16441, 16440>,
    <16450, 16440, 16445>,
    <16450, 16445, 16449>,
    <16450, 16449, 16451>,
    <16450, 16451, 15563>,
    <16450, 15563, 15701>,
    <16450, 15701, 15699>,
    <16450, 15699, 16441>,
    <16452, 16453, 16454>,
    <16452, 16454, 16455>,
    <16452, 16455, 16385>,
    <16452, 16385, 16384>,
    <16452, 16384, 15563>,
    <16452, 15563, 16451>,
    <16452, 16451, 16449>,
    <16452, 16449, 16453>,
    <16456, 16457, 16454>,
    <16456, 16454, 16453>,
    <16456, 16453, 16449>,
    <16456, 16449, 16448>,
    <16456, 16448, 16447>,
    <16456, 16447, 16458>,
    <16456, 16458, 16459>,
    <16456, 16459, 16457>,
    <16460, 16455, 16454>,
    <16460, 16454, 16457>,
    <16460, 16457, 16459>,
    <16460, 16459, 16461>,
    <16460, 16461, 16389>,
    <16460, 16389, 16388>,
    <16460, 16388, 16385>,
    <16460, 16385, 16455>,
    <16462, 16463, 16464>,
    <16462, 16464, 16465>,
    <16462, 16465, 16466>,
    <16462, 16466, 16467>,
    <16462, 16467, 16468>,
    <16462, 16468, 16469>,
    <16462, 16469, 16470>,
    <16462, 16470, 16463>,
    <16471, 16472, 16464>,
    <16471, 16464, 16463>,
    <16471, 16463, 16470>,
    <16471, 16470, 16473>,
    <16471, 16473, 15527>,
    <16471, 15527, 16435>,
    <16471, 16435, 16432>,
    <16471, 16432, 16472>,
    <16474, 16465, 16464>,
    <16474, 16464, 16472>,
    <16474, 16472, 16432>,
    <16474, 16432, 16431>,
    <16474, 16431, 16411>,
    <16474, 16411, 16475>,
    <16474, 16475, 16466>,
    <16474, 16466, 16465>,
    <16476, 16477, 16478>,
    <16476, 16478, 16479>,
    <16476, 16479, 16470>,
    <16476, 16470, 16469>,
    <16476, 16469, 16468>,
    <16476, 16468, 16480>,
    <16476, 16480, 16481>,
    <16476, 16481, 16477>,
    <16482, 16483, 16478>,
    <16482, 16478, 16477>,
    <16482, 16477, 16481>,
    <16482, 16481, 16484>,
    <16482, 16484, 15584>,
    <16482, 15584, 15583>,
    <16482, 15583, 15582>,
    <16482, 15582, 16483>,
    <16485, 16479, 16478>,
    <16485, 16478, 16483>,
    <16485, 16483, 15582>,
    <16485, 15582, 15591>,
    <16485, 15591, 15527>,
    <16485, 15527, 16473>,
    <16485, 16473, 16470>,
    <16485, 16470, 16479>,
    <16486, 16487, 16488>,
    <16486, 16488, 16489>,
    <16486, 16489, 16490>,
    <16486, 16490, 16491>,
    <16486, 16491, 15632>,
    <16486, 15632, 15644>,
    <16486, 15644, 15642>,
    <16486, 15642, 16487>,
    <16492, 16493, 16488>,
    <16492, 16488, 16487>,
    <16492, 16487, 15642>,
    <16492, 15642, 15641>,
    <16492, 15641, 16494>,
    <16492, 16494, 16495>,
    <16492, 16496, 16497>,
    <16492, 16497, 16493>,
    <16498, 16489, 16488>,
    <16498, 16488, 16493>,
    <16498, 16493, 16499>,
    <16498, 16499, 16500>,
    <16498, 16501, 16502>,
    <16498, 16502, 16503>,
    <16498, 16503, 16490>,
    <16498, 16490, 16489>,
    <16504, 16505, 16506>,
    <16504, 16506, 16507>,
    <16504, 16507, 16508>,
    <16504, 16508, 16509>,
    <16504, 16509, 15738>,
    <16504, 15738, 15749>,
    <16504, 15749, 15747>,
    <16504, 15747, 16505>,
    <16510, 16511, 16506>,
    <16510, 16506, 16505>,
    <16510, 16505, 15747>,
    <16510, 15747, 15746>,
    <16510, 15746, 15632>,
    <16510, 15632, 16512>,
    <16510, 16512, 16513>,
    <16510, 16513, 16511>,
    <16514, 16507, 16506>,
    <16514, 16506, 16511>,
    <16514, 16511, 16513>,
    <16514, 16513, 16515>,
    <16514, 16515, 16516>,
    <16514, 16516, 16517>,
    <16514, 16517, 16508>,
    <16514, 16508, 16507>,
    <16518, 16519, 16520>,
    <16518, 16520, 16521>,
    <16518, 16521, 16513>,
    <16518, 16513, 16512>,
    <16518, 16512, 15632>,
    <16518, 15632, 16491>,
    <16518, 16491, 16490>,
    <16518, 16490, 16519>,
    <16522, 16523, 16520>,
    <16522, 16520, 16519>,
    <16522, 16519, 16490>,
    <16522, 16490, 16503>,
    <16522, 16503, 16524>,
    <16522, 16524, 16525>,
    <16522, 16525, 16526>,
    <16522, 16526, 16523>,
    <16527, 16521, 16520>,
    <16527, 16520, 16523>,
    <16527, 16523, 16526>,
    <16527, 16526, 16528>,
    <16527, 16528, 16516>,
    <16527, 16516, 16515>,
    <16527, 16515, 16513>,
    <16527, 16513, 16521>,
    <16529, 16530, 16531>,
    <16529, 16531, 16532>,
    <16529, 16532, 16533>,
    <16529, 16533, 16534>,
    <16529, 16534, 16535>,
    <16529, 16535, 16536>,
    <16529, 16536, 16537>,
    <16529, 16537, 16530>,
    <16538, 16539, 16531>,
    <16538, 16531, 16530>,
    <16538, 16530, 16537>,
    <16538, 16537, 16540>,
    <16538, 16540, 16541>,
    <16538, 16541, 16542>,
    <16538, 16543, 16544>,
    <16538, 16544, 16539>,
    <16545, 16532, 16531>,
    <16545, 16531, 16539>,
    <16545, 16539, 16546>,
    <16545, 16546, 16547>,
    <16545, 16548, 16549>,
    <16545, 16549, 16550>,
    <16545, 16550, 16533>,
    <16545, 16533, 16532>,
    <16551, 16552, 16553>,
    <16551, 16553, 16554>,
    <16551, 16554, 16555>,
    <16551, 16555, 16556>,
    <16551, 16556, 16535>,
    <16551, 16535, 16534>,
    <16551, 16534, 16533>,
    <16551, 16533, 16552>,
    <16557, 16558, 16553>,
    <16557, 16553, 16552>,
    <16557, 16552, 16533>,
    <16557, 16533, 16550>,
    <16557, 16550, 16559>,
    <16557, 16559, 15656>,
    <16557, 15656, 15653>,
    <16557, 15653, 16558>,
    <16560, 16554, 16553>,
    <16560, 16553, 16558>,
    <16560, 16558, 15653>,
    <16560, 15653, 15652>,
    <16560, 15652, 15651>,
    <16560, 15651, 16561>,
    <16560, 16561, 16555>,
    <16560, 16555, 16554>,
    <16562, 16563, 16564>,
    <16562, 16564, 16565>,
    <16562, 16565, 15843>,
    <16562, 15843, 15842>,
    <16562, 15842, 15831>,
    <16562, 15831, 16566>,
    <16562, 16566, 16567>,
    <16562, 16567, 16563>,
    <16568, 16569, 16564>,
    <16568, 16564, 16563>,
    <16568, 16563, 16567>,
    <16568, 16567, 16570>,
    <16568, 16570, 16571>,
    <16568, 16571, 16572>,
    <16568, 16572, 16573>,
    <16568, 16573, 16569>,
    <16574, 16565, 16564>,
    <16574, 16564, 16569>,
    <16574, 16569, 16573>,
    <16574, 16573, 16575>,
    <16574, 16575, 15687>,
    <16574, 15687, 15845>,
    <16574, 15845, 15843>,
    <16574, 15843, 16565>,
    <16576, 16577, 16578>,
    <16576, 16578, 16579>,
    <16576, 16579, 16443>,
    <16576, 16443, 16442>,
    <16576, 16442, 15687>,
    <16576, 15687, 16575>,
    <16576, 16575, 16573>,
    <16576, 16573, 16577>,
    <16580, 16581, 16578>,
    <16580, 16578, 16577>,
    <16580, 16577, 16573>,
    <16580, 16573, 16572>,
    <16580, 16572, 16571>,
    <16580, 16571, 16582>,
    <16580, 16582, 16583>,
    <16580, 16583, 16581>,
    <16584, 16579, 16578>,
    <16584, 16578, 16581>,
    <16584, 16581, 16583>,
    <16584, 16583, 16585>,
    <16584, 16585, 16447>,
    <16584, 16447, 16446>,
    <16584, 16446, 16443>,
    <16584, 16443, 16579>,
    <16586, 16587, 16588>,
    <16586, 16588, 16589>,
    <16586, 16589, 16590>,
    <16586, 16590, 16591>,
    <16586, 16591, 16592>,
    <16586, 16592, 16593>,
    <16586, 16593, 16594>,
    <16586, 16594, 16587>,
    <16595, 16596, 16588>,
    <16595, 16588, 16587>,
    <16595, 16587, 16594>,
    <16595, 16594, 16597>,
    <16595, 16597, 15584>,
    <16595, 15584, 16484>,
    <16595, 16484, 16481>,
    <16595, 16481, 16596>,
    <16598, 16589, 16588>,
    <16598, 16588, 16596>,
    <16598, 16596, 16481>,
    <16598, 16481, 16480>,
    <16598, 16480, 16468>,
    <16598, 16468, 16599>,
    <16598, 16599, 16590>,
    <16598, 16590, 16589>,
    <16600, 16601, 16602>,
    <16600, 16602, 16603>,
    <16600, 16603, 16594>,
    <16600, 16594, 16593>,
    <16600, 16593, 16592>,
    <16600, 16592, 16604>,
    <16600, 16604, 16605>,
    <16600, 16605, 16601>,
    <16606, 16607, 16602>,
    <16606, 16602, 16601>,
    <16606, 16601, 16605>,
    <16606, 16605, 16608>,
    <16606, 16608, 15708>,
    <16606, 15708, 15707>,
    <16606, 15707, 15706>,
    <16606, 15706, 16607>,
    <16609, 16603, 16602>,
    <16609, 16602, 16607>,
    <16609, 16607, 15706>,
    <16609, 15706, 15715>,
    <16609, 15715, 15584>,
    <16609, 15584, 16597>,
    <16609, 16597, 16594>,
    <16609, 16594, 16603>,
    <16610, 16611, 16612>,
    <16610, 16612, 16613>,
    <16610, 16613, 16614>,
    <16610, 16614, 16615>,
    <16610, 16615, 15786>,
    <16610, 15786, 15797>,
    <16610, 15797, 15795>,
    <16610, 15795, 16611>,
    <16616, 16617, 16612>,
    <16616, 16612, 16611>,
    <16616, 16611, 15795>,
    <16616, 15795, 15794>,
    <16616, 15794, 15738>,
    <16616, 15738, 16618>,
    <16616, 16618, 16619>,
    <16616, 16619, 16617>,
    <16620, 16613, 16612>,
    <16620, 16612, 16617>,
    <16620, 16617, 16619>,
    <16620, 16619, 16621>,
    <16620, 16621, 16622>,
    <16620, 16622, 16623>,
    <16620, 16623, 16614>,
    <16620, 16614, 16613>,
    <16624, 16625, 16626>,
    <16624, 16626, 16627>,
    <16624, 16627, 16619>,
    <16624, 16619, 16618>,
    <16624, 16618, 15738>,
    <16624, 15738, 16509>,
    <16624, 16509, 16508>,
    <16624, 16508, 16625>,
    <16628, 16629, 16626>,
    <16628, 16626, 16625>,
    <16628, 16625, 16508>,
    <16628, 16508, 16517>,
    <16628, 16517, 16516>,
    <16628, 16516, 16630>,
    <16628, 16630, 16631>,
    <16628, 16631, 16629>,
    <16632, 16627, 16626>,
    <16632, 16626, 16629>,
    <16632, 16629, 16631>,
    <16632, 16631, 16633>,
    <16632, 16633, 16622>,
    <16632, 16622, 16621>,
    <16632, 16621, 16619>,
    <16632, 16619, 16627>,
    <16634, 16635, 16636>,
    <16634, 16636, 16637>,
    <16634, 16637, 16638>,
    <16634, 16638, 16639>,
    <16634, 16639, 16640>,
    <16634, 16640, 16641>,
    <16634, 16641, 16642>,
    <16634, 16642, 16635>,
    <16643, 16644, 16636>,
    <16643, 16636, 16635>,
    <16643, 16635, 16642>,
    <16643, 16642, 16645>,
    <16643, 16645, 16535>,
    <16643, 16535, 16556>,
    <16643, 16556, 16555>,
    <16643, 16555, 16644>,
    <16646, 16637, 16636>,
    <16646, 16636, 16644>,
    <16646, 16644, 16555>,
    <16646, 16555, 16561>,
    <16646, 16561, 15651>,
    <16646, 15651, 16647>,
    <16646, 16647, 16638>,
    <16646, 16638, 16637>,
    <16648, 16649, 16650>,
    <16648, 16650, 16651>,
    <16648, 16651, 16652>,
    <16648, 16652, 16653>,
    <16648, 16653, 16640>,
    <16648, 16640, 16639>,
    <16648, 16639, 16638>,
    <16648, 16638, 16649>,
    <16654, 16655, 16650>,
    <16654, 16650, 16649>,
    <16654, 16649, 16638>,
    <16654, 16638, 16647>,
    <16654, 16647, 15651>,
    <16654, 15651, 15761>,
    <16654, 15761, 15758>,
    <16654, 15758, 16655>,
    <16656, 16651, 16650>,
    <16656, 16650, 16655>,
    <16656, 16655, 15758>,
    <16656, 15758, 15757>,
    <16656, 15757, 15756>,
    <16656, 15756, 16657>,
    <16656, 16657, 16652>,
    <16656, 16652, 16651>,
    <16658, 16659, 16660>,
    <16658, 16660, 16661>,
    <16658, 16661, 16662>,
    <16658, 16662, 16663>,
    <16658, 16663, 15882>,
    <16658, 15882, 15893>,
    <16658, 15893, 15891>,
    <16658, 15891, 16659>,
    <16664, 16665, 16660>,
    <16664, 16660, 16659>,
    <16664, 16659, 15891>,
    <16664, 15891, 15890>,
    <16664, 15890, 15786>,
    <16664, 15786, 16666>,
    <16664, 16666, 16667>,
    <16664, 16667, 16665>,
    <16668, 16661, 16660>,
    <16668, 16660, 16665>,
    <16668, 16665, 16667>,
    <16668, 16667, 16669>,
    <16668, 16669, 16670>,
    <16668, 16670, 16671>,
    <16668, 16671, 16662>,
    <16668, 16662, 16661>,
    <16672, 16673, 16674>,
    <16672, 16674, 16675>,
    <16672, 16675, 16667>,
    <16672, 16667, 16666>,
    <16672, 16666, 15786>,
    <16672, 15786, 16615>,
    <16672, 16615, 16614>,
    <16672, 16614, 16673>,
    <16676, 16677, 16674>,
    <16676, 16674, 16673>,
    <16676, 16673, 16614>,
    <16676, 16614, 16623>,
    <16676, 16623, 16622>,
    <16676, 16622, 16678>,
    <16676, 16678, 16679>,
    <16676, 16679, 16677>,
    <16680, 16675, 16674>,
    <16680, 16674, 16677>,
    <16680, 16677, 16679>,
    <16680, 16679, 16681>,
    <16680, 16681, 16670>,
    <16680, 16670, 16669>,
    <16680, 16669, 16667>,
    <16680, 16667, 16675>,
    <16682, 16683, 16684>,
    <16682, 16684, 16685>,
    <16682, 16685, 16686>,
    <16682, 16686, 16687>,
    <16682, 16687, 16688>,
    <16682, 16688, 16689>,
    <16682, 16689, 16690>,
    <16682, 16690, 16683>,
    <16691, 16692, 16684>,
    <16691, 16684, 16683>,
    <16691, 16683, 16690>,
    <16691, 16690, 16693>,
    <16691, 16693, 16640>,
    <16691, 16640, 16653>,
    <16691, 16653, 16652>,
    <16691, 16652, 16692>,
    <16694, 16685, 16684>,
    <16694, 16684, 16692>,
    <16694, 16692, 16652>,
    <16694, 16652, 16657>,
    <16694, 16657, 15756>,
    <16694, 15756, 16695>,
    <16694, 16695, 16686>,
    <16694, 16686, 16685>,
    <16696, 16697, 16698>,
    <16696, 16698, 16699>,
    <16696, 16699, 16700>,
    <16696, 16700, 16701>,
    <16696, 16701, 16688>,
    <16696, 16688, 16687>,
    <16696, 16687, 16686>,
    <16696, 16686, 16697>,
    <16702, 16703, 16698>,
    <16702, 16698, 16697>,
    <16702, 16697, 16686>,
    <16702, 16686, 16695>,
    <16702, 16695, 15756>,
    <16702, 15756, 15809>,
    <16702, 15809, 15806>,
    <16702, 15806, 16703>,
    <16704, 16699, 16698>,
    <16704, 16698, 16703>,
    <16704, 16703, 15806>,
    <16704, 15806, 15805>,
    <16704, 15805, 15804>,
    <16704, 15804, 16705>,
    <16704, 16705, 16700>,
    <16704, 16700, 16699>,
    <16706, 16707, 16708>,
    <16706, 16708, 16709>,
    <16706, 16709, 15939>,
    <16706, 15939, 15938>,
    <16706, 15938, 15927>,
    <16706, 15927, 16710>,
    <16706, 16710, 16711>,
    <16706, 16711, 16707>,
    <16712, 16713, 16708>,
    <16712, 16708, 16707>,
    <16712, 16707, 16711>,
    <16712, 16711, 16714>,
    <16712, 16714, 16715>,
    <16712, 16715, 16716>,
    <16712, 16716, 16717>,
    <16712, 16717, 16713>,
    <16718, 16709, 16708>,
    <16718, 16708, 16713>,
    <16718, 16713, 16717>,
    <16718, 16717, 16719>,
    <16718, 16719, 15831>,
    <16718, 15831, 15941>,
    <16718, 15941, 15939>,
    <16718, 15939, 16709>,
    <16720, 16721, 16722>,
    <16720, 16722, 16723>,
    <16720, 16723, 16567>,
    <16720, 16567, 16566>,
    <16720, 16566, 15831>,
    <16720, 15831, 16719>,
    <16720, 16719, 16717>,
    <16720, 16717, 16721>,
    <16724, 16725, 16722>,
    <16724, 16722, 16721>,
    <16724, 16721, 16717>,
    <16724, 16717, 16716>,
    <16724, 16716, 16715>,
    <16724, 16715, 16726>,
    <16724, 16726, 16727>,
    <16724, 16727, 16725>,
    <16728, 16723, 16722>,
    <16728, 16722, 16725>,
    <16728, 16725, 16727>,
    <16728, 16727, 16729>,
    <16728, 16729, 16571>,
    <16728, 16571, 16570>,
    <16728, 16570, 16567>,
    <16728, 16567, 16723>,
    <16730, 16731, 16732>,
    <16730, 16732, 16733>,
    <16730, 16733, 16734>,
    <16730, 16734, 16735>,
    <16730, 16735, 16736>,
    <16730, 16736, 16737>,
    <16730, 16737, 16738>,
    <16730, 16738, 16731>,
    <16739, 16740, 16732>,
    <16739, 16732, 16731>,
    <16739, 16731, 16738>,
    <16739, 16738, 16741>,
    <16739, 16741, 15708>,
    <16739, 15708, 16608>,
    <16739, 16608, 16605>,
    <16739, 16605, 16740>,
    <16742, 16733, 16732>,
    <16742, 16732, 16740>,
    <16742, 16740, 16605>,
    <16742, 16605, 16604>,
    <16742, 16604, 16592>,
    <16742, 16592, 16743>,
    <16742, 16743, 16734>,
    <16742, 16734, 16733>,
    <16744, 16745, 16746>,
    <16744, 16746, 16747>,
    <16744, 16747, 16738>,
    <16744, 16738, 16737>,
    <16744, 16737, 16736>,
    <16744, 16736, 16748>,
    <16744, 16748, 16749>,
    <16744, 16749, 16745>,
    <16750, 16751, 16746>,
    <16750, 16746, 16745>,
    <16750, 16745, 16749>,
    <16750, 16749, 16752>,
    <16750, 16752, 15852>,
    <16750, 15852, 15851>,
    <16750, 15851, 15850>,
    <16750, 15850, 16751>,
    <16753, 16747, 16746>,
    <16753, 16746, 16751>,
    <16753, 16751, 15850>,
    <16753, 15850, 15859>,
    <16753, 15859, 15708>,
    <16753, 15708, 16741>,
    <16753, 16741, 16738>,
    <16753, 16738, 16747>,
    <16754, 16755, 16756>,
    <16754, 16756, 16757>,
    <16754, 16757, 16758>,
    <16754, 16758, 16759>,
    <16754, 16759, 15978>,
    <16754, 15978, 15989>,
    <16754, 15989, 15987>,
    <16754, 15987, 16755>,
    <16760, 16761, 16756>,
    <16760, 16756, 16755>,
    <16760, 16755, 15987>,
    <16760, 15987, 15986>,
    <16760, 15986, 15882>,
    <16760, 15882, 16762>,
    <16760, 16762, 16763>,
    <16760, 16763, 16761>,
    <16764, 16757, 16756>,
    <16764, 16756, 16761>,
    <16764, 16761, 16763>,
    <16764, 16763, 16765>,
    <16764, 16765, 16766>,
    <16764, 16766, 16767>,
    <16764, 16767, 16758>,
    <16764, 16758, 16757>,
    <16768, 16769, 16770>,
    <16768, 16770, 16771>,
    <16768, 16771, 16763>,
    <16768, 16763, 16762>,
    <16768, 16762, 15882>,
    <16768, 15882, 16663>,
    <16768, 16663, 16662>,
    <16768, 16662, 16769>,
    <16772, 16773, 16770>,
    <16772, 16770, 16769>,
    <16772, 16769, 16662>,
    <16772, 16662, 16671>,
    <16772, 16671, 16670>,
    <16772, 16670, 16774>,
    <16772, 16774, 16775>,
    <16772, 16775, 16773>,
    <16776, 16771, 16770>,
    <16776, 16770, 16773>,
    <16776, 16773, 16775>,
    <16776, 16775, 16777>,
    <16776, 16777, 16766>,
    <16776, 16766, 16765>,
    <16776, 16765, 16763>,
    <16776, 16763, 16771>,
    <16778, 16779, 16780>,
    <16778, 16780, 16781>,
    <16778, 16781, 16782>,
    <16778, 16782, 16783>,
    <16778, 16783, 16784>,
    <16778, 16784, 16785>,
    <16778, 16785, 16786>,
    <16778, 16786, 16779>,
    <16787, 16788, 16780>,
    <16787, 16780, 16779>,
    <16787, 16779, 16786>,
    <16787, 16786, 16789>,
    <16787, 16789, 16688>,
    <16787, 16688, 16701>,
    <16787, 16701, 16700>,
    <16787, 16700, 16788>,
    <16790, 16781, 16780>,
    <16790, 16780, 16788>,
    <16790, 16788, 16700>,
    <16790, 16700, 16705>,
    <16790, 16705, 15804>,
    <16790, 15804, 16791>,
    <16790, 16791, 16782>,
    <16790, 16782, 16781>,
    <16792, 16793, 16794>,
    <16792, 16794, 16795>,
    <16792, 16795, 16796>,
    <16792, 16796, 16797>,
    <16792, 16797, 16784>,
    <16792, 16784, 16783>,
    <16792, 16783, 16782>,
    <16792, 16782, 16793>,
    <16798, 16799, 16794>,
    <16798, 16794, 16793>,
    <16798, 16793, 16782>,
    <16798, 16782, 16791>,
    <16798, 16791, 15804>,
    <16798, 15804, 15905>,
    <16798, 15905, 15902>,
    <16798, 15902, 16799>,
    <16800, 16795, 16794>,
    <16800, 16794, 16799>,
    <16800, 16799, 15902>,
    <16800, 15902, 15901>,
    <16800, 15901, 15900>,
    <16800, 15900, 16801>,
    <16800, 16801, 16796>,
    <16800, 16796, 16795>,
    <16802, 16803, 16804>,
    <16802, 16804, 16805>,
    <16802, 16805, 16054>,
    <16802, 16054, 16053>,
    <16802, 16053, 16024>,
    <16802, 16024, 16806>,
    <16802, 16806, 16807>,
    <16802, 16807, 16803>,
    <16808, 16809, 16804>,
    <16808, 16804, 16803>,
    <16808, 16803, 16807>,
    <16808, 16807, 16810>,
    <16808, 16810, 16811>,
    <16808, 16811, 16812>,
    <16808, 16812, 16813>,
    <16808, 16813, 16809>,
    <16814, 16805, 16804>,
    <16814, 16804, 16809>,
    <16814, 16809, 16813>,
    <16814, 16813, 16815>,
    <16814, 16815, 15927>,
    <16814, 15927, 16056>,
    <16814, 16056, 16054>,
    <16814, 16054, 16805>,
    <16816, 16817, 16818>,
    <16816, 16818, 16819>,
    <16816, 16819, 16711>,
    <16816, 16711, 16710>,
    <16816, 16710, 15927>,
    <16816, 15927, 16815>,
    <16816, 16815, 16813>,
    <16816, 16813, 16817>,
    <16820, 16821, 16818>,
    <16820, 16818, 16817>,
    <16820, 16817, 16813>,
    <16820, 16813, 16812>,
    <16820, 16812, 16811>,
    <16820, 16811, 16822>,
    <16820, 16822, 16823>,
    <16820, 16823, 16821>,
    <16824, 16819, 16818>,
    <16824, 16818, 16821>,
    <16824, 16821, 16823>,
    <16824, 16823, 16825>,
    <16824, 16825, 16715>,
    <16824, 16715, 16714>,
    <16824, 16714, 16711>,
    <16824, 16711, 16819>,
    <16826, 16827, 16828>,
    <16826, 16828, 16829>,
    <16826, 16829, 16830>,
    <16826, 16830, 16831>,
    <16826, 16831, 16832>,
    <16826, 16832, 16833>,
    <16826, 16833, 16834>,
    <16826, 16834, 16827>,
    <16835, 16836, 16828>,
    <16835, 16828, 16827>,
    <16835, 16827, 16834>,
    <16835, 16834, 16837>,
    <16835, 16837, 15852>,
    <16835, 15852, 16752>,
    <16835, 16752, 16749>,
    <16835, 16749, 16836>,
    <16838, 16829, 16828>,
    <16838, 16828, 16836>,
    <16838, 16836, 16749>,
    <16838, 16749, 16748>,
    <16838, 16748, 16736>,
    <16838, 16736, 16839>,
    <16838, 16839, 16830>,
    <16838, 16830, 16829>,
    <16840, 16841, 16842>,
    <16840, 16842, 16843>,
    <16840, 16843, 16834>,
    <16840, 16834, 16833>,
    <16840, 16833, 16832>,
    <16840, 16832, 16844>,
    <16840, 16844, 16845>,
    <16840, 16845, 16841>,
    <16846, 16847, 16842>,
    <16846, 16842, 16841>,
    <16846, 16841, 16845>,
    <16846, 16845, 16848>,
    <16846, 16848, 15948>,
    <16846, 15948, 15947>,
    <16846, 15947, 15946>,
    <16846, 15946, 16847>,
    <16849, 16843, 16842>,
    <16849, 16842, 16847>,
    <16849, 16847, 15946>,
    <16849, 15946, 15955>,
    <16849, 15955, 15852>,
    <16849, 15852, 16837>,
    <16849, 16837, 16834>,
    <16849, 16834, 16843>,
    <16850, 16851, 16852>,
    <16850, 16852, 16853>,
    <16850, 16853, 16854>,
    <16850, 16854, 16855>,
    <16850, 16855, 16093>,
    <16850, 16093, 16104>,
    <16850, 16104, 16102>,
    <16850, 16102, 16851>,
    <16856, 16857, 16852>,
    <16856, 16852, 16851>,
    <16856, 16851, 16102>,
    <16856, 16102, 16101>,
    <16856, 16101, 15978>,
    <16856, 15978, 16858>,
    <16856, 16858, 16859>,
    <16856, 16859, 16857>,
    <16860, 16853, 16852>,
    <16860, 16852, 16857>,
    <16860, 16857, 16859>,
    <16860, 16859, 16861>,
    <16860, 16861, 16862>,
    <16860, 16862, 16863>,
    <16860, 16863, 16854>,
    <16860, 16854, 16853>,
    <16864, 16865, 16866>,
    <16864, 16866, 16867>,
    <16864, 16867, 16859>,
    <16864, 16859, 16858>,
    <16864, 16858, 15978>,
    <16864, 15978, 16759>,
    <16864, 16759, 16758>,
    <16864, 16758, 16865>,
    <16868, 16869, 16866>,
    <16868, 16866, 16865>,
    <16868, 16865, 16758>,
    <16868, 16758, 16767>,
    <16868, 16767, 16766>,
    <16868, 16766, 16870>,
    <16868, 16870, 16871>,
    <16868, 16871, 16869>,
    <16872, 16867, 16866>,
    <16872, 16866, 16869>,
    <16872, 16869, 16871>,
    <16872, 16871, 16873>,
    <16872, 16873, 16862>,
    <16872, 16862, 16861>,
    <16872, 16861, 16859>,
    <16872, 16859, 16867>,
    <16874, 16875, 16876>,
    <16874, 16876, 16877>,
    <16874, 16877, 16878>,
    <16874, 16878, 16879>,
    <16874, 16879, 16880>,
    <16874, 16880, 16881>,
    <16874, 16881, 16882>,
    <16874, 16882, 16875>,
    <16883, 16884, 16876>,
    <16883, 16876, 16875>,
    <16883, 16875, 16882>,
    <16883, 16882, 16885>,
    <16883, 16885, 16784>,
    <16883, 16784, 16797>,
    <16883, 16797, 16796>,
    <16883, 16796, 16884>,
    <16886, 16877, 16876>,
    <16886, 16876, 16884>,
    <16886, 16884, 16796>,
    <16886, 16796, 16801>,
    <16886, 16801, 15900>,
    <16886, 15900, 16887>,
    <16886, 16887, 16878>,
    <16886, 16878, 16877>,
    <16888, 16889, 16890>,
    <16888, 16890, 16891>,
    <16888, 16891, 16892>,
    <16888, 16892, 16893>,
    <16888, 16893, 16880>,
    <16888, 16880, 16879>,
    <16888, 16879, 16878>,
    <16888, 16878, 16889>,
    <16894, 16895, 16890>,
    <16894, 16890, 16889>,
    <16894, 16889, 16878>,
    <16894, 16878, 16887>,
    <16894, 16887, 15900>,
    <16894, 15900, 16001>,
    <16894, 16001, 15998>,
    <16894, 15998, 16895>,
    <16896, 16891, 16890>,
    <16896, 16890, 16895>,
    <16896, 16895, 15998>,
    <16896, 15998, 15997>,
    <16896, 15997, 15996>,
    <16896, 15996, 16897>,
    <16896, 16897, 16892>,
    <16896, 16892, 16891>,
    <16898, 16899, 16900>,
    <16898, 16900, 16901>,
    <16898, 16901, 16902>,
    <16898, 16902, 16903>,
    <16898, 16903, 16904>,
    <16898, 16904, 16905>,
    <16898, 16906, 16907>,
    <16898, 16907, 16899>,
    <16908, 16909, 16900>,
    <16908, 16900, 16899>,
    <16908, 16899, 16910>,
    <16908, 16910, 16911>,
    <16908, 16912, 16913>,
    <16908, 16913, 16914>,
    <16908, 16914, 16915>,
    <16908, 16915, 16909>,
    <16916, 16901, 16900>,
    <16916, 16900, 16909>,
    <16916, 16909, 16915>,
    <16916, 16915, 16917>,
    <16916, 16917, 16918>,
    <16916, 16918, 16919>,
    <16916, 16919, 16902>,
    <16916, 16902, 16901>,
    <16920, 16921, 16922>,
    <16920, 16922, 16923>,
    <16920, 16923, 16144>,
    <16920, 16144, 16143>,
    <16920, 16143, 16924>,
    <16920, 16924, 16903>,
    <16920, 16903, 16902>,
    <16920, 16902, 16921>,
    <16925, 16926, 16922>,
    <16925, 16922, 16921>,
    <16925, 16921, 16902>,
    <16925, 16902, 16919>,
    <16925, 16919, 16918>,
    <16925, 16918, 16927>,
    <16925, 16927, 16928>,
    <16925, 16928, 16926>,
    <16929, 16923, 16922>,
    <16929, 16922, 16926>,
    <16929, 16926, 16928>,
    <16929, 16928, 16930>,
    <16929, 16930, 16024>,
    <16929, 16024, 16146>,
    <16929, 16146, 16144>,
    <16929, 16144, 16923>,
    <16931, 16932, 16933>,
    <16931, 16933, 16934>,
    <16931, 16934, 16807>,
    <16931, 16807, 16806>,
    <16931, 16806, 16024>,
    <16931, 16024, 16930>,
    <16931, 16930, 16928>,
    <16931, 16928, 16932>,
    <16935, 16936, 16933>,
    <16935, 16933, 16932>,
    <16935, 16932, 16928>,
    <16935, 16928, 16927>,
    <16935, 16927, 16918>,
    <16935, 16918, 16937>,
    <16935, 16937, 16938>,
    <16935, 16938, 16936>,
    <16939, 16934, 16933>,
    <16939, 16933, 16936>,
    <16939, 16936, 16938>,
    <16939, 16938, 16940>,
    <16939, 16940, 16811>,
    <16939, 16811, 16810>,
    <16939, 16810, 16807>,
    <16939, 16807, 16934>,
    <16941, 16942, 16943>,
    <16941, 16943, 16944>,
    <16941, 16944, 16945>,
    <16941, 16945, 16946>,
    <16941, 16946, 16947>,
    <16941, 16947, 16948>,
    <16941, 16948, 16949>,
    <16941, 16949, 16942>,
    <16950, 16951, 16943>,
    <16950, 16943, 16942>,
    <16950, 16942, 16949>,
    <16950, 16949, 16952>,
    <16950, 16952, 15948>,
    <16950, 15948, 16848>,
    <16950, 16848, 16845>,
    <16950, 16845, 16951>,
    <16953, 16944, 16943>,
    <16953, 16943, 16951>,
    <16953, 16951, 16845>,
    <16953, 16845, 16844>,
    <16953, 16844, 16832>,
    <16953, 16832, 16954>,
    <16953, 16954, 16945>,
    <16953, 16945, 16944>,
    <16955, 16956, 16957>,
    <16955, 16957, 16958>,
    <16955, 16958, 16949>,
    <16955, 16949, 16948>,
    <16955, 16948, 16947>,
    <16955, 16947, 16959>,
    <16955, 16959, 16960>,
    <16955, 16960, 16956>,
    <16961, 16962, 16957>,
    <16961, 16957, 16956>,
    <16961, 16956, 16960>,
    <16961, 16960, 16963>,
    <16961, 16963, 16063>,
    <16961, 16063, 16062>,
    <16961, 16062, 16061>,
    <16961, 16061, 16962>,
    <16964, 16958, 16957>,
    <16964, 16957, 16962>,
    <16964, 16962, 16061>,
    <16964, 16061, 16070>,
    <16964, 16070, 15948>,
    <16964, 15948, 16952>,
    <16964, 16952, 16949>,
    <16964, 16949, 16958>,
    <16965, 16966, 16967>,
    <16965, 16967, 16968>,
    <16965, 16968, 16969>,
    <16965, 16969, 16970>,
    <16965, 16970, 16196>,
    <16965, 16196, 16218>,
    <16965, 16218, 16216>,
    <16965, 16216, 16966>,
    <16971, 16972, 16967>,
    <16971, 16967, 16966>,
    <16971, 16966, 16216>,
    <16971, 16216, 16215>,
    <16971, 16215, 16093>,
    <16971, 16093, 16973>,
    <16971, 16973, 16974>,
    <16971, 16974, 16972>,
    <16975, 16968, 16967>,
    <16975, 16967, 16972>,
    <16975, 16972, 16974>,
    <16975, 16974, 16976>,
    <16975, 16976, 16977>,
    <16975, 16977, 16978>,
    <16975, 16978, 16969>,
    <16975, 16969, 16968>,
    <16979, 16980, 16981>,
    <16979, 16981, 16982>,
    <16979, 16982, 16974>,
    <16979, 16974, 16973>,
    <16979, 16973, 16093>,
    <16979, 16093, 16855>,
    <16979, 16855, 16854>,
    <16979, 16854, 16980>,
    <16983, 16984, 16981>,
    <16983, 16981, 16980>,
    <16983, 16980, 16854>,
    <16983, 16854, 16863>,
    <16983, 16863, 16862>,
    <16983, 16862, 16985>,
    <16983, 16985, 16986>,
    <16983, 16986, 16984>,
    <16987, 16982, 16981>,
    <16987, 16981, 16984>,
    <16987, 16984, 16986>,
    <16987, 16986, 16988>,
    <16987, 16988, 16977>,
    <16987, 16977, 16976>,
    <16987, 16976, 16974>,
    <16987, 16974, 16982>,
    <16989, 16990, 16991>,
    <16989, 16991, 16992>,
    <16989, 16992, 16993>,
    <16989, 16993, 16994>,
    <16989, 16994, 16995>,
    <16989, 16995, 16996>,
    <16989, 16996, 16997>,
    <16989, 16997, 16990>,
    <16998, 16999, 16991>,
    <16998, 16991, 16990>,
    <16998, 16990, 16997>,
    <16998, 16997, 17000>,
    <16998, 17000, 16880>,
    <16998, 16880, 16893>,
    <16998, 16893, 16892>,
    <16998, 16892, 16999>,
    <17001, 16992, 16991>,
    <17001, 16991, 16999>,
    <17001, 16999, 16892>,
    <17001, 16892, 16897>,
    <17001, 16897, 15996>,
    <17001, 15996, 17002>,
    <17001, 17002, 16993>,
    <17001, 16993, 16992>,
    <17003, 17004, 17005>,
    <17003, 17005, 17006>,
    <17003, 17006, 17007>,
    <17003, 17007, 17008>,
    <17003, 17008, 16995>,
    <17003, 16995, 16994>,
    <17003, 16994, 16993>,
    <17003, 16993, 17004>,
    <17009, 17010, 17005>,
    <17009, 17005, 17004>,
    <17009, 17004, 16993>,
    <17009, 16993, 17002>,
    <17009, 17002, 15996>,
    <17009, 15996, 16116>,
    <17009, 16116, 16113>,
    <17009, 16113, 17010>,
    <17011, 17006, 17005>,
    <17011, 17005, 17010>,
    <17011, 17010, 16113>,
    <17011, 16113, 16112>,
    <17011, 16112, 16111>,
    <17011, 16111, 17012>,
    <17011, 17012, 17007>,
    <17011, 17007, 17006>,
    <17013, 17014, 17015>,
    <17013, 17015, 17016>,
    <17013, 17016, 16915>,
    <17013, 16915, 16914>,
    <17013, 16914, 17017>,
    <17013, 17017, 17018>,
    <17013, 17019, 17020>,
    <17013, 17020, 17014>,
    <17021, 17022, 17015>,
    <17021, 17015, 17014>,
    <17021, 17014, 17023>,
    <17021, 17023, 17024>,
    <17021, 17025, 17026>,
    <17021, 17026, 17027>,
    <17021, 17027, 17028>,
    <17021, 17028, 17022>,
    <17029, 17016, 17015>,
    <17029, 17015, 17022>,
    <17029, 17022, 17028>,
    <17029, 17028, 17030>,
    <17029, 17030, 16918>,
    <17029, 16918, 16917>,
    <17029, 16917, 16915>,
    <17029, 16915, 17016>,
    <17031, 17032, 17033>,
    <17031, 17033, 17034>,
    <17031, 17034, 17035>,
    <17031, 17035, 17036>,
    <17031, 17036, 17037>,
    <17031, 17037, 17038>,
    <17031, 17038, 17039>,
    <17031, 17039, 17032>,
    <17040, 17041, 17033>,
    <17040, 17033, 17032>,
    <17040, 17032, 17039>,
    <17040, 17039, 17042>,
    <17040, 17042, 16063>,
    <17040, 16063, 16963>,
    <17040, 16963, 16960>,
    <17040, 16960, 17041>,
    <17043, 17034, 17033>,
    <17043, 17033, 17041>,
    <17043, 17041, 16960>,
    <17043, 16960, 16959>,
    <17043, 16959, 16947>,
    <17043, 16947, 17044>,
    <17043, 17044, 17035>,
    <17043, 17035, 17034>,
    <17045, 17046, 17047>,
    <17045, 17047, 17048>,
    <17045, 17048, 17039>,
    <17045, 17039, 17038>,
    <17045, 17038, 17049>,
    <17045, 17049, 17050>,
    <17045, 17051, 17052>,
    <17045, 17052, 17046>,
    <17053, 17054, 17047>,
    <17053, 17047, 17046>,
    <17053, 17046, 17055>,
    <17053, 17055, 17056>,
    <17053, 17057, 17058>,
    <17053, 17058, 16331>,
    <17053, 16331, 16330>,
    <17053, 16330, 17054>,
    <17059, 17048, 17047>,
    <17059, 17047, 17054>,
    <17059, 17054, 16330>,
    <17059, 16330, 16343>,
    <17059, 16343, 16063>,
    <17059, 16063, 17042>,
    <17059, 17042, 17039>,
    <17059, 17039, 17048>,
    <17060, 17061, 17062>,
    <17060, 17062, 17063>,
    <17060, 17063, 17064>,
    <17060, 17064, 17065>,
    <17060, 17065, 17066>,
    <17060, 17066, 17067>,
    <17060, 17068, 17069>,
    <17060, 17069, 17061>,
    <17070, 17071, 17062>,
    <17070, 17062, 17061>,
    <17070, 17061, 17072>,
    <17070, 17072, 17073>,
    <17070, 17074, 17075>,
    <17070, 17075, 17076>,
    <17070, 17076, 17077>,
    <17070, 17077, 17071>,
    <17078, 17063, 17062>,
    <17078, 17062, 17071>,
    <17078, 17071, 17077>,
    <17078, 17077, 17079>,
    <17078, 17079, 17080>,
    <17078, 17080, 17081>,
    <17078, 17081, 17064>,
    <17078, 17064, 17063>,
    <17082, 17083, 17084>,
    <17082, 17084, 17085>,
    <17082, 17085, 17077>,
    <17082, 17077, 17076>,
    <17082, 17076, 17086>,
    <17082, 17086, 16313>,
    <17082, 16313, 16312>,
    <17082, 16312, 17083>,
    <17087, 17088, 17084>,
    <17087, 17084, 17083>,
    <17087, 17083, 16312>,
    <17087, 16312, 16325>,
    <17087, 16325, 16196>,
    <17087, 16196, 17089>,
    <17087, 17089, 17090>,
    <17087, 17090, 17088>,
    <17091, 17085, 17084>,
    <17091, 17084, 17088>,
    <17091, 17088, 17090>,
    <17091, 17090, 17092>,
    <17091, 17092, 17080>,
    <17091, 17080, 17079>,
    <17091, 17079, 17077>,
    <17091, 17077, 17085>,
    <17093, 17094, 17095>,
    <17093, 17095, 17096>,
    <17093, 17096, 17090>,
    <17093, 17090, 17089>,
    <17093, 17089, 16196>,
    <17093, 16196, 16970>,
    <17093, 16970, 16969>,
    <17093, 16969, 17094>,
    <17097, 17098, 17095>,
    <17097, 17095, 17094>,
    <17097, 17094, 16969>,
    <17097, 16969, 16978>,
    <17097, 16978, 16977>,
    <17097, 16977, 17099>,
    <17097, 17099, 17100>,
    <17097, 17100, 17098>,
    <17101, 17096, 17095>,
    <17101, 17095, 17098>,
    <17101, 17098, 17100>,
    <17101, 17100, 17102>,
    <17101, 17102, 17080>,
    <17101, 17080, 17092>,
    <17101, 17092, 17090>,
    <17101, 17090, 17096>,
    <17103, 17104, 17105>,
    <17103, 17105, 17106>,
    <17103, 17106, 17107>,
    <17103, 17107, 17108>,
    <17103, 17108, 17109>,
    <17103, 17109, 17110>,
    <17103, 17111, 17112>,
    <17103, 17112, 17104>,
    <17113, 17114, 17105>,
    <17113, 17105, 17104>,
    <17113, 17104, 17115>,
    <17113, 17115, 17116>,
    <17113, 17117, 17118>,
    <17113, 17118, 17119>,
    <17113, 17119, 17120>,
    <17113, 17120, 17114>,
    <17121, 17106, 17105>,
    <17121, 17105, 17114>,
    <17121, 17114, 17120>,
    <17121, 17120, 17122>,
    <17121, 17122, 17123>,
    <17121, 17123, 17124>,
    <17121, 17124, 17107>,
    <17121, 17107, 17106>,
    <17125, 17126, 17127>,
    <17125, 17127, 17128>,
    <17125, 17128, 17129>,
    <17125, 17129, 17130>,
    <17125, 17130, 17123>,
    <17125, 17123, 17131>,
    <17125, 17131, 17132>,
    <17125, 17132, 17126>,
    <17133, 17134, 17127>,
    <17133, 17127, 17126>,
    <17133, 17126, 17132>,
    <17133, 17132, 17135>,
    <17133, 17135, 16995>,
    <17133, 16995, 17008>,
    <17133, 17008, 17007>,
    <17133, 17007, 17134>,
    <17136, 17128, 17127>,
    <17136, 17127, 17134>,
    <17136, 17134, 17007>,
    <17136, 17007, 17012>,
    <17136, 17012, 16111>,
    <17136, 16111, 17137>,
    <17136, 17137, 17129>,
    <17136, 17129, 17128>,
    <17138, 17139, 17140>,
    <17138, 17140, 17141>,
    <17138, 17141, 16353>,
    <17138, 16353, 16352>,
    <17138, 16352, 17142>,
    <17138, 17142, 17108>,
    <17138, 17108, 17107>,
    <17138, 17107, 17139>,
    <17143, 17144, 17140>,
    <17143, 17140, 17139>,
    <17143, 17139, 17107>,
    <17143, 17107, 17124>,
    <17143, 17124, 17123>,
    <17143, 17123, 17145>,
    <17143, 17145, 17146>,
    <17143, 17146, 17144>,
    <17147, 17141, 17140>,
    <17147, 17140, 17144>,
    <17147, 17144, 17146>,
    <17147, 17146, 17148>,
    <17147, 17148, 16239>,
    <17147, 16239, 16356>,
    <17147, 16356, 16353>,
    <17147, 16353, 17141>,
    <17149, 17150, 17151>,
    <17149, 17151, 17152>,
    <17149, 17152, 17146>,
    <17149, 17146, 17145>,
    <17149, 17145, 17123>,
    <17149, 17123, 17130>,
    <17149, 17130, 17129>,
    <17149, 17129, 17150>,
    <17153, 17154, 17151>,
    <17153, 17151, 17150>,
    <17153, 17150, 17129>,
    <17153, 17129, 17137>,
    <17153, 17137, 16111>,
    <17153, 16111, 16251>,
    <17153, 16251, 16248>,
    <17153, 16248, 17154>,
    <17155, 17152, 17151>,
    <17155, 17151, 17154>,
    <17155, 17154, 16248>,
    <17155, 16248, 16247>,
    <17155, 16247, 16239>,
    <17155, 16239, 17148>,
    <17155, 17148, 17146>,
    <17155, 17146, 17152>,
    <17156, 17157, 17158>,
    <17156, 17158, 17159>,
    <17156, 17159, 17160>,
    <17156, 17160, 17161>,
    <17156, 17162, 17163>,
    <17156, 17163, 17065>,
    <17156, 17065, 17064>,
    <17156, 17064, 17157>,
    <17164, 17165, 17158>,
    <17164, 17158, 17157>,
    <17164, 17157, 17064>,
    <17164, 17064, 17081>,
    <17164, 17081, 17080>,
    <17164, 17080, 17166>,
    <17164, 17166, 17167>,
    <17164, 17167, 17165>,
    <17168, 17159, 17158>,
    <17168, 17158, 17165>,
    <17168, 17165, 17167>,
    <17168, 17167, 17169>,
    <17168, 17169, 17170>,
    <17168, 17170, 17171>,
    <17168, 17172, 17173>,
    <17168, 17173, 17159>,
    <17174, 17175, 17176>,
    <17174, 17176, 17177>,
    <17174, 17177, 17120>,
    <17174, 17120, 17119>,
    <17174, 17119, 17178>,
    <17174, 17178, 17179>,
    <17174, 17180, 17181>,
    <17174, 17181, 17175>,
    <17182, 17183, 17176>,
    <17182, 17176, 17175>,
    <17182, 17175, 17184>,
    <17182, 17184, 17185>,
    <17182, 17186, 17187>,
    <17182, 17187, 17188>,
    <17182, 17188, 17189>,
    <17182, 17189, 17183>,
    <17190, 17177, 17176>,
    <17190, 17176, 17183>,
    <17190, 17183, 17189>,
    <17190, 17189, 17191>,
    <17190, 17191, 17123>,
    <17190, 17123, 17122>,
    <17190, 17122, 17120>,
    <17190, 17120, 17177>,
    <17192, 17193, 17194>,
    <17192, 17194, 17195>,
    <17192, 17195, 17196>,
    <17192, 17196, 17197>,
    <17192, 17197, 17198>,
    <17192, 17198, 17199>,
    <17192, 17200, 17201>,
    <17192, 17201, 17193>,
    <17202, 17203, 17194>,
    <17202, 17194, 17193>,
    <17202, 17193, 17204>,
    <17202, 17204, 17205>,
    <17202, 17206, 17207>,
    <17202, 17207, 17169>,
    <17202, 17169, 17167>,
    <17202, 17167, 17203>,
    <17208, 17195, 17194>,
    <17208, 17194, 17203>,
    <17208, 17203, 17167>,
    <17208, 17167, 17166>,
    <17208, 17166, 17080>,
    <17208, 17080, 17209>,
    <17208, 17209, 17196>,
    <17208, 17196, 17195>,
    <17210, 17211, 17212>,
    <17210, 17212, 17213>,
    <17210, 17213, 17214>,
    <17210, 17214, 17215>,
    <17210, 17215, 17216>,
    <17210, 17216, 17217>,
    <17210, 17218, 17219>,
    <17210, 17219, 17211>,
    <17220, 17221, 17212>,
    <17220, 17212, 17211>,
    <17220, 17211, 17222>,
    <17220, 17222, 17223>,
    <17220, 17224, 17225>,
    <17220, 17225, 17036>,
    <17220, 17036, 17035>,
    <17220, 17035, 17221>,
    <17226, 17213, 17212>,
    <17226, 17212, 17221>,
    <17226, 17221, 17035>,
    <17226, 17035, 17044>,
    <17226, 17044, 16947>,
    <17226, 16947, 17227>,
    <17226, 17227, 17214>,
    <17226, 17214, 17213>,
    <17228, 17229, 17230>,
    <17228, 17230, 17231>,
    <17228, 17231, 16401>,
    <17228, 16401, 16400>,
    <17228, 16400, 16389>,
    <17228, 16389, 17232>,
    <17228, 17232, 17233>,
    <17228, 17233, 17229>,
    <17234, 17235, 17230>,
    <17234, 17230, 17229>,
    <17234, 17229, 17233>,
    <17234, 17233, 17236>,
    <17234, 17236, 17237>,
    <17234, 17237, 17238>,
    <17234, 17239, 17240>,
    <17234, 17240, 17235>,
    <17241, 17231, 17230>,
    <17241, 17230, 17235>,
    <17241, 17235, 17242>,
    <17241, 17242, 17243>,
    <17241, 17244, 17245>,
    <17241, 17245, 16403>,
    <17241, 16403, 16401>,
    <17241, 16401, 17231>,
    <17246, 17247, 17248>,
    <17246, 17248, 17249>,
    <17246, 17249, 16459>,
    <17246, 16459, 16458>,
    <17246, 16458, 16447>,
    <17246, 16447, 17250>,
    <17246, 17250, 17251>,
    <17246, 17251, 17247>,
    <17252, 17253, 17248>,
    <17252, 17248, 17247>,
    <17252, 17247, 17251>,
    <17252, 17251, 17254>,
    <17252, 17254, 17255>,
    <17252, 17255, 17256>,
    <17252, 17256, 17257>,
    <17252, 17257, 17253>,
    <17258, 17249, 17248>,
    <17258, 17248, 17253>,
    <17258, 17253, 17257>,
    <17258, 17257, 17259>,
    <17258, 17259, 16389>,
    <17258, 16389, 16461>,
    <17258, 16461, 16459>,
    <17258, 16459, 17249>,
    <17260, 17261, 17262>,
    <17260, 17262, 17263>,
    <17260, 17263, 17233>,
    <17260, 17233, 17232>,
    <17260, 17232, 16389>,
    <17260, 16389, 17259>,
    <17260, 17259, 17257>,
    <17260, 17257, 17261>,
    <17264, 17265, 17262>,
    <17264, 17262, 17261>,
    <17264, 17261, 17257>,
    <17264, 17257, 17256>,
    <17264, 17256, 17255>,
    <17264, 17255, 17266>,
    <17264, 17266, 17267>,
    <17264, 17267, 17265>,
    <17268, 17263, 17262>,
    <17268, 17262, 17265>,
    <17268, 17265, 17267>,
    <17268, 17267, 17269>,
    <17268, 17269, 17270>,
    <17268, 17270, 17236>,
    <17268, 17236, 17233>,
    <17268, 17233, 17263>,
    <17271, 17272, 17273>,
    <17271, 17273, 17274>,
    <17271, 17274, 17275>,
    <17271, 17275, 17276>,
    <17271, 17276, 17277>,
    <17271, 17277, 17278>,
    <17271, 17278, 17279>,
    <17271, 17279, 17272>,
    <17280, 17281, 17273>,
    <17280, 17273, 17272>,
    <17280, 17272, 17279>,
    <17280, 17279, 17282>,
    <17280, 17282, 17283>,
    <17280, 17283, 17284>,
    <17280, 17285, 17286>,
    <17280, 17286, 17281>,
    <17287, 17274, 17273>,
    <17287, 17273, 17281>,
    <17287, 17281, 17288>,
    <17287, 17288, 17289>,
    <17287, 17290, 17291>,
    <17287, 17291, 17292>,
    <17287, 17292, 17275>,
    <17287, 17275, 17274>,
    <17293, 17294, 17295>,
    <17293, 17295, 17296>,
    <17293, 17296, 17279>,
    <17293, 17279, 17278>,
    <17293, 17278, 17277>,
    <17293, 17277, 17297>,
    <17293, 17297, 17298>,
    <17293, 17298, 17294>,
    <17299, 17300, 17295>,
    <17299, 17295, 17294>,
    <17299, 17294, 17298>,
    <17299, 17298, 17301>,
    <17299, 17301, 16411>,
    <17299, 16411, 16410>,
    <17299, 16410, 16409>,
    <17299, 16409, 17300>,
    <17302, 17296, 17295>,
    <17302, 17295, 17300>,
    <17302, 17300, 16409>,
    <17302, 16409, 16426>,
    <17302, 16426, 17303>,
    <17302, 17303, 17282>,
    <17302, 17282, 17279>,
    <17302, 17279, 17296>,
    <17304, 17305, 17306>,
    <17304, 17306, 17307>,
    <17304, 17307, 16583>,
    <17304, 16583, 16582>,
    <17304, 16582, 16571>,
    <17304, 16571, 17308>,
    <17304, 17308, 17309>,
    <17304, 17309, 17305>,
    <17310, 17311, 17306>,
    <17310, 17306, 17305>,
    <17310, 17305, 17309>,
    <17310, 17309, 17312>,
    <17310, 17312, 17313>,
    <17310, 17313, 17314>,
    <17310, 17314, 17315>,
    <17310, 17315, 17311>,
    <17316, 17307, 17306>,
    <17316, 17306, 17311>,
    <17316, 17311, 17315>,
    <17316, 17315, 17317>,
    <17316, 17317, 16447>,
    <17316, 16447, 16585>,
    <17316, 16585, 16583>,
    <17316, 16583, 17307>,
    <17318, 17319, 17320>,
    <17318, 17320, 17321>,
    <17318, 17321, 17251>,
    <17318, 17251, 17250>,
    <17318, 17250, 16447>,
    <17318, 16447, 17317>,
    <17318, 17317, 17315>,
    <17318, 17315, 17319>,
    <17322, 17323, 17320>,
    <17322, 17320, 17319>,
    <17322, 17319, 17315>,
    <17322, 17315, 17314>,
    <17322, 17314, 17313>,
    <17322, 17313, 17324>,
    <17322, 17324, 17325>,
    <17322, 17325, 17323>,
    <17326, 17321, 17320>,
    <17326, 17320, 17323>,
    <17326, 17323, 17325>,
    <17326, 17325, 17327>,
    <17326, 17327, 17255>,
    <17326, 17255, 17254>,
    <17326, 17254, 17251>,
    <17326, 17251, 17321>,
    <17328, 17329, 17330>,
    <17328, 17330, 17331>,
    <17328, 17331, 17332>,
    <17328, 17332, 17333>,
    <17328, 17333, 17334>,
    <17328, 17334, 17335>,
    <17328, 17335, 17336>,
    <17328, 17336, 17329>,
    <17337, 17338, 17330>,
    <17337, 17330, 17329>,
    <17337, 17329, 17336>,
    <17337, 17336, 17339>,
    <17337, 17339, 16411>,
    <17337, 16411, 17301>,
    <17337, 17301, 17298>,
    <17337, 17298, 17338>,
    <17340, 17331, 17330>,
    <17340, 17330, 17338>,
    <17340, 17338, 17298>,
    <17340, 17298, 17297>,
    <17340, 17297, 17277>,
    <17340, 17277, 17341>,
    <17340, 17341, 17332>,
    <17340, 17332, 17331>,
    <17342, 17343, 17344>,
    <17342, 17344, 17345>,
    <17342, 17345, 17336>,
    <17342, 17336, 17335>,
    <17342, 17335, 17334>,
    <17342, 17334, 17346>,
    <17342, 17346, 17347>,
    <17342, 17347, 17343>,
    <17348, 17349, 17344>,
    <17348, 17344, 17343>,
    <17348, 17343, 17347>,
    <17348, 17347, 17350>,
    <17348, 17350, 16468>,
    <17348, 16468, 16467>,
    <17348, 16467, 16466>,
    <17348, 16466, 17349>,
    <17351, 17345, 17344>,
    <17351, 17344, 17349>,
    <17351, 17349, 16466>,
    <17351, 16466, 16475>,
    <17351, 16475, 16411>,
    <17351, 16411, 17339>,
    <17351, 17339, 17336>,
    <17351, 17336, 17345>,
    <17352, 17353, 17354>,
    <17352, 17354, 17355>,
    <17352, 17355, 17356>,
    <17352, 17356, 17357>,
    <17352, 17357, 16516>,
    <17352, 16516, 16528>,
    <17352, 16528, 16526>,
    <17352, 16526, 17353>,
    <17358, 17359, 17354>,
    <17358, 17354, 17353>,
    <17358, 17353, 16526>,
    <17358, 16526, 16525>,
    <17358, 16525, 17360>,
    <17358, 17360, 17361>,
    <17358, 17362, 17363>,
    <17358, 17363, 17359>,
    <17364, 17355, 17354>,
    <17364, 17354, 17359>,
    <17364, 17359, 17365>,
    <17364, 17365, 17366>,
    <17364, 17367, 17368>,
    <17364, 17368, 17369>,
    <17364, 17369, 17356>,
    <17364, 17356, 17355>,
    <17370, 17371, 17372>,
    <17370, 17372, 17373>,
    <17370, 17373, 17374>,
    <17370, 17374, 17375>,
    <17370, 17376, 17377>,
    <17370, 17377, 17378>,
    <17370, 17378, 17379>,
    <17370, 17379, 17371>,
    <17380, 17381, 17372>,
    <17380, 17372, 17371>,
    <17380, 17371, 17379>,
    <17380, 17379, 17382>,
    <17380, 17382, 17123>,
    <17380, 17123, 17191>,
    <17380, 17191, 17189>,
    <17380, 17189, 17381>,
    <17383, 17373, 17372>,
    <17383, 17372, 17381>,
    <17383, 17381, 17189>,
    <17383, 17189, 17188>,
    <17383, 17188, 17384>,
    <17383, 17384, 17385>,
    <17383, 17386, 17387>,
    <17383, 17387, 17373>,
    <17388, 17389, 17390>,
    <17388, 17390, 17391>,
    <17388, 17391, 17392>,
    <17388, 17392, 17393>,
    <17388, 17393, 16622>,
    <17388, 16622, 16633>,
    <17388, 16633, 16631>,
    <17388, 16631, 17389>,
    <17394, 17395, 17390>,
    <17394, 17390, 17389>,
    <17394, 17389, 16631>,
    <17394, 16631, 16630>,
    <17394, 16630, 16516>,
    <17394, 16516, 17396>,
    <17394, 17396, 17397>,
    <17394, 17397, 17395>,
    <17398, 17391, 17390>,
    <17398, 17390, 17395>,
    <17398, 17395, 17397>,
    <17398, 17397, 17399>,
    <17398, 17399, 17400>,
    <17398, 17400, 17401>,
    <17398, 17401, 17392>,
    <17398, 17392, 17391>,
    <17402, 17403, 17404>,
    <17402, 17404, 17405>,
    <17402, 17405, 17397>,
    <17402, 17397, 17396>,
    <17402, 17396, 16516>,
    <17402, 16516, 17357>,
    <17402, 17357, 17356>,
    <17402, 17356, 17403>,
    <17406, 17407, 17404>,
    <17406, 17404, 17403>,
    <17406, 17403, 17356>,
    <17406, 17356, 17369>,
    <17406, 17369, 17408>,
    <17406, 17408, 17409>,
    <17406, 17409, 17410>,
    <17406, 17410, 17407>,
    <17411, 17405, 17404>,
    <17411, 17404, 17407>,
    <17411, 17407, 17410>,
    <17411, 17410, 17412>,
    <17411, 17412, 17400>,
    <17411, 17400, 17399>,
    <17411, 17399, 17397>,
    <17411, 17397, 17405>,
    <17413, 17414, 17415>,
    <17413, 17415, 17416>,
    <17413, 17416, 17417>,
    <17413, 17417, 17418>,
    <17413, 17418, 17419>,
    <17413, 17419, 17420>,
    <17413, 17420, 17421>,
    <17413, 17421, 17414>,
    <17422, 17423, 17415>,
    <17422, 17415, 17414>,
    <17422, 17414, 17421>,
    <17422, 17421, 17424>,
    <17422, 17424, 17425>,
    <17422, 17425, 17426>,
    <17422, 17427, 17428>,
    <17422, 17428, 17423>,
    <17429, 17416, 17415>,
    <17429, 17415, 17423>,
    <17429, 17423, 17430>,
    <17429, 17430, 17431>,
    <17429, 17432, 17433>,
    <17429, 17433, 17434>,
    <17429, 17434, 17417>,
    <17429, 17417, 17416>,
    <17435, 17436, 17437>,
    <17435, 17437, 17438>,
    <17435, 17438, 17439>,
    <17435, 17439, 17440>,
    <17435, 17440, 17419>,
    <17435, 17419, 17418>,
    <17435, 17418, 17417>,
    <17435, 17417, 17436>,
    <17441, 17442, 17437>,
    <17441, 17437, 17436>,
    <17441, 17436, 17417>,
    <17441, 17417, 17434>,
    <17441, 17434, 17443>,
    <17441, 17443, 16540>,
    <17441, 16540, 16537>,
    <17441, 16537, 17442>,
    <17444, 17438, 17437>,
    <17444, 17437, 17442>,
    <17444, 17442, 16537>,
    <17444, 16537, 16536>,
    <17444, 16536, 16535>,
    <17444, 16535, 17445>,
    <17444, 17445, 17439>,
    <17444, 17439, 17438>,
    <17446, 17447, 17448>,
    <17446, 17448, 17449>,
    <17446, 17449, 16727>,
    <17446, 16727, 16726>,
    <17446, 16726, 16715>,
    <17446, 16715, 17450>,
    <17446, 17450, 17451>,
    <17446, 17451, 17447>,
    <17452, 17453, 17448>,
    <17452, 17448, 17447>,
    <17452, 17447, 17451>,
    <17452, 17451, 17454>,
    <17452, 17454, 17455>,
    <17452, 17455, 17456>,
    <17452, 17456, 17457>,
    <17452, 17457, 17453>,
    <17458, 17449, 17448>,
    <17458, 17448, 17453>,
    <17458, 17453, 17457>,
    <17458, 17457, 17459>,
    <17458, 17459, 16571>,
    <17458, 16571, 16729>,
    <17458, 16729, 16727>,
    <17458, 16727, 17449>,
    <17460, 17461, 17462>,
    <17460, 17462, 17463>,
    <17460, 17463, 17309>,
    <17460, 17309, 17308>,
    <17460, 17308, 16571>,
    <17460, 16571, 17459>,
    <17460, 17459, 17457>,
    <17460, 17457, 17461>,
    <17464, 17465, 17462>,
    <17464, 17462, 17461>,
    <17464, 17461, 17457>,
    <17464, 17457, 17456>,
    <17464, 17456, 17455>,
    <17464, 17455, 17466>,
    <17464, 17466, 17467>,
    <17464, 17467, 17465>,
    <17468, 17463, 17462>,
    <17468, 17462, 17465>,
    <17468, 17465, 17467>,
    <17468, 17467, 17469>,
    <17468, 17469, 17313>,
    <17468, 17313, 17312>,
    <17468, 17312, 17309>,
    <17468, 17309, 17463>,
    <17470, 17471, 17472>,
    <17470, 17472, 17473>,
    <17470, 17473, 17474>,
    <17470, 17474, 17475>,
    <17470, 17475, 17476>,
    <17470, 17476, 17477>,
    <17470, 17477, 17478>,
    <17470, 17478, 17471>,
    <17479, 17480, 17472>,
    <17479, 17472, 17471>,
    <17479, 17471, 17478>,
    <17479, 17478, 17481>,
    <17479, 17481, 16468>,
    <17479, 16468, 17350>,
    <17479, 17350, 17347>,
    <17479, 17347, 17480>,
    <17482, 17473, 17472>,
    <17482, 17472, 17480>,
    <17482, 17480, 17347>,
    <17482, 17347, 17346>,
    <17482, 17346, 17334>,
    <17482, 17334, 17483>,
    <17482, 17483, 17474>,
    <17482, 17474, 17473>,
    <17484, 17485, 17486>,
    <17484, 17486, 17487>,
    <17484, 17487, 17478>,
    <17484, 17478, 17477>,
    <17484, 17477, 17476>,
    <17484, 17476, 17488>,
    <17484, 17488, 17489>,
    <17484, 17489, 17485>,
    <17490, 17491, 17486>,
    <17490, 17486, 17485>,
    <17490, 17485, 17489>,
    <17490, 17489, 17492>,
    <17490, 17492, 16592>,
    <17490, 16592, 16591>,
    <17490, 16591, 16590>,
    <17490, 16590, 17491>,
    <17493, 17487, 17486>,
    <17493, 17486, 17491>,
    <17493, 17491, 16590>,
    <17493, 16590, 16599>,
    <17493, 16599, 16468>,
    <17493, 16468, 17481>,
    <17493, 17481, 17478>,
    <17493, 17478, 17487>,
    <17494, 17495, 17496>,
    <17494, 17496, 17497>,
    <17494, 17497, 17498>,
    <17494, 17498, 17499>,
    <17494, 17499, 16670>,
    <17494, 16670, 16681>,
    <17494, 16681, 16679>,
    <17494, 16679, 17495>,
    <17500, 17501, 17496>,
    <17500, 17496, 17495>,
    <17500, 17495, 16679>,
    <17500, 16679, 16678>,
    <17500, 16678, 16622>,
    <17500, 16622, 17502>,
    <17500, 17502, 17503>,
    <17500, 17503, 17501>,
    <17504, 17497, 17496>,
    <17504, 17496, 17501>,
    <17504, 17501, 17503>,
    <17504, 17503, 17505>,
    <17504, 17505, 17506>,
    <17504, 17506, 17507>,
    <17504, 17507, 17498>,
    <17504, 17498, 17497>,
    <17508, 17509, 17510>,
    <17508, 17510, 17511>,
    <17508, 17511, 17503>,
    <17508, 17503, 17502>,
    <17508, 17502, 16622>,
    <17508, 16622, 17393>,
    <17508, 17393, 17392>,
    <17508, 17392, 17509>,
    <17512, 17513, 17510>,
    <17512, 17510, 17509>,
    <17512, 17509, 17392>,
    <17512, 17392, 17401>,
    <17512, 17401, 17400>,
    <17512, 17400, 17514>,
    <17512, 17514, 17515>,
    <17512, 17515, 17513>,
    <17516, 17511, 17510>,
    <17516, 17510, 17513>,
    <17516, 17513, 17515>,
    <17516, 17515, 17517>,
    <17516, 17517, 17506>,
    <17516, 17506, 17505>,
    <17516, 17505, 17503>,
    <17516, 17503, 17511>,
    <17518, 17519, 17520>,
    <17518, 17520, 17521>,
    <17518, 17521, 17522>,
    <17518, 17522, 17523>,
    <17518, 17523, 17524>,
    <17518, 17524, 17525>,
    <17518, 17525, 17526>,
    <17518, 17526, 17519>,
    <17527, 17528, 17520>,
    <17527, 17520, 17519>,
    <17527, 17519, 17526>,
    <17527, 17526, 17529>,
    <17527, 17529, 17419>,
    <17527, 17419, 17440>,
    <17527, 17440, 17439>,
    <17527, 17439, 17528>,
    <17530, 17521, 17520>,
    <17530, 17520, 17528>,
    <17530, 17528, 17439>,
    <17530, 17439, 17445>,
    <17530, 17445, 16535>,
    <17530, 16535, 17531>,
    <17530, 17531, 17522>,
    <17530, 17522, 17521>,
    <17532, 17533, 17534>,
    <17532, 17534, 17535>,
    <17532, 17535, 17536>,
    <17532, 17536, 17537>,
    <17532, 17537, 17524>,
    <17532, 17524, 17523>,
    <17532, 17523, 17522>,
    <17532, 17522, 17533>,
    <17538, 17539, 17534>,
    <17538, 17534, 17533>,
    <17538, 17533, 17522>,
    <17538, 17522, 17531>,
    <17538, 17531, 16535>,
    <17538, 16535, 16645>,
    <17538, 16645, 16642>,
    <17538, 16642, 17539>,
    <17540, 17535, 17534>,
    <17540, 17534, 17539>,
    <17540, 17539, 16642>,
    <17540, 16642, 16641>,
    <17540, 16641, 16640>,
    <17540, 16640, 17541>,
    <17540, 17541, 17536>,
    <17540, 17536, 17535>,
    <17542, 17543, 17544>,
    <17542, 17544, 17545>,
    <17542, 17545, 17546>,
    <17542, 17546, 17547>,
    <17542, 17547, 16766>,
    <17542, 16766, 16777>,
    <17542, 16777, 16775>,
    <17542, 16775, 17543>,
    <17548, 17549, 17544>,
    <17548, 17544, 17543>,
    <17548, 17543, 16775>,
    <17548, 16775, 16774>,
    <17548, 16774, 16670>,
    <17548, 16670, 17550>,
    <17548, 17550, 17551>,
    <17548, 17551, 17549>,
    <17552, 17545, 17544>,
    <17552, 17544, 17549>,
    <17552, 17549, 17551>,
    <17552, 17551, 17553>,
    <17552, 17553, 17554>,
    <17552, 17554, 17555>,
    <17552, 17555, 17546>,
    <17552, 17546, 17545>,
    <17556, 17557, 17558>,
    <17556, 17558, 17559>,
    <17556, 17559, 17551>,
    <17556, 17551, 17550>,
    <17556, 17550, 16670>,
    <17556, 16670, 17499>,
    <17556, 17499, 17498>,
    <17556, 17498, 17557>,
    <17560, 17561, 17558>,
    <17560, 17558, 17557>,
    <17560, 17557, 17498>,
    <17560, 17498, 17507>,
    <17560, 17507, 17506>,
    <17560, 17506, 17562>,
    <17560, 17562, 17563>,
    <17560, 17563, 17561>,
    <17564, 17559, 17558>,
    <17564, 17558, 17561>,
    <17564, 17561, 17563>,
    <17564, 17563, 17565>,
    <17564, 17565, 17554>,
    <17564, 17554, 17553>,
    <17564, 17553, 17551>,
    <17564, 17551, 17559>,
    <17566, 17567, 17568>,
    <17566, 17568, 17569>,
    <17566, 17569, 17570>,
    <17566, 17570, 17571>,
    <17566, 17571, 17572>,
    <17566, 17572, 17573>,
    <17566, 17573, 17574>,
    <17566, 17574, 17567>,
    <17575, 17576, 17568>,
    <17575, 17568, 17567>,
    <17575, 17567, 17574>,
    <17575, 17574, 17577>,
    <17575, 17577, 17524>,
    <17575, 17524, 17537>,
    <17575, 17537, 17536>,
    <17575, 17536, 17576>,
    <17578, 17569, 17568>,
    <17578, 17568, 17576>,
    <17578, 17576, 17536>,
    <17578, 17536, 17541>,
    <17578, 17541, 16640>,
    <17578, 16640, 17579>,
    <17578, 17579, 17570>,
    <17578, 17570, 17569>,
    <17580, 17581, 17582>,
    <17580, 17582, 17583>,
    <17580, 17583, 17584>,
    <17580, 17584, 17585>,
    <17580, 17585, 17572>,
    <17580, 17572, 17571>,
    <17580, 17571, 17570>,
    <17580, 17570, 17581>,
    <17586, 17587, 17582>,
    <17586, 17582, 17581>,
    <17586, 17581, 17570>,
    <17586, 17570, 17579>,
    <17586, 17579, 16640>,
    <17586, 16640, 16693>,
    <17586, 16693, 16690>,
    <17586, 16690, 17587>,
    <17588, 17583, 17582>,
    <17588, 17582, 17587>,
    <17588, 17587, 16690>,
    <17588, 16690, 16689>,
    <17588, 16689, 16688>,
    <17588, 16688, 17589>,
    <17588, 17589, 17584>,
    <17588, 17584, 17583>,
    <17590, 17591, 17592>,
    <17590, 17592, 17593>,
    <17590, 17593, 16823>,
    <17590, 16823, 16822>,
    <17590, 16822, 16811>,
    <17590, 16811, 17594>,
    <17590, 17594, 17595>,
    <17590, 17595, 17591>,
    <17596, 17597, 17592>,
    <17596, 17592, 17591>,
    <17596, 17591, 17595>,
    <17596, 17595, 17598>,
    <17596, 17598, 17599>,
    <17596, 17599, 17600>,
    <17596, 17600, 17601>,
    <17596, 17601, 17597>,
    <17602, 17593, 17592>,
    <17602, 17592, 17597>,
    <17602, 17597, 17601>,
    <17602, 17601, 17603>,
    <17602, 17603, 16715>,
    <17602, 16715, 16825>,
    <17602, 16825, 16823>,
    <17602, 16823, 17593>,
    <17604, 17605, 17606>,
    <17604, 17606, 17607>,
    <17604, 17607, 17451>,
    <17604, 17451, 17450>,
    <17604, 17450, 16715>,
    <17604, 16715, 17603>,
    <17604, 17603, 17601>,
    <17604, 17601, 17605>,
    <17608, 17609, 17606>,
    <17608, 17606, 17605>,
    <17608, 17605, 17601>,
    <17608, 17601, 17600>,
    <17608, 17600, 17599>,
    <17608, 17599, 17610>,
    <17608, 17610, 17611>,
    <17608, 17611, 17609>,
    <17612, 17607, 17606>,
    <17612, 17606, 17609>,
    <17612, 17609, 17611>,
    <17612, 17611, 17613>,
    <17612, 17613, 17455>,
    <17612, 17455, 17454>,
    <17612, 17454, 17451>,
    <17612, 17451, 17607>,
    <17614, 17615, 17616>,
    <17614, 17616, 17617>,
    <17614, 17617, 17618>,
    <17614, 17618, 17619>,
    <17614, 17619, 17620>,
    <17614, 17620, 17621>,
    <17614, 17621, 17622>,
    <17614, 17622, 17615>,
    <17623, 17624, 17616>,
    <17623, 17616, 17615>,
    <17623, 17615, 17622>,
    <17623, 17622, 17625>,
    <17623, 17625, 16592>,
    <17623, 16592, 17492>,
    <17623, 17492, 17489>,
    <17623, 17489, 17624>,
    <17626, 17617, 17616>,
    <17626, 17616, 17624>,
    <17626, 17624, 17489>,
    <17626, 17489, 17488>,
    <17626, 17488, 17476>,
    <17626, 17476, 17627>,
    <17626, 17627, 17618>,
    <17626, 17618, 17617>,
    <17628, 17629, 17630>,
    <17628, 17630, 17631>,
    <17628, 17631, 17622>,
    <17628, 17622, 17621>,
    <17628, 17621, 17620>,
    <17628, 17620, 17632>,
    <17628, 17632, 17633>,
    <17628, 17633, 17629>,
    <17634, 17635, 17630>,
    <17634, 17630, 17629>,
    <17634, 17629, 17633>,
    <17634, 17633, 17636>,
    <17634, 17636, 16736>,
    <17634, 16736, 16735>,
    <17634, 16735, 16734>,
    <17634, 16734, 17635>,
    <17637, 17631, 17630>,
    <17637, 17630, 17635>,
    <17637, 17635, 16734>,
    <17637, 16734, 16743>,
    <17637, 16743, 16592>,
    <17637, 16592, 17625>,
    <17637, 17625, 17622>,
    <17637, 17622, 17631>,
    <17638, 17639, 17640>,
    <17638, 17640, 17641>,
    <17638, 17641, 17642>,
    <17638, 17642, 17643>,
    <17638, 17643, 16862>,
    <17638, 16862, 16873>,
    <17638, 16873, 16871>,
    <17638, 16871, 17639>,
    <17644, 17645, 17640>,
    <17644, 17640, 17639>,
    <17644, 17639, 16871>,
    <17644, 16871, 16870>,
    <17644, 16870, 16766>,
    <17644, 16766, 17646>,
    <17644, 17646, 17647>,
    <17644, 17647, 17645>,
    <17648, 17641, 17640>,
    <17648, 17640, 17645>,
    <17648, 17645, 17647>,
    <17648, 17647, 17649>,
    <17648, 17649, 17650>,
    <17648, 17650, 17651>,
    <17648, 17651, 17642>,
    <17648, 17642, 17641>,
    <17652, 17653, 17654>,
    <17652, 17654, 17655>,
    <17652, 17655, 17647>,
    <17652, 17647, 17646>,
    <17652, 17646, 16766>,
    <17652, 16766, 17547>,
    <17652, 17547, 17546>,
    <17652, 17546, 17653>,
    <17656, 17657, 17654>,
    <17656, 17654, 17653>,
    <17656, 17653, 17546>,
    <17656, 17546, 17555>,
    <17656, 17555, 17554>,
    <17656, 17554, 17658>,
    <17656, 17658, 17659>,
    <17656, 17659, 17657>,
    <17660, 17655, 17654>,
    <17660, 17654, 17657>,
    <17660, 17657, 17659>,
    <17660, 17659, 17661>,
    <17660, 17661, 17650>,
    <17660, 17650, 17649>,
    <17660, 17649, 17647>,
    <17660, 17647, 17655>,
    <17662, 17663, 17664>,
    <17662, 17664, 17665>,
    <17662, 17665, 17666>,
    <17662, 17666, 17667>,
    <17662, 17667, 17668>,
    <17662, 17668, 17669>,
    <17662, 17669, 17670>,
    <17662, 17670, 17663>,
    <17671, 17672, 17664>,
    <17671, 17664, 17663>,
    <17671, 17663, 17670>,
    <17671, 17670, 17673>,
    <17671, 17673, 17572>,
    <17671, 17572, 17585>,
    <17671, 17585, 17584>,
    <17671, 17584, 17672>,
    <17674, 17665, 17664>,
    <17674, 17664, 17672>,
    <17674, 17672, 17584>,
    <17674, 17584, 17589>,
    <17674, 17589, 16688>,
    <17674, 16688, 17675>,
    <17674, 17675, 17666>,
    <17674, 17666, 17665>,
    <17676, 17677, 17678>,
    <17676, 17678, 17679>,
    <17676, 17679, 17680>,
    <17676, 17680, 17681>,
    <17676, 17681, 17668>,
    <17676, 17668, 17667>,
    <17676, 17667, 17666>,
    <17676, 17666, 17677>,
    <17682, 17683, 17678>,
    <17682, 17678, 17677>,
    <17682, 17677, 17666>,
    <17682, 17666, 17675>,
    <17682, 17675, 16688>,
    <17682, 16688, 16789>,
    <17682, 16789, 16786>,
    <17682, 16786, 17683>,
    <17684, 17679, 17678>,
    <17684, 17678, 17683>,
    <17684, 17683, 16786>,
    <17684, 16786, 16785>,
    <17684, 16785, 16784>,
    <17684, 16784, 17685>,
    <17684, 17685, 17680>,
    <17684, 17680, 17679>,
    <17686, 17687, 17688>,
    <17686, 17688, 17689>,
    <17686, 17689, 16938>,
    <17686, 16938, 16937>,
    <17686, 16937, 16918>,
    <17686, 16918, 17690>,
    <17686, 17690, 17691>,
    <17686, 17691, 17687>,
    <17692, 17693, 17688>,
    <17692, 17688, 17687>,
    <17692, 17687, 17691>,
    <17692, 17691, 17694>,
    <17692, 17694, 17695>,
    <17692, 17695, 17696>,
    <17692, 17696, 17697>,
    <17692, 17697, 17693>,
    <17698, 17689, 17688>,
    <17698, 17688, 17693>,
    <17698, 17693, 17697>,
    <17698, 17697, 17699>,
    <17698, 17699, 16811>,
    <17698, 16811, 16940>,
    <17698, 16940, 16938>,
    <17698, 16938, 17689>,
    <17700, 17701, 17702>,
    <17700, 17702, 17703>,
    <17700, 17703, 17595>,
    <17700, 17595, 17594>,
    <17700, 17594, 16811>,
    <17700, 16811, 17699>,
    <17700, 17699, 17697>,
    <17700, 17697, 17701>,
    <17704, 17705, 17702>,
    <17704, 17702, 17701>,
    <17704, 17701, 17697>,
    <17704, 17697, 17696>,
    <17704, 17696, 17695>,
    <17704, 17695, 17706>,
    <17704, 17706, 17707>,
    <17704, 17707, 17705>,
    <17708, 17703, 17702>,
    <17708, 17702, 17705>,
    <17708, 17705, 17707>,
    <17708, 17707, 17709>,
    <17708, 17709, 17599>,
    <17708, 17599, 17598>,
    <17708, 17598, 17595>,
    <17708, 17595, 17703>,
    <17710, 17711, 17712>,
    <17710, 17712, 17713>,
    <17710, 17713, 17714>,
    <17710, 17714, 17715>,
    <17710, 17715, 17716>,
    <17710, 17716, 17717>,
    <17710, 17717, 17718>,
    <17710, 17718, 17711>,
    <17719, 17720, 17712>,
    <17719, 17712, 17711>,
    <17719, 17711, 17718>,
    <17719, 17718, 17721>,
    <17719, 17721, 16736>,
    <17719, 16736, 17636>,
    <17719, 17636, 17633>,
    <17719, 17633, 17720>,
    <17722, 17713, 17712>,
    <17722, 17712, 17720>,
    <17722, 17720, 17633>,
    <17722, 17633, 17632>,
    <17722, 17632, 17620>,
    <17722, 17620, 17723>,
    <17722, 17723, 17714>,
    <17722, 17714, 17713>,
    <17724, 17725, 17726>,
    <17724, 17726, 17727>,
    <17724, 17727, 17718>,
    <17724, 17718, 17717>,
    <17724, 17717, 17716>,
    <17724, 17716, 17728>,
    <17724, 17728, 17729>,
    <17724, 17729, 17725>,
    <17730, 17731, 17726>,
    <17730, 17726, 17725>,
    <17730, 17725, 17729>,
    <17730, 17729, 17732>,
    <17730, 17732, 16832>,
    <17730, 16832, 16831>,
    <17730, 16831, 16830>,
    <17730, 16830, 17731>,
    <17733, 17727, 17726>,
    <17733, 17726, 17731>,
    <17733, 17731, 16830>,
    <17733, 16830, 16839>,
    <17733, 16839, 16736>,
    <17733, 16736, 17721>,
    <17733, 17721, 17718>,
    <17733, 17718, 17727>,
    <17734, 17735, 17736>,
    <17734, 17736, 17737>,
    <17734, 17737, 17738>,
    <17734, 17738, 17739>,
    <17734, 17739, 16977>,
    <17734, 16977, 16988>,
    <17734, 16988, 16986>,
    <17734, 16986, 17735>,
    <17740, 17741, 17736>,
    <17740, 17736, 17735>,
    <17740, 17735, 16986>,
    <17740, 16986, 16985>,
    <17740, 16985, 16862>,
    <17740, 16862, 17742>,
    <17740, 17742, 17743>,
    <17740, 17743, 17741>,
    <17744, 17737, 17736>,
    <17744, 17736, 17741>,
    <17744, 17741, 17743>,
    <17744, 17743, 17745>,
    <17744, 17745, 17746>,
    <17744, 17746, 17747>,
    <17744, 17747, 17738>,
    <17744, 17738, 17737>,
    <17748, 17749, 17750>,
    <17748, 17750, 17751>,
    <17748, 17751, 17743>,
    <17748, 17743, 17742>,
    <17748, 17742, 16862>,
    <17748, 16862, 17643>,
    <17748, 17643, 17642>,
    <17748, 17642, 17749>,
    <17752, 17753, 17750>,
    <17752, 17750, 17749>,
    <17752, 17749, 17642>,
    <17752, 17642, 17651>,
    <17752, 17651, 17650>,
    <17752, 17650, 17754>,
    <17752, 17754, 17755>,
    <17752, 17755, 17753>,
    <17756, 17751, 17750>,
    <17756, 17750, 17753>,
    <17756, 17753, 17755>,
    <17756, 17755, 17757>,
    <17756, 17757, 17746>,
    <17756, 17746, 17745>,
    <17756, 17745, 17743>,
    <17756, 17743, 17751>,
    <17758, 17759, 17760>,
    <17758, 17760, 17761>,
    <17758, 17761, 17762>,
    <17758, 17762, 17763>,
    <17758, 17763, 17764>,
    <17758, 17764, 17765>,
    <17758, 17765, 17766>,
    <17758, 17766, 17759>,
    <17767, 17768, 17760>,
    <17767, 17760, 17759>,
    <17767, 17759, 17766>,
    <17767, 17766, 17769>,
    <17767, 17769, 17668>,
    <17767, 17668, 17681>,
    <17767, 17681, 17680>,
    <17767, 17680, 17768>,
    <17770, 17761, 17760>,
    <17770, 17760, 17768>,
    <17770, 17768, 17680>,
    <17770, 17680, 17685>,
    <17770, 17685, 16784>,
    <17770, 16784, 17771>,
    <17770, 17771, 17762>,
    <17770, 17762, 17761>,
    <17772, 17773, 17774>,
    <17772, 17774, 17775>,
    <17772, 17775, 17776>,
    <17772, 17776, 17777>,
    <17772, 17777, 17764>,
    <17772, 17764, 17763>,
    <17772, 17763, 17762>,
    <17772, 17762, 17773>,
    <17778, 17779, 17774>,
    <17778, 17774, 17773>,
    <17778, 17773, 17762>,
    <17778, 17762, 17771>,
    <17778, 17771, 16784>,
    <17778, 16784, 16885>,
    <17778, 16885, 16882>,
    <17778, 16882, 17779>,
    <17780, 17775, 17774>,
    <17780, 17774, 17779>,
    <17780, 17779, 16882>,
    <17780, 16882, 16881>,
    <17780, 16881, 16880>,
    <17780, 16880, 17781>,
    <17780, 17781, 17776>,
    <17780, 17776, 17775>,
    <17782, 17783, 17784>,
    <17782, 17784, 17785>,
    <17782, 17785, 17786>,
    <17782, 17786, 17787>,
    <17782, 17787, 17788>,
    <17782, 17788, 17789>,
    <17782, 17790, 17791>,
    <17782, 17791, 17783>,
    <17792, 17793, 17784>,
    <17792, 17784, 17783>,
    <17792, 17783, 17794>,
    <17792, 17794, 17795>,
    <17792, 17796, 17797>,
    <17792, 17797, 17798>,
    <17792, 17798, 17799>,
    <17792, 17799, 17793>,
    <17800, 17785, 17784>,
    <17800, 17784, 17793>,
    <17800, 17793, 17799>,
    <17800, 17799, 17801>,
    <17800, 17801, 17802>,
    <17800, 17802, 17803>,
    <17800, 17803, 17786>,
    <17800, 17786, 17785>,
    <17804, 17805, 17806>,
    <17804, 17806, 17807>,
    <17804, 17807, 17028>,
    <17804, 17028, 17027>,
    <17804, 17027, 17808>,
    <17804, 17808, 17787>,
    <17804, 17787, 17786>,
    <17804, 17786, 17805>,
    <17809, 17810, 17806>,
    <17809, 17806, 17805>,
    <17809, 17805, 17786>,
    <17809, 17786, 17803>,
    <17809, 17803, 17802>,
    <17809, 17802, 17811>,
    <17809, 17811, 17812>,
    <17809, 17812, 17810>,
    <17813, 17807, 17806>,
    <17813, 17806, 17810>,
    <17813, 17810, 17812>,
    <17813, 17812, 17814>,
    <17813, 17814, 16918>,
    <17813, 16918, 17030>,
    <17813, 17030, 17028>,
    <17813, 17028, 17807>,
    <17815, 17816, 17817>,
    <17815, 17817, 17818>,
    <17815, 17818, 17691>,
    <17815, 17691, 17690>,
    <17815, 17690, 16918>,
    <17815, 16918, 17814>,
    <17815, 17814, 17812>,
    <17815, 17812, 17816>,
    <17819, 17820, 17817>,
    <17819, 17817, 17816>,
    <17819, 17816, 17812>,
    <17819, 17812, 17811>,
    <17819, 17811, 17802>,
    <17819, 17802, 17821>,
    <17819, 17821, 17822>,
    <17819, 17822, 17820>,
    <17823, 17818, 17817>,
    <17823, 17817, 17820>,
    <17823, 17820, 17822>,
    <17823, 17822, 17824>,
    <17823, 17824, 17695>,
    <17823, 17695, 17694>,
    <17823, 17694, 17691>,
    <17823, 17691, 17818>,
    <17825, 17826, 17827>,
    <17825, 17827, 17828>,
    <17825, 17828, 17829>,
    <17825, 17829, 17830>,
    <17825, 17830, 17831>,
    <17825, 17831, 17832>,
    <17825, 17832, 17833>,
    <17825, 17833, 17826>,
    <17834, 17835, 17827>,
    <17834, 17827, 17826>,
    <17834, 17826, 17833>,
    <17834, 17833, 17836>,
    <17834, 17836, 16832>,
    <17834, 16832, 17732>,
    <17834, 17732, 17729>,
    <17834, 17729, 17835>,
    <17837, 17828, 17827>,
    <17837, 17827, 17835>,
    <17837, 17835, 17729>,
    <17837, 17729, 17728>,
    <17837, 17728, 17716>,
    <17837, 17716, 17838>,
    <17837, 17838, 17829>,
    <17837, 17829, 17828>,
    <17839, 17840, 17841>,
    <17839, 17841, 17842>,
    <17839, 17842, 17833>,
    <17839, 17833, 17832>,
    <17839, 17832, 17831>,
    <17839, 17831, 17843>,
    <17839, 17843, 17844>,
    <17839, 17844, 17840>,
    <17845, 17846, 17841>,
    <17845, 17841, 17840>,
    <17845, 17840, 17844>,
    <17845, 17844, 17847>,
    <17845, 17847, 16947>,
    <17845, 16947, 16946>,
    <17845, 16946, 16945>,
    <17845, 16945, 17846>,
    <17848, 17842, 17841>,
    <17848, 17841, 17846>,
    <17848, 17846, 16945>,
    <17848, 16945, 16954>,
    <17848, 16954, 16832>,
    <17848, 16832, 17836>,
    <17848, 17836, 17833>,
    <17848, 17833, 17842>,
    <17849, 17850, 17851>,
    <17849, 17851, 17852>,
    <17849, 17852, 17853>,
    <17849, 17853, 17854>,
    <17849, 17854, 17080>,
    <17849, 17080, 17102>,
    <17849, 17102, 17100>,
    <17849, 17100, 17850>,
    <17855, 17856, 17851>,
    <17855, 17851, 17850>,
    <17855, 17850, 17100>,
    <17855, 17100, 17099>,
    <17855, 17099, 16977>,
    <17855, 16977, 17857>,
    <17855, 17857, 17858>,
    <17855, 17858, 17856>,
    <17859, 17852, 17851>,
    <17859, 17851, 17856>,
    <17859, 17856, 17858>,
    <17859, 17858, 17860>,
    <17859, 17860, 17861>,
    <17859, 17861, 17862>,
    <17859, 17862, 17853>,
    <17859, 17853, 17852>,
    <17863, 17864, 17865>,
    <17863, 17865, 17866>,
    <17863, 17866, 17858>,
    <17863, 17858, 17857>,
    <17863, 17857, 16977>,
    <17863, 16977, 17739>,
    <17863, 17739, 17738>,
    <17863, 17738, 17864>,
    <17867, 17868, 17865>,
    <17867, 17865, 17864>,
    <17867, 17864, 17738>,
    <17867, 17738, 17747>,
    <17867, 17747, 17746>,
    <17867, 17746, 17869>,
    <17867, 17869, 17870>,
    <17867, 17870, 17868>,
    <17871, 17866, 17865>,
    <17871, 17865, 17868>,
    <17871, 17868, 17870>,
    <17871, 17870, 17872>,
    <17871, 17872, 17861>,
    <17871, 17861, 17860>,
    <17871, 17860, 17858>,
    <17871, 17858, 17866>,
    <17873, 17874, 17875>,
    <17873, 17875, 17876>,
    <17873, 17876, 17877>,
    <17873, 17877, 17878>,
    <17873, 17878, 17879>,
    <17873, 17879, 17880>,
    <17873, 17880, 17881>,
    <17873, 17881, 17874>,
    <17882, 17883, 17875>,
    <17882, 17875, 17874>,
    <17882, 17874, 17881>,
    <17882, 17881, 17884>,
    <17882, 17884, 17764>,
    <17882, 17764, 17777>,
    <17882, 17777, 17776>,
    <17882, 17776, 17883>,
    <17885, 17876, 17875>,
    <17885, 17875, 17883>,
    <17885, 17883, 17776>,
    <17885, 17776, 17781>,
    <17885, 17781, 16880>,
    <17885, 16880, 17886>,
    <17885, 17886, 17877>,
    <17885, 17877, 17876>,
    <17887, 17888, 17889>,
    <17887, 17889, 17890>,
    <17887, 17890, 17891>,
    <17887, 17891, 17892>,
    <17887, 17892, 17879>,
    <17887, 17879, 17878>,
    <17887, 17878, 17877>,
    <17887, 17877, 17888>,
    <17893, 17894, 17889>,
    <17893, 17889, 17888>,
    <17893, 17888, 17877>,
    <17893, 17877, 17886>,
    <17893, 17886, 16880>,
    <17893, 16880, 17000>,
    <17893, 17000, 16997>,
    <17893, 16997, 17894>,
    <17895, 17890, 17889>,
    <17895, 17889, 17894>,
    <17895, 17894, 16997>,
    <17895, 16997, 16996>,
    <17895, 16996, 16995>,
    <17895, 16995, 17896>,
    <17895, 17896, 17891>,
    <17895, 17891, 17890>,
    <17897, 17898, 17899>,
    <17897, 17899, 17900>,
    <17897, 17900, 17799>,
    <17897, 17799, 17798>,
    <17897, 17798, 17901>,
    <17897, 17901, 17902>,
    <17897, 17903, 17904>,
    <17897, 17904, 17898>,
    <17905, 17906, 17899>,
    <17905, 17899, 17898>,
    <17905, 17898, 17907>,
    <17905, 17907, 17908>,
    <17905, 17909, 17910>,
    <17905, 17910, 17911>,
    <17905, 17911, 17912>,
    <17905, 17912, 17906>,
    <17913, 17900, 17899>,
    <17913, 17899, 17906>,
    <17913, 17906, 17912>,
    <17913, 17912, 17914>,
    <17913, 17914, 17802>,
    <17913, 17802, 17801>,
    <17913, 17801, 17799>,
    <17913, 17799, 17900>,
    <17915, 17916, 17917>,
    <17915, 17917, 17918>,
    <17915, 17918, 17919>,
    <17915, 17919, 17920>,
    <17915, 17920, 17921>,
    <17915, 17921, 17922>,
    <17915, 17922, 17923>,
    <17915, 17923, 17916>,
    <17924, 17925, 17917>,
    <17924, 17917, 17916>,
    <17924, 17916, 17923>,
    <17924, 17923, 17926>,
    <17924, 17926, 16947>,
    <17924, 16947, 17847>,
    <17924, 17847, 17844>,
    <17924, 17844, 17925>,
    <17927, 17918, 17917>,
    <17927, 17917, 17925>,
    <17927, 17925, 17844>,
    <17927, 17844, 17843>,
    <17927, 17843, 17831>,
    <17927, 17831, 17928>,
    <17927, 17928, 17919>,
    <17927, 17919, 17918>,
    <17929, 17930, 17931>,
    <17929, 17931, 17932>,
    <17929, 17932, 17923>,
    <17929, 17923, 17922>,
    <17929, 17922, 17933>,
    <17929, 17933, 17934>,
    <17929, 17935, 17936>,
    <17929, 17936, 17930>,
    <17937, 17938, 17931>,
    <17937, 17931, 17930>,
    <17937, 17930, 17939>,
    <17937, 17939, 17940>,
    <17937, 17941, 17942>,
    <17937, 17942, 17215>,
    <17937, 17215, 17214>,
    <17937, 17214, 17938>,
    <17943, 17932, 17931>,
    <17943, 17931, 17938>,
    <17943, 17938, 17214>,
    <17943, 17214, 17227>,
    <17943, 17227, 16947>,
    <17943, 16947, 17926>,
    <17943, 17926, 17923>,
    <17943, 17923, 17932>,
    <17944, 17945, 17946>,
    <17944, 17946, 17947>,
    <17944, 17947, 17948>,
    <17944, 17948, 17949>,
    <17944, 17949, 17950>,
    <17944, 17950, 17951>,
    <17944, 17952, 17953>,
    <17944, 17953, 17945>,
    <17954, 17955, 17946>,
    <17954, 17946, 17945>,
    <17954, 17945, 17956>,
    <17954, 17956, 17957>,
    <17954, 17958, 17959>,
    <17954, 17959, 17960>,
    <17954, 17960, 17961>,
    <17954, 17961, 17955>,
    <17962, 17947, 17946>,
    <17962, 17946, 17955>,
    <17962, 17955, 17961>,
    <17962, 17961, 17963>,
    <17962, 17963, 17964>,
    <17962, 17964, 17965>,
    <17962, 17965, 17948>,
    <17962, 17948, 17947>,
    <17966, 17967, 17968>,
    <17966, 17968, 17969>,
    <17966, 17969, 17961>,
    <17966, 17961, 17960>,
    <17966, 17960, 17970>,
    <17966, 17970, 17197>,
    <17966, 17197, 17196>,
    <17966, 17196, 17967>,
    <17971, 17972, 17968>,
    <17971, 17968, 17967>,
    <17971, 17967, 17196>,
    <17971, 17196, 17209>,
    <17971, 17209, 17080>,
    <17971, 17080, 17973>,
    <17971, 17973, 17974>,
    <17971, 17974, 17972>,
    <17975, 17969, 17968>,
    <17975, 17968, 17972>,
    <17975, 17972, 17974>,
    <17975, 17974, 17976>,
    <17975, 17976, 17964>,
    <17975, 17964, 17963>,
    <17975, 17963, 17961>,
    <17975, 17961, 17969>,
    <17977, 17978, 17979>,
    <17977, 17979, 17980>,
    <17977, 17980, 17974>,
    <17977, 17974, 17973>,
    <17977, 17973, 17080>,
    <17977, 17080, 17854>,
    <17977, 17854, 17853>,
    <17977, 17853, 17978>,
    <17981, 17982, 17979>,
    <17981, 17979, 17978>,
    <17981, 17978, 17853>,
    <17981, 17853, 17862>,
    <17981, 17862, 17861>,
    <17981, 17861, 17983>,
    <17981, 17983, 17984>,
    <17981, 17984, 17982>,
    <17985, 17980, 17979>,
    <17985, 17979, 17982>,
    <17985, 17982, 17984>,
    <17985, 17984, 17986>,
    <17985, 17986, 17964>,
    <17985, 17964, 17976>,
    <17985, 17976, 17974>,
    <17985, 17974, 17980>,
    <17987, 17988, 17989>,
    <17987, 17989, 17990>,
    <17987, 17990, 17991>,
    <17987, 17991, 17992>,
    <17987, 17992, 17993>,
    <17987, 17993, 17994>,
    <17987, 17995, 17996>,
    <17987, 17996, 17988>,
    <17997, 17998, 17989>,
    <17997, 17989, 17988>,
    <17997, 17988, 17999>,
    <17997, 17999, 18000>,
    <17997, 18001, 18002>,
    <17997, 18002, 18003>,
    <17997, 18003, 18004>,
    <17997, 18004, 17998>,
    <18005, 17990, 17989>,
    <18005, 17989, 17998>,
    <18005, 17998, 18004>,
    <18005, 18004, 18006>,
    <18005, 18006, 18007>,
    <18005, 18007, 18008>,
    <18005, 18008, 17991>,
    <18005, 17991, 17990>,
    <18009, 18010, 18011>,
    <18009, 18011, 18012>,
    <18009, 18012, 18013>,
    <18009, 18013, 18014>,
    <18009, 18014, 18007>,
    <18009, 18007, 18015>,
    <18009, 18015, 18016>,
    <18009, 18016, 18010>,
    <18017, 18018, 18011>,
    <18017, 18011, 18010>,
    <18017, 18010, 18016>,
    <18017, 18016, 18019>,
    <18017, 18019, 17879>,
    <18017, 17879, 17892>,
    <18017, 17892, 17891>,
    <18017, 17891, 18018>,
    <18020, 18012, 18011>,
    <18020, 18011, 18018>,
    <18020, 18018, 17891>,
    <18020, 17891, 17896>,
    <18020, 17896, 16995>,
    <18020, 16995, 18021>,
    <18020, 18021, 18013>,
    <18020, 18013, 18012>,
    <18022, 18023, 18024>,
    <18022, 18024, 18025>,
    <18022, 18025, 17379>,
    <18022, 17379, 17378>,
    <18022, 17378, 18026>,
    <18022, 18026, 17992>,
    <18022, 17992, 17991>,
    <18022, 17991, 18023>,
    <18027, 18028, 18024>,
    <18027, 18024, 18023>,
    <18027, 18023, 17991>,
    <18027, 17991, 18008>,
    <18027, 18008, 18007>,
    <18027, 18007, 18029>,
    <18027, 18029, 18030>,
    <18027, 18030, 18028>,
    <18031, 18025, 18024>,
    <18031, 18024, 18028>,
    <18031, 18028, 18030>,
    <18031, 18030, 18032>,
    <18031, 18032, 17123>,
    <18031, 17123, 17382>,
    <18031, 17382, 17379>,
    <18031, 17379, 18025>,
    <18033, 18034, 18035>,
    <18033, 18035, 18036>,
    <18033, 18036, 18030>,
    <18033, 18030, 18029>,
    <18033, 18029, 18007>,
    <18033, 18007, 18014>,
    <18033, 18014, 18013>,
    <18033, 18013, 18034>,
    <18037, 18038, 18035>,
    <18037, 18035, 18034>,
    <18037, 18034, 18013>,
    <18037, 18013, 18021>,
    <18037, 18021, 16995>,
    <18037, 16995, 17135>,
    <18037, 17135, 17132>,
    <18037, 17132, 18038>,
    <18039, 18036, 18035>,
    <18039, 18035, 18038>,
    <18039, 18038, 17132>,
    <18039, 17132, 17131>,
    <18039, 17131, 17123>,
    <18039, 17123, 18032>,
    <18039, 18032, 18030>,
    <18039, 18030, 18036>,
    <18040, 18041, 18042>,
    <18040, 18042, 18043>,
    <18040, 18043, 18044>,
    <18040, 18044, 18045>,
    <18040, 18046, 18047>,
    <18040, 18047, 17949>,
    <18040, 17949, 17948>,
    <18040, 17948, 18041>,
    <18048, 18049, 18042>,
    <18048, 18042, 18041>,
    <18048, 18041, 17948>,
    <18048, 17948, 17965>,
    <18048, 17965, 17964>,
    <18048, 17964, 18050>,
    <18048, 18050, 18051>,
    <18048, 18051, 18049>,
    <18052, 18043, 18042>,
    <18052, 18042, 18049>,
    <18052, 18049, 18051>,
    <18052, 18051, 18053>,
    <18052, 18053, 18054>,
    <18052, 18054, 18055>,
    <18052, 18056, 18057>,
    <18052, 18057, 18043>,
    <18058, 18059, 18060>,
    <18058, 18060, 18061>,
    <18058, 18061, 18004>,
    <18058, 18004, 18003>,
    <18058, 18003, 18062>,
    <18058, 18062, 18063>,
    <18058, 18064, 18065>,
    <18058, 18065, 18059>,
    <18066, 18067, 18060>,
    <18066, 18060, 18059>,
    <18066, 18059, 18068>,
    <18066, 18068, 18069>,
    <18066, 18070, 18071>,
    <18066, 18071, 18072>,
    <18066, 18072, 18073>,
    <18066, 18073, 18067>,
    <18074, 18061, 18060>,
    <18074, 18060, 18067>,
    <18074, 18067, 18073>,
    <18074, 18073, 18075>,
    <18074, 18075, 18007>,
    <18074, 18007, 18006>,
    <18074, 18006, 18004>,
    <18074, 18004, 18061>,
    <18076, 18077, 18078>,
    <18076, 18078, 18079>,
    <18076, 18079, 17267>,
    <18076, 17267, 17266>,
    <18076, 17266, 17255>,
    <18076, 17255, 18080>,
    <18076, 18080, 18081>,
    <18076, 18081, 18077>,
    <18082, 18083, 18078>,
    <18082, 18078, 18077>,
    <18082, 18077, 18081>,
    <18082, 18081, 18084>,
    <18082, 18084, 18085>,
    <18082, 18085, 18086>,
    <18082, 18087, 18088>,
    <18082, 18088, 18083>,
    <18089, 18079, 18078>,
    <18089, 18078, 18083>,
    <18089, 18083, 18090>,
    <18089, 18090, 18091>,
    <18089, 18092, 18093>,
    <18089, 18093, 17269>,
    <18089, 17269, 17267>,
    <18089, 17267, 18079>,
    <18094, 18095, 18096>,
    <18094, 18096, 18097>,
    <18094, 18097, 17325>,
    <18094, 17325, 17324>,
    <18094, 17324, 17313>,
    <18094, 17313, 18098>,
    <18094, 18098, 18099>,
    <18094, 18099, 18095>,
    <18100, 18101, 18096>,
    <18100, 18096, 18095>,
    <18100, 18095, 18099>,
    <18100, 18099, 18102>,
    <18100, 18102, 18103>,
    <18100, 18103, 18104>,
    <18100, 18104, 18105>,
    <18100, 18105, 18101>,
    <18106, 18097, 18096>,
    <18106, 18096, 18101>,
    <18106, 18101, 18105>,
    <18106, 18105, 18107>,
    <18106, 18107, 17255>,
    <18106, 17255, 17327>,
    <18106, 17327, 17325>,
    <18106, 17325, 18097>,
    <18108, 18109, 18110>,
    <18108, 18110, 18111>,
    <18108, 18111, 18081>,
    <18108, 18081, 18080>,
    <18108, 18080, 17255>,
    <18108, 17255, 18107>,
    <18108, 18107, 18105>,
    <18108, 18105, 18109>,
    <18112, 18113, 18110>,
    <18112, 18110, 18109>,
    <18112, 18109, 18105>,
    <18112, 18105, 18104>,
    <18112, 18104, 18103>,
    <18112, 18103, 18114>,
    <18112, 18114, 18115>,
    <18112, 18115, 18113>,
    <18116, 18111, 18110>,
    <18116, 18110, 18113>,
    <18116, 18113, 18115>,
    <18116, 18115, 18117>,
    <18116, 18117, 18118>,
    <18116, 18118, 18084>,
    <18116, 18084, 18081>,
    <18116, 18081, 18111>,
    <18119, 18120, 18121>,
    <18119, 18121, 18122>,
    <18119, 18122, 18123>,
    <18119, 18123, 18124>,
    <18119, 18124, 18125>,
    <18119, 18125, 18126>,
    <18119, 18126, 18127>,
    <18119, 18127, 18120>,
    <18128, 18129, 18121>,
    <18128, 18121, 18120>,
    <18128, 18120, 18127>,
    <18128, 18127, 18130>,
    <18128, 18130, 18131>,
    <18128, 18131, 18132>,
    <18128, 18133, 18134>,
    <18128, 18134, 18129>,
    <18135, 18122, 18121>,
    <18135, 18121, 18129>,
    <18135, 18129, 18136>,
    <18135, 18136, 18137>,
    <18135, 18138, 18139>,
    <18135, 18139, 18140>,
    <18135, 18140, 18123>,
    <18135, 18123, 18122>,
    <18141, 18142, 18143>,
    <18141, 18143, 18144>,
    <18141, 18144, 18127>,
    <18141, 18127, 18126>,
    <18141, 18126, 18125>,
    <18141, 18125, 18145>,
    <18141, 18145, 18146>,
    <18141, 18146, 18142>,
    <18147, 18148, 18143>,
    <18147, 18143, 18142>,
    <18147, 18142, 18146>,
    <18147, 18146, 18149>,
    <18147, 18149, 17277>,
    <18147, 17277, 17276>,
    <18147, 17276, 17275>,
    <18147, 17275, 18148>,
    <18150, 18144, 18143>,
    <18150, 18143, 18148>,
    <18150, 18148, 17275>,
    <18150, 17275, 17292>,
    <18150, 17292, 18151>,
    <18150, 18151, 18130>,
    <18150, 18130, 18127>,
    <18150, 18127, 18144>,
    <18152, 18153, 18154>,
    <18152, 18154, 18155>,
    <18152, 18155, 17467>,
    <18152, 17467, 17466>,
    <18152, 17466, 17455>,
    <18152, 17455, 18156>,
    <18152, 18156, 18157>,
    <18152, 18157, 18153>,
    <18158, 18159, 18154>,
    <18158, 18154, 18153>,
    <18158, 18153, 18157>,
    <18158, 18157, 18160>,
    <18158, 18160, 18161>,
    <18158, 18161, 18162>,
    <18158, 18162, 18163>,
    <18158, 18163, 18159>,
    <18164, 18155, 18154>,
    <18164, 18154, 18159>,
    <18164, 18159, 18163>,
    <18164, 18163, 18165>,
    <18164, 18165, 17313>,
    <18164, 17313, 17469>,
    <18164, 17469, 17467>,
    <18164, 17467, 18155>,
    <18166, 18167, 18168>,
    <18166, 18168, 18169>,
    <18166, 18169, 18099>,
    <18166, 18099, 18098>,
    <18166, 18098, 17313>,
    <18166, 17313, 18165>,
    <18166, 18165, 18163>,
    <18166, 18163, 18167>,
    <18170, 18171, 18168>,
    <18170, 18168, 18167>,
    <18170, 18167, 18163>,
    <18170, 18163, 18162>,
    <18170, 18162, 18161>,
    <18170, 18161, 18172>,
    <18170, 18172, 18173>,
    <18170, 18173, 18171>,
    <18174, 18169, 18168>,
    <18174, 18168, 18171>,
    <18174, 18171, 18173>,
    <18174, 18173, 18175>,
    <18174, 18175, 18103>,
    <18174, 18103, 18102>,
    <18174, 18102, 18099>,
    <18174, 18099, 18169>,
    <18176, 18177, 18178>,
    <18176, 18178, 18179>,
    <18176, 18179, 18180>,
    <18176, 18180, 18181>,
    <18176, 18181, 18182>,
    <18176, 18182, 18183>,
    <18176, 18183, 18184>,
    <18176, 18184, 18177>,
    <18185, 18186, 18178>,
    <18185, 18178, 18177>,
    <18185, 18177, 18184>,
    <18185, 18184, 18187>,
    <18185, 18187, 17277>,
    <18185, 17277, 18149>,
    <18185, 18149, 18146>,
    <18185, 18146, 18186>,
    <18188, 18179, 18178>,
    <18188, 18178, 18186>,
    <18188, 18186, 18146>,
    <18188, 18146, 18145>,
    <18188, 18145, 18125>,
    <18188, 18125, 18189>,
    <18188, 18189, 18180>,
    <18188, 18180, 18179>,
    <18190, 18191, 18192>,
    <18190, 18192, 18193>,
    <18190, 18193, 18184>,
    <18190, 18184, 18183>,
    <18190, 18183, 18182>,
    <18190, 18182, 18194>,
    <18190, 18194, 18195>,
    <18190, 18195, 18191>,
    <18196, 18197, 18192>,
    <18196, 18192, 18191>,
    <18196, 18191, 18195>,
    <18196, 18195, 18198>,
    <18196, 18198, 17334>,
    <18196, 17334, 17333>,
    <18196, 17333, 17332>,
    <18196, 17332, 18197>,
    <18199, 18193, 18192>,
    <18199, 18192, 18197>,
    <18199, 18197, 17332>,
    <18199, 17332, 17341>,
    <18199, 17341, 17277>,
    <18199, 17277, 18187>,
    <18199, 18187, 18184>,
    <18199, 18184, 18193>,
    <18200, 18201, 18202>,
    <18200, 18202, 18203>,
    <18200, 18203, 18204>,
    <18200, 18204, 18205>,
    <18200, 18205, 17400>,
    <18200, 17400, 17412>,
    <18200, 17412, 17410>,
    <18200, 17410, 18201>,
    <18206, 18207, 18202>,
    <18206, 18202, 18201>,
    <18206, 18201, 17410>,
    <18206, 17410, 17409>,
    <18206, 17409, 18208>,
    <18206, 18208, 18209>,
    <18206, 18210, 18211>,
    <18206, 18211, 18207>,
    <18212, 18203, 18202>,
    <18212, 18202, 18207>,
    <18212, 18207, 18213>,
    <18212, 18213, 18214>,
    <18212, 18215, 18216>,
    <18212, 18216, 18217>,
    <18212, 18217, 18204>,
    <18212, 18204, 18203>,
    <18218, 18219, 18220>,
    <18218, 18220, 18221>,
    <18218, 18221, 18222>,
    <18218, 18222, 18223>,
    <18218, 18223, 17506>,
    <18218, 17506, 17517>,
    <18218, 17517, 17515>,
    <18218, 17515, 18219>,
    <18224, 18225, 18220>,
    <18224, 18220, 18219>,
    <18224, 18219, 17515>,
    <18224, 17515, 17514>,
    <18224, 17514, 17400>,
    <18224, 17400, 18226>,
    <18224, 18226, 18227>,
    <18224, 18227, 18225>,
    <18228, 18221, 18220>,
    <18228, 18220, 18225>,
    <18228, 18225, 18227>,
    <18228, 18227, 18229>,
    <18228, 18229, 18230>,
    <18228, 18230, 18231>,
    <18228, 18231, 18222>,
    <18228, 18222, 18221>,
    <18232, 18233, 18234>,
    <18232, 18234, 18235>,
    <18232, 18235, 18227>,
    <18232, 18227, 18226>,
    <18232, 18226, 17400>,
    <18232, 17400, 18205>,
    <18232, 18205, 18204>,
    <18232, 18204, 18233>,
    <18236, 18237, 18234>,
    <18236, 18234, 18233>,
    <18236, 18233, 18204>,
    <18236, 18204, 18217>,
    <18236, 18217, 18238>,
    <18236, 18238, 18239>,
    <18236, 18239, 18240>,
    <18236, 18240, 18237>,
    <18241, 18235, 18234>,
    <18241, 18234, 18237>,
    <18241, 18237, 18240>,
    <18241, 18240, 18242>,
    <18241, 18242, 18230>,
    <18241, 18230, 18229>,
    <18241, 18229, 18227>,
    <18241, 18227, 18235>,
    <18243, 18244, 18245>,
    <18243, 18245, 18246>,
    <18243, 18246, 18247>,
    <18243, 18247, 18248>,
    <18243, 18248, 18249>,
    <18243, 18249, 18250>,
    <18243, 18250, 18251>,
    <18243, 18251, 18244>,
    <18252, 18253, 18245>,
    <18252, 18245, 18244>,
    <18252, 18244, 18251>,
    <18252, 18251, 18254>,
    <18252, 18254, 18255>,
    <18252, 18255, 18256>,
    <18252, 18257, 18258>,
    <18252, 18258, 18253>,
    <18259, 18246, 18245>,
    <18259, 18245, 18253>,
    <18259, 18253, 18260>,
    <18259, 18260, 18261>,
    <18259, 18262, 18263>,
    <18259, 18263, 18264>,
    <18259, 18264, 18247>,
    <18259, 18247, 18246>,
    <18265, 18266, 18267>,
    <18265, 18267, 18268>,
    <18265, 18268, 18269>,
    <18265, 18269, 18270>,
    <18265, 18270, 18249>,
    <18265, 18249, 18248>,
    <18265, 18248, 18247>,
    <18265, 18247, 18266>,
    <18271, 18272, 18267>,
    <18271, 18267, 18266>,
    <18271, 18266, 18247>,
    <18271, 18247, 18264>,
    <18271, 18264, 18273>,
    <18271, 18273, 17424>,
    <18271, 17424, 17421>,
    <18271, 17421, 18272>,
    <18274, 18268, 18267>,
    <18274, 18267, 18272>,
    <18274, 18272, 17421>,
    <18274, 17421, 17420>,
    <18274, 17420, 17419>,
    <18274, 17419, 18275>,
    <18274, 18275, 18269>,
    <18274, 18269, 18268>,
    <18276, 18277, 18278>,
    <18276, 18278, 18279>,
    <18276, 18279, 17611>,
    <18276, 17611, 17610>,
    <18276, 17610, 17599>,
    <18276, 17599, 18280>,
    <18276, 18280, 18281>,
    <18276, 18281, 18277>,
    <18282, 18283, 18278>,
    <18282, 18278, 18277>,
    <18282, 18277, 18281>,
    <18282, 18281, 18284>,
    <18282, 18284, 18285>,
    <18282, 18285, 18286>,
    <18282, 18286, 18287>,
    <18282, 18287, 18283>,
    <18288, 18279, 18278>,
    <18288, 18278, 18283>,
    <18288, 18283, 18287>,
    <18288, 18287, 18289>,
    <18288, 18289, 17455>,
    <18288, 17455, 17613>,
    <18288, 17613, 17611>,
    <18288, 17611, 18279>,
    <18290, 18291, 18292>,
    <18290, 18292, 18293>,
    <18290, 18293, 18157>,
    <18290, 18157, 18156>,
    <18290, 18156, 17455>,
    <18290, 17455, 18289>,
    <18290, 18289, 18287>,
    <18290, 18287, 18291>,
    <18294, 18295, 18292>,
    <18294, 18292, 18291>,
    <18294, 18291, 18287>,
    <18294, 18287, 18286>,
    <18294, 18286, 18285>,
    <18294, 18285, 18296>,
    <18294, 18296, 18297>,
    <18294, 18297, 18295>,
    <18298, 18293, 18292>,
    <18298, 18292, 18295>,
    <18298, 18295, 18297>,
    <18298, 18297, 18299>,
    <18298, 18299, 18161>,
    <18298, 18161, 18160>,
    <18298, 18160, 18157>,
    <18298, 18157, 18293>,
    <18300, 18301, 18302>,
    <18300, 18302, 18303>,
    <18300, 18303, 18304>,
    <18300, 18304, 18305>,
    <18300, 18305, 18306>,
    <18300, 18306, 18307>,
    <18300, 18307, 18308>,
    <18300, 18308, 18301>,
    <18309, 18310, 18302>,
    <18309, 18302, 18301>,
    <18309, 18301, 18308>,
    <18309, 18308, 18311>,
    <18309, 18311, 17334>,
    <18309, 17334, 18198>,
    <18309, 18198, 18195>,
    <18309, 18195, 18310>,
    <18312, 18303, 18302>,
    <18312, 18302, 18310>,
    <18312, 18310, 18195>,
    <18312, 18195, 18194>,
    <18312, 18194, 18182>,
    <18312, 18182, 18313>,
    <18312, 18313, 18304>,
    <18312, 18304, 18303>,
    <18314, 18315, 18316>,
    <18314, 18316, 18317>,
    <18314, 18317, 18308>,
    <18314, 18308, 18307>,
    <18314, 18307, 18306>,
    <18314, 18306, 18318>,
    <18314, 18318, 18319>,
    <18314, 18319, 18315>,
    <18320, 18321, 18316>,
    <18320, 18316, 18315>,
    <18320, 18315, 18319>,
    <18320, 18319, 18322>,
    <18320, 18322, 17476>,
    <18320, 17476, 17475>,
    <18320, 17475, 17474>,
    <18320, 17474, 18321>,
    <18323, 18317, 18316>,
    <18323, 18316, 18321>,
    <18323, 18321, 17474>,
    <18323, 17474, 17483>,
    <18323, 17483, 17334>,
    <18323, 17334, 18311>,
    <18323, 18311, 18308>,
    <18323, 18308, 18317>,
    <18324, 18325, 18326>,
    <18324, 18326, 18327>,
    <18324, 18327, 18328>,
    <18324, 18328, 18329>,
    <18324, 18329, 17554>,
    <18324, 17554, 17565>,
    <18324, 17565, 17563>,
    <18324, 17563, 18325>,
    <18330, 18331, 18326>,
    <18330, 18326, 18325>,
    <18330, 18325, 17563>,
    <18330, 17563, 17562>,
    <18330, 17562, 17506>,
    <18330, 17506, 18332>,
    <18330, 18332, 18333>,
    <18330, 18333, 18331>,
    <18334, 18327, 18326>,
    <18334, 18326, 18331>,
    <18334, 18331, 18333>,
    <18334, 18333, 18335>,
    <18334, 18335, 18336>,
    <18334, 18336, 18337>,
    <18334, 18337, 18328>,
    <18334, 18328, 18327>,
    <18338, 18339, 18340>,
    <18338, 18340, 18341>,
    <18338, 18341, 18333>,
    <18338, 18333, 18332>,
    <18338, 18332, 17506>,
    <18338, 17506, 18223>,
    <18338, 18223, 18222>,
    <18338, 18222, 18339>,
    <18342, 18343, 18340>,
    <18342, 18340, 18339>,
    <18342, 18339, 18222>,
    <18342, 18222, 18231>,
    <18342, 18231, 18230>,
    <18342, 18230, 18344>,
    <18342, 18344, 18345>,
    <18342, 18345, 18343>,
    <18346, 18341, 18340>,
    <18346, 18340, 18343>,
    <18346, 18343, 18345>,
    <18346, 18345, 18347>,
    <18346, 18347, 18336>,
    <18346, 18336, 18335>,
    <18346, 18335, 18333>,
    <18346, 18333, 18341>,
    <18348, 18349, 18350>,
    <18348, 18350, 18351>,
    <18348, 18351, 18352>,
    <18348, 18352, 18353>,
    <18348, 18353, 18354>,
    <18348, 18354, 18355>,
    <18348, 18355, 18356>,
    <18348, 18356, 18349>,
    <18357, 18358, 18350>,
    <18357, 18350, 18349>,
    <18357, 18349, 18356>,
    <18357, 18356, 18359>,
    <18357, 18359, 18249>,
    <18357, 18249, 18270>,
    <18357, 18270, 18269>,
    <18357, 18269, 18358>,
    <18360, 18351, 18350>,
    <18360, 18350, 18358>,
    <18360, 18358, 18269>,
    <18360, 18269, 18275>,
    <18360, 18275, 17419>,
    <18360, 17419, 18361>,
    <18360, 18361, 18352>,
    <18360, 18352, 18351>,
    <18362, 18363, 18364>,
    <18362, 18364, 18365>,
    <18362, 18365, 18366>,
    <18362, 18366, 18367>,
    <18362, 18367, 18354>,
    <18362, 18354, 18353>,
    <18362, 18353, 18352>,
    <18362, 18352, 18363>,
    <18368, 18369, 18364>,
    <18368, 18364, 18363>,
    <18368, 18363, 18352>,
    <18368, 18352, 18361>,
    <18368, 18361, 17419>,
    <18368, 17419, 17529>,
    <18368, 17529, 17526>,
    <18368, 17526, 18369>,
    <18370, 18365, 18364>,
    <18370, 18364, 18369>,
    <18370, 18369, 17526>,
    <18370, 17526, 17525>,
    <18370, 17525, 17524>,
    <18370, 17524, 18371>,
    <18370, 18371, 18366>,
    <18370, 18366, 18365>,
    <18372, 18373, 18374>,
    <18372, 18374, 18375>,
    <18372, 18375, 18376>,
    <18372, 18376, 18377>,
    <18372, 18377, 18378>,
    <18372, 18378, 18379>,
    <18372, 18380, 18381>,
    <18372, 18381, 18373>,
    <18382, 18383, 18374>,
    <18382, 18374, 18373>,
    <18382, 18373, 18384>,
    <18382, 18384, 18385>,
    <18382, 18386, 18387>,
    <18382, 18387, 17920>,
    <18382, 17920, 17919>,
    <18382, 17919, 18383>,
    <18388, 18375, 18374>,
    <18388, 18374, 18383>,
    <18388, 18383, 17919>,
    <18388, 17919, 17928>,
    <18388, 17928, 17831>,
    <18388, 17831, 18389>,
    <18388, 18389, 18376>,
    <18388, 18376, 18375>,
    <18390, 18391, 18392>,
    <18390, 18392, 18393>,
    <18390, 18393, 18394>,
    <18390, 18394, 18395>,
    <18390, 18395, 18396>,
    <18390, 18396, 18397>,
    <18390, 18398, 18399>,
    <18390, 18399, 18391>,
    <18400, 18401, 18392>,
    <18400, 18392, 18391>,
    <18400, 18391, 18402>,
    <18400, 18402, 18403>,
    <18400, 18404, 18405>,
    <18400, 18405, 18053>,
    <18400, 18053, 18051>,
    <18400, 18051, 18401>,
    <18406, 18393, 18392>,
    <18406, 18392, 18401>,
    <18406, 18401, 18051>,
    <18406, 18051, 18050>,
    <18406, 18050, 17964>,
    <18406, 17964, 18407>,
    <18406, 18407, 18394>,
    <18406, 18394, 18393>,
    <18408, 18409, 18410>,
    <18408, 18410, 18411>,
    <18408, 18411, 18412>,
    <18408, 18412, 18413>,
    <18408, 18413, 17650>,
    <18408, 17650, 17661>,
    <18408, 17661, 17659>,
    <18408, 17659, 18409>,
    <18414, 18415, 18410>,
    <18414, 18410, 18409>,
    <18414, 18409, 17659>,
    <18414, 17659, 17658>,
    <18414, 17658, 17554>,
    <18414, 17554, 18416>,
    <18414, 18416, 18417>,
    <18414, 18417, 18415>,
    <18418, 18411, 18410>,
    <18418, 18410, 18415>,
    <18418, 18415, 18417>,
    <18418, 18417, 18419>,
    <18418, 18419, 18420>,
    <18418, 18420, 18421>,
    <18418, 18421, 18412>,
    <18418, 18412, 18411>,
    <18422, 18423, 18424>,
    <18422, 18424, 18425>,
    <18422, 18425, 18417>,
    <18422, 18417, 18416>,
    <18422, 18416, 17554>,
    <18422, 17554, 18329>,
    <18422, 18329, 18328>,
    <18422, 18328, 18423>,
    <18426, 18427, 18424>,
    <18426, 18424, 18423>,
    <18426, 18423, 18328>,
    <18426, 18328, 18337>,
    <18426, 18337, 18336>,
    <18426, 18336, 18428>,
    <18426, 18428, 18429>,
    <18426, 18429, 18427>,
    <18430, 18425, 18424>,
    <18430, 18424, 18427>,
    <18430, 18427, 18429>,
    <18430, 18429, 18431>,
    <18430, 18431, 18420>,
    <18430, 18420, 18419>,
    <18430, 18419, 18417>,
    <18430, 18417, 18425>,
    <18432, 18433, 18434>,
    <18432, 18434, 18435>,
    <18432, 18435, 18436>,
    <18432, 18436, 18437>,
    <18432, 18437, 18438>,
    <18432, 18438, 18439>,
    <18432, 18439, 18440>,
    <18432, 18440, 18433>,
    <18441, 18442, 18434>,
    <18441, 18434, 18433>,
    <18441, 18433, 18440>,
    <18441, 18440, 18443>,
    <18441, 18443, 18354>,
    <18441, 18354, 18367>,
    <18441, 18367, 18366>,
    <18441, 18366, 18442>,
    <18444, 18435, 18434>,
    <18444, 18434, 18442>,
    <18444, 18442, 18366>,
    <18444, 18366, 18371>,
    <18444, 18371, 17524>,
    <18444, 17524, 18445>,
    <18444, 18445, 18436>,
    <18444, 18436, 18435>,
    <18446, 18447, 18448>,
    <18446, 18448, 18449>,
    <18446, 18449, 18450>,
    <18446, 18450, 18451>,
    <18446, 18451, 18438>,
    <18446, 18438, 18437>,
    <18446, 18437, 18436>,
    <18446, 18436, 18447>,
    <18452, 18453, 18448>,
    <18452, 18448, 18447>,
    <18452, 18447, 18436>,
    <18452, 18436, 18445>,
    <18452, 18445, 17524>,
    <18452, 17524, 17577>,
    <18452, 17577, 17574>,
    <18452, 17574, 18453>,
    <18454, 18449, 18448>,
    <18454, 18448, 18453>,
    <18454, 18453, 17574>,
    <18454, 17574, 17573>,
    <18454, 17573, 17572>,
    <18454, 17572, 18455>,
    <18454, 18455, 18450>,
    <18454, 18450, 18449>,
    <18456, 18457, 18458>,
    <18456, 18458, 18459>,
    <18456, 18459, 17707>,
    <18456, 17707, 17706>,
    <18456, 17706, 17695>,
    <18456, 17695, 18460>,
    <18456, 18460, 18461>,
    <18456, 18461, 18457>,
    <18462, 18463, 18458>,
    <18462, 18458, 18457>,
    <18462, 18457, 18461>,
    <18462, 18461, 18464>,
    <18462, 18464, 18465>,
    <18462, 18465, 18466>,
    <18462, 18466, 18467>,
    <18462, 18467, 18463>,
    <18468, 18459, 18458>,
    <18468, 18458, 18463>,
    <18468, 18463, 18467>,
    <18468, 18467, 18469>,
    <18468, 18469, 17599>,
    <18468, 17599, 17709>,
    <18468, 17709, 17707>,
    <18468, 17707, 18459>,
    <18470, 18471, 18472>,
    <18470, 18472, 18473>,
    <18470, 18473, 18281>,
    <18470, 18281, 18280>,
    <18470, 18280, 17599>,
    <18470, 17599, 18469>,
    <18470, 18469, 18467>,
    <18470, 18467, 18471>,
    <18474, 18475, 18472>,
    <18474, 18472, 18471>,
    <18474, 18471, 18467>,
    <18474, 18467, 18466>,
    <18474, 18466, 18465>,
    <18474, 18465, 18476>,
    <18474, 18476, 18477>,
    <18474, 18477, 18475>,
    <18478, 18473, 18472>,
    <18478, 18472, 18475>,
    <18478, 18475, 18477>,
    <18478, 18477, 18479>,
    <18478, 18479, 18285>,
    <18478, 18285, 18284>,
    <18478, 18284, 18281>,
    <18478, 18281, 18473>,
    <18480, 18481, 18482>,
    <18480, 18482, 18483>,
    <18480, 18483, 18484>,
    <18480, 18484, 18485>,
    <18480, 18485, 18486>,
    <18480, 18486, 18487>,
    <18480, 18487, 18488>,
    <18480, 18488, 18481>,
    <18489, 18490, 18482>,
    <18489, 18482, 18481>,
    <18489, 18481, 18488>,
    <18489, 18488, 18491>,
    <18489, 18491, 17476>,
    <18489, 17476, 18322>,
    <18489, 18322, 18319>,
    <18489, 18319, 18490>,
    <18492, 18483, 18482>,
    <18492, 18482, 18490>,
    <18492, 18490, 18319>,
    <18492, 18319, 18318>,
    <18492, 18318, 18306>,
    <18492, 18306, 18493>,
    <18492, 18493, 18484>,
    <18492, 18484, 18483>,
    <18494, 18495, 18496>,
    <18494, 18496, 18497>,
    <18494, 18497, 18488>,
    <18494, 18488, 18487>,
    <18494, 18487, 18486>,
    <18494, 18486, 18498>,
    <18494, 18498, 18499>,
    <18494, 18499, 18495>,
    <18500, 18501, 18496>,
    <18500, 18496, 18495>,
    <18500, 18495, 18499>,
    <18500, 18499, 18502>,
    <18500, 18502, 17620>,
    <18500, 17620, 17619>,
    <18500, 17619, 17618>,
    <18500, 17618, 18501>,
    <18503, 18497, 18496>,
    <18503, 18496, 18501>,
    <18503, 18501, 17618>,
    <18503, 17618, 17627>,
    <18503, 17627, 17476>,
    <18503, 17476, 18491>,
    <18503, 18491, 18488>,
    <18503, 18488, 18497>,
    <18504, 18505, 18506>,
    <18504, 18506, 18507>,
    <18504, 18507, 18508>,
    <18504, 18508, 18509>,
    <18504, 18510, 18511>,
    <18504, 18511, 18512>,
    <18504, 18512, 18513>,
    <18504, 18513, 18505>,
    <18514, 18515, 18506>,
    <18514, 18506, 18505>,
    <18514, 18505, 18513>,
    <18514, 18513, 18516>,
    <18514, 18516, 18007>,
    <18514, 18007, 18075>,
    <18514, 18075, 18073>,
    <18514, 18073, 18515>,
    <18517, 18507, 18506>,
    <18517, 18506, 18515>,
    <18517, 18515, 18073>,
    <18517, 18073, 18072>,
    <18517, 18072, 18518>,
    <18517, 18518, 18519>,
    <18517, 18520, 18521>,
    <18517, 18521, 18507>,
    <18522, 18523, 18524>,
    <18522, 18524, 18525>,
    <18522, 18525, 18526>,
    <18522, 18526, 18527>,
    <18522, 18527, 17746>,
    <18522, 17746, 17757>,
    <18522, 17757, 17755>,
    <18522, 17755, 18523>,
    <18528, 18529, 18524>,
    <18528, 18524, 18523>,
    <18528, 18523, 17755>,
    <18528, 17755, 17754>,
    <18528, 17754, 17650>,
    <18528, 17650, 18530>,
    <18528, 18530, 18531>,
    <18528, 18531, 18529>,
    <18532, 18525, 18524>,
    <18532, 18524, 18529>,
    <18532, 18529, 18531>,
    <18532, 18531, 18533>,
    <18532, 18533, 18534>,
    <18532, 18534, 18535>,
    <18532, 18535, 18526>,
    <18532, 18526, 18525>,
    <18536, 18537, 18538>,
    <18536, 18538, 18539>,
    <18536, 18539, 18531>,
    <18536, 18531, 18530>,
    <18536, 18530, 17650>,
    <18536, 17650, 18413>,
    <18536, 18413, 18412>,
    <18536, 18412, 18537>,
    <18540, 18541, 18538>,
    <18540, 18538, 18537>,
    <18540, 18537, 18412>,
    <18540, 18412, 18421>,
    <18540, 18421, 18420>,
    <18540, 18420, 18542>,
    <18540, 18542, 18543>,
    <18540, 18543, 18541>,
    <18544, 18539, 18538>,
    <18544, 18538, 18541>,
    <18544, 18541, 18543>,
    <18544, 18543, 18545>,
    <18544, 18545, 18534>,
    <18544, 18534, 18533>,
    <18544, 18533, 18531>,
    <18544, 18531, 18539>,
    <18546, 18547, 18548>,
    <18546, 18548, 18549>,
    <18546, 18549, 18550>,
    <18546, 18550, 18551>,
    <18546, 18551, 18552>,
    <18546, 18552, 18553>,
    <18546, 18553, 18554>,
    <18546, 18554, 18547>,
    <18555, 18556, 18548>,
    <18555, 18548, 18547>,
    <18555, 18547, 18554>,
    <18555, 18554, 18557>,
    <18555, 18557, 18438>,
    <18555, 18438, 18451>,
    <18555, 18451, 18450>,
    <18555, 18450, 18556>,
    <18558, 18549, 18548>,
    <18558, 18548, 18556>,
    <18558, 18556, 18450>,
    <18558, 18450, 18455>,
    <18558, 18455, 17572>,
    <18558, 17572, 18559>,
    <18558, 18559, 18550>,
    <18558, 18550, 18549>,
    <18560, 18561, 18562>,
    <18560, 18562, 18563>,
    <18560, 18563, 18564>,
    <18560, 18564, 18565>,
    <18560, 18565, 18552>,
    <18560, 18552, 18551>,
    <18560, 18551, 18550>,
    <18560, 18550, 18561>,
    <18566, 18567, 18562>,
    <18566, 18562, 18561>,
    <18566, 18561, 18550>,
    <18566, 18550, 18559>,
    <18566, 18559, 17572>,
    <18566, 17572, 17673>,
    <18566, 17673, 17670>,
    <18566, 17670, 18567>,
    <18568, 18563, 18562>,
    <18568, 18562, 18567>,
    <18568, 18567, 17670>,
    <18568, 17670, 17669>,
    <18568, 17669, 17668>,
    <18568, 17668, 18569>,
    <18568, 18569, 18564>,
    <18568, 18564, 18563>,
    <18570, 18571, 18572>,
    <18570, 18572, 18573>,
    <18570, 18573, 17822>,
    <18570, 17822, 17821>,
    <18570, 17821, 17802>,
    <18570, 17802, 18574>,
    <18570, 18574, 18575>,
    <18570, 18575, 18571>,
    <18576, 18577, 18572>,
    <18576, 18572, 18571>,
    <18576, 18571, 18575>,
    <18576, 18575, 18578>,
    <18576, 18578, 18579>,
    <18576, 18579, 18580>,
    <18576, 18580, 18581>,
    <18576, 18581, 18577>,
    <18582, 18573, 18572>,
    <18582, 18572, 18577>,
    <18582, 18577, 18581>,
    <18582, 18581, 18583>,
    <18582, 18583, 17695>,
    <18582, 17695, 17824>,
    <18582, 17824, 17822>,
    <18582, 17822, 18573>,
    <18584, 18585, 18586>,
    <18584, 18586, 18587>,
    <18584, 18587, 18461>,
    <18584, 18461, 18460>,
    <18584, 18460, 17695>,
    <18584, 17695, 18583>,
    <18584, 18583, 18581>,
    <18584, 18581, 18585>,
    <18588, 18589, 18586>,
    <18588, 18586, 18585>,
    <18588, 18585, 18581>,
    <18588, 18581, 18580>,
    <18588, 18580, 18579>,
    <18588, 18579, 18590>,
    <18588, 18590, 18591>,
    <18588, 18591, 18589>,
    <18592, 18587, 18586>,
    <18592, 18586, 18589>,
    <18592, 18589, 18591>,
    <18592, 18591, 18593>,
    <18592, 18593, 18465>,
    <18592, 18465, 18464>,
    <18592, 18464, 18461>,
    <18592, 18461, 18587>,
    <18594, 18595, 18596>,
    <18594, 18596, 18597>,
    <18594, 18597, 18598>,
    <18594, 18598, 18599>,
    <18594, 18599, 18600>,
    <18594, 18600, 18601>,
    <18594, 18601, 18602>,
    <18594, 18602, 18595>,
    <18603, 18604, 18596>,
    <18603, 18596, 18595>,
    <18603, 18595, 18602>,
    <18603, 18602, 18605>,
    <18603, 18605, 17620>,
    <18603, 17620, 18502>,
    <18603, 18502, 18499>,
    <18603, 18499, 18604>,
    <18606, 18597, 18596>,
    <18606, 18596, 18604>,
    <18606, 18604, 18499>,
    <18606, 18499, 18498>,
    <18606, 18498, 18486>,
    <18606, 18486, 18607>,
    <18606, 18607, 18598>,
    <18606, 18598, 18597>,
    <18608, 18609, 18610>,
    <18608, 18610, 18611>,
    <18608, 18611, 18602>,
    <18608, 18602, 18601>,
    <18608, 18601, 18600>,
    <18608, 18600, 18612>,
    <18608, 18612, 18613>,
    <18608, 18613, 18609>,
    <18614, 18615, 18610>,
    <18614, 18610, 18609>,
    <18614, 18609, 18613>,
    <18614, 18613, 18616>,
    <18614, 18616, 17716>,
    <18614, 17716, 17715>,
    <18614, 17715, 17714>,
    <18614, 17714, 18615>,
    <18617, 18611, 18610>,
    <18617, 18610, 18615>,
    <18617, 18615, 17714>,
    <18617, 17714, 17723>,
    <18617, 17723, 17620>,
    <18617, 17620, 18605>,
    <18617, 18605, 18602>,
    <18617, 18602, 18611>,
    <18618, 18619, 18620>,
    <18618, 18620, 18621>,
    <18618, 18621, 18622>,
    <18618, 18622, 18623>,
    <18618, 18623, 17861>,
    <18618, 17861, 17872>,
    <18618, 17872, 17870>,
    <18618, 17870, 18619>,
    <18624, 18625, 18620>,
    <18624, 18620, 18619>,
    <18624, 18619, 17870>,
    <18624, 17870, 17869>,
    <18624, 17869, 17746>,
    <18624, 17746, 18626>,
    <18624, 18626, 18627>,
    <18624, 18627, 18625>,
    <18628, 18621, 18620>,
    <18628, 18620, 18625>,
    <18628, 18625, 18627>,
    <18628, 18627, 18629>,
    <18628, 18629, 18630>,
    <18628, 18630, 18631>,
    <18628, 18631, 18622>,
    <18628, 18622, 18621>,
    <18632, 18633, 18634>,
    <18632, 18634, 18635>,
    <18632, 18635, 18627>,
    <18632, 18627, 18626>,
    <18632, 18626, 17746>,
    <18632, 17746, 18527>,
    <18632, 18527, 18526>,
    <18632, 18526, 18633>,
    <18636, 18637, 18634>,
    <18636, 18634, 18633>,
    <18636, 18633, 18526>,
    <18636, 18526, 18535>,
    <18636, 18535, 18534>,
    <18636, 18534, 18638>,
    <18636, 18638, 18639>,
    <18636, 18639, 18637>,
    <18640, 18635, 18634>,
    <18640, 18634, 18637>,
    <18640, 18637, 18639>,
    <18640, 18639, 18641>,
    <18640, 18641, 18630>,
    <18640, 18630, 18629>,
    <18640, 18629, 18627>,
    <18640, 18627, 18635>,
    <18642, 18643, 18644>,
    <18642, 18644, 18645>,
    <18642, 18645, 18646>,
    <18642, 18646, 18647>,
    <18642, 18647, 18648>,
    <18642, 18648, 18649>,
    <18642, 18649, 18650>,
    <18642, 18650, 18643>,
    <18651, 18652, 18644>,
    <18651, 18644, 18643>,
    <18651, 18643, 18650>,
    <18651, 18650, 18653>,
    <18651, 18653, 18552>,
    <18651, 18552, 18565>,
    <18651, 18565, 18564>,
    <18651, 18564, 18652>,
    <18654, 18645, 18644>,
    <18654, 18644, 18652>,
    <18654, 18652, 18564>,
    <18654, 18564, 18569>,
    <18654, 18569, 17668>,
    <18654, 17668, 18655>,
    <18654, 18655, 18646>,
    <18654, 18646, 18645>,
    <18656, 18657, 18658>,
    <18656, 18658, 18659>,
    <18656, 18659, 18660>,
    <18656, 18660, 18661>,
    <18656, 18661, 18648>,
    <18656, 18648, 18647>,
    <18656, 18647, 18646>,
    <18656, 18646, 18657>,
    <18662, 18663, 18658>,
    <18662, 18658, 18657>,
    <18662, 18657, 18646>,
    <18662, 18646, 18655>,
    <18662, 18655, 17668>,
    <18662, 17668, 17769>,
    <18662, 17769, 17766>,
    <18662, 17766, 18663>,
    <18664, 18659, 18658>,
    <18664, 18658, 18663>,
    <18664, 18663, 17766>,
    <18664, 17766, 17765>,
    <18664, 17765, 17764>,
    <18664, 17764, 18665>,
    <18664, 18665, 18660>,
    <18664, 18660, 18659>,
    <18666, 18667, 18668>,
    <18666, 18668, 18669>,
    <18666, 18669, 17912>,
    <18666, 17912, 17911>,
    <18666, 17911, 18670>,
    <18666, 18670, 18671>,
    <18666, 18671, 18672>,
    <18666, 18672, 18667>,
    <18673, 18674, 18668>,
    <18673, 18668, 18667>,
    <18673, 18667, 18672>,
    <18673, 18672, 18675>,
    <18673, 18675, 18676>,
    <18673, 18676, 18677>,
    <18673, 18677, 18678>,
    <18673, 18678, 18674>,
    <18679, 18669, 18668>,
    <18679, 18668, 18674>,
    <18679, 18674, 18678>,
    <18679, 18678, 18680>,
    <18679, 18680, 17802>,
    <18679, 17802, 17914>,
    <18679, 17914, 17912>,
    <18679, 17912, 18669>,
    <18681, 18682, 18683>,
    <18681, 18683, 18684>,
    <18681, 18684, 18672>,
    <18681, 18672, 18671>,
    <18681, 18671, 18685>,
    <18681, 18685, 18686>,
    <18681, 18687, 18688>,
    <18681, 18688, 18682>,
    <18689, 18690, 18683>,
    <18689, 18683, 18682>,
    <18689, 18682, 18691>,
    <18689, 18691, 18692>,
    <18689, 18693, 18694>,
    <18689, 18694, 18695>,
    <18689, 18695, 18696>,
    <18689, 18696, 18690>,
    <18697, 18684, 18683>,
    <18697, 18683, 18690>,
    <18697, 18690, 18696>,
    <18697, 18696, 18698>,
    <18697, 18698, 18676>,
    <18697, 18676, 18675>,
    <18697, 18675, 18672>,
    <18697, 18672, 18684>,
    <18699, 18700, 18701>,
    <18699, 18701, 18702>,
    <18699, 18702, 18575>,
    <18699, 18575, 18574>,
    <18699, 18574, 17802>,
    <18699, 17802, 18680>,
    <18699, 18680, 18678>,
    <18699, 18678, 18700>,
    <18703, 18704, 18701>,
    <18703, 18701, 18700>,
    <18703, 18700, 18678>,
    <18703, 18678, 18677>,
    <18703, 18677, 18676>,
    <18703, 18676, 18705>,
    <18703, 18705, 18706>,
    <18703, 18706, 18704>,
    <18707, 18702, 18701>,
    <18707, 18701, 18704>,
    <18707, 18704, 18706>,
    <18707, 18706, 18708>,
    <18707, 18708, 18579>,
    <18707, 18579, 18578>,
    <18707, 18578, 18575>,
    <18707, 18575, 18702>,
    <18709, 18710, 18711>,
    <18709, 18711, 18712>,
    <18709, 18712, 18713>,
    <18709, 18713, 18714>,
    <18709, 18714, 18715>,
    <18709, 18715, 18716>,
    <18709, 18716, 18717>,
    <18709, 18717, 18710>,
    <18718, 18719, 18711>,
    <18718, 18711, 18710>,
    <18718, 18710, 18717>,
    <18718, 18717, 18720>,
    <18718, 18720, 17716>,
    <18718, 17716, 18616>,
    <18718, 18616, 18613>,
    <18718, 18613, 18719>,
    <18721, 18712, 18711>,
    <18721, 18711, 18719>,
    <18721, 18719, 18613>,
    <18721, 18613, 18612>,
    <18721, 18612, 18600>,
    <18721, 18600, 18722>,
    <18721, 18722, 18713>,
    <18721, 18713, 18712>,
    <18723, 18724, 18725>,
    <18723, 18725, 18726>,
    <18723, 18726, 18717>,
    <18723, 18717, 18716>,
    <18723, 18716, 18715>,
    <18723, 18715, 18727>,
    <18723, 18727, 18728>,
    <18723, 18728, 18724>,
    <18729, 18730, 18725>,
    <18729, 18725, 18724>,
    <18729, 18724, 18728>,
    <18729, 18728, 18731>,
    <18729, 18731, 17831>,
    <18729, 17831, 17830>,
    <18729, 17830, 17829>,
    <18729, 17829, 18730>,
    <18732, 18726, 18725>,
    <18732, 18725, 18730>,
    <18732, 18730, 17829>,
    <18732, 17829, 17838>,
    <18732, 17838, 17716>,
    <18732, 17716, 18720>,
    <18732, 18720, 18717>,
    <18732, 18717, 18726>,
    <18733, 18734, 18735>,
    <18733, 18735, 18736>,
    <18733, 18736, 18737>,
    <18733, 18737, 18738>,
    <18733, 18738, 17964>,
    <18733, 17964, 17986>,
    <18733, 17986, 17984>,
    <18733, 17984, 18734>,
    <18739, 18740, 18735>,
    <18739, 18735, 18734>,
    <18739, 18734, 17984>,
    <18739, 17984, 17983>,
    <18739, 17983, 17861>,
    <18739, 17861, 18741>,
    <18739, 18741, 18742>,
    <18739, 18742, 18740>,
    <18743, 18736, 18735>,
    <18743, 18735, 18740>,
    <18743, 18740, 18742>,
    <18743, 18742, 18744>,
    <18743, 18744, 18745>,
    <18743, 18745, 18746>,
    <18743, 18746, 18737>,
    <18743, 18737, 18736>,
    <18747, 18748, 18749>,
    <18747, 18749, 18750>,
    <18747, 18750, 18742>,
    <18747, 18742, 18741>,
    <18747, 18741, 17861>,
    <18747, 17861, 18623>,
    <18747, 18623, 18622>,
    <18747, 18622, 18748>,
    <18751, 18752, 18749>,
    <18751, 18749, 18748>,
    <18751, 18748, 18622>,
    <18751, 18622, 18631>,
    <18751, 18631, 18630>,
    <18751, 18630, 18753>,
    <18751, 18753, 18754>,
    <18751, 18754, 18752>,
    <18755, 18750, 18749>,
    <18755, 18749, 18752>,
    <18755, 18752, 18754>,
    <18755, 18754, 18756>,
    <18755, 18756, 18745>,
    <18755, 18745, 18744>,
    <18755, 18744, 18742>,
    <18755, 18742, 18750>,
    <18757, 18758, 18759>,
    <18757, 18759, 18760>,
    <18757, 18760, 18761>,
    <18757, 18761, 18762>,
    <18757, 18762, 18763>,
    <18757, 18763, 18764>,
    <18757, 18764, 18765>,
    <18757, 18765, 18758>,
    <18766, 18767, 18759>,
    <18766, 18759, 18758>,
    <18766, 18758, 18765>,
    <18766, 18765, 18768>,
    <18766, 18768, 18648>,
    <18766, 18648, 18661>,
    <18766, 18661, 18660>,
    <18766, 18660, 18767>,
    <18769, 18760, 18759>,
    <18769, 18759, 18767>,
    <18769, 18767, 18660>,
    <18769, 18660, 18665>,
    <18769, 18665, 17764>,
    <18769, 17764, 18770>,
    <18769, 18770, 18761>,
    <18769, 18761, 18760>,
    <18771, 18772, 18773>,
    <18771, 18773, 18774>,
    <18771, 18774, 18775>,
    <18771, 18775, 18776>,
    <18771, 18776, 18763>,
    <18771, 18763, 18762>,
    <18771, 18762, 18761>,
    <18771, 18761, 18772>,
    <18777, 18778, 18773>,
    <18777, 18773, 18772>,
    <18777, 18772, 18761>,
    <18777, 18761, 18770>,
    <18777, 18770, 17764>,
    <18777, 17764, 17884>,
    <18777, 17884, 17881>,
    <18777, 17881, 18778>,
    <18779, 18774, 18773>,
    <18779, 18773, 18778>,
    <18779, 18778, 17881>,
    <18779, 17881, 17880>,
    <18779, 17880, 17879>,
    <18779, 17879, 18780>,
    <18779, 18780, 18775>,
    <18779, 18775, 18774>,
    <18781, 18782, 18783>,
    <18781, 18783, 18784>,
    <18781, 18784, 18785>,
    <18781, 18785, 18786>,
    <18781, 18786, 18787>,
    <18781, 18787, 18788>,
    <18781, 18789, 18790>,
    <18781, 18790, 18782>,
    <18791, 18792, 18783>,
    <18791, 18783, 18782>,
    <18791, 18782, 18793>,
    <18791, 18793, 18794>,
    <18791, 18795, 18796>,
    <18791, 18796, 18377>,
    <18791, 18377, 18376>,
    <18791, 18376, 18792>,
    <18797, 18784, 18783>,
    <18797, 18783, 18792>,
    <18797, 18792, 18376>,
    <18797, 18376, 18389>,
    <18797, 18389, 17831>,
    <18797, 17831, 18798>,
    <18797, 18798, 18785>,
    <18797, 18785, 18784>,
    <18799, 18800, 18801>,
    <18799, 18801, 18802>,
    <18799, 18802, 18696>,
    <18799, 18696, 18695>,
    <18799, 18695, 18803>,
    <18799, 18803, 18804>,
    <18799, 18805, 18806>,
    <18799, 18806, 18800>,
    <18807, 18808, 18801>,
    <18807, 18801, 18800>,
    <18807, 18800, 18809>,
    <18807, 18809, 18810>,
    <18807, 18811, 18812>,
    <18807, 18812, 18813>,
    <18807, 18813, 18814>,
    <18807, 18814, 18808>,
    <18815, 18802, 18801>,
    <18815, 18801, 18808>,
    <18815, 18808, 18814>,
    <18815, 18814, 18816>,
    <18815, 18816, 18676>,
    <18815, 18676, 18698>,
    <18815, 18698, 18696>,
    <18815, 18696, 18802>,
    <18817, 18818, 18819>,
    <18817, 18819, 18820>,
    <18817, 18820, 18821>,
    <18817, 18821, 18822>,
    <18817, 18822, 18823>,
    <18817, 18823, 18786>,
    <18817, 18786, 18785>,
    <18817, 18785, 18818>,
    <18824, 18825, 18819>,
    <18824, 18819, 18818>,
    <18824, 18818, 18785>,
    <18824, 18785, 18798>,
    <18824, 18798, 17831>,
    <18824, 17831, 18731>,
    <18824, 18731, 18728>,
    <18824, 18728, 18825>,
    <18826, 18820, 18819>,
    <18826, 18819, 18825>,
    <18826, 18825, 18728>,
    <18826, 18728, 18727>,
    <18826, 18727, 18715>,
    <18826, 18715, 18827>,
    <18826, 18827, 18821>,
    <18826, 18821, 18820>,
    <18828, 18829, 18830>,
    <18828, 18830, 18831>,
    <18828, 18831, 18832>,
    <18828, 18832, 18833>,
    <18828, 18833, 18834>,
    <18828, 18834, 18835>,
    <18828, 18836, 18837>,
    <18828, 18837, 18829>,
    <18838, 18839, 18830>,
    <18838, 18830, 18829>,
    <18838, 18829, 18840>,
    <18838, 18840, 18841>,
    <18838, 18842, 18843>,
    <18838, 18843, 18844>,
    <18838, 18844, 18845>,
    <18838, 18845, 18839>,
    <18846, 18831, 18830>,
    <18846, 18830, 18839>,
    <18846, 18839, 18845>,
    <18846, 18845, 18847>,
    <18846, 18847, 18848>,
    <18846, 18848, 18849>,
    <18846, 18849, 18832>,
    <18846, 18832, 18831>,
    <18850, 18851, 18852>,
    <18850, 18852, 18853>,
    <18850, 18853, 18845>,
    <18850, 18845, 18844>,
    <18850, 18844, 18854>,
    <18850, 18854, 18395>,
    <18850, 18395, 18394>,
    <18850, 18394, 18851>,
    <18855, 18856, 18852>,
    <18855, 18852, 18851>,
    <18855, 18851, 18394>,
    <18855, 18394, 18407>,
    <18855, 18407, 17964>,
    <18855, 17964, 18857>,
    <18855, 18857, 18858>,
    <18855, 18858, 18856>,
    <18859, 18853, 18852>,
    <18859, 18852, 18856>,
    <18859, 18856, 18858>,
    <18859, 18858, 18860>,
    <18859, 18860, 18848>,
    <18859, 18848, 18847>,
    <18859, 18847, 18845>,
    <18859, 18845, 18853>,
    <18861, 18862, 18863>,
    <18861, 18863, 18864>,
    <18861, 18864, 18858>,
    <18861, 18858, 18857>,
    <18861, 18857, 17964>,
    <18861, 17964, 18738>,
    <18861, 18738, 18737>,
    <18861, 18737, 18862>,
    <18865, 18866, 18863>,
    <18865, 18863, 18862>,
    <18865, 18862, 18737>,
    <18865, 18737, 18746>,
    <18865, 18746, 18745>,
    <18865, 18745, 18867>,
    <18865, 18867, 18868>,
    <18865, 18868, 18866>,
    <18869, 18864, 18863>,
    <18869, 18863, 18866>,
    <18869, 18866, 18868>,
    <18869, 18868, 18870>,
    <18869, 18870, 18848>,
    <18869, 18848, 18860>,
    <18869, 18860, 18858>,
    <18869, 18858, 18864>,
    <18871, 18872, 18873>,
    <18871, 18873, 18874>,
    <18871, 18874, 18875>,
    <18871, 18875, 18876>,
    <18871, 18876, 18877>,
    <18871, 18877, 18878>,
    <18871, 18879, 18880>,
    <18871, 18880, 18872>,
    <18881, 18882, 18873>,
    <18881, 18873, 18872>,
    <18881, 18872, 18883>,
    <18881, 18883, 18884>,
    <18881, 18885, 18886>,
    <18881, 18886, 18887>,
    <18881, 18887, 18888>,
    <18881, 18888, 18882>,
    <18889, 18874, 18873>,
    <18889, 18873, 18882>,
    <18889, 18882, 18888>,
    <18889, 18888, 18890>,
    <18889, 18890, 18891>,
    <18889, 18891, 18892>,
    <18889, 18892, 18875>,
    <18889, 18875, 18874>,
    <18893, 18894, 18895>,
    <18893, 18895, 18896>,
    <18893, 18896, 18897>,
    <18893, 18897, 18898>,
    <18893, 18898, 18891>,
    <18893, 18891, 18899>,
    <18893, 18899, 18900>,
    <18893, 18900, 18894>,
    <18901, 18902, 18895>,
    <18901, 18895, 18894>,
    <18901, 18894, 18900>,
    <18901, 18900, 18903>,
    <18901, 18903, 18763>,
    <18901, 18763, 18776>,
    <18901, 18776, 18775>,
    <18901, 18775, 18902>,
    <18904, 18896, 18895>,
    <18904, 18895, 18902>,
    <18904, 18902, 18775>,
    <18904, 18775, 18780>,
    <18904, 18780, 17879>,
    <18904, 17879, 18905>,
    <18904, 18905, 18897>,
    <18904, 18897, 18896>,
    <18906, 18907, 18908>,
    <18906, 18908, 18909>,
    <18906, 18909, 18513>,
    <18906, 18513, 18512>,
    <18906, 18512, 18910>,
    <18906, 18910, 18876>,
    <18906, 18876, 18875>,
    <18906, 18875, 18907>,
    <18911, 18912, 18908>,
    <18911, 18908, 18907>,
    <18911, 18907, 18875>,
    <18911, 18875, 18892>,
    <18911, 18892, 18891>,
    <18911, 18891, 18913>,
    <18911, 18913, 18914>,
    <18911, 18914, 18912>,
    <18915, 18909, 18908>,
    <18915, 18908, 18912>,
    <18915, 18912, 18914>,
    <18915, 18914, 18916>,
    <18915, 18916, 18007>,
    <18915, 18007, 18516>,
    <18915, 18516, 18513>,
    <18915, 18513, 18909>,
    <18917, 18918, 18919>,
    <18917, 18919, 18920>,
    <18917, 18920, 18914>,
    <18917, 18914, 18913>,
    <18917, 18913, 18891>,
    <18917, 18891, 18898>,
    <18917, 18898, 18897>,
    <18917, 18897, 18918>,
    <18921, 18922, 18919>,
    <18921, 18919, 18918>,
    <18921, 18918, 18897>,
    <18921, 18897, 18905>,
    <18921, 18905, 17879>,
    <18921, 17879, 18019>,
    <18921, 18019, 18016>,
    <18921, 18016, 18922>,
    <18923, 18920, 18919>,
    <18923, 18919, 18922>,
    <18923, 18922, 18016>,
    <18923, 18016, 18015>,
    <18923, 18015, 18007>,
    <18923, 18007, 18916>,
    <18923, 18916, 18914>,
    <18923, 18914, 18920>,
    <18924, 18925, 18926>,
    <18924, 18926, 18927>,
    <18924, 18927, 18115>,
    <18924, 18115, 18114>,
    <18924, 18114, 18103>,
    <18924, 18103, 18928>,
    <18924, 18928, 18929>,
    <18924, 18929, 18925>,
    <18930, 18931, 18926>,
    <18930, 18926, 18925>,
    <18930, 18925, 18929>,
    <18930, 18929, 18932>,
    <18930, 18932, 18933>,
    <18930, 18933, 4898>,
    <18930, 4898, 4896>,
    <18930, 4896, 18931>,
    <18934, 18927, 18926>,
    <18934, 18926, 18931>,
    <18934, 18931, 4896>,
    <18934, 4896, 4895>,
    <18934, 4895, 18935>,
    <18934, 18935, 18117>,
    <18934, 18117, 18115>,
    <18934, 18115, 18927>,
    <18936, 18937, 18938>,
    <18936, 18938, 18939>,
    <18936, 18939, 18173>,
    <18936, 18173, 18172>,
    <18936, 18172, 18161>,
    <18936, 18161, 18940>,
    <18936, 18940, 18941>,
    <18936, 18941, 18937>,
    <18942, 18943, 18938>,
    <18942, 18938, 18937>,
    <18942, 18937, 18941>,
    <18942, 18941, 18944>,
    <18942, 18944, 18945>,
    <18942, 18945, 18946>,
    <18942, 18946, 18947>,
    <18942, 18947, 18943>,
    <18948, 18939, 18938>,
    <18948, 18938, 18943>,
    <18948, 18943, 18947>,
    <18948, 18947, 18949>,
    <18948, 18949, 18103>,
    <18948, 18103, 18175>,
    <18948, 18175, 18173>,
    <18948, 18173, 18939>,
    <18950, 18951, 18952>,
    <18950, 18952, 18953>,
    <18950, 18953, 18929>,
    <18950, 18929, 18928>,
    <18950, 18928, 18103>,
    <18950, 18103, 18949>,
    <18950, 18949, 18947>,
    <18950, 18947, 18951>,
    <18954, 18955, 18952>,
    <18954, 18952, 18951>,
    <18954, 18951, 18947>,
    <18954, 18947, 18946>,
    <18954, 18946, 18945>,
    <18954, 18945, 18956>,
    <18954, 18956, 18957>,
    <18954, 18957, 18955>,
    <18958, 18953, 18952>,
    <18958, 18952, 18955>,
    <18958, 18955, 18957>,
    <18958, 18957, 18959>,
    <18958, 18959, 18960>,
    <18958, 18960, 18932>,
    <18958, 18932, 18929>,
    <18958, 18929, 18953>,
    <18961, 18962, 18963>,
    <18961, 18963, 18964>,
    <18961, 18964, 18965>,
    <18961, 18965, 18966>,
    <18961, 18966, 18967>,
    <18961, 18967, 18968>,
    <18961, 18968, 18969>,
    <18961, 18969, 18962>,
    <18970, 18971, 18963>,
    <18970, 18963, 18962>,
    <18970, 18962, 18969>,
    <18970, 18969, 18972>,
    <18970, 18972, 18973>,
    <18970, 18973, 18974>,
    <18970, 18975, 18976>,
    <18970, 18976, 18971>,
    <18977, 18964, 18963>,
    <18977, 18963, 18971>,
    <18977, 18971, 18978>,
    <18977, 18978, 18979>,
    <18977, 18980, 18981>,
    <18977, 18981, 18982>,
    <18977, 18982, 18965>,
    <18977, 18965, 18964>,
    <18983, 18984, 18985>,
    <18983, 18985, 18986>,
    <18983, 18986, 18969>,
    <18983, 18969, 18968>,
    <18983, 18968, 18967>,
    <18983, 18967, 18987>,
    <18983, 18987, 18988>,
    <18983, 18988, 18984>,
    <18989, 18990, 18985>,
    <18989, 18985, 18984>,
    <18989, 18984, 18988>,
    <18989, 18988, 18991>,
    <18989, 18991, 18125>,
    <18989, 18125, 18124>,
    <18989, 18124, 18123>,
    <18989, 18123, 18990>,
    <18992, 18986, 18985>,
    <18992, 18985, 18990>,
    <18992, 18990, 18123>,
    <18992, 18123, 18140>,
    <18992, 18140, 18993>,
    <18992, 18993, 18972>,
    <18992, 18972, 18969>,
    <18992, 18969, 18986>,
    <18994, 18995, 18996>,
    <18994, 18996, 18997>,
    <18994, 18997, 18998>,
    <18994, 18998, 18999>,
    <18994, 19000, 19001>,
    <18994, 19001, 18833>,
    <18994, 18833, 18832>,
    <18994, 18832, 18995>,
    <19002, 19003, 18996>,
    <19002, 18996, 18995>,
    <19002, 18995, 18832>,
    <19002, 18832, 18849>,
    <19002, 18849, 18848>,
    <19002, 18848, 19004>,
    <19002, 19004, 19005>,
    <19002, 19005, 19003>,
    <19006, 18997, 18996>,
    <19006, 18996, 19003>,
    <19006, 19003, 19005>,
    <19006, 19005, 19007>,
    <19006, 19007, 19008>,
    <19006, 19008, 19009>,
    <19006, 19010, 19011>,
    <19006, 19011, 18997>,
    <19012, 19013, 19014>,
    <19012, 19014, 19015>,
    <19012, 19015, 18888>,
    <19012, 18888, 18887>,
    <19012, 18887, 19016>,
    <19012, 19016, 19017>,
    <19012, 19018, 19019>,
    <19012, 19019, 19013>,
    <19020, 19021, 19014>,
    <19020, 19014, 19013>,
    <19020, 19013, 19022>,
    <19020, 19022, 19023>,
    <19020, 19024, 19025>,
    <19020, 19025, 19026>,
    <19020, 19026, 19027>,
    <19020, 19027, 19021>,
    <19028, 19015, 19014>,
    <19028, 19014, 19021>,
    <19028, 19021, 19027>,
    <19028, 19027, 19029>,
    <19028, 19029, 18891>,
    <19028, 18891, 18890>,
    <19028, 18890, 18888>,
    <19028, 18888, 19015>,
    <19030, 19031, 19032>,
    <19030, 19032, 19033>,
    <19030, 19033, 18297>,
    <19030, 18297, 18296>,
    <19030, 18296, 18285>,
    <19030, 18285, 19034>,
    <19030, 19034, 19035>,
    <19030, 19035, 19031>,
    <19036, 19037, 19032>,
    <19036, 19032, 19031>,
    <19036, 19031, 19035>,
    <19036, 19035, 19038>,
    <19036, 19038, 19039>,
    <19036, 19039, 19040>,
    <19036, 19040, 19041>,
    <19036, 19041, 19037>,
    <19042, 19033, 19032>,
    <19042, 19032, 19037>,
    <19042, 19037, 19041>,
    <19042, 19041, 19043>,
    <19042, 19043, 18161>,
    <19042, 18161, 18299>,
    <19042, 18299, 18297>,
    <19042, 18297, 19033>,
    <19044, 19045, 19046>,
    <19044, 19046, 19047>,
    <19044, 19047, 18941>,
    <19044, 18941, 18940>,
    <19044, 18940, 18161>,
    <19044, 18161, 19043>,
    <19044, 19043, 19041>,
    <19044, 19041, 19045>,
    <19048, 19049, 19046>,
    <19048, 19046, 19045>,
    <19048, 19045, 19041>,
    <19048, 19041, 19040>,
    <19048, 19040, 19039>,
    <19048, 19039, 19050>,
    <19048, 19050, 19051>,
    <19048, 19051, 19049>,
    <19052, 19047, 19046>,
    <19052, 19046, 19049>,
    <19052, 19049, 19051>,
    <19052, 19051, 19053>,
    <19052, 19053, 18945>,
    <19052, 18945, 18944>,
    <19052, 18944, 18941>,
    <19052, 18941, 19047>,
    <19054, 19055, 19056>,
    <19054, 19056, 19057>,
    <19054, 19057, 19058>,
    <19054, 19058, 19059>,
    <19054, 19059, 19060>,
    <19054, 19060, 19061>,
    <19054, 19061, 19062>,
    <19054, 19062, 19055>,
    <19063, 19064, 19056>,
    <19063, 19056, 19055>,
    <19063, 19055, 19062>,
    <19063, 19062, 19065>,
    <19063, 19065, 18125>,
    <19063, 18125, 18991>,
    <19063, 18991, 18988>,
    <19063, 18988, 19064>,
    <19066, 19057, 19056>,
    <19066, 19056, 19064>,
    <19066, 19064, 18988>,
    <19066, 18988, 18987>,
    <19066, 18987, 18967>,
    <19066, 18967, 19067>,
    <19066, 19067, 19058>,
    <19066, 19058, 19057>,
    <19068, 19069, 19070>,
    <19068, 19070, 19071>,
    <19068, 19071, 19062>,
    <19068, 19062, 19061>,
    <19068, 19061, 19060>,
    <19068, 19060, 19072>,
    <19068, 19072, 19073>,
    <19068, 19073, 19069>,
    <19074, 19075, 19070>,
    <19074, 19070, 19069>,
    <19074, 19069, 19073>,
    <19074, 19073, 19076>,
    <19074, 19076, 18182>,
    <19074, 18182, 18181>,
    <19074, 18181, 18180>,
    <19074, 18180, 19075>,
    <19077, 19071, 19070>,
    <19077, 19070, 19075>,
    <19077, 19075, 18180>,
    <19077, 18180, 18189>,
    <19077, 18189, 18125>,
    <19077, 18125, 19065>,
    <19077, 19065, 19062>,
    <19077, 19062, 19071>,
    <19078, 19079, 19080>,
    <19078, 19080, 19081>,
    <19078, 19081, 19082>,
    <19078, 19082, 19083>,
    <19078, 19083, 18230>,
    <19078, 18230, 18242>,
    <19078, 18242, 18240>,
    <19078, 18240, 19079>,
    <19084, 19085, 19080>,
    <19084, 19080, 19079>,
    <19084, 19079, 18240>,
    <19084, 18240, 18239>,
    <19084, 18239, 19086>,
    <19084, 19086, 5041>,
    <19084, 5041, 5040>,
    <19084, 5040, 19085>,
    <19087, 19081, 19080>,
    <19087, 19080, 19085>,
    <19087, 19085, 5040>,
    <19087, 5040, 5057>,
    <19087, 5057, 19088>,
    <19087, 19088, 19089>,
    <19087, 19089, 19082>,
    <19087, 19082, 19081>,
    <19090, 19091, 19092>,
    <19090, 19092, 19093>,
    <19090, 19093, 19094>,
    <19090, 19094, 19095>,
    <19090, 19095, 18336>,
    <19090, 18336, 18347>,
    <19090, 18347, 18345>,
    <19090, 18345, 19091>,
    <19096, 19097, 19092>,
    <19096, 19092, 19091>,
    <19096, 19091, 18345>,
    <19096, 18345, 18344>,
    <19096, 18344, 18230>,
    <19096, 18230, 19098>,
    <19096, 19098, 19099>,
    <19096, 19099, 19097>,
    <19100, 19093, 19092>,
    <19100, 19092, 19097>,
    <19100, 19097, 19099>,
    <19100, 19099, 19101>,
    <19100, 19101, 19102>,
    <19100, 19102, 19103>,
    <19100, 19103, 19094>,
    <19100, 19094, 19093>,
    <19104, 19105, 19106>,
    <19104, 19106, 19107>,
    <19104, 19107, 19099>,
    <19104, 19099, 19098>,
    <19104, 19098, 18230>,
    <19104, 18230, 19083>,
    <19104, 19083, 19082>,
    <19104, 19082, 19105>,
    <19108, 19109, 19106>,
    <19108, 19106, 19105>,
    <19108, 19105, 19082>,
    <19108, 19082, 19089>,
    <19108, 19089, 19110>,
    <19108, 19110, 19111>,
    <19108, 19111, 19112>,
    <19108, 19112, 19109>,
    <19113, 19107, 19106>,
    <19113, 19106, 19109>,
    <19113, 19109, 19112>,
    <19113, 19112, 19114>,
    <19113, 19114, 19102>,
    <19113, 19102, 19101>,
    <19113, 19101, 19099>,
    <19113, 19099, 19107>,
    <19115, 19116, 19117>,
    <19115, 19117, 19118>,
    <19115, 19118, 19119>,
    <19115, 19119, 19120>,
    <19115, 19120, 19121>,
    <19115, 19121, 19122>,
    <19115, 19122, 19123>,
    <19115, 19123, 19116>,
    <19124, 19125, 19117>,
    <19124, 19117, 19116>,
    <19124, 19116, 19123>,
    <19124, 19123, 19126>,
    <19124, 19126, 19127>,
    <19124, 19127, 19128>,
    <19124, 19129, 19130>,
    <19124, 19130, 19125>,
    <19131, 19118, 19117>,
    <19131, 19117, 19125>,
    <19131, 19125, 19132>,
    <19131, 19132, 19133>,
    <19131, 19134, 19135>,
    <19131, 19135, 19136>,
    <19131, 19136, 19119>,
    <19131, 19119, 19118>,
    <19137, 19138, 19139>,
    <19137, 19139, 19140>,
    <19137, 19140, 19141>,
    <19137, 19141, 19142>,
    <19137, 19142, 19121>,
    <19137, 19121, 19120>,
    <19137, 19120, 19119>,
    <19137, 19119, 19138>,
    <19143, 19144, 19139>,
    <19143, 19139, 19138>,
    <19143, 19138, 19119>,
    <19143, 19119, 19136>,
    <19143, 19136, 19145>,
    <19143, 19145, 18254>,
    <19143, 18254, 18251>,
    <19143, 18251, 19144>,
    <19146, 19140, 19139>,
    <19146, 19139, 19144>,
    <19146, 19144, 18251>,
    <19146, 18251, 18250>,
    <19146, 18250, 18249>,
    <19146, 18249, 19147>,
    <19146, 19147, 19141>,
    <19146, 19141, 19140>,
    <19148, 19149, 19150>,
    <19148, 19150, 19151>,
    <19148, 19151, 18477>,
    <19148, 18477, 18476>,
    <19148, 18476, 18465>,
    <19148, 18465, 19152>,
    <19148, 19152, 19153>,
    <19148, 19153, 19149>,
    <19154, 19155, 19150>,
    <19154, 19150, 19149>,
    <19154, 19149, 19153>,
    <19154, 19153, 19156>,
    <19154, 19156, 19157>,
    <19154, 19157, 19158>,
    <19154, 19158, 19159>,
    <19154, 19159, 19155>,
    <19160, 19151, 19150>,
    <19160, 19150, 19155>,
    <19160, 19155, 19159>,
    <19160, 19159, 19161>,
    <19160, 19161, 18285>,
    <19160, 18285, 18479>,
    <19160, 18479, 18477>,
    <19160, 18477, 19151>,
    <19162, 19163, 19164>,
    <19162, 19164, 19165>,
    <19162, 19165, 19035>,
    <19162, 19035, 19034>,
    <19162, 19034, 18285>,
    <19162, 18285, 19161>,
    <19162, 19161, 19159>,
    <19162, 19159, 19163>,
    <19166, 19167, 19164>,
    <19166, 19164, 19163>,
    <19166, 19163, 19159>,
    <19166, 19159, 19158>,
    <19166, 19158, 19157>,
    <19166, 19157, 19168>,
    <19166, 19168, 19169>,
    <19166, 19169, 19167>,
    <19170, 19165, 19164>,
    <19170, 19164, 19167>,
    <19170, 19167, 19169>,
    <19170, 19169, 19171>,
    <19170, 19171, 19039>,
    <19170, 19039, 19038>,
    <19170, 19038, 19035>,
    <19170, 19035, 19165>,
    <19172, 19173, 19174>,
    <19172, 19174, 19175>,
    <19172, 19175, 19176>,
    <19172, 19176, 19177>,
    <19172, 19177, 19178>,
    <19172, 19178, 19179>,
    <19172, 19179, 19180>,
    <19172, 19180, 19173>,
    <19181, 19182, 19174>,
    <19181, 19174, 19173>,
    <19181, 19173, 19180>,
    <19181, 19180, 19183>,
    <19181, 19183, 18182>,
    <19181, 18182, 19076>,
    <19181, 19076, 19073>,
    <19181, 19073, 19182>,
    <19184, 19175, 19174>,
    <19184, 19174, 19182>,
    <19184, 19182, 19073>,
    <19184, 19073, 19072>,
    <19184, 19072, 19060>,
    <19184, 19060, 19185>,
    <19184, 19185, 19176>,
    <19184, 19176, 19175>,
    <19186, 19187, 19188>,
    <19186, 19188, 19189>,
    <19186, 19189, 19180>,
    <19186, 19180, 19179>,
    <19186, 19179, 19178>,
    <19186, 19178, 19190>,
    <19186, 19190, 19191>,
    <19186, 19191, 19187>,
    <19192, 19193, 19188>,
    <19192, 19188, 19187>,
    <19192, 19187, 19191>,
    <19192, 19191, 19194>,
    <19192, 19194, 18306>,
    <19192, 18306, 18305>,
    <19192, 18305, 18304>,
    <19192, 18304, 19193>,
    <19195, 19189, 19188>,
    <19195, 19188, 19193>,
    <19195, 19193, 18304>,
    <19195, 18304, 18313>,
    <19195, 18313, 18182>,
    <19195, 18182, 19183>,
    <19195, 19183, 19180>,
    <19195, 19180, 19189>,
    <19196, 19197, 19198>,
    <19196, 19198, 19199>,
    <19196, 19199, 19200>,
    <19196, 19200, 19201>,
    <19196, 19201, 18420>,
    <19196, 18420, 18431>,
    <19196, 18431, 18429>,
    <19196, 18429, 19197>,
    <19202, 19203, 19198>,
    <19202, 19198, 19197>,
    <19202, 19197, 18429>,
    <19202, 18429, 18428>,
    <19202, 18428, 18336>,
    <19202, 18336, 19204>,
    <19202, 19204, 19205>,
    <19202, 19205, 19203>,
    <19206, 19199, 19198>,
    <19206, 19198, 19203>,
    <19206, 19203, 19205>,
    <19206, 19205, 19207>,
    <19206, 19207, 19208>,
    <19206, 19208, 19209>,
    <19206, 19209, 19200>,
    <19206, 19200, 19199>,
    <19210, 19211, 19212>,
    <19210, 19212, 19213>,
    <19210, 19213, 19205>,
    <19210, 19205, 19204>,
    <19210, 19204, 18336>,
    <19210, 18336, 19095>,
    <19210, 19095, 19094>,
    <19210, 19094, 19211>,
    <19214, 19215, 19212>,
    <19214, 19212, 19211>,
    <19214, 19211, 19094>,
    <19214, 19094, 19103>,
    <19214, 19103, 19102>,
    <19214, 19102, 19216>,
    <19214, 19216, 19217>,
    <19214, 19217, 19215>,
    <19218, 19213, 19212>,
    <19218, 19212, 19215>,
    <19218, 19215, 19217>,
    <19218, 19217, 19219>,
    <19218, 19219, 19208>,
    <19218, 19208, 19207>,
    <19218, 19207, 19205>,
    <19218, 19205, 19213>,
    <19220, 19221, 19222>,
    <19220, 19222, 19223>,
    <19220, 19223, 19224>,
    <19220, 19224, 19225>,
    <19220, 19225, 19226>,
    <19220, 19226, 19227>,
    <19220, 19227, 19228>,
    <19220, 19228, 19221>,
    <19229, 19230, 19222>,
    <19229, 19222, 19221>,
    <19229, 19221, 19228>,
    <19229, 19228, 19231>,
    <19229, 19231, 19121>,
    <19229, 19121, 19142>,
    <19229, 19142, 19141>,
    <19229, 19141, 19230>,
    <19232, 19223, 19222>,
    <19232, 19222, 19230>,
    <19232, 19230, 19141>,
    <19232, 19141, 19147>,
    <19232, 19147, 18249>,
    <19232, 18249, 19233>,
    <19232, 19233, 19224>,
    <19232, 19224, 19223>,
    <19234, 19235, 19236>,
    <19234, 19236, 19237>,
    <19234, 19237, 19238>,
    <19234, 19238, 19239>,
    <19234, 19239, 19226>,
    <19234, 19226, 19225>,
    <19234, 19225, 19224>,
    <19234, 19224, 19235>,
    <19240, 19241, 19236>,
    <19240, 19236, 19235>,
    <19240, 19235, 19224>,
    <19240, 19224, 19233>,
    <19240, 19233, 18249>,
    <19240, 18249, 18359>,
    <19240, 18359, 18356>,
    <19240, 18356, 19241>,
    <19242, 19237, 19236>,
    <19242, 19236, 19241>,
    <19242, 19241, 18356>,
    <19242, 18356, 18355>,
    <19242, 18355, 18354>,
    <19242, 18354, 19243>,
    <19242, 19243, 19238>,
    <19242, 19238, 19237>,
    <19244, 19245, 19246>,
    <19244, 19246, 19247>,
    <19244, 19247, 19248>,
    <19244, 19248, 19249>,
    <19244, 19249, 18534>,
    <19244, 18534, 18545>,
    <19244, 18545, 18543>,
    <19244, 18543, 19245>,
    <19250, 19251, 19246>,
    <19250, 19246, 19245>,
    <19250, 19245, 18543>,
    <19250, 18543, 18542>,
    <19250, 18542, 18420>,
    <19250, 18420, 19252>,
    <19250, 19252, 19253>,
    <19250, 19253, 19251>,
    <19254, 19247, 19246>,
    <19254, 19246, 19251>,
    <19254, 19251, 19253>,
    <19254, 19253, 19255>,
    <19254, 19255, 19256>,
    <19254, 19256, 19257>,
    <19254, 19257, 19248>,
    <19254, 19248, 19247>,
    <19258, 19259, 19260>,
    <19258, 19260, 19261>,
    <19258, 19261, 19253>,
    <19258, 19253, 19252>,
    <19258, 19252, 18420>,
    <19258, 18420, 19201>,
    <19258, 19201, 19200>,
    <19258, 19200, 19259>,
    <19262, 19263, 19260>,
    <19262, 19260, 19259>,
    <19262, 19259, 19200>,
    <19262, 19200, 19209>,
    <19262, 19209, 19208>,
    <19262, 19208, 19264>,
    <19262, 19264, 19265>,
    <19262, 19265, 19263>,
    <19266, 19261, 19260>,
    <19266, 19260, 19263>,
    <19266, 19263, 19265>,
    <19266, 19265, 19267>,
    <19266, 19267, 19256>,
    <19266, 19256, 19255>,
    <19266, 19255, 19253>,
    <19266, 19253, 19261>,
    <19268, 19269, 19270>,
    <19268, 19270, 19271>,
    <19268, 19271, 19272>,
    <19268, 19272, 19273>,
    <19268, 19273, 19274>,
    <19268, 19274, 19275>,
    <19268, 19275, 19276>,
    <19268, 19276, 19269>,
    <19277, 19278, 19270>,
    <19277, 19270, 19269>,
    <19277, 19269, 19276>,
    <19277, 19276, 19279>,
    <19277, 19279, 19226>,
    <19277, 19226, 19239>,
    <19277, 19239, 19238>,
    <19277, 19238, 19278>,
    <19280, 19271, 19270>,
    <19280, 19270, 19278>,
    <19280, 19278, 19238>,
    <19280, 19238, 19243>,
    <19280, 19243, 18354>,
    <19280, 18354, 19281>,
    <19280, 19281, 19272>,
    <19280, 19272, 19271>,
    <19282, 19283, 19284>,
    <19282, 19284, 19285>,
    <19282, 19285, 19286>,
    <19282, 19286, 19287>,
    <19282, 19287, 19274>,
    <19282, 19274, 19273>,
    <19282, 19273, 19272>,
    <19282, 19272, 19283>,
    <19288, 19289, 19284>,
    <19288, 19284, 19283>,
    <19288, 19283, 19272>,
    <19288, 19272, 19281>,
    <19288, 19281, 18354>,
    <19288, 18354, 18443>,
    <19288, 18443, 18440>,
    <19288, 18440, 19289>,
    <19290, 19285, 19284>,
    <19290, 19284, 19289>,
    <19290, 19289, 18440>,
    <19290, 18440, 18439>,
    <19290, 18439, 18438>,
    <19290, 18438, 19291>,
    <19290, 19291, 19286>,
    <19290, 19286, 19285>,
    <19292, 19293, 19294>,
    <19292, 19294, 19295>,
    <19292, 19295, 18591>,
    <19292, 18591, 18590>,
    <19292, 18590, 18579>,
    <19292, 18579, 19296>,
    <19292, 19296, 19297>,
    <19292, 19297, 19293>,
    <19298, 19299, 19294>,
    <19298, 19294, 19293>,
    <19298, 19293, 19297>,
    <19298, 19297, 19300>,
    <19298, 19300, 19301>,
    <19298, 19301, 19302>,
    <19298, 19302, 19303>,
    <19298, 19303, 19299>,
    <19304, 19295, 19294>,
    <19304, 19294, 19299>,
    <19304, 19299, 19303>,
    <19304, 19303, 19305>,
    <19304, 19305, 18465>,
    <19304, 18465, 18593>,
    <19304, 18593, 18591>,
    <19304, 18591, 19295>,
    <19306, 19307, 19308>,
    <19306, 19308, 19309>,
    <19306, 19309, 19153>,
    <19306, 19153, 19152>,
    <19306, 19152, 18465>,
    <19306, 18465, 19305>,
    <19306, 19305, 19303>,
    <19306, 19303, 19307>,
    <19310, 19311, 19308>,
    <19310, 19308, 19307>,
    <19310, 19307, 19303>,
    <19310, 19303, 19302>,
    <19310, 19302, 19301>,
    <19310, 19301, 19312>,
    <19310, 19312, 19313>,
    <19310, 19313, 19311>,
    <19314, 19309, 19308>,
    <19314, 19308, 19311>,
    <19314, 19311, 19313>,
    <19314, 19313, 19315>,
    <19314, 19315, 19157>,
    <19314, 19157, 19156>,
    <19314, 19156, 19153>,
    <19314, 19153, 19309>,
    <19316, 19317, 19318>,
    <19316, 19318, 19319>,
    <19316, 19319, 19320>,
    <19316, 19320, 19321>,
    <19316, 19321, 19322>,
    <19316, 19322, 19323>,
    <19316, 19323, 19324>,
    <19316, 19324, 19317>,
    <19325, 19326, 19318>,
    <19325, 19318, 19317>,
    <19325, 19317, 19324>,
    <19325, 19324, 19327>,
    <19325, 19327, 18306>,
    <19325, 18306, 19194>,
    <19325, 19194, 19191>,
    <19325, 19191, 19326>,
    <19328, 19319, 19318>,
    <19328, 19318, 19326>,
    <19328, 19326, 19191>,
    <19328, 19191, 19190>,
    <19328, 19190, 19178>,
    <19328, 19178, 19329>,
    <19328, 19329, 19320>,
    <19328, 19320, 19319>,
    <19330, 19331, 19332>,
    <19330, 19332, 19333>,
    <19330, 19333, 19324>,
    <19330, 19324, 19323>,
    <19330, 19323, 19322>,
    <19330, 19322, 19334>,
    <19330, 19334, 19335>,
    <19330, 19335, 19331>,
    <19336, 19337, 19332>,
    <19336, 19332, 19331>,
    <19336, 19331, 19335>,
    <19336, 19335, 19338>,
    <19336, 19338, 18486>,
    <19336, 18486, 18485>,
    <19336, 18485, 18484>,
    <19336, 18484, 19337>,
    <19339, 19333, 19332>,
    <19339, 19332, 19337>,
    <19339, 19337, 18484>,
    <19339, 18484, 18493>,
    <19339, 18493, 18306>,
    <19339, 18306, 19327>,
    <19339, 19327, 19324>,
    <19339, 19324, 19333>,
    <19340, 19341, 19342>,
    <19340, 19342, 19343>,
    <19340, 19343, 19344>,
    <19340, 19344, 19345>,
    <19340, 19345, 19346>,
    <19340, 19346, 19347>,
    <19340, 19348, 19349>,
    <19340, 19349, 19341>,
    <19350, 19351, 19342>,
    <19350, 19342, 19341>,
    <19350, 19341, 19352>,
    <19350, 19352, 19353>,
    <19350, 19354, 19355>,
    <19350, 19355, 18822>,
    <19350, 18822, 18821>,
    <19350, 18821, 19351>,
    <19356, 19343, 19342>,
    <19356, 19342, 19351>,
    <19356, 19351, 18821>,
    <19356, 18821, 18827>,
    <19356, 18827, 18715>,
    <19356, 18715, 19357>,
    <19356, 19357, 19344>,
    <19356, 19344, 19343>,
    <19358, 19359, 19360>,
    <19358, 19360, 19361>,
    <19358, 19361, 19362>,
    <19358, 19362, 19363>,
    <19358, 19363, 18630>,
    <19358, 18630, 18641>,
    <19358, 18641, 18639>,
    <19358, 18639, 19359>,
    <19364, 19365, 19360>,
    <19364, 19360, 19359>,
    <19364, 19359, 18639>,
    <19364, 18639, 18638>,
    <19364, 18638, 18534>,
    <19364, 18534, 19366>,
    <19364, 19366, 19367>,
    <19364, 19367, 19365>,
    <19368, 19361, 19360>,
    <19368, 19360, 19365>,
    <19368, 19365, 19367>,
    <19368, 19367, 19369>,
    <19368, 19369, 19370>,
    <19368, 19370, 19371>,
    <19368, 19371, 19362>,
    <19368, 19362, 19361>,
    <19372, 19373, 19374>,
    <19372, 19374, 19375>,
    <19372, 19375, 19367>,
    <19372, 19367, 19366>,
    <19372, 19366, 18534>,
    <19372, 18534, 19249>,
    <19372, 19249, 19248>,
    <19372, 19248, 19373>,
    <19376, 19377, 19374>,
    <19376, 19374, 19373>,
    <19376, 19373, 19248>,
    <19376, 19248, 19257>,
    <19376, 19257, 19256>,
    <19376, 19256, 19378>,
    <19376, 19378, 19379>,
    <19376, 19379, 19377>,
    <19380, 19375, 19374>,
    <19380, 19374, 19377>,
    <19380, 19377, 19379>,
    <19380, 19379, 19381>,
    <19380, 19381, 19370>,
    <19380, 19370, 19369>,
    <19380, 19369, 19367>,
    <19380, 19367, 19375>,
    <19382, 19383, 19384>,
    <19382, 19384, 19385>,
    <19382, 19385, 19386>,
    <19382, 19386, 19387>,
    <19382, 19387, 19388>,
    <19382, 19388, 19389>,
    <19382, 19389, 19390>,
    <19382, 19390, 19383>,
    <19391, 19392, 19384>,
    <19391, 19384, 19383>,
    <19391, 19383, 19390>,
    <19391, 19390, 19393>,
    <19391, 19393, 19274>,
    <19391, 19274, 19287>,
    <19391, 19287, 19286>,
    <19391, 19286, 19392>,
    <19394, 19385, 19384>,
    <19394, 19384, 19392>,
    <19394, 19392, 19286>,
    <19394, 19286, 19291>,
    <19394, 19291, 18438>,
    <19394, 18438, 19395>,
    <19394, 19395, 19386>,
    <19394, 19386, 19385>,
    <19396, 19397, 19398>,
    <19396, 19398, 19399>,
    <19396, 19399, 19400>,
    <19396, 19400, 19401>,
    <19396, 19401, 19388>,
    <19396, 19388, 19387>,
    <19396, 19387, 19386>,
    <19396, 19386, 19397>,
    <19402, 19403, 19398>,
    <19402, 19398, 19397>,
    <19402, 19397, 19386>,
    <19402, 19386, 19395>,
    <19402, 19395, 18438>,
    <19402, 18438, 18557>,
    <19402, 18557, 18554>,
    <19402, 18554, 19403>,
    <19404, 19399, 19398>,
    <19404, 19398, 19403>,
    <19404, 19403, 18554>,
    <19404, 18554, 18553>,
    <19404, 18553, 18552>,
    <19404, 18552, 19405>,
    <19404, 19405, 19400>,
    <19404, 19400, 19399>,
    <19406, 19407, 19408>,
    <19406, 19408, 19409>,
    <19406, 19409, 18706>,
    <19406, 18706, 18705>,
    <19406, 18705, 18676>,
    <19406, 18676, 19410>,
    <19406, 19410, 19411>,
    <19406, 19411, 19407>,
    <19412, 19413, 19408>,
    <19412, 19408, 19407>,
    <19412, 19407, 19411>,
    <19412, 19411, 19414>,
    <19412, 19414, 19415>,
    <19412, 19415, 19416>,
    <19412, 19416, 19417>,
    <19412, 19417, 19413>,
    <19418, 19409, 19408>,
    <19418, 19408, 19413>,
    <19418, 19413, 19417>,
    <19418, 19417, 19419>,
    <19418, 19419, 18579>,
    <19418, 18579, 18708>,
    <19418, 18708, 18706>,
    <19418, 18706, 19409>,
    <19420, 19421, 19422>,
    <19420, 19422, 19423>,
    <19420, 19423, 19297>,
    <19420, 19297, 19296>,
    <19420, 19296, 18579>,
    <19420, 18579, 19419>,
    <19420, 19419, 19417>,
    <19420, 19417, 19421>,
    <19424, 19425, 19422>,
    <19424, 19422, 19421>,
    <19424, 19421, 19417>,
    <19424, 19417, 19416>,
    <19424, 19416, 19415>,
    <19424, 19415, 19426>,
    <19424, 19426, 19427>,
    <19424, 19427, 19425>,
    <19428, 19423, 19422>,
    <19428, 19422, 19425>,
    <19428, 19425, 19427>,
    <19428, 19427, 19429>,
    <19428, 19429, 19301>,
    <19428, 19301, 19300>,
    <19428, 19300, 19297>,
    <19428, 19297, 19423>,
    <19430, 19431, 19432>,
    <19430, 19432, 19433>,
    <19430, 19433, 19434>,
    <19430, 19434, 19435>,
    <19430, 19435, 19436>,
    <19430, 19436, 19437>,
    <19430, 19437, 19438>,
    <19430, 19438, 19431>,
    <19439, 19440, 19432>,
    <19439, 19432, 19431>,
    <19439, 19431, 19438>,
    <19439, 19438, 19441>,
    <19439, 19441, 18486>,
    <19439, 18486, 19338>,
    <19439, 19338, 19335>,
    <19439, 19335, 19440>,
    <19442, 19433, 19432>,
    <19442, 19432, 19440>,
    <19442, 19440, 19335>,
    <19442, 19335, 19334>,
    <19442, 19334, 19322>,
    <19442, 19322, 19443>,
    <19442, 19443, 19434>,
    <19442, 19434, 19433>,
    <19444, 19445, 19446>,
    <19444, 19446, 19447>,
    <19444, 19447, 19438>,
    <19444, 19438, 19437>,
    <19444, 19437, 19436>,
    <19444, 19436, 19448>,
    <19444, 19448, 19449>,
    <19444, 19449, 19445>,
    <19450, 19451, 19446>,
    <19450, 19446, 19445>,
    <19450, 19445, 19449>,
    <19450, 19449, 19452>,
    <19450, 19452, 18600>,
    <19450, 18600, 18599>,
    <19450, 18599, 18598>,
    <19450, 18598, 19451>,
    <19453, 19447, 19446>,
    <19453, 19446, 19451>,
    <19453, 19451, 18598>,
    <19453, 18598, 18607>,
    <19453, 18607, 18486>,
    <19453, 18486, 19441>,
    <19453, 19441, 19438>,
    <19453, 19438, 19447>,
    <19454, 19455, 19456>,
    <19454, 19456, 19457>,
    <19454, 19457, 19458>,
    <19454, 19458, 19459>,
    <19454, 19459, 19460>,
    <19454, 19460, 19461>,
    <19454, 19462, 19463>,
    <19454, 19463, 19455>,
    <19464, 19465, 19456>,
    <19464, 19456, 19455>,
    <19464, 19455, 19466>,
    <19464, 19466, 19467>,
    <19464, 19468, 19469>,
    <19464, 19469, 19007>,
    <19464, 19007, 19005>,
    <19464, 19005, 19465>,
    <19470, 19457, 19456>,
    <19470, 19456, 19465>,
    <19470, 19465, 19005>,
    <19470, 19005, 19004>,
    <19470, 19004, 18848>,
    <19470, 18848, 19471>,
    <19470, 19471, 19458>,
    <19470, 19458, 19457>,
    <19472, 19473, 19474>,
    <19472, 19474, 19475>,
    <19472, 19475, 18957>,
    <19472, 18957, 18956>,
    <19472, 18956, 18945>,
    <19472, 18945, 19476>,
    <19472, 19476, 19477>,
    <19472, 19477, 19473>,
    <19478, 19479, 19474>,
    <19478, 19474, 19473>,
    <19478, 19473, 19477>,
    <19478, 19477, 19480>,
    <19478, 19480, 19481>,
    <19478, 19481, 19482>,
    <19478, 19483, 19484>,
    <19478, 19484, 19479>,
    <19485, 19475, 19474>,
    <19485, 19474, 19479>,
    <19485, 19479, 19486>,
    <19485, 19486, 19487>,
    <19485, 19488, 19489>,
    <19485, 19489, 18959>,
    <19485, 18959, 18957>,
    <19485, 18957, 19475>,
    <19490, 19491, 19492>,
    <19490, 19492, 19493>,
    <19490, 19493, 19494>,
    <19490, 19494, 19495>,
    <19490, 19495, 18745>,
    <19490, 18745, 18756>,
    <19490, 18756, 18754>,
    <19490, 18754, 19491>,
    <19496, 19497, 19492>,
    <19496, 19492, 19491>,
    <19496, 19491, 18754>,
    <19496, 18754, 18753>,
    <19496, 18753, 18630>,
    <19496, 18630, 19498>,
    <19496, 19498, 19499>,
    <19496, 19499, 19497>,
    <19500, 19493, 19492>,
    <19500, 19492, 19497>,
    <19500, 19497, 19499>,
    <19500, 19499, 19501>,
    <19500, 19501, 19502>,
    <19500, 19502, 19503>,
    <19500, 19503, 19494>,
    <19500, 19494, 19493>,
    <19504, 19505, 19506>,
    <19504, 19506, 19507>,
    <19504, 19507, 19499>,
    <19504, 19499, 19498>,
    <19504, 19498, 18630>,
    <19504, 18630, 19363>,
    <19504, 19363, 19362>,
    <19504, 19362, 19505>,
    <19508, 19509, 19506>,
    <19508, 19506, 19505>,
    <19508, 19505, 19362>,
    <19508, 19362, 19371>,
    <19508, 19371, 19370>,
    <19508, 19370, 19510>,
    <19508, 19510, 19511>,
    <19508, 19511, 19509>,
    <19512, 19507, 19506>,
    <19512, 19506, 19509>,
    <19512, 19509, 19511>,
    <19512, 19511, 19513>,
    <19512, 19513, 19502>,
    <19512, 19502, 19501>,
    <19512, 19501, 19499>,
    <19512, 19499, 19507>,
    <19514, 19515, 19516>,
    <19514, 19516, 19517>,
    <19514, 19517, 19518>,
    <19514, 19518, 19519>,
    <19514, 19519, 19520>,
    <19514, 19520, 19521>,
    <19514, 19521, 19522>,
    <19514, 19522, 19515>,
    <19523, 19524, 19516>,
    <19523, 19516, 19515>,
    <19523, 19515, 19522>,
    <19523, 19522, 19525>,
    <19523, 19525, 19388>,
    <19523, 19388, 19401>,
    <19523, 19401, 19400>,
    <19523, 19400, 19524>,
    <19526, 19517, 19516>,
    <19526, 19516, 19524>,
    <19526, 19524, 19400>,
    <19526, 19400, 19405>,
    <19526, 19405, 18552>,
    <19526, 18552, 19527>,
    <19526, 19527, 19518>,
    <19526, 19518, 19517>,
    <19528, 19529, 19530>,
    <19528, 19530, 19531>,
    <19528, 19531, 19532>,
    <19528, 19532, 19533>,
    <19528, 19533, 19520>,
    <19528, 19520, 19519>,
    <19528, 19519, 19518>,
    <19528, 19518, 19529>,
    <19534, 19535, 19530>,
    <19534, 19530, 19529>,
    <19534, 19529, 19518>,
    <19534, 19518, 19527>,
    <19534, 19527, 18552>,
    <19534, 18552, 18653>,
    <19534, 18653, 18650>,
    <19534, 18650, 19535>,
    <19536, 19531, 19530>,
    <19536, 19530, 19535>,
    <19536, 19535, 18650>,
    <19536, 18650, 18649>,
    <19536, 18649, 18648>,
    <19536, 18648, 19537>,
    <19536, 19537, 19532>,
    <19536, 19532, 19531>,
    <19538, 19539, 19540>,
    <19538, 19540, 19541>,
    <19538, 19541, 19051>,
    <19538, 19051, 19050>,
    <19538, 19050, 19039>,
    <19538, 19039, 19542>,
    <19538, 19542, 19543>,
    <19538, 19543, 19539>,
    <19544, 19545, 19540>,
    <19544, 19540, 19539>,
    <19544, 19539, 19543>,
    <19544, 19543, 19546>,
    <19544, 19546, 19547>,
    <19544, 19547, 19548>,
    <19544, 19548, 19549>,
    <19544, 19549, 19545>,
    <19550, 19541, 19540>,
    <19550, 19540, 19545>,
    <19550, 19545, 19549>,
    <19550, 19549, 19551>,
    <19550, 19551, 18945>,
    <19550, 18945, 19053>,
    <19550, 19053, 19051>,
    <19550, 19051, 19541>,
    <19552, 19553, 19554>,
    <19552, 19554, 19555>,
    <19552, 19555, 19477>,
    <19552, 19477, 19476>,
    <19552, 19476, 18945>,
    <19552, 18945, 19551>,
    <19552, 19551, 19549>,
    <19552, 19549, 19553>,
    <19556, 19557, 19554>,
    <19556, 19554, 19553>,
    <19556, 19553, 19549>,
    <19556, 19549, 19548>,
    <19556, 19548, 19547>,
    <19556, 19547, 19558>,
    <19556, 19558, 19559>,
    <19556, 19559, 19557>,
    <19560, 19555, 19554>,
    <19560, 19554, 19557>,
    <19560, 19557, 19559>,
    <19560, 19559, 19561>,
    <19560, 19561, 19562>,
    <19560, 19562, 19480>,
    <19560, 19480, 19477>,
    <19560, 19477, 19555>,
    <19563, 19564, 19565>,
    <19563, 19565, 19566>,
    <19563, 19566, 19567>,
    <19563, 19567, 19568>,
    <19563, 19568, 19569>,
    <19563, 19569, 19570>,
    <19563, 19570, 19571>,
    <19563, 19571, 19564>,
    <19572, 19573, 19565>,
    <19572, 19565, 19564>,
    <19572, 19564, 19571>,
    <19572, 19571, 19574>,
    <19572, 19574, 19575>,
    <19572, 19575, 19576>,
    <19572, 19577, 19578>,
    <19572, 19578, 19573>,
    <19579, 19566, 19565>,
    <19579, 19565, 19573>,
    <19579, 19573, 19580>,
    <19579, 19580, 19581>,
    <19579, 19582, 19583>,
    <19579, 19583, 19584>,
    <19579, 19584, 19567>,
    <19579, 19567, 19566>,
    <19585, 19586, 19587>,
    <19585, 19587, 19588>,
    <19585, 19588, 19571>,
    <19585, 19571, 19570>,
    <19585, 19570, 19569>,
    <19585, 19569, 19589>,
    <19585, 19589, 19590>,
    <19585, 19590, 19586>,
    <19591, 19592, 19587>,
    <19591, 19587, 19586>,
    <19591, 19586, 19590>,
    <19591, 19590, 19593>,
    <19591, 19593, 18967>,
    <19591, 18967, 18966>,
    <19591, 18966, 18965>,
    <19591, 18965, 19592>,
    <19594, 19588, 19587>,
    <19594, 19587, 19592>,
    <19594, 19592, 18965>,
    <19594, 18965, 18982>,
    <19594, 18982, 19595>,
    <19594, 19595, 19574>,
    <19594, 19574, 19571>,
    <19594, 19571, 19588>,
    <19596, 19597, 19598>,
    <19596, 19598, 19599>,
    <19596, 19599, 19600>,
    <19596, 19600, 19601>,
    <19596, 19602, 19603>,
    <19596, 19603, 19604>,
    <19596, 19604, 19605>,
    <19596, 19605, 19597>,
    <19606, 19607, 19598>,
    <19606, 19598, 19597>,
    <19606, 19597, 19605>,
    <19606, 19605, 19608>,
    <19606, 19608, 18891>,
    <19606, 18891, 19029>,
    <19606, 19029, 19027>,
    <19606, 19027, 19607>,
    <19609, 19599, 19598>,
    <19609, 19598, 19607>,
    <19609, 19607, 19027>,
    <19609, 19027, 19026>,
    <19609, 19026, 19610>,
    <19609, 19610, 19611>,
    <19609, 19612, 19613>,
    <19609, 19613, 19599>,
    <19614, 19615, 19616>,
    <19614, 19616, 19617>,
    <19614, 19617, 19169>,
    <19614, 19169, 19168>,
    <19614, 19168, 19157>,
    <19614, 19157, 19618>,
    <19614, 19618, 19619>,
    <19614, 19619, 19615>,
    <19620, 19621, 19616>,
    <19620, 19616, 19615>,
    <19620, 19615, 19619>,
    <19620, 19619, 19622>,
    <19620, 19622, 19623>,
    <19620, 19623, 19624>,
    <19620, 19624, 19625>,
    <19620, 19625, 19621>,
    <19626, 19617, 19616>,
    <19626, 19616, 19621>,
    <19626, 19621, 19625>,
    <19626, 19625, 19627>,
    <19626, 19627, 19039>,
    <19626, 19039, 19171>,
    <19626, 19171, 19169>,
    <19626, 19169, 19617>,
    <19628, 19629, 19630>,
    <19628, 19630, 19631>,
    <19628, 19631, 19543>,
    <19628, 19543, 19542>,
    <19628, 19542, 19039>,
    <19628, 19039, 19627>,
    <19628, 19627, 19625>,
    <19628, 19625, 19629>,
    <19632, 19633, 19630>,
    <19632, 19630, 19629>,
    <19632, 19629, 19625>,
    <19632, 19625, 19624>,
    <19632, 19624, 19623>,
    <19632, 19623, 19634>,
    <19632, 19634, 19635>,
    <19632, 19635, 19633>,
    <19636, 19631, 19630>,
    <19636, 19630, 19633>,
    <19636, 19633, 19635>,
    <19636, 19635, 19637>,
    <19636, 19637, 19547>,
    <19636, 19547, 19546>,
    <19636, 19546, 19543>,
    <19636, 19543, 19631>,
    <19638, 19639, 19640>,
    <19638, 19640, 19641>,
    <19638, 19641, 19642>,
    <19638, 19642, 19643>,
    <19638, 19643, 19644>,
    <19638, 19644, 19645>,
    <19638, 19645, 19646>,
    <19638, 19646, 19639>,
    <19647, 19648, 19640>,
    <19647, 19640, 19639>,
    <19647, 19639, 19646>,
    <19647, 19646, 19649>,
    <19647, 19649, 18967>,
    <19647, 18967, 19593>,
    <19647, 19593, 19590>,
    <19647, 19590, 19648>,
    <19650, 19641, 19640>,
    <19650, 19640, 19648>,
    <19650, 19648, 19590>,
    <19650, 19590, 19589>,
    <19650, 19589, 19569>,
    <19650, 19569, 19651>,
    <19650, 19651, 19642>,
    <19650, 19642, 19641>,
    <19652, 19653, 19654>,
    <19652, 19654, 19655>,
    <19652, 19655, 19646>,
    <19652, 19646, 19645>,
    <19652, 19645, 19644>,
    <19652, 19644, 19656>,
    <19652, 19656, 19657>,
    <19652, 19657, 19653>,
    <19658, 19659, 19654>,
    <19658, 19654, 19653>,
    <19658, 19653, 19657>,
    <19658, 19657, 19660>,
    <19658, 19660, 19060>,
    <19658, 19060, 19059>,
    <19658, 19059, 19058>,
    <19658, 19058, 19659>,
    <19661, 19655, 19654>,
    <19661, 19654, 19659>,
    <19661, 19659, 19058>,
    <19661, 19058, 19067>,
    <19661, 19067, 18967>,
    <19661, 18967, 19649>,
    <19661, 19649, 19646>,
    <19661, 19646, 19655>,
    <19662, 19663, 19664>,
    <19662, 19664, 19665>,
    <19662, 19665, 18814>,
    <19662, 18814, 18813>,
    <19662, 18813, 19666>,
    <19662, 19666, 19667>,
    <19662, 19667, 19668>,
    <19662, 19668, 19663>,
    <19669, 19670, 19664>,
    <19669, 19664, 19663>,
    <19669, 19663, 19668>,
    <19669, 19668, 19671>,
    <19669, 19671, 19672>,
    <19669, 19672, 19673>,
    <19669, 19673, 19674>,
    <19669, 19674, 19670>,
    <19675, 19665, 19664>,
    <19675, 19664, 19670>,
    <19675, 19670, 19674>,
    <19675, 19674, 19676>,
    <19675, 19676, 18676>,
    <19675, 18676, 18816>,
    <19675, 18816, 18814>,
    <19675, 18814, 19665>,
    <19677, 19678, 19679>,
    <19677, 19679, 19680>,
    <19677, 19680, 19668>,
    <19677, 19668, 19667>,
    <19677, 19667, 19681>,
    <19677, 19681, 19682>,
    <19677, 19683, 19684>,
    <19677, 19684, 19678>,
    <19685, 19686, 19679>,
    <19685, 19679, 19678>,
    <19685, 19678, 19687>,
    <19685, 19687, 19688>,
    <19685, 19689, 19690>,
    <19685, 19690, 19691>,
    <19685, 19691, 19692>,
    <19685, 19692, 19686>,
    <19693, 19680, 19679>,
    <19693, 19679, 19686>,
    <19693, 19686, 19692>,
    <19693, 19692, 19694>,
    <19693, 19694, 19672>,
    <19693, 19672, 19671>,
    <19693, 19671, 19668>,
    <19693, 19668, 19680>,
    <19695, 19696, 19697>,
    <19695, 19697, 19698>,
    <19695, 19698, 19411>,
    <19695, 19411, 19410>,
    <19695, 19410, 18676>,
    <19695, 18676, 19676>,
    <19695, 19676, 19674>,
    <19695, 19674, 19696>,
    <19699, 19700, 19697>,
    <19699, 19697, 19696>,
    <19699, 19696, 19674>,
    <19699, 19674, 19673>,
    <19699, 19673, 19672>,
    <19699, 19672, 19701>,
    <19699, 19701, 19702>,
    <19699, 19702, 19700>,
    <19703, 19698, 19697>,
    <19703, 19697, 19700>,
    <19703, 19700, 19702>,
    <19703, 19702, 19704>,
    <19703, 19704, 19415>,
    <19703, 19415, 19414>,
    <19703, 19414, 19411>,
    <19703, 19411, 19698>,
    <19705, 19706, 19707>,
    <19705, 19707, 19708>,
    <19705, 19708, 19709>,
    <19705, 19709, 19710>,
    <19705, 19710, 19711>,
    <19705, 19711, 19712>,
    <19705, 19712, 19713>,
    <19705, 19713, 19706>,
    <19714, 19715, 19707>,
    <19714, 19707, 19706>,
    <19714, 19706, 19713>,
    <19714, 19713, 19716>,
    <19714, 19716, 18600>,
    <19714, 18600, 19452>,
    <19714, 19452, 19449>,
    <19714, 19449, 19715>,
    <19717, 19708, 19707>,
    <19717, 19707, 19715>,
    <19717, 19715, 19449>,
    <19717, 19449, 19448>,
    <19717, 19448, 19436>,
    <19717, 19436, 19718>,
    <19717, 19718, 19709>,
    <19717, 19709, 19708>,
    <19719, 19720, 19721>,
    <19719, 19721, 19722>,
    <19719, 19722, 19713>,
    <19719, 19713, 19712>,
    <19719, 19712, 19711>,
    <19719, 19711, 19723>,
    <19719, 19723, 19724>,
    <19719, 19724, 19720>,
    <19725, 19726, 19721>,
    <19725, 19721, 19720>,
    <19725, 19720, 19724>,
    <19725, 19724, 19727>,
    <19725, 19727, 18715>,
    <19725, 18715, 18714>,
    <19725, 18714, 18713>,
    <19725, 18713, 19726>,
    <19728, 19722, 19721>,
    <19728, 19721, 19726>,
    <19728, 19726, 18713>,
    <19728, 18713, 18722>,
    <19728, 18722, 18600>,
    <19728, 18600, 19716>,
    <19728, 19716, 19713>,
    <19728, 19713, 19722>,
    <19729, 19730, 19731>,
    <19729, 19731, 19732>,
    <19729, 19732, 19733>,
    <19729, 19733, 19734>,
    <19729, 19734, 19102>,
    <19729, 19102, 19114>,
    <19729, 19114, 19112>,
    <19729, 19112, 19730>,
    <19735, 19736, 19731>,
    <19735, 19731, 19730>,
    <19735, 19730, 19112>,
    <19735, 19112, 19111>,
    <19735, 19111, 19737>,
    <19735, 19737, 19738>,
    <19735, 19739, 19740>,
    <19735, 19740, 19736>,
    <19741, 19732, 19731>,
    <19741, 19731, 19736>,
    <19741, 19736, 19742>,
    <19741, 19742, 19743>,
    <19741, 19744, 19745>,
    <19741, 19745, 19746>,
    <19741, 19746, 19733>,
    <19741, 19733, 19732>,
    <19747, 19748, 19749>,
    <19747, 19749, 19750>,
    <19747, 19750, 19751>,
    <19747, 19751, 19752>,
    <19747, 19752, 19208>,
    <19747, 19208, 19219>,
    <19747, 19219, 19217>,
    <19747, 19217, 19748>,
    <19753, 19754, 19749>,
    <19753, 19749, 19748>,
    <19753, 19748, 19217>,
    <19753, 19217, 19216>,
    <19753, 19216, 19102>,
    <19753, 19102, 19755>,
    <19753, 19755, 19756>,
    <19753, 19756, 19754>,
    <19757, 19750, 19749>,
    <19757, 19749, 19754>,
    <19757, 19754, 19756>,
    <19757, 19756, 19758>,
    <19757, 19758, 19759>,
    <19757, 19759, 19760>,
    <19757, 19760, 19751>,
    <19757, 19751, 19750>,
    <19761, 19762, 19763>,
    <19761, 19763, 19764>,
    <19761, 19764, 19756>,
    <19761, 19756, 19755>,
    <19761, 19755, 19102>,
    <19761, 19102, 19734>,
    <19761, 19734, 19733>,
    <19761, 19733, 19762>,
    <19765, 19766, 19763>,
    <19765, 19763, 19762>,
    <19765, 19762, 19733>,
    <19765, 19733, 19746>,
    <19765, 19746, 19767>,
    <19765, 19767, 19768>,
    <19765, 19768, 19769>,
    <19765, 19769, 19766>,
    <19770, 19764, 19763>,
    <19770, 19763, 19766>,
    <19770, 19766, 19769>,
    <19770, 19769, 19771>,
    <19770, 19771, 19759>,
    <19770, 19759, 19758>,
    <19770, 19758, 19756>,
    <19770, 19756, 19764>,
    <19772, 19773, 19774>,
    <19772, 19774, 19775>,
    <19772, 19775, 19776>,
    <19772, 19776, 19777>,
    <19772, 19777, 19778>,
    <19772, 19778, 19779>,
    <19772, 19779, 19780>,
    <19772, 19780, 19773>,
    <19781, 19782, 19774>,
    <19781, 19774, 19773>,
    <19781, 19773, 19780>,
    <19781, 19780, 19783>,
    <19781, 19783, 19784>,
    <19781, 19784, 19785>,
    <19781, 19786, 19787>,
    <19781, 19787, 19782>,
    <19788, 19775, 19774>,
    <19788, 19774, 19782>,
    <19788, 19782, 19789>,
    <19788, 19789, 19790>,
    <19788, 19791, 19792>,
    <19788, 19792, 19793>,
    <19788, 19793, 19776>,
    <19788, 19776, 19775>,
    <19794, 19795, 19796>,
    <19794, 19796, 19797>,
    <19794, 19797, 19798>,
    <19794, 19798, 19799>,
    <19794, 19799, 19778>,
    <19794, 19778, 19777>,
    <19794, 19777, 19776>,
    <19794, 19776, 19795>,
    <19800, 19801, 19796>,
    <19800, 19796, 19795>,
    <19800, 19795, 19776>,
    <19800, 19776, 19793>,
    <19800, 19793, 19802>,
    <19800, 19802, 19126>,
    <19800, 19126, 19123>,
    <19800, 19123, 19801>,
    <19803, 19797, 19796>,
    <19803, 19796, 19801>,
    <19803, 19801, 19123>,
    <19803, 19123, 19122>,
    <19803, 19122, 19121>,
    <19803, 19121, 19804>,
    <19803, 19804, 19798>,
    <19803, 19798, 19797>,
    <19805, 19806, 19807>,
    <19805, 19807, 19808>,
    <19805, 19808, 19809>,
    <19805, 19809, 19810>,
    <19805, 19810, 18848>,
    <19805, 18848, 18870>,
    <19805, 18870, 18868>,
    <19805, 18868, 19806>,
    <19811, 19812, 19807>,
    <19811, 19807, 19806>,
    <19811, 19806, 18868>,
    <19811, 18868, 18867>,
    <19811, 18867, 18745>,
    <19811, 18745, 19813>,
    <19811, 19813, 19814>,
    <19811, 19814, 19812>,
    <19815, 19808, 19807>,
    <19815, 19807, 19812>,
    <19815, 19812, 19814>,
    <19815, 19814, 19816>,
    <19815, 19816, 19817>,
    <19815, 19817, 19818>,
    <19815, 19818, 19809>,
    <19815, 19809, 19808>,
    <19819, 19820, 19821>,
    <19819, 19821, 19822>,
    <19819, 19822, 19814>,
    <19819, 19814, 19813>,
    <19819, 19813, 18745>,
    <19819, 18745, 19495>,
    <19819, 19495, 19494>,
    <19819, 19494, 19820>,
    <19823, 19824, 19821>,
    <19823, 19821, 19820>,
    <19823, 19820, 19494>,
    <19823, 19494, 19503>,
    <19823, 19503, 19502>,
    <19823, 19502, 19825>,
    <19823, 19825, 19826>,
    <19823, 19826, 19824>,
    <19827, 19822, 19821>,
    <19827, 19821, 19824>,
    <19827, 19824, 19826>,
    <19827, 19826, 19828>,
    <19827, 19828, 19817>,
    <19827, 19817, 19816>,
    <19827, 19816, 19814>,
    <19827, 19814, 19822>,
    <19829, 19830, 19831>,
    <19829, 19831, 19832>,
    <19829, 19832, 19833>,
    <19829, 19833, 19834>,
    <19829, 19834, 19835>,
    <19829, 19835, 19836>,
    <19829, 19836, 19837>,
    <19829, 19837, 19830>,
    <19838, 19839, 19831>,
    <19838, 19831, 19830>,
    <19838, 19830, 19837>,
    <19838, 19837, 19840>,
    <19838, 19840, 19520>,
    <19838, 19520, 19533>,
    <19838, 19533, 19532>,
    <19838, 19532, 19839>,
    <19841, 19832, 19831>,
    <19841, 19831, 19839>,
    <19841, 19839, 19532>,
    <19841, 19532, 19537>,
    <19841, 19537, 18648>,
    <19841, 18648, 19842>,
    <19841, 19842, 19833>,
    <19841, 19833, 19832>,
    <19843, 19844, 19845>,
    <19843, 19845, 19846>,
    <19843, 19846, 19847>,
    <19843, 19847, 19848>,
    <19843, 19848, 19835>,
    <19843, 19835, 19834>,
    <19843, 19834, 19833>,
    <19843, 19833, 19844>,
    <19849, 19850, 19845>,
    <19849, 19845, 19844>,
    <19849, 19844, 19833>,
    <19849, 19833, 19842>,
    <19849, 19842, 18648>,
    <19849, 18648, 18768>,
    <19849, 18768, 18765>,
    <19849, 18765, 19850>,
    <19851, 19846, 19845>,
    <19851, 19845, 19850>,
    <19851, 19850, 18765>,
    <19851, 18765, 18764>,
    <19851, 18764, 18763>,
    <19851, 18763, 19852>,
    <19851, 19852, 19847>,
    <19851, 19847, 19846>,
    <19853, 19854, 19855>,
    <19853, 19855, 19856>,
    <19853, 19856, 19559>,
    <19853, 19559, 19558>,
    <19853, 19558, 19547>,
    <19853, 19547, 19857>,
    <19853, 19857, 19858>,
    <19853, 19858, 19854>,
    <19859, 19860, 19855>,
    <19859, 19855, 19854>,
    <19859, 19854, 19858>,
    <19859, 19858, 19861>,
    <19859, 19861, 5290>,
    <19859, 5290, 5289>,
    <19859, 5289, 5287>,
    <19859, 5287, 19860>,
    <19862, 19856, 19855>,
    <19862, 19855, 19860>,
    <19862, 19860, 5287>,
    <19862, 5287, 5286>,
    <19862, 5286, 19863>,
    <19862, 19863, 19561>,
    <19862, 19561, 19559>,
    <19862, 19559, 19856>,
    <19864, 19865, 19866>,
    <19864, 19866, 19867>,
    <19864, 19867, 19313>,
    <19864, 19313, 19312>,
    <19864, 19312, 19301>,
    <19864, 19301, 19868>,
    <19864, 19868, 19869>,
    <19864, 19869, 19865>,
    <19870, 19871, 19866>,
    <19870, 19866, 19865>,
    <19870, 19865, 19869>,
    <19870, 19869, 19872>,
    <19870, 19872, 19873>,
    <19870, 19873, 19874>,
    <19870, 19874, 19875>,
    <19870, 19875, 19871>,
    <19876, 19867, 19866>,
    <19876, 19866, 19871>,
    <19876, 19871, 19875>,
    <19876, 19875, 19877>,
    <19876, 19877, 19157>,
    <19876, 19157, 19315>,
    <19876, 19315, 19313>,
    <19876, 19313, 19867>,
    <19878, 19879, 19880>,
    <19878, 19880, 19881>,
    <19878, 19881, 19619>,
    <19878, 19619, 19618>,
    <19878, 19618, 19157>,
    <19878, 19157, 19877>,
    <19878, 19877, 19875>,
    <19878, 19875, 19879>,
    <19882, 19883, 19880>,
    <19882, 19880, 19879>,
    <19882, 19879, 19875>,
    <19882, 19875, 19874>,
    <19882, 19874, 19873>,
    <19882, 19873, 19884>,
    <19882, 19884, 19885>,
    <19882, 19885, 19883>,
    <19886, 19881, 19880>,
    <19886, 19880, 19883>,
    <19886, 19883, 19885>,
    <19886, 19885, 19887>,
    <19886, 19887, 19623>,
    <19886, 19623, 19622>,
    <19886, 19622, 19619>,
    <19886, 19619, 19881>,
    <19888, 19889, 19890>,
    <19888, 19890, 19891>,
    <19888, 19891, 19892>,
    <19888, 19892, 19893>,
    <19888, 19893, 19894>,
    <19888, 19894, 19895>,
    <19888, 19895, 19896>,
    <19888, 19896, 19889>,
    <19897, 19898, 19890>,
    <19897, 19890, 19889>,
    <19897, 19889, 19896>,
    <19897, 19896, 19899>,
    <19897, 19899, 19060>,
    <19897, 19060, 19660>,
    <19897, 19660, 19657>,
    <19897, 19657, 19898>,
    <19900, 19891, 19890>,
    <19900, 19890, 19898>,
    <19900, 19898, 19657>,
    <19900, 19657, 19656>,
    <19900, 19656, 19644>,
    <19900, 19644, 19901>,
    <19900, 19901, 19892>,
    <19900, 19892, 19891>,
    <19902, 19903, 19904>,
    <19902, 19904, 19905>,
    <19902, 19905, 19896>,
    <19902, 19896, 19895>,
    <19902, 19895, 19894>,
    <19902, 19894, 19906>,
    <19902, 19906, 19907>,
    <19902, 19907, 19903>,
    <19908, 19909, 19904>,
    <19908, 19904, 19903>,
    <19908, 19903, 19907>,
    <19908, 19907, 19910>,
    <19908, 19910, 19178>,
    <19908, 19178, 19177>,
    <19908, 19177, 19176>,
    <19908, 19176, 19909>,
    <19911, 19905, 19904>,
    <19911, 19904, 19909>,
    <19911, 19909, 19176>,
    <19911, 19176, 19185>,
    <19911, 19185, 19060>,
    <19911, 19060, 19899>,
    <19911, 19899, 19896>,
    <19911, 19896, 19905>,
    <19912, 19913, 19914>,
    <19912, 19914, 19915>,
    <19912, 19915, 19916>,
    <19912, 19916, 19917>,
    <19912, 19917, 19256>,
    <19912, 19256, 19267>,
    <19912, 19267, 19265>,
    <19912, 19265, 19913>,
    <19918, 19919, 19914>,
    <19918, 19914, 19913>,
    <19918, 19913, 19265>,
    <19918, 19265, 19264>,
    <19918, 19264, 19208>,
    <19918, 19208, 19920>,
    <19918, 19920, 19921>,
    <19918, 19921, 19919>,
    <19922, 19915, 19914>,
    <19922, 19914, 19919>,
    <19922, 19919, 19921>,
    <19922, 19921, 19923>,
    <19922, 19923, 19924>,
    <19922, 19924, 19925>,
    <19922, 19925, 19916>,
    <19922, 19916, 19915>,
    <19926, 19927, 19928>,
    <19926, 19928, 19929>,
    <19926, 19929, 19921>,
    <19926, 19921, 19920>,
    <19926, 19920, 19208>,
    <19926, 19208, 19752>,
    <19926, 19752, 19751>,
    <19926, 19751, 19927>,
    <19930, 19931, 19928>,
    <19930, 19928, 19927>,
    <19930, 19927, 19751>,
    <19930, 19751, 19760>,
    <19930, 19760, 19759>,
    <19930, 19759, 19932>,
    <19930, 19932, 19933>,
    <19930, 19933, 19931>,
    <19934, 19929, 19928>,
    <19934, 19928, 19931>,
    <19934, 19931, 19933>,
    <19934, 19933, 19935>,
    <19934, 19935, 19924>,
    <19934, 19924, 19923>,
    <19934, 19923, 19921>,
    <19934, 19921, 19929>,
    <19936, 19937, 19938>,
    <19936, 19938, 19939>,
    <19936, 19939, 19940>,
    <19936, 19940, 19941>,
    <19936, 19941, 19942>,
    <19936, 19942, 19943>,
    <19936, 19943, 19944>,
    <19936, 19944, 19937>,
    <19945, 19946, 19938>,
    <19945, 19938, 19937>,
    <19945, 19937, 19944>,
    <19945, 19944, 19947>,
    <19945, 19947, 19778>,
    <19945, 19778, 19799>,
    <19945, 19799, 19798>,
    <19945, 19798, 19946>,
    <19948, 19939, 19938>,
    <19948, 19938, 19946>,
    <19948, 19946, 19798>,
    <19948, 19798, 19804>,
    <19948, 19804, 19121>,
    <19948, 19121, 19949>,
    <19948, 19949, 19940>,
    <19948, 19940, 19939>,
    <19950, 19951, 19952>,
    <19950, 19952, 19953>,
    <19950, 19953, 19954>,
    <19950, 19954, 19955>,
    <19950, 19955, 19942>,
    <19950, 19942, 19941>,
    <19950, 19941, 19940>,
    <19950, 19940, 19951>,
    <19956, 19957, 19952>,
    <19956, 19952, 19951>,
    <19956, 19951, 19940>,
    <19956, 19940, 19949>,
    <19956, 19949, 19121>,
    <19956, 19121, 19231>,
    <19956, 19231, 19228>,
    <19956, 19228, 19957>,
    <19958, 19953, 19952>,
    <19958, 19952, 19957>,
    <19958, 19957, 19228>,
    <19958, 19228, 19227>,
    <19958, 19227, 19226>,
    <19958, 19226, 19959>,
    <19958, 19959, 19954>,
    <19958, 19954, 19953>,
    <19960, 19961, 19962>,
    <19960, 19962, 19963>,
    <19960, 19963, 19635>,
    <19960, 19635, 19634>,
    <19960, 19634, 19623>,
    <19960, 19623, 19964>,
    <19960, 19964, 19965>,
    <19960, 19965, 19961>,
    <19966, 19967, 19962>,
    <19966, 19962, 19961>,
    <19966, 19961, 19965>,
    <19966, 19965, 19968>,
    <19966, 19968, 19969>,
    <19966, 19969, 19970>,
    <19966, 19970, 19971>,
    <19966, 19971, 19967>,
    <19972, 19963, 19962>,
    <19972, 19962, 19967>,
    <19972, 19967, 19971>,
    <19972, 19971, 19973>,
    <19972, 19973, 19547>,
    <19972, 19547, 19637>,
    <19972, 19637, 19635>,
    <19972, 19635, 19963>,
    <19974, 19975, 19976>,
    <19974, 19976, 19977>,
    <19974, 19977, 19858>,
    <19974, 19858, 19857>,
    <19974, 19857, 19547>,
    <19974, 19547, 19973>,
    <19974, 19973, 19971>,
    <19974, 19971, 19975>,
    <19978, 19979, 19976>,
    <19978, 19976, 19975>,
    <19978, 19975, 19971>,
    <19978, 19971, 19970>,
    <19978, 19970, 19969>,
    <19978, 19969, 19980>,
    <19978, 19980, 19981>,
    <19978, 19981, 19979>,
    <19982, 19977, 19976>,
    <19982, 19976, 19979>,
    <19982, 19979, 19981>,
    <19982, 19981, 19983>,
    <19982, 19983, 5290>,
    <19982, 5290, 19861>,
    <19982, 19861, 19858>,
    <19982, 19858, 19977>,
    <19984, 19985, 19986>,
    <19984, 19986, 19987>,
    <19984, 19987, 19981>,
    <19984, 19981, 19980>,
    <19984, 19980, 19969>,
    <19984, 19969, 19988>,
    <19984, 19988, 19989>,
    <19984, 19989, 19985>,
    <19990, 19991, 19986>,
    <19990, 19986, 19985>,
    <19990, 19985, 19989>,
    <19990, 19989, 19992>,
    <19990, 19992, 19993>,
    <19990, 19993, 5346>,
    <19990, 5346, 5344>,
    <19990, 5344, 19991>,
    <19994, 19987, 19986>,
    <19994, 19986, 19991>,
    <19994, 19991, 5344>,
    <19994, 5344, 5343>,
    <19994, 5343, 5290>,
    <19994, 5290, 19983>,
    <19994, 19983, 19981>,
    <19994, 19981, 19987>,
    <19995, 19996, 19997>,
    <19995, 19997, 19998>,
    <19995, 19998, 19989>,
    <19995, 19989, 19988>,
    <19995, 19988, 19969>,
    <19995, 19969, 19999>,
    <19995, 19999, 20000>,
    <19995, 20000, 19996>,
    <20001, 20002, 19997>,
    <20001, 19997, 19996>,
    <20001, 19996, 20000>,
    <20001, 20000, 20003>,
    <20001, 20003, 19569>,
    <20001, 19569, 19568>,
    <20001, 19568, 19567>,
    <20001, 19567, 20002>,
    <20004, 19998, 19997>,
    <20004, 19997, 20002>,
    <20004, 20002, 19567>,
    <20004, 19567, 19584>,
    <20004, 19584, 20005>,
    <20004, 20005, 19992>,
    <20004, 19992, 19989>,
    <20004, 19989, 19998>,
    <20006, 20007, 20008>,
    <20006, 20008, 20009>,
    <20006, 20009, 20010>,
    <20006, 20010, 20011>,
    <20006, 20011, 20012>,
    <20006, 20012, 20013>,
    <20006, 20014, 20015>,
    <20006, 20015, 20007>,
    <20016, 20017, 20008>,
    <20016, 20008, 20007>,
    <20016, 20007, 20018>,
    <20016, 20018, 20019>,
    <20016, 20020, 20021>,
    <20016, 20021, 19345>,
    <20016, 19345, 19344>,
    <20016, 19344, 20017>,
    <20022, 20009, 20008>,
    <20022, 20008, 20017>,
    <20022, 20017, 19344>,
    <20022, 19344, 19357>,
    <20022, 19357, 18715>,
    <20022, 18715, 20023>,
    <20022, 20023, 20010>,
    <20022, 20010, 20009>,
    <20024, 20025, 20026>,
    <20024, 20026, 20027>,
    <20024, 20027, 19692>,
    <20024, 19692, 19691>,
    <20024, 19691, 20028>,
    <20024, 20028, 20029>,
    <20024, 20030, 20031>,
    <20024, 20031, 20025>,
    <20032, 20033, 20026>,
    <20032, 20026, 20025>,
    <20032, 20025, 20034>,
    <20032, 20034, 20035>,
    <20032, 20036, 20037>,
    <20032, 20037, 20038>,
    <20032, 20038, 20039>,
    <20032, 20039, 20033>,
    <20040, 20027, 20026>,
    <20040, 20026, 20033>,
    <20040, 20033, 20039>,
    <20040, 20039, 20041>,
    <20040, 20041, 19672>,
    <20040, 19672, 19694>,
    <20040, 19694, 19692>,
    <20040, 19692, 20027>,
    <20042, 20043, 20044>,
    <20042, 20044, 20045>,
    <20042, 20045, 20046>,
    <20042, 20046, 20047>,
    <20042, 20047, 20048>,
    <20042, 20048, 20011>,
    <20042, 20011, 20010>,
    <20042, 20010, 20043>,
    <20049, 20050, 20044>,
    <20049, 20044, 20043>,
    <20049, 20043, 20010>,
    <20049, 20010, 20023>,
    <20049, 20023, 18715>,
    <20049, 18715, 19727>,
    <20049, 19727, 19724>,
    <20049, 19724, 20050>,
    <20051, 20045, 20044>,
    <20051, 20044, 20050>,
    <20051, 20050, 19724>,
    <20051, 19724, 19723>,
    <20051, 19723, 19711>,
    <20051, 19711, 20052>,
    <20051, 20052, 20046>,
    <20051, 20046, 20045>,
    <20053, 20054, 20055>,
    <20053, 20055, 20056>,
    <20053, 20056, 19885>,
    <20053, 19885, 19884>,
    <20053, 19884, 19873>,
    <20053, 19873, 20057>,
    <20053, 20057, 20058>,
    <20053, 20058, 20054>,
    <20059, 20060, 20055>,
    <20059, 20055, 20054>,
    <20059, 20054, 20058>,
    <20059, 20058, 20061>,
    <20059, 20061, 20062>,
    <20059, 20062, 20063>,
    <20059, 20063, 20064>,
    <20059, 20064, 20060>,
    <20065, 20056, 20055>,
    <20065, 20055, 20060>,
    <20065, 20060, 20064>,
    <20065, 20064, 20066>,
    <20065, 20066, 19623>,
    <20065, 19623, 19887>,
    <20065, 19887, 19885>,
    <20065, 19885, 20056>,
    <20067, 20068, 20069>,
    <20067, 20069, 20070>,
    <20067, 20070, 19965>,
    <20067, 19965, 19964>,
    <20067, 19964, 19623>,
    <20067, 19623, 20066>,
    <20067, 20066, 20064>,
    <20067, 20064, 20068>,
    <20071, 20072, 20069>,
    <20071, 20069, 20068>,
    <20071, 20068, 20064>,
    <20071, 20064, 20063>,
    <20071, 20063, 20062>,
    <20071, 20062, 20073>,
    <20071, 20073, 20074>,
    <20071, 20074, 20072>,
    <20075, 20070, 20069>,
    <20075, 20069, 20072>,
    <20075, 20072, 20074>,
    <20075, 20074, 20076>,
    <20075, 20076, 19969>,
    <20075, 19969, 19968>,
    <20075, 19968, 19965>,
    <20075, 19965, 20070>,
    <20077, 20078, 20079>,
    <20077, 20079, 20080>,
    <20077, 20080, 20074>,
    <20077, 20074, 20073>,
    <20077, 20073, 20062>,
    <20077, 20062, 20081>,
    <20077, 20081, 20082>,
    <20077, 20082, 20078>,
    <20083, 20084, 20079>,
    <20083, 20079, 20078>,
    <20083, 20078, 20082>,
    <20083, 20082, 20085>,
    <20083, 20085, 19569>,
    <20083, 19569, 20003>,
    <20083, 20003, 20000>,
    <20083, 20000, 20084>,
    <20086, 20080, 20079>,
    <20086, 20079, 20084>,
    <20086, 20084, 20000>,
    <20086, 20000, 19999>,
    <20086, 19999, 19969>,
    <20086, 19969, 20076>,
    <20086, 20076, 20074>,
    <20086, 20074, 20080>,
    <20087, 20088, 20089>,
    <20087, 20089, 20090>,
    <20087, 20090, 20082>,
    <20087, 20082, 20081>,
    <20087, 20081, 20062>,
    <20087, 20062, 20091>,
    <20087, 20091, 20092>,
    <20087, 20092, 20088>,
    <20093, 20094, 20089>,
    <20093, 20089, 20088>,
    <20093, 20088, 20092>,
    <20093, 20092, 20095>,
    <20093, 20095, 19644>,
    <20093, 19644, 19643>,
    <20093, 19643, 19642>,
    <20093, 19642, 20094>,
    <20096, 20090, 20089>,
    <20096, 20089, 20094>,
    <20096, 20094, 19642>,
    <20096, 19642, 19651>,
    <20096, 19651, 19569>,
    <20096, 19569, 20085>,
    <20096, 20085, 20082>,
    <20096, 20082, 20090>,
    <20097, 20098, 20099>,
    <20097, 20099, 20100>,
    <20097, 20100, 20101>,
    <20097, 20101, 20102>,
    <20097, 20102, 19370>,
    <20097, 19370, 19381>,
    <20097, 19381, 19379>,
    <20097, 19379, 20098>,
    <20103, 20104, 20099>,
    <20103, 20099, 20098>,
    <20103, 20098, 19379>,
    <20103, 19379, 19378>,
    <20103, 19378, 19256>,
    <20103, 19256, 20105>,
    <20103, 20105, 20106>,
    <20103, 20106, 20104>,
    <20107, 20100, 20099>,
    <20107, 20099, 20104>,
    <20107, 20104, 20106>,
    <20107, 20106, 20108>,
    <20107, 20108, 20109>,
    <20107, 20109, 20110>,
    <20107, 20110, 20101>,
    <20107, 20101, 20100>,
    <20111, 20112, 20113>,
    <20111, 20113, 20114>,
    <20111, 20114, 20106>,
    <20111, 20106, 20105>,
    <20111, 20105, 19256>,
    <20111, 19256, 19917>,
    <20111, 19917, 19916>,
    <20111, 19916, 20112>,
    <20115, 20116, 20113>,
    <20115, 20113, 20112>,
    <20115, 20112, 19916>,
    <20115, 19916, 19925>,
    <20115, 19925, 19924>,
    <20115, 19924, 20117>,
    <20115, 20117, 20118>,
    <20115, 20118, 20116>,
    <20119, 20114, 20113>,
    <20119, 20113, 20116>,
    <20119, 20116, 20118>,
    <20119, 20118, 20120>,
    <20119, 20120, 20109>,
    <20119, 20109, 20108>,
    <20119, 20108, 20106>,
    <20119, 20106, 20114>,
    <20121, 20122, 20123>,
    <20121, 20123, 20124>,
    <20121, 20124, 20125>,
    <20121, 20125, 20126>,
    <20121, 20126, 20127>,
    <20121, 20127, 20128>,
    <20121, 20128, 20129>,
    <20121, 20129, 20122>,
    <20130, 20131, 20123>,
    <20130, 20123, 20122>,
    <20130, 20122, 20129>,
    <20130, 20129, 20132>,
    <20130, 20132, 19942>,
    <20130, 19942, 19955>,
    <20130, 19955, 19954>,
    <20130, 19954, 20131>,
    <20133, 20124, 20123>,
    <20133, 20123, 20131>,
    <20133, 20131, 19954>,
    <20133, 19954, 19959>,
    <20133, 19959, 19226>,
    <20133, 19226, 20134>,
    <20133, 20134, 20125>,
    <20133, 20125, 20124>,
    <20135, 20136, 20137>,
    <20135, 20137, 20138>,
    <20135, 20138, 20139>,
    <20135, 20139, 20140>,
    <20135, 20140, 20127>,
    <20135, 20127, 20126>,
    <20135, 20126, 20125>,
    <20135, 20125, 20136>,
    <20141, 20142, 20137>,
    <20141, 20137, 20136>,
    <20141, 20136, 20125>,
    <20141, 20125, 20134>,
    <20141, 20134, 19226>,
    <20141, 19226, 19279>,
    <20141, 19279, 19276>,
    <20141, 19276, 20142>,
    <20143, 20138, 20137>,
    <20143, 20137, 20142>,
    <20143, 20142, 19276>,
    <20143, 19276, 19275>,
    <20143, 19275, 19274>,
    <20143, 19274, 20144>,
    <20143, 20144, 20139>,
    <20143, 20139, 20138>,
    <20145, 20146, 20147>,
    <20145, 20147, 20148>,
    <20145, 20148, 20149>,
    <20145, 20149, 20150>,
    <20145, 20150, 19759>,
    <20145, 19759, 19771>,
    <20145, 19771, 19769>,
    <20145, 19769, 20146>,
    <20151, 20152, 20147>,
    <20151, 20147, 20146>,
    <20151, 20146, 19769>,
    <20151, 19769, 19768>,
    <20151, 19768, 20153>,
    <20151, 20153, 5384>,
    <20151, 5384, 5383>,
    <20151, 5383, 20152>,
    <20154, 20148, 20147>,
    <20154, 20147, 20152>,
    <20154, 20152, 5383>,
    <20154, 5383, 5393>,
    <20154, 5393, 20155>,
    <20154, 20155, 20156>,
    <20154, 20156, 20149>,
    <20154, 20149, 20148>,
    <20157, 20158, 20159>,
    <20157, 20159, 20160>,
    <20157, 20160, 19427>,
    <20157, 19427, 19426>,
    <20157, 19426, 19415>,
    <20157, 19415, 20161>,
    <20157, 20161, 20162>,
    <20157, 20162, 20158>,
    <20163, 20164, 20159>,
    <20163, 20159, 20158>,
    <20163, 20158, 20162>,
    <20163, 20162, 20165>,
    <20163, 20165, 20166>,
    <20163, 20166, 20167>,
    <20163, 20167, 20168>,
    <20163, 20168, 20164>,
    <20169, 20160, 20159>,
    <20169, 20159, 20164>,
    <20169, 20164, 20168>,
    <20169, 20168, 20170>,
    <20169, 20170, 19301>,
    <20169, 19301, 19429>,
    <20169, 19429, 19427>,
    <20169, 19427, 20160>,
    <20171, 20172, 20173>,
    <20171, 20173, 20174>,
    <20171, 20174, 19869>,
    <20171, 19869, 19868>,
    <20171, 19868, 19301>,
    <20171, 19301, 20170>,
    <20171, 20170, 20168>,
    <20171, 20168, 20172>,
    <20175, 20176, 20173>,
    <20175, 20173, 20172>,
    <20175, 20172, 20168>,
    <20175, 20168, 20167>,
    <20175, 20167, 20166>,
    <20175, 20166, 20177>,
    <20175, 20177, 20178>,
    <20175, 20178, 20176>,
    <20179, 20174, 20173>,
    <20179, 20173, 20176>,
    <20179, 20176, 20178>,
    <20179, 20178, 20180>,
    <20179, 20180, 19873>,
    <20179, 19873, 19872>,
    <20179, 19872, 19869>,
    <20179, 19869, 20174>,
    <20181, 20182, 20183>,
    <20181, 20183, 20184>,
    <20181, 20184, 20185>,
    <20181, 20185, 20186>,
    <20181, 20186, 20187>,
    <20181, 20187, 20188>,
    <20181, 20188, 20189>,
    <20181, 20189, 20182>,
    <20190, 20191, 20183>,
    <20190, 20183, 20182>,
    <20190, 20182, 20189>,
    <20190, 20189, 20192>,
    <20190, 20192, 19178>,
    <20190, 19178, 19910>,
    <20190, 19910, 19907>,
    <20190, 19907, 20191>,
    <20193, 20184, 20183>,
    <20193, 20183, 20191>,
    <20193, 20191, 19907>,
    <20193, 19907, 19906>,
    <20193, 19906, 19894>,
    <20193, 19894, 20194>,
    <20193, 20194, 20185>,
    <20193, 20185, 20184>,
    <20195, 20196, 20197>,
    <20195, 20197, 20198>,
    <20195, 20198, 20189>,
    <20195, 20189, 20188>,
    <20195, 20188, 20187>,
    <20195, 20187, 20199>,
    <20195, 20199, 20200>,
    <20195, 20200, 20196>,
    <20201, 20202, 20197>,
    <20201, 20197, 20196>,
    <20201, 20196, 20200>,
    <20201, 20200, 20203>,
    <20201, 20203, 19322>,
    <20201, 19322, 19321>,
    <20201, 19321, 19320>,
    <20201, 19320, 20202>,
    <20204, 20198, 20197>,
    <20204, 20197, 20202>,
    <20204, 20202, 19320>,
    <20204, 19320, 19329>,
    <20204, 19329, 19178>,
    <20204, 19178, 20192>,
    <20204, 20192, 20189>,
    <20204, 20189, 20198>,
    <20205, 20206, 20207>,
    <20205, 20207, 20208>,
    <20205, 20208, 20209>,
    <20205, 20209, 20210>,
    <20205, 20210, 19924>,
    <20205, 19924, 19935>,
    <20205, 19935, 19933>,
    <20205, 19933, 20206>,
    <20211, 20212, 20207>,
    <20211, 20207, 20206>,
    <20211, 20206, 19933>,
    <20211, 19933, 19932>,
    <20211, 19932, 19759>,
    <20211, 19759, 20213>,
    <20211, 20213, 20214>,
    <20211, 20214, 20212>,
    <20215, 20208, 20207>,
    <20215, 20207, 20212>,
    <20215, 20212, 20214>,
    <20215, 20214, 20216>,
    <20215, 20216, 20217>,
    <20215, 20217, 20218>,
    <20215, 20218, 20209>,
    <20215, 20209, 20208>,
    <20219, 20220, 20221>,
    <20219, 20221, 20222>,
    <20219, 20222, 20214>,
    <20219, 20214, 20213>,
    <20219, 20213, 19759>,
    <20219, 19759, 20150>,
    <20219, 20150, 20149>,
    <20219, 20149, 20220>,
    <20223, 20224, 20221>,
    <20223, 20221, 20220>,
    <20223, 20220, 20149>,
    <20223, 20149, 20156>,
    <20223, 20156, 20225>,
    <20223, 20225, 20226>,
    <20223, 20226, 20227>,
    <20223, 20227, 20224>,
    <20228, 20222, 20221>,
    <20228, 20221, 20224>,
    <20228, 20224, 20227>,
    <20228, 20227, 20229>,
    <20228, 20229, 20217>,
    <20228, 20217, 20216>,
    <20228, 20216, 20214>,
    <20228, 20214, 20222>,
    <20230, 20231, 20232>,
    <20230, 20232, 20233>,
    <20230, 20233, 20234>,
    <20230, 20234, 20235>,
    <20230, 20235, 20217>,
    <20230, 20217, 20229>,
    <20230, 20229, 20227>,
    <20230, 20227, 20231>,
    <20236, 20237, 20232>,
    <20236, 20232, 20231>,
    <20236, 20231, 20227>,
    <20236, 20227, 20226>,
    <20236, 20226, 20238>,
    <20236, 20238, 20239>,
    <20236, 20240, 20241>,
    <20236, 20241, 20237>,
    <20242, 20233, 20232>,
    <20242, 20232, 20237>,
    <20242, 20237, 20243>,
    <20242, 20243, 20244>,
    <20242, 20245, 20246>,
    <20242, 20246, 20247>,
    <20242, 20247, 20234>,
    <20242, 20234, 20233>,
    <20248, 20249, 20250>,
    <20248, 20250, 20251>,
    <20248, 20251, 20252>,
    <20248, 20252, 20253>,
    <20248, 20253, 20217>,
    <20248, 20217, 20235>,
    <20248, 20235, 20234>,
    <20248, 20234, 20249>,
    <20254, 20255, 20250>,
    <20254, 20250, 20249>,
    <20254, 20249, 20234>,
    <20254, 20234, 20247>,
    <20254, 20247, 20256>,
    <20254, 20256, 19783>,
    <20254, 19783, 19780>,
    <20254, 19780, 20255>,
    <20257, 20251, 20250>,
    <20257, 20250, 20255>,
    <20257, 20255, 19780>,
    <20257, 19780, 19779>,
    <20257, 19779, 19778>,
    <20257, 19778, 20258>,
    <20257, 20258, 20252>,
    <20257, 20252, 20251>,
    <20259, 20260, 20261>,
    <20259, 20261, 20262>,
    <20259, 20262, 20263>,
    <20259, 20263, 20264>,
    <20259, 20264, 20265>,
    <20259, 20265, 20266>,
    <20259, 20267, 20268>,
    <20259, 20268, 20260>,
    <20269, 20270, 20261>,
    <20269, 20261, 20260>,
    <20269, 20260, 20271>,
    <20269, 20271, 20272>,
    <20269, 20273, 20274>,
    <20269, 20274, 20275>,
    <20269, 20275, 20276>,
    <20269, 20276, 20270>,
    <20277, 20262, 20261>,
    <20277, 20261, 20270>,
    <20277, 20270, 20276>,
    <20277, 20276, 20278>,
    <20277, 20278, 20279>,
    <20277, 20279, 20280>,
    <20277, 20280, 20263>,
    <20277, 20263, 20262>,
    <20281, 20282, 20283>,
    <20281, 20283, 20284>,
    <20281, 20284, 20276>,
    <20281, 20276, 20275>,
    <20281, 20275, 20285>,
    <20281, 20285, 19459>,
    <20281, 19459, 19458>,
    <20281, 19458, 20282>,
    <20286, 20287, 20283>,
    <20286, 20283, 20282>,
    <20286, 20282, 19458>,
    <20286, 19458, 19471>,
    <20286, 19471, 18848>,
    <20286, 18848, 20288>,
    <20286, 20288, 20289>,
    <20286, 20289, 20287>,
    <20290, 20284, 20283>,
    <20290, 20283, 20287>,
    <20290, 20287, 20289>,
    <20290, 20289, 20291>,
    <20290, 20291, 20279>,
    <20290, 20279, 20278>,
    <20290, 20278, 20276>,
    <20290, 20276, 20284>,
    <20292, 20293, 20294>,
    <20292, 20294, 20295>,
    <20292, 20295, 20289>,
    <20292, 20289, 20288>,
    <20292, 20288, 18848>,
    <20292, 18848, 19810>,
    <20292, 19810, 19809>,
    <20292, 19809, 20293>,
    <20296, 20297, 20294>,
    <20296, 20294, 20293>,
    <20296, 20293, 19809>,
    <20296, 19809, 19818>,
    <20296, 19818, 19817>,
    <20296, 19817, 20298>,
    <20296, 20298, 20299>,
    <20296, 20299, 20297>,
    <20300, 20295, 20294>,
    <20300, 20294, 20297>,
    <20300, 20297, 20299>,
    <20300, 20299, 20301>,
    <20300, 20301, 20279>,
    <20300, 20279, 20291>,
    <20300, 20291, 20289>,
    <20300, 20289, 20295>,
    <20302, 20303, 20304>,
    <20302, 20304, 20305>,
    <20302, 20305, 20306>,
    <20302, 20306, 20307>,
    <20302, 20307, 20308>,
    <20302, 20308, 20309>,
    <20302, 20309, 20310>,
    <20302, 20310, 20303>,
    <20311, 20312, 20304>,
    <20311, 20304, 20303>,
    <20311, 20303, 20310>,
    <20311, 20310, 20313>,
    <20311, 20313, 19835>,
    <20311, 19835, 19848>,
    <20311, 19848, 19847>,
    <20311, 19847, 20312>,
    <20314, 20305, 20304>,
    <20314, 20304, 20312>,
    <20314, 20312, 19847>,
    <20314, 19847, 19852>,
    <20314, 19852, 18763>,
    <20314, 18763, 20315>,
    <20314, 20315, 20306>,
    <20314, 20306, 20305>,
    <20316, 20317, 20318>,
    <20316, 20318, 20319>,
    <20316, 20319, 19605>,
    <20316, 19605, 19604>,
    <20316, 19604, 20320>,
    <20316, 20320, 20321>,
    <20316, 20321, 20322>,
    <20316, 20322, 20317>,
    <20323, 20324, 20318>,
    <20323, 20318, 20317>,
    <20323, 20317, 20322>,
    <20323, 20322, 20325>,
    <20323, 20325, 20308>,
    <20323, 20308, 20326>,
    <20323, 20326, 20327>,
    <20323, 20327, 20324>,
    <20328, 20319, 20318>,
    <20328, 20318, 20324>,
    <20328, 20324, 20327>,
    <20328, 20327, 20329>,
    <20328, 20329, 18891>,
    <20328, 18891, 19608>,
    <20328, 19608, 19605>,
    <20328, 19605, 20319>,
    <20330, 20331, 20332>,
    <20330, 20332, 20333>,
    <20330, 20333, 20327>,
    <20330, 20327, 20326>,
    <20330, 20326, 20308>,
    <20330, 20308, 20307>,
    <20330, 20307, 20306>,
    <20330, 20306, 20331>,
    <20334, 20335, 20332>,
    <20334, 20332, 20331>,
    <20334, 20331, 20306>,
    <20334, 20306, 20315>,
    <20334, 20315, 18763>,
    <20334, 18763, 18903>,
    <20334, 18903, 18900>,
    <20334, 18900, 20335>,
    <20336, 20333, 20332>,
    <20336, 20332, 20335>,
    <20336, 20335, 18900>,
    <20336, 18900, 18899>,
    <20336, 18899, 18891>,
    <20336, 18891, 20329>,
    <20336, 20329, 20327>,
    <20336, 20327, 20333>,
    <20337, 20338, 20339>,
    <20337, 20339, 20340>,
    <20337, 20340, 20178>,
    <20337, 20178, 20177>,
    <20337, 20177, 20166>,
    <20337, 20166, 20341>,
    <20337, 20341, 20342>,
    <20337, 20342, 20338>,
    <20343, 20344, 20339>,
    <20343, 20339, 20338>,
    <20343, 20338, 20342>,
    <20343, 20342, 20345>,
    <20343, 20345, 20346>,
    <20343, 20346, 20347>,
    <20343, 20347, 20348>,
    <20343, 20348, 20344>,
    <20349, 20340, 20339>,
    <20349, 20339, 20344>,
    <20349, 20344, 20348>,
    <20349, 20348, 20350>,
    <20349, 20350, 19873>,
    <20349, 19873, 20180>,
    <20349, 20180, 20178>,
    <20349, 20178, 20340>,
    <20351, 20352, 20353>,
    <20351, 20353, 20354>,
    <20351, 20354, 20058>,
    <20351, 20058, 20057>,
    <20351, 20057, 19873>,
    <20351, 19873, 20350>,
    <20351, 20350, 20348>,
    <20351, 20348, 20352>,
    <20355, 20356, 20353>,
    <20355, 20353, 20352>,
    <20355, 20352, 20348>,
    <20355, 20348, 20347>,
    <20355, 20347, 20346>,
    <20355, 20346, 20357>,
    <20355, 20357, 20358>,
    <20355, 20358, 20356>,
    <20359, 20354, 20353>,
    <20359, 20353, 20356>,
    <20359, 20356, 20358>,
    <20359, 20358, 20360>,
    <20359, 20360, 20062>,
    <20359, 20062, 20061>,
    <20359, 20061, 20058>,
    <20359, 20058, 20354>,
    <20361, 20362, 20363>,
    <20361, 20363, 20364>,
    <20361, 20364, 20358>,
    <20361, 20358, 20357>,
    <20361, 20357, 20346>,
    <20361, 20346, 20365>,
    <20361, 20365, 20366>,
    <20361, 20366, 20362>,
    <20367, 20368, 20363>,
    <20367, 20363, 20362>,
    <20367, 20362, 20366>,
    <20367, 20366, 20369>,
    <20367, 20369, 19644>,
    <20367, 19644, 20095>,
    <20367, 20095, 20092>,
    <20367, 20092, 20368>,
    <20370, 20364, 20363>,
    <20370, 20363, 20368>,
    <20370, 20368, 20092>,
    <20370, 20092, 20091>,
    <20370, 20091, 20062>,
    <20370, 20062, 20360>,
    <20370, 20360, 20358>,
    <20370, 20358, 20364>,
    <20371, 20372, 20373>,
    <20371, 20373, 20374>,
    <20371, 20374, 20366>,
    <20371, 20366, 20365>,
    <20371, 20365, 20346>,
    <20371, 20346, 20375>,
    <20371, 20375, 20376>,
    <20371, 20376, 20372>,
    <20377, 20378, 20373>,
    <20377, 20373, 20372>,
    <20377, 20372, 20376>,
    <20377, 20376, 20379>,
    <20377, 20379, 19894>,
    <20377, 19894, 19893>,
    <20377, 19893, 19892>,
    <20377, 19892, 20378>,
    <20380, 20374, 20373>,
    <20380, 20373, 20378>,
    <20380, 20378, 19892>,
    <20380, 19892, 19901>,
    <20380, 19901, 19644>,
    <20380, 19644, 20369>,
    <20380, 20369, 20366>,
    <20380, 20366, 20374>,
    <20381, 20382, 20383>,
    <20381, 20383, 20384>,
    <20381, 20384, 20322>,
    <20381, 20322, 20321>,
    <20381, 20321, 20385>,
    <20381, 20385, 20386>,
    <20381, 20387, 20388>,
    <20381, 20388, 20382>,
    <20389, 20390, 20383>,
    <20389, 20383, 20382>,
    <20389, 20382, 20391>,
    <20389, 20391, 20392>,
    <20389, 20393, 20394>,
    <20389, 20394, 20395>,
    <20389, 20395, 20396>,
    <20389, 20396, 20390>,
    <20397, 20384, 20383>,
    <20397, 20383, 20390>,
    <20397, 20390, 20396>,
    <20397, 20396, 20398>,
    <20397, 20398, 20308>,
    <20397, 20308, 20325>,
    <20397, 20325, 20322>,
    <20397, 20322, 20384>,
    <20399, 20400, 20401>,
    <20399, 20401, 20402>,
    <20399, 20402, 20403>,
    <20399, 20403, 20404>,
    <20399, 20404, 20109>,
    <20399, 20109, 20120>,
    <20399, 20120, 20118>,
    <20399, 20118, 20400>,
    <20405, 20406, 20401>,
    <20405, 20401, 20400>,
    <20405, 20400, 20118>,
    <20405, 20118, 20117>,
    <20405, 20117, 19924>,
    <20405, 19924, 20407>,
    <20405, 20407, 20408>,
    <20405, 20408, 20406>,
    <20409, 20402, 20401>,
    <20409, 20401, 20406>,
    <20409, 20406, 20408>,
    <20409, 20408, 20410>,
    <20409, 20410, 20411>,
    <20409, 20411, 20412>,
    <20409, 20412, 20403>,
    <20409, 20403, 20402>,
    <20413, 20414, 20415>,
    <20413, 20415, 20416>,
    <20413, 20416, 20408>,
    <20413, 20408, 20407>,
    <20413, 20407, 19924>,
    <20413, 19924, 20210>,
    <20413, 20210, 20209>,
    <20413, 20209, 20414>,
    <20417, 20418, 20415>,
    <20417, 20415, 20414>,
    <20417, 20414, 20209>,
    <20417, 20209, 20218>,
    <20417, 20218, 20217>,
    <20417, 20217, 20419>,
    <20417, 20419, 20420>,
    <20417, 20420, 20418>,
    <20421, 20416, 20415>,
    <20421, 20415, 20418>,
    <20421, 20418, 20420>,
    <20421, 20420, 20422>,
    <20421, 20422, 20411>,
    <20421, 20411, 20410>,
    <20421, 20410, 20408>,
    <20421, 20408, 20416>,
    <20423, 20424, 20425>,
    <20423, 20425, 20426>,
    <20423, 20426, 20427>,
    <20423, 20427, 20428>,
    <20423, 20428, 20411>,
    <20423, 20411, 20422>,
    <20423, 20422, 20420>,
    <20423, 20420, 20424>,
    <20429, 20430, 20425>,
    <20429, 20425, 20424>,
    <20429, 20424, 20420>,
    <20429, 20420, 20419>,
    <20429, 20419, 20217>,
    <20429, 20217, 20253>,
    <20429, 20253, 20252>,
    <20429, 20252, 20430>,
    <20431, 20426, 20425>,
    <20431, 20425, 20430>,
    <20431, 20430, 20252>,
    <20431, 20252, 20258>,
    <20431, 20258, 19778>,
    <20431, 19778, 20432>,
    <20431, 20432, 20427>,
    <20431, 20427, 20426>,
    <20433, 20434, 20435>,
    <20433, 20435, 20436>,
    <20433, 20436, 20437>,
    <20433, 20437, 20438>,
    <20433, 20438, 20411>,
    <20433, 20411, 20428>,
    <20433, 20428, 20427>,
    <20433, 20427, 20434>,
    <20439, 20440, 20435>,
    <20439, 20435, 20434>,
    <20439, 20434, 20427>,
    <20439, 20427, 20432>,
    <20439, 20432, 19778>,
    <20439, 19778, 19947>,
    <20439, 19947, 19944>,
    <20439, 19944, 20440>,
    <20441, 20436, 20435>,
    <20441, 20435, 20440>,
    <20441, 20440, 19944>,
    <20441, 19944, 19943>,
    <20441, 19943, 19942>,
    <20441, 19942, 20442>,
    <20441, 20442, 20437>,
    <20441, 20437, 20436>,
    <20443, 20444, 20445>,
    <20443, 20445, 20446>,
    <20443, 20446, 20447>,
    <20443, 20447, 20448>,
    <20443, 20448, 19502>,
    <20443, 19502, 19513>,
    <20443, 19513, 19511>,
    <20443, 19511, 20444>,
    <20449, 20450, 20445>,
    <20449, 20445, 20444>,
    <20449, 20444, 19511>,
    <20449, 19511, 19510>,
    <20449, 19510, 19370>,
    <20449, 19370, 20451>,
    <20449, 20451, 20452>,
    <20449, 20452, 20450>,
    <20453, 20446, 20445>,
    <20453, 20445, 20450>,
    <20453, 20450, 20452>,
    <20453, 20452, 20454>,
    <20453, 20454, 20455>,
    <20453, 20455, 20456>,
    <20453, 20456, 20447>,
    <20453, 20447, 20446>,
    <20457, 20458, 20459>,
    <20457, 20459, 20460>,
    <20457, 20460, 20452>,
    <20457, 20452, 20451>,
    <20457, 20451, 19370>,
    <20457, 19370, 20102>,
    <20457, 20102, 20101>,
    <20457, 20101, 20458>,
    <20461, 20462, 20459>,
    <20461, 20459, 20458>,
    <20461, 20458, 20101>,
    <20461, 20101, 20110>,
    <20461, 20110, 20109>,
    <20461, 20109, 20463>,
    <20461, 20463, 20464>,
    <20461, 20464, 20462>,
    <20465, 20460, 20459>,
    <20465, 20459, 20462>,
    <20465, 20462, 20464>,
    <20465, 20464, 20466>,
    <20465, 20466, 20455>,
    <20465, 20455, 20454>,
    <20465, 20454, 20452>,
    <20465, 20452, 20460>,
    <20467, 20468, 20469>,
    <20467, 20469, 20470>,
    <20467, 20470, 20471>,
    <20467, 20471, 20472>,
    <20467, 20472, 20473>,
    <20467, 20473, 20474>,
    <20467, 20474, 20475>,
    <20467, 20475, 20468>,
    <20476, 20477, 20469>,
    <20476, 20469, 20468>,
    <20476, 20468, 20475>,
    <20476, 20475, 20478>,
    <20476, 20478, 20127>,
    <20476, 20127, 20140>,
    <20476, 20140, 20139>,
    <20476, 20139, 20477>,
    <20479, 20470, 20469>,
    <20479, 20469, 20477>,
    <20479, 20477, 20139>,
    <20479, 20139, 20144>,
    <20479, 20144, 19274>,
    <20479, 19274, 20480>,
    <20479, 20480, 20471>,
    <20479, 20471, 20470>,
    <20481, 20482, 20483>,
    <20481, 20483, 20484>,
    <20481, 20484, 20485>,
    <20481, 20485, 20486>,
    <20481, 20486, 20473>,
    <20481, 20473, 20472>,
    <20481, 20472, 20471>,
    <20481, 20471, 20482>,
    <20487, 20488, 20483>,
    <20487, 20483, 20482>,
    <20487, 20482, 20471>,
    <20487, 20471, 20480>,
    <20487, 20480, 19274>,
    <20487, 19274, 19393>,
    <20487, 19393, 19390>,
    <20487, 19390, 20488>,
    <20489, 20484, 20483>,
    <20489, 20483, 20488>,
    <20489, 20488, 19390>,
    <20489, 19390, 19389>,
    <20489, 19389, 19388>,
    <20489, 19388, 20490>,
    <20489, 20490, 20485>,
    <20489, 20485, 20484>,
    <20491, 20492, 20493>,
    <20491, 20493, 20494>,
    <20491, 20494, 20495>,
    <20491, 20495, 20496>,
    <20491, 20497, 20498>,
    <20491, 20498, 20264>,
    <20491, 20264, 20263>,
    <20491, 20263, 20492>,
    <20499, 20500, 20493>,
    <20499, 20493, 20492>,
    <20499, 20492, 20263>,
    <20499, 20263, 20280>,
    <20499, 20280, 20279>,
    <20499, 20279, 20501>,
    <20499, 20501, 20502>,
    <20499, 20502, 20500>,
    <20503, 20494, 20493>,
    <20503, 20493, 20500>,
    <20503, 20500, 20502>,
    <20503, 20502, 20504>,
    <20503, 20504, 20505>,
    <20503, 20505, 20506>,
    <20503, 20507, 20508>,
    <20503, 20508, 20494>,
    <20509, 20510, 20511>,
    <20509, 20511, 20512>,
    <20509, 20512, 20396>,
    <20509, 20396, 20395>,
    <20509, 20395, 20513>,
    <20509, 20513, 20514>,
    <20509, 20515, 20516>,
    <20509, 20516, 20510>,
    <20517, 20518, 20511>,
    <20517, 20511, 20510>,
    <20517, 20510, 20519>,
    <20517, 20519, 20520>,
    <20517, 20521, 20522>,
    <20517, 20522, 20523>,
    <20517, 20523, 20524>,
    <20517, 20524, 20518>,
    <20525, 20512, 20511>,
    <20525, 20511, 20518>,
    <20525, 20518, 20524>,
    <20525, 20524, 20526>,
    <20525, 20526, 20308>,
    <20525, 20308, 20398>,
    <20525, 20398, 20396>,
    <20525, 20396, 20512>,
    <20527, 20528, 20529>,
    <20527, 20529, 20530>,
    <20527, 20530, 20531>,
    <20527, 20531, 20532>,
    <20527, 20532, 20455>,
    <20527, 20455, 20466>,
    <20527, 20466, 20464>,
    <20527, 20464, 20528>,
    <20533, 20534, 20529>,
    <20533, 20529, 20528>,
    <20533, 20528, 20464>,
    <20533, 20464, 20463>,
    <20533, 20463, 20109>,
    <20533, 20109, 20535>,
    <20533, 20535, 20536>,
    <20533, 20536, 20534>,
    <20537, 20530, 20529>,
    <20537, 20529, 20534>,
    <20537, 20534, 20536>,
    <20537, 20536, 20538>,
    <20537, 20538, 20539>,
    <20537, 20539, 20540>,
    <20537, 20540, 20531>,
    <20537, 20531, 20530>,
    <20541, 20542, 20543>,
    <20541, 20543, 20544>,
    <20541, 20544, 20536>,
    <20541, 20536, 20535>,
    <20541, 20535, 20109>,
    <20541, 20109, 20404>,
    <20541, 20404, 20403>,
    <20541, 20403, 20542>,
    <20545, 20546, 20543>,
    <20545, 20543, 20542>,
    <20545, 20542, 20403>,
    <20545, 20403, 20412>,
    <20545, 20412, 20411>,
    <20545, 20411, 20547>,
    <20545, 20547, 20548>,
    <20545, 20548, 20546>,
    <20549, 20544, 20543>,
    <20549, 20543, 20546>,
    <20549, 20546, 20548>,
    <20549, 20548, 20550>,
    <20549, 20550, 20539>,
    <20549, 20539, 20538>,
    <20549, 20538, 20536>,
    <20549, 20536, 20544>,
    <20551, 20552, 20553>,
    <20551, 20553, 20554>,
    <20551, 20554, 20555>,
    <20551, 20555, 20556>,
    <20551, 20556, 20539>,
    <20551, 20539, 20550>,
    <20551, 20550, 20548>,
    <20551, 20548, 20552>,
    <20557, 20558, 20553>,
    <20557, 20553, 20552>,
    <20557, 20552, 20548>,
    <20557, 20548, 20547>,
    <20557, 20547, 20411>,
    <20557, 20411, 20438>,
    <20557, 20438, 20437>,
    <20557, 20437, 20558>,
    <20559, 20554, 20553>,
    <20559, 20553, 20558>,
    <20559, 20558, 20437>,
    <20559, 20437, 20442>,
    <20559, 20442, 19942>,
    <20559, 19942, 20560>,
    <20559, 20560, 20555>,
    <20559, 20555, 20554>,
    <20561, 20562, 20563>,
    <20561, 20563, 20564>,
    <20561, 20564, 20565>,
    <20561, 20565, 20566>,
    <20561, 20566, 20539>,
    <20561, 20539, 20556>,
    <20561, 20556, 20555>,
    <20561, 20555, 20562>,
    <20567, 20568, 20563>,
    <20567, 20563, 20562>,
    <20567, 20562, 20555>,
    <20567, 20555, 20560>,
    <20567, 20560, 19942>,
    <20567, 19942, 20132>,
    <20567, 20132, 20129>,
    <20567, 20129, 20568>,
    <20569, 20564, 20563>,
    <20569, 20563, 20568>,
    <20569, 20568, 20129>,
    <20569, 20129, 20128>,
    <20569, 20128, 20127>,
    <20569, 20127, 20570>,
    <20569, 20570, 20565>,
    <20569, 20565, 20564>,
    <20571, 20572, 20573>,
    <20571, 20573, 20574>,
    <20571, 20574, 19702>,
    <20571, 19702, 19701>,
    <20571, 19701, 19672>,
    <20571, 19672, 20575>,
    <20571, 20575, 20576>,
    <20571, 20576, 20572>,
    <20577, 20578, 20573>,
    <20577, 20573, 20572>,
    <20577, 20572, 20576>,
    <20577, 20576, 20579>,
    <20577, 20579, 20580>,
    <20577, 20580, 20581>,
    <20577, 20581, 20582>,
    <20577, 20582, 20578>,
    <20583, 20574, 20573>,
    <20583, 20573, 20578>,
    <20583, 20578, 20582>,
    <20583, 20582, 20584>,
    <20583, 20584, 19415>,
    <20583, 19415, 19704>,
    <20583, 19704, 19702>,
    <20583, 19702, 20574>,
    <20585, 20586, 20587>,
    <20585, 20587, 20588>,
    <20585, 20588, 20162>,
    <20585, 20162, 20161>,
    <20585, 20161, 19415>,
    <20585, 19415, 20584>,
    <20585, 20584, 20582>,
    <20585, 20582, 20586>,
    <20589, 20590, 20587>,
    <20589, 20587, 20586>,
    <20589, 20586, 20582>,
    <20589, 20582, 20581>,
    <20589, 20581, 20580>,
    <20589, 20580, 20591>,
    <20589, 20591, 20592>,
    <20589, 20592, 20590>,
    <20593, 20588, 20587>,
    <20593, 20587, 20590>,
    <20593, 20590, 20592>,
    <20593, 20592, 20594>,
    <20593, 20594, 20166>,
    <20593, 20166, 20165>,
    <20593, 20165, 20162>,
    <20593, 20162, 20588>,
    <20595, 20596, 20597>,
    <20595, 20597, 20598>,
    <20595, 20598, 20599>,
    <20595, 20599, 20600>,
    <20595, 20600, 20601>,
    <20595, 20601, 20602>,
    <20595, 20602, 20603>,
    <20595, 20603, 20596>,
    <20604, 20605, 20597>,
    <20604, 20597, 20596>,
    <20604, 20596, 20603>,
    <20604, 20603, 20606>,
    <20604, 20606, 19322>,
    <20604, 19322, 20203>,
    <20604, 20203, 20200>,
    <20604, 20200, 20605>,
    <20607, 20598, 20597>,
    <20607, 20597, 20605>,
    <20607, 20605, 20200>,
    <20607, 20200, 20199>,
    <20607, 20199, 20187>,
    <20607, 20187, 20608>,
    <20607, 20608, 20599>,
    <20607, 20599, 20598>,
    <20609, 20610, 20611>,
    <20609, 20611, 20612>,
    <20609, 20612, 20603>,
    <20609, 20603, 20602>,
    <20609, 20602, 20601>,
    <20609, 20601, 20613>,
    <20609, 20613, 20614>,
    <20609, 20614, 20610>,
    <20615, 20616, 20611>,
    <20615, 20611, 20610>,
    <20615, 20610, 20614>,
    <20615, 20614, 20617>,
    <20615, 20617, 19436>,
    <20615, 19436, 19435>,
    <20615, 19435, 19434>,
    <20615, 19434, 20616>,
    <20618, 20612, 20611>,
    <20618, 20611, 20616>,
    <20618, 20616, 19434>,
    <20618, 19434, 19443>,
    <20618, 19443, 19322>,
    <20618, 19322, 20606>,
    <20618, 20606, 20603>,
    <20618, 20603, 20612>,
    <20619, 20620, 20621>,
    <20619, 20621, 20622>,
    <20619, 20622, 20592>,
    <20619, 20592, 20591>,
    <20619, 20591, 20580>,
    <20619, 20580, 20623>,
    <20619, 20623, 20624>,
    <20619, 20624, 20620>,
    <20625, 20626, 20621>,
    <20625, 20621, 20620>,
    <20625, 20620, 20624>,
    <20625, 20624, 20627>,
    <20625, 20627, 20628>,
    <20625, 20628, 20629>,
    <20625, 20629, 20630>,
    <20625, 20630, 20626>,
    <20631, 20622, 20621>,
    <20631, 20621, 20626>,
    <20631, 20626, 20630>,
    <20631, 20630, 20632>,
    <20631, 20632, 20166>,
    <20631, 20166, 20594>,
    <20631, 20594, 20592>,
    <20631, 20592, 20622>,
    <20633, 20634, 20635>,
    <20633, 20635, 20636>,
    <20633, 20636, 20342>,
    <20633, 20342, 20341>,
    <20633, 20341, 20166>,
    <20633, 20166, 20632>,
    <20633, 20632, 20630>,
    <20633, 20630, 20634>,
    <20637, 20638, 20635>,
    <20637, 20635, 20634>,
    <20637, 20634, 20630>,
    <20637, 20630, 20629>,
    <20637, 20629, 20628>,
    <20637, 20628, 20639>,
    <20637, 20639, 20640>,
    <20637, 20640, 20638>,
    <20641, 20636, 20635>,
    <20641, 20635, 20638>,
    <20641, 20638, 20640>,
    <20641, 20640, 20642>,
    <20641, 20642, 20346>,
    <20641, 20346, 20345>,
    <20641, 20345, 20342>,
    <20641, 20342, 20636>,
    <20643, 20644, 20645>,
    <20643, 20645, 20646>,
    <20643, 20646, 20640>,
    <20643, 20640, 20639>,
    <20643, 20639, 20628>,
    <20643, 20628, 20647>,
    <20643, 20647, 20648>,
    <20643, 20648, 20644>,
    <20649, 20650, 20645>,
    <20649, 20645, 20644>,
    <20649, 20644, 20648>,
    <20649, 20648, 20651>,
    <20649, 20651, 19894>,
    <20649, 19894, 20379>,
    <20649, 20379, 20376>,
    <20649, 20376, 20650>,
    <20652, 20646, 20645>,
    <20652, 20645, 20650>,
    <20652, 20650, 20376>,
    <20652, 20376, 20375>,
    <20652, 20375, 20346>,
    <20652, 20346, 20642>,
    <20652, 20642, 20640>,
    <20652, 20640, 20646>,
    <20653, 20654, 20655>,
    <20653, 20655, 20656>,
    <20653, 20656, 20648>,
    <20653, 20648, 20647>,
    <20653, 20647, 20628>,
    <20653, 20628, 20657>,
    <20653, 20657, 20658>,
    <20653, 20658, 20654>,
    <20659, 20660, 20655>,
    <20659, 20655, 20654>,
    <20659, 20654, 20658>,
    <20659, 20658, 20661>,
    <20659, 20661, 20187>,
    <20659, 20187, 20186>,
    <20659, 20186, 20185>,
    <20659, 20185, 20660>,
    <20662, 20656, 20655>,
    <20662, 20655, 20660>,
    <20662, 20660, 20185>,
    <20662, 20185, 20194>,
    <20662, 20194, 19894>,
    <20662, 19894, 20651>,
    <20662, 20651, 20648>,
    <20662, 20648, 20656>,
    <20663, 20664, 20665>,
    <20663, 20665, 20666>,
    <20663, 20666, 20667>,
    <20663, 20667, 20668>,
    <20663, 20668, 19817>,
    <20663, 19817, 19828>,
    <20663, 19828, 19826>,
    <20663, 19826, 20664>,
    <20669, 20670, 20665>,
    <20669, 20665, 20664>,
    <20669, 20664, 19826>,
    <20669, 19826, 19825>,
    <20669, 19825, 19502>,
    <20669, 19502, 20671>,
    <20669, 20671, 20672>,
    <20669, 20672, 20670>,
    <20673, 20666, 20665>,
    <20673, 20665, 20670>,
    <20673, 20670, 20672>,
    <20673, 20672, 20674>,
    <20673, 20674, 20675>,
    <20673, 20675, 20676>,
    <20673, 20676, 20667>,
    <20673, 20667, 20666>,
    <20677, 20678, 20679>,
    <20677, 20679, 20680>,
    <20677, 20680, 20672>,
    <20677, 20672, 20671>,
    <20677, 20671, 19502>,
    <20677, 19502, 20448>,
    <20677, 20448, 20447>,
    <20677, 20447, 20678>,
    <20681, 20682, 20679>,
    <20681, 20679, 20678>,
    <20681, 20678, 20447>,
    <20681, 20447, 20456>,
    <20681, 20456, 20455>,
    <20681, 20455, 20683>,
    <20681, 20683, 20684>,
    <20681, 20684, 20682>,
    <20685, 20680, 20679>,
    <20685, 20679, 20682>,
    <20685, 20682, 20684>,
    <20685, 20684, 20686>,
    <20685, 20686, 20675>,
    <20685, 20675, 20674>,
    <20685, 20674, 20672>,
    <20685, 20672, 20680>,
    <20687, 20688, 20689>,
    <20687, 20689, 20690>,
    <20687, 20690, 20691>,
    <20687, 20691, 20692>,
    <20687, 20692, 20693>,
    <20687, 20693, 20694>,
    <20687, 20694, 20695>,
    <20687, 20695, 20688>,
    <20696, 20697, 20689>,
    <20696, 20689, 20688>,
    <20696, 20688, 20695>,
    <20696, 20695, 20698>,
    <20696, 20698, 20473>,
    <20696, 20473, 20486>,
    <20696, 20486, 20485>,
    <20696, 20485, 20697>,
    <20699, 20690, 20689>,
    <20699, 20689, 20697>,
    <20699, 20697, 20485>,
    <20699, 20485, 20490>,
    <20699, 20490, 19388>,
    <20699, 19388, 20700>,
    <20699, 20700, 20691>,
    <20699, 20691, 20690>,
    <20701, 20702, 20703>,
    <20701, 20703, 20704>,
    <20701, 20704, 20705>,
    <20701, 20705, 20706>,
    <20701, 20706, 20693>,
    <20701, 20693, 20692>,
    <20701, 20692, 20691>,
    <20701, 20691, 20702>,
    <20707, 20708, 20703>,
    <20707, 20703, 20702>,
    <20707, 20702, 20691>,
    <20707, 20691, 20700>,
    <20707, 20700, 19388>,
    <20707, 19388, 19525>,
    <20707, 19525, 19522>,
    <20707, 19522, 20708>,
    <20709, 20704, 20703>,
    <20709, 20703, 20708>,
    <20709, 20708, 19522>,
    <20709, 19522, 19521>,
    <20709, 19521, 19520>,
    <20709, 19520, 20710>,
    <20709, 20710, 20705>,
    <20709, 20705, 20704>,
    <20711, 20712, 20713>,
    <20711, 20713, 20714>,
    <20711, 20714, 20715>,
    <20711, 20715, 20716>,
    <20711, 20716, 20717>,
    <20711, 20717, 20718>,
    <20711, 20719, 20720>,
    <20711, 20720, 20712>,
    <20721, 20722, 20713>,
    <20721, 20713, 20712>,
    <20721, 20712, 20723>,
    <20721, 20723, 20724>,
    <20721, 20725, 20726>,
    <20721, 20726, 20047>,
    <20721, 20047, 20046>,
    <20721, 20046, 20722>,
    <20727, 20714, 20713>,
    <20727, 20713, 20722>,
    <20727, 20722, 20046>,
    <20727, 20046, 20052>,
    <20727, 20052, 19711>,
    <20727, 19711, 20728>,
    <20727, 20728, 20715>,
    <20727, 20715, 20714>,
    <20729, 20730, 20731>,
    <20729, 20731, 20732>,
    <20729, 20732, 20733>,
    <20729, 20733, 20734>,
    <20729, 20734, 20675>,
    <20729, 20675, 20686>,
    <20729, 20686, 20684>,
    <20729, 20684, 20730>,
    <20735, 20736, 20731>,
    <20735, 20731, 20730>,
    <20735, 20730, 20684>,
    <20735, 20684, 20683>,
    <20735, 20683, 20455>,
    <20735, 20455, 20737>,
    <20735, 20737, 20738>,
    <20735, 20738, 20736>,
    <20739, 20732, 20731>,
    <20739, 20731, 20736>,
    <20739, 20736, 20738>,
    <20739, 20738, 20740>,
    <20739, 20740, 20741>,
    <20739, 20741, 20742>,
    <20739, 20742, 20733>,
    <20739, 20733, 20732>,
    <20743, 20744, 20745>,
    <20743, 20745, 20746>,
    <20743, 20746, 20738>,
    <20743, 20738, 20737>,
    <20743, 20737, 20455>,
    <20743, 20455, 20532>,
    <20743, 20532, 20531>,
    <20743, 20531, 20744>,
    <20747, 20748, 20745>,
    <20747, 20745, 20744>,
    <20747, 20744, 20531>,
    <20747, 20531, 20540>,
    <20747, 20540, 20539>,
    <20747, 20539, 20749>,
    <20747, 20749, 20750>,
    <20747, 20750, 20748>,
    <20751, 20746, 20745>,
    <20751, 20745, 20748>,
    <20751, 20748, 20750>,
    <20751, 20750, 20752>,
    <20751, 20752, 20741>,
    <20751, 20741, 20740>,
    <20751, 20740, 20738>,
    <20751, 20738, 20746>,
    <20753, 20754, 20755>,
    <20753, 20755, 20756>,
    <20753, 20756, 20757>,
    <20753, 20757, 20758>,
    <20753, 20758, 20741>,
    <20753, 20741, 20752>,
    <20753, 20752, 20750>,
    <20753, 20750, 20754>,
    <20759, 20760, 20755>,
    <20759, 20755, 20754>,
    <20759, 20754, 20750>,
    <20759, 20750, 20749>,
    <20759, 20749, 20539>,
    <20759, 20539, 20566>,
    <20759, 20566, 20565>,
    <20759, 20565, 20760>,
    <20761, 20756, 20755>,
    <20761, 20755, 20760>,
    <20761, 20760, 20565>,
    <20761, 20565, 20570>,
    <20761, 20570, 20127>,
    <20761, 20127, 20762>,
    <20761, 20762, 20757>,
    <20761, 20757, 20756>,
    <20763, 20764, 20765>,
    <20763, 20765, 20766>,
    <20763, 20766, 20767>,
    <20763, 20767, 20768>,
    <20763, 20768, 20741>,
    <20763, 20741, 20758>,
    <20763, 20758, 20757>,
    <20763, 20757, 20764>,
    <20769, 20770, 20765>,
    <20769, 20765, 20764>,
    <20769, 20764, 20757>,
    <20769, 20757, 20762>,
    <20769, 20762, 20127>,
    <20769, 20127, 20478>,
    <20769, 20478, 20475>,
    <20769, 20475, 20770>,
    <20771, 20766, 20765>,
    <20771, 20765, 20770>,
    <20771, 20770, 20475>,
    <20771, 20475, 20474>,
    <20771, 20474, 20473>,
    <20771, 20473, 20772>,
    <20771, 20772, 20767>,
    <20771, 20767, 20766>,
    <20773, 20774, 20775>,
    <20773, 20775, 20776>,
    <20773, 20776, 20624>,
    <20773, 20624, 20623>,
    <20773, 20623, 20580>,
    <20773, 20580, 20777>,
    <20773, 20777, 20778>,
    <20773, 20778, 20774>,
    <20779, 20780, 20775>,
    <20779, 20775, 20774>,
    <20779, 20774, 20778>,
    <20779, 20778, 20781>,
    <20779, 20781, 20782>,
    <20779, 20782, 20783>,
    <20779, 20783, 20784>,
    <20779, 20784, 20780>,
    <20785, 20776, 20775>,
    <20785, 20775, 20780>,
    <20785, 20780, 20784>,
    <20785, 20784, 20786>,
    <20785, 20786, 20628>,
    <20785, 20628, 20627>,
    <20785, 20627, 20624>,
    <20785, 20624, 20776>,
    <20787, 20788, 20789>,
    <20787, 20789, 20790>,
    <20787, 20790, 20784>,
    <20787, 20784, 20783>,
    <20787, 20783, 20782>,
    <20787, 20782, 20791>,
    <20787, 20791, 20792>,
    <20787, 20792, 20788>,
    <20793, 20794, 20789>,
    <20793, 20789, 20788>,
    <20793, 20788, 20792>,
    <20793, 20792, 20795>,
    <20793, 20795, 20187>,
    <20793, 20187, 20661>,
    <20793, 20661, 20658>,
    <20793, 20658, 20794>,
    <20796, 20790, 20789>,
    <20796, 20789, 20794>,
    <20796, 20794, 20658>,
    <20796, 20658, 20657>,
    <20796, 20657, 20628>,
    <20796, 20628, 20786>,
    <20796, 20786, 20784>,
    <20796, 20784, 20790>,
    <20797, 20798, 20799>,
    <20797, 20799, 20800>,
    <20797, 20800, 20792>,
    <20797, 20792, 20791>,
    <20797, 20791, 20782>,
    <20797, 20782, 20801>,
    <20797, 20801, 20802>,
    <20797, 20802, 20798>,
    <20803, 20804, 20799>,
    <20803, 20799, 20798>,
    <20803, 20798, 20802>,
    <20803, 20802, 20805>,
    <20803, 20805, 20601>,
    <20803, 20601, 20600>,
    <20803, 20600, 20599>,
    <20803, 20599, 20804>,
    <20806, 20800, 20799>,
    <20806, 20799, 20804>,
    <20806, 20804, 20599>,
    <20806, 20599, 20608>,
    <20806, 20608, 20187>,
    <20806, 20187, 20795>,
    <20806, 20795, 20792>,
    <20806, 20792, 20800>,
    <20807, 20808, 20809>,
    <20807, 20809, 20810>,
    <20807, 20810, 20039>,
    <20807, 20039, 20038>,
    <20807, 20038, 20811>,
    <20807, 20811, 20812>,
    <20807, 20812, 20813>,
    <20807, 20813, 20808>,
    <20814, 20815, 20809>,
    <20814, 20809, 20808>,
    <20814, 20808, 20813>,
    <20814, 20813, 20816>,
    <20814, 20816, 20817>,
    <20814, 20817, 20818>,
    <20814, 20818, 20819>,
    <20814, 20819, 20815>,
    <20820, 20810, 20809>,
    <20820, 20809, 20815>,
    <20820, 20815, 20819>,
    <20820, 20819, 20821>,
    <20820, 20821, 19672>,
    <20820, 19672, 20041>,
    <20820, 20041, 20039>,
    <20820, 20039, 20810>,
    <20822, 20823, 20824>,
    <20822, 20824, 20825>,
    <20822, 20825, 20813>,
    <20822, 20813, 20812>,
    <20822, 20812, 20826>,
    <20822, 20826, 20827>,
    <20822, 20828, 20829>,
    <20822, 20829, 20823>,
    <20830, 20831, 20824>,
    <20830, 20824, 20823>,
    <20830, 20823, 20832>,
    <20830, 20832, 20833>,
    <20830, 20834, 20835>,
    <20830, 20835, 20836>,
    <20830, 20836, 20837>,
    <20830, 20837, 20831>,
    <20838, 20825, 20824>,
    <20838, 20824, 20831>,
    <20838, 20831, 20837>,
    <20838, 20837, 20839>,
    <20838, 20839, 20817>,
    <20838, 20817, 20816>,
    <20838, 20816, 20813>,
    <20838, 20813, 20825>,
    <20840, 20841, 20842>,
    <20840, 20842, 20843>,
    <20840, 20843, 20576>,
    <20840, 20576, 20575>,
    <20840, 20575, 19672>,
    <20840, 19672, 20821>,
    <20840, 20821, 20819>,
    <20840, 20819, 20841>,
    <20844, 20845, 20842>,
    <20844, 20842, 20841>,
    <20844, 20841, 20819>,
    <20844, 20819, 20818>,
    <20844, 20818, 20817>,
    <20844, 20817, 20846>,
    <20844, 20846, 20847>,
    <20844, 20847, 20845>,
    <20848, 20843, 20842>,
    <20848, 20842, 20845>,
    <20848, 20845, 20847>,
    <20848, 20847, 20849>,
    <20848, 20849, 20580>,
    <20848, 20580, 20579>,
    <20848, 20579, 20576>,
    <20848, 20576, 20843>,
    <20850, 20851, 20852>,
    <20850, 20852, 20853>,
    <20850, 20853, 20847>,
    <20850, 20847, 20846>,
    <20850, 20846, 20817>,
    <20850, 20817, 20854>,
    <20850, 20854, 20855>,
    <20850, 20855, 20851>,
    <20856, 20857, 20852>,
    <20856, 20852, 20851>,
    <20856, 20851, 20855>,
    <20856, 20855, 20858>,
    <20856, 20858, 20782>,
    <20856, 20782, 20781>,
    <20856, 20781, 20778>,
    <20856, 20778, 20857>,
    <20859, 20853, 20852>,
    <20859, 20852, 20857>,
    <20859, 20857, 20778>,
    <20859, 20778, 20777>,
    <20859, 20777, 20580>,
    <20859, 20580, 20849>,
    <20859, 20849, 20847>,
    <20859, 20847, 20853>,
    <20860, 20861, 20862>,
    <20860, 20862, 20863>,
    <20860, 20863, 20864>,
    <20860, 20864, 20865>,
    <20860, 20865, 20866>,
    <20860, 20866, 20867>,
    <20860, 20867, 20868>,
    <20860, 20868, 20861>,
    <20869, 20870, 20862>,
    <20869, 20862, 20861>,
    <20869, 20861, 20868>,
    <20869, 20868, 20871>,
    <20869, 20871, 19436>,
    <20869, 19436, 20617>,
    <20869, 20617, 20614>,
    <20869, 20614, 20870>,
    <20872, 20863, 20862>,
    <20872, 20862, 20870>,
    <20872, 20870, 20614>,
    <20872, 20614, 20613>,
    <20872, 20613, 20601>,
    <20872, 20601, 20873>,
    <20872, 20873, 20864>,
    <20872, 20864, 20863>,
    <20874, 20875, 20876>,
    <20874, 20876, 20877>,
    <20874, 20877, 20868>,
    <20874, 20868, 20867>,
    <20874, 20867, 20866>,
    <20874, 20866, 20878>,
    <20874, 20878, 20879>,
    <20874, 20879, 20875>,
    <20880, 20881, 20876>,
    <20880, 20876, 20875>,
    <20880, 20875, 20879>,
    <20880, 20879, 20882>,
    <20880, 20882, 19711>,
    <20880, 19711, 19710>,
    <20880, 19710, 19709>,
    <20880, 19709, 20881>,
    <20883, 20877, 20876>,
    <20883, 20876, 20881>,
    <20883, 20881, 19709>,
    <20883, 19709, 19718>,
    <20883, 19718, 19436>,
    <20883, 19436, 20871>,
    <20883, 20871, 20868>,
    <20883, 20868, 20877>,
    <20884, 20885, 20886>,
    <20884, 20886, 20887>,
    <20884, 20887, 20888>,
    <20884, 20888, 20889>,
    <20884, 20889, 20890>,
    <20884, 20890, 20891>,
    <20884, 20892, 20893>,
    <20884, 20893, 20885>,
    <20894, 20895, 20886>,
    <20894, 20886, 20885>,
    <20894, 20885, 20896>,
    <20894, 20896, 20897>,
    <20894, 20898, 20899>,
    <20894, 20899, 20504>,
    <20894, 20504, 20502>,
    <20894, 20502, 20895>,
    <20900, 20887, 20886>,
    <20900, 20886, 20895>,
    <20900, 20895, 20502>,
    <20900, 20502, 20501>,
    <20900, 20501, 20279>,
    <20900, 20279, 20901>,
    <20900, 20901, 20888>,
    <20900, 20888, 20887>,
    <20902, 20903, 20904>,
    <20902, 20904, 20905>,
    <20902, 20905, 20906>,
    <20902, 20906, 20907>,
    <20902, 20907, 20279>,
    <20902, 20279, 20301>,
    <20902, 20301, 20299>,
    <20902, 20299, 20903>,
    <20908, 20909, 20904>,
    <20908, 20904, 20903>,
    <20908, 20903, 20299>,
    <20908, 20299, 20298>,
    <20908, 20298, 19817>,
    <20908, 19817, 20910>,
    <20908, 20910, 20911>,
    <20908, 20911, 20909>,
    <20912, 20905, 20904>,
    <20912, 20904, 20909>,
    <20912, 20909, 20911>,
    <20912, 20911, 20913>,
    <20912, 20913, 20914>,
    <20912, 20914, 20915>,
    <20912, 20915, 20906>,
    <20912, 20906, 20905>,
    <20916, 20917, 20918>,
    <20916, 20918, 20919>,
    <20916, 20919, 20911>,
    <20916, 20911, 20910>,
    <20916, 20910, 19817>,
    <20916, 19817, 20668>,
    <20916, 20668, 20667>,
    <20916, 20667, 20917>,
    <20920, 20921, 20918>,
    <20920, 20918, 20917>,
    <20920, 20917, 20667>,
    <20920, 20667, 20676>,
    <20920, 20676, 20675>,
    <20920, 20675, 20922>,
    <20920, 20922, 20923>,
    <20920, 20923, 20921>,
    <20924, 20919, 20918>,
    <20924, 20918, 20921>,
    <20924, 20921, 20923>,
    <20924, 20923, 20925>,
    <20924, 20925, 20914>,
    <20924, 20914, 20913>,
    <20924, 20913, 20911>,
    <20924, 20911, 20919>,
    <20926, 20927, 20928>,
    <20926, 20928, 20929>,
    <20926, 20929, 20930>,
    <20926, 20930, 20931>,
    <20926, 20931, 20932>,
    <20926, 20932, 20933>,
    <20926, 20933, 20934>,
    <20926, 20934, 20927>,
    <20935, 20936, 20928>,
    <20935, 20928, 20927>,
    <20935, 20927, 20934>,
    <20935, 20934, 20937>,
    <20935, 20937, 20693>,
    <20935, 20693, 20706>,
    <20935, 20706, 20705>,
    <20935, 20705, 20936>,
    <20938, 20929, 20928>,
    <20938, 20928, 20936>,
    <20938, 20936, 20705>,
    <20938, 20705, 20710>,
    <20938, 20710, 19520>,
    <20938, 19520, 20939>,
    <20938, 20939, 20930>,
    <20938, 20930, 20929>,
    <20940, 20941, 20942>,
    <20940, 20942, 20943>,
    <20940, 20943, 20944>,
    <20940, 20944, 20945>,
    <20940, 20945, 20932>,
    <20940, 20932, 20931>,
    <20940, 20931, 20930>,
    <20940, 20930, 20941>,
    <20946, 20947, 20942>,
    <20946, 20942, 20941>,
    <20946, 20941, 20930>,
    <20946, 20930, 20939>,
    <20946, 20939, 19520>,
    <20946, 19520, 19840>,
    <20946, 19840, 19837>,
    <20946, 19837, 20947>,
    <20948, 20943, 20942>,
    <20948, 20942, 20947>,
    <20948, 20947, 19837>,
    <20948, 19837, 19836>,
    <20948, 19836, 19835>,
    <20948, 19835, 20949>,
    <20948, 20949, 20944>,
    <20948, 20944, 20943>,
    <20950, 20951, 20952>,
    <20950, 20952, 20953>,
    <20950, 20953, 20954>,
    <20950, 20954, 20955>,
    <20950, 20955, 20914>,
    <20950, 20914, 20925>,
    <20950, 20925, 20923>,
    <20950, 20923, 20951>,
    <20956, 20957, 20952>,
    <20956, 20952, 20951>,
    <20956, 20951, 20923>,
    <20956, 20923, 20922>,
    <20956, 20922, 20675>,
    <20956, 20675, 20958>,
    <20956, 20958, 20959>,
    <20956, 20959, 20957>,
    <20960, 20953, 20952>,
    <20960, 20952, 20957>,
    <20960, 20957, 20959>,
    <20960, 20959, 20961>,
    <20960, 20961, 20962>,
    <20960, 20962, 20963>,
    <20960, 20963, 20954>,
    <20960, 20954, 20953>,
    <20964, 20965, 20966>,
    <20964, 20966, 20967>,
    <20964, 20967, 20959>,
    <20964, 20959, 20958>,
    <20964, 20958, 20675>,
    <20964, 20675, 20734>,
    <20964, 20734, 20733>,
    <20964, 20733, 20965>,
    <20968, 20969, 20966>,
    <20968, 20966, 20965>,
    <20968, 20965, 20733>,
    <20968, 20733, 20742>,
    <20968, 20742, 20741>,
    <20968, 20741, 20970>,
    <20968, 20970, 20971>,
    <20968, 20971, 20969>,
    <20972, 20967, 20966>,
    <20972, 20966, 20969>,
    <20972, 20969, 20971>,
    <20972, 20971, 20973>,
    <20972, 20973, 20962>,
    <20972, 20962, 20961>,
    <20972, 20961, 20959>,
    <20972, 20959, 20967>,
    <20974, 20975, 20976>,
    <20974, 20976, 20977>,
    <20974, 20977, 20978>,
    <20974, 20978, 20979>,
    <20974, 20979, 20962>,
    <20974, 20962, 20973>,
    <20974, 20973, 20971>,
    <20974, 20971, 20975>,
    <20980, 20981, 20976>,
    <20980, 20976, 20975>,
    <20980, 20975, 20971>,
    <20980, 20971, 20970>,
    <20980, 20970, 20741>,
    <20980, 20741, 20768>,
    <20980, 20768, 20767>,
    <20980, 20767, 20981>,
    <20982, 20977, 20976>,
    <20982, 20976, 20981>,
    <20982, 20981, 20767>,
    <20982, 20767, 20772>,
    <20982, 20772, 20473>,
    <20982, 20473, 20983>,
    <20982, 20983, 20978>,
    <20982, 20978, 20977>,
    <20984, 20985, 20986>,
    <20984, 20986, 20987>,
    <20984, 20987, 20988>,
    <20984, 20988, 20989>,
    <20984, 20989, 20962>,
    <20984, 20962, 20979>,
    <20984, 20979, 20978>,
    <20984, 20978, 20985>,
    <20990, 20991, 20986>,
    <20990, 20986, 20985>,
    <20990, 20985, 20978>,
    <20990, 20978, 20983>,
    <20990, 20983, 20473>,
    <20990, 20473, 20698>,
    <20990, 20698, 20695>,
    <20990, 20695, 20991>,
    <20992, 20987, 20986>,
    <20992, 20986, 20991>,
    <20992, 20991, 20695>,
    <20992, 20695, 20694>,
    <20992, 20694, 20693>,
    <20992, 20693, 20993>,
    <20992, 20993, 20988>,
    <20992, 20988, 20987>,
    <20994, 20995, 20996>,
    <20994, 20996, 20997>,
    <20994, 20997, 20998>,
    <20994, 20998, 20999>,
    <20994, 21000, 21001>,
    <20994, 21001, 21002>,
    <20994, 21002, 21003>,
    <20994, 21003, 20995>,
    <21004, 21005, 20996>,
    <21004, 20996, 20995>,
    <21004, 20995, 21003>,
    <21004, 21003, 21006>,
    <21004, 21006, 20308>,
    <21004, 20308, 20526>,
    <21004, 20526, 20524>,
    <21004, 20524, 21005>,
    <21007, 20997, 20996>,
    <21007, 20996, 21005>,
    <21007, 21005, 20524>,
    <21007, 20524, 20523>,
    <21007, 20523, 21008>,
    <21007, 21008, 21009>,
    <21007, 21010, 21011>,
    <21007, 21011, 20997>,
    <21012, 21013, 21014>,
    <21012, 21014, 21015>,
    <21012, 21015, 20837>,
    <21012, 20837, 20836>,
    <21012, 20836, 21016>,
    <21012, 21016, 21017>,
    <21012, 21018, 21019>,
    <21012, 21019, 21013>,
    <21020, 21021, 21014>,
    <21020, 21014, 21013>,
    <21020, 21013, 21022>,
    <21020, 21022, 21023>,
    <21020, 21024, 21025>,
    <21020, 21025, 21026>,
    <21020, 21026, 21027>,
    <21020, 21027, 21021>,
    <21028, 21015, 21014>,
    <21028, 21014, 21021>,
    <21028, 21021, 21027>,
    <21028, 21027, 21029>,
    <21028, 21029, 20817>,
    <21028, 20817, 20839>,
    <21028, 20839, 20837>,
    <21028, 20837, 21015>,
    <21030, 21031, 21032>,
    <21030, 21032, 21033>,
    <21030, 21033, 21034>,
    <21030, 21034, 21035>,
    <21030, 21035, 21036>,
    <21030, 21036, 21037>,
    <21030, 21037, 21038>,
    <21030, 21038, 21031>,
    <21039, 21040, 21032>,
    <21039, 21032, 21031>,
    <21039, 21031, 21038>,
    <21039, 21038, 21041>,
    <21039, 21041, 19711>,
    <21039, 19711, 20882>,
    <21039, 20882, 20879>,
    <21039, 20879, 21040>,
    <21042, 21033, 21032>,
    <21042, 21032, 21040>,
    <21042, 21040, 20879>,
    <21042, 20879, 20878>,
    <21042, 20878, 20866>,
    <21042, 20866, 21043>,
    <21042, 21043, 21034>,
    <21042, 21034, 21033>,
    <21044, 21045, 21046>,
    <21044, 21046, 21047>,
    <21044, 21047, 21038>,
    <21044, 21038, 21037>,
    <21044, 21037, 21048>,
    <21044, 21048, 21049>,
    <21044, 21050, 21051>,
    <21044, 21051, 21045>,
    <21052, 21053, 21046>,
    <21052, 21046, 21045>,
    <21052, 21045, 21054>,
    <21052, 21054, 21055>,
    <21052, 21056, 21057>,
    <21052, 21057, 20716>,
    <21052, 20716, 20715>,
    <21052, 20715, 21053>,
    <21058, 21047, 21046>,
    <21058, 21046, 21053>,
    <21058, 21053, 20715>,
    <21058, 20715, 20728>,
    <21058, 20728, 19711>,
    <21058, 19711, 21041>,
    <21058, 21041, 21038>,
    <21058, 21038, 21047>,
    <21059, 21060, 21061>,
    <21059, 21061, 21062>,
    <21059, 21062, 21027>,
    <21059, 21027, 21026>,
    <21059, 21026, 21063>,
    <21059, 21063, 21064>,
    <21059, 21064, 21065>,
    <21059, 21065, 21060>,
    <21066, 21067, 21061>,
    <21066, 21061, 21060>,
    <21066, 21060, 21065>,
    <21066, 21065, 21068>,
    <21066, 21068, 21069>,
    <21066, 21069, 21070>,
    <21066, 21070, 21071>,
    <21066, 21071, 21067>,
    <21072, 21062, 21061>,
    <21072, 21061, 21067>,
    <21072, 21067, 21071>,
    <21072, 21071, 21073>,
    <21072, 21073, 20817>,
    <21072, 20817, 21029>,
    <21072, 21029, 21027>,
    <21072, 21027, 21062>,
    <21074, 21075, 21076>,
    <21074, 21076, 21077>,
    <21074, 21077, 20855>,
    <21074, 20855, 20854>,
    <21074, 20854, 20817>,
    <21074, 20817, 21073>,
    <21074, 21073, 21071>,
    <21074, 21071, 21075>,
    <21078, 21079, 21076>,
    <21078, 21076, 21075>,
    <21078, 21075, 21071>,
    <21078, 21071, 21070>,
    <21078, 21070, 21069>,
    <21078, 21069, 21080>,
    <21078, 21080, 21081>,
    <21078, 21081, 21079>,
    <21082, 21077, 21076>,
    <21082, 21076, 21079>,
    <21082, 21079, 21081>,
    <21082, 21081, 21083>,
    <21082, 21083, 20782>,
    <21082, 20782, 20858>,
    <21082, 20858, 20855>,
    <21082, 20855, 21077>,
    <21084, 21085, 21086>,
    <21084, 21086, 21087>,
    <21084, 21087, 21081>,
    <21084, 21081, 21080>,
    <21084, 21080, 21069>,
    <21084, 21069, 21088>,
    <21084, 21088, 21089>,
    <21084, 21089, 21085>,
    <21090, 21091, 21086>,
    <21090, 21086, 21085>,
    <21090, 21085, 21089>,
    <21090, 21089, 21092>,
    <21090, 21092, 20601>,
    <21090, 20601, 20805>,
    <21090, 20805, 20802>,
    <21090, 20802, 21091>,
    <21093, 21087, 21086>,
    <21093, 21086, 21091>,
    <21093, 21091, 20802>,
    <21093, 20802, 20801>,
    <21093, 20801, 20782>,
    <21093, 20782, 21083>,
    <21093, 21083, 21081>,
    <21093, 21081, 21087>,
    <21094, 21095, 21096>,
    <21094, 21096, 21097>,
    <21094, 21097, 21089>,
    <21094, 21089, 21088>,
    <21094, 21088, 21069>,
    <21094, 21069, 21098>,
    <21094, 21098, 21099>,
    <21094, 21099, 21095>,
    <21100, 21101, 21096>,
    <21100, 21096, 21095>,
    <21100, 21095, 21099>,
    <21100, 21099, 21102>,
    <21100, 21102, 20866>,
    <21100, 20866, 20865>,
    <21100, 20865, 20864>,
    <21100, 20864, 21101>,
    <21103, 21097, 21096>,
    <21103, 21096, 21101>,
    <21103, 21101, 20864>,
    <21103, 20864, 20873>,
    <21103, 20873, 20601>,
    <21103, 20601, 21092>,
    <21103, 21092, 21089>,
    <21103, 21089, 21097>,
    <21104, 21105, 21106>,
    <21104, 21106, 21107>,
    <21104, 21107, 21065>,
    <21104, 21065, 21064>,
    <21104, 21064, 21108>,
    <21104, 21108, 21109>,
    <21104, 21110, 21111>,
    <21104, 21111, 21105>,
    <21112, 21113, 21106>,
    <21112, 21106, 21105>,
    <21112, 21105, 21114>,
    <21112, 21114, 21115>,
    <21112, 21116, 21117>,
    <21112, 21117, 21118>,
    <21112, 21118, 21119>,
    <21112, 21119, 21113>,
    <21120, 21107, 21106>,
    <21120, 21106, 21113>,
    <21120, 21113, 21119>,
    <21120, 21119, 21121>,
    <21120, 21121, 21069>,
    <21120, 21069, 21068>,
    <21120, 21068, 21065>,
    <21120, 21065, 21107>,
    <21122, 21123, 21124>,
    <21122, 21124, 21125>,
    <21122, 21125, 21126>,
    <21122, 21126, 21127>,
    <21122, 21127, 21128>,
    <21122, 21128, 21129>,
    <21122, 21130, 21131>,
    <21122, 21131, 21123>,
    <21132, 21133, 21124>,
    <21132, 21124, 21123>,
    <21132, 21123, 21134>,
    <21132, 21134, 21135>,
    <21132, 21136, 21137>,
    <21132, 21137, 21035>,
    <21132, 21035, 21034>,
    <21132, 21034, 21133>,
    <21138, 21125, 21124>,
    <21138, 21124, 21133>,
    <21138, 21133, 21034>,
    <21138, 21034, 21043>,
    <21138, 21043, 20866>,
    <21138, 20866, 21139>,
    <21138, 21139, 21126>,
    <21138, 21126, 21125>,
    <21140, 21141, 21142>,
    <21140, 21142, 21143>,
    <21140, 21143, 21144>,
    <21140, 21144, 21145>,
    <21140, 21145, 20914>,
    <21140, 20914, 20955>,
    <21140, 20955, 20954>,
    <21140, 20954, 21141>,
    <21146, 21147, 21142>,
    <21146, 21142, 21141>,
    <21146, 21141, 20954>,
    <21146, 20954, 20963>,
    <21146, 20963, 20962>,
    <21146, 20962, 21148>,
    <21146, 21148, 21149>,
    <21146, 21149, 21147>,
    <21150, 21143, 21142>,
    <21150, 21142, 21147>,
    <21150, 21147, 21149>,
    <21150, 21149, 21151>,
    <21150, 21151, 21152>,
    <21150, 21152, 21153>,
    <21150, 21153, 21144>,
    <21150, 21144, 21143>,
    <21154, 21155, 21156>,
    <21154, 21156, 21157>,
    <21154, 21157, 21158>,
    <21154, 21158, 21159>,
    <21154, 21159, 21152>,
    <21154, 21152, 21151>,
    <21154, 21151, 21149>,
    <21154, 21149, 21155>,
    <21160, 21161, 21156>,
    <21160, 21156, 21155>,
    <21160, 21155, 21149>,
    <21160, 21149, 21148>,
    <21160, 21148, 20962>,
    <21160, 20962, 20989>,
    <21160, 20989, 20988>,
    <21160, 20988, 21161>,
    <21162, 21157, 21156>,
    <21162, 21156, 21161>,
    <21162, 21161, 20988>,
    <21162, 20988, 20993>,
    <21162, 20993, 20693>,
    <21162, 20693, 21163>,
    <21162, 21163, 21158>,
    <21162, 21158, 21157>,
    <21164, 21165, 21166>,
    <21164, 21166, 21167>,
    <21164, 21167, 21168>,
    <21164, 21168, 21169>,
    <21164, 21169, 21152>,
    <21164, 21152, 21159>,
    <21164, 21159, 21158>,
    <21164, 21158, 21165>,
    <21170, 21171, 21166>,
    <21170, 21166, 21165>,
    <21170, 21165, 21158>,
    <21170, 21158, 21163>,
    <21170, 21163, 20693>,
    <21170, 20693, 20937>,
    <21170, 20937, 20934>,
    <21170, 20934, 21171>,
    <21172, 21167, 21166>,
    <21172, 21166, 21171>,
    <21172, 21171, 20934>,
    <21172, 20934, 20933>,
    <21172, 20933, 20932>,
    <21172, 20932, 21173>,
    <21172, 21173, 21168>,
    <21172, 21168, 21167>,
    <21174, 21175, 21176>,
    <21174, 21176, 21177>,
    <21174, 21177, 21178>,
    <21174, 21178, 21179>,
    <21174, 21179, 21180>,
    <21174, 21180, 20889>,
    <21174, 20889, 20888>,
    <21174, 20888, 21175>,
    <21181, 21182, 21176>,
    <21181, 21176, 21175>,
    <21181, 21175, 20888>,
    <21181, 20888, 20901>,
    <21181, 20901, 20279>,
    <21181, 20279, 21183>,
    <21181, 21183, 21184>,
    <21181, 21184, 21182>,
    <21185, 21177, 21176>,
    <21185, 21176, 21182>,
    <21185, 21182, 21184>,
    <21185, 21184, 21186>,
    <21185, 21186, 21187>,
    <21185, 21187, 21188>,
    <21185, 21188, 21178>,
    <21185, 21178, 21177>,
    <21189, 21190, 21191>,
    <21189, 21191, 21192>,
    <21189, 21192, 21184>,
    <21189, 21184, 21183>,
    <21189, 21183, 20279>,
    <21189, 20279, 20907>,
    <21189, 20907, 20906>,
    <21189, 20906, 21190>,
    <21193, 21194, 21191>,
    <21193, 21191, 21190>,
    <21193, 21190, 20906>,
    <21193, 20906, 20915>,
    <21193, 20915, 20914>,
    <21193, 20914, 21195>,
    <21193, 21195, 21196>,
    <21193, 21196, 21194>,
    <21197, 21192, 21191>,
    <21197, 21191, 21194>,
    <21197, 21194, 21196>,
    <21197, 21196, 21198>,
    <21197, 21198, 21187>,
    <21197, 21187, 21186>,
    <21197, 21186, 21184>,
    <21197, 21184, 21192>,
    <21199, 21200, 21201>,
    <21199, 21201, 21202>,
    <21199, 21202, 21203>,
    <21199, 21203, 21204>,
    <21199, 21204, 21187>,
    <21199, 21187, 21198>,
    <21199, 21198, 21196>,
    <21199, 21196, 21200>,
    <21205, 21206, 21201>,
    <21205, 21201, 21200>,
    <21205, 21200, 21196>,
    <21205, 21196, 21195>,
    <21205, 21195, 20914>,
    <21205, 20914, 21145>,
    <21205, 21145, 21144>,
    <21205, 21144, 21206>,
    <21207, 21202, 21201>,
    <21207, 21201, 21206>,
    <21207, 21206, 21144>,
    <21207, 21144, 21153>,
    <21207, 21153, 21152>,
    <21207, 21152, 21208>,
    <21207, 21208, 21203>,
    <21207, 21203, 21202>,
    <21209, 21210, 21211>,
    <21209, 21211, 21212>,
    <21209, 21212, 21213>,
    <21209, 21213, 21214>,
    <21209, 21214, 21215>,
    <21209, 21215, 21216>,
    <21209, 21216, 21217>,
    <21209, 21217, 21210>,
    <21218, 21219, 21211>,
    <21218, 21211, 21210>,
    <21218, 21210, 21217>,
    <21218, 21217, 21220>,
    <21218, 21220, 20932>,
    <21218, 20932, 20945>,
    <21218, 20945, 20944>,
    <21218, 20944, 21219>,
    <21221, 21212, 21211>,
    <21221, 21211, 21219>,
    <21221, 21219, 20944>,
    <21221, 20944, 20949>,
    <21221, 20949, 19835>,
    <21221, 19835, 21222>,
    <21221, 21222, 21213>,
    <21221, 21213, 21212>,
    <21223, 21224, 21225>,
    <21223, 21225, 21226>,
    <21223, 21226, 21003>,
    <21223, 21003, 21002>,
    <21223, 21002, 21227>,
    <21223, 21227, 21228>,
    <21223, 21228, 21229>,
    <21223, 21229, 21224>,
    <21230, 21231, 21225>,
    <21230, 21225, 21224>,
    <21230, 21224, 21229>,
    <21230, 21229, 21232>,
    <21230, 21232, 21215>,
    <21230, 21215, 21233>,
    <21230, 21233, 21234>,
    <21230, 21234, 21231>,
    <21235, 21226, 21225>,
    <21235, 21225, 21231>,
    <21235, 21231, 21234>,
    <21235, 21234, 21236>,
    <21235, 21236, 20308>,
    <21235, 20308, 21006>,
    <21235, 21006, 21003>,
    <21235, 21003, 21226>,
    <21237, 21238, 21239>,
    <21237, 21239, 21240>,
    <21237, 21240, 21234>,
    <21237, 21234, 21233>,
    <21237, 21233, 21215>,
    <21237, 21215, 21214>,
    <21237, 21214, 21213>,
    <21237, 21213, 21238>,
    <21241, 21242, 21239>,
    <21241, 21239, 21238>,
    <21241, 21238, 21213>,
    <21241, 21213, 21222>,
    <21241, 21222, 19835>,
    <21241, 19835, 20313>,
    <21241, 20313, 20310>,
    <21241, 20310, 21242>,
    <21243, 21240, 21239>,
    <21243, 21239, 21242>,
    <21243, 21242, 20310>,
    <21243, 20310, 20309>,
    <21243, 20309, 20308>,
    <21243, 20308, 21236>,
    <21243, 21236, 21234>,
    <21243, 21234, 21240>,
    <21244, 21245, 21246>,
    <21244, 21246, 21247>,
    <21244, 21247, 21248>,
    <21244, 21248, 21249>,
    <21244, 21249, 21250>,
    <21244, 21250, 21251>,
    <21244, 21252, 21253>,
    <21244, 21253, 21245>,
    <21254, 21255, 21246>,
    <21254, 21246, 21245>,
    <21254, 21245, 21256>,
    <21254, 21256, 21257>,
    <21254, 21258, 21259>,
    <21254, 21259, 21179>,
    <21254, 21179, 21178>,
    <21254, 21178, 21255>,
    <21260, 21247, 21246>,
    <21260, 21246, 21255>,
    <21260, 21255, 21178>,
    <21260, 21178, 21188>,
    <21260, 21188, 21187>,
    <21260, 21187, 21261>,
    <21260, 21261, 21248>,
    <21260, 21248, 21247>,
    <21262, 21263, 21264>,
    <21262, 21264, 21265>,
    <21262, 21265, 21229>,
    <21262, 21229, 21228>,
    <21262, 21228, 21266>,
    <21262, 21266, 21267>,
    <21262, 21268, 21269>,
    <21262, 21269, 21263>,
    <21270, 21271, 21264>,
    <21270, 21264, 21263>,
    <21270, 21263, 21272>,
    <21270, 21272, 21273>,
    <21270, 21274, 21275>,
    <21270, 21275, 21276>,
    <21270, 21276, 21277>,
    <21270, 21277, 21271>,
    <21278, 21265, 21264>,
    <21278, 21264, 21271>,
    <21278, 21271, 21277>,
    <21278, 21277, 21279>,
    <21278, 21279, 21215>,
    <21278, 21215, 21232>,
    <21278, 21232, 21229>,
    <21278, 21229, 21265>,
    <21280, 21281, 21282>,
    <21280, 21282, 21283>,
    <21280, 21283, 21119>,
    <21280, 21119, 21118>,
    <21280, 21118, 21284>,
    <21280, 21284, 21285>,
    <21280, 21286, 21287>,
    <21280, 21287, 21281>,
    <21288, 21289, 21282>,
    <21288, 21282, 21281>,
    <21288, 21281, 21290>,
    <21288, 21290, 21291>,
    <21288, 21292, 21293>,
    <21288, 21293, 21294>,
    <21288, 21294, 21295>,
    <21288, 21295, 21289>,
    <21296, 21283, 21282>,
    <21296, 21282, 21289>,
    <21296, 21289, 21295>,
    <21296, 21295, 21297>,
    <21296, 21297, 21069>,
    <21296, 21069, 21121>,
    <21296, 21121, 21119>,
    <21296, 21119, 21283>,
    <21298, 21299, 21300>,
    <21298, 21300, 21301>,
    <21298, 21301, 21295>,
    <21298, 21295, 21294>,
    <21298, 21294, 21302>,
    <21298, 21302, 21303>,
    <21298, 21303, 21304>,
    <21298, 21304, 21299>,
    <21305, 21306, 21300>,
    <21305, 21300, 21299>,
    <21305, 21299, 21304>,
    <21305, 21304, 21307>,
    <21305, 21307, 20866>,
    <21305, 20866, 21102>,
    <21305, 21102, 21099>,
    <21305, 21099, 21306>,
    <21308, 21301, 21300>,
    <21308, 21300, 21306>,
    <21308, 21306, 21099>,
    <21308, 21099, 21098>,
    <21308, 21098, 21069>,
    <21308, 21069, 21297>,
    <21308, 21297, 21295>,
    <21308, 21295, 21301>,
    <21309, 21310, 21311>,
    <21309, 21311, 21312>,
    <21309, 21312, 21304>,
    <21309, 21304, 21303>,
    <21309, 21303, 21313>,
    <21309, 21313, 21314>,
    <21309, 21315, 21316>,
    <21309, 21316, 21310>,
    <21317, 21318, 21311>,
    <21317, 21311, 21310>,
    <21317, 21310, 21319>,
    <21317, 21319, 21320>,
    <21317, 21321, 21322>,
    <21317, 21322, 21127>,
    <21317, 21127, 21126>,
    <21317, 21126, 21318>,
    <21323, 21312, 21311>,
    <21323, 21311, 21318>,
    <21323, 21318, 21126>,
    <21323, 21126, 21139>,
    <21323, 21139, 20866>,
    <21323, 20866, 21307>,
    <21323, 21307, 21304>,
    <21323, 21304, 21312>,
    <21324, 21325, 21326>,
    <21324, 21326, 21327>,
    <21324, 21327, 21328>,
    <21324, 21328, 21329>,
    <21324, 21330, 21331>,
    <21324, 21331, 21249>,
    <21324, 21249, 21248>,
    <21324, 21248, 21325>,
    <21332, 21333, 21326>,
    <21332, 21326, 21325>,
    <21332, 21325, 21248>,
    <21332, 21248, 21261>,
    <21332, 21261, 21187>,
    <21332, 21187, 21334>,
    <21332, 21334, 21335>,
    <21332, 21335, 21333>,
    <21336, 21327, 21326>,
    <21336, 21326, 21333>,
    <21336, 21333, 21335>,
    <21336, 21335, 21337>,
    <21336, 21337, 21338>,
    <21336, 21338, 21339>,
    <21336, 21340, 21341>,
    <21336, 21341, 21327>,
    <21342, 21343, 21344>,
    <21342, 21344, 21345>,
    <21342, 21345, 21277>,
    <21342, 21277, 21276>,
    <21342, 21276, 21346>,
    <21342, 21346, 21347>,
    <21342, 21348, 21349>,
    <21342, 21349, 21343>,
    <21350, 21351, 21344>,
    <21350, 21344, 21343>,
    <21350, 21343, 21352>,
    <21350, 21352, 21353>,
    <21350, 21354, 21355>,
    <21350, 21355, 21356>,
    <21350, 21356, 21357>,
    <21350, 21357, 21351>,
    <21358, 21345, 21344>,
    <21358, 21344, 21351>,
    <21358, 21351, 21357>,
    <21358, 21357, 21359>,
    <21358, 21359, 21215>,
    <21358, 21215, 21279>,
    <21358, 21279, 21277>,
    <21358, 21277, 21345>,
    <21360, 21361, 21362>,
    <21360, 21362, 21363>,
    <21360, 21363, 21364>,
    <21360, 21364, 21365>,
    <21360, 21365, 21187>,
    <21360, 21187, 21204>,
    <21360, 21204, 21203>,
    <21360, 21203, 21361>,
    <21366, 21367, 21362>,
    <21366, 21362, 21361>,
    <21366, 21361, 21203>,
    <21366, 21203, 21208>,
    <21366, 21208, 21152>,
    <21366, 21152, 21368>,
    <21366, 21368, 21369>,
    <21366, 21369, 21367>,
    <21370, 21363, 21362>,
    <21370, 21362, 21367>,
    <21370, 21367, 21369>,
    <21370, 21369, 21371>,
    <21370, 21371, 21372>,
    <21370, 21372, 21373>,
    <21370, 21373, 21364>,
    <21370, 21364, 21363>,
    <21374, 21375, 21376>,
    <21374, 21376, 21377>,
    <21374, 21377, 21378>,
    <21374, 21378, 21379>,
    <21374, 21379, 21372>,
    <21374, 21372, 21371>,
    <21374, 21371, 21369>,
    <21374, 21369, 21375>,
    <21380, 21381, 21376>,
    <21380, 21376, 21375>,
    <21380, 21375, 21369>,
    <21380, 21369, 21368>,
    <21380, 21368, 21152>,
    <21380, 21152, 21169>,
    <21380, 21169, 21168>,
    <21380, 21168, 21381>,
    <21382, 21377, 21376>,
    <21382, 21376, 21381>,
    <21382, 21381, 21168>,
    <21382, 21168, 21173>,
    <21382, 21173, 20932>,
    <21382, 20932, 21383>,
    <21382, 21383, 21378>,
    <21382, 21378, 21377>,
    <21384, 21385, 21386>,
    <21384, 21386, 21387>,
    <21384, 21387, 21388>,
    <21384, 21388, 21389>,
    <21384, 21389, 21372>,
    <21384, 21372, 21379>,
    <21384, 21379, 21378>,
    <21384, 21378, 21385>,
    <21390, 21391, 21386>,
    <21390, 21386, 21385>,
    <21390, 21385, 21378>,
    <21390, 21378, 21383>,
    <21390, 21383, 20932>,
    <21390, 20932, 21220>,
    <21390, 21220, 21217>,
    <21390, 21217, 21391>,
    <21392, 21387, 21386>,
    <21392, 21386, 21391>,
    <21392, 21391, 21217>,
    <21392, 21217, 21216>,
    <21392, 21216, 21215>,
    <21392, 21215, 21393>,
    <21392, 21393, 21388>,
    <21392, 21388, 21387>,
    <21394, 21395, 21396>,
    <21394, 21396, 21397>,
    <21394, 21397, 21398>,
    <21394, 21398, 21399>,
    <21394, 21399, 21400>,
    <21394, 21400, 21401>,
    <21394, 21402, 21403>,
    <21394, 21403, 21395>,
    <21404, 21405, 21396>,
    <21404, 21396, 21395>,
    <21404, 21395, 21406>,
    <21404, 21406, 21407>,
    <21404, 21408, 21409>,
    <21404, 21409, 21337>,
    <21404, 21337, 21335>,
    <21404, 21335, 21405>,
    <21410, 21397, 21396>,
    <21410, 21396, 21405>,
    <21410, 21405, 21335>,
    <21410, 21335, 21334>,
    <21410, 21334, 21187>,
    <21410, 21187, 21411>,
    <21410, 21411, 21398>,
    <21410, 21398, 21397>,
    <21412, 21413, 21414>,
    <21412, 21414, 21415>,
    <21412, 21415, 21416>,
    <21412, 21416, 21417>,
    <21412, 21417, 21418>,
    <21412, 21418, 21399>,
    <21412, 21399, 21398>,
    <21412, 21398, 21413>,
    <21419, 21420, 21414>,
    <21419, 21414, 21413>,
    <21419, 21413, 21398>,
    <21419, 21398, 21411>,
    <21419, 21411, 21187>,
    <21419, 21187, 21365>,
    <21419, 21365, 21364>,
    <21419, 21364, 21420>,
    <21421, 21415, 21414>,
    <21421, 21414, 21420>,
    <21421, 21420, 21364>,
    <21421, 21364, 21373>,
    <21421, 21373, 21372>,
    <21421, 21372, 21422>,
    <21421, 21422, 21416>,
    <21421, 21416, 21415>,
    <21423, 21424, 21425>,
    <21423, 21425, 21426>,
    <21423, 21426, 21427>,
    <21423, 21427, 21428>,
    <21423, 21428, 21429>,
    <21423, 21429, 21430>,
    <21423, 21430, 21431>,
    <21423, 21431, 21424>,
    <21432, 21433, 21425>,
    <21432, 21425, 21424>,
    <21432, 21424, 21431>,
    <21432, 21431, 21434>,
    <21432, 21434, 21372>,
    <21432, 21372, 21389>,
    <21432, 21389, 21388>,
    <21432, 21388, 21433>,
    <21435, 21426, 21425>,
    <21435, 21425, 21433>,
    <21435, 21433, 21388>,
    <21435, 21388, 21393>,
    <21435, 21393, 21215>,
    <21435, 21215, 21436>,
    <21435, 21436, 21427>,
    <21435, 21427, 21426>,
    <21437, 21438, 21439>,
    <21437, 21439, 21440>,
    <21437, 21440, 21441>,
    <21437, 21441, 21442>,
    <21437, 21443, 21444>,
    <21437, 21444, 21428>,
    <21437, 21428, 21427>,
    <21437, 21427, 21438>,
    <21445, 21446, 21439>,
    <21445, 21439, 21438>,
    <21445, 21438, 21427>,
    <21445, 21427, 21436>,
    <21445, 21436, 21215>,
    <21445, 21215, 21359>,
    <21445, 21359, 21357>,
    <21445, 21357, 21446>,
    <21447, 21440, 21439>,
    <21447, 21439, 21446>,
    <21447, 21446, 21357>,
    <21447, 21357, 21356>,
    <21447, 21356, 21448>,
    <21447, 21448, 21449>,
    <21447, 21450, 21451>,
    <21447, 21451, 21440>,
    <21452, 21453, 21454>,
    <21452, 21454, 21455>,
    <21452, 21455, 21456>,
    <21452, 21456, 21457>,
    <21452, 21457, 21458>,
    <21452, 21458, 21459>,
    <21452, 21460, 21461>,
    <21452, 21461, 21453>,
    <21462, 21463, 21454>,
    <21462, 21454, 21453>,
    <21462, 21453, 21464>,
    <21462, 21464, 21465>,
    <21462, 21466, 21467>,
    <21462, 21467, 21417>,
    <21462, 21417, 21416>,
    <21462, 21416, 21463>,
    <21468, 21455, 21454>,
    <21468, 21454, 21463>,
    <21468, 21463, 21416>,
    <21468, 21416, 21422>,
    <21468, 21422, 21372>,
    <21468, 21372, 21469>,
    <21468, 21469, 21456>,
    <21468, 21456, 21455>,
    <21470, 21471, 21472>,
    <21470, 21472, 21473>,
    <21470, 21473, 21431>,
    <21470, 21431, 21430>,
    <21470, 21430, 21474>,
    <21470, 21474, 21475>,
    <21470, 21476, 21477>,
    <21470, 21477, 21471>,
    <21478, 21479, 21472>,
    <21478, 21472, 21471>,
    <21478, 21471, 21480>,
    <21478, 21480, 21481>,
    <21478, 21482, 21483>,
    <21478, 21483, 21484>,
    <21478, 21484, 21485>,
    <21478, 21485, 21479>,
    <21486, 21473, 21472>,
    <21486, 21472, 21479>,
    <21486, 21479, 21485>,
    <21486, 21485, 21487>,
    <21486, 21487, 21372>,
    <21486, 21372, 21434>,
    <21486, 21434, 21431>,
    <21486, 21431, 21473>,
    <21488, 21489, 21490>,
    <21488, 21490, 21491>,
    <21488, 21491, 21492>,
    <21488, 21492, 21493>,
    <21488, 21494, 21495>,
    <21488, 21495, 21457>,
    <21488, 21457, 21456>,
    <21488, 21456, 21489>,
    <21496, 21497, 21490>,
    <21496, 21490, 21489>,
    <21496, 21489, 21456>,
    <21496, 21456, 21469>,
    <21496, 21469, 21372>,
    <21496, 21372, 21487>,
    <21496, 21487, 21485>,
    <21496, 21485, 21497>,
    <21498, 21491, 21490>,
    <21498, 21490, 21497>,
    <21498, 21497, 21485>,
    <21498, 21485, 21484>,
    <21498, 21484, 21499>,
    <21498, 21499, 21500>,
    <21498, 21501, 21502>,
    <21498, 21502, 21491>
  }
  uv_indices {
    35712,   // from 0 triangles and 17856 quads
    <12113, 12121, 12114>,
    <12113, 12114, 12118>    <12113, 12118, 12115>,
    <12113, 12115, 12119>    <12113, 12119, 12116>,
    <12113, 12116, 12120>    <12113, 12120, 12117>,
    <12113, 12117, 12121>    <12122, 12130, 12123>,
    <12122, 12123, 12127>    <12122, 12127, 12124>,
    <12122, 12124, 12128>    <12122, 12128, 12125>,
    <12122, 12125, 12129>    <12122, 12129, 12126>,
    <12122, 12126, 12130>    <12131, 12139, 12132>,
    <12131, 12132, 12136>    <12131, 12136, 12133>,
    <12131, 12133, 12137>    <12131, 12137, 12134>,
    <12131, 12134, 12138>    <12131, 12138, 12135>,
    <12131, 12135, 12139>    <12140, 12148, 12141>,
    <12140, 12141, 12145>    <12140, 12145, 12142>,
    <12140, 12142, 12146>    <12140, 12146, 12143>,
    <12140, 12143, 12147>    <12140, 12147, 12144>,
    <12140, 12144, 12148>    <12149, 12157, 12150>,
    <12149, 12150, 12154>    <12149, 12154, 12151>,
    <12149, 12151, 12155>    <12149, 12155, 12152>,
    <12149, 12152, 12156>    <12149, 12156, 12153>,
    <12149, 12153, 12157>    <12158, 12166, 12159>,
    <12158, 12159, 12163>    <12158, 12163, 12160>,
    <12158, 12160, 12164>    <12158, 12164, 12161>,
    <12158, 12161, 12165>    <12158, 12165, 12162>,
    <12158, 12162, 12166>    <12167, 12175, 12168>,
    <12167, 12168, 12172>    <12167, 12172, 12169>,
    <12167, 12169, 12173>    <12167, 12173, 12170>,
    <12167, 12170, 12174>    <12167, 12174, 12171>,
    <12167, 12171, 12175>    <12176, 12184, 12177>,
    <12176, 12177, 12181>    <12176, 12181, 12178>,
    <12176, 12178, 12182>    <12176, 12182, 12179>,
    <12176, 12179, 12183>    <12176, 12183, 12180>,
    <12176, 12180, 12184>    <12185, 12193, 12186>,
    <12185, 12186, 12190>    <12185, 12190, 12187>,
    <12185, 12187, 12191>    <12185, 12191, 12188>,
    <12185, 12188, 12192>    <12185, 12192, 12189>,
    <12185, 12189, 12193>    <12194, 12202, 12195>,
    <12194, 12195, 12199>    <12194, 12199, 12196>,
    <12194, 12196, 12200>    <12194, 12200, 12197>,
    <12194, 12197, 12201>    <12194, 12201, 12198>,
    <12194, 12198, 12202>    <12203, 12211, 12204>,
    <12203, 12204, 12208>    <12203, 12208, 12205>,
    <12203, 12205, 12209>    <12203, 12209, 12206>,
    <12203, 12206, 12210>    <12203, 12210, 12207>,
    <12203, 12207, 12211>    <12212, 12220, 12213>,
    <12212, 12213, 12217>    <12212, 12217, 12214>,
    <12212, 12214, 12218>    <12212, 12218, 12215>,
    <12212, 12215, 12219>    <12212, 12219, 12216>,
    <12212, 12216, 12220>    <12221, 12229, 12222>,
    <12221, 12222, 12226>    <12221, 12226, 12223>,
    <12221, 12223, 12227>    <12221, 12227, 12224>,
    <12221, 12224, 12228>    <12221, 12228, 12225>,
    <12221, 12225, 12229>    <12230, 12238, 12231>,
    <12230, 12231, 12235>    <12230, 12235, 12232>,
    <12230, 12232, 12236>    <12230, 12236, 12233>,
    <12230, 12233, 12237>    <12230, 12237, 12234>,
    <12230, 12234, 12238>    <12239, 12247, 12240>,
    <12239, 12240, 12244>    <12239, 12244, 12241>,
    <12239, 12241, 12245>    <12239, 12245, 12242>,
    <12239, 12242, 12246>    <12239, 12246, 12243>,
    <12239, 12243, 12247>    <12248, 12256, 12249>,
    <12248, 12249, 12253>    <12248, 12253, 12250>,
    <12248, 12250, 12254>    <12248, 12254, 12251>,
    <12248, 12251, 12255>    <12248, 12255, 12252>,
    <12248, 12252, 12256>    <12257, 12265, 12258>,
    <12257, 12258, 12262>    <12257, 12262, 12259>,
    <12257, 12259, 12263>    <12257, 12263, 12260>,
    <12257, 12260, 12264>    <12257, 12264, 12261>,
    <12257, 12261, 12265>    <12266, 12274, 12267>,
    <12266, 12267, 12271>    <12266, 12271, 12268>,
    <12266, 12268, 12272>    <12266, 12272, 12269>,
    <12266, 12269, 12273>    <12266, 12273, 12270>,
    <12266, 12270, 12274>    <12275, 12283, 12276>,
    <12275, 12276, 12280>    <12275, 12280, 12277>,
    <12275, 12277, 12281>    <12275, 12281, 12278>,
    <12275, 12278, 12282>    <12275, 12282, 12279>,
    <12275, 12279, 12283>    <12284, 12292, 12285>,
    <12284, 12285, 12289>    <12284, 12289, 12286>,
    <12284, 12286, 12290>    <12284, 12290, 12287>,
    <12284, 12287, 12291>    <12284, 12291, 12288>,
    <12284, 12288, 12292>    <12293, 12301, 12294>,
    <12293, 12294, 12298>    <12293, 12298, 12295>,
    <12293, 12295, 12299>    <12293, 12299, 12296>,
    <12293, 12296, 12300>    <12293, 12300, 12297>,
    <12293, 12297, 12301>    <12302, 12310, 12303>,
    <12302, 12303, 12307>    <12302, 12307, 12304>,
    <12302, 12304, 12308>    <12302, 12308, 12305>,
    <12302, 12305, 12309>    <12302, 12309, 12306>,
    <12302, 12306, 12310>    <12311, 12319, 12312>,
    <12311, 12312, 12316>    <12311, 12316, 12313>,
    <12311, 12313, 12317>    <12311, 12317, 12314>,
    <12311, 12314, 12318>    <12311, 12318, 12315>,
    <12311, 12315, 12319>    <12320, 12328, 12321>,
    <12320, 12321, 12325>    <12320, 12325, 12322>,
    <12320, 12322, 12326>    <12320, 12326, 12323>,
    <12320, 12323, 12327>    <12320, 12327, 12324>,
    <12320, 12324, 12328>    <12329, 12337, 12330>,
    <12329, 12330, 12334>    <12329, 12334, 12331>,
    <12329, 12331, 12335>    <12329, 12335, 12332>,
    <12329, 12332, 12336>    <12329, 12336, 12333>,
    <12329, 12333, 12337>    <12338, 12346, 12339>,
    <12338, 12339, 12343>    <12338, 12343, 12340>,
    <12338, 12340, 12344>    <12338, 12344, 12341>,
    <12338, 12341, 12345>    <12338, 12345, 12342>,
    <12338, 12342, 12346>    <12347, 12355, 12348>,
    <12347, 12348, 12352>    <12347, 12352, 12349>,
    <12347, 12349, 12353>    <12347, 12353, 12350>,
    <12347, 12350, 12354>    <12347, 12354, 12351>,
    <12347, 12351, 12355>    <12356, 12364, 12357>,
    <12356, 12357, 12361>    <12356, 12361, 12358>,
    <12356, 12358, 12362>    <12356, 12362, 12359>,
    <12356, 12359, 12363>    <12356, 12363, 12360>,
    <12356, 12360, 12364>    <12365, 12373, 12366>,
    <12365, 12366, 12370>    <12365, 12370, 12367>,
    <12365, 12367, 12371>    <12365, 12371, 12368>,
    <12365, 12368, 12372>    <12365, 12372, 12369>,
    <12365, 12369, 12373>    <12374, 12382, 12375>,
    <12374, 12375, 12379>    <12374, 12379, 12376>,
    <12374, 12376, 12380>    <12374, 12380, 12377>,
    <12374, 12377, 12381>    <12374, 12381, 12378>,
    <12374, 12378, 12382>    <12383, 12391, 12384>,
    <12383, 12384, 12388>    <12383, 12388, 12385>,
    <12383, 12385, 12389>    <12383, 12389, 12386>,
    <12383, 12386, 12390>    <12383, 12390, 12387>,
    <12383, 12387, 12391>    <12392, 12400, 12393>,
    <12392, 12393, 12397>    <12392, 12397, 12394>,
    <12392, 12394, 12398>    <12392, 12398, 12395>,
    <12392, 12395, 12399>    <12392, 12399, 12396>,
    <12392, 12396, 12400>    <12401, 12409, 12402>,
    <12401, 12402, 12406>    <12401, 12406, 12403>,
    <12401, 12403, 12407>    <12401, 12407, 12404>,
    <12401, 12404, 12408>    <12401, 12408, 12405>,
    <12401, 12405, 12409>    <12410, 12418, 12411>,
    <12410, 12411, 12415>    <12410, 12415, 12412>,
    <12410, 12412, 12416>    <12410, 12416, 12413>,
    <12410, 12413, 12417>    <12410, 12417, 12414>,
    <12410, 12414, 12418>    <12419, 12427, 12420>,
    <12419, 12420, 12424>    <12419, 12424, 12421>,
    <12419, 12421, 12425>    <12419, 12425, 12422>,
    <12419, 12422, 12426>    <12419, 12426, 12423>,
    <12419, 12423, 12427>    <12428, 12436, 12429>,
    <12428, 12429, 12433>    <12428, 12433, 12430>,
    <12428, 12430, 12434>    <12428, 12434, 12431>,
    <12428, 12431, 12435>    <12428, 12435, 12432>,
    <12428, 12432, 12436>    <12437, 12445, 12438>,
    <12437, 12438, 12442>    <12437, 12442, 12439>,
    <12437, 12439, 12443>    <12437, 12443, 12440>,
    <12437, 12440, 12444>    <12437, 12444, 12441>,
    <12437, 12441, 12445>    <12446, 12454, 12447>,
    <12446, 12447, 12451>    <12446, 12451, 12448>,
    <12446, 12448, 12452>    <12446, 12452, 12449>,
    <12446, 12449, 12453>    <12446, 12453, 12450>,
    <12446, 12450, 12454>    <12455, 12463, 12456>,
    <12455, 12456, 12460>    <12455, 12460, 12457>,
    <12455, 12457, 12461>    <12455, 12461, 12458>,
    <12455, 12458, 12462>    <12455, 12462, 12459>,
    <12455, 12459, 12463>    <12464, 12472, 12465>,
    <12464, 12465, 12469>    <12464, 12469, 12466>,
    <12464, 12466, 12470>    <12464, 12470, 12467>,
    <12464, 12467, 12471>    <12464, 12471, 12468>,
    <12464, 12468, 12472>    <12473, 12481, 12474>,
    <12473, 12474, 12478>    <12473, 12478, 12475>,
    <12473, 12475, 12479>    <12473, 12479, 12476>,
    <12473, 12476, 12480>    <12473, 12480, 12477>,
    <12473, 12477, 12481>    <12482, 12490, 12483>,
    <12482, 12483, 12487>    <12482, 12487, 12484>,
    <12482, 12484, 12488>    <12482, 12488, 12485>,
    <12482, 12485, 12489>    <12482, 12489, 12486>,
    <12482, 12486, 12490>    <12491, 12499, 12492>,
    <12491, 12492, 12496>    <12491, 12496, 12493>,
    <12491, 12493, 12497>    <12491, 12497, 12494>,
    <12491, 12494, 12498>    <12491, 12498, 12495>,
    <12491, 12495, 12499>    <12500, 12508, 12501>,
    <12500, 12501, 12505>    <12500, 12505, 12502>,
    <12500, 12502, 12506>    <12500, 12506, 12503>,
    <12500, 12503, 12507>    <12500, 12507, 12504>,
    <12500, 12504, 12508>    <12509, 12517, 12510>,
    <12509, 12510, 12514>    <12509, 12514, 12511>,
    <12509, 12511, 12515>    <12509, 12515, 12512>,
    <12509, 12512, 12516>    <12509, 12516, 12513>,
    <12509, 12513, 12517>    <12518, 12526, 12519>,
    <12518, 12519, 12523>    <12518, 12523, 12520>,
    <12518, 12520, 12524>    <12518, 12524, 12521>,
    <12518, 12521, 12525>    <12518, 12525, 12522>,
    <12518, 12522, 12526>    <12527, 12535, 12528>,
    <12527, 12528, 12532>    <12527, 12532, 12529>,
    <12527, 12529, 12533>    <12527, 12533, 12530>,
    <12527, 12530, 12534>    <12527, 12534, 12531>,
    <12527, 12531, 12535>    <12536, 12544, 12537>,
    <12536, 12537, 12541>    <12536, 12541, 12538>,
    <12536, 12538, 12542>    <12536, 12542, 12539>,
    <12536, 12539, 12543>    <12536, 12543, 12540>,
    <12536, 12540, 12544>    <12545, 12553, 12546>,
    <12545, 12546, 12550>    <12545, 12550, 12547>,
    <12545, 12547, 12551>    <12545, 12551, 12548>,
    <12545, 12548, 12552>    <12545, 12552, 12549>,
    <12545, 12549, 12553>    <12554, 12562, 12555>,
    <12554, 12555, 12559>    <12554, 12559, 12556>,
    <12554, 12556, 12560>    <12554, 12560, 12557>,
    <12554, 12557, 12561>    <12554, 12561, 12558>,
    <12554, 12558, 12562>    <12563, 12571, 12564>,
    <12563, 12564, 12568>    <12563, 12568, 12565>,
    <12563, 12565, 12569>    <12563, 12569, 12566>,
    <12563, 12566, 12570>    <12563, 12570, 12567>,
    <12563, 12567, 12571>    <12572, 12580, 12573>,
    <12572, 12573, 12577>    <12572, 12577, 12574>,
    <12572, 12574, 12578>    <12572, 12578, 12575>,
    <12572, 12575, 12579>    <12572, 12579, 12576>,
    <12572, 12576, 12580>    <12581, 12589, 12582>,
    <12581, 12582, 12586>    <12581, 12586, 12583>,
    <12581, 12583, 12587>    <12581, 12587, 12584>,
    <12581, 12584, 12588>    <12581, 12588, 12585>,
    <12581, 12585, 12589>    <12590, 12598, 12591>,
    <12590, 12591, 12595>    <12590, 12595, 12592>,
    <12590, 12592, 12596>    <12590, 12596, 12593>,
    <12590, 12593, 12597>    <12590, 12597, 12594>,
    <12590, 12594, 12598>    <12599, 12607, 12600>,
    <12599, 12600, 12604>    <12599, 12604, 12601>,
    <12599, 12601, 12605>    <12599, 12605, 12602>,
    <12599, 12602, 12606>    <12599, 12606, 12603>,
    <12599, 12603, 12607>    <12608, 12616, 12609>,
    <12608, 12609, 12613>    <12608, 12613, 12610>,
    <12608, 12610, 12614>    <12608, 12614, 12611>,
    <12608, 12611, 12615>    <12608, 12615, 12612>,
    <12608, 12612, 12616>    <12617, 12625, 12618>,
    <12617, 12618, 12622>    <12617, 12622, 12619>,
    <12617, 12619, 12623>    <12617, 12623, 12620>,
    <12617, 12620, 12624>    <12617, 12624, 12621>,
    <12617, 12621, 12625>    <12626, 12634, 12627>,
    <12626, 12627, 12631>    <12626, 12631, 12628>,
    <12626, 12628, 12632>    <12626, 12632, 12629>,
    <12626, 12629, 12633>    <12626, 12633, 12630>,
    <12626, 12630, 12634>    <12635, 12643, 12636>,
    <12635, 12636, 12640>    <12635, 12640, 12637>,
    <12635, 12637, 12641>    <12635, 12641, 12638>,
    <12635, 12638, 12642>    <12635, 12642, 12639>,
    <12635, 12639, 12643>    <12644, 12652, 12645>,
    <12644, 12645, 12649>    <12644, 12649, 12646>,
    <12644, 12646, 12650>    <12644, 12650, 12647>,
    <12644, 12647, 12651>    <12644, 12651, 12648>,
    <12644, 12648, 12652>    <12653, 12661, 12654>,
    <12653, 12654, 12658>    <12653, 12658, 12655>,
    <12653, 12655, 12659>    <12653, 12659, 12656>,
    <12653, 12656, 12660>    <12653, 12660, 12657>,
    <12653, 12657, 12661>    <12662, 12670, 12663>,
    <12662, 12663, 12667>    <12662, 12667, 12664>,
    <12662, 12664, 12668>    <12662, 12668, 12665>,
    <12662, 12665, 12669>    <12662, 12669, 12666>,
    <12662, 12666, 12670>    <12671, 12679, 12672>,
    <12671, 12672, 12676>    <12671, 12676, 12673>,
    <12671, 12673, 12677>    <12671, 12677, 12674>,
    <12671, 12674, 12678>    <12671, 12678, 12675>,
    <12671, 12675, 12679>    <12680, 12688, 12681>,
    <12680, 12681, 12685>    <12680, 12685, 12682>,
    <12680, 12682, 12686>    <12680, 12686, 12683>,
    <12680, 12683, 12687>    <12680, 12687, 12684>,
    <12680, 12684, 12688>    <12689, 12697, 12690>,
    <12689, 12690, 12694>    <12689, 12694, 12691>,
    <12689, 12691, 12695>    <12689, 12695, 12692>,
    <12689, 12692, 12696>    <12689, 12696, 12693>,
    <12689, 12693, 12697>    <12698, 12706, 12699>,
    <12698, 12699, 12703>    <12698, 12703, 12700>,
    <12698, 12700, 12704>    <12698, 12704, 12701>,
    <12698, 12701, 12705>    <12698, 12705, 12702>,
    <12698, 12702, 12706>    <12707, 12715, 12708>,
    <12707, 12708, 12712>    <12707, 12712, 12709>,
    <12707, 12709, 12713>    <12707, 12713, 12710>,
    <12707, 12710, 12714>    <12707, 12714, 12711>,
    <12707, 12711, 12715>    <12716, 12724, 12717>,
    <12716, 12717, 12721>    <12716, 12721, 12718>,
    <12716, 12718, 12722>    <12716, 12722, 12719>,
    <12716, 12719, 12723>    <12716, 12723, 12720>,
    <12716, 12720, 12724>    <12725, 12733, 12726>,
    <12725, 12726, 12730>    <12725, 12730, 12727>,
    <12725, 12727, 12731>    <12725, 12731, 12728>,
    <12725, 12728, 12732>    <12725, 12732, 12729>,
    <12725, 12729, 12733>    <12734, 12742, 12735>,
    <12734, 12735, 12739>    <12734, 12739, 12736>,
    <12734, 12736, 12740>    <12734, 12740, 12737>,
    <12734, 12737, 12741>    <12734, 12741, 12738>,
    <12734, 12738, 12742>    <12743, 12751, 12744>,
    <12743, 12744, 12748>    <12743, 12748, 12745>,
    <12743, 12745, 12749>    <12743, 12749, 12746>,
    <12743, 12746, 12750>    <12743, 12750, 12747>,
    <12743, 12747, 12751>    <12752, 12760, 12753>,
    <12752, 12753, 12757>    <12752, 12757, 12754>,
    <12752, 12754, 12758>    <12752, 12758, 12755>,
    <12752, 12755, 12759>    <12752, 12759, 12756>,
    <12752, 12756, 12760>    <12761, 12769, 12762>,
    <12761, 12762, 12766>    <12761, 12766, 12763>,
    <12761, 12763, 12767>    <12761, 12767, 12764>,
    <12761, 12764, 12768>    <12761, 12768, 12765>,
    <12761, 12765, 12769>    <12770, 12778, 12771>,
    <12770, 12771, 12775>    <12770, 12775, 12772>,
    <12770, 12772, 12776>    <12770, 12776, 12773>,
    <12770, 12773, 12777>    <12770, 12777, 12774>,
    <12770, 12774, 12778>    <12779, 12787, 12780>,
    <12779, 12780, 12784>    <12779, 12784, 12781>,
    <12779, 12781, 12785>    <12779, 12785, 12782>,
    <12779, 12782, 12786>    <12779, 12786, 12783>,
    <12779, 12783, 12787>    <12788, 12796, 12789>,
    <12788, 12789, 12793>    <12788, 12793, 12790>,
    <12788, 12790, 12794>    <12788, 12794, 12791>,
    <12788, 12791, 12795>    <12788, 12795, 12792>,
    <12788, 12792, 12796>    <12797, 12805, 12798>,
    <12797, 12798, 12802>    <12797, 12802, 12799>,
    <12797, 12799, 12803>    <12797, 12803, 12800>,
    <12797, 12800, 12804>    <12797, 12804, 12801>,
    <12797, 12801, 12805>    <12806, 12814, 12807>,
    <12806, 12807, 12811>    <12806, 12811, 12808>,
    <12806, 12808, 12812>    <12806, 12812, 12809>,
    <12806, 12809, 12813>    <12806, 12813, 12810>,
    <12806, 12810, 12814>    <12815, 12823, 12816>,
    <12815, 12816, 12820>    <12815, 12820, 12817>,
    <12815, 12817, 12821>    <12815, 12821, 12818>,
    <12815, 12818, 12822>    <12815, 12822, 12819>,
    <12815, 12819, 12823>    <12824, 12832, 12825>,
    <12824, 12825, 12829>    <12824, 12829, 12826>,
    <12824, 12826, 12830>    <12824, 12830, 12827>,
    <12824, 12827, 12831>    <12824, 12831, 12828>,
    <12824, 12828, 12832>    <12833, 12841, 12834>,
    <12833, 12834, 12838>    <12833, 12838, 12835>,
    <12833, 12835, 12839>    <12833, 12839, 12836>,
    <12833, 12836, 12840>    <12833, 12840, 12837>,
    <12833, 12837, 12841>    <12842, 12850, 12843>,
    <12842, 12843, 12847>    <12842, 12847, 12844>,
    <12842, 12844, 12848>    <12842, 12848, 12845>,
    <12842, 12845, 12849>    <12842, 12849, 12846>,
    <12842, 12846, 12850>    <12851, 12859, 12852>,
    <12851, 12852, 12856>    <12851, 12856, 12853>,
    <12851, 12853, 12857>    <12851, 12857, 12854>,
    <12851, 12854, 12858>    <12851, 12858, 12855>,
    <12851, 12855, 12859>    <12860, 12868, 12861>,
    <12860, 12861, 12865>    <12860, 12865, 12862>,
    <12860, 12862, 12866>    <12860, 12866, 12863>,
    <12860, 12863, 12867>    <12860, 12867, 12864>,
    <12860, 12864, 12868>    <12869, 12877, 12870>,
    <12869, 12870, 12874>    <12869, 12874, 12871>,
    <12869, 12871, 12875>    <12869, 12875, 12872>,
    <12869, 12872, 12876>    <12869, 12876, 12873>,
    <12869, 12873, 12877>    <12878, 12886, 12879>,
    <12878, 12879, 12883>    <12878, 12883, 12880>,
    <12878, 12880, 12884>    <12878, 12884, 12881>,
    <12878, 12881, 12885>    <12878, 12885, 12882>,
    <12878, 12882, 12886>    <12887, 12895, 12888>,
    <12887, 12888, 12892>    <12887, 12892, 12889>,
    <12887, 12889, 12893>    <12887, 12893, 12890>,
    <12887, 12890, 12894>    <12887, 12894, 12891>,
    <12887, 12891, 12895>    <12896, 12904, 12897>,
    <12896, 12897, 12901>    <12896, 12901, 12898>,
    <12896, 12898, 12902>    <12896, 12902, 12899>,
    <12896, 12899, 12903>    <12896, 12903, 12900>,
    <12896, 12900, 12904>    <12905, 12913, 12906>,
    <12905, 12906, 12910>    <12905, 12910, 12907>,
    <12905, 12907, 12911>    <12905, 12911, 12908>,
    <12905, 12908, 12912>    <12905, 12912, 12909>,
    <12905, 12909, 12913>    <12914, 12922, 12915>,
    <12914, 12915, 12919>    <12914, 12919, 12916>,
    <12914, 12916, 12920>    <12914, 12920, 12917>,
    <12914, 12917, 12921>    <12914, 12921, 12918>,
    <12914, 12918, 12922>    <12923, 12931, 12924>,
    <12923, 12924, 12928>    <12923, 12928, 12925>,
    <12923, 12925, 12929>    <12923, 12929, 12926>,
    <12923, 12926, 12930>    <12923, 12930, 12927>,
    <12923, 12927, 12931>    <12932, 12940, 12933>,
    <12932, 12933, 12937>    <12932, 12937, 12934>,
    <12932, 12934, 12938>    <12932, 12938, 12935>,
    <12932, 12935, 12939>    <12932, 12939, 12936>,
    <12932, 12936, 12940>    <12941, 12949, 12942>,
    <12941, 12942, 12946>    <12941, 12946, 12943>,
    <12941, 12943, 12947>    <12941, 12947, 12944>,
    <12941, 12944, 12948>    <12941, 12948, 12945>,
    <12941, 12945, 12949>    <12950, 12958, 12951>,
    <12950, 12951, 12955>    <12950, 12955, 12952>,
    <12950, 12952, 12956>    <12950, 12956, 12953>,
    <12950, 12953, 12957>    <12950, 12957, 12954>,
    <12950, 12954, 12958>    <12959, 12967, 12960>,
    <12959, 12960, 12964>    <12959, 12964, 12961>,
    <12959, 12961, 12965>    <12959, 12965, 12962>,
    <12959, 12962, 12966>    <12959, 12966, 12963>,
    <12959, 12963, 12967>    <12968, 12976, 12969>,
    <12968, 12969, 12973>    <12968, 12973, 12970>,
    <12968, 12970, 12974>    <12968, 12974, 12971>,
    <12968, 12971, 12975>    <12968, 12975, 12972>,
    <12968, 12972, 12976>    <12977, 12985, 12978>,
    <12977, 12978, 12982>    <12977, 12982, 12979>,
    <12977, 12979, 12983>    <12977, 12983, 12980>,
    <12977, 12980, 12984>    <12977, 12984, 12981>,
    <12977, 12981, 12985>    <12986, 12994, 12987>,
    <12986, 12987, 12991>    <12986, 12991, 12988>,
    <12986, 12988, 12992>    <12986, 12992, 12989>,
    <12986, 12989, 12993>    <12986, 12993, 12990>,
    <12986, 12990, 12994>    <12995, 13003, 12996>,
    <12995, 12996, 13000>    <12995, 13000, 12997>,
    <12995, 12997, 13001>    <12995, 13001, 12998>,
    <12995, 12998, 13002>    <12995, 13002, 12999>,
    <12995, 12999, 13003>    <13004, 13012, 13005>,
    <13004, 13005, 13009>    <13004, 13009, 13006>,
    <13004, 13006, 13010>    <13004, 13010, 13007>,
    <13004, 13007, 13011>    <13004, 13011, 13008>,
    <13004, 13008, 13012>    <13013, 13021, 13014>,
    <13013, 13014, 13018>    <13013, 13018, 13015>,
    <13013, 13015, 13019>    <13013, 13019, 13016>,
    <13013, 13016, 13020>    <13013, 13020, 13017>,
    <13013, 13017, 13021>    <13022, 13030, 13023>,
    <13022, 13023, 13027>    <13022, 13027, 13024>,
    <13022, 13024, 13028>    <13022, 13028, 13025>,
    <13022, 13025, 13029>    <13022, 13029, 13026>,
    <13022, 13026, 13030>    <13031, 13039, 13032>,
    <13031, 13032, 13036>    <13031, 13036, 13033>,
    <13031, 13033, 13037>    <13031, 13037, 13034>,
    <13031, 13034, 13038>    <13031, 13038, 13035>,
    <13031, 13035, 13039>    <13040, 13048, 13041>,
    <13040, 13041, 13045>    <13040, 13045, 13042>,
    <13040, 13042, 13046>    <13040, 13046, 13043>,
    <13040, 13043, 13047>    <13040, 13047, 13044>,
    <13040, 13044, 13048>    <13049, 13057, 13050>,
    <13049, 13050, 13054>    <13049, 13054, 13051>,
    <13049, 13051, 13055>    <13049, 13055, 13052>,
    <13049, 13052, 13056>    <13049, 13056, 13053>,
    <13049, 13053, 13057>    <13058, 13066, 13059>,
    <13058, 13059, 13063>    <13058, 13063, 13060>,
    <13058, 13060, 13064>    <13058, 13064, 13061>,
    <13058, 13061, 13065>    <13058, 13065, 13062>,
    <13058, 13062, 13066>    <13067, 13075, 13068>,
    <13067, 13068, 13072>    <13067, 13072, 13069>,
    <13067, 13069, 13073>    <13067, 13073, 13070>,
    <13067, 13070, 13074>    <13067, 13074, 13071>,
    <13067, 13071, 13075>    <13076, 13084, 13077>,
    <13076, 13077, 13081>    <13076, 13081, 13078>,
    <13076, 13078, 13082>    <13076, 13082, 13079>,
    <13076, 13079, 13083>    <13076, 13083, 13080>,
    <13076, 13080, 13084>    <13085, 13093, 13086>,
    <13085, 13086, 13090>    <13085, 13090, 13087>,
    <13085, 13087, 13091>    <13085, 13091, 13088>,
    <13085, 13088, 13092>    <13085, 13092, 13089>,
    <13085, 13089, 13093>    <13094, 13102, 13095>,
    <13094, 13095, 13099>    <13094, 13099, 13096>,
    <13094, 13096, 13100>    <13094, 13100, 13097>,
    <13094, 13097, 13101>    <13094, 13101, 13098>,
    <13094, 13098, 13102>    <13103, 13111, 13104>,
    <13103, 13104, 13108>    <13103, 13108, 13105>,
    <13103, 13105, 13109>    <13103, 13109, 13106>,
    <13103, 13106, 13110>    <13103, 13110, 13107>,
    <13103, 13107, 13111>    <13112, 13120, 13113>,
    <13112, 13113, 13117>    <13112, 13117, 13114>,
    <13112, 13114, 13118>    <13112, 13118, 13115>,
    <13112, 13115, 13119>    <13112, 13119, 13116>,
    <13112, 13116, 13120>    <13121, 13129, 13122>,
    <13121, 13122, 13126>    <13121, 13126, 13123>,
    <13121, 13123, 13127>    <13121, 13127, 13124>,
    <13121, 13124, 13128>    <13121, 13128, 13125>,
    <13121, 13125, 13129>    <13130, 13138, 13131>,
    <13130, 13131, 13135>    <13130, 13135, 13132>,
    <13130, 13132, 13136>    <13130, 13136, 13133>,
    <13130, 13133, 13137>    <13130, 13137, 13134>,
    <13130, 13134, 13138>    <13139, 13147, 13140>,
    <13139, 13140, 13144>    <13139, 13144, 13141>,
    <13139, 13141, 13145>    <13139, 13145, 13142>,
    <13139, 13142, 13146>    <13139, 13146, 13143>,
    <13139, 13143, 13147>    <13148, 13156, 13149>,
    <13148, 13149, 13153>    <13148, 13153, 13150>,
    <13148, 13150, 13154>    <13148, 13154, 13151>,
    <13148, 13151, 13155>    <13148, 13155, 13152>,
    <13148, 13152, 13156>    <13157, 13165, 13158>,
    <13157, 13158, 13162>    <13157, 13162, 13159>,
    <13157, 13159, 13163>    <13157, 13163, 13160>,
    <13157, 13160, 13164>    <13157, 13164, 13161>,
    <13157, 13161, 13165>    <13166, 13174, 13167>,
    <13166, 13167, 13171>    <13166, 13171, 13168>,
    <13166, 13168, 13172>    <13166, 13172, 13169>,
    <13166, 13169, 13173>    <13166, 13173, 13170>,
    <13166, 13170, 13174>    <13175, 13183, 13176>,
    <13175, 13176, 13180>    <13175, 13180, 13177>,
    <13175, 13177, 13181>    <13175, 13181, 13178>,
    <13175, 13178, 13182>    <13175, 13182, 13179>,
    <13175, 13179, 13183>    <13184, 13192, 13185>,
    <13184, 13185, 13189>    <13184, 13189, 13186>,
    <13184, 13186, 13190>    <13184, 13190, 13187>,
    <13184, 13187, 13191>    <13184, 13191, 13188>,
    <13184, 13188, 13192>    <13193, 13201, 13194>,
    <13193, 13194, 13198>    <13193, 13198, 13195>,
    <13193, 13195, 13199>    <13193, 13199, 13196>,
    <13193, 13196, 13200>    <13193, 13200, 13197>,
    <13193, 13197, 13201>    <13202, 13210, 13203>,
    <13202, 13203, 13207>    <13202, 13207, 13204>,
    <13202, 13204, 13208>    <13202, 13208, 13205>,
    <13202, 13205, 13209>    <13202, 13209, 13206>,
    <13202, 13206, 13210>    <13211, 13219, 13212>,
    <13211, 13212, 13216>    <13211, 13216, 13213>,
    <13211, 13213, 13217>    <13211, 13217, 13214>,
    <13211, 13214, 13218>    <13211, 13218, 13215>,
    <13211, 13215, 13219>    <13220, 13228, 13221>,
    <13220, 13221, 13225>    <13220, 13225, 13222>,
    <13220, 13222, 13226>    <13220, 13226, 13223>,
    <13220, 13223, 13227>    <13220, 13227, 13224>,
    <13220, 13224, 13228>    <13229, 13237, 13230>,
    <13229, 13230, 13234>    <13229, 13234, 13231>,
    <13229, 13231, 13235>    <13229, 13235, 13232>,
    <13229, 13232, 13236>    <13229, 13236, 13233>,
    <13229, 13233, 13237>    <13238, 13246, 13239>,
    <13238, 13239, 13243>    <13238, 13243, 13240>,
    <13238, 13240, 13244>    <13238, 13244, 13241>,
    <13238, 13241, 13245>    <13238, 13245, 13242>,
    <13238, 13242, 13246>    <13247, 13255, 13248>,
    <13247, 13248, 13252>    <13247, 13252, 13249>,
    <13247, 13249, 13253>    <13247, 13253, 13250>,
    <13247, 13250, 13254>    <13247, 13254, 13251>,
    <13247, 13251, 13255>    <13256, 13264, 13257>,
    <13256, 13257, 13261>    <13256, 13261, 13258>,
    <13256, 13258, 13262>    <13256, 13262, 13259>,
    <13256, 13259, 13263>    <13256, 13263, 13260>,
    <13256, 13260, 13264>    <13265, 13273, 13266>,
    <13265, 13266, 13270>    <13265, 13270, 13267>,
    <13265, 13267, 13271>    <13265, 13271, 13268>,
    <13265, 13268, 13272>    <13265, 13272, 13269>,
    <13265, 13269, 13273>    <13274, 13282, 13275>,
    <13274, 13275, 13279>    <13274, 13279, 13276>,
    <13274, 13276, 13280>    <13274, 13280, 13277>,
    <13274, 13277, 13281>    <13274, 13281, 13278>,
    <13274, 13278, 13282>    <13283, 13291, 13284>,
    <13283, 13284, 13288>    <13283, 13288, 13285>,
    <13283, 13285, 13289>    <13283, 13289, 13286>,
    <13283, 13286, 13290>    <13283, 13290, 13287>,
    <13283, 13287, 13291>    <13292, 13300, 13293>,
    <13292, 13293, 13297>    <13292, 13297, 13294>,
    <13292, 13294, 13298>    <13292, 13298, 13295>,
    <13292, 13295, 13299>    <13292, 13299, 13296>,
    <13292, 13296, 13300>    <13301, 13309, 13302>,
    <13301, 13302, 13306>    <13301, 13306, 13303>,
    <13301, 13303, 13307>    <13301, 13307, 13304>,
    <13301, 13304, 13308>    <13301, 13308, 13305>,
    <13301, 13305, 13309>    <13310, 13318, 13311>,
    <13310, 13311, 13315>    <13310, 13315, 13312>,
    <13310, 13312, 13316>    <13310, 13316, 13313>,
    <13310, 13313, 13317>    <13310, 13317, 13314>,
    <13310, 13314, 13318>    <13319, 13327, 13320>,
    <13319, 13320, 13324>    <13319, 13324, 13321>,
    <13319, 13321, 13325>    <13319, 13325, 13322>,
    <13319, 13322, 13326>    <13319, 13326, 13323>,
    <13319, 13323, 13327>    <13328, 13336, 13329>,
    <13328, 13329, 13333>    <13328, 13333, 13330>,
    <13328, 13330, 13334>    <13328, 13334, 13331>,
    <13328, 13331, 13335>    <13328, 13335, 13332>,
    <13328, 13332, 13336>    <13337, 13345, 13338>,
    <13337, 13338, 13342>    <13337, 13342, 13339>,
    <13337, 13339, 13343>    <13337, 13343, 13340>,
    <13337, 13340, 13344>    <13337, 13344, 13341>,
    <13337, 13341, 13345>    <13346, 13354, 13347>,
    <13346, 13347, 13351>    <13346, 13351, 13348>,
    <13346, 13348, 13352>    <13346, 13352, 13349>,
    <13346, 13349, 13353>    <13346, 13353, 13350>,
    <13346, 13350, 13354>    <13355, 13363, 13356>,
    <13355, 13356, 13360>    <13355, 13360, 13357>,
    <13355, 13357, 13361>    <13355, 13361, 13358>,
    <13355, 13358, 13362>    <13355, 13362, 13359>,
    <13355, 13359, 13363>    <13364, 13372, 13365>,
    <13364, 13365, 13369>    <13364, 13369, 13366>,
    <13364, 13366, 13370>    <13364, 13370, 13367>,
    <13364, 13367, 13371>    <13364, 13371, 13368>,
    <13364, 13368, 13372>    <13373, 13381, 13374>,
    <13373, 13374, 13378>    <13373, 13378, 13375>,
    <13373, 13375, 13379>    <13373, 13379, 13376>,
    <13373, 13376, 13380>    <13373, 13380, 13377>,
    <13373, 13377, 13381>    <13382, 13390, 13383>,
    <13382, 13383, 13387>    <13382, 13387, 13384>,
    <13382, 13384, 13388>    <13382, 13388, 13385>,
    <13382, 13385, 13389>    <13382, 13389, 13386>,
    <13382, 13386, 13390>    <13391, 13399, 13392>,
    <13391, 13392, 13396>    <13391, 13396, 13393>,
    <13391, 13393, 13397>    <13391, 13397, 13394>,
    <13391, 13394, 13398>    <13391, 13398, 13395>,
    <13391, 13395, 13399>    <13400, 13408, 13401>,
    <13400, 13401, 13405>    <13400, 13405, 13402>,
    <13400, 13402, 13406>    <13400, 13406, 13403>,
    <13400, 13403, 13407>    <13400, 13407, 13404>,
    <13400, 13404, 13408>    <13409, 13417, 13410>,
    <13409, 13410, 13414>    <13409, 13414, 13411>,
    <13409, 13411, 13415>    <13409, 13415, 13412>,
    <13409, 13412, 13416>    <13409, 13416, 13413>,
    <13409, 13413, 13417>    <13418, 13426, 13419>,
    <13418, 13419, 13423>    <13418, 13423, 13420>,
    <13418, 13420, 13424>    <13418, 13424, 13421>,
    <13418, 13421, 13425>    <13418, 13425, 13422>,
    <13418, 13422, 13426>    <13427, 13435, 13428>,
    <13427, 13428, 13432>    <13427, 13432, 13429>,
    <13427, 13429, 13433>    <13427, 13433, 13430>,
    <13427, 13430, 13434>    <13427, 13434, 13431>,
    <13427, 13431, 13435>    <13436, 13444, 13437>,
    <13436, 13437, 13441>    <13436, 13441, 13438>,
    <13436, 13438, 13442>    <13436, 13442, 13439>,
    <13436, 13439, 13443>    <13436, 13443, 13440>,
    <13436, 13440, 13444>    <13445, 13453, 13446>,
    <13445, 13446, 13450>    <13445, 13450, 13447>,
    <13445, 13447, 13451>    <13445, 13451, 13448>,
    <13445, 13448, 13452>    <13445, 13452, 13449>,
    <13445, 13449, 13453>    <13454, 13462, 13455>,
    <13454, 13455, 13459>    <13454, 13459, 13456>,
    <13454, 13456, 13460>    <13454, 13460, 13457>,
    <13454, 13457, 13461>    <13454, 13461, 13458>,
    <13454, 13458, 13462>    <13463, 13471, 13464>,
    <13463, 13464, 13468>    <13463, 13468, 13465>,
    <13463, 13465, 13469>    <13463, 13469, 13466>,
    <13463, 13466, 13470>    <13463, 13470, 13467>,
    <13463, 13467, 13471>    <13472, 13480, 13473>,
    <13472, 13473, 13477>    <13472, 13477, 13474>,
    <13472, 13474, 13478>    <13472, 13478, 13475>,
    <13472, 13475, 13479>    <13472, 13479, 13476>,
    <13472, 13476, 13480>    <13481, 13489, 13482>,
    <13481, 13482, 13486>    <13481, 13486, 13483>,
    <13481, 13483, 13487>    <13481, 13487, 13484>,
    <13481, 13484, 13488>    <13481, 13488, 13485>,
    <13481, 13485, 13489>    <13490, 13498, 13491>,
    <13490, 13491, 13495>    <13490, 13495, 13492>,
    <13490, 13492, 13496>    <13490, 13496, 13493>,
    <13490, 13493, 13497>    <13490, 13497, 13494>,
    <13490, 13494, 13498>    <13499, 13507, 13500>,
    <13499, 13500, 13504>    <13499, 13504, 13501>,
    <13499, 13501, 13505>    <13499, 13505, 13502>,
    <13499, 13502, 13506>    <13499, 13506, 13503>,
    <13499, 13503, 13507>    <13508, 13516, 13509>,
    <13508, 13509, 13513>    <13508, 13513, 13510>,
    <13508, 13510, 13514>    <13508, 13514, 13511>,
    <13508, 13511, 13515>    <13508, 13515, 13512>,
    <13508, 13512, 13516>    <13517, 13525, 13518>,
    <13517, 13518, 13522>    <13517, 13522, 13519>,
    <13517, 13519, 13523>    <13517, 13523, 13520>,
    <13517, 13520, 13524>    <13517, 13524, 13521>,
    <13517, 13521, 13525>    <13526, 13534, 13527>,
    <13526, 13527, 13531>    <13526, 13531, 13528>,
    <13526, 13528, 13532>    <13526, 13532, 13529>,
    <13526, 13529, 13533>    <13526, 13533, 13530>,
    <13526, 13530, 13534>    <13535, 13543, 13536>,
    <13535, 13536, 13540>    <13535, 13540, 13537>,
    <13535, 13537, 13541>    <13535, 13541, 13538>,
    <13535, 13538, 13542>    <13535, 13542, 13539>,
    <13535, 13539, 13543>    <13544, 13552, 13545>,
    <13544, 13545, 13549>    <13544, 13549, 13546>,
    <13544, 13546, 13550>    <13544, 13550, 13547>,
    <13544, 13547, 13551>    <13544, 13551, 13548>,
    <13544, 13548, 13552>    <13553, 13561, 13554>,
    <13553, 13554, 13558>    <13553, 13558, 13555>,
    <13553, 13555, 13559>    <13553, 13559, 13556>,
    <13553, 13556, 13560>    <13553, 13560, 13557>,
    <13553, 13557, 13561>    <13562, 13570, 13563>,
    <13562, 13563, 13567>    <13562, 13567, 13564>,
    <13562, 13564, 13568>    <13562, 13568, 13565>,
    <13562, 13565, 13569>    <13562, 13569, 13566>,
    <13562, 13566, 13570>    <13571, 13579, 13572>,
    <13571, 13572, 13576>    <13571, 13576, 13573>,
    <13571, 13573, 13577>    <13571, 13577, 13574>,
    <13571, 13574, 13578>    <13571, 13578, 13575>,
    <13571, 13575, 13579>    <13580, 13588, 13581>,
    <13580, 13581, 13585>    <13580, 13585, 13582>,
    <13580, 13582, 13586>    <13580, 13586, 13583>,
    <13580, 13583, 13587>    <13580, 13587, 13584>,
    <13580, 13584, 13588>    <13589, 13597, 13590>,
    <13589, 13590, 13594>    <13589, 13594, 13591>,
    <13589, 13591, 13595>    <13589, 13595, 13592>,
    <13589, 13592, 13596>    <13589, 13596, 13593>,
    <13589, 13593, 13597>    <13598, 13606, 13599>,
    <13598, 13599, 13603>    <13598, 13603, 13600>,
    <13598, 13600, 13604>    <13598, 13604, 13601>,
    <13598, 13601, 13605>    <13598, 13605, 13602>,
    <13598, 13602, 13606>    <13607, 13615, 13608>,
    <13607, 13608, 13612>    <13607, 13612, 13609>,
    <13607, 13609, 13613>    <13607, 13613, 13610>,
    <13607, 13610, 13614>    <13607, 13614, 13611>,
    <13607, 13611, 13615>    <13616, 13624, 13617>,
    <13616, 13617, 13621>    <13616, 13621, 13618>,
    <13616, 13618, 13622>    <13616, 13622, 13619>,
    <13616, 13619, 13623>    <13616, 13623, 13620>,
    <13616, 13620, 13624>    <13625, 13633, 13626>,
    <13625, 13626, 13630>    <13625, 13630, 13627>,
    <13625, 13627, 13631>    <13625, 13631, 13628>,
    <13625, 13628, 13632>    <13625, 13632, 13629>,
    <13625, 13629, 13633>    <13634, 13642, 13635>,
    <13634, 13635, 13639>    <13634, 13639, 13636>,
    <13634, 13636, 13640>    <13634, 13640, 13637>,
    <13634, 13637, 13641>    <13634, 13641, 13638>,
    <13634, 13638, 13642>    <13643, 13651, 13644>,
    <13643, 13644, 13648>    <13643, 13648, 13645>,
    <13643, 13645, 13649>    <13643, 13649, 13646>,
    <13643, 13646, 13650>    <13643, 13650, 13647>,
    <13643, 13647, 13651>    <13652, 13660, 13653>,
    <13652, 13653, 13657>    <13652, 13657, 13654>,
    <13652, 13654, 13658>    <13652, 13658, 13655>,
    <13652, 13655, 13659>    <13652, 13659, 13656>,
    <13652, 13656, 13660>    <13661, 13669, 13662>,
    <13661, 13662, 13666>    <13661, 13666, 13663>,
    <13661, 13663, 13667>    <13661, 13667, 13664>,
    <13661, 13664, 13668>    <13661, 13668, 13665>,
    <13661, 13665, 13669>    <13670, 13678, 13671>,
    <13670, 13671, 13675>    <13670, 13675, 13672>,
    <13670, 13672, 13676>    <13670, 13676, 13673>,
    <13670, 13673, 13677>    <13670, 13677, 13674>,
    <13670, 13674, 13678>    <13679, 13687, 13680>,
    <13679, 13680, 13684>    <13679, 13684, 13681>,
    <13679, 13681, 13685>    <13679, 13685, 13682>,
    <13679, 13682, 13686>    <13679, 13686, 13683>,
    <13679, 13683, 13687>    <13688, 13696, 13689>,
    <13688, 13689, 13693>    <13688, 13693, 13690>,
    <13688, 13690, 13694>    <13688, 13694, 13691>,
    <13688, 13691, 13695>    <13688, 13695, 13692>,
    <13688, 13692, 13696>    <13697, 13705, 13698>,
    <13697, 13698, 13702>    <13697, 13702, 13699>,
    <13697, 13699, 13703>    <13697, 13703, 13700>,
    <13697, 13700, 13704>    <13697, 13704, 13701>,
    <13697, 13701, 13705>    <13706, 13714, 13707>,
    <13706, 13707, 13711>    <13706, 13711, 13708>,
    <13706, 13708, 13712>    <13706, 13712, 13709>,
    <13706, 13709, 13713>    <13706, 13713, 13710>,
    <13706, 13710, 13714>    <13715, 13723, 13716>,
    <13715, 13716, 13720>    <13715, 13720, 13717>,
    <13715, 13717, 13721>    <13715, 13721, 13718>,
    <13715, 13718, 13722>    <13715, 13722, 13719>,
    <13715, 13719, 13723>    <13724, 13732, 13725>,
    <13724, 13725, 13729>    <13724, 13729, 13726>,
    <13724, 13726, 13730>    <13724, 13730, 13727>,
    <13724, 13727, 13731>    <13724, 13731, 13728>,
    <13724, 13728, 13732>    <13733, 13741, 13734>,
    <13733, 13734, 13738>    <13733, 13738, 13735>,
    <13733, 13735, 13739>    <13733, 13739, 13736>,
    <13733, 13736, 13740>    <13733, 13740, 13737>,
    <13733, 13737, 13741>    <13742, 13750, 13743>,
    <13742, 13743, 13747>    <13742, 13747, 13744>,
    <13742, 13744, 13748>    <13742, 13748, 13745>,
    <13742, 13745, 13749>    <13742, 13749, 13746>,
    <13742, 13746, 13750>    <13751, 13759, 13752>,
    <13751, 13752, 13756>    <13751, 13756, 13753>,
    <13751, 13753, 13757>    <13751, 13757, 13754>,
    <13751, 13754, 13758>    <13751, 13758, 13755>,
    <13751, 13755, 13759>    <13760, 13768, 13761>,
    <13760, 13761, 13765>    <13760, 13765, 13762>,
    <13760, 13762, 13766>    <13760, 13766, 13763>,
    <13760, 13763, 13767>    <13760, 13767, 13764>,
    <13760, 13764, 13768>    <13769, 13777, 13770>,
    <13769, 13770, 13774>    <13769, 13774, 13771>,
    <13769, 13771, 13775>    <13769, 13775, 13772>,
    <13769, 13772, 13776>    <13769, 13776, 13773>,
    <13769, 13773, 13777>    <13778, 13786, 13779>,
    <13778, 13779, 13783>    <13778, 13783, 13780>,
    <13778, 13780, 13784>    <13778, 13784, 13781>,
    <13778, 13781, 13785>    <13778, 13785, 13782>,
    <13778, 13782, 13786>    <13787, 13795, 13788>,
    <13787, 13788, 13792>    <13787, 13792, 13789>,
    <13787, 13789, 13793>    <13787, 13793, 13790>,
    <13787, 13790, 13794>    <13787, 13794, 13791>,
    <13787, 13791, 13795>    <13796, 13804, 13797>,
    <13796, 13797, 13801>    <13796, 13801, 13798>,
    <13796, 13798, 13802>    <13796, 13802, 13799>,
    <13796, 13799, 13803>    <13796, 13803, 13800>,
    <13796, 13800, 13804>    <13805, 13813, 13806>,
    <13805, 13806, 13810>    <13805, 13810, 13807>,
    <13805, 13807, 13811>    <13805, 13811, 13808>,
    <13805, 13808, 13812>    <13805, 13812, 13809>,
    <13805, 13809, 13813>    <13814, 13822, 13815>,
    <13814, 13815, 13819>    <13814, 13819, 13816>,
    <13814, 13816, 13820>    <13814, 13820, 13817>,
    <13814, 13817, 13821>    <13814, 13821, 13818>,
    <13814, 13818, 13822>    <13823, 13831, 13824>,
    <13823, 13824, 13828>    <13823, 13828, 13825>,
    <13823, 13825, 13829>    <13823, 13829, 13826>,
    <13823, 13826, 13830>    <13823, 13830, 13827>,
    <13823, 13827, 13831>    <13832, 13840, 13833>,
    <13832, 13833, 13837>    <13832, 13837, 13834>,
    <13832, 13834, 13838>    <13832, 13838, 13835>,
    <13832, 13835, 13839>    <13832, 13839, 13836>,
    <13832, 13836, 13840>    <13841, 13849, 13842>,
    <13841, 13842, 13846>    <13841, 13846, 13843>,
    <13841, 13843, 13847>    <13841, 13847, 13844>,
    <13841, 13844, 13848>    <13841, 13848, 13845>,
    <13841, 13845, 13849>    <13850, 13858, 13851>,
    <13850, 13851, 13855>    <13850, 13855, 13852>,
    <13850, 13852, 13856>    <13850, 13856, 13853>,
    <13850, 13853, 13857>    <13850, 13857, 13854>,
    <13850, 13854, 13858>    <13859, 13867, 13860>,
    <13859, 13860, 13864>    <13859, 13864, 13861>,
    <13859, 13861, 13865>    <13859, 13865, 13862>,
    <13859, 13862, 13866>    <13859, 13866, 13863>,
    <13859, 13863, 13867>    <13868, 13876, 13869>,
    <13868, 13869, 13873>    <13868, 13873, 13870>,
    <13868, 13870, 13874>    <13868, 13874, 13871>,
    <13868, 13871, 13875>    <13868, 13875, 13872>,
    <13868, 13872, 13876>    <13877, 13885, 13878>,
    <13877, 13878, 13882>    <13877, 13882, 13879>,
    <13877, 13879, 13883>    <13877, 13883, 13880>,
    <13877, 13880, 13884>    <13877, 13884, 13881>,
    <13877, 13881, 13885>    <13886, 13894, 13887>,
    <13886, 13887, 13891>    <13886, 13891, 13888>,
    <13886, 13888, 13892>    <13886, 13892, 13889>,
    <13886, 13889, 13893>    <13886, 13893, 13890>,
    <13886, 13890, 13894>    <13895, 13903, 13896>,
    <13895, 13896, 13900>    <13895, 13900, 13897>,
    <13895, 13897, 13901>    <13895, 13901, 13898>,
    <13895, 13898, 13902>    <13895, 13902, 13899>,
    <13895, 13899, 13903>    <13904, 13912, 13905>,
    <13904, 13905, 13909>    <13904, 13909, 13906>,
    <13904, 13906, 13910>    <13904, 13910, 13907>,
    <13904, 13907, 13911>    <13904, 13911, 13908>,
    <13904, 13908, 13912>    <13913, 13921, 13914>,
    <13913, 13914, 13918>    <13913, 13918, 13915>,
    <13913, 13915, 13919>    <13913, 13919, 13916>,
    <13913, 13916, 13920>    <13913, 13920, 13917>,
    <13913, 13917, 13921>    <13922, 13930, 13923>,
    <13922, 13923, 13927>    <13922, 13927, 13924>,
    <13922, 13924, 13928>    <13922, 13928, 13925>,
    <13922, 13925, 13929>    <13922, 13929, 13926>,
    <13922, 13926, 13930>    <13931, 13939, 13932>,
    <13931, 13932, 13936>    <13931, 13936, 13933>,
    <13931, 13933, 13937>    <13931, 13937, 13934>,
    <13931, 13934, 13938>    <13931, 13938, 13935>,
    <13931, 13935, 13939>    <13940, 13948, 13941>,
    <13940, 13941, 13945>    <13940, 13945, 13942>,
    <13940, 13942, 13946>    <13940, 13946, 13943>,
    <13940, 13943, 13947>    <13940, 13947, 13944>,
    <13940, 13944, 13948>    <13949, 13957, 13950>,
    <13949, 13950, 13954>    <13949, 13954, 13951>,
    <13949, 13951, 13955>    <13949, 13955, 13952>,
    <13949, 13952, 13956>    <13949, 13956, 13953>,
    <13949, 13953, 13957>    <13958, 13966, 13959>,
    <13958, 13959, 13963>    <13958, 13963, 13960>,
    <13958, 13960, 13964>    <13958, 13964, 13961>,
    <13958, 13961, 13965>    <13958, 13965, 13962>,
    <13958, 13962, 13966>    <13967, 13975, 13968>,
    <13967, 13968, 13972>    <13967, 13972, 13969>,
    <13967, 13969, 13973>    <13967, 13973, 13970>,
    <13967, 13970, 13974>    <13967, 13974, 13971>,
    <13967, 13971, 13975>    <13976, 13984, 13977>,
    <13976, 13977, 13981>    <13976, 13981, 13978>,
    <13976, 13978, 13982>    <13976, 13982, 13979>,
    <13976, 13979, 13983>    <13976, 13983, 13980>,
    <13976, 13980, 13984>    <13985, 13993, 13986>,
    <13985, 13986, 13990>    <13985, 13990, 13987>,
    <13985, 13987, 13991>    <13985, 13991, 13988>,
    <13985, 13988, 13992>    <13985, 13992, 13989>,
    <13985, 13989, 13993>    <13994, 14002, 13995>,
    <13994, 13995, 13999>    <13994, 13999, 13996>,
    <13994, 13996, 14000>    <13994, 14000, 13997>,
    <13994, 13997, 14001>    <13994, 14001, 13998>,
    <13994, 13998, 14002>    <14003, 14011, 14004>,
    <14003, 14004, 14008>    <14003, 14008, 14005>,
    <14003, 14005, 14009>    <14003, 14009, 14006>,
    <14003, 14006, 14010>    <14003, 14010, 14007>,
    <14003, 14007, 14011>    <14012, 14020, 14013>,
    <14012, 14013, 14017>    <14012, 14017, 14014>,
    <14012, 14014, 14018>    <14012, 14018, 14015>,
    <14012, 14015, 14019>    <14012, 14019, 14016>,
    <14012, 14016, 14020>    <14021, 14029, 14022>,
    <14021, 14022, 14026>    <14021, 14026, 14023>,
    <14021, 14023, 14027>    <14021, 14027, 14024>,
    <14021, 14024, 14028>    <14021, 14028, 14025>,
    <14021, 14025, 14029>    <14030, 14038, 14031>,
    <14030, 14031, 14035>    <14030, 14035, 14032>,
    <14030, 14032, 14036>    <14030, 14036, 14033>,
    <14030, 14033, 14037>    <14030, 14037, 14034>,
    <14030, 14034, 14038>    <14039, 14047, 14040>,
    <14039, 14040, 14044>    <14039, 14044, 14041>,
    <14039, 14041, 14045>    <14039, 14045, 14042>,
    <14039, 14042, 14046>    <14039, 14046, 14043>,
    <14039, 14043, 14047>    <14048, 14056, 14049>,
    <14048, 14049, 14053>    <14048, 14053, 14050>,
    <14048, 14050, 14054>    <14048, 14054, 14051>,
    <14048, 14051, 14055>    <14048, 14055, 14052>,
    <14048, 14052, 14056>    <14057, 14065, 14058>,
    <14057, 14058, 14062>    <14057, 14062, 14059>,
    <14057, 14059, 14063>    <14057, 14063, 14060>,
    <14057, 14060, 14064>    <14057, 14064, 14061>,
    <14057, 14061, 14065>    <14066, 14074, 14067>,
    <14066, 14067, 14071>    <14066, 14071, 14068>,
    <14066, 14068, 14072>    <14066, 14072, 14069>,
    <14066, 14069, 14073>    <14066, 14073, 14070>,
    <14066, 14070, 14074>    <14075, 14083, 14076>,
    <14075, 14076, 14080>    <14075, 14080, 14077>,
    <14075, 14077, 14081>    <14075, 14081, 14078>,
    <14075, 14078, 14082>    <14075, 14082, 14079>,
    <14075, 14079, 14083>    <14084, 14092, 14085>,
    <14084, 14085, 14089>    <14084, 14089, 14086>,
    <14084, 14086, 14090>    <14084, 14090, 14087>,
    <14084, 14087, 14091>    <14084, 14091, 14088>,
    <14084, 14088, 14092>    <14093, 14101, 14094>,
    <14093, 14094, 14098>    <14093, 14098, 14095>,
    <14093, 14095, 14099>    <14093, 14099, 14096>,
    <14093, 14096, 14100>    <14093, 14100, 14097>,
    <14093, 14097, 14101>    <14102, 14110, 14103>,
    <14102, 14103, 14107>    <14102, 14107, 14104>,
    <14102, 14104, 14108>    <14102, 14108, 14105>,
    <14102, 14105, 14109>    <14102, 14109, 14106>,
    <14102, 14106, 14110>    <14111, 14119, 14112>,
    <14111, 14112, 14116>    <14111, 14116, 14113>,
    <14111, 14113, 14117>    <14111, 14117, 14114>,
    <14111, 14114, 14118>    <14111, 14118, 14115>,
    <14111, 14115, 14119>    <14120, 14128, 14121>,
    <14120, 14121, 14125>    <14120, 14125, 14122>,
    <14120, 14122, 14126>    <14120, 14126, 14123>,
    <14120, 14123, 14127>    <14120, 14127, 14124>,
    <14120, 14124, 14128>    <14129, 14137, 14130>,
    <14129, 14130, 14134>    <14129, 14134, 14131>,
    <14129, 14131, 14135>    <14129, 14135, 14132>,
    <14129, 14132, 14136>    <14129, 14136, 14133>,
    <14129, 14133, 14137>    <14138, 14146, 14139>,
    <14138, 14139, 14143>    <14138, 14143, 14140>,
    <14138, 14140, 14144>    <14138, 14144, 14141>,
    <14138, 14141, 14145>    <14138, 14145, 14142>,
    <14138, 14142, 14146>    <14147, 14155, 14148>,
    <14147, 14148, 14152>    <14147, 14152, 14149>,
    <14147, 14149, 14153>    <14147, 14153, 14150>,
    <14147, 14150, 14154>    <14147, 14154, 14151>,
    <14147, 14151, 14155>    <14156, 14164, 14157>,
    <14156, 14157, 14161>    <14156, 14161, 14158>,
    <14156, 14158, 14162>    <14156, 14162, 14159>,
    <14156, 14159, 14163>    <14156, 14163, 14160>,
    <14156, 14160, 14164>    <14165, 14173, 14166>,
    <14165, 14166, 14170>    <14165, 14170, 14167>,
    <14165, 14167, 14171>    <14165, 14171, 14168>,
    <14165, 14168, 14172>    <14165, 14172, 14169>,
    <14165, 14169, 14173>    <14174, 14182, 14175>,
    <14174, 14175, 14179>    <14174, 14179, 14176>,
    <14174, 14176, 14180>    <14174, 14180, 14177>,
    <14174, 14177, 14181>    <14174, 14181, 14178>,
    <14174, 14178, 14182>    <14183, 14191, 14184>,
    <14183, 14184, 14188>    <14183, 14188, 14185>,
    <14183, 14185, 14189>    <14183, 14189, 14186>,
    <14183, 14186, 14190>    <14183, 14190, 14187>,
    <14183, 14187, 14191>    <14192, 14200, 14193>,
    <14192, 14193, 14197>    <14192, 14197, 14194>,
    <14192, 14194, 14198>    <14192, 14198, 14195>,
    <14192, 14195, 14199>    <14192, 14199, 14196>,
    <14192, 14196, 14200>    <14201, 14209, 14202>,
    <14201, 14202, 14206>    <14201, 14206, 14203>,
    <14201, 14203, 14207>    <14201, 14207, 14204>,
    <14201, 14204, 14208>    <14201, 14208, 14205>,
    <14201, 14205, 14209>    <14210, 14218, 14211>,
    <14210, 14211, 14215>    <14210, 14215, 14212>,
    <14210, 14212, 14216>    <14210, 14216, 14213>,
    <14210, 14213, 14217>    <14210, 14217, 14214>,
    <14210, 14214, 14218>    <14219, 14227, 14220>,
    <14219, 14220, 14224>    <14219, 14224, 14221>,
    <14219, 14221, 14225>    <14219, 14225, 14222>,
    <14219, 14222, 14226>    <14219, 14226, 14223>,
    <14219, 14223, 14227>    <14228, 14236, 14229>,
    <14228, 14229, 14233>    <14228, 14233, 14230>,
    <14228, 14230, 14234>    <14228, 14234, 14231>,
    <14228, 14231, 14235>    <14228, 14235, 14232>,
    <14228, 14232, 14236>    <14237, 14245, 14238>,
    <14237, 14238, 14242>    <14237, 14242, 14239>,
    <14237, 14239, 14243>    <14237, 14243, 14240>,
    <14237, 14240, 14244>    <14237, 14244, 14241>,
    <14237, 14241, 14245>    <14246, 14254, 14247>,
    <14246, 14247, 14251>    <14246, 14251, 14248>,
    <14246, 14248, 14252>    <14246, 14252, 14249>,
    <14246, 14249, 14253>    <14246, 14253, 14250>,
    <14246, 14250, 14254>    <14255, 14263, 14256>,
    <14255, 14256, 14260>    <14255, 14260, 14257>,
    <14255, 14257, 14261>    <14255, 14261, 14258>,
    <14255, 14258, 14262>    <14255, 14262, 14259>,
    <14255, 14259, 14263>    <14264, 14272, 14265>,
    <14264, 14265, 14269>    <14264, 14269, 14266>,
    <14264, 14266, 14270>    <14264, 14270, 14267>,
    <14264, 14267, 14271>    <14264, 14271, 14268>,
    <14264, 14268, 14272>    <14273, 14281, 14274>,
    <14273, 14274, 14278>    <14273, 14278, 14275>,
    <14273, 14275, 14279>    <14273, 14279, 14276>,
    <14273, 14276, 14280>    <14273, 14280, 14277>,
    <14273, 14277, 14281>    <14282, 14290, 14283>,
    <14282, 14283, 14287>    <14282, 14287, 14284>,
    <14282, 14284, 14288>    <14282, 14288, 14285>,
    <14282, 14285, 14289>    <14282, 14289, 14286>,
    <14282, 14286, 14290>    <14291, 14299, 14292>,
    <14291, 14292, 14296>    <14291, 14296, 14293>,
    <14291, 14293, 14297>    <14291, 14297, 14294>,
    <14291, 14294, 14298>    <14291, 14298, 14295>,
    <14291, 14295, 14299>    <14300, 14308, 14301>,
    <14300, 14301, 14305>    <14300, 14305, 14302>,
    <14300, 14302, 14306>    <14300, 14306, 14303>,
    <14300, 14303, 14307>    <14300, 14307, 14304>,
    <14300, 14304, 14308>    <14309, 14317, 14310>,
    <14309, 14310, 14314>    <14309, 14314, 14311>,
    <14309, 14311, 14315>    <14309, 14315, 14312>,
    <14309, 14312, 14316>    <14309, 14316, 14313>,
    <14309, 14313, 14317>    <14318, 14326, 14319>,
    <14318, 14319, 14323>    <14318, 14323, 14320>,
    <14318, 14320, 14324>    <14318, 14324, 14321>,
    <14318, 14321, 14325>    <14318, 14325, 14322>,
    <14318, 14322, 14326>    <14327, 14335, 14328>,
    <14327, 14328, 14332>    <14327, 14332, 14329>,
    <14327, 14329, 14333>    <14327, 14333, 14330>,
    <14327, 14330, 14334>    <14327, 14334, 14331>,
    <14327, 14331, 14335>    <14336, 14344, 14337>,
    <14336, 14337, 14341>    <14336, 14341, 14338>,
    <14336, 14338, 14342>    <14336, 14342, 14339>,
    <14336, 14339, 14343>    <14336, 14343, 14340>,
    <14336, 14340, 14344>    <14345, 14353, 14346>,
    <14345, 14346, 14350>    <14345, 14350, 14347>,
    <14345, 14347, 14351>    <14345, 14351, 14348>,
    <14345, 14348, 14352>    <14345, 14352, 14349>,
    <14345, 14349, 14353>    <14354, 14362, 14355>,
    <14354, 14355, 14359>    <14354, 14359, 14356>,
    <14354, 14356, 14360>    <14354, 14360, 14357>,
    <14354, 14357, 14361>    <14354, 14361, 14358>,
    <14354, 14358, 14362>    <14363, 14371, 14364>,
    <14363, 14364, 14368>    <14363, 14368, 14365>,
    <14363, 14365, 14369>    <14363, 14369, 14366>,
    <14363, 14366, 14370>    <14363, 14370, 14367>,
    <14363, 14367, 14371>    <14372, 14380, 14373>,
    <14372, 14373, 14377>    <14372, 14377, 14374>,
    <14372, 14374, 14378>    <14372, 14378, 14375>,
    <14372, 14375, 14379>    <14372, 14379, 14376>,
    <14372, 14376, 14380>    <14381, 14389, 14382>,
    <14381, 14382, 14386>    <14381, 14386, 14383>,
    <14381, 14383, 14387>    <14381, 14387, 14384>,
    <14381, 14384, 14388>    <14381, 14388, 14385>,
    <14381, 14385, 14389>    <14390, 14398, 14391>,
    <14390, 14391, 14395>    <14390, 14395, 14392>,
    <14390, 14392, 14396>    <14390, 14396, 14393>,
    <14390, 14393, 14397>    <14390, 14397, 14394>,
    <14390, 14394, 14398>    <14399, 14407, 14400>,
    <14399, 14400, 14404>    <14399, 14404, 14401>,
    <14399, 14401, 14405>    <14399, 14405, 14402>,
    <14399, 14402, 14406>    <14399, 14406, 14403>,
    <14399, 14403, 14407>    <14408, 14416, 14409>,
    <14408, 14409, 14413>    <14408, 14413, 14410>,
    <14408, 14410, 14414>    <14408, 14414, 14411>,
    <14408, 14411, 14415>    <14408, 14415, 14412>,
    <14408, 14412, 14416>    <14417, 14425, 14418>,
    <14417, 14418, 14422>    <14417, 14422, 14419>,
    <14417, 14419, 14423>    <14417, 14423, 14420>,
    <14417, 14420, 14424>    <14417, 14424, 14421>,
    <14417, 14421, 14425>    <14426, 14434, 14427>,
    <14426, 14427, 14431>    <14426, 14431, 14428>,
    <14426, 14428, 14432>    <14426, 14432, 14429>,
    <14426, 14429, 14433>    <14426, 14433, 14430>,
    <14426, 14430, 14434>    <14435, 14443, 14436>,
    <14435, 14436, 14440>    <14435, 14440, 14437>,
    <14435, 14437, 14441>    <14435, 14441, 14438>,
    <14435, 14438, 14442>    <14435, 14442, 14439>,
    <14435, 14439, 14443>    <14444, 14452, 14445>,
    <14444, 14445, 14449>    <14444, 14449, 14446>,
    <14444, 14446, 14450>    <14444, 14450, 14447>,
    <14444, 14447, 14451>    <14444, 14451, 14448>,
    <14444, 14448, 14452>    <14453, 14461, 14454>,
    <14453, 14454, 14458>    <14453, 14458, 14455>,
    <14453, 14455, 14459>    <14453, 14459, 14456>,
    <14453, 14456, 14460>    <14453, 14460, 14457>,
    <14453, 14457, 14461>    <14462, 14470, 14463>,
    <14462, 14463, 14467>    <14462, 14467, 14464>,
    <14462, 14464, 14468>    <14462, 14468, 14465>,
    <14462, 14465, 14469>    <14462, 14469, 14466>,
    <14462, 14466, 14470>    <14471, 14479, 14472>,
    <14471, 14472, 14476>    <14471, 14476, 14473>,
    <14471, 14473, 14477>    <14471, 14477, 14474>,
    <14471, 14474, 14478>    <14471, 14478, 14475>,
    <14471, 14475, 14479>    <14480, 14488, 14481>,
    <14480, 14481, 14485>    <14480, 14485, 14482>,
    <14480, 14482, 14486>    <14480, 14486, 14483>,
    <14480, 14483, 14487>    <14480, 14487, 14484>,
    <14480, 14484, 14488>    <14489, 14497, 14490>,
    <14489, 14490, 14494>    <14489, 14494, 14491>,
    <14489, 14491, 14495>    <14489, 14495, 14492>,
    <14489, 14492, 14496>    <14489, 14496, 14493>,
    <14489, 14493, 14497>    <14498, 14506, 14499>,
    <14498, 14499, 14503>    <14498, 14503, 14500>,
    <14498, 14500, 14504>    <14498, 14504, 14501>,
    <14498, 14501, 14505>    <14498, 14505, 14502>,
    <14498, 14502, 14506>    <14507, 14515, 14508>,
    <14507, 14508, 14512>    <14507, 14512, 14509>,
    <14507, 14509, 14513>    <14507, 14513, 14510>,
    <14507, 14510, 14514>    <14507, 14514, 14511>,
    <14507, 14511, 14515>    <14516, 14524, 14517>,
    <14516, 14517, 14521>    <14516, 14521, 14518>,
    <14516, 14518, 14522>    <14516, 14522, 14519>,
    <14516, 14519, 14523>    <14516, 14523, 14520>,
    <14516, 14520, 14524>    <14525, 14533, 14526>,
    <14525, 14526, 14530>    <14525, 14530, 14527>,
    <14525, 14527, 14531>    <14525, 14531, 14528>,
    <14525, 14528, 14532>    <14525, 14532, 14529>,
    <14525, 14529, 14533>    <14534, 14542, 14535>,
    <14534, 14535, 14539>    <14534, 14539, 14536>,
    <14534, 14536, 14540>    <14534, 14540, 14537>,
    <14534, 14537, 14541>    <14534, 14541, 14538>,
    <14534, 14538, 14542>    <14543, 14551, 14544>,
    <14543, 14544, 14548>    <14543, 14548, 14545>,
    <14543, 14545, 14549>    <14543, 14549, 14546>,
    <14543, 14546, 14550>    <14543, 14550, 14547>,
    <14543, 14547, 14551>    <14552, 14560, 14553>,
    <14552, 14553, 14557>    <14552, 14557, 14554>,
    <14552, 14554, 14558>    <14552, 14558, 14555>,
    <14552, 14555, 14559>    <14552, 14559, 14556>,
    <14552, 14556, 14560>    <14561, 14569, 14562>,
    <14561, 14562, 14566>    <14561, 14566, 14563>,
    <14561, 14563, 14567>    <14561, 14567, 14564>,
    <14561, 14564, 14568>    <14561, 14568, 14565>,
    <14561, 14565, 14569>    <14570, 14578, 14571>,
    <14570, 14571, 14575>    <14570, 14575, 14572>,
    <14570, 14572, 14576>    <14570, 14576, 14573>,
    <14570, 14573, 14577>    <14570, 14577, 14574>,
    <14570, 14574, 14578>    <14579, 14587, 14580>,
    <14579, 14580, 14584>    <14579, 14584, 14581>,
    <14579, 14581, 14585>    <14579, 14585, 14582>,
    <14579, 14582, 14586>    <14579, 14586, 14583>,
    <14579, 14583, 14587>    <14588, 14596, 14589>,
    <14588, 14589, 14593>    <14588, 14593, 14590>,
    <14588, 14590, 14594>    <14588, 14594, 14591>,
    <14588, 14591, 14595>    <14588, 14595, 14592>,
    <14588, 14592, 14596>    <14597, 14605, 14598>,
    <14597, 14598, 14602>    <14597, 14602, 14599>,
    <14597, 14599, 14603>    <14597, 14603, 14600>,
    <14597, 14600, 14604>    <14597, 14604, 14601>,
    <14597, 14601, 14605>    <14606, 14614, 14607>,
    <14606, 14607, 14611>    <14606, 14611, 14608>,
    <14606, 14608, 14612>    <14606, 14612, 14609>,
    <14606, 14609, 14613>    <14606, 14613, 14610>,
    <14606, 14610, 14614>    <14615, 14623, 14616>,
    <14615, 14616, 14620>    <14615, 14620, 14617>,
    <14615, 14617, 14621>    <14615, 14621, 14618>,
    <14615, 14618, 14622>    <14615, 14622, 14619>,
    <14615, 14619, 14623>    <14624, 14632, 14625>,
    <14624, 14625, 14629>    <14624, 14629, 14626>,
    <14624, 14626, 14630>    <14624, 14630, 14627>,
    <14624, 14627, 14631>    <14624, 14631, 14628>,
    <14624, 14628, 14632>    <14633, 14641, 14634>,
    <14633, 14634, 14638>    <14633, 14638, 14635>,
    <14633, 14635, 14639>    <14633, 14639, 14636>,
    <14633, 14636, 14640>    <14633, 14640, 14637>,
    <14633, 14637, 14641>    <14642, 14650, 14643>,
    <14642, 14643, 14647>    <14642, 14647, 14644>,
    <14642, 14644, 14648>    <14642, 14648, 14645>,
    <14642, 14645, 14649>    <14642, 14649, 14646>,
    <14642, 14646, 14650>    <14651, 14659, 14652>,
    <14651, 14652, 14656>    <14651, 14656, 14653>,
    <14651, 14653, 14657>    <14651, 14657, 14654>,
    <14651, 14654, 14658>    <14651, 14658, 14655>,
    <14651, 14655, 14659>    <14660, 14668, 14661>,
    <14660, 14661, 14665>    <14660, 14665, 14662>,
    <14660, 14662, 14666>    <14660, 14666, 14663>,
    <14660, 14663, 14667>    <14660, 14667, 14664>,
    <14660, 14664, 14668>    <14669, 14677, 14670>,
    <14669, 14670, 14674>    <14669, 14674, 14671>,
    <14669, 14671, 14675>    <14669, 14675, 14672>,
    <14669, 14672, 14676>    <14669, 14676, 14673>,
    <14669, 14673, 14677>    <14678, 14686, 14679>,
    <14678, 14679, 14683>    <14678, 14683, 14680>,
    <14678, 14680, 14684>    <14678, 14684, 14681>,
    <14678, 14681, 14685>    <14678, 14685, 14682>,
    <14678, 14682, 14686>    <14687, 14695, 14688>,
    <14687, 14688, 14692>    <14687, 14692, 14689>,
    <14687, 14689, 14693>    <14687, 14693, 14690>,
    <14687, 14690, 14694>    <14687, 14694, 14691>,
    <14687, 14691, 14695>    <14696, 14704, 14697>,
    <14696, 14697, 14701>    <14696, 14701, 14698>,
    <14696, 14698, 14702>    <14696, 14702, 14699>,
    <14696, 14699, 14703>    <14696, 14703, 14700>,
    <14696, 14700, 14704>    <14705, 14713, 14706>,
    <14705, 14706, 14710>    <14705, 14710, 14707>,
    <14705, 14707, 14711>    <14705, 14711, 14708>,
    <14705, 14708, 14712>    <14705, 14712, 14709>,
    <14705, 14709, 14713>    <14714, 14722, 14715>,
    <14714, 14715, 14719>    <14714, 14719, 14716>,
    <14714, 14716, 14720>    <14714, 14720, 14717>,
    <14714, 14717, 14721>    <14714, 14721, 14718>,
    <14714, 14718, 14722>    <14723, 14731, 14724>,
    <14723, 14724, 14728>    <14723, 14728, 14725>,
    <14723, 14725, 14729>    <14723, 14729, 14726>,
    <14723, 14726, 14730>    <14723, 14730, 14727>,
    <14723, 14727, 14731>    <14732, 14740, 14733>,
    <14732, 14733, 14737>    <14732, 14737, 14734>,
    <14732, 14734, 14738>    <14732, 14738, 14735>,
    <14732, 14735, 14739>    <14732, 14739, 14736>,
    <14732, 14736, 14740>    <14741, 14749, 14742>,
    <14741, 14742, 14746>    <14741, 14746, 14743>,
    <14741, 14743, 14747>    <14741, 14747, 14744>,
    <14741, 14744, 14748>    <14741, 14748, 14745>,
    <14741, 14745, 14749>    <14750, 14758, 14751>,
    <14750, 14751, 14755>    <14750, 14755, 14752>,
    <14750, 14752, 14756>    <14750, 14756, 14753>,
    <14750, 14753, 14757>    <14750, 14757, 14754>,
    <14750, 14754, 14758>    <14759, 14767, 14760>,
    <14759, 14760, 14764>    <14759, 14764, 14761>,
    <14759, 14761, 14765>    <14759, 14765, 14762>,
    <14759, 14762, 14766>    <14759, 14766, 14763>,
    <14759, 14763, 14767>    <14768, 14776, 14769>,
    <14768, 14769, 14773>    <14768, 14773, 14770>,
    <14768, 14770, 14774>    <14768, 14774, 14771>,
    <14768, 14771, 14775>    <14768, 14775, 14772>,
    <14768, 14772, 14776>    <14777, 14785, 14778>,
    <14777, 14778, 14782>    <14777, 14782, 14779>,
    <14777, 14779, 14783>    <14777, 14783, 14780>,
    <14777, 14780, 14784>    <14777, 14784, 14781>,
    <14777, 14781, 14785>    <14786, 14794, 14787>,
    <14786, 14787, 14791>    <14786, 14791, 14788>,
    <14786, 14788, 14792>    <14786, 14792, 14789>,
    <14786, 14789, 14793>    <14786, 14793, 14790>,
    <14786, 14790, 14794>    <14795, 14803, 14796>,
    <14795, 14796, 14800>    <14795, 14800, 14797>,
    <14795, 14797, 14801>    <14795, 14801, 14798>,
    <14795, 14798, 14802>    <14795, 14802, 14799>,
    <14795, 14799, 14803>    <14804, 14812, 14805>,
    <14804, 14805, 14809>    <14804, 14809, 14806>,
    <14804, 14806, 14810>    <14804, 14810, 14807>,
    <14804, 14807, 14811>    <14804, 14811, 14808>,
    <14804, 14808, 14812>    <14813, 14821, 14814>,
    <14813, 14814, 14818>    <14813, 14818, 14815>,
    <14813, 14815, 14819>    <14813, 14819, 14816>,
    <14813, 14816, 14820>    <14813, 14820, 14817>,
    <14813, 14817, 14821>    <14822, 14830, 14823>,
    <14822, 14823, 14827>    <14822, 14827, 14824>,
    <14822, 14824, 14828>    <14822, 14828, 14825>,
    <14822, 14825, 14829>    <14822, 14829, 14826>,
    <14822, 14826, 14830>    <14831, 14839, 14832>,
    <14831, 14832, 14836>    <14831, 14836, 14833>,
    <14831, 14833, 14837>    <14831, 14837, 14834>,
    <14831, 14834, 14838>    <14831, 14838, 14835>,
    <14831, 14835, 14839>    <14840, 14848, 14841>,
    <14840, 14841, 14845>    <14840, 14845, 14842>,
    <14840, 14842, 14846>    <14840, 14846, 14843>,
    <14840, 14843, 14847>    <14840, 14847, 14844>,
    <14840, 14844, 14848>    <14849, 14857, 14850>,
    <14849, 14850, 14854>    <14849, 14854, 14851>,
    <14849, 14851, 14855>    <14849, 14855, 14852>,
    <14849, 14852, 14856>    <14849, 14856, 14853>,
    <14849, 14853, 14857>    <14858, 14866, 14859>,
    <14858, 14859, 14863>    <14858, 14863, 14860>,
    <14858, 14860, 14864>    <14858, 14864, 14861>,
    <14858, 14861, 14865>    <14858, 14865, 14862>,
    <14858, 14862, 14866>    <14867, 14875, 14868>,
    <14867, 14868, 14872>    <14867, 14872, 14869>,
    <14867, 14869, 14873>    <14867, 14873, 14870>,
    <14867, 14870, 14874>    <14867, 14874, 14871>,
    <14867, 14871, 14875>    <14876, 14884, 14877>,
    <14876, 14877, 14881>    <14876, 14881, 14878>,
    <14876, 14878, 14882>    <14876, 14882, 14879>,
    <14876, 14879, 14883>    <14876, 14883, 14880>,
    <14876, 14880, 14884>    <14885, 14893, 14886>,
    <14885, 14886, 14890>    <14885, 14890, 14887>,
    <14885, 14887, 14891>    <14885, 14891, 14888>,
    <14885, 14888, 14892>    <14885, 14892, 14889>,
    <14885, 14889, 14893>    <14894, 14902, 14895>,
    <14894, 14895, 14899>    <14894, 14899, 14896>,
    <14894, 14896, 14900>    <14894, 14900, 14897>,
    <14894, 14897, 14901>    <14894, 14901, 14898>,
    <14894, 14898, 14902>    <14903, 14911, 14904>,
    <14903, 14904, 14908>    <14903, 14908, 14905>,
    <14903, 14905, 14909>    <14903, 14909, 14906>,
    <14903, 14906, 14910>    <14903, 14910, 14907>,
    <14903, 14907, 14911>    <14912, 14920, 14913>,
    <14912, 14913, 14917>    <14912, 14917, 14914>,
    <14912, 14914, 14918>    <14912, 14918, 14915>,
    <14912, 14915, 14919>    <14912, 14919, 14916>,
    <14912, 14916, 14920>    <14921, 14929, 14922>,
    <14921, 14922, 14926>    <14921, 14926, 14923>,
    <14921, 14923, 14927>    <14921, 14927, 14924>,
    <14921, 14924, 14928>    <14921, 14928, 14925>,
    <14921, 14925, 14929>    <14930, 14938, 14931>,
    <14930, 14931, 14935>    <14930, 14935, 14932>,
    <14930, 14932, 14936>    <14930, 14936, 14933>,
    <14930, 14933, 14937>    <14930, 14937, 14934>,
    <14930, 14934, 14938>    <14939, 14947, 14940>,
    <14939, 14940, 14944>    <14939, 14944, 14941>,
    <14939, 14941, 14945>    <14939, 14945, 14942>,
    <14939, 14942, 14946>    <14939, 14946, 14943>,
    <14939, 14943, 14947>    <14948, 14956, 14949>,
    <14948, 14949, 14953>    <14948, 14953, 14950>,
    <14948, 14950, 14954>    <14948, 14954, 14951>,
    <14948, 14951, 14955>    <14948, 14955, 14952>,
    <14948, 14952, 14956>    <14957, 14965, 14958>,
    <14957, 14958, 14962>    <14957, 14962, 14959>,
    <14957, 14959, 14963>    <14957, 14963, 14960>,
    <14957, 14960, 14964>    <14957, 14964, 14961>,
    <14957, 14961, 14965>    <14966, 14974, 14967>,
    <14966, 14967, 14971>    <14966, 14971, 14968>,
    <14966, 14968, 14972>    <14966, 14972, 14969>,
    <14966, 14969, 14973>    <14966, 14973, 14970>,
    <14966, 14970, 14974>    <14975, 14983, 14976>,
    <14975, 14976, 14980>    <14975, 14980, 14977>,
    <14975, 14977, 14981>    <14975, 14981, 14978>,
    <14975, 14978, 14982>    <14975, 14982, 14979>,
    <14975, 14979, 14983>    <14984, 14992, 14985>,
    <14984, 14985, 14989>    <14984, 14989, 14986>,
    <14984, 14986, 14990>    <14984, 14990, 14987>,
    <14984, 14987, 14991>    <14984, 14991, 14988>,
    <14984, 14988, 14992>    <14993, 15001, 14994>,
    <14993, 14994, 14998>    <14993, 14998, 14995>,
    <14993, 14995, 14999>    <14993, 14999, 14996>,
    <14993, 14996, 15000>    <14993, 15000, 14997>,
    <14993, 14997, 15001>    <15002, 15010, 15003>,
    <15002, 15003, 15007>    <15002, 15007, 15004>,
    <15002, 15004, 15008>    <15002, 15008, 15005>,
    <15002, 15005, 15009>    <15002, 15009, 15006>,
    <15002, 15006, 15010>    <15011, 15019, 15012>,
    <15011, 15012, 15016>    <15011, 15016, 15013>,
    <15011, 15013, 15017>    <15011, 15017, 15014>,
    <15011, 15014, 15018>    <15011, 15018, 15015>,
    <15011, 15015, 15019>    <15020, 15028, 15021>,
    <15020, 15021, 15025>    <15020, 15025, 15022>,
    <15020, 15022, 15026>    <15020, 15026, 15023>,
    <15020, 15023, 15027>    <15020, 15027, 15024>,
    <15020, 15024, 15028>    <15029, 15037, 15030>,
    <15029, 15030, 15034>    <15029, 15034, 15031>,
    <15029, 15031, 15035>    <15029, 15035, 15032>,
    <15029, 15032, 15036>    <15029, 15036, 15033>,
    <15029, 15033, 15037>    <15038, 15046, 15039>,
    <15038, 15039, 15043>    <15038, 15043, 15040>,
    <15038, 15040, 15044>    <15038, 15044, 15041>,
    <15038, 15041, 15045>    <15038, 15045, 15042>,
    <15038, 15042, 15046>    <15047, 15055, 15048>,
    <15047, 15048, 15052>    <15047, 15052, 15049>,
    <15047, 15049, 15053>    <15047, 15053, 15050>,
    <15047, 15050, 15054>    <15047, 15054, 15051>,
    <15047, 15051, 15055>    <15056, 15064, 15057>,
    <15056, 15057, 15061>    <15056, 15061, 15058>,
    <15056, 15058, 15062>    <15056, 15062, 15059>,
    <15056, 15059, 15063>    <15056, 15063, 15060>,
    <15056, 15060, 15064>    <15065, 15073, 15066>,
    <15065, 15066, 15070>    <15065, 15070, 15067>,
    <15065, 15067, 15071>    <15065, 15071, 15068>,
    <15065, 15068, 15072>    <15065, 15072, 15069>,
    <15065, 15069, 15073>    <15074, 15082, 15075>,
    <15074, 15075, 15079>    <15074, 15079, 15076>,
    <15074, 15076, 15080>    <15074, 15080, 15077>,
    <15074, 15077, 15081>    <15074, 15081, 15078>,
    <15074, 15078, 15082>    <15083, 15091, 15084>,
    <15083, 15084, 15088>    <15083, 15088, 15085>,
    <15083, 15085, 15089>    <15083, 15089, 15086>,
    <15083, 15086, 15090>    <15083, 15090, 15087>,
    <15083, 15087, 15091>    <15092, 15100, 15093>,
    <15092, 15093, 15097>    <15092, 15097, 15094>,
    <15092, 15094, 15098>    <15092, 15098, 15095>,
    <15092, 15095, 15099>    <15092, 15099, 15096>,
    <15092, 15096, 15100>    <15101, 15109, 15102>,
    <15101, 15102, 15106>    <15101, 15106, 15103>,
    <15101, 15103, 15107>    <15101, 15107, 15104>,
    <15101, 15104, 15108>    <15101, 15108, 15105>,
    <15101, 15105, 15109>    <15110, 15118, 15111>,
    <15110, 15111, 15115>    <15110, 15115, 15112>,
    <15110, 15112, 15116>    <15110, 15116, 15113>,
    <15110, 15113, 15117>    <15110, 15117, 15114>,
    <15110, 15114, 15118>    <15119, 15127, 15120>,
    <15119, 15120, 15124>    <15119, 15124, 15121>,
    <15119, 15121, 15125>    <15119, 15125, 15122>,
    <15119, 15122, 15126>    <15119, 15126, 15123>,
    <15119, 15123, 15127>    <15128, 15136, 15129>,
    <15128, 15129, 15133>    <15128, 15133, 15130>,
    <15128, 15130, 15134>    <15128, 15134, 15131>,
    <15128, 15131, 15135>    <15128, 15135, 15132>,
    <15128, 15132, 15136>    <15137, 15145, 15138>,
    <15137, 15138, 15142>    <15137, 15142, 15139>,
    <15137, 15139, 15143>    <15137, 15143, 15140>,
    <15137, 15140, 15144>    <15137, 15144, 15141>,
    <15137, 15141, 15145>    <15146, 15154, 15147>,
    <15146, 15147, 15151>    <15146, 15151, 15148>,
    <15146, 15148, 15152>    <15146, 15152, 15149>,
    <15146, 15149, 15153>    <15146, 15153, 15150>,
    <15146, 15150, 15154>    <15155, 15163, 15156>,
    <15155, 15156, 15160>    <15155, 15160, 15157>,
    <15155, 15157, 15161>    <15155, 15161, 15158>,
    <15155, 15158, 15162>    <15155, 15162, 15159>,
    <15155, 15159, 15163>    <15164, 15172, 15165>,
    <15164, 15165, 15169>    <15164, 15169, 15166>,
    <15164, 15166, 15170>    <15164, 15170, 15167>,
    <15164, 15167, 15171>    <15164, 15171, 15168>,
    <15164, 15168, 15172>    <15173, 15181, 15174>,
    <15173, 15174, 15178>    <15173, 15178, 15175>,
    <15173, 15175, 15179>    <15173, 15179, 15176>,
    <15173, 15176, 15180>    <15173, 15180, 15177>,
    <15173, 15177, 15181>    <15182, 15190, 15183>,
    <15182, 15183, 15187>    <15182, 15187, 15184>,
    <15182, 15184, 15188>    <15182, 15188, 15185>,
    <15182, 15185, 15189>    <15182, 15189, 15186>,
    <15182, 15186, 15190>    <15191, 15199, 15192>,
    <15191, 15192, 15196>    <15191, 15196, 15193>,
    <15191, 15193, 15197>    <15191, 15197, 15194>,
    <15191, 15194, 15198>    <15191, 15198, 15195>,
    <15191, 15195, 15199>    <15200, 15208, 15201>,
    <15200, 15201, 15205>    <15200, 15205, 15202>,
    <15200, 15202, 15206>    <15200, 15206, 15203>,
    <15200, 15203, 15207>    <15200, 15207, 15204>,
    <15200, 15204, 15208>    <15209, 15217, 15210>,
    <15209, 15210, 15214>    <15209, 15214, 15211>,
    <15209, 15211, 15215>    <15209, 15215, 15212>,
    <15209, 15212, 15216>    <15209, 15216, 15213>,
    <15209, 15213, 15217>    <15218, 15226, 15219>,
    <15218, 15219, 15223>    <15218, 15223, 15220>,
    <15218, 15220, 15224>    <15218, 15224, 15221>,
    <15218, 15221, 15225>    <15218, 15225, 15222>,
    <15218, 15222, 15226>    <15227, 15235, 15228>,
    <15227, 15228, 15232>    <15227, 15232, 15229>,
    <15227, 15229, 15233>    <15227, 15233, 15230>,
    <15227, 15230, 15234>    <15227, 15234, 15231>,
    <15227, 15231, 15235>    <15236, 15244, 15237>,
    <15236, 15237, 15241>    <15236, 15241, 15238>,
    <15236, 15238, 15242>    <15236, 15242, 15239>,
    <15236, 15239, 15243>    <15236, 15243, 15240>,
    <15236, 15240, 15244>    <15245, 15253, 15246>,
    <15245, 15246, 15250>    <15245, 15250, 15247>,
    <15245, 15247, 15251>    <15245, 15251, 15248>,
    <15245, 15248, 15252>    <15245, 15252, 15249>,
    <15245, 15249, 15253>    <15254, 15262, 15255>,
    <15254, 15255, 15259>    <15254, 15259, 15256>,
    <15254, 15256, 15260>    <15254, 15260, 15257>,
    <15254, 15257, 15261>    <15254, 15261, 15258>,
    <15254, 15258, 15262>    <15263, 15271, 15264>,
    <15263, 15264, 15268>    <15263, 15268, 15265>,
    <15263, 15265, 15269>    <15263, 15269, 15266>,
    <15263, 15266, 15270>    <15263, 15270, 15267>,
    <15263, 15267, 15271>    <15272, 15280, 15273>,
    <15272, 15273, 15277>    <15272, 15277, 15274>,
    <15272, 15274, 15278>    <15272, 15278, 15275>,
    <15272, 15275, 15279>    <15272, 15279, 15276>,
    <15272, 15276, 15280>    <15281, 15289, 15282>,
    <15281, 15282, 15286>    <15281, 15286, 15283>,
    <15281, 15283, 15287>    <15281, 15287, 15284>,
    <15281, 15284, 15288>    <15281, 15288, 15285>,
    <15281, 15285, 15289>    <15290, 15298, 15291>,
    <15290, 15291, 15295>    <15290, 15295, 15292>,
    <15290, 15292, 15296>    <15290, 15296, 15293>,
    <15290, 15293, 15297>    <15290, 15297, 15294>,
    <15290, 15294, 15298>    <15299, 15307, 15300>,
    <15299, 15300, 15304>    <15299, 15304, 15301>,
    <15299, 15301, 15305>    <15299, 15305, 15302>,
    <15299, 15302, 15306>    <15299, 15306, 15303>,
    <15299, 15303, 15307>    <15308, 15316, 15309>,
    <15308, 15309, 15313>    <15308, 15313, 15310>,
    <15308, 15310, 15314>    <15308, 15314, 15311>,
    <15308, 15311, 15315>    <15308, 15315, 15312>,
    <15308, 15312, 15316>    <15317, 15325, 15318>,
    <15317, 15318, 15322>    <15317, 15322, 15319>,
    <15317, 15319, 15323>    <15317, 15323, 15320>,
    <15317, 15320, 15324>    <15317, 15324, 15321>,
    <15317, 15321, 15325>    <15326, 15334, 15327>,
    <15326, 15327, 15331>    <15326, 15331, 15328>,
    <15326, 15328, 15332>    <15326, 15332, 15329>,
    <15326, 15329, 15333>    <15326, 15333, 15330>,
    <15326, 15330, 15334>    <15335, 15343, 15336>,
    <15335, 15336, 15340>    <15335, 15340, 15337>,
    <15335, 15337, 15341>    <15335, 15341, 15338>,
    <15335, 15338, 15342>    <15335, 15342, 15339>,
    <15335, 15339, 15343>    <15344, 15352, 15345>,
    <15344, 15345, 15349>    <15344, 15349, 15346>,
    <15344, 15346, 15350>    <15344, 15350, 15347>,
    <15344, 15347, 15351>    <15344, 15351, 15348>,
    <15344, 15348, 15352>    <15353, 15361, 15354>,
    <15353, 15354, 15358>    <15353, 15358, 15355>,
    <15353, 15355, 15359>    <15353, 15359, 15356>,
    <15353, 15356, 15360>    <15353, 15360, 15357>,
    <15353, 15357, 15361>    <15362, 15370, 15363>,
    <15362, 15363, 15367>    <15362, 15367, 15364>,
    <15362, 15364, 15368>    <15362, 15368, 15365>,
    <15362, 15365, 15369>    <15362, 15369, 15366>,
    <15362, 15366, 15370>    <15371, 15379, 15372>,
    <15371, 15372, 15376>    <15371, 15376, 15373>,
    <15371, 15373, 15377>    <15371, 15377, 15374>,
    <15371, 15374, 15378>    <15371, 15378, 15375>,
    <15371, 15375, 15379>    <15380, 15388, 15381>,
    <15380, 15381, 15385>    <15380, 15385, 15382>,
    <15380, 15382, 15386>    <15380, 15386, 15383>,
    <15380, 15383, 15387>    <15380, 15387, 15384>,
    <15380, 15384, 15388>    <15389, 15397, 15390>,
    <15389, 15390, 15394>    <15389, 15394, 15391>,
    <15389, 15391, 15395>    <15389, 15395, 15392>,
    <15389, 15392, 15396>    <15389, 15396, 15393>,
    <15389, 15393, 15397>    <15398, 15406, 15399>,
    <15398, 15399, 15403>    <15398, 15403, 15400>,
    <15398, 15400, 15404>    <15398, 15404, 15401>,
    <15398, 15401, 15405>    <15398, 15405, 15402>,
    <15398, 15402, 15406>    <15407, 15415, 15408>,
    <15407, 15408, 15412>    <15407, 15412, 15409>,
    <15407, 15409, 15413>    <15407, 15413, 15410>,
    <15407, 15410, 15414>    <15407, 15414, 15411>,
    <15407, 15411, 15415>    <15416, 15424, 15417>,
    <15416, 15417, 15421>    <15416, 15421, 15418>,
    <15416, 15418, 15422>    <15416, 15422, 15419>,
    <15416, 15419, 15423>    <15416, 15423, 15420>,
    <15416, 15420, 15424>    <15425, 15433, 15426>,
    <15425, 15426, 15430>    <15425, 15430, 15427>,
    <15425, 15427, 15431>    <15425, 15431, 15428>,
    <15425, 15428, 15432>    <15425, 15432, 15429>,
    <15425, 15429, 15433>    <15434, 15442, 15435>,
    <15434, 15435, 15439>    <15434, 15439, 15436>,
    <15434, 15436, 15440>    <15434, 15440, 15437>,
    <15434, 15437, 15441>    <15434, 15441, 15438>,
    <15434, 15438, 15442>    <15443, 15451, 15444>,
    <15443, 15444, 15448>    <15443, 15448, 15445>,
    <15443, 15445, 15449>    <15443, 15449, 15446>,
    <15443, 15446, 15450>    <15443, 15450, 15447>,
    <15443, 15447, 15451>    <15452, 15460, 15453>,
    <15452, 15453, 15457>    <15452, 15457, 15454>,
    <15452, 15454, 15458>    <15452, 15458, 15455>,
    <15452, 15455, 15459>    <15452, 15459, 15456>,
    <15452, 15456, 15460>    <15461, 15469, 15462>,
    <15461, 15462, 15466>    <15461, 15466, 15463>,
    <15461, 15463, 15467>    <15461, 15467, 15464>,
    <15461, 15464, 15468>    <15461, 15468, 15465>,
    <15461, 15465, 15469>    <15470, 15478, 15471>,
    <15470, 15471, 15475>    <15470, 15475, 15472>,
    <15470, 15472, 15476>    <15470, 15476, 15473>,
    <15470, 15473, 15477>    <15470, 15477, 15474>,
    <15470, 15474, 15478>    <15479, 15487, 15480>,
    <15479, 15480, 15484>    <15479, 15484, 15481>,
    <15479, 15481, 15485>    <15479, 15485, 15482>,
    <15479, 15482, 15486>    <15479, 15486, 15483>,
    <15479, 15483, 15487>    <15488, 15496, 15489>,
    <15488, 15489, 15493>    <15488, 15493, 15490>,
    <15488, 15490, 15494>    <15488, 15494, 15491>,
    <15488, 15491, 15495>    <15488, 15495, 15492>,
    <15488, 15492, 15496>    <15497, 15505, 15498>,
    <15497, 15498, 15502>    <15497, 15502, 15499>,
    <15497, 15499, 15503>    <15497, 15503, 15500>,
    <15497, 15500, 15504>    <15497, 15504, 15501>,
    <15497, 15501, 15505>    <15506, 15514, 15507>,
    <15506, 15507, 15511>    <15506, 15511, 15508>,
    <15506, 15508, 15512>    <15506, 15512, 15509>,
    <15506, 15509, 15513>    <15506, 15513, 15510>,
    <15506, 15510, 15514>    <15515, 15523, 15516>,
    <15515, 15516, 15520>    <15515, 15520, 15517>,
    <15515, 15517, 15521>    <15515, 15521, 15518>,
    <15515, 15518, 15522>    <15515, 15522, 15519>,
    <15515, 15519, 15523>    <15524, 15532, 15525>,
    <15524, 15525, 15529>    <15524, 15529, 15526>,
    <15524, 15526, 15530>    <15524, 15530, 15527>,
    <15524, 15527, 15531>    <15524, 15531, 15528>,
    <15524, 15528, 15532>    <15533, 15541, 15534>,
    <15533, 15534, 15538>    <15533, 15538, 15535>,
    <15533, 15535, 15539>    <15533, 15539, 15536>,
    <15533, 15536, 15540>    <15533, 15540, 15537>,
    <15533, 15537, 15541>    <15542, 15550, 15543>,
    <15542, 15543, 15547>    <15542, 15547, 15544>,
    <15542, 15544, 15548>    <15542, 15548, 15545>,
    <15542, 15545, 15549>    <15542, 15549, 15546>,
    <15542, 15546, 15550>    <15551, 15559, 15552>,
    <15551, 15552, 15556>    <15551, 15556, 15553>,
    <15551, 15553, 15557>    <15551, 15557, 15554>,
    <15551, 15554, 15558>    <15551, 15558, 15555>,
    <15551, 15555, 15559>    <15560, 15568, 15561>,
    <15560, 15561, 15565>    <15560, 15565, 15562>,
    <15560, 15562, 15566>    <15560, 15566, 15563>,
    <15560, 15563, 15567>    <15560, 15567, 15564>,
    <15560, 15564, 15568>    <15569, 15577, 15570>,
    <15569, 15570, 15574>    <15569, 15574, 15571>,
    <15569, 15571, 15575>    <15569, 15575, 15572>,
    <15569, 15572, 15576>    <15569, 15576, 15573>,
    <15569, 15573, 15577>    <15578, 15586, 15579>,
    <15578, 15579, 15583>    <15578, 15583, 15580>,
    <15578, 15580, 15584>    <15578, 15584, 15581>,
    <15578, 15581, 15585>    <15578, 15585, 15582>,
    <15578, 15582, 15586>    <15587, 15595, 15588>,
    <15587, 15588, 15592>    <15587, 15592, 15589>,
    <15587, 15589, 15593>    <15587, 15593, 15590>,
    <15587, 15590, 15594>    <15587, 15594, 15591>,
    <15587, 15591, 15595>    <15596, 15604, 15597>,
    <15596, 15597, 15601>    <15596, 15601, 15598>,
    <15596, 15598, 15602>    <15596, 15602, 15599>,
    <15596, 15599, 15603>    <15596, 15603, 15600>,
    <15596, 15600, 15604>    <15605, 15613, 15606>,
    <15605, 15606, 15610>    <15605, 15610, 15607>,
    <15605, 15607, 15611>    <15605, 15611, 15608>,
    <15605, 15608, 15612>    <15605, 15612, 15609>,
    <15605, 15609, 15613>    <15614, 15622, 15615>,
    <15614, 15615, 15619>    <15614, 15619, 15616>,
    <15614, 15616, 15620>    <15614, 15620, 15617>,
    <15614, 15617, 15621>    <15614, 15621, 15618>,
    <15614, 15618, 15622>    <15623, 15631, 15624>,
    <15623, 15624, 15628>    <15623, 15628, 15625>,
    <15623, 15625, 15629>    <15623, 15629, 15626>,
    <15623, 15626, 15630>    <15623, 15630, 15627>,
    <15623, 15627, 15631>    <15632, 15640, 15633>,
    <15632, 15633, 15637>    <15632, 15637, 15634>,
    <15632, 15634, 15638>    <15632, 15638, 15635>,
    <15632, 15635, 15639>    <15632, 15639, 15636>,
    <15632, 15636, 15640>    <15641, 15649, 15642>,
    <15641, 15642, 15646>    <15641, 15646, 15643>,
    <15641, 15643, 15647>    <15641, 15647, 15644>,
    <15641, 15644, 15648>    <15641, 15648, 15645>,
    <15641, 15645, 15649>    <15650, 15658, 15651>,
    <15650, 15651, 15655>    <15650, 15655, 15652>,
    <15650, 15652, 15656>    <15650, 15656, 15653>,
    <15650, 15653, 15657>    <15650, 15657, 15654>,
    <15650, 15654, 15658>    <15659, 15667, 15660>,
    <15659, 15660, 15664>    <15659, 15664, 15661>,
    <15659, 15661, 15665>    <15659, 15665, 15662>,
    <15659, 15662, 15666>    <15659, 15666, 15663>,
    <15659, 15663, 15667>    <15668, 15676, 15669>,
    <15668, 15669, 15673>    <15668, 15673, 15670>,
    <15668, 15670, 15674>    <15668, 15674, 15671>,
    <15668, 15671, 15675>    <15668, 15675, 15672>,
    <15668, 15672, 15676>    <15677, 15685, 15678>,
    <15677, 15678, 15682>    <15677, 15682, 15679>,
    <15677, 15679, 15683>    <15677, 15683, 15680>,
    <15677, 15680, 15684>    <15677, 15684, 15681>,
    <15677, 15681, 15685>    <15686, 15694, 15687>,
    <15686, 15687, 15691>    <15686, 15691, 15688>,
    <15686, 15688, 15692>    <15686, 15692, 15689>,
    <15686, 15689, 15693>    <15686, 15693, 15690>,
    <15686, 15690, 15694>    <15695, 15703, 15696>,
    <15695, 15696, 15700>    <15695, 15700, 15697>,
    <15695, 15697, 15701>    <15695, 15701, 15698>,
    <15695, 15698, 15702>    <15695, 15702, 15699>,
    <15695, 15699, 15703>    <15704, 15712, 15705>,
    <15704, 15705, 15709>    <15704, 15709, 15706>,
    <15704, 15706, 15710>    <15704, 15710, 15707>,
    <15704, 15707, 15711>    <15704, 15711, 15708>,
    <15704, 15708, 15712>    <15713, 15721, 15714>,
    <15713, 15714, 15718>    <15713, 15718, 15715>,
    <15713, 15715, 15719>    <15713, 15719, 15716>,
    <15713, 15716, 15720>    <15713, 15720, 15717>,
    <15713, 15717, 15721>    <15722, 15730, 15723>,
    <15722, 15723, 15727>    <15722, 15727, 15724>,
    <15722, 15724, 15728>    <15722, 15728, 15725>,
    <15722, 15725, 15729>    <15722, 15729, 15726>,
    <15722, 15726, 15730>    <15731, 15739, 15732>,
    <15731, 15732, 15736>    <15731, 15736, 15733>,
    <15731, 15733, 15737>    <15731, 15737, 15734>,
    <15731, 15734, 15738>    <15731, 15738, 15735>,
    <15731, 15735, 15739>    <15740, 15748, 15741>,
    <15740, 15741, 15745>    <15740, 15745, 15742>,
    <15740, 15742, 15746>    <15740, 15746, 15743>,
    <15740, 15743, 15747>    <15740, 15747, 15744>,
    <15740, 15744, 15748>    <15749, 15757, 15750>,
    <15749, 15750, 15754>    <15749, 15754, 15751>,
    <15749, 15751, 15755>    <15749, 15755, 15752>,
    <15749, 15752, 15756>    <15749, 15756, 15753>,
    <15749, 15753, 15757>    <15758, 15766, 15759>,
    <15758, 15759, 15763>    <15758, 15763, 15760>,
    <15758, 15760, 15764>    <15758, 15764, 15761>,
    <15758, 15761, 15765>    <15758, 15765, 15762>,
    <15758, 15762, 15766>    <15767, 15775, 15768>,
    <15767, 15768, 15772>    <15767, 15772, 15769>,
    <15767, 15769, 15773>    <15767, 15773, 15770>,
    <15767, 15770, 15774>    <15767, 15774, 15771>,
    <15767, 15771, 15775>    <15776, 15784, 15777>,
    <15776, 15777, 15781>    <15776, 15781, 15778>,
    <15776, 15778, 15782>    <15776, 15782, 15779>,
    <15776, 15779, 15783>    <15776, 15783, 15780>,
    <15776, 15780, 15784>    <15785, 15793, 15786>,
    <15785, 15786, 15790>    <15785, 15790, 15787>,
    <15785, 15787, 15791>    <15785, 15791, 15788>,
    <15785, 15788, 15792>    <15785, 15792, 15789>,
    <15785, 15789, 15793>    <15794, 15802, 15795>,
    <15794, 15795, 15799>    <15794, 15799, 15796>,
    <15794, 15796, 15800>    <15794, 15800, 15797>,
    <15794, 15797, 15801>    <15794, 15801, 15798>,
    <15794, 15798, 15802>    <15803, 15811, 15804>,
    <15803, 15804, 15808>    <15803, 15808, 15805>,
    <15803, 15805, 15809>    <15803, 15809, 15806>,
    <15803, 15806, 15810>    <15803, 15810, 15807>,
    <15803, 15807, 15811>    <15812, 15820, 15813>,
    <15812, 15813, 15817>    <15812, 15817, 15814>,
    <15812, 15814, 15818>    <15812, 15818, 15815>,
    <15812, 15815, 15819>    <15812, 15819, 15816>,
    <15812, 15816, 15820>    <15821, 15829, 15822>,
    <15821, 15822, 15826>    <15821, 15826, 15823>,
    <15821, 15823, 15827>    <15821, 15827, 15824>,
    <15821, 15824, 15828>    <15821, 15828, 15825>,
    <15821, 15825, 15829>    <15830, 15838, 15831>,
    <15830, 15831, 15835>    <15830, 15835, 15832>,
    <15830, 15832, 15836>    <15830, 15836, 15833>,
    <15830, 15833, 15837>    <15830, 15837, 15834>,
    <15830, 15834, 15838>    <15839, 15847, 15840>,
    <15839, 15840, 15844>    <15839, 15844, 15841>,
    <15839, 15841, 15845>    <15839, 15845, 15842>,
    <15839, 15842, 15846>    <15839, 15846, 15843>,
    <15839, 15843, 15847>    <15848, 15856, 15849>,
    <15848, 15849, 15853>    <15848, 15853, 15850>,
    <15848, 15850, 15854>    <15848, 15854, 15851>,
    <15848, 15851, 15855>    <15848, 15855, 15852>,
    <15848, 15852, 15856>    <15857, 15865, 15858>,
    <15857, 15858, 15862>    <15857, 15862, 15859>,
    <15857, 15859, 15863>    <15857, 15863, 15860>,
    <15857, 15860, 15864>    <15857, 15864, 15861>,
    <15857, 15861, 15865>    <15866, 15874, 15867>,
    <15866, 15867, 15871>    <15866, 15871, 15868>,
    <15866, 15868, 15872>    <15866, 15872, 15869>,
    <15866, 15869, 15873>    <15866, 15873, 15870>,
    <15866, 15870, 15874>    <15875, 15883, 15876>,
    <15875, 15876, 15880>    <15875, 15880, 15877>,
    <15875, 15877, 15881>    <15875, 15881, 15878>,
    <15875, 15878, 15882>    <15875, 15882, 15879>,
    <15875, 15879, 15883>    <15884, 15892, 15885>,
    <15884, 15885, 15889>    <15884, 15889, 15886>,
    <15884, 15886, 15890>    <15884, 15890, 15887>,
    <15884, 15887, 15891>    <15884, 15891, 15888>,
    <15884, 15888, 15892>    <15893, 15901, 15894>,
    <15893, 15894, 15898>    <15893, 15898, 15895>,
    <15893, 15895, 15899>    <15893, 15899, 15896>,
    <15893, 15896, 15900>    <15893, 15900, 15897>,
    <15893, 15897, 15901>    <15902, 15910, 15903>,
    <15902, 15903, 15907>    <15902, 15907, 15904>,
    <15902, 15904, 15908>    <15902, 15908, 15905>,
    <15902, 15905, 15909>    <15902, 15909, 15906>,
    <15902, 15906, 15910>    <15911, 15919, 15912>,
    <15911, 15912, 15916>    <15911, 15916, 15913>,
    <15911, 15913, 15917>    <15911, 15917, 15914>,
    <15911, 15914, 15918>    <15911, 15918, 15915>,
    <15911, 15915, 15919>    <15920, 15928, 15921>,
    <15920, 15921, 15925>    <15920, 15925, 15922>,
    <15920, 15922, 15926>    <15920, 15926, 15923>,
    <15920, 15923, 15927>    <15920, 15927, 15924>,
    <15920, 15924, 15928>    <15929, 15937, 15930>,
    <15929, 15930, 15934>    <15929, 15934, 15931>,
    <15929, 15931, 15935>    <15929, 15935, 15932>,
    <15929, 15932, 15936>    <15929, 15936, 15933>,
    <15929, 15933, 15937>    <15938, 15946, 15939>,
    <15938, 15939, 15943>    <15938, 15943, 15940>,
    <15938, 15940, 15944>    <15938, 15944, 15941>,
    <15938, 15941, 15945>    <15938, 15945, 15942>,
    <15938, 15942, 15946>    <15947, 15955, 15948>,
    <15947, 15948, 15952>    <15947, 15952, 15949>,
    <15947, 15949, 15953>    <15947, 15953, 15950>,
    <15947, 15950, 15954>    <15947, 15954, 15951>,
    <15947, 15951, 15955>    <15956, 15964, 15957>,
    <15956, 15957, 15961>    <15956, 15961, 15958>,
    <15956, 15958, 15962>    <15956, 15962, 15959>,
    <15956, 15959, 15963>    <15956, 15963, 15960>,
    <15956, 15960, 15964>    <15965, 15973, 15966>,
    <15965, 15966, 15970>    <15965, 15970, 15967>,
    <15965, 15967, 15971>    <15965, 15971, 15968>,
    <15965, 15968, 15972>    <15965, 15972, 15969>,
    <15965, 15969, 15973>    <15974, 15982, 15975>,
    <15974, 15975, 15979>    <15974, 15979, 15976>,
    <15974, 15976, 15980>    <15974, 15980, 15977>,
    <15974, 15977, 15981>    <15974, 15981, 15978>,
    <15974, 15978, 15982>    <15983, 15991, 15984>,
    <15983, 15984, 15988>    <15983, 15988, 15985>,
    <15983, 15985, 15989>    <15983, 15989, 15986>,
    <15983, 15986, 15990>    <15983, 15990, 15987>,
    <15983, 15987, 15991>    <15992, 16000, 15993>,
    <15992, 15993, 15997>    <15992, 15997, 15994>,
    <15992, 15994, 15998>    <15992, 15998, 15995>,
    <15992, 15995, 15999>    <15992, 15999, 15996>,
    <15992, 15996, 16000>    <16001, 16009, 16002>,
    <16001, 16002, 16006>    <16001, 16006, 16003>,
    <16001, 16003, 16007>    <16001, 16007, 16004>,
    <16001, 16004, 16008>    <16001, 16008, 16005>,
    <16001, 16005, 16009>    <16010, 16018, 16011>,
    <16010, 16011, 16015>    <16010, 16015, 16012>,
    <16010, 16012, 16016>    <16010, 16016, 16013>,
    <16010, 16013, 16017>    <16010, 16017, 16014>,
    <16010, 16014, 16018>    <16019, 16027, 16020>,
    <16019, 16020, 16024>    <16019, 16024, 16021>,
    <16019, 16021, 16025>    <16019, 16025, 16022>,
    <16019, 16022, 16026>    <16019, 16026, 16023>,
    <16019, 16023, 16027>    <16028, 16036, 16029>,
    <16028, 16029, 16033>    <16028, 16033, 16030>,
    <16028, 16030, 16034>    <16028, 16034, 16031>,
    <16028, 16031, 16035>    <16028, 16035, 16032>,
    <16028, 16032, 16036>    <16037, 16045, 16038>,
    <16037, 16038, 16042>    <16037, 16042, 16039>,
    <16037, 16039, 16043>    <16037, 16043, 16040>,
    <16037, 16040, 16044>    <16037, 16044, 16041>,
    <16037, 16041, 16045>    <16046, 16054, 16047>,
    <16046, 16047, 16051>    <16046, 16051, 16048>,
    <16046, 16048, 16052>    <16046, 16052, 16049>,
    <16046, 16049, 16053>    <16046, 16053, 16050>,
    <16046, 16050, 16054>    <16055, 16063, 16056>,
    <16055, 16056, 16060>    <16055, 16060, 16057>,
    <16055, 16057, 16061>    <16055, 16061, 16058>,
    <16055, 16058, 16062>    <16055, 16062, 16059>,
    <16055, 16059, 16063>    <16064, 16072, 16065>,
    <16064, 16065, 16069>    <16064, 16069, 16066>,
    <16064, 16066, 16070>    <16064, 16070, 16067>,
    <16064, 16067, 16071>    <16064, 16071, 16068>,
    <16064, 16068, 16072>    <16073, 16081, 16074>,
    <16073, 16074, 16078>    <16073, 16078, 16075>,
    <16073, 16075, 16079>    <16073, 16079, 16076>,
    <16073, 16076, 16080>    <16073, 16080, 16077>,
    <16073, 16077, 16081>    <16082, 16090, 16083>,
    <16082, 16083, 16087>    <16082, 16087, 16084>,
    <16082, 16084, 16088>    <16082, 16088, 16085>,
    <16082, 16085, 16089>    <16082, 16089, 16086>,
    <16082, 16086, 16090>    <16091, 16099, 16092>,
    <16091, 16092, 16096>    <16091, 16096, 16093>,
    <16091, 16093, 16097>    <16091, 16097, 16094>,
    <16091, 16094, 16098>    <16091, 16098, 16095>,
    <16091, 16095, 16099>    <16100, 16108, 16101>,
    <16100, 16101, 16105>    <16100, 16105, 16102>,
    <16100, 16102, 16106>    <16100, 16106, 16103>,
    <16100, 16103, 16107>    <16100, 16107, 16104>,
    <16100, 16104, 16108>    <16109, 16117, 16110>,
    <16109, 16110, 16114>    <16109, 16114, 16111>,
    <16109, 16111, 16115>    <16109, 16115, 16112>,
    <16109, 16112, 16116>    <16109, 16116, 16113>,
    <16109, 16113, 16117>    <16118, 16126, 16119>,
    <16118, 16119, 16123>    <16118, 16123, 16120>,
    <16118, 16120, 16124>    <16118, 16124, 16121>,
    <16118, 16121, 16125>    <16118, 16125, 16122>,
    <16118, 16122, 16126>    <16127, 16135, 16128>,
    <16127, 16128, 16132>    <16127, 16132, 16129>,
    <16127, 16129, 16133>    <16127, 16133, 16130>,
    <16127, 16130, 16134>    <16127, 16134, 16131>,
    <16127, 16131, 16135>    <16136, 16144, 16137>,
    <16136, 16137, 16141>    <16136, 16141, 16138>,
    <16136, 16138, 16142>    <16136, 16142, 16139>,
    <16136, 16139, 16143>    <16136, 16143, 16140>,
    <16136, 16140, 16144>    <16145, 16153, 16146>,
    <16145, 16146, 16150>    <16145, 16150, 16147>,
    <16145, 16147, 16151>    <16145, 16151, 16148>,
    <16145, 16148, 16152>    <16145, 16152, 16149>,
    <16145, 16149, 16153>    <16154, 16162, 16155>,
    <16154, 16155, 16159>    <16154, 16159, 16156>,
    <16154, 16156, 16160>    <16154, 16160, 16157>,
    <16154, 16157, 16161>    <16154, 16161, 16158>,
    <16154, 16158, 16162>    <16163, 16171, 16164>,
    <16163, 16164, 16168>    <16163, 16168, 16165>,
    <16163, 16165, 16169>    <16163, 16169, 16166>,
    <16163, 16166, 16170>    <16163, 16170, 16167>,
    <16163, 16167, 16171>    <16172, 16180, 16173>,
    <16172, 16173, 16177>    <16172, 16177, 16174>,
    <16172, 16174, 16178>    <16172, 16178, 16175>,
    <16172, 16175, 16179>    <16172, 16179, 16176>,
    <16172, 16176, 16180>    <16181, 16189, 16182>,
    <16181, 16182, 16186>    <16181, 16186, 16183>,
    <16181, 16183, 16187>    <16181, 16187, 16184>,
    <16181, 16184, 16188>    <16181, 16188, 16185>,
    <16181, 16185, 16189>    <16190, 16198, 16191>,
    <16190, 16191, 16195>    <16190, 16195, 16192>,
    <16190, 16192, 16196>    <16190, 16196, 16193>,
    <16190, 16193, 16197>    <16190, 16197, 16194>,
    <16190, 16194, 16198>    <16199, 16207, 16200>,
    <16199, 16200, 16204>    <16199, 16204, 16201>,
    <16199, 16201, 16205>    <16199, 16205, 16202>,
    <16199, 16202, 16206>    <16199, 16206, 16203>,
    <16199, 16203, 16207>    <16208, 16216, 16209>,
    <16208, 16209, 16213>    <16208, 16213, 16210>,
    <16208, 16210, 16214>    <16208, 16214, 16211>,
    <16208, 16211, 16215>    <16208, 16215, 16212>,
    <16208, 16212, 16216>    <16217, 16225, 16218>,
    <16217, 16218, 16222>    <16217, 16222, 16219>,
    <16217, 16219, 16223>    <16217, 16223, 16220>,
    <16217, 16220, 16224>    <16217, 16224, 16221>,
    <16217, 16221, 16225>    <16226, 16234, 16227>,
    <16226, 16227, 16231>    <16226, 16231, 16228>,
    <16226, 16228, 16232>    <16226, 16232, 16229>,
    <16226, 16229, 16233>    <16226, 16233, 16230>,
    <16226, 16230, 16234>    <16235, 16243, 16236>,
    <16235, 16236, 16240>    <16235, 16240, 16237>,
    <16235, 16237, 16241>    <16235, 16241, 16238>,
    <16235, 16238, 16242>    <16235, 16242, 16239>,
    <16235, 16239, 16243>    <16244, 16252, 16245>,
    <16244, 16245, 16249>    <16244, 16249, 16246>,
    <16244, 16246, 16250>    <16244, 16250, 16247>,
    <16244, 16247, 16251>    <16244, 16251, 16248>,
    <16244, 16248, 16252>    <16253, 16261, 16254>,
    <16253, 16254, 16258>    <16253, 16258, 16255>,
    <16253, 16255, 16259>    <16253, 16259, 16256>,
    <16253, 16256, 16260>    <16253, 16260, 16257>,
    <16253, 16257, 16261>    <16262, 16270, 16263>,
    <16262, 16263, 16267>    <16262, 16267, 16264>,
    <16262, 16264, 16268>    <16262, 16268, 16265>,
    <16262, 16265, 16269>    <16262, 16269, 16266>,
    <16262, 16266, 16270>    <16271, 16279, 16272>,
    <16271, 16272, 16276>    <16271, 16276, 16273>,
    <16271, 16273, 16277>    <16271, 16277, 16274>,
    <16271, 16274, 16278>    <16271, 16278, 16275>,
    <16271, 16275, 16279>    <16280, 16288, 16281>,
    <16280, 16281, 16285>    <16280, 16285, 16282>,
    <16280, 16282, 16286>    <16280, 16286, 16283>,
    <16280, 16283, 16287>    <16280, 16287, 16284>,
    <16280, 16284, 16288>    <16289, 16297, 16290>,
    <16289, 16290, 16294>    <16289, 16294, 16291>,
    <16289, 16291, 16295>    <16289, 16295, 16292>,
    <16289, 16292, 16296>    <16289, 16296, 16293>,
    <16289, 16293, 16297>    <16298, 16306, 16299>,
    <16298, 16299, 16303>    <16298, 16303, 16300>,
    <16298, 16300, 16304>    <16298, 16304, 16301>,
    <16298, 16301, 16305>    <16298, 16305, 16302>,
    <16298, 16302, 16306>    <16307, 16315, 16308>,
    <16307, 16308, 16312>    <16307, 16312, 16309>,
    <16307, 16309, 16313>    <16307, 16313, 16310>,
    <16307, 16310, 16314>    <16307, 16314, 16311>,
    <16307, 16311, 16315>    <16316, 16324, 16317>,
    <16316, 16317, 16321>    <16316, 16321, 16318>,
    <16316, 16318, 16322>    <16316, 16322, 16319>,
    <16316, 16319, 16323>    <16316, 16323, 16320>,
    <16316, 16320, 16324>    <16325, 16333, 16326>,
    <16325, 16326, 16330>    <16325, 16330, 16327>,
    <16325, 16327, 16331>    <16325, 16331, 16328>,
    <16325, 16328, 16332>    <16325, 16332, 16329>,
    <16325, 16329, 16333>    <16334, 16342, 16335>,
    <16334, 16335, 16339>    <16334, 16339, 16336>,
    <16334, 16336, 16340>    <16334, 16340, 16337>,
    <16334, 16337, 16341>    <16334, 16341, 16338>,
    <16334, 16338, 16342>    <16343, 16351, 16344>,
    <16343, 16344, 16348>    <16343, 16348, 16345>,
    <16343, 16345, 16349>    <16343, 16349, 16346>,
    <16343, 16346, 16350>    <16343, 16350, 16347>,
    <16343, 16347, 16351>    <16352, 16360, 16353>,
    <16352, 16353, 16357>    <16352, 16357, 16354>,
    <16352, 16354, 16358>    <16352, 16358, 16355>,
    <16352, 16355, 16359>    <16352, 16359, 16356>,
    <16352, 16356, 16360>    <16361, 16369, 16362>,
    <16361, 16362, 16366>    <16361, 16366, 16363>,
    <16361, 16363, 16367>    <16361, 16367, 16364>,
    <16361, 16364, 16368>    <16361, 16368, 16365>,
    <16361, 16365, 16369>    <16370, 16378, 16371>,
    <16370, 16371, 16375>    <16370, 16375, 16372>,
    <16370, 16372, 16376>    <16370, 16376, 16373>,
    <16370, 16373, 16377>    <16370, 16377, 16374>,
    <16370, 16374, 16378>    <16379, 16387, 16380>,
    <16379, 16380, 16384>    <16379, 16384, 16381>,
    <16379, 16381, 16385>    <16379, 16385, 16382>,
    <16379, 16382, 16386>    <16379, 16386, 16383>,
    <16379, 16383, 16387>    <16388, 16396, 16389>,
    <16388, 16389, 16393>    <16388, 16393, 16390>,
    <16388, 16390, 16394>    <16388, 16394, 16391>,
    <16388, 16391, 16395>    <16388, 16395, 16392>,
    <16388, 16392, 16396>    <16397, 16405, 16398>,
    <16397, 16398, 16402>    <16397, 16402, 16399>,
    <16397, 16399, 16403>    <16397, 16403, 16400>,
    <16397, 16400, 16404>    <16397, 16404, 16401>,
    <16397, 16401, 16405>    <16406, 16414, 16407>,
    <16406, 16407, 16411>    <16406, 16411, 16408>,
    <16406, 16408, 16412>    <16406, 16412, 16409>,
    <16406, 16409, 16413>    <16406, 16413, 16410>,
    <16406, 16410, 16414>    <16415, 16423, 16416>,
    <16415, 16416, 16420>    <16415, 16420, 16417>,
    <16415, 16417, 16421>    <16415, 16421, 16418>,
    <16415, 16418, 16422>    <16415, 16422, 16419>,
    <16415, 16419, 16423>    <16424, 16432, 16425>,
    <16424, 16425, 16429>    <16424, 16429, 16426>,
    <16424, 16426, 16430>    <16424, 16430, 16427>,
    <16424, 16427, 16431>    <16424, 16431, 16428>,
    <16424, 16428, 16432>    <16433, 16441, 16434>,
    <16433, 16434, 16438>    <16433, 16438, 16435>,
    <16433, 16435, 16439>    <16433, 16439, 16436>,
    <16433, 16436, 16440>    <16433, 16440, 16437>,
    <16433, 16437, 16441>    <16442, 16450, 16443>,
    <16442, 16443, 16447>    <16442, 16447, 16444>,
    <16442, 16444, 16448>    <16442, 16448, 16445>,
    <16442, 16445, 16449>    <16442, 16449, 16446>,
    <16442, 16446, 16450>    <16451, 16459, 16452>,
    <16451, 16452, 16456>    <16451, 16456, 16453>,
    <16451, 16453, 16457>    <16451, 16457, 16454>,
    <16451, 16454, 16458>    <16451, 16458, 16455>,
    <16451, 16455, 16459>    <16460, 16468, 16461>,
    <16460, 16461, 16465>    <16460, 16465, 16462>,
    <16460, 16462, 16466>    <16460, 16466, 16463>,
    <16460, 16463, 16467>    <16460, 16467, 16464>,
    <16460, 16464, 16468>    <16469, 16477, 16470>,
    <16469, 16470, 16474>    <16469, 16474, 16471>,
    <16469, 16471, 16475>    <16469, 16475, 16472>,
    <16469, 16472, 16476>    <16469, 16476, 16473>,
    <16469, 16473, 16477>    <16478, 16486, 16479>,
    <16478, 16479, 16483>    <16478, 16483, 16480>,
    <16478, 16480, 16484>    <16478, 16484, 16481>,
    <16478, 16481, 16485>    <16478, 16485, 16482>,
    <16478, 16482, 16486>    <16487, 16495, 16488>,
    <16487, 16488, 16492>    <16487, 16492, 16489>,
    <16487, 16489, 16493>    <16487, 16493, 16490>,
    <16487, 16490, 16494>    <16487, 16494, 16491>,
    <16487, 16491, 16495>    <16496, 16504, 16497>,
    <16496, 16497, 16501>    <16496, 16501, 16498>,
    <16496, 16498, 16502>    <16496, 16502, 16499>,
    <16496, 16499, 16503>    <16496, 16503, 16500>,
    <16496, 16500, 16504>    <16505, 16513, 16506>,
    <16505, 16506, 16510>    <16505, 16510, 16507>,
    <16505, 16507, 16511>    <16505, 16511, 16508>,
    <16505, 16508, 16512>    <16505, 16512, 16509>,
    <16505, 16509, 16513>    <16514, 16522, 16515>,
    <16514, 16515, 16519>    <16514, 16519, 16516>,
    <16514, 16516, 16520>    <16514, 16520, 16517>,
    <16514, 16517, 16521>    <16514, 16521, 16518>,
    <16514, 16518, 16522>    <16523, 16531, 16524>,
    <16523, 16524, 16528>    <16523, 16528, 16525>,
    <16523, 16525, 16529>    <16523, 16529, 16526>,
    <16523, 16526, 16530>    <16523, 16530, 16527>,
    <16523, 16527, 16531>    <16532, 16540, 16533>,
    <16532, 16533, 16537>    <16532, 16537, 16534>,
    <16532, 16534, 16538>    <16532, 16538, 16535>,
    <16532, 16535, 16539>    <16532, 16539, 16536>,
    <16532, 16536, 16540>    <16541, 16549, 16542>,
    <16541, 16542, 16546>    <16541, 16546, 16543>,
    <16541, 16543, 16547>    <16541, 16547, 16544>,
    <16541, 16544, 16548>    <16541, 16548, 16545>,
    <16541, 16545, 16549>    <16550, 16558, 16551>,
    <16550, 16551, 16555>    <16550, 16555, 16552>,
    <16550, 16552, 16556>    <16550, 16556, 16553>,
    <16550, 16553, 16557>    <16550, 16557, 16554>,
    <16550, 16554, 16558>    <16559, 16567, 16560>,
    <16559, 16560, 16564>    <16559, 16564, 16561>,
    <16559, 16561, 16565>    <16559, 16565, 16562>,
    <16559, 16562, 16566>    <16559, 16566, 16563>,
    <16559, 16563, 16567>    <16568, 16576, 16569>,
    <16568, 16569, 16573>    <16568, 16573, 16570>,
    <16568, 16570, 16574>    <16568, 16574, 16571>,
    <16568, 16571, 16575>    <16568, 16575, 16572>,
    <16568, 16572, 16576>    <16577, 16585, 16578>,
    <16577, 16578, 16582>    <16577, 16582, 16579>,
    <16577, 16579, 16583>    <16577, 16583, 16580>,
    <16577, 16580, 16584>    <16577, 16584, 16581>,
    <16577, 16581, 16585>    <16586, 16594, 16587>,
    <16586, 16587, 16591>    <16586, 16591, 16588>,
    <16586, 16588, 16592>    <16586, 16592, 16589>,
    <16586, 16589, 16593>    <16586, 16593, 16590>,
    <16586, 16590, 16594>    <16595, 16603, 16596>,
    <16595, 16596, 16600>    <16595, 16600, 16597>,
    <16595, 16597, 16601>    <16595, 16601, 16598>,
    <16595, 16598, 16602>    <16595, 16602, 16599>,
    <16595, 16599, 16603>    <16604, 16612, 16605>,
    <16604, 16605, 16609>    <16604, 16609, 16606>,
    <16604, 16606, 16610>    <16604, 16610, 16607>,
    <16604, 16607, 16611>    <16604, 16611, 16608>,
    <16604, 16608, 16612>    <16613, 16621, 16614>,
    <16613, 16614, 16618>    <16613, 16618, 16615>,
    <16613, 16615, 16619>    <16613, 16619, 16616>,
    <16613, 16616, 16620>    <16613, 16620, 16617>,
    <16613, 16617, 16621>    <16622, 16630, 16623>,
    <16622, 16623, 16627>    <16622, 16627, 16624>,
    <16622, 16624, 16628>    <16622, 16628, 16625>,
    <16622, 16625, 16629>    <16622, 16629, 16626>,
    <16622, 16626, 16630>    <16631, 16639, 16632>,
    <16631, 16632, 16636>    <16631, 16636, 16633>,
    <16631, 16633, 16637>    <16631, 16637, 16634>,
    <16631, 16634, 16638>    <16631, 16638, 16635>,
    <16631, 16635, 16639>    <16640, 16648, 16641>,
    <16640, 16641, 16645>    <16640, 16645, 16642>,
    <16640, 16642, 16646>    <16640, 16646, 16643>,
    <16640, 16643, 16647>    <16640, 16647, 16644>,
    <16640, 16644, 16648>    <16649, 16657, 16650>,
    <16649, 16650, 16654>    <16649, 16654, 16651>,
    <16649, 16651, 16655>    <16649, 16655, 16652>,
    <16649, 16652, 16656>    <16649, 16656, 16653>,
    <16649, 16653, 16657>    <16658, 16666, 16659>,
    <16658, 16659, 16663>    <16658, 16663, 16660>,
    <16658, 16660, 16664>    <16658, 16664, 16661>,
    <16658, 16661, 16665>    <16658, 16665, 16662>,
    <16658, 16662, 16666>    <16667, 16675, 16668>,
    <16667, 16668, 16672>    <16667, 16672, 16669>,
    <16667, 16669, 16673>    <16667, 16673, 16670>,
    <16667, 16670, 16674>    <16667, 16674, 16671>,
    <16667, 16671, 16675>    <16676, 16684, 16677>,
    <16676, 16677, 16681>    <16676, 16681, 16678>,
    <16676, 16678, 16682>    <16676, 16682, 16679>,
    <16676, 16679, 16683>    <16676, 16683, 16680>,
    <16676, 16680, 16684>    <16685, 16693, 16686>,
    <16685, 16686, 16690>    <16685, 16690, 16687>,
    <16685, 16687, 16691>    <16685, 16691, 16688>,
    <16685, 16688, 16692>    <16685, 16692, 16689>,
    <16685, 16689, 16693>    <16694, 16702, 16695>,
    <16694, 16695, 16699>    <16694, 16699, 16696>,
    <16694, 16696, 16700>    <16694, 16700, 16697>,
    <16694, 16697, 16701>    <16694, 16701, 16698>,
    <16694, 16698, 16702>    <16703, 16711, 16704>,
    <16703, 16704, 16708>    <16703, 16708, 16705>,
    <16703, 16705, 16709>    <16703, 16709, 16706>,
    <16703, 16706, 16710>    <16703, 16710, 16707>,
    <16703, 16707, 16711>    <16712, 16720, 16713>,
    <16712, 16713, 16717>    <16712, 16717, 16714>,
    <16712, 16714, 16718>    <16712, 16718, 16715>,
    <16712, 16715, 16719>    <16712, 16719, 16716>,
    <16712, 16716, 16720>    <16721, 16729, 16722>,
    <16721, 16722, 16726>    <16721, 16726, 16723>,
    <16721, 16723, 16727>    <16721, 16727, 16724>,
    <16721, 16724, 16728>    <16721, 16728, 16725>,
    <16721, 16725, 16729>    <16730, 16738, 16731>,
    <16730, 16731, 16735>    <16730, 16735, 16732>,
    <16730, 16732, 16736>    <16730, 16736, 16733>,
    <16730, 16733, 16737>    <16730, 16737, 16734>,
    <16730, 16734, 16738>    <16739, 16747, 16740>,
    <16739, 16740, 16744>    <16739, 16744, 16741>,
    <16739, 16741, 16745>    <16739, 16745, 16742>,
    <16739, 16742, 16746>    <16739, 16746, 16743>,
    <16739, 16743, 16747>    <16748, 16756, 16749>,
    <16748, 16749, 16753>    <16748, 16753, 16750>,
    <16748, 16750, 16754>    <16748, 16754, 16751>,
    <16748, 16751, 16755>    <16748, 16755, 16752>,
    <16748, 16752, 16756>    <16757, 16765, 16758>,
    <16757, 16758, 16762>    <16757, 16762, 16759>,
    <16757, 16759, 16763>    <16757, 16763, 16760>,
    <16757, 16760, 16764>    <16757, 16764, 16761>,
    <16757, 16761, 16765>    <16766, 16774, 16767>,
    <16766, 16767, 16771>    <16766, 16771, 16768>,
    <16766, 16768, 16772>    <16766, 16772, 16769>,
    <16766, 16769, 16773>    <16766, 16773, 16770>,
    <16766, 16770, 16774>    <16775, 16783, 16776>,
    <16775, 16776, 16780>    <16775, 16780, 16777>,
    <16775, 16777, 16781>    <16775, 16781, 16778>,
    <16775, 16778, 16782>    <16775, 16782, 16779>,
    <16775, 16779, 16783>    <16784, 16792, 16785>,
    <16784, 16785, 16789>    <16784, 16789, 16786>,
    <16784, 16786, 16790>    <16784, 16790, 16787>,
    <16784, 16787, 16791>    <16784, 16791, 16788>,
    <16784, 16788, 16792>    <16793, 16801, 16794>,
    <16793, 16794, 16798>    <16793, 16798, 16795>,
    <16793, 16795, 16799>    <16793, 16799, 16796>,
    <16793, 16796, 16800>    <16793, 16800, 16797>,
    <16793, 16797, 16801>    <16802, 16810, 16803>,
    <16802, 16803, 16807>    <16802, 16807, 16804>,
    <16802, 16804, 16808>    <16802, 16808, 16805>,
    <16802, 16805, 16809>    <16802, 16809, 16806>,
    <16802, 16806, 16810>    <16811, 16819, 16812>,
    <16811, 16812, 16816>    <16811, 16816, 16813>,
    <16811, 16813, 16817>    <16811, 16817, 16814>,
    <16811, 16814, 16818>    <16811, 16818, 16815>,
    <16811, 16815, 16819>    <16820, 16828, 16821>,
    <16820, 16821, 16825>    <16820, 16825, 16822>,
    <16820, 16822, 16826>    <16820, 16826, 16823>,
    <16820, 16823, 16827>    <16820, 16827, 16824>,
    <16820, 16824, 16828>    <16829, 16837, 16830>,
    <16829, 16830, 16834>    <16829, 16834, 16831>,
    <16829, 16831, 16835>    <16829, 16835, 16832>,
    <16829, 16832, 16836>    <16829, 16836, 16833>,
    <16829, 16833, 16837>    <16838, 16846, 16839>,
    <16838, 16839, 16843>    <16838, 16843, 16840>,
    <16838, 16840, 16844>    <16838, 16844, 16841>,
    <16838, 16841, 16845>    <16838, 16845, 16842>,
    <16838, 16842, 16846>    <16847, 16855, 16848>,
    <16847, 16848, 16852>    <16847, 16852, 16849>,
    <16847, 16849, 16853>    <16847, 16853, 16850>,
    <16847, 16850, 16854>    <16847, 16854, 16851>,
    <16847, 16851, 16855>    <16856, 16864, 16857>,
    <16856, 16857, 16861>    <16856, 16861, 16858>,
    <16856, 16858, 16862>    <16856, 16862, 16859>,
    <16856, 16859, 16863>    <16856, 16863, 16860>,
    <16856, 16860, 16864>    <16865, 16873, 16866>,
    <16865, 16866, 16870>    <16865, 16870, 16867>,
    <16865, 16867, 16871>    <16865, 16871, 16868>,
    <16865, 16868, 16872>    <16865, 16872, 16869>,
    <16865, 16869, 16873>    <16874, 16882, 16875>,
    <16874, 16875, 16879>    <16874, 16879, 16876>,
    <16874, 16876, 16880>    <16874, 16880, 16877>,
    <16874, 16877, 16881>    <16874, 16881, 16878>,
    <16874, 16878, 16882>    <16883, 16891, 16884>,
    <16883, 16884, 16888>    <16883, 16888, 16885>,
    <16883, 16885, 16889>    <16883, 16889, 16886>,
    <16883, 16886, 16890>    <16883, 16890, 16887>,
    <16883, 16887, 16891>    <16892, 16900, 16893>,
    <16892, 16893, 16897>    <16892, 16897, 16894>,
    <16892, 16894, 16898>    <16892, 16898, 16895>,
    <16892, 16895, 16899>    <16892, 16899, 16896>,
    <16892, 16896, 16900>    <16901, 16909, 16902>,
    <16901, 16902, 16906>    <16901, 16906, 16903>,
    <16901, 16903, 16907>    <16901, 16907, 16904>,
    <16901, 16904, 16908>    <16901, 16908, 16905>,
    <16901, 16905, 16909>    <16910, 16918, 16911>,
    <16910, 16911, 16915>    <16910, 16915, 16912>,
    <16910, 16912, 16916>    <16910, 16916, 16913>,
    <16910, 16913, 16917>    <16910, 16917, 16914>,
    <16910, 16914, 16918>    <16919, 16927, 16920>,
    <16919, 16920, 16924>    <16919, 16924, 16921>,
    <16919, 16921, 16925>    <16919, 16925, 16922>,
    <16919, 16922, 16926>    <16919, 16926, 16923>,
    <16919, 16923, 16927>    <16928, 16936, 16929>,
    <16928, 16929, 16933>    <16928, 16933, 16930>,
    <16928, 16930, 16934>    <16928, 16934, 16931>,
    <16928, 16931, 16935>    <16928, 16935, 16932>,
    <16928, 16932, 16936>    <16937, 16945, 16938>,
    <16937, 16938, 16942>    <16937, 16942, 16939>,
    <16937, 16939, 16943>    <16937, 16943, 16940>,
    <16937, 16940, 16944>    <16937, 16944, 16941>,
    <16937, 16941, 16945>    <16946, 16954, 16947>,
    <16946, 16947, 16951>    <16946, 16951, 16948>,
    <16946, 16948, 16952>    <16946, 16952, 16949>,
    <16946, 16949, 16953>    <16946, 16953, 16950>,
    <16946, 16950, 16954>    <16955, 16963, 16956>,
    <16955, 16956, 16960>    <16955, 16960, 16957>,
    <16955, 16957, 16961>    <16955, 16961, 16958>,
    <16955, 16958, 16962>    <16955, 16962, 16959>,
    <16955, 16959, 16963>    <16964, 16972, 16965>,
    <16964, 16965, 16969>    <16964, 16969, 16966>,
    <16964, 16966, 16970>    <16964, 16970, 16967>,
    <16964, 16967, 16971>    <16964, 16971, 16968>,
    <16964, 16968, 16972>    <16973, 16981, 16974>,
    <16973, 16974, 16978>    <16973, 16978, 16975>,
    <16973, 16975, 16979>    <16973, 16979, 16976>,
    <16973, 16976, 16980>    <16973, 16980, 16977>,
    <16973, 16977, 16981>    <16982, 16990, 16983>,
    <16982, 16983, 16987>    <16982, 16987, 16984>,
    <16982, 16984, 16988>    <16982, 16988, 16985>,
    <16982, 16985, 16989>    <16982, 16989, 16986>,
    <16982, 16986, 16990>    <16991, 16999, 16992>,
    <16991, 16992, 16996>    <16991, 16996, 16993>,
    <16991, 16993, 16997>    <16991, 16997, 16994>,
    <16991, 16994, 16998>    <16991, 16998, 16995>,
    <16991, 16995, 16999>    <17000, 17008, 17001>,
    <17000, 17001, 17005>    <17000, 17005, 17002>,
    <17000, 17002, 17006>    <17000, 17006, 17003>,
    <17000, 17003, 17007>    <17000, 17007, 17004>,
    <17000, 17004, 17008>    <17009, 17017, 17010>,
    <17009, 17010, 17014>    <17009, 17014, 17011>,
    <17009, 17011, 17015>    <17009, 17015, 17012>,
    <17009, 17012, 17016>    <17009, 17016, 17013>,
    <17009, 17013, 17017>    <17018, 17026, 17019>,
    <17018, 17019, 17023>    <17018, 17023, 17020>,
    <17018, 17020, 17024>    <17018, 17024, 17021>,
    <17018, 17021, 17025>    <17018, 17025, 17022>,
    <17018, 17022, 17026>    <17027, 17035, 17028>,
    <17027, 17028, 17032>    <17027, 17032, 17029>,
    <17027, 17029, 17033>    <17027, 17033, 17030>,
    <17027, 17030, 17034>    <17027, 17034, 17031>,
    <17027, 17031, 17035>    <17036, 17044, 17037>,
    <17036, 17037, 17041>    <17036, 17041, 17038>,
    <17036, 17038, 17042>    <17036, 17042, 17039>,
    <17036, 17039, 17043>    <17036, 17043, 17040>,
    <17036, 17040, 17044>    <17045, 17053, 17046>,
    <17045, 17046, 17050>    <17045, 17050, 17047>,
    <17045, 17047, 17051>    <17045, 17051, 17048>,
    <17045, 17048, 17052>    <17045, 17052, 17049>,
    <17045, 17049, 17053>    <17054, 17062, 17055>,
    <17054, 17055, 17059>    <17054, 17059, 17056>,
    <17054, 17056, 17060>    <17054, 17060, 17057>,
    <17054, 17057, 17061>    <17054, 17061, 17058>,
    <17054, 17058, 17062>    <17063, 17071, 17064>,
    <17063, 17064, 17068>    <17063, 17068, 17065>,
    <17063, 17065, 17069>    <17063, 17069, 17066>,
    <17063, 17066, 17070>    <17063, 17070, 17067>,
    <17063, 17067, 17071>    <17072, 17080, 17073>,
    <17072, 17073, 17077>    <17072, 17077, 17074>,
    <17072, 17074, 17078>    <17072, 17078, 17075>,
    <17072, 17075, 17079>    <17072, 17079, 17076>,
    <17072, 17076, 17080>    <17081, 17089, 17082>,
    <17081, 17082, 17086>    <17081, 17086, 17083>,
    <17081, 17083, 17087>    <17081, 17087, 17084>,
    <17081, 17084, 17088>    <17081, 17088, 17085>,
    <17081, 17085, 17089>    <17090, 17098, 17091>,
    <17090, 17091, 17095>    <17090, 17095, 17092>,
    <17090, 17092, 17096>    <17090, 17096, 17093>,
    <17090, 17093, 17097>    <17090, 17097, 17094>,
    <17090, 17094, 17098>    <17099, 17107, 17100>,
    <17099, 17100, 17104>    <17099, 17104, 17101>,
    <17099, 17101, 17105>    <17099, 17105, 17102>,
    <17099, 17102, 17106>    <17099, 17106, 17103>,
    <17099, 17103, 17107>    <17108, 17116, 17109>,
    <17108, 17109, 17113>    <17108, 17113, 17110>,
    <17108, 17110, 17114>    <17108, 17114, 17111>,
    <17108, 17111, 17115>    <17108, 17115, 17112>,
    <17108, 17112, 17116>    <17117, 17125, 17118>,
    <17117, 17118, 17122>    <17117, 17122, 17119>,
    <17117, 17119, 17123>    <17117, 17123, 17120>,
    <17117, 17120, 17124>    <17117, 17124, 17121>,
    <17117, 17121, 17125>    <17126, 17134, 17127>,
    <17126, 17127, 17131>    <17126, 17131, 17128>,
    <17126, 17128, 17132>    <17126, 17132, 17129>,
    <17126, 17129, 17133>    <17126, 17133, 17130>,
    <17126, 17130, 17134>    <17135, 17143, 17136>,
    <17135, 17136, 17140>    <17135, 17140, 17137>,
    <17135, 17137, 17141>    <17135, 17141, 17138>,
    <17135, 17138, 17142>    <17135, 17142, 17139>,
    <17135, 17139, 17143>    <17144, 17152, 17145>,
    <17144, 17145, 17149>    <17144, 17149, 17146>,
    <17144, 17146, 17150>    <17144, 17150, 17147>,
    <17144, 17147, 17151>    <17144, 17151, 17148>,
    <17144, 17148, 17152>    <17153, 17161, 17154>,
    <17153, 17154, 17158>    <17153, 17158, 17155>,
    <17153, 17155, 17159>    <17153, 17159, 17156>,
    <17153, 17156, 17160>    <17153, 17160, 17157>,
    <17153, 17157, 17161>    <17162, 17170, 17163>,
    <17162, 17163, 17167>    <17162, 17167, 17164>,
    <17162, 17164, 17168>    <17162, 17168, 17165>,
    <17162, 17165, 17169>    <17162, 17169, 17166>,
    <17162, 17166, 17170>    <17171, 17179, 17172>,
    <17171, 17172, 17176>    <17171, 17176, 17173>,
    <17171, 17173, 17177>    <17171, 17177, 17174>,
    <17171, 17174, 17178>    <17171, 17178, 17175>,
    <17171, 17175, 17179>    <17180, 17188, 17181>,
    <17180, 17181, 17185>    <17180, 17185, 17182>,
    <17180, 17182, 17186>    <17180, 17186, 17183>,
    <17180, 17183, 17187>    <17180, 17187, 17184>,
    <17180, 17184, 17188>    <17189, 17197, 17190>,
    <17189, 17190, 17194>    <17189, 17194, 17191>,
    <17189, 17191, 17195>    <17189, 17195, 17192>,
    <17189, 17192, 17196>    <17189, 17196, 17193>,
    <17189, 17193, 17197>    <17198, 17206, 17199>,
    <17198, 17199, 17203>    <17198, 17203, 17200>,
    <17198, 17200, 17204>    <17198, 17204, 17201>,
    <17198, 17201, 17205>    <17198, 17205, 17202>,
    <17198, 17202, 17206>    <17207, 17215, 17208>,
    <17207, 17208, 17212>    <17207, 17212, 17209>,
    <17207, 17209, 17213>    <17207, 17213, 17210>,
    <17207, 17210, 17214>    <17207, 17214, 17211>,
    <17207, 17211, 17215>    <17216, 17224, 17217>,
    <17216, 17217, 17221>    <17216, 17221, 17218>,
    <17216, 17218, 17222>    <17216, 17222, 17219>,
    <17216, 17219, 17223>    <17216, 17223, 17220>,
    <17216, 17220, 17224>    <17225, 17233, 17226>,
    <17225, 17226, 17230>    <17225, 17230, 17227>,
    <17225, 17227, 17231>    <17225, 17231, 17228>,
    <17225, 17228, 17232>    <17225, 17232, 17229>,
    <17225, 17229, 17233>    <17234, 17242, 17235>,
    <17234, 17235, 17239>    <17234, 17239, 17236>,
    <17234, 17236, 17240>    <17234, 17240, 17237>,
    <17234, 17237, 17241>    <17234, 17241, 17238>,
    <17234, 17238, 17242>    <17243, 17251, 17244>,
    <17243, 17244, 17248>    <17243, 17248, 17245>,
    <17243, 17245, 17249>    <17243, 17249, 17246>,
    <17243, 17246, 17250>    <17243, 17250, 17247>,
    <17243, 17247, 17251>    <17252, 17260, 17253>,
    <17252, 17253, 17257>    <17252, 17257, 17254>,
    <17252, 17254, 17258>    <17252, 17258, 17255>,
    <17252, 17255, 17259>    <17252, 17259, 17256>,
    <17252, 17256, 17260>    <17261, 17269, 17262>,
    <17261, 17262, 17266>    <17261, 17266, 17263>,
    <17261, 17263, 17267>    <17261, 17267, 17264>,
    <17261, 17264, 17268>    <17261, 17268, 17265>,
    <17261, 17265, 17269>    <17270, 17278, 17271>,
    <17270, 17271, 17275>    <17270, 17275, 17272>,
    <17270, 17272, 17276>    <17270, 17276, 17273>,
    <17270, 17273, 17277>    <17270, 17277, 17274>,
    <17270, 17274, 17278>    <17279, 17287, 17280>,
    <17279, 17280, 17284>    <17279, 17284, 17281>,
    <17279, 17281, 17285>    <17279, 17285, 17282>,
    <17279, 17282, 17286>    <17279, 17286, 17283>,
    <17279, 17283, 17287>    <17288, 17296, 17289>,
    <17288, 17289, 17293>    <17288, 17293, 17290>,
    <17288, 17290, 17294>    <17288, 17294, 17291>,
    <17288, 17291, 17295>    <17288, 17295, 17292>,
    <17288, 17292, 17296>    <17297, 17305, 17298>,
    <17297, 17298, 17302>    <17297, 17302, 17299>,
    <17297, 17299, 17303>    <17297, 17303, 17300>,
    <17297, 17300, 17304>    <17297, 17304, 17301>,
    <17297, 17301, 17305>    <17306, 17314, 17307>,
    <17306, 17307, 17311>    <17306, 17311, 17308>,
    <17306, 17308, 17312>    <17306, 17312, 17309>,
    <17306, 17309, 17313>    <17306, 17313, 17310>,
    <17306, 17310, 17314>    <17315, 17323, 17316>,
    <17315, 17316, 17320>    <17315, 17320, 17317>,
    <17315, 17317, 17321>    <17315, 17321, 17318>,
    <17315, 17318, 17322>    <17315, 17322, 17319>,
    <17315, 17319, 17323>    <17324, 17332, 17325>,
    <17324, 17325, 17329>    <17324, 17329, 17326>,
    <17324, 17326, 17330>    <17324, 17330, 17327>,
    <17324, 17327, 17331>    <17324, 17331, 17328>,
    <17324, 17328, 17332>    <17333, 17341, 17334>,
    <17333, 17334, 17338>    <17333, 17338, 17335>,
    <17333, 17335, 17339>    <17333, 17339, 17336>,
    <17333, 17336, 17340>    <17333, 17340, 17337>,
    <17333, 17337, 17341>    <17342, 17350, 17343>,
    <17342, 17343, 17347>    <17342, 17347, 17344>,
    <17342, 17344, 17348>    <17342, 17348, 17345>,
    <17342, 17345, 17349>    <17342, 17349, 17346>,
    <17342, 17346, 17350>    <17351, 17359, 17352>,
    <17351, 17352, 17356>    <17351, 17356, 17353>,
    <17351, 17353, 17357>    <17351, 17357, 17354>,
    <17351, 17354, 17358>    <17351, 17358, 17355>,
    <17351, 17355, 17359>    <17360, 17368, 17361>,
    <17360, 17361, 17365>    <17360, 17365, 17362>,
    <17360, 17362, 17366>    <17360, 17366, 17363>,
    <17360, 17363, 17367>    <17360, 17367, 17364>,
    <17360, 17364, 17368>    <17369, 17377, 17370>,
    <17369, 17370, 17374>    <17369, 17374, 17371>,
    <17369, 17371, 17375>    <17369, 17375, 17372>,
    <17369, 17372, 17376>    <17369, 17376, 17373>,
    <17369, 17373, 17377>    <17378, 17386, 17379>,
    <17378, 17379, 17383>    <17378, 17383, 17380>,
    <17378, 17380, 17384>    <17378, 17384, 17381>,
    <17378, 17381, 17385>    <17378, 17385, 17382>,
    <17378, 17382, 17386>    <17387, 17395, 17388>,
    <17387, 17388, 17392>    <17387, 17392, 17389>,
    <17387, 17389, 17393>    <17387, 17393, 17390>,
    <17387, 17390, 17394>    <17387, 17394, 17391>,
    <17387, 17391, 17395>    <17396, 17404, 17397>,
    <17396, 17397, 17401>    <17396, 17401, 17398>,
    <17396, 17398, 17402>    <17396, 17402, 17399>,
    <17396, 17399, 17403>    <17396, 17403, 17400>,
    <17396, 17400, 17404>    <17405, 17413, 17406>,
    <17405, 17406, 17410>    <17405, 17410, 17407>,
    <17405, 17407, 17411>    <17405, 17411, 17408>,
    <17405, 17408, 17412>    <17405, 17412, 17409>,
    <17405, 17409, 17413>    <17414, 17422, 17415>,
    <17414, 17415, 17419>    <17414, 17419, 17416>,
    <17414, 17416, 17420>    <17414, 17420, 17417>,
    <17414, 17417, 17421>    <17414, 17421, 17418>,
    <17414, 17418, 17422>    <17423, 17431, 17424>,
    <17423, 17424, 17428>    <17423, 17428, 17425>,
    <17423, 17425, 17429>    <17423, 17429, 17426>,
    <17423, 17426, 17430>    <17423, 17430, 17427>,
    <17423, 17427, 17431>    <17432, 17440, 17433>,
    <17432, 17433, 17437>    <17432, 17437, 17434>,
    <17432, 17434, 17438>    <17432, 17438, 17435>,
    <17432, 17435, 17439>    <17432, 17439, 17436>,
    <17432, 17436, 17440>    <17441, 17449, 17442>,
    <17441, 17442, 17446>    <17441, 17446, 17443>,
    <17441, 17443, 17447>    <17441, 17447, 17444>,
    <17441, 17444, 17448>    <17441, 17448, 17445>,
    <17441, 17445, 17449>    <17450, 17458, 17451>,
    <17450, 17451, 17455>    <17450, 17455, 17452>,
    <17450, 17452, 17456>    <17450, 17456, 17453>,
    <17450, 17453, 17457>    <17450, 17457, 17454>,
    <17450, 17454, 17458>    <17459, 17467, 17460>,
    <17459, 17460, 17464>    <17459, 17464, 17461>,
    <17459, 17461, 17465>    <17459, 17465, 17462>,
    <17459, 17462, 17466>    <17459, 17466, 17463>,
    <17459, 17463, 17467>    <17468, 17476, 17469>,
    <17468, 17469, 17473>    <17468, 17473, 17470>,
    <17468, 17470, 17474>    <17468, 17474, 17471>,
    <17468, 17471, 17475>    <17468, 17475, 17472>,
    <17468, 17472, 17476>    <17477, 17485, 17478>,
    <17477, 17478, 17482>    <17477, 17482, 17479>,
    <17477, 17479, 17483>    <17477, 17483, 17480>,
    <17477, 17480, 17484>    <17477, 17484, 17481>,
    <17477, 17481, 17485>    <17486, 17494, 17487>,
    <17486, 17487, 17491>    <17486, 17491, 17488>,
    <17486, 17488, 17492>    <17486, 17492, 17489>,
    <17486, 17489, 17493>    <17486, 17493, 17490>,
    <17486, 17490, 17494>    <17495, 17503, 17496>,
    <17495, 17496, 17500>    <17495, 17500, 17497>,
    <17495, 17497, 17501>    <17495, 17501, 17498>,
    <17495, 17498, 17502>    <17495, 17502, 17499>,
    <17495, 17499, 17503>    <17504, 17512, 17505>,
    <17504, 17505, 17509>    <17504, 17509, 17506>,
    <17504, 17506, 17510>    <17504, 17510, 17507>,
    <17504, 17507, 17511>    <17504, 17511, 17508>,
    <17504, 17508, 17512>    <17513, 17521, 17514>,
    <17513, 17514, 17518>    <17513, 17518, 17515>,
    <17513, 17515, 17519>    <17513, 17519, 17516>,
    <17513, 17516, 17520>    <17513, 17520, 17517>,
    <17513, 17517, 17521>    <17522, 17530, 17523>,
    <17522, 17523, 17527>    <17522, 17527, 17524>,
    <17522, 17524, 17528>    <17522, 17528, 17525>,
    <17522, 17525, 17529>    <17522, 17529, 17526>,
    <17522, 17526, 17530>    <17531, 17539, 17532>,
    <17531, 17532, 17536>    <17531, 17536, 17533>,
    <17531, 17533, 17537>    <17531, 17537, 17534>,
    <17531, 17534, 17538>    <17531, 17538, 17535>,
    <17531, 17535, 17539>    <17540, 17548, 17541>,
    <17540, 17541, 17545>    <17540, 17545, 17542>,
    <17540, 17542, 17546>    <17540, 17546, 17543>,
    <17540, 17543, 17547>    <17540, 17547, 17544>,
    <17540, 17544, 17548>    <17549, 17557, 17550>,
    <17549, 17550, 17554>    <17549, 17554, 17551>,
    <17549, 17551, 17555>    <17549, 17555, 17552>,
    <17549, 17552, 17556>    <17549, 17556, 17553>,
    <17549, 17553, 17557>    <17558, 17566, 17559>,
    <17558, 17559, 17563>    <17558, 17563, 17560>,
    <17558, 17560, 17564>    <17558, 17564, 17561>,
    <17558, 17561, 17565>    <17558, 17565, 17562>,
    <17558, 17562, 17566>    <17567, 17575, 17568>,
    <17567, 17568, 17572>    <17567, 17572, 17569>,
    <17567, 17569, 17573>    <17567, 17573, 17570>,
    <17567, 17570, 17574>    <17567, 17574, 17571>,
    <17567, 17571, 17575>    <17576, 17584, 17577>,
    <17576, 17577, 17581>    <17576, 17581, 17578>,
    <17576, 17578, 17582>    <17576, 17582, 17579>,
    <17576, 17579, 17583>    <17576, 17583, 17580>,
    <17576, 17580, 17584>    <17585, 17593, 17586>,
    <17585, 17586, 17590>    <17585, 17590, 17587>,
    <17585, 17587, 17591>    <17585, 17591, 17588>,
    <17585, 17588, 17592>    <17585, 17592, 17589>,
    <17585, 17589, 17593>    <17594, 17602, 17595>,
    <17594, 17595, 17599>    <17594, 17599, 17596>,
    <17594, 17596, 17600>    <17594, 17600, 17597>,
    <17594, 17597, 17601>    <17594, 17601, 17598>,
    <17594, 17598, 17602>    <17603, 17611, 17604>,
    <17603, 17604, 17608>    <17603, 17608, 17605>,
    <17603, 17605, 17609>    <17603, 17609, 17606>,
    <17603, 17606, 17610>    <17603, 17610, 17607>,
    <17603, 17607, 17611>    <17612, 17620, 17613>,
    <17612, 17613, 17617>    <17612, 17617, 17614>,
    <17612, 17614, 17618>    <17612, 17618, 17615>,
    <17612, 17615, 17619>    <17612, 17619, 17616>,
    <17612, 17616, 17620>    <17621, 17629, 17622>,
    <17621, 17622, 17626>    <17621, 17626, 17623>,
    <17621, 17623, 17627>    <17621, 17627, 17624>,
    <17621, 17624, 17628>    <17621, 17628, 17625>,
    <17621, 17625, 17629>    <17630, 17638, 17631>,
    <17630, 17631, 17635>    <17630, 17635, 17632>,
    <17630, 17632, 17636>    <17630, 17636, 17633>,
    <17630, 17633, 17637>    <17630, 17637, 17634>,
    <17630, 17634, 17638>    <17639, 17647, 17640>,
    <17639, 17640, 17644>    <17639, 17644, 17641>,
    <17639, 17641, 17645>    <17639, 17645, 17642>,
    <17639, 17642, 17646>    <17639, 17646, 17643>,
    <17639, 17643, 17647>    <17648, 17656, 17649>,
    <17648, 17649, 17653>    <17648, 17653, 17650>,
    <17648, 17650, 17654>    <17648, 17654, 17651>,
    <17648, 17651, 17655>    <17648, 17655, 17652>,
    <17648, 17652, 17656>    <17657, 17665, 17658>,
    <17657, 17658, 17662>    <17657, 17662, 17659>,
    <17657, 17659, 17663>    <17657, 17663, 17660>,
    <17657, 17660, 17664>    <17657, 17664, 17661>,
    <17657, 17661, 17665>    <17666, 17674, 17667>,
    <17666, 17667, 17671>    <17666, 17671, 17668>,
    <17666, 17668, 17672>    <17666, 17672, 17669>,
    <17666, 17669, 17673>    <17666, 17673, 17670>,
    <17666, 17670, 17674>    <17675, 17683, 17676>,
    <17675, 17676, 17680>    <17675, 17680, 17677>,
    <17675, 17677, 17681>    <17675, 17681, 17678>,
    <17675, 17678, 17682>    <17675, 17682, 17679>,
    <17675, 17679, 17683>    <17684, 17692, 17685>,
    <17684, 17685, 17689>    <17684, 17689, 17686>,
    <17684, 17686, 17690>    <17684, 17690, 17687>,
    <17684, 17687, 17691>    <17684, 17691, 17688>,
    <17684, 17688, 17692>    <17693, 17701, 17694>,
    <17693, 17694, 17698>    <17693, 17698, 17695>,
    <17693, 17695, 17699>    <17693, 17699, 17696>,
    <17693, 17696, 17700>    <17693, 17700, 17697>,
    <17693, 17697, 17701>    <17702, 17710, 17703>,
    <17702, 17703, 17707>    <17702, 17707, 17704>,
    <17702, 17704, 17708>    <17702, 17708, 17705>,
    <17702, 17705, 17709>    <17702, 17709, 17706>,
    <17702, 17706, 17710>    <17711, 17719, 17712>,
    <17711, 17712, 17716>    <17711, 17716, 17713>,
    <17711, 17713, 17717>    <17711, 17717, 17714>,
    <17711, 17714, 17718>    <17711, 17718, 17715>,
    <17711, 17715, 17719>    <17720, 17728, 17721>,
    <17720, 17721, 17725>    <17720, 17725, 17722>,
    <17720, 17722, 17726>    <17720, 17726, 17723>,
    <17720, 17723, 17727>    <17720, 17727, 17724>,
    <17720, 17724, 17728>    <17729, 17737, 17730>,
    <17729, 17730, 17734>    <17729, 17734, 17731>,
    <17729, 17731, 17735>    <17729, 17735, 17732>,
    <17729, 17732, 17736>    <17729, 17736, 17733>,
    <17729, 17733, 17737>    <17738, 17746, 17739>,
    <17738, 17739, 17743>    <17738, 17743, 17740>,
    <17738, 17740, 17744>    <17738, 17744, 17741>,
    <17738, 17741, 17745>    <17738, 17745, 17742>,
    <17738, 17742, 17746>    <17747, 17755, 17748>,
    <17747, 17748, 17752>    <17747, 17752, 17749>,
    <17747, 17749, 17753>    <17747, 17753, 17750>,
    <17747, 17750, 17754>    <17747, 17754, 17751>,
    <17747, 17751, 17755>    <17756, 17764, 17757>,
    <17756, 17757, 17761>    <17756, 17761, 17758>,
    <17756, 17758, 17762>    <17756, 17762, 17759>,
    <17756, 17759, 17763>    <17756, 17763, 17760>,
    <17756, 17760, 17764>    <17765, 17773, 17766>,
    <17765, 17766, 17770>    <17765, 17770, 17767>,
    <17765, 17767, 17771>    <17765, 17771, 17768>,
    <17765, 17768, 17772>    <17765, 17772, 17769>,
    <17765, 17769, 17773>    <17774, 17782, 17775>,
    <17774, 17775, 17779>    <17774, 17779, 17776>,
    <17774, 17776, 17780>    <17774, 17780, 17777>,
    <17774, 17777, 17781>    <17774, 17781, 17778>,
    <17774, 17778, 17782>    <17783, 17791, 17784>,
    <17783, 17784, 17788>    <17783, 17788, 17785>,
    <17783, 17785, 17789>    <17783, 17789, 17786>,
    <17783, 17786, 17790>    <17783, 17790, 17787>,
    <17783, 17787, 17791>    <17792, 17800, 17793>,
    <17792, 17793, 17797>    <17792, 17797, 17794>,
    <17792, 17794, 17798>    <17792, 17798, 17795>,
    <17792, 17795, 17799>    <17792, 17799, 17796>,
    <17792, 17796, 17800>    <17801, 17809, 17802>,
    <17801, 17802, 17806>    <17801, 17806, 17803>,
    <17801, 17803, 17807>    <17801, 17807, 17804>,
    <17801, 17804, 17808>    <17801, 17808, 17805>,
    <17801, 17805, 17809>    <17810, 17818, 17811>,
    <17810, 17811, 17815>    <17810, 17815, 17812>,
    <17810, 17812, 17816>    <17810, 17816, 17813>,
    <17810, 17813, 17817>    <17810, 17817, 17814>,
    <17810, 17814, 17818>    <17819, 17827, 17820>,
    <17819, 17820, 17824>    <17819, 17824, 17821>,
    <17819, 17821, 17825>    <17819, 17825, 17822>,
    <17819, 17822, 17826>    <17819, 17826, 17823>,
    <17819, 17823, 17827>    <17828, 17836, 17829>,
    <17828, 17829, 17833>    <17828, 17833, 17830>,
    <17828, 17830, 17834>    <17828, 17834, 17831>,
    <17828, 17831, 17835>    <17828, 17835, 17832>,
    <17828, 17832, 17836>    <17837, 17845, 17838>,
    <17837, 17838, 17842>    <17837, 17842, 17839>,
    <17837, 17839, 17843>    <17837, 17843, 17840>,
    <17837, 17840, 17844>    <17837, 17844, 17841>,
    <17837, 17841, 17845>    <17846, 17854, 17847>,
    <17846, 17847, 17851>    <17846, 17851, 17848>,
    <17846, 17848, 17852>    <17846, 17852, 17849>,
    <17846, 17849, 17853>    <17846, 17853, 17850>,
    <17846, 17850, 17854>    <17855, 17863, 17856>,
    <17855, 17856, 17860>    <17855, 17860, 17857>,
    <17855, 17857, 17861>    <17855, 17861, 17858>,
    <17855, 17858, 17862>    <17855, 17862, 17859>,
    <17855, 17859, 17863>    <17864, 17872, 17865>,
    <17864, 17865, 17869>    <17864, 17869, 17866>,
    <17864, 17866, 17870>    <17864, 17870, 17867>,
    <17864, 17867, 17871>    <17864, 17871, 17868>,
    <17864, 17868, 17872>    <17873, 17881, 17874>,
    <17873, 17874, 17878>    <17873, 17878, 17875>,
    <17873, 17875, 17879>    <17873, 17879, 17876>,
    <17873, 17876, 17880>    <17873, 17880, 17877>,
    <17873, 17877, 17881>    <17882, 17890, 17883>,
    <17882, 17883, 17887>    <17882, 17887, 17884>,
    <17882, 17884, 17888>    <17882, 17888, 17885>,
    <17882, 17885, 17889>    <17882, 17889, 17886>,
    <17882, 17886, 17890>    <17891, 17899, 17892>,
    <17891, 17892, 17896>    <17891, 17896, 17893>,
    <17891, 17893, 17897>    <17891, 17897, 17894>,
    <17891, 17894, 17898>    <17891, 17898, 17895>,
    <17891, 17895, 17899>    <17900, 17908, 17901>,
    <17900, 17901, 17905>    <17900, 17905, 17902>,
    <17900, 17902, 17906>    <17900, 17906, 17903>,
    <17900, 17903, 17907>    <17900, 17907, 17904>,
    <17900, 17904, 17908>    <17909, 17917, 17910>,
    <17909, 17910, 17914>    <17909, 17914, 17911>,
    <17909, 17911, 17915>    <17909, 17915, 17912>,
    <17909, 17912, 17916>    <17909, 17916, 17913>,
    <17909, 17913, 17917>    <17918, 17926, 17919>,
    <17918, 17919, 17923>    <17918, 17923, 17920>,
    <17918, 17920, 17924>    <17918, 17924, 17921>,
    <17918, 17921, 17925>    <17918, 17925, 17922>,
    <17918, 17922, 17926>    <17927, 17935, 17928>,
    <17927, 17928, 17932>    <17927, 17932, 17929>,
    <17927, 17929, 17933>    <17927, 17933, 17930>,
    <17927, 17930, 17934>    <17927, 17934, 17931>,
    <17927, 17931, 17935>    <17936, 17944, 17937>,
    <17936, 17937, 17941>    <17936, 17941, 17938>,
    <17936, 17938, 17942>    <17936, 17942, 17939>,
    <17936, 17939, 17943>    <17936, 17943, 17940>,
    <17936, 17940, 17944>    <17945, 17953, 17946>,
    <17945, 17946, 17950>    <17945, 17950, 17947>,
    <17945, 17947, 17951>    <17945, 17951, 17948>,
    <17945, 17948, 17952>    <17945, 17952, 17949>,
    <17945, 17949, 17953>    <17954, 17962, 17955>,
    <17954, 17955, 17959>    <17954, 17959, 17956>,
    <17954, 17956, 17960>    <17954, 17960, 17957>,
    <17954, 17957, 17961>    <17954, 17961, 17958>,
    <17954, 17958, 17962>    <17963, 17971, 17964>,
    <17963, 17964, 17968>    <17963, 17968, 17965>,
    <17963, 17965, 17969>    <17963, 17969, 17966>,
    <17963, 17966, 17970>    <17963, 17970, 17967>,
    <17963, 17967, 17971>    <17972, 17980, 17973>,
    <17972, 17973, 17977>    <17972, 17977, 17974>,
    <17972, 17974, 17978>    <17972, 17978, 17975>,
    <17972, 17975, 17979>    <17972, 17979, 17976>,
    <17972, 17976, 17980>    <17981, 17989, 17982>,
    <17981, 17982, 17986>    <17981, 17986, 17983>,
    <17981, 17983, 17987>    <17981, 17987, 17984>,
    <17981, 17984, 17988>    <17981, 17988, 17985>,
    <17981, 17985, 17989>    <17990, 17998, 17991>,
    <17990, 17991, 17995>    <17990, 17995, 17992>,
    <17990, 17992, 17996>    <17990, 17996, 17993>,
    <17990, 17993, 17997>    <17990, 17997, 17994>,
    <17990, 17994, 17998>    <17999, 18007, 18000>,
    <17999, 18000, 18004>    <17999, 18004, 18001>,
    <17999, 18001, 18005>    <17999, 18005, 18002>,
    <17999, 18002, 18006>    <17999, 18006, 18003>,
    <17999, 18003, 18007>    <18008, 18016, 18009>,
    <18008, 18009, 18013>    <18008, 18013, 18010>,
    <18008, 18010, 18014>    <18008, 18014, 18011>,
    <18008, 18011, 18015>    <18008, 18015, 18012>,
    <18008, 18012, 18016>    <18017, 18025, 18018>,
    <18017, 18018, 18022>    <18017, 18022, 18019>,
    <18017, 18019, 18023>    <18017, 18023, 18020>,
    <18017, 18020, 18024>    <18017, 18024, 18021>,
    <18017, 18021, 18025>    <18026, 18034, 18027>,
    <18026, 18027, 18031>    <18026, 18031, 18028>,
    <18026, 18028, 18032>    <18026, 18032, 18029>,
    <18026, 18029, 18033>    <18026, 18033, 18030>,
    <18026, 18030, 18034>    <18035, 18043, 18036>,
    <18035, 18036, 18040>    <18035, 18040, 18037>,
    <18035, 18037, 18041>    <18035, 18041, 18038>,
    <18035, 18038, 18042>    <18035, 18042, 18039>,
    <18035, 18039, 18043>    <18044, 18052, 18045>,
    <18044, 18045, 18049>    <18044, 18049, 18046>,
    <18044, 18046, 18050>    <18044, 18050, 18047>,
    <18044, 18047, 18051>    <18044, 18051, 18048>,
    <18044, 18048, 18052>    <18053, 18061, 18054>,
    <18053, 18054, 18058>    <18053, 18058, 18055>,
    <18053, 18055, 18059>    <18053, 18059, 18056>,
    <18053, 18056, 18060>    <18053, 18060, 18057>,
    <18053, 18057, 18061>    <18062, 18070, 18063>,
    <18062, 18063, 18067>    <18062, 18067, 18064>,
    <18062, 18064, 18068>    <18062, 18068, 18065>,
    <18062, 18065, 18069>    <18062, 18069, 18066>,
    <18062, 18066, 18070>    <18071, 18079, 18072>,
    <18071, 18072, 18076>    <18071, 18076, 18073>,
    <18071, 18073, 18077>    <18071, 18077, 18074>,
    <18071, 18074, 18078>    <18071, 18078, 18075>,
    <18071, 18075, 18079>    <18080, 18088, 18081>,
    <18080, 18081, 18085>    <18080, 18085, 18082>,
    <18080, 18082, 18086>    <18080, 18086, 18083>,
    <18080, 18083, 18087>    <18080, 18087, 18084>,
    <18080, 18084, 18088>    <18089, 18097, 18090>,
    <18089, 18090, 18094>    <18089, 18094, 18091>,
    <18089, 18091, 18095>    <18089, 18095, 18092>,
    <18089, 18092, 18096>    <18089, 18096, 18093>,
    <18089, 18093, 18097>    <18098, 18106, 18099>,
    <18098, 18099, 18103>    <18098, 18103, 18100>,
    <18098, 18100, 18104>    <18098, 18104, 18101>,
    <18098, 18101, 18105>    <18098, 18105, 18102>,
    <18098, 18102, 18106>    <18107, 18115, 18108>,
    <18107, 18108, 18112>    <18107, 18112, 18109>,
    <18107, 18109, 18113>    <18107, 18113, 18110>,
    <18107, 18110, 18114>    <18107, 18114, 18111>,
    <18107, 18111, 18115>    <18116, 18124, 18117>,
    <18116, 18117, 18121>    <18116, 18121, 18118>,
    <18116, 18118, 18122>    <18116, 18122, 18119>,
    <18116, 18119, 18123>    <18116, 18123, 18120>,
    <18116, 18120, 18124>    <18125, 18133, 18126>,
    <18125, 18126, 18130>    <18125, 18130, 18127>,
    <18125, 18127, 18131>    <18125, 18131, 18128>,
    <18125, 18128, 18132>    <18125, 18132, 18129>,
    <18125, 18129, 18133>    <18134, 18142, 18135>,
    <18134, 18135, 18139>    <18134, 18139, 18136>,
    <18134, 18136, 18140>    <18134, 18140, 18137>,
    <18134, 18137, 18141>    <18134, 18141, 18138>,
    <18134, 18138, 18142>    <18143, 18151, 18144>,
    <18143, 18144, 18148>    <18143, 18148, 18145>,
    <18143, 18145, 18149>    <18143, 18149, 18146>,
    <18143, 18146, 18150>    <18143, 18150, 18147>,
    <18143, 18147, 18151>    <18152, 18160, 18153>,
    <18152, 18153, 18157>    <18152, 18157, 18154>,
    <18152, 18154, 18158>    <18152, 18158, 18155>,
    <18152, 18155, 18159>    <18152, 18159, 18156>,
    <18152, 18156, 18160>    <18161, 18169, 18162>,
    <18161, 18162, 18166>    <18161, 18166, 18163>,
    <18161, 18163, 18167>    <18161, 18167, 18164>,
    <18161, 18164, 18168>    <18161, 18168, 18165>,
    <18161, 18165, 18169>    <18170, 18178, 18171>,
    <18170, 18171, 18175>    <18170, 18175, 18172>,
    <18170, 18172, 18176>    <18170, 18176, 18173>,
    <18170, 18173, 18177>    <18170, 18177, 18174>,
    <18170, 18174, 18178>    <18179, 18187, 18180>,
    <18179, 18180, 18184>    <18179, 18184, 18181>,
    <18179, 18181, 18185>    <18179, 18185, 18182>,
    <18179, 18182, 18186>    <18179, 18186, 18183>,
    <18179, 18183, 18187>    <18188, 18196, 18189>,
    <18188, 18189, 18193>    <18188, 18193, 18190>,
    <18188, 18190, 18194>    <18188, 18194, 18191>,
    <18188, 18191, 18195>    <18188, 18195, 18192>,
    <18188, 18192, 18196>    <18197, 18205, 18198>,
    <18197, 18198, 18202>    <18197, 18202, 18199>,
    <18197, 18199, 18203>    <18197, 18203, 18200>,
    <18197, 18200, 18204>    <18197, 18204, 18201>,
    <18197, 18201, 18205>    <18206, 18214, 18207>,
    <18206, 18207, 18211>    <18206, 18211, 18208>,
    <18206, 18208, 18212>    <18206, 18212, 18209>,
    <18206, 18209, 18213>    <18206, 18213, 18210>,
    <18206, 18210, 18214>    <18215, 18223, 18216>,
    <18215, 18216, 18220>    <18215, 18220, 18217>,
    <18215, 18217, 18221>    <18215, 18221, 18218>,
    <18215, 18218, 18222>    <18215, 18222, 18219>,
    <18215, 18219, 18223>    <18224, 18232, 18225>,
    <18224, 18225, 18229>    <18224, 18229, 18226>,
    <18224, 18226, 18230>    <18224, 18230, 18227>,
    <18224, 18227, 18231>    <18224, 18231, 18228>,
    <18224, 18228, 18232>    <18233, 18241, 18234>,
    <18233, 18234, 18238>    <18233, 18238, 18235>,
    <18233, 18235, 18239>    <18233, 18239, 18236>,
    <18233, 18236, 18240>    <18233, 18240, 18237>,
    <18233, 18237, 18241>    <18242, 18250, 18243>,
    <18242, 18243, 18247>    <18242, 18247, 18244>,
    <18242, 18244, 18248>    <18242, 18248, 18245>,
    <18242, 18245, 18249>    <18242, 18249, 18246>,
    <18242, 18246, 18250>    <18251, 18259, 18252>,
    <18251, 18252, 18256>    <18251, 18256, 18253>,
    <18251, 18253, 18257>    <18251, 18257, 18254>,
    <18251, 18254, 18258>    <18251, 18258, 18255>,
    <18251, 18255, 18259>    <18260, 18268, 18261>,
    <18260, 18261, 18265>    <18260, 18265, 18262>,
    <18260, 18262, 18266>    <18260, 18266, 18263>,
    <18260, 18263, 18267>    <18260, 18267, 18264>,
    <18260, 18264, 18268>    <18269, 18277, 18270>,
    <18269, 18270, 18274>    <18269, 18274, 18271>,
    <18269, 18271, 18275>    <18269, 18275, 18272>,
    <18269, 18272, 18276>    <18269, 18276, 18273>,
    <18269, 18273, 18277>    <18278, 18286, 18279>,
    <18278, 18279, 18283>    <18278, 18283, 18280>,
    <18278, 18280, 18284>    <18278, 18284, 18281>,
    <18278, 18281, 18285>    <18278, 18285, 18282>,
    <18278, 18282, 18286>    <18287, 18295, 18288>,
    <18287, 18288, 18292>    <18287, 18292, 18289>,
    <18287, 18289, 18293>    <18287, 18293, 18290>,
    <18287, 18290, 18294>    <18287, 18294, 18291>,
    <18287, 18291, 18295>    <18296, 18304, 18297>,
    <18296, 18297, 18301>    <18296, 18301, 18298>,
    <18296, 18298, 18302>    <18296, 18302, 18299>,
    <18296, 18299, 18303>    <18296, 18303, 18300>,
    <18296, 18300, 18304>    <18305, 18313, 18306>,
    <18305, 18306, 18310>    <18305, 18310, 18307>,
    <18305, 18307, 18311>    <18305, 18311, 18308>,
    <18305, 18308, 18312>    <18305, 18312, 18309>,
    <18305, 18309, 18313>    <18314, 18322, 18315>,
    <18314, 18315, 18319>    <18314, 18319, 18316>,
    <18314, 18316, 18320>    <18314, 18320, 18317>,
    <18314, 18317, 18321>    <18314, 18321, 18318>,
    <18314, 18318, 18322>    <18323, 18331, 18324>,
    <18323, 18324, 18328>    <18323, 18328, 18325>,
    <18323, 18325, 18329>    <18323, 18329, 18326>,
    <18323, 18326, 18330>    <18323, 18330, 18327>,
    <18323, 18327, 18331>    <18332, 18340, 18333>,
    <18332, 18333, 18337>    <18332, 18337, 18334>,
    <18332, 18334, 18338>    <18332, 18338, 18335>,
    <18332, 18335, 18339>    <18332, 18339, 18336>,
    <18332, 18336, 18340>    <18341, 18349, 18342>,
    <18341, 18342, 18346>    <18341, 18346, 18343>,
    <18341, 18343, 18347>    <18341, 18347, 18344>,
    <18341, 18344, 18348>    <18341, 18348, 18345>,
    <18341, 18345, 18349>    <18350, 18358, 18351>,
    <18350, 18351, 18355>    <18350, 18355, 18352>,
    <18350, 18352, 18356>    <18350, 18356, 18353>,
    <18350, 18353, 18357>    <18350, 18357, 18354>,
    <18350, 18354, 18358>    <18359, 18367, 18360>,
    <18359, 18360, 18364>    <18359, 18364, 18361>,
    <18359, 18361, 18365>    <18359, 18365, 18362>,
    <18359, 18362, 18366>    <18359, 18366, 18363>,
    <18359, 18363, 18367>    <18368, 18376, 18369>,
    <18368, 18369, 18373>    <18368, 18373, 18370>,
    <18368, 18370, 18374>    <18368, 18374, 18371>,
    <18368, 18371, 18375>    <18368, 18375, 18372>,
    <18368, 18372, 18376>    <18377, 18385, 18378>,
    <18377, 18378, 18382>    <18377, 18382, 18379>,
    <18377, 18379, 18383>    <18377, 18383, 18380>,
    <18377, 18380, 18384>    <18377, 18384, 18381>,
    <18377, 18381, 18385>    <18386, 18394, 18387>,
    <18386, 18387, 18391>    <18386, 18391, 18388>,
    <18386, 18388, 18392>    <18386, 18392, 18389>,
    <18386, 18389, 18393>    <18386, 18393, 18390>,
    <18386, 18390, 18394>    <18395, 18403, 18396>,
    <18395, 18396, 18400>    <18395, 18400, 18397>,
    <18395, 18397, 18401>    <18395, 18401, 18398>,
    <18395, 18398, 18402>    <18395, 18402, 18399>,
    <18395, 18399, 18403>    <18404, 18412, 18405>,
    <18404, 18405, 18409>    <18404, 18409, 18406>,
    <18404, 18406, 18410>    <18404, 18410, 18407>,
    <18404, 18407, 18411>    <18404, 18411, 18408>,
    <18404, 18408, 18412>    <18413, 18421, 18414>,
    <18413, 18414, 18418>    <18413, 18418, 18415>,
    <18413, 18415, 18419>    <18413, 18419, 18416>,
    <18413, 18416, 18420>    <18413, 18420, 18417>,
    <18413, 18417, 18421>    <18422, 18430, 18423>,
    <18422, 18423, 18427>    <18422, 18427, 18424>,
    <18422, 18424, 18428>    <18422, 18428, 18425>,
    <18422, 18425, 18429>    <18422, 18429, 18426>,
    <18422, 18426, 18430>    <18431, 18439, 18432>,
    <18431, 18432, 18436>    <18431, 18436, 18433>,
    <18431, 18433, 18437>    <18431, 18437, 18434>,
    <18431, 18434, 18438>    <18431, 18438, 18435>,
    <18431, 18435, 18439>    <18440, 18448, 18441>,
    <18440, 18441, 18445>    <18440, 18445, 18442>,
    <18440, 18442, 18446>    <18440, 18446, 18443>,
    <18440, 18443, 18447>    <18440, 18447, 18444>,
    <18440, 18444, 18448>    <18449, 18457, 18450>,
    <18449, 18450, 18454>    <18449, 18454, 18451>,
    <18449, 18451, 18455>    <18449, 18455, 18452>,
    <18449, 18452, 18456>    <18449, 18456, 18453>,
    <18449, 18453, 18457>    <18458, 18466, 18459>,
    <18458, 18459, 18463>    <18458, 18463, 18460>,
    <18458, 18460, 18464>    <18458, 18464, 18461>,
    <18458, 18461, 18465>    <18458, 18465, 18462>,
    <18458, 18462, 18466>    <18467, 18475, 18468>,
    <18467, 18468, 18472>    <18467, 18472, 18469>,
    <18467, 18469, 18473>    <18467, 18473, 18470>,
    <18467, 18470, 18474>    <18467, 18474, 18471>,
    <18467, 18471, 18475>    <18476, 18484, 18477>,
    <18476, 18477, 18481>    <18476, 18481, 18478>,
    <18476, 18478, 18482>    <18476, 18482, 18479>,
    <18476, 18479, 18483>    <18476, 18483, 18480>,
    <18476, 18480, 18484>    <18485, 18493, 18486>,
    <18485, 18486, 18490>    <18485, 18490, 18487>,
    <18485, 18487, 18491>    <18485, 18491, 18488>,
    <18485, 18488, 18492>    <18485, 18492, 18489>,
    <18485, 18489, 18493>    <18494, 18502, 18495>,
    <18494, 18495, 18499>    <18494, 18499, 18496>,
    <18494, 18496, 18500>    <18494, 18500, 18497>,
    <18494, 18497, 18501>    <18494, 18501, 18498>,
    <18494, 18498, 18502>    <18503, 18511, 18504>,
    <18503, 18504, 18508>    <18503, 18508, 18505>,
    <18503, 18505, 18509>    <18503, 18509, 18506>,
    <18503, 18506, 18510>    <18503, 18510, 18507>,
    <18503, 18507, 18511>    <18512, 18520, 18513>,
    <18512, 18513, 18517>    <18512, 18517, 18514>,
    <18512, 18514, 18518>    <18512, 18518, 18515>,
    <18512, 18515, 18519>    <18512, 18519, 18516>,
    <18512, 18516, 18520>    <18521, 18529, 18522>,
    <18521, 18522, 18526>    <18521, 18526, 18523>,
    <18521, 18523, 18527>    <18521, 18527, 18524>,
    <18521, 18524, 18528>    <18521, 18528, 18525>,
    <18521, 18525, 18529>    <18530, 18538, 18531>,
    <18530, 18531, 18535>    <18530, 18535, 18532>,
    <18530, 18532, 18536>    <18530, 18536, 18533>,
    <18530, 18533, 18537>    <18530, 18537, 18534>,
    <18530, 18534, 18538>    <18539, 18547, 18540>,
    <18539, 18540, 18544>    <18539, 18544, 18541>,
    <18539, 18541, 18545>    <18539, 18545, 18542>,
    <18539, 18542, 18546>    <18539, 18546, 18543>,
    <18539, 18543, 18547>    <18548, 18556, 18549>,
    <18548, 18549, 18553>    <18548, 18553, 18550>,
    <18548, 18550, 18554>    <18548, 18554, 18551>,
    <18548, 18551, 18555>    <18548, 18555, 18552>,
    <18548, 18552, 18556>    <18557, 18565, 18558>,
    <18557, 18558, 18562>    <18557, 18562, 18559>,
    <18557, 18559, 18563>    <18557, 18563, 18560>,
    <18557, 18560, 18564>    <18557, 18564, 18561>,
    <18557, 18561, 18565>    <18566, 18574, 18567>,
    <18566, 18567, 18571>    <18566, 18571, 18568>,
    <18566, 18568, 18572>    <18566, 18572, 18569>,
    <18566, 18569, 18573>    <18566, 18573, 18570>,
    <18566, 18570, 18574>    <18575, 18583, 18576>,
    <18575, 18576, 18580>    <18575, 18580, 18577>,
    <18575, 18577, 18581>    <18575, 18581, 18578>,
    <18575, 18578, 18582>    <18575, 18582, 18579>,
    <18575, 18579, 18583>    <18584, 18592, 18585>,
    <18584, 18585, 18589>    <18584, 18589, 18586>,
    <18584, 18586, 18590>    <18584, 18590, 18587>,
    <18584, 18587, 18591>    <18584, 18591, 18588>,
    <18584, 18588, 18592>    <18593, 18601, 18594>,
    <18593, 18594, 18598>    <18593, 18598, 18595>,
    <18593, 18595, 18599>    <18593, 18599, 18596>,
    <18593, 18596, 18600>    <18593, 18600, 18597>,
    <18593, 18597, 18601>    <18602, 18610, 18603>,
    <18602, 18603, 18607>    <18602, 18607, 18604>,
    <18602, 18604, 18608>    <18602, 18608, 18605>,
    <18602, 18605, 18609>    <18602, 18609, 18606>,
    <18602, 18606, 18610>    <18611, 18619, 18612>,
    <18611, 18612, 18616>    <18611, 18616, 18613>,
    <18611, 18613, 18617>    <18611, 18617, 18614>,
    <18611, 18614, 18618>    <18611, 18618, 18615>,
    <18611, 18615, 18619>    <18620, 18628, 18621>,
    <18620, 18621, 18625>    <18620, 18625, 18622>,
    <18620, 18622, 18626>    <18620, 18626, 18623>,
    <18620, 18623, 18627>    <18620, 18627, 18624>,
    <18620, 18624, 18628>    <18629, 18637, 18630>,
    <18629, 18630, 18634>    <18629, 18634, 18631>,
    <18629, 18631, 18635>    <18629, 18635, 18632>,
    <18629, 18632, 18636>    <18629, 18636, 18633>,
    <18629, 18633, 18637>    <18638, 18646, 18639>,
    <18638, 18639, 18643>    <18638, 18643, 18640>,
    <18638, 18640, 18644>    <18638, 18644, 18641>,
    <18638, 18641, 18645>    <18638, 18645, 18642>,
    <18638, 18642, 18646>    <18647, 18655, 18648>,
    <18647, 18648, 18652>    <18647, 18652, 18649>,
    <18647, 18649, 18653>    <18647, 18653, 18650>,
    <18647, 18650, 18654>    <18647, 18654, 18651>,
    <18647, 18651, 18655>    <18656, 18664, 18657>,
    <18656, 18657, 18661>    <18656, 18661, 18658>,
    <18656, 18658, 18662>    <18656, 18662, 18659>,
    <18656, 18659, 18663>    <18656, 18663, 18660>,
    <18656, 18660, 18664>    <18665, 18673, 18666>,
    <18665, 18666, 18670>    <18665, 18670, 18667>,
    <18665, 18667, 18671>    <18665, 18671, 18668>,
    <18665, 18668, 18672>    <18665, 18672, 18669>,
    <18665, 18669, 18673>    <18674, 18682, 18675>,
    <18674, 18675, 18679>    <18674, 18679, 18676>,
    <18674, 18676, 18680>    <18674, 18680, 18677>,
    <18674, 18677, 18681>    <18674, 18681, 18678>,
    <18674, 18678, 18682>    <18683, 18691, 18684>,
    <18683, 18684, 18688>    <18683, 18688, 18685>,
    <18683, 18685, 18689>    <18683, 18689, 18686>,
    <18683, 18686, 18690>    <18683, 18690, 18687>,
    <18683, 18687, 18691>    <18692, 18700, 18693>,
    <18692, 18693, 18697>    <18692, 18697, 18694>,
    <18692, 18694, 18698>    <18692, 18698, 18695>,
    <18692, 18695, 18699>    <18692, 18699, 18696>,
    <18692, 18696, 18700>    <18701, 18709, 18702>,
    <18701, 18702, 18706>    <18701, 18706, 18703>,
    <18701, 18703, 18707>    <18701, 18707, 18704>,
    <18701, 18704, 18708>    <18701, 18708, 18705>,
    <18701, 18705, 18709>    <18710, 18718, 18711>,
    <18710, 18711, 18715>    <18710, 18715, 18712>,
    <18710, 18712, 18716>    <18710, 18716, 18713>,
    <18710, 18713, 18717>    <18710, 18717, 18714>,
    <18710, 18714, 18718>    <18719, 18727, 18720>,
    <18719, 18720, 18724>    <18719, 18724, 18721>,
    <18719, 18721, 18725>    <18719, 18725, 18722>,
    <18719, 18722, 18726>    <18719, 18726, 18723>,
    <18719, 18723, 18727>    <18728, 18736, 18729>,
    <18728, 18729, 18733>    <18728, 18733, 18730>,
    <18728, 18730, 18734>    <18728, 18734, 18731>,
    <18728, 18731, 18735>    <18728, 18735, 18732>,
    <18728, 18732, 18736>    <18737, 18745, 18738>,
    <18737, 18738, 18742>    <18737, 18742, 18739>,
    <18737, 18739, 18743>    <18737, 18743, 18740>,
    <18737, 18740, 18744>    <18737, 18744, 18741>,
    <18737, 18741, 18745>    <18746, 18754, 18747>,
    <18746, 18747, 18751>    <18746, 18751, 18748>,
    <18746, 18748, 18752>    <18746, 18752, 18749>,
    <18746, 18749, 18753>    <18746, 18753, 18750>,
    <18746, 18750, 18754>    <18755, 18763, 18756>,
    <18755, 18756, 18760>    <18755, 18760, 18757>,
    <18755, 18757, 18761>    <18755, 18761, 18758>,
    <18755, 18758, 18762>    <18755, 18762, 18759>,
    <18755, 18759, 18763>    <18764, 18772, 18765>,
    <18764, 18765, 18769>    <18764, 18769, 18766>,
    <18764, 18766, 18770>    <18764, 18770, 18767>,
    <18764, 18767, 18771>    <18764, 18771, 18768>,
    <18764, 18768, 18772>    <18773, 18781, 18774>,
    <18773, 18774, 18778>    <18773, 18778, 18775>,
    <18773, 18775, 18779>    <18773, 18779, 18776>,
    <18773, 18776, 18780>    <18773, 18780, 18777>,
    <18773, 18777, 18781>    <18782, 18790, 18783>,
    <18782, 18783, 18787>    <18782, 18787, 18784>,
    <18782, 18784, 18788>    <18782, 18788, 18785>,
    <18782, 18785, 18789>    <18782, 18789, 18786>,
    <18782, 18786, 18790>    <18791, 18799, 18792>,
    <18791, 18792, 18796>    <18791, 18796, 18793>,
    <18791, 18793, 18797>    <18791, 18797, 18794>,
    <18791, 18794, 18798>    <18791, 18798, 18795>,
    <18791, 18795, 18799>    <18800, 18808, 18801>,
    <18800, 18801, 18805>    <18800, 18805, 18802>,
    <18800, 18802, 18806>    <18800, 18806, 18803>,
    <18800, 18803, 18807>    <18800, 18807, 18804>,
    <18800, 18804, 18808>    <18809, 18817, 18810>,
    <18809, 18810, 18814>    <18809, 18814, 18811>,
    <18809, 18811, 18815>    <18809, 18815, 18812>,
    <18809, 18812, 18816>    <18809, 18816, 18813>,
    <18809, 18813, 18817>    <18818, 18826, 18819>,
    <18818, 18819, 18823>    <18818, 18823, 18820>,
    <18818, 18820, 18824>    <18818, 18824, 18821>,
    <18818, 18821, 18825>    <18818, 18825, 18822>,
    <18818, 18822, 18826>    <18827, 18835, 18828>,
    <18827, 18828, 18832>    <18827, 18832, 18829>,
    <18827, 18829, 18833>    <18827, 18833, 18830>,
    <18827, 18830, 18834>    <18827, 18834, 18831>,
    <18827, 18831, 18835>    <18836, 18844, 18837>,
    <18836, 18837, 18841>    <18836, 18841, 18838>,
    <18836, 18838, 18842>    <18836, 18842, 18839>,
    <18836, 18839, 18843>    <18836, 18843, 18840>,
    <18836, 18840, 18844>    <18845, 18853, 18846>,
    <18845, 18846, 18850>    <18845, 18850, 18847>,
    <18845, 18847, 18851>    <18845, 18851, 18848>,
    <18845, 18848, 18852>    <18845, 18852, 18849>,
    <18845, 18849, 18853>    <18854, 18862, 18855>,
    <18854, 18855, 18859>    <18854, 18859, 18856>,
    <18854, 18856, 18860>    <18854, 18860, 18857>,
    <18854, 18857, 18861>    <18854, 18861, 18858>,
    <18854, 18858, 18862>    <18863, 18871, 18864>,
    <18863, 18864, 18868>    <18863, 18868, 18865>,
    <18863, 18865, 18869>    <18863, 18869, 18866>,
    <18863, 18866, 18870>    <18863, 18870, 18867>,
    <18863, 18867, 18871>    <18872, 18880, 18873>,
    <18872, 18873, 18877>    <18872, 18877, 18874>,
    <18872, 18874, 18878>    <18872, 18878, 18875>,
    <18872, 18875, 18879>    <18872, 18879, 18876>,
    <18872, 18876, 18880>    <18881, 18889, 18882>,
    <18881, 18882, 18886>    <18881, 18886, 18883>,
    <18881, 18883, 18887>    <18881, 18887, 18884>,
    <18881, 18884, 18888>    <18881, 18888, 18885>,
    <18881, 18885, 18889>    <18890, 18898, 18891>,
    <18890, 18891, 18895>    <18890, 18895, 18892>,
    <18890, 18892, 18896>    <18890, 18896, 18893>,
    <18890, 18893, 18897>    <18890, 18897, 18894>,
    <18890, 18894, 18898>    <18899, 18907, 18900>,
    <18899, 18900, 18904>    <18899, 18904, 18901>,
    <18899, 18901, 18905>    <18899, 18905, 18902>,
    <18899, 18902, 18906>    <18899, 18906, 18903>,
    <18899, 18903, 18907>    <18908, 18916, 18909>,
    <18908, 18909, 18913>    <18908, 18913, 18910>,
    <18908, 18910, 18914>    <18908, 18914, 18911>,
    <18908, 18911, 18915>    <18908, 18915, 18912>,
    <18908, 18912, 18916>    <18917, 18925, 18918>,
    <18917, 18918, 18922>    <18917, 18922, 18919>,
    <18917, 18919, 18923>    <18917, 18923, 18920>,
    <18917, 18920, 18924>    <18917, 18924, 18921>,
    <18917, 18921, 18925>    <18926, 18934, 18927>,
    <18926, 18927, 18931>    <18926, 18931, 18928>,
    <18926, 18928, 18932>    <18926, 18932, 18929>,
    <18926, 18929, 18933>    <18926, 18933, 18930>,
    <18926, 18930, 18934>    <18935, 18943, 18936>,
    <18935, 18936, 18940>    <18935, 18940, 18937>,
    <18935, 18937, 18941>    <18935, 18941, 18938>,
    <18935, 18938, 18942>    <18935, 18942, 18939>,
    <18935, 18939, 18943>    <18944, 18952, 18945>,
    <18944, 18945, 18949>    <18944, 18949, 18946>,
    <18944, 18946, 18950>    <18944, 18950, 18947>,
    <18944, 18947, 18951>    <18944, 18951, 18948>,
    <18944, 18948, 18952>    <18953, 18961, 18954>,
    <18953, 18954, 18958>    <18953, 18958, 18955>,
    <18953, 18955, 18959>    <18953, 18959, 18956>,
    <18953, 18956, 18960>    <18953, 18960, 18957>,
    <18953, 18957, 18961>    <18962, 18970, 18963>,
    <18962, 18963, 18967>    <18962, 18967, 18964>,
    <18962, 18964, 18968>    <18962, 18968, 18965>,
    <18962, 18965, 18969>    <18962, 18969, 18966>,
    <18962, 18966, 18970>    <18971, 18979, 18972>,
    <18971, 18972, 18976>    <18971, 18976, 18973>,
    <18971, 18973, 18977>    <18971, 18977, 18974>,
    <18971, 18974, 18978>    <18971, 18978, 18975>,
    <18971, 18975, 18979>    <18980, 18988, 18981>,
    <18980, 18981, 18985>    <18980, 18985, 18982>,
    <18980, 18982, 18986>    <18980, 18986, 18983>,
    <18980, 18983, 18987>    <18980, 18987, 18984>,
    <18980, 18984, 18988>    <18989, 18997, 18990>,
    <18989, 18990, 18994>    <18989, 18994, 18991>,
    <18989, 18991, 18995>    <18989, 18995, 18992>,
    <18989, 18992, 18996>    <18989, 18996, 18993>,
    <18989, 18993, 18997>    <18998, 19006, 18999>,
    <18998, 18999, 19003>    <18998, 19003, 19000>,
    <18998, 19000, 19004>    <18998, 19004, 19001>,
    <18998, 19001, 19005>    <18998, 19005, 19002>,
    <18998, 19002, 19006>    <19007, 19015, 19008>,
    <19007, 19008, 19012>    <19007, 19012, 19009>,
    <19007, 19009, 19013>    <19007, 19013, 19010>,
    <19007, 19010, 19014>    <19007, 19014, 19011>,
    <19007, 19011, 19015>    <19016, 19024, 19017>,
    <19016, 19017, 19021>    <19016, 19021, 19018>,
    <19016, 19018, 19022>    <19016, 19022, 19019>,
    <19016, 19019, 19023>    <19016, 19023, 19020>,
    <19016, 19020, 19024>    <19025, 19033, 19026>,
    <19025, 19026, 19030>    <19025, 19030, 19027>,
    <19025, 19027, 19031>    <19025, 19031, 19028>,
    <19025, 19028, 19032>    <19025, 19032, 19029>,
    <19025, 19029, 19033>    <19034, 19042, 19035>,
    <19034, 19035, 19039>    <19034, 19039, 19036>,
    <19034, 19036, 19040>    <19034, 19040, 19037>,
    <19034, 19037, 19041>    <19034, 19041, 19038>,
    <19034, 19038, 19042>    <19043, 19051, 19044>,
    <19043, 19044, 19048>    <19043, 19048, 19045>,
    <19043, 19045, 19049>    <19043, 19049, 19046>,
    <19043, 19046, 19050>    <19043, 19050, 19047>,
    <19043, 19047, 19051>    <19052, 19060, 19053>,
    <19052, 19053, 19057>    <19052, 19057, 19054>,
    <19052, 19054, 19058>    <19052, 19058, 19055>,
    <19052, 19055, 19059>    <19052, 19059, 19056>,
    <19052, 19056, 19060>    <19061, 19069, 19062>,
    <19061, 19062, 19066>    <19061, 19066, 19063>,
    <19061, 19063, 19067>    <19061, 19067, 19064>,
    <19061, 19064, 19068>    <19061, 19068, 19065>,
    <19061, 19065, 19069>    <19070, 19078, 19071>,
    <19070, 19071, 19075>    <19070, 19075, 19072>,
    <19070, 19072, 19076>    <19070, 19076, 19073>,
    <19070, 19073, 19077>    <19070, 19077, 19074>,
    <19070, 19074, 19078>    <19079, 19087, 19080>,
    <19079, 19080, 19084>    <19079, 19084, 19081>,
    <19079, 19081, 19085>    <19079, 19085, 19082>,
    <19079, 19082, 19086>    <19079, 19086, 19083>,
    <19079, 19083, 19087>    <19088, 19096, 19089>,
    <19088, 19089, 19093>    <19088, 19093, 19090>,
    <19088, 19090, 19094>    <19088, 19094, 19091>,
    <19088, 19091, 19095>    <19088, 19095, 19092>,
    <19088, 19092, 19096>    <19097, 19105, 19098>,
    <19097, 19098, 19102>    <19097, 19102, 19099>,
    <19097, 19099, 19103>    <19097, 19103, 19100>,
    <19097, 19100, 19104>    <19097, 19104, 19101>,
    <19097, 19101, 19105>    <19106, 19114, 19107>,
    <19106, 19107, 19111>    <19106, 19111, 19108>,
    <19106, 19108, 19112>    <19106, 19112, 19109>,
    <19106, 19109, 19113>    <19106, 19113, 19110>,
    <19106, 19110, 19114>    <19115, 19123, 19116>,
    <19115, 19116, 19120>    <19115, 19120, 19117>,
    <19115, 19117, 19121>    <19115, 19121, 19118>,
    <19115, 19118, 19122>    <19115, 19122, 19119>,
    <19115, 19119, 19123>    <19124, 19132, 19125>,
    <19124, 19125, 19129>    <19124, 19129, 19126>,
    <19124, 19126, 19130>    <19124, 19130, 19127>,
    <19124, 19127, 19131>    <19124, 19131, 19128>,
    <19124, 19128, 19132>    <19133, 19141, 19134>,
    <19133, 19134, 19138>    <19133, 19138, 19135>,
    <19133, 19135, 19139>    <19133, 19139, 19136>,
    <19133, 19136, 19140>    <19133, 19140, 19137>,
    <19133, 19137, 19141>    <19142, 19150, 19143>,
    <19142, 19143, 19147>    <19142, 19147, 19144>,
    <19142, 19144, 19148>    <19142, 19148, 19145>,
    <19142, 19145, 19149>    <19142, 19149, 19146>,
    <19142, 19146, 19150>    <19151, 19159, 19152>,
    <19151, 19152, 19156>    <19151, 19156, 19153>,
    <19151, 19153, 19157>    <19151, 19157, 19154>,
    <19151, 19154, 19158>    <19151, 19158, 19155>,
    <19151, 19155, 19159>    <19160, 19168, 19161>,
    <19160, 19161, 19165>    <19160, 19165, 19162>,
    <19160, 19162, 19166>    <19160, 19166, 19163>,
    <19160, 19163, 19167>    <19160, 19167, 19164>,
    <19160, 19164, 19168>    <19169, 19177, 19170>,
    <19169, 19170, 19174>    <19169, 19174, 19171>,
    <19169, 19171, 19175>    <19169, 19175, 19172>,
    <19169, 19172, 19176>    <19169, 19176, 19173>,
    <19169, 19173, 19177>    <19178, 19186, 19179>,
    <19178, 19179, 19183>    <19178, 19183, 19180>,
    <19178, 19180, 19184>    <19178, 19184, 19181>,
    <19178, 19181, 19185>    <19178, 19185, 19182>,
    <19178, 19182, 19186>    <19187, 19195, 19188>,
    <19187, 19188, 19192>    <19187, 19192, 19189>,
    <19187, 19189, 19193>    <19187, 19193, 19190>,
    <19187, 19190, 19194>    <19187, 19194, 19191>,
    <19187, 19191, 19195>    <19196, 19204, 19197>,
    <19196, 19197, 19201>    <19196, 19201, 19198>,
    <19196, 19198, 19202>    <19196, 19202, 19199>,
    <19196, 19199, 19203>    <19196, 19203, 19200>,
    <19196, 19200, 19204>    <19205, 19213, 19206>,
    <19205, 19206, 19210>    <19205, 19210, 19207>,
    <19205, 19207, 19211>    <19205, 19211, 19208>,
    <19205, 19208, 19212>    <19205, 19212, 19209>,
    <19205, 19209, 19213>    <19214, 19222, 19215>,
    <19214, 19215, 19219>    <19214, 19219, 19216>,
    <19214, 19216, 19220>    <19214, 19220, 19217>,
    <19214, 19217, 19221>    <19214, 19221, 19218>,
    <19214, 19218, 19222>    <19223, 19231, 19224>,
    <19223, 19224, 19228>    <19223, 19228, 19225>,
    <19223, 19225, 19229>    <19223, 19229, 19226>,
    <19223, 19226, 19230>    <19223, 19230, 19227>,
    <19223, 19227, 19231>    <19232, 19240, 19233>,
    <19232, 19233, 19237>    <19232, 19237, 19234>,
    <19232, 19234, 19238>    <19232, 19238, 19235>,
    <19232, 19235, 19239>    <19232, 19239, 19236>,
    <19232, 19236, 19240>    <19241, 19249, 19242>,
    <19241, 19242, 19246>    <19241, 19246, 19243>,
    <19241, 19243, 19247>    <19241, 19247, 19244>,
    <19241, 19244, 19248>    <19241, 19248, 19245>,
    <19241, 19245, 19249>    <19250, 19258, 19251>,
    <19250, 19251, 19255>    <19250, 19255, 19252>,
    <19250, 19252, 19256>    <19250, 19256, 19253>,
    <19250, 19253, 19257>    <19250, 19257, 19254>,
    <19250, 19254, 19258>    <19259, 19267, 19260>,
    <19259, 19260, 19264>    <19259, 19264, 19261>,
    <19259, 19261, 19265>    <19259, 19265, 19262>,
    <19259, 19262, 19266>    <19259, 19266, 19263>,
    <19259, 19263, 19267>    <19268, 19276, 19269>,
    <19268, 19269, 19273>    <19268, 19273, 19270>,
    <19268, 19270, 19274>    <19268, 19274, 19271>,
    <19268, 19271, 19275>    <19268, 19275, 19272>,
    <19268, 19272, 19276>    <19277, 19285, 19278>,
    <19277, 19278, 19282>    <19277, 19282, 19279>,
    <19277, 19279, 19283>    <19277, 19283, 19280>,
    <19277, 19280, 19284>    <19277, 19284, 19281>,
    <19277, 19281, 19285>    <19286, 19294, 19287>,
    <19286, 19287, 19291>    <19286, 19291, 19288>,
    <19286, 19288, 19292>    <19286, 19292, 19289>,
    <19286, 19289, 19293>    <19286, 19293, 19290>,
    <19286, 19290, 19294>    <19295, 19303, 19296>,
    <19295, 19296, 19300>    <19295, 19300, 19297>,
    <19295, 19297, 19301>    <19295, 19301, 19298>,
    <19295, 19298, 19302>    <19295, 19302, 19299>,
    <19295, 19299, 19303>    <19304, 19312, 19305>,
    <19304, 19305, 19309>    <19304, 19309, 19306>,
    <19304, 19306, 19310>    <19304, 19310, 19307>,
    <19304, 19307, 19311>    <19304, 19311, 19308>,
    <19304, 19308, 19312>    <19313, 19321, 19314>,
    <19313, 19314, 19318>    <19313, 19318, 19315>,
    <19313, 19315, 19319>    <19313, 19319, 19316>,
    <19313, 19316, 19320>    <19313, 19320, 19317>,
    <19313, 19317, 19321>    <19322, 19330, 19323>,
    <19322, 19323, 19327>    <19322, 19327, 19324>,
    <19322, 19324, 19328>    <19322, 19328, 19325>,
    <19322, 19325, 19329>    <19322, 19329, 19326>,
    <19322, 19326, 19330>    <19331, 19339, 19332>,
    <19331, 19332, 19336>    <19331, 19336, 19333>,
    <19331, 19333, 19337>    <19331, 19337, 19334>,
    <19331, 19334, 19338>    <19331, 19338, 19335>,
    <19331, 19335, 19339>    <19340, 19348, 19341>,
    <19340, 19341, 19345>    <19340, 19345, 19342>,
    <19340, 19342, 19346>    <19340, 19346, 19343>,
    <19340, 19343, 19347>    <19340, 19347, 19344>,
    <19340, 19344, 19348>    <19349, 19357, 19350>,
    <19349, 19350, 19354>    <19349, 19354, 19351>,
    <19349, 19351, 19355>    <19349, 19355, 19352>,
    <19349, 19352, 19356>    <19349, 19356, 19353>,
    <19349, 19353, 19357>    <19358, 19366, 19359>,
    <19358, 19359, 19363>    <19358, 19363, 19360>,
    <19358, 19360, 19364>    <19358, 19364, 19361>,
    <19358, 19361, 19365>    <19358, 19365, 19362>,
    <19358, 19362, 19366>    <19367, 19375, 19368>,
    <19367, 19368, 19372>    <19367, 19372, 19369>,
    <19367, 19369, 19373>    <19367, 19373, 19370>,
    <19367, 19370, 19374>    <19367, 19374, 19371>,
    <19367, 19371, 19375>    <19376, 19384, 19377>,
    <19376, 19377, 19381>    <19376, 19381, 19378>,
    <19376, 19378, 19382>    <19376, 19382, 19379>,
    <19376, 19379, 19383>    <19376, 19383, 19380>,
    <19376, 19380, 19384>    <19385, 19393, 19386>,
    <19385, 19386, 19390>    <19385, 19390, 19387>,
    <19385, 19387, 19391>    <19385, 19391, 19388>,
    <19385, 19388, 19392>    <19385, 19392, 19389>,
    <19385, 19389, 19393>    <19394, 19402, 19395>,
    <19394, 19395, 19399>    <19394, 19399, 19396>,
    <19394, 19396, 19400>    <19394, 19400, 19397>,
    <19394, 19397, 19401>    <19394, 19401, 19398>,
    <19394, 19398, 19402>    <19403, 19411, 19404>,
    <19403, 19404, 19408>    <19403, 19408, 19405>,
    <19403, 19405, 19409>    <19403, 19409, 19406>,
    <19403, 19406, 19410>    <19403, 19410, 19407>,
    <19403, 19407, 19411>    <19412, 19420, 19413>,
    <19412, 19413, 19417>    <19412, 19417, 19414>,
    <19412, 19414, 19418>    <19412, 19418, 19415>,
    <19412, 19415, 19419>    <19412, 19419, 19416>,
    <19412, 19416, 19420>    <19421, 19429, 19422>,
    <19421, 19422, 19426>    <19421, 19426, 19423>,
    <19421, 19423, 19427>    <19421, 19427, 19424>,
    <19421, 19424, 19428>    <19421, 19428, 19425>,
    <19421, 19425, 19429>    <19430, 19438, 19431>,
    <19430, 19431, 19435>    <19430, 19435, 19432>,
    <19430, 19432, 19436>    <19430, 19436, 19433>,
    <19430, 19433, 19437>    <19430, 19437, 19434>,
    <19430, 19434, 19438>    <19439, 19447, 19440>,
    <19439, 19440, 19444>    <19439, 19444, 19441>,
    <19439, 19441, 19445>    <19439, 19445, 19442>,
    <19439, 19442, 19446>    <19439, 19446, 19443>,
    <19439, 19443, 19447>    <19448, 19456, 19449>,
    <19448, 19449, 19453>    <19448, 19453, 19450>,
    <19448, 19450, 19454>    <19448, 19454, 19451>,
    <19448, 19451, 19455>    <19448, 19455, 19452>,
    <19448, 19452, 19456>    <19457, 19465, 19458>,
    <19457, 19458, 19462>    <19457, 19462, 19459>,
    <19457, 19459, 19463>    <19457, 19463, 19460>,
    <19457, 19460, 19464>    <19457, 19464, 19461>,
    <19457, 19461, 19465>    <19466, 19474, 19467>,
    <19466, 19467, 19471>    <19466, 19471, 19468>,
    <19466, 19468, 19472>    <19466, 19472, 19469>,
    <19466, 19469, 19473>    <19466, 19473, 19470>,
    <19466, 19470, 19474>    <19475, 19483, 19476>,
    <19475, 19476, 19480>    <19475, 19480, 19477>,
    <19475, 19477, 19481>    <19475, 19481, 19478>,
    <19475, 19478, 19482>    <19475, 19482, 19479>,
    <19475, 19479, 19483>    <19484, 19492, 19485>,
    <19484, 19485, 19489>    <19484, 19489, 19486>,
    <19484, 19486, 19490>    <19484, 19490, 19487>,
    <19484, 19487, 19491>    <19484, 19491, 19488>,
    <19484, 19488, 19492>    <19493, 19501, 19494>,
    <19493, 19494, 19498>    <19493, 19498, 19495>,
    <19493, 19495, 19499>    <19493, 19499, 19496>,
    <19493, 19496, 19500>    <19493, 19500, 19497>,
    <19493, 19497, 19501>    <19502, 19510, 19503>,
    <19502, 19503, 19507>    <19502, 19507, 19504>,
    <19502, 19504, 19508>    <19502, 19508, 19505>,
    <19502, 19505, 19509>    <19502, 19509, 19506>,
    <19502, 19506, 19510>    <19511, 19519, 19512>,
    <19511, 19512, 19516>    <19511, 19516, 19513>,
    <19511, 19513, 19517>    <19511, 19517, 19514>,
    <19511, 19514, 19518>    <19511, 19518, 19515>,
    <19511, 19515, 19519>    <19520, 19528, 19521>,
    <19520, 19521, 19525>    <19520, 19525, 19522>,
    <19520, 19522, 19526>    <19520, 19526, 19523>,
    <19520, 19523, 19527>    <19520, 19527, 19524>,
    <19520, 19524, 19528>    <19529, 19537, 19530>,
    <19529, 19530, 19534>    <19529, 19534, 19531>,
    <19529, 19531, 19535>    <19529, 19535, 19532>,
    <19529, 19532, 19536>    <19529, 19536, 19533>,
    <19529, 19533, 19537>    <19538, 19546, 19539>,
    <19538, 19539, 19543>    <19538, 19543, 19540>,
    <19538, 19540, 19544>    <19538, 19544, 19541>,
    <19538, 19541, 19545>    <19538, 19545, 19542>,
    <19538, 19542, 19546>    <19547, 19555, 19548>,
    <19547, 19548, 19552>    <19547, 19552, 19549>,
    <19547, 19549, 19553>    <19547, 19553, 19550>,
    <19547, 19550, 19554>    <19547, 19554, 19551>,
    <19547, 19551, 19555>    <19556, 19564, 19557>,
    <19556, 19557, 19561>    <19556, 19561, 19558>,
    <19556, 19558, 19562>    <19556, 19562, 19559>,
    <19556, 19559, 19563>    <19556, 19563, 19560>,
    <19556, 19560, 19564>    <19565, 19573, 19566>,
    <19565, 19566, 19570>    <19565, 19570, 19567>,
    <19565, 19567, 19571>    <19565, 19571, 19568>,
    <19565, 19568, 19572>    <19565, 19572, 19569>,
    <19565, 19569, 19573>    <19574, 19582, 19575>,
    <19574, 19575, 19579>    <19574, 19579, 19576>,
    <19574, 19576, 19580>    <19574, 19580, 19577>,
    <19574, 19577, 19581>    <19574, 19581, 19578>,
    <19574, 19578, 19582>    <19583, 19591, 19584>,
    <19583, 19584, 19588>    <19583, 19588, 19585>,
    <19583, 19585, 19589>    <19583, 19589, 19586>,
    <19583, 19586, 19590>    <19583, 19590, 19587>,
    <19583, 19587, 19591>    <19592, 19600, 19593>,
    <19592, 19593, 19597>    <19592, 19597, 19594>,
    <19592, 19594, 19598>    <19592, 19598, 19595>,
    <19592, 19595, 19599>    <19592, 19599, 19596>,
    <19592, 19596, 19600>    <19601, 19609, 19602>,
    <19601, 19602, 19606>    <19601, 19606, 19603>,
    <19601, 19603, 19607>    <19601, 19607, 19604>,
    <19601, 19604, 19608>    <19601, 19608, 19605>,
    <19601, 19605, 19609>    <19610, 19618, 19611>,
    <19610, 19611, 19615>    <19610, 19615, 19612>,
    <19610, 19612, 19616>    <19610, 19616, 19613>,
    <19610, 19613, 19617>    <19610, 19617, 19614>,
    <19610, 19614, 19618>    <19619, 19627, 19620>,
    <19619, 19620, 19624>    <19619, 19624, 19621>,
    <19619, 19621, 19625>    <19619, 19625, 19622>,
    <19619, 19622, 19626>    <19619, 19626, 19623>,
    <19619, 19623, 19627>    <19628, 19636, 19629>,
    <19628, 19629, 19633>    <19628, 19633, 19630>,
    <19628, 19630, 19634>    <19628, 19634, 19631>,
    <19628, 19631, 19635>    <19628, 19635, 19632>,
    <19628, 19632, 19636>    <19637, 19645, 19638>,
    <19637, 19638, 19642>    <19637, 19642, 19639>,
    <19637, 19639, 19643>    <19637, 19643, 19640>,
    <19637, 19640, 19644>    <19637, 19644, 19641>,
    <19637, 19641, 19645>    <19646, 19654, 19647>,
    <19646, 19647, 19651>    <19646, 19651, 19648>,
    <19646, 19648, 19652>    <19646, 19652, 19649>,
    <19646, 19649, 19653>    <19646, 19653, 19650>,
    <19646, 19650, 19654>    <19655, 19663, 19656>,
    <19655, 19656, 19660>    <19655, 19660, 19657>,
    <19655, 19657, 19661>    <19655, 19661, 19658>,
    <19655, 19658, 19662>    <19655, 19662, 19659>,
    <19655, 19659, 19663>    <19664, 19672, 19665>,
    <19664, 19665, 19669>    <19664, 19669, 19666>,
    <19664, 19666, 19670>    <19664, 19670, 19667>,
    <19664, 19667, 19671>    <19664, 19671, 19668>,
    <19664, 19668, 19672>    <19673, 19681, 19674>,
    <19673, 19674, 19678>    <19673, 19678, 19675>,
    <19673, 19675, 19679>    <19673, 19679, 19676>,
    <19673, 19676, 19680>    <19673, 19680, 19677>,
    <19673, 19677, 19681>    <19682, 19690, 19683>,
    <19682, 19683, 19687>    <19682, 19687, 19684>,
    <19682, 19684, 19688>    <19682, 19688, 19685>,
    <19682, 19685, 19689>    <19682, 19689, 19686>,
    <19682, 19686, 19690>    <19691, 19699, 19692>,
    <19691, 19692, 19696>    <19691, 19696, 19693>,
    <19691, 19693, 19697>    <19691, 19697, 19694>,
    <19691, 19694, 19698>    <19691, 19698, 19695>,
    <19691, 19695, 19699>    <19700, 19708, 19701>,
    <19700, 19701, 19705>    <19700, 19705, 19702>,
    <19700, 19702, 19706>    <19700, 19706, 19703>,
    <19700, 19703, 19707>    <19700, 19707, 19704>,
    <19700, 19704, 19708>    <19709, 19717, 19710>,
    <19709, 19710, 19714>    <19709, 19714, 19711>,
    <19709, 19711, 19715>    <19709, 19715, 19712>,
    <19709, 19712, 19716>    <19709, 19716, 19713>,
    <19709, 19713, 19717>    <19718, 19726, 19719>,
    <19718, 19719, 19723>    <19718, 19723, 19720>,
    <19718, 19720, 19724>    <19718, 19724, 19721>,
    <19718, 19721, 19725>    <19718, 19725, 19722>,
    <19718, 19722, 19726>    <19727, 19735, 19728>,
    <19727, 19728, 19732>    <19727, 19732, 19729>,
    <19727, 19729, 19733>    <19727, 19733, 19730>,
    <19727, 19730, 19734>    <19727, 19734, 19731>,
    <19727, 19731, 19735>    <19736, 19744, 19737>,
    <19736, 19737, 19741>    <19736, 19741, 19738>,
    <19736, 19738, 19742>    <19736, 19742, 19739>,
    <19736, 19739, 19743>    <19736, 19743, 19740>,
    <19736, 19740, 19744>    <19745, 19753, 19746>,
    <19745, 19746, 19750>    <19745, 19750, 19747>,
    <19745, 19747, 19751>    <19745, 19751, 19748>,
    <19745, 19748, 19752>    <19745, 19752, 19749>,
    <19745, 19749, 19753>    <19754, 19762, 19755>,
    <19754, 19755, 19759>    <19754, 19759, 19756>,
    <19754, 19756, 19760>    <19754, 19760, 19757>,
    <19754, 19757, 19761>    <19754, 19761, 19758>,
    <19754, 19758, 19762>    <19763, 19771, 19764>,
    <19763, 19764, 19768>    <19763, 19768, 19765>,
    <19763, 19765, 19769>    <19763, 19769, 19766>,
    <19763, 19766, 19770>    <19763, 19770, 19767>,
    <19763, 19767, 19771>    <19772, 19780, 19773>,
    <19772, 19773, 19777>    <19772, 19777, 19774>,
    <19772, 19774, 19778>    <19772, 19778, 19775>,
    <19772, 19775, 19779>    <19772, 19779, 19776>,
    <19772, 19776, 19780>    <19781, 19789, 19782>,
    <19781, 19782, 19786>    <19781, 19786, 19783>,
    <19781, 19783, 19787>    <19781, 19787, 19784>,
    <19781, 19784, 19788>    <19781, 19788, 19785>,
    <19781, 19785, 19789>    <19790, 19798, 19791>,
    <19790, 19791, 19795>    <19790, 19795, 19792>,
    <19790, 19792, 19796>    <19790, 19796, 19793>,
    <19790, 19793, 19797>    <19790, 19797, 19794>,
    <19790, 19794, 19798>    <19799, 19807, 19800>,
    <19799, 19800, 19804>    <19799, 19804, 19801>,
    <19799, 19801, 19805>    <19799, 19805, 19802>,
    <19799, 19802, 19806>    <19799, 19806, 19803>,
    <19799, 19803, 19807>    <19808, 19816, 19809>,
    <19808, 19809, 19813>    <19808, 19813, 19810>,
    <19808, 19810, 19814>    <19808, 19814, 19811>,
    <19808, 19811, 19815>    <19808, 19815, 19812>,
    <19808, 19812, 19816>    <19817, 19825, 19818>,
    <19817, 19818, 19822>    <19817, 19822, 19819>,
    <19817, 19819, 19823>    <19817, 19823, 19820>,
    <19817, 19820, 19824>    <19817, 19824, 19821>,
    <19817, 19821, 19825>    <19826, 19834, 19827>,
    <19826, 19827, 19831>    <19826, 19831, 19828>,
    <19826, 19828, 19832>    <19826, 19832, 19829>,
    <19826, 19829, 19833>    <19826, 19833, 19830>,
    <19826, 19830, 19834>    <19835, 19843, 19836>,
    <19835, 19836, 19840>    <19835, 19840, 19837>,
    <19835, 19837, 19841>    <19835, 19841, 19838>,
    <19835, 19838, 19842>    <19835, 19842, 19839>,
    <19835, 19839, 19843>    <19844, 19852, 19845>,
    <19844, 19845, 19849>    <19844, 19849, 19846>,
    <19844, 19846, 19850>    <19844, 19850, 19847>,
    <19844, 19847, 19851>    <19844, 19851, 19848>,
    <19844, 19848, 19852>    <19853, 19861, 19854>,
    <19853, 19854, 19858>    <19853, 19858, 19855>,
    <19853, 19855, 19859>    <19853, 19859, 19856>,
    <19853, 19856, 19860>    <19853, 19860, 19857>,
    <19853, 19857, 19861>    <19862, 19870, 19863>,
    <19862, 19863, 19867>    <19862, 19867, 19864>,
    <19862, 19864, 19868>    <19862, 19868, 19865>,
    <19862, 19865, 19869>    <19862, 19869, 19866>,
    <19862, 19866, 19870>    <19871, 19879, 19872>,
    <19871, 19872, 19876>    <19871, 19876, 19873>,
    <19871, 19873, 19877>    <19871, 19877, 19874>,
    <19871, 19874, 19878>    <19871, 19878, 19875>,
    <19871, 19875, 19879>    <19880, 19888, 19881>,
    <19880, 19881, 19885>    <19880, 19885, 19882>,
    <19880, 19882, 19886>    <19880, 19886, 19883>,
    <19880, 19883, 19887>    <19880, 19887, 19884>,
    <19880, 19884, 19888>    <19889, 19897, 19890>,
    <19889, 19890, 19894>    <19889, 19894, 19891>,
    <19889, 19891, 19895>    <19889, 19895, 19892>,
    <19889, 19892, 19896>    <19889, 19896, 19893>,
    <19889, 19893, 19897>    <19898, 19906, 19899>,
    <19898, 19899, 19903>    <19898, 19903, 19900>,
    <19898, 19900, 19904>    <19898, 19904, 19901>,
    <19898, 19901, 19905>    <19898, 19905, 19902>,
    <19898, 19902, 19906>    <19907, 19915, 19908>,
    <19907, 19908, 19912>    <19907, 19912, 19909>,
    <19907, 19909, 19913>    <19907, 19913, 19910>,
    <19907, 19910, 19914>    <19907, 19914, 19911>,
    <19907, 19911, 19915>    <19916, 19924, 19917>,
    <19916, 19917, 19921>    <19916, 19921, 19918>,
    <19916, 19918, 19922>    <19916, 19922, 19919>,
    <19916, 19919, 19923>    <19916, 19923, 19920>,
    <19916, 19920, 19924>    <19925, 19933, 19926>,
    <19925, 19926, 19930>    <19925, 19930, 19927>,
    <19925, 19927, 19931>    <19925, 19931, 19928>,
    <19925, 19928, 19932>    <19925, 19932, 19929>,
    <19925, 19929, 19933>    <19934, 19942, 19935>,
    <19934, 19935, 19939>    <19934, 19939, 19936>,
    <19934, 19936, 19940>    <19934, 19940, 19937>,
    <19934, 19937, 19941>    <19934, 19941, 19938>,
    <19934, 19938, 19942>    <19943, 19951, 19944>,
    <19943, 19944, 19948>    <19943, 19948, 19945>,
    <19943, 19945, 19949>    <19943, 19949, 19946>,
    <19943, 19946, 19950>    <19943, 19950, 19947>,
    <19943, 19947, 19951>    <19952, 19960, 19953>,
    <19952, 19953, 19957>    <19952, 19957, 19954>,
    <19952, 19954, 19958>    <19952, 19958, 19955>,
    <19952, 19955, 19959>    <19952, 19959, 19956>,
    <19952, 19956, 19960>    <19961, 19969, 19962>,
    <19961, 19962, 19966>    <19961, 19966, 19963>,
    <19961, 19963, 19967>    <19961, 19967, 19964>,
    <19961, 19964, 19968>    <19961, 19968, 19965>,
    <19961, 19965, 19969>    <19970, 19978, 19971>,
    <19970, 19971, 19975>    <19970, 19975, 19972>,
    <19970, 19972, 19976>    <19970, 19976, 19973>,
    <19970, 19973, 19977>    <19970, 19977, 19974>,
    <19970, 19974, 19978>    <19979, 19987, 19980>,
    <19979, 19980, 19984>    <19979, 19984, 19981>,
    <19979, 19981, 19985>    <19979, 19985, 19982>,
    <19979, 19982, 19986>    <19979, 19986, 19983>,
    <19979, 19983, 19987>    <19988, 19996, 19989>,
    <19988, 19989, 19993>    <19988, 19993, 19990>,
    <19988, 19990, 19994>    <19988, 19994, 19991>,
    <19988, 19991, 19995>    <19988, 19995, 19992>,
    <19988, 19992, 19996>    <19997, 20005, 19998>,
    <19997, 19998, 20002>    <19997, 20002, 19999>,
    <19997, 19999, 20003>    <19997, 20003, 20000>,
    <19997, 20000, 20004>    <19997, 20004, 20001>,
    <19997, 20001, 20005>    <20006, 20014, 20007>,
    <20006, 20007, 20011>    <20006, 20011, 20008>,
    <20006, 20008, 20012>    <20006, 20012, 20009>,
    <20006, 20009, 20013>    <20006, 20013, 20010>,
    <20006, 20010, 20014>    <20015, 20023, 20016>,
    <20015, 20016, 20020>    <20015, 20020, 20017>,
    <20015, 20017, 20021>    <20015, 20021, 20018>,
    <20015, 20018, 20022>    <20015, 20022, 20019>,
    <20015, 20019, 20023>    <20024, 20032, 20025>,
    <20024, 20025, 20029>    <20024, 20029, 20026>,
    <20024, 20026, 20030>    <20024, 20030, 20027>,
    <20024, 20027, 20031>    <20024, 20031, 20028>,
    <20024, 20028, 20032>    <20033, 20041, 20034>,
    <20033, 20034, 20038>    <20033, 20038, 20035>,
    <20033, 20035, 20039>    <20033, 20039, 20036>,
    <20033, 20036, 20040>    <20033, 20040, 20037>,
    <20033, 20037, 20041>    <20042, 20050, 20043>,
    <20042, 20043, 20047>    <20042, 20047, 20044>,
    <20042, 20044, 20048>    <20042, 20048, 20045>,
    <20042, 20045, 20049>    <20042, 20049, 20046>,
    <20042, 20046, 20050>    <20051, 20059, 20052>,
    <20051, 20052, 20056>    <20051, 20056, 20053>,
    <20051, 20053, 20057>    <20051, 20057, 20054>,
    <20051, 20054, 20058>    <20051, 20058, 20055>,
    <20051, 20055, 20059>    <20060, 20068, 20061>,
    <20060, 20061, 20065>    <20060, 20065, 20062>,
    <20060, 20062, 20066>    <20060, 20066, 20063>,
    <20060, 20063, 20067>    <20060, 20067, 20064>,
    <20060, 20064, 20068>    <20069, 20077, 20070>,
    <20069, 20070, 20074>    <20069, 20074, 20071>,
    <20069, 20071, 20075>    <20069, 20075, 20072>,
    <20069, 20072, 20076>    <20069, 20076, 20073>,
    <20069, 20073, 20077>    <20078, 20086, 20079>,
    <20078, 20079, 20083>    <20078, 20083, 20080>,
    <20078, 20080, 20084>    <20078, 20084, 20081>,
    <20078, 20081, 20085>    <20078, 20085, 20082>,
    <20078, 20082, 20086>    <20087, 20095, 20088>,
    <20087, 20088, 20092>    <20087, 20092, 20089>,
    <20087, 20089, 20093>    <20087, 20093, 20090>,
    <20087, 20090, 20094>    <20087, 20094, 20091>,
    <20087, 20091, 20095>    <20096, 20104, 20097>,
    <20096, 20097, 20101>    <20096, 20101, 20098>,
    <20096, 20098, 20102>    <20096, 20102, 20099>,
    <20096, 20099, 20103>    <20096, 20103, 20100>,
    <20096, 20100, 20104>    <20105, 20113, 20106>,
    <20105, 20106, 20110>    <20105, 20110, 20107>,
    <20105, 20107, 20111>    <20105, 20111, 20108>,
    <20105, 20108, 20112>    <20105, 20112, 20109>,
    <20105, 20109, 20113>    <20114, 20122, 20115>,
    <20114, 20115, 20119>    <20114, 20119, 20116>,
    <20114, 20116, 20120>    <20114, 20120, 20117>,
    <20114, 20117, 20121>    <20114, 20121, 20118>,
    <20114, 20118, 20122>    <20123, 20131, 20124>,
    <20123, 20124, 20128>    <20123, 20128, 20125>,
    <20123, 20125, 20129>    <20123, 20129, 20126>,
    <20123, 20126, 20130>    <20123, 20130, 20127>,
    <20123, 20127, 20131>    <20132, 20140, 20133>,
    <20132, 20133, 20137>    <20132, 20137, 20134>,
    <20132, 20134, 20138>    <20132, 20138, 20135>,
    <20132, 20135, 20139>    <20132, 20139, 20136>,
    <20132, 20136, 20140>    <20141, 20149, 20142>,
    <20141, 20142, 20146>    <20141, 20146, 20143>,
    <20141, 20143, 20147>    <20141, 20147, 20144>,
    <20141, 20144, 20148>    <20141, 20148, 20145>,
    <20141, 20145, 20149>    <20150, 20158, 20151>,
    <20150, 20151, 20155>    <20150, 20155, 20152>,
    <20150, 20152, 20156>    <20150, 20156, 20153>,
    <20150, 20153, 20157>    <20150, 20157, 20154>,
    <20150, 20154, 20158>    <20159, 20167, 20160>,
    <20159, 20160, 20164>    <20159, 20164, 20161>,
    <20159, 20161, 20165>    <20159, 20165, 20162>,
    <20159, 20162, 20166>    <20159, 20166, 20163>,
    <20159, 20163, 20167>    <20168, 20176, 20169>,
    <20168, 20169, 20173>    <20168, 20173, 20170>,
    <20168, 20170, 20174>    <20168, 20174, 20171>,
    <20168, 20171, 20175>    <20168, 20175, 20172>,
    <20168, 20172, 20176>    <20177, 20185, 20178>,
    <20177, 20178, 20182>    <20177, 20182, 20179>,
    <20177, 20179, 20183>    <20177, 20183, 20180>,
    <20177, 20180, 20184>    <20177, 20184, 20181>,
    <20177, 20181, 20185>    <20186, 20194, 20187>,
    <20186, 20187, 20191>    <20186, 20191, 20188>,
    <20186, 20188, 20192>    <20186, 20192, 20189>,
    <20186, 20189, 20193>    <20186, 20193, 20190>,
    <20186, 20190, 20194>    <20195, 20203, 20196>,
    <20195, 20196, 20200>    <20195, 20200, 20197>,
    <20195, 20197, 20201>    <20195, 20201, 20198>,
    <20195, 20198, 20202>    <20195, 20202, 20199>,
    <20195, 20199, 20203>    <20204, 20212, 20205>,
    <20204, 20205, 20209>    <20204, 20209, 20206>,
    <20204, 20206, 20210>    <20204, 20210, 20207>,
    <20204, 20207, 20211>    <20204, 20211, 20208>,
    <20204, 20208, 20212>    <20213, 20221, 20214>,
    <20213, 20214, 20218>    <20213, 20218, 20215>,
    <20213, 20215, 20219>    <20213, 20219, 20216>,
    <20213, 20216, 20220>    <20213, 20220, 20217>,
    <20213, 20217, 20221>    <20222, 20230, 20223>,
    <20222, 20223, 20227>    <20222, 20227, 20224>,
    <20222, 20224, 20228>    <20222, 20228, 20225>,
    <20222, 20225, 20229>    <20222, 20229, 20226>,
    <20222, 20226, 20230>    <20231, 20239, 20232>,
    <20231, 20232, 20236>    <20231, 20236, 20233>,
    <20231, 20233, 20237>    <20231, 20237, 20234>,
    <20231, 20234, 20238>    <20231, 20238, 20235>,
    <20231, 20235, 20239>    <20240, 20248, 20241>,
    <20240, 20241, 20245>    <20240, 20245, 20242>,
    <20240, 20242, 20246>    <20240, 20246, 20243>,
    <20240, 20243, 20247>    <20240, 20247, 20244>,
    <20240, 20244, 20248>    <20249, 20257, 20250>,
    <20249, 20250, 20254>    <20249, 20254, 20251>,
    <20249, 20251, 20255>    <20249, 20255, 20252>,
    <20249, 20252, 20256>    <20249, 20256, 20253>,
    <20249, 20253, 20257>    <20258, 20266, 20259>,
    <20258, 20259, 20263>    <20258, 20263, 20260>,
    <20258, 20260, 20264>    <20258, 20264, 20261>,
    <20258, 20261, 20265>    <20258, 20265, 20262>,
    <20258, 20262, 20266>    <20267, 20275, 20268>,
    <20267, 20268, 20272>    <20267, 20272, 20269>,
    <20267, 20269, 20273>    <20267, 20273, 20270>,
    <20267, 20270, 20274>    <20267, 20274, 20271>,
    <20267, 20271, 20275>    <20276, 20284, 20277>,
    <20276, 20277, 20281>    <20276, 20281, 20278>,
    <20276, 20278, 20282>    <20276, 20282, 20279>,
    <20276, 20279, 20283>    <20276, 20283, 20280>,
    <20276, 20280, 20284>    <20285, 20293, 20286>,
    <20285, 20286, 20290>    <20285, 20290, 20287>,
    <20285, 20287, 20291>    <20285, 20291, 20288>,
    <20285, 20288, 20292>    <20285, 20292, 20289>,
    <20285, 20289, 20293>    <20294, 20302, 20295>,
    <20294, 20295, 20299>    <20294, 20299, 20296>,
    <20294, 20296, 20300>    <20294, 20300, 20297>,
    <20294, 20297, 20301>    <20294, 20301, 20298>,
    <20294, 20298, 20302>    <20303, 20311, 20304>,
    <20303, 20304, 20308>    <20303, 20308, 20305>,
    <20303, 20305, 20309>    <20303, 20309, 20306>,
    <20303, 20306, 20310>    <20303, 20310, 20307>,
    <20303, 20307, 20311>    <20312, 20320, 20313>,
    <20312, 20313, 20317>    <20312, 20317, 20314>,
    <20312, 20314, 20318>    <20312, 20318, 20315>,
    <20312, 20315, 20319>    <20312, 20319, 20316>,
    <20312, 20316, 20320>    <20321, 20329, 20322>,
    <20321, 20322, 20326>    <20321, 20326, 20323>,
    <20321, 20323, 20327>    <20321, 20327, 20324>,
    <20321, 20324, 20328>    <20321, 20328, 20325>,
    <20321, 20325, 20329>    <20330, 20338, 20331>,
    <20330, 20331, 20335>    <20330, 20335, 20332>,
    <20330, 20332, 20336>    <20330, 20336, 20333>,
    <20330, 20333, 20337>    <20330, 20337, 20334>,
    <20330, 20334, 20338>    <20339, 20347, 20340>,
    <20339, 20340, 20344>    <20339, 20344, 20341>,
    <20339, 20341, 20345>    <20339, 20345, 20342>,
    <20339, 20342, 20346>    <20339, 20346, 20343>,
    <20339, 20343, 20347>    <20348, 20356, 20349>,
    <20348, 20349, 20353>    <20348, 20353, 20350>,
    <20348, 20350, 20354>    <20348, 20354, 20351>,
    <20348, 20351, 20355>    <20348, 20355, 20352>,
    <20348, 20352, 20356>    <20357, 20365, 20358>,
    <20357, 20358, 20362>    <20357, 20362, 20359>,
    <20357, 20359, 20363>    <20357, 20363, 20360>,
    <20357, 20360, 20364>    <20357, 20364, 20361>,
    <20357, 20361, 20365>    <20366, 20374, 20367>,
    <20366, 20367, 20371>    <20366, 20371, 20368>,
    <20366, 20368, 20372>    <20366, 20372, 20369>,
    <20366, 20369, 20373>    <20366, 20373, 20370>,
    <20366, 20370, 20374>    <20375, 20383, 20376>,
    <20375, 20376, 20380>    <20375, 20380, 20377>,
    <20375, 20377, 20381>    <20375, 20381, 20378>,
    <20375, 20378, 20382>    <20375, 20382, 20379>,
    <20375, 20379, 20383>    <20384, 20392, 20385>,
    <20384, 20385, 20389>    <20384, 20389, 20386>,
    <20384, 20386, 20390>    <20384, 20390, 20387>,
    <20384, 20387, 20391>    <20384, 20391, 20388>,
    <20384, 20388, 20392>    <20393, 20401, 20394>,
    <20393, 20394, 20398>    <20393, 20398, 20395>,
    <20393, 20395, 20399>    <20393, 20399, 20396>,
    <20393, 20396, 20400>    <20393, 20400, 20397>,
    <20393, 20397, 20401>    <20402, 20410, 20403>,
    <20402, 20403, 20407>    <20402, 20407, 20404>,
    <20402, 20404, 20408>    <20402, 20408, 20405>,
    <20402, 20405, 20409>    <20402, 20409, 20406>,
    <20402, 20406, 20410>    <20411, 20419, 20412>,
    <20411, 20412, 20416>    <20411, 20416, 20413>,
    <20411, 20413, 20417>    <20411, 20417, 20414>,
    <20411, 20414, 20418>    <20411, 20418, 20415>,
    <20411, 20415, 20419>    <20420, 20428, 20421>,
    <20420, 20421, 20425>    <20420, 20425, 20422>,
    <20420, 20422, 20426>    <20420, 20426, 20423>,
    <20420, 20423, 20427>    <20420, 20427, 20424>,
    <20420, 20424, 20428>    <20429, 20437, 20430>,
    <20429, 20430, 20434>    <20429, 20434, 20431>,
    <20429, 20431, 20435>    <20429, 20435, 20432>,
    <20429, 20432, 20436>    <20429, 20436, 20433>,
    <20429, 20433, 20437>    <20438, 20446, 20439>,
    <20438, 20439, 20443>    <20438, 20443, 20440>,
    <20438, 20440, 20444>    <20438, 20444, 20441>,
    <20438, 20441, 20445>    <20438, 20445, 20442>,
    <20438, 20442, 20446>    <20447, 20455, 20448>,
    <20447, 20448, 20452>    <20447, 20452, 20449>,
    <20447, 20449, 20453>    <20447, 20453, 20450>,
    <20447, 20450, 20454>    <20447, 20454, 20451>,
    <20447, 20451, 20455>    <20456, 20464, 20457>,
    <20456, 20457, 20461>    <20456, 20461, 20458>,
    <20456, 20458, 20462>    <20456, 20462, 20459>,
    <20456, 20459, 20463>    <20456, 20463, 20460>,
    <20456, 20460, 20464>    <20465, 20473, 20466>,
    <20465, 20466, 20470>    <20465, 20470, 20467>,
    <20465, 20467, 20471>    <20465, 20471, 20468>,
    <20465, 20468, 20472>    <20465, 20472, 20469>,
    <20465, 20469, 20473>    <20474, 20482, 20475>,
    <20474, 20475, 20479>    <20474, 20479, 20476>,
    <20474, 20476, 20480>    <20474, 20480, 20477>,
    <20474, 20477, 20481>    <20474, 20481, 20478>,
    <20474, 20478, 20482>    <20483, 20491, 20484>,
    <20483, 20484, 20488>    <20483, 20488, 20485>,
    <20483, 20485, 20489>    <20483, 20489, 20486>,
    <20483, 20486, 20490>    <20483, 20490, 20487>,
    <20483, 20487, 20491>    <20492, 20500, 20493>,
    <20492, 20493, 20497>    <20492, 20497, 20494>,
    <20492, 20494, 20498>    <20492, 20498, 20495>,
    <20492, 20495, 20499>    <20492, 20499, 20496>,
    <20492, 20496, 20500>    <20501, 20509, 20502>,
    <20501, 20502, 20506>    <20501, 20506, 20503>,
    <20501, 20503, 20507>    <20501, 20507, 20504>,
    <20501, 20504, 20508>    <20501, 20508, 20505>,
    <20501, 20505, 20509>    <20510, 20518, 20511>,
    <20510, 20511, 20515>    <20510, 20515, 20512>,
    <20510, 20512, 20516>    <20510, 20516, 20513>,
    <20510, 20513, 20517>    <20510, 20517, 20514>,
    <20510, 20514, 20518>    <20519, 20527, 20520>,
    <20519, 20520, 20524>    <20519, 20524, 20521>,
    <20519, 20521, 20525>    <20519, 20525, 20522>,
    <20519, 20522, 20526>    <20519, 20526, 20523>,
    <20519, 20523, 20527>    <20528, 20536, 20529>,
    <20528, 20529, 20533>    <20528, 20533, 20530>,
    <20528, 20530, 20534>    <20528, 20534, 20531>,
    <20528, 20531, 20535>    <20528, 20535, 20532>,
    <20528, 20532, 20536>    <20537, 20545, 20538>,
    <20537, 20538, 20542>    <20537, 20542, 20539>,
    <20537, 20539, 20543>    <20537, 20543, 20540>,
    <20537, 20540, 20544>    <20537, 20544, 20541>,
    <20537, 20541, 20545>    <20546, 20554, 20547>,
    <20546, 20547, 20551>    <20546, 20551, 20548>,
    <20546, 20548, 20552>    <20546, 20552, 20549>,
    <20546, 20549, 20553>    <20546, 20553, 20550>,
    <20546, 20550, 20554>    <20555, 20563, 20556>,
    <20555, 20556, 20560>    <20555, 20560, 20557>,
    <20555, 20557, 20561>    <20555, 20561, 20558>,
    <20555, 20558, 20562>    <20555, 20562, 20559>,
    <20555, 20559, 20563>    <20564, 20572, 20565>,
    <20564, 20565, 20569>    <20564, 20569, 20566>,
    <20564, 20566, 20570>    <20564, 20570, 20567>,
    <20564, 20567, 20571>    <20564, 20571, 20568>,
    <20564, 20568, 20572>    <20573, 20581, 20574>,
    <20573, 20574, 20578>    <20573, 20578, 20575>,
    <20573, 20575, 20579>    <20573, 20579, 20576>,
    <20573, 20576, 20580>    <20573, 20580, 20577>,
    <20573, 20577, 20581>    <20582, 20590, 20583>,
    <20582, 20583, 20587>    <20582, 20587, 20584>,
    <20582, 20584, 20588>    <20582, 20588, 20585>,
    <20582, 20585, 20589>    <20582, 20589, 20586>,
    <20582, 20586, 20590>    <20591, 20599, 20592>,
    <20591, 20592, 20596>    <20591, 20596, 20593>,
    <20591, 20593, 20597>    <20591, 20597, 20594>,
    <20591, 20594, 20598>    <20591, 20598, 20595>,
    <20591, 20595, 20599>    <20600, 20608, 20601>,
    <20600, 20601, 20605>    <20600, 20605, 20602>,
    <20600, 20602, 20606>    <20600, 20606, 20603>,
    <20600, 20603, 20607>    <20600, 20607, 20604>,
    <20600, 20604, 20608>    <20609, 20617, 20610>,
    <20609, 20610, 20614>    <20609, 20614, 20611>,
    <20609, 20611, 20615>    <20609, 20615, 20612>,
    <20609, 20612, 20616>    <20609, 20616, 20613>,
    <20609, 20613, 20617>    <20618, 20626, 20619>,
    <20618, 20619, 20623>    <20618, 20623, 20620>,
    <20618, 20620, 20624>    <20618, 20624, 20621>,
    <20618, 20621, 20625>    <20618, 20625, 20622>,
    <20618, 20622, 20626>    <20627, 20635, 20628>,
    <20627, 20628, 20632>    <20627, 20632, 20629>,
    <20627, 20629, 20633>    <20627, 20633, 20630>,
    <20627, 20630, 20634>    <20627, 20634, 20631>,
    <20627, 20631, 20635>    <20636, 20644, 20637>,
    <20636, 20637, 20641>    <20636, 20641, 20638>,
    <20636, 20638, 20642>    <20636, 20642, 20639>,
    <20636, 20639, 20643>    <20636, 20643, 20640>,
    <20636, 20640, 20644>    <20645, 20653, 20646>,
    <20645, 20646, 20650>    <20645, 20650, 20647>,
    <20645, 20647, 20651>    <20645, 20651, 20648>,
    <20645, 20648, 20652>    <20645, 20652, 20649>,
    <20645, 20649, 20653>    <20654, 20662, 20655>,
    <20654, 20655, 20659>    <20654, 20659, 20656>,
    <20654, 20656, 20660>    <20654, 20660, 20657>,
    <20654, 20657, 20661>    <20654, 20661, 20658>,
    <20654, 20658, 20662>    <20663, 20671, 20664>,
    <20663, 20664, 20668>    <20663, 20668, 20665>,
    <20663, 20665, 20669>    <20663, 20669, 20666>,
    <20663, 20666, 20670>    <20663, 20670, 20667>,
    <20663, 20667, 20671>    <20672, 20680, 20673>,
    <20672, 20673, 20677>    <20672, 20677, 20674>,
    <20672, 20674, 20678>    <20672, 20678, 20675>,
    <20672, 20675, 20679>    <20672, 20679, 20676>,
    <20672, 20676, 20680>    <20681, 20689, 20682>,
    <20681, 20682, 20686>    <20681, 20686, 20683>,
    <20681, 20683, 20687>    <20681, 20687, 20684>,
    <20681, 20684, 20688>    <20681, 20688, 20685>,
    <20681, 20685, 20689>    <20690, 20698, 20691>,
    <20690, 20691, 20695>    <20690, 20695, 20692>,
    <20690, 20692, 20696>    <20690, 20696, 20693>,
    <20690, 20693, 20697>    <20690, 20697, 20694>,
    <20690, 20694, 20698>    <20699, 20707, 20700>,
    <20699, 20700, 20704>    <20699, 20704, 20701>,
    <20699, 20701, 20705>    <20699, 20705, 20702>,
    <20699, 20702, 20706>    <20699, 20706, 20703>,
    <20699, 20703, 20707>    <20708, 20716, 20709>,
    <20708, 20709, 20713>    <20708, 20713, 20710>,
    <20708, 20710, 20714>    <20708, 20714, 20711>,
    <20708, 20711, 20715>    <20708, 20715, 20712>,
    <20708, 20712, 20716>    <20717, 20725, 20718>,
    <20717, 20718, 20722>    <20717, 20722, 20719>,
    <20717, 20719, 20723>    <20717, 20723, 20720>,
    <20717, 20720, 20724>    <20717, 20724, 20721>,
    <20717, 20721, 20725>    <20726, 20734, 20727>,
    <20726, 20727, 20731>    <20726, 20731, 20728>,
    <20726, 20728, 20732>    <20726, 20732, 20729>,
    <20726, 20729, 20733>    <20726, 20733, 20730>,
    <20726, 20730, 20734>    <20735, 20743, 20736>,
    <20735, 20736, 20740>    <20735, 20740, 20737>,
    <20735, 20737, 20741>    <20735, 20741, 20738>,
    <20735, 20738, 20742>    <20735, 20742, 20739>,
    <20735, 20739, 20743>    <20744, 20752, 20745>,
    <20744, 20745, 20749>    <20744, 20749, 20746>,
    <20744, 20746, 20750>    <20744, 20750, 20747>,
    <20744, 20747, 20751>    <20744, 20751, 20748>,
    <20744, 20748, 20752>    <20753, 20761, 20754>,
    <20753, 20754, 20758>    <20753, 20758, 20755>,
    <20753, 20755, 20759>    <20753, 20759, 20756>,
    <20753, 20756, 20760>    <20753, 20760, 20757>,
    <20753, 20757, 20761>    <20762, 20770, 20763>,
    <20762, 20763, 20767>    <20762, 20767, 20764>,
    <20762, 20764, 20768>    <20762, 20768, 20765>,
    <20762, 20765, 20769>    <20762, 20769, 20766>,
    <20762, 20766, 20770>    <20771, 20779, 20772>,
    <20771, 20772, 20776>    <20771, 20776, 20773>,
    <20771, 20773, 20777>    <20771, 20777, 20774>,
    <20771, 20774, 20778>    <20771, 20778, 20775>,
    <20771, 20775, 20779>    <20780, 20788, 20781>,
    <20780, 20781, 20785>    <20780, 20785, 20782>,
    <20780, 20782, 20786>    <20780, 20786, 20783>,
    <20780, 20783, 20787>    <20780, 20787, 20784>,
    <20780, 20784, 20788>    <20789, 20797, 20790>,
    <20789, 20790, 20794>    <20789, 20794, 20791>,
    <20789, 20791, 20795>    <20789, 20795, 20792>,
    <20789, 20792, 20796>    <20789, 20796, 20793>,
    <20789, 20793, 20797>    <20798, 20806, 20799>,
    <20798, 20799, 20803>    <20798, 20803, 20800>,
    <20798, 20800, 20804>    <20798, 20804, 20801>,
    <20798, 20801, 20805>    <20798, 20805, 20802>,
    <20798, 20802, 20806>    <20807, 20815, 20808>,
    <20807, 20808, 20812>    <20807, 20812, 20809>,
    <20807, 20809, 20813>    <20807, 20813, 20810>,
    <20807, 20810, 20814>    <20807, 20814, 20811>,
    <20807, 20811, 20815>    <20816, 20824, 20817>,
    <20816, 20817, 20821>    <20816, 20821, 20818>,
    <20816, 20818, 20822>    <20816, 20822, 20819>,
    <20816, 20819, 20823>    <20816, 20823, 20820>,
    <20816, 20820, 20824>    <20825, 20833, 20826>,
    <20825, 20826, 20830>    <20825, 20830, 20827>,
    <20825, 20827, 20831>    <20825, 20831, 20828>,
    <20825, 20828, 20832>    <20825, 20832, 20829>,
    <20825, 20829, 20833>    <20834, 20842, 20835>,
    <20834, 20835, 20839>    <20834, 20839, 20836>,
    <20834, 20836, 20840>    <20834, 20840, 20837>,
    <20834, 20837, 20841>    <20834, 20841, 20838>,
    <20834, 20838, 20842>    <20843, 20851, 20844>,
    <20843, 20844, 20848>    <20843, 20848, 20845>,
    <20843, 20845, 20849>    <20843, 20849, 20846>,
    <20843, 20846, 20850>    <20843, 20850, 20847>,
    <20843, 20847, 20851>    <20852, 20860, 20853>,
    <20852, 20853, 20857>    <20852, 20857, 20854>,
    <20852, 20854, 20858>    <20852, 20858, 20855>,
    <20852, 20855, 20859>    <20852, 20859, 20856>,
    <20852, 20856, 20860>    <20861, 20869, 20862>,
    <20861, 20862, 20866>    <20861, 20866, 20863>,
    <20861, 20863, 20867>    <20861, 20867, 20864>,
    <20861, 20864, 20868>    <20861, 20868, 20865>,
    <20861, 20865, 20869>    <20870, 20878, 20871>,
    <20870, 20871, 20875>    <20870, 20875, 20872>,
    <20870, 20872, 20876>    <20870, 20876, 20873>,
    <20870, 20873, 20877>    <20870, 20877, 20874>,
    <20870, 20874, 20878>    <20879, 20887, 20880>,
    <20879, 20880, 20884>    <20879, 20884, 20881>,
    <20879, 20881, 20885>    <20879, 20885, 20882>,
    <20879, 20882, 20886>    <20879, 20886, 20883>,
    <20879, 20883, 20887>    <20888, 20896, 20889>,
    <20888, 20889, 20893>    <20888, 20893, 20890>,
    <20888, 20890, 20894>    <20888, 20894, 20891>,
    <20888, 20891, 20895>    <20888, 20895, 20892>,
    <20888, 20892, 20896>    <20897, 20905, 20898>,
    <20897, 20898, 20902>    <20897, 20902, 20899>,
    <20897, 20899, 20903>    <20897, 20903, 20900>,
    <20897, 20900, 20904>    <20897, 20904, 20901>,
    <20897, 20901, 20905>    <20906, 20914, 20907>,
    <20906, 20907, 20911>    <20906, 20911, 20908>,
    <20906, 20908, 20912>    <20906, 20912, 20909>,
    <20906, 20909, 20913>    <20906, 20913, 20910>,
    <20906, 20910, 20914>    <20915, 20923, 20916>,
    <20915, 20916, 20920>    <20915, 20920, 20917>,
    <20915, 20917, 20921>    <20915, 20921, 20918>,
    <20915, 20918, 20922>    <20915, 20922, 20919>,
    <20915, 20919, 20923>    <20924, 20932, 20925>,
    <20924, 20925, 20929>    <20924, 20929, 20926>,
    <20924, 20926, 20930>    <20924, 20930, 20927>,
    <20924, 20927, 20931>    <20924, 20931, 20928>,
    <20924, 20928, 20932>    <20933, 20941, 20934>,
    <20933, 20934, 20938>    <20933, 20938, 20935>,
    <20933, 20935, 20939>    <20933, 20939, 20936>,
    <20933, 20936, 20940>    <20933, 20940, 20937>,
    <20933, 20937, 20941>    <20942, 20950, 20943>,
    <20942, 20943, 20947>    <20942, 20947, 20944>,
    <20942, 20944, 20948>    <20942, 20948, 20945>,
    <20942, 20945, 20949>    <20942, 20949, 20946>,
    <20942, 20946, 20950>    <20951, 20959, 20952>,
    <20951, 20952, 20956>    <20951, 20956, 20953>,
    <20951, 20953, 20957>    <20951, 20957, 20954>,
    <20951, 20954, 20958>    <20951, 20958, 20955>,
    <20951, 20955, 20959>    <20960, 20968, 20961>,
    <20960, 20961, 20965>    <20960, 20965, 20962>,
    <20960, 20962, 20966>    <20960, 20966, 20963>,
    <20960, 20963, 20967>    <20960, 20967, 20964>,
    <20960, 20964, 20968>    <20969, 20977, 20970>,
    <20969, 20970, 20974>    <20969, 20974, 20971>,
    <20969, 20971, 20975>    <20969, 20975, 20972>,
    <20969, 20972, 20976>    <20969, 20976, 20973>,
    <20969, 20973, 20977>    <20978, 20986, 20979>,
    <20978, 20979, 20983>    <20978, 20983, 20980>,
    <20978, 20980, 20984>    <20978, 20984, 20981>,
    <20978, 20981, 20985>    <20978, 20985, 20982>,
    <20978, 20982, 20986>    <20987, 20995, 20988>,
    <20987, 20988, 20992>    <20987, 20992, 20989>,
    <20987, 20989, 20993>    <20987, 20993, 20990>,
    <20987, 20990, 20994>    <20987, 20994, 20991>,
    <20987, 20991, 20995>    <20996, 21004, 20997>,
    <20996, 20997, 21001>    <20996, 21001, 20998>,
    <20996, 20998, 21002>    <20996, 21002, 20999>,
    <20996, 20999, 21003>    <20996, 21003, 21000>,
    <20996, 21000, 21004>    <21005, 21013, 21006>,
    <21005, 21006, 21010>    <21005, 21010, 21007>,
    <21005, 21007, 21011>    <21005, 21011, 21008>,
    <21005, 21008, 21012>    <21005, 21012, 21009>,
    <21005, 21009, 21013>    <21014, 21022, 21015>,
    <21014, 21015, 21019>    <21014, 21019, 21016>,
    <21014, 21016, 21020>    <21014, 21020, 21017>,
    <21014, 21017, 21021>    <21014, 21021, 21018>,
    <21014, 21018, 21022>    <21023, 21031, 21024>,
    <21023, 21024, 21028>    <21023, 21028, 21025>,
    <21023, 21025, 21029>    <21023, 21029, 21026>,
    <21023, 21026, 21030>    <21023, 21030, 21027>,
    <21023, 21027, 21031>    <21032, 21040, 21033>,
    <21032, 21033, 21037>    <21032, 21037, 21034>,
    <21032, 21034, 21038>    <21032, 21038, 21035>,
    <21032, 21035, 21039>    <21032, 21039, 21036>,
    <21032, 21036, 21040>    <21041, 21049, 21042>,
    <21041, 21042, 21046>    <21041, 21046, 21043>,
    <21041, 21043, 21047>    <21041, 21047, 21044>,
    <21041, 21044, 21048>    <21041, 21048, 21045>,
    <21041, 21045, 21049>    <21050, 21058, 21051>,
    <21050, 21051, 21055>    <21050, 21055, 21052>,
    <21050, 21052, 21056>    <21050, 21056, 21053>,
    <21050, 21053, 21057>    <21050, 21057, 21054>,
    <21050, 21054, 21058>    <21059, 21067, 21060>,
    <21059, 21060, 21064>    <21059, 21064, 21061>,
    <21059, 21061, 21065>    <21059, 21065, 21062>,
    <21059, 21062, 21066>    <21059, 21066, 21063>,
    <21059, 21063, 21067>    <21068, 21076, 21069>,
    <21068, 21069, 21073>    <21068, 21073, 21070>,
    <21068, 21070, 21074>    <21068, 21074, 21071>,
    <21068, 21071, 21075>    <21068, 21075, 21072>,
    <21068, 21072, 21076>    <21077, 21085, 21078>,
    <21077, 21078, 21082>    <21077, 21082, 21079>,
    <21077, 21079, 21083>    <21077, 21083, 21080>,
    <21077, 21080, 21084>    <21077, 21084, 21081>,
    <21077, 21081, 21085>    <21086, 21094, 21087>,
    <21086, 21087, 21091>    <21086, 21091, 21088>,
    <21086, 21088, 21092>    <21086, 21092, 21089>,
    <21086, 21089, 21093>    <21086, 21093, 21090>,
    <21086, 21090, 21094>    <21095, 21103, 21096>,
    <21095, 21096, 21100>    <21095, 21100, 21097>,
    <21095, 21097, 21101>    <21095, 21101, 21098>,
    <21095, 21098, 21102>    <21095, 21102, 21099>,
    <21095, 21099, 21103>    <21104, 21112, 21105>,
    <21104, 21105, 21109>    <21104, 21109, 21106>,
    <21104, 21106, 21110>    <21104, 21110, 21107>,
    <21104, 21107, 21111>    <21104, 21111, 21108>,
    <21104, 21108, 21112>    <21113, 21121, 21114>,
    <21113, 21114, 21118>    <21113, 21118, 21115>,
    <21113, 21115, 21119>    <21113, 21119, 21116>,
    <21113, 21116, 21120>    <21113, 21120, 21117>,
    <21113, 21117, 21121>    <21122, 21130, 21123>,
    <21122, 21123, 21127>    <21122, 21127, 21124>,
    <21122, 21124, 21128>    <21122, 21128, 21125>,
    <21122, 21125, 21129>    <21122, 21129, 21126>,
    <21122, 21126, 21130>    <21131, 21139, 21132>,
    <21131, 21132, 21136>    <21131, 21136, 21133>,
    <21131, 21133, 21137>    <21131, 21137, 21134>,
    <21131, 21134, 21138>    <21131, 21138, 21135>,
    <21131, 21135, 21139>    <21140, 21148, 21141>,
    <21140, 21141, 21145>    <21140, 21145, 21142>,
    <21140, 21142, 21146>    <21140, 21146, 21143>,
    <21140, 21143, 21147>    <21140, 21147, 21144>,
    <21140, 21144, 21148>    <21149, 21157, 21150>,
    <21149, 21150, 21154>    <21149, 21154, 21151>,
    <21149, 21151, 21155>    <21149, 21155, 21152>,
    <21149, 21152, 21156>    <21149, 21156, 21153>,
    <21149, 21153, 21157>    <21158, 21166, 21159>,
    <21158, 21159, 21163>    <21158, 21163, 21160>,
    <21158, 21160, 21164>    <21158, 21164, 21161>,
    <21158, 21161, 21165>    <21158, 21165, 21162>,
    <21158, 21162, 21166>    <21167, 21175, 21168>,
    <21167, 21168, 21172>    <21167, 21172, 21169>,
    <21167, 21169, 21173>    <21167, 21173, 21170>,
    <21167, 21170, 21174>    <21167, 21174, 21171>,
    <21167, 21171, 21175>    <21176, 21184, 21177>,
    <21176, 21177, 21181>    <21176, 21181, 21178>,
    <21176, 21178, 21182>    <21176, 21182, 21179>,
    <21176, 21179, 21183>    <21176, 21183, 21180>,
    <21176, 21180, 21184>    <21185, 21193, 21186>,
    <21185, 21186, 21190>    <21185, 21190, 21187>,
    <21185, 21187, 21191>    <21185, 21191, 21188>,
    <21185, 21188, 21192>    <21185, 21192, 21189>,
    <21185, 21189, 21193>    <21194, 21202, 21195>,
    <21194, 21195, 21199>    <21194, 21199, 21196>,
    <21194, 21196, 21200>    <21194, 21200, 21197>,
    <21194, 21197, 21201>    <21194, 21201, 21198>,
    <21194, 21198, 21202>    <21203, 21211, 21204>,
    <21203, 21204, 21208>    <21203, 21208, 21205>,
    <21203, 21205, 21209>    <21203, 21209, 21206>,
    <21203, 21206, 21210>    <21203, 21210, 21207>,
    <21203, 21207, 21211>    <21212, 21220, 21213>,
    <21212, 21213, 21217>    <21212, 21217, 21214>,
    <21212, 21214, 21218>    <21212, 21218, 21215>,
    <21212, 21215, 21219>    <21212, 21219, 21216>,
    <21212, 21216, 21220>    <21221, 21229, 21222>,
    <21221, 21222, 21226>    <21221, 21226, 21223>,
    <21221, 21223, 21227>    <21221, 21227, 21224>,
    <21221, 21224, 21228>    <21221, 21228, 21225>,
    <21221, 21225, 21229>    <21230, 21238, 21231>,
    <21230, 21231, 21235>    <21230, 21235, 21232>,
    <21230, 21232, 21236>    <21230, 21236, 21233>,
    <21230, 21233, 21237>    <21230, 21237, 21234>,
    <21230, 21234, 21238>    <21239, 21247, 21240>,
    <21239, 21240, 21244>    <21239, 21244, 21241>,
    <21239, 21241, 21245>    <21239, 21245, 21242>,
    <21239, 21242, 21246>    <21239, 21246, 21243>,
    <21239, 21243, 21247>    <21248, 21256, 21249>,
    <21248, 21249, 21253>    <21248, 21253, 21250>,
    <21248, 21250, 21254>    <21248, 21254, 21251>,
    <21248, 21251, 21255>    <21248, 21255, 21252>,
    <21248, 21252, 21256>    <21257, 21265, 21258>,
    <21257, 21258, 21262>    <21257, 21262, 21259>,
    <21257, 21259, 21263>    <21257, 21263, 21260>,
    <21257, 21260, 21264>    <21257, 21264, 21261>,
    <21257, 21261, 21265>    <21266, 21274, 21267>,
    <21266, 21267, 21271>    <21266, 21271, 21268>,
    <21266, 21268, 21272>    <21266, 21272, 21269>,
    <21266, 21269, 21273>    <21266, 21273, 21270>,
    <21266, 21270, 21274>    <21275, 21283, 21276>,
    <21275, 21276, 21280>    <21275, 21280, 21277>,
    <21275, 21277, 21281>    <21275, 21281, 21278>,
    <21275, 21278, 21282>    <21275, 21282, 21279>,
    <21275, 21279, 21283>    <21284, 21292, 21285>,
    <21284, 21285, 21289>    <21284, 21289, 21286>,
    <21284, 21286, 21290>    <21284, 21290, 21287>,
    <21284, 21287, 21291>    <21284, 21291, 21288>,
    <21284, 21288, 21292>    <21293, 21301, 21294>,
    <21293, 21294, 21298>    <21293, 21298, 21295>,
    <21293, 21295, 21299>    <21293, 21299, 21296>,
    <21293, 21296, 21300>    <21293, 21300, 21297>,
    <21293, 21297, 21301>    <21302, 21310, 21303>,
    <21302, 21303, 21307>    <21302, 21307, 21304>,
    <21302, 21304, 21308>    <21302, 21308, 21305>,
    <21302, 21305, 21309>    <21302, 21309, 21306>,
    <21302, 21306, 21310>    <21311, 21319, 21312>,
    <21311, 21312, 21316>    <21311, 21316, 21313>,
    <21311, 21313, 21317>    <21311, 21317, 21314>,
    <21311, 21314, 21318>    <21311, 21318, 21315>,
    <21311, 21315, 21319>    <21320, 21328, 21321>,
    <21320, 21321, 21325>    <21320, 21325, 21322>,
    <21320, 21322, 21326>    <21320, 21326, 21323>,
    <21320, 21323, 21327>    <21320, 21327, 21324>,
    <21320, 21324, 21328>    <21329, 21337, 21330>,
    <21329, 21330, 21334>    <21329, 21334, 21331>,
    <21329, 21331, 21335>    <21329, 21335, 21332>,
    <21329, 21332, 21336>    <21329, 21336, 21333>,
    <21329, 21333, 21337>    <21338, 21346, 21339>,
    <21338, 21339, 21343>    <21338, 21343, 21340>,
    <21338, 21340, 21344>    <21338, 21344, 21341>,
    <21338, 21341, 21345>    <21338, 21345, 21342>,
    <21338, 21342, 21346>    <21347, 21355, 21348>,
    <21347, 21348, 21352>    <21347, 21352, 21349>,
    <21347, 21349, 21353>    <21347, 21353, 21350>,
    <21347, 21350, 21354>    <21347, 21354, 21351>,
    <21347, 21351, 21355>    <21356, 21364, 21357>,
    <21356, 21357, 21361>    <21356, 21361, 21358>,
    <21356, 21358, 21362>    <21356, 21362, 21359>,
    <21356, 21359, 21363>    <21356, 21363, 21360>,
    <21356, 21360, 21364>    <21365, 21373, 21366>,
    <21365, 21366, 21370>    <21365, 21370, 21367>,
    <21365, 21367, 21371>    <21365, 21371, 21368>,
    <21365, 21368, 21372>    <21365, 21372, 21369>,
    <21365, 21369, 21373>    <21374, 21382, 21375>,
    <21374, 21375, 21379>    <21374, 21379, 21376>,
    <21374, 21376, 21380>    <21374, 21380, 21377>,
    <21374, 21377, 21381>    <21374, 21381, 21378>,
    <21374, 21378, 21382>    <21383, 21391, 21384>,
    <21383, 21384, 21388>    <21383, 21388, 21385>,
    <21383, 21385, 21389>    <21383, 21389, 21386>,
    <21383, 21386, 21390>    <21383, 21390, 21387>,
    <21383, 21387, 21391>    <21392, 21400, 21393>,
    <21392, 21393, 21397>    <21392, 21397, 21394>,
    <21392, 21394, 21398>    <21392, 21398, 21395>,
    <21392, 21395, 21399>    <21392, 21399, 21396>,
    <21392, 21396, 21400>    <21401, 21409, 21402>,
    <21401, 21402, 21406>    <21401, 21406, 21403>,
    <21401, 21403, 21407>    <21401, 21407, 21404>,
    <21401, 21404, 21408>    <21401, 21408, 21405>,
    <21401, 21405, 21409>    <21410, 21418, 21411>,
    <21410, 21411, 21415>    <21410, 21415, 21412>,
    <21410, 21412, 21416>    <21410, 21416, 21413>,
    <21410, 21413, 21417>    <21410, 21417, 21414>,
    <21410, 21414, 21418>    <21419, 21427, 21420>,
    <21419, 21420, 21424>    <21419, 21424, 21421>,
    <21419, 21421, 21425>    <21419, 21425, 21422>,
    <21419, 21422, 21426>    <21419, 21426, 21423>,
    <21419, 21423, 21427>    <21428, 21436, 21429>,
    <21428, 21429, 21433>    <21428, 21433, 21430>,
    <21428, 21430, 21434>    <21428, 21434, 21431>,
    <21428, 21431, 21435>    <21428, 21435, 21432>,
    <21428, 21432, 21436>    <21437, 21445, 21438>,
    <21437, 21438, 21442>    <21437, 21442, 21439>,
    <21437, 21439, 21443>    <21437, 21443, 21440>,
    <21437, 21440, 21444>    <21437, 21444, 21441>,
    <21437, 21441, 21445>    <21446, 21454, 21447>,
    <21446, 21447, 21451>    <21446, 21451, 21448>,
    <21446, 21448, 21452>    <21446, 21452, 21449>,
    <21446, 21449, 21453>    <21446, 21453, 21450>,
    <21446, 21450, 21454>    <21455, 21463, 21456>,
    <21455, 21456, 21460>    <21455, 21460, 21457>,
    <21455, 21457, 21461>    <21455, 21461, 21458>,
    <21455, 21458, 21462>    <21455, 21462, 21459>,
    <21455, 21459, 21463>    <21464, 21472, 21465>,
    <21464, 21465, 21469>    <21464, 21469, 21466>,
    <21464, 21466, 21470>    <21464, 21470, 21467>,
    <21464, 21467, 21471>    <21464, 21471, 21468>,
    <21464, 21468, 21472>    <21473, 21481, 21474>,
    <21473, 21474, 21478>    <21473, 21478, 21475>,
    <21473, 21475, 21479>    <21473, 21479, 21476>,
    <21473, 21476, 21480>    <21473, 21480, 21477>,
    <21473, 21477, 21481>    <21482, 21490, 21483>,
    <21482, 21483, 21487>    <21482, 21487, 21484>,
    <21482, 21484, 21488>    <21482, 21488, 21485>,
    <21482, 21485, 21489>    <21482, 21489, 21486>,
    <21482, 21486, 21490>    <21491, 21499, 21492>,
    <21491, 21492, 21496>    <21491, 21496, 21493>,
    <21491, 21493, 21497>    <21491, 21497, 21494>,
    <21491, 21494, 21498>    <21491, 21498, 21495>,
    <21491, 21495, 21499>    <21500, 21508, 21501>,
    <21500, 21501, 21505>    <21500, 21505, 21502>,
    <21500, 21502, 21506>    <21500, 21506, 21503>,
    <21500, 21503, 21507>    <21500, 21507, 21504>,
    <21500, 21504, 21508>    <21509, 21517, 21510>,
    <21509, 21510, 21514>    <21509, 21514, 21511>,
    <21509, 21511, 21515>    <21509, 21515, 21512>,
    <21509, 21512, 21516>    <21509, 21516, 21513>,
    <21509, 21513, 21517>    <21518, 21526, 21519>,
    <21518, 21519, 21523>    <21518, 21523, 21520>,
    <21518, 21520, 21524>    <21518, 21524, 21521>,
    <21518, 21521, 21525>    <21518, 21525, 21522>,
    <21518, 21522, 21526>    <21527, 21535, 21528>,
    <21527, 21528, 21532>    <21527, 21532, 21529>,
    <21527, 21529, 21533>    <21527, 21533, 21530>,
    <21527, 21530, 21534>    <21527, 21534, 21531>,
    <21527, 21531, 21535>    <21536, 21544, 21537>,
    <21536, 21537, 21541>    <21536, 21541, 21538>,
    <21536, 21538, 21542>    <21536, 21542, 21539>,
    <21536, 21539, 21543>    <21536, 21543, 21540>,
    <21536, 21540, 21544>    <21545, 21553, 21546>,
    <21545, 21546, 21550>    <21545, 21550, 21547>,
    <21545, 21547, 21551>    <21545, 21551, 21548>,
    <21545, 21548, 21552>    <21545, 21552, 21549>,
    <21545, 21549, 21553>    <21554, 21562, 21555>,
    <21554, 21555, 21559>    <21554, 21559, 21556>,
    <21554, 21556, 21560>    <21554, 21560, 21557>,
    <21554, 21557, 21561>    <21554, 21561, 21558>,
    <21554, 21558, 21562>    <21563, 21571, 21564>,
    <21563, 21564, 21568>    <21563, 21568, 21565>,
    <21563, 21565, 21569>    <21563, 21569, 21566>,
    <21563, 21566, 21570>    <21563, 21570, 21567>,
    <21563, 21567, 21571>    <21572, 21580, 21573>,
    <21572, 21573, 21577>    <21572, 21577, 21574>,
    <21572, 21574, 21578>    <21572, 21578, 21575>,
    <21572, 21575, 21579>    <21572, 21579, 21576>,
    <21572, 21576, 21580>    <21581, 21589, 21582>,
    <21581, 21582, 21586>    <21581, 21586, 21583>,
    <21581, 21583, 21587>    <21581, 21587, 21584>,
    <21581, 21584, 21588>    <21581, 21588, 21585>,
    <21581, 21585, 21589>    <21590, 21598, 21591>,
    <21590, 21591, 21595>    <21590, 21595, 21592>,
    <21590, 21592, 21596>    <21590, 21596, 21593>,
    <21590, 21593, 21597>    <21590, 21597, 21594>,
    <21590, 21594, 21598>    <21599, 21607, 21600>,
    <21599, 21600, 21604>    <21599, 21604, 21601>,
    <21599, 21601, 21605>    <21599, 21605, 21602>,
    <21599, 21602, 21606>    <21599, 21606, 21603>,
    <21599, 21603, 21607>    <21608, 21616, 21609>,
    <21608, 21609, 21613>    <21608, 21613, 21610>,
    <21608, 21610, 21614>    <21608, 21614, 21611>,
    <21608, 21611, 21615>    <21608, 21615, 21612>,
    <21608, 21612, 21616>    <21617, 21625, 21618>,
    <21617, 21618, 21622>    <21617, 21622, 21619>,
    <21617, 21619, 21623>    <21617, 21623, 21620>,
    <21617, 21620, 21624>    <21617, 21624, 21621>,
    <21617, 21621, 21625>    <21626, 21634, 21627>,
    <21626, 21627, 21631>    <21626, 21631, 21628>,
    <21626, 21628, 21632>    <21626, 21632, 21629>,
    <21626, 21629, 21633>    <21626, 21633, 21630>,
    <21626, 21630, 21634>    <21635, 21643, 21636>,
    <21635, 21636, 21640>    <21635, 21640, 21637>,
    <21635, 21637, 21641>    <21635, 21641, 21638>,
    <21635, 21638, 21642>    <21635, 21642, 21639>,
    <21635, 21639, 21643>    <21644, 21652, 21645>,
    <21644, 21645, 21649>    <21644, 21649, 21646>,
    <21644, 21646, 21650>    <21644, 21650, 21647>,
    <21644, 21647, 21651>    <21644, 21651, 21648>,
    <21644, 21648, 21652>    <21653, 21661, 21654>,
    <21653, 21654, 21658>    <21653, 21658, 21655>,
    <21653, 21655, 21659>    <21653, 21659, 21656>,
    <21653, 21656, 21660>    <21653, 21660, 21657>,
    <21653, 21657, 21661>    <21662, 21670, 21663>,
    <21662, 21663, 21667>    <21662, 21667, 21664>,
    <21662, 21664, 21668>    <21662, 21668, 21665>,
    <21662, 21665, 21669>    <21662, 21669, 21666>,
    <21662, 21666, 21670>    <21671, 21679, 21672>,
    <21671, 21672, 21676>    <21671, 21676, 21673>,
    <21671, 21673, 21677>    <21671, 21677, 21674>,
    <21671, 21674, 21678>    <21671, 21678, 21675>,
    <21671, 21675, 21679>    <21680, 21688, 21681>,
    <21680, 21681, 21685>    <21680, 21685, 21682>,
    <21680, 21682, 21686>    <21680, 21686, 21683>,
    <21680, 21683, 21687>    <21680, 21687, 21684>,
    <21680, 21684, 21688>    <21689, 21697, 21690>,
    <21689, 21690, 21694>    <21689, 21694, 21691>,
    <21689, 21691, 21695>    <21689, 21695, 21692>,
    <21689, 21692, 21696>    <21689, 21696, 21693>,
    <21689, 21693, 21697>    <21698, 21706, 21699>,
    <21698, 21699, 21703>    <21698, 21703, 21700>,
    <21698, 21700, 21704>    <21698, 21704, 21701>,
    <21698, 21701, 21705>    <21698, 21705, 21702>,
    <21698, 21702, 21706>    <21707, 21715, 21708>,
    <21707, 21708, 21712>    <21707, 21712, 21709>,
    <21707, 21709, 21713>    <21707, 21713, 21710>,
    <21707, 21710, 21714>    <21707, 21714, 21711>,
    <21707, 21711, 21715>    <21716, 21724, 21717>,
    <21716, 21717, 21721>    <21716, 21721, 21718>,
    <21716, 21718, 21722>    <21716, 21722, 21719>,
    <21716, 21719, 21723>    <21716, 21723, 21720>,
    <21716, 21720, 21724>    <21725, 21733, 21726>,
    <21725, 21726, 21730>    <21725, 21730, 21727>,
    <21725, 21727, 21731>    <21725, 21731, 21728>,
    <21725, 21728, 21732>    <21725, 21732, 21729>,
    <21725, 21729, 21733>    <21734, 21742, 21735>,
    <21734, 21735, 21739>    <21734, 21739, 21736>,
    <21734, 21736, 21740>    <21734, 21740, 21737>,
    <21734, 21737, 21741>    <21734, 21741, 21738>,
    <21734, 21738, 21742>    <21743, 21751, 21744>,
    <21743, 21744, 21748>    <21743, 21748, 21745>,
    <21743, 21745, 21749>    <21743, 21749, 21746>,
    <21743, 21746, 21750>    <21743, 21750, 21747>,
    <21743, 21747, 21751>    <21752, 21760, 21753>,
    <21752, 21753, 21757>    <21752, 21757, 21754>,
    <21752, 21754, 21758>    <21752, 21758, 21755>,
    <21752, 21755, 21759>    <21752, 21759, 21756>,
    <21752, 21756, 21760>    <21761, 21769, 21762>,
    <21761, 21762, 21766>    <21761, 21766, 21763>,
    <21761, 21763, 21767>    <21761, 21767, 21764>,
    <21761, 21764, 21768>    <21761, 21768, 21765>,
    <21761, 21765, 21769>    <21770, 21778, 21771>,
    <21770, 21771, 21775>    <21770, 21775, 21772>,
    <21770, 21772, 21776>    <21770, 21776, 21773>,
    <21770, 21773, 21777>    <21770, 21777, 21774>,
    <21770, 21774, 21778>    <21779, 21787, 21780>,
    <21779, 21780, 21784>    <21779, 21784, 21781>,
    <21779, 21781, 21785>    <21779, 21785, 21782>,
    <21779, 21782, 21786>    <21779, 21786, 21783>,
    <21779, 21783, 21787>    <21788, 21796, 21789>,
    <21788, 21789, 21793>    <21788, 21793, 21790>,
    <21788, 21790, 21794>    <21788, 21794, 21791>,
    <21788, 21791, 21795>    <21788, 21795, 21792>,
    <21788, 21792, 21796>    <21797, 21805, 21798>,
    <21797, 21798, 21802>    <21797, 21802, 21799>,
    <21797, 21799, 21803>    <21797, 21803, 21800>,
    <21797, 21800, 21804>    <21797, 21804, 21801>,
    <21797, 21801, 21805>    <21806, 21814, 21807>,
    <21806, 21807, 21811>    <21806, 21811, 21808>,
    <21806, 21808, 21812>    <21806, 21812, 21809>,
    <21806, 21809, 21813>    <21806, 21813, 21810>,
    <21806, 21810, 21814>    <21815, 21823, 21816>,
    <21815, 21816, 21820>    <21815, 21820, 21817>,
    <21815, 21817, 21821>    <21815, 21821, 21818>,
    <21815, 21818, 21822>    <21815, 21822, 21819>,
    <21815, 21819, 21823>    <21824, 21832, 21825>,
    <21824, 21825, 21829>    <21824, 21829, 21826>,
    <21824, 21826, 21830>    <21824, 21830, 21827>,
    <21824, 21827, 21831>    <21824, 21831, 21828>,
    <21824, 21828, 21832>    <21833, 21841, 21834>,
    <21833, 21834, 21838>    <21833, 21838, 21835>,
    <21833, 21835, 21839>    <21833, 21839, 21836>,
    <21833, 21836, 21840>    <21833, 21840, 21837>,
    <21833, 21837, 21841>    <21842, 21850, 21843>,
    <21842, 21843, 21847>    <21842, 21847, 21844>,
    <21842, 21844, 21848>    <21842, 21848, 21845>,
    <21842, 21845, 21849>    <21842, 21849, 21846>,
    <21842, 21846, 21850>    <21851, 21859, 21852>,
    <21851, 21852, 21856>    <21851, 21856, 21853>,
    <21851, 21853, 21857>    <21851, 21857, 21854>,
    <21851, 21854, 21858>    <21851, 21858, 21855>,
    <21851, 21855, 21859>    <21860, 21868, 21861>,
    <21860, 21861, 21865>    <21860, 21865, 21862>,
    <21860, 21862, 21866>    <21860, 21866, 21863>,
    <21860, 21863, 21867>    <21860, 21867, 21864>,
    <21860, 21864, 21868>    <21869, 21877, 21870>,
    <21869, 21870, 21874>    <21869, 21874, 21871>,
    <21869, 21871, 21875>    <21869, 21875, 21872>,
    <21869, 21872, 21876>    <21869, 21876, 21873>,
    <21869, 21873, 21877>    <21878, 21886, 21879>,
    <21878, 21879, 21883>    <21878, 21883, 21880>,
    <21878, 21880, 21884>    <21878, 21884, 21881>,
    <21878, 21881, 21885>    <21878, 21885, 21882>,
    <21878, 21882, 21886>    <21887, 21895, 21888>,
    <21887, 21888, 21892>    <21887, 21892, 21889>,
    <21887, 21889, 21893>    <21887, 21893, 21890>,
    <21887, 21890, 21894>    <21887, 21894, 21891>,
    <21887, 21891, 21895>    <21896, 21904, 21897>,
    <21896, 21897, 21901>    <21896, 21901, 21898>,
    <21896, 21898, 21902>    <21896, 21902, 21899>,
    <21896, 21899, 21903>    <21896, 21903, 21900>,
    <21896, 21900, 21904>    <21905, 21913, 21906>,
    <21905, 21906, 21910>    <21905, 21910, 21907>,
    <21905, 21907, 21911>    <21905, 21911, 21908>,
    <21905, 21908, 21912>    <21905, 21912, 21909>,
    <21905, 21909, 21913>    <21914, 21922, 21915>,
    <21914, 21915, 21919>    <21914, 21919, 21916>,
    <21914, 21916, 21920>    <21914, 21920, 21917>,
    <21914, 21917, 21921>    <21914, 21921, 21918>,
    <21914, 21918, 21922>    <21923, 21931, 21924>,
    <21923, 21924, 21928>    <21923, 21928, 21925>,
    <21923, 21925, 21929>    <21923, 21929, 21926>,
    <21923, 21926, 21930>    <21923, 21930, 21927>,
    <21923, 21927, 21931>    <21932, 21940, 21933>,
    <21932, 21933, 21937>    <21932, 21937, 21934>,
    <21932, 21934, 21938>    <21932, 21938, 21935>,
    <21932, 21935, 21939>    <21932, 21939, 21936>,
    <21932, 21936, 21940>    <21941, 21949, 21942>,
    <21941, 21942, 21946>    <21941, 21946, 21943>,
    <21941, 21943, 21947>    <21941, 21947, 21944>,
    <21941, 21944, 21948>    <21941, 21948, 21945>,
    <21941, 21945, 21949>    <21950, 21958, 21951>,
    <21950, 21951, 21955>    <21950, 21955, 21952>,
    <21950, 21952, 21956>    <21950, 21956, 21953>,
    <21950, 21953, 21957>    <21950, 21957, 21954>,
    <21950, 21954, 21958>    <21959, 21967, 21960>,
    <21959, 21960, 21964>    <21959, 21964, 21961>,
    <21959, 21961, 21965>    <21959, 21965, 21962>,
    <21959, 21962, 21966>    <21959, 21966, 21963>,
    <21959, 21963, 21967>    <21968, 21976, 21969>,
    <21968, 21969, 21973>    <21968, 21973, 21970>,
    <21968, 21970, 21974>    <21968, 21974, 21971>,
    <21968, 21971, 21975>    <21968, 21975, 21972>,
    <21968, 21972, 21976>    <21977, 21985, 21978>,
    <21977, 21978, 21982>    <21977, 21982, 21979>,
    <21977, 21979, 21983>    <21977, 21983, 21980>,
    <21977, 21980, 21984>    <21977, 21984, 21981>,
    <21977, 21981, 21985>    <21986, 21994, 21987>,
    <21986, 21987, 21991>    <21986, 21991, 21988>,
    <21986, 21988, 21992>    <21986, 21992, 21989>,
    <21986, 21989, 21993>    <21986, 21993, 21990>,
    <21986, 21990, 21994>    <21995, 22003, 21996>,
    <21995, 21996, 22000>    <21995, 22000, 21997>,
    <21995, 21997, 22001>    <21995, 22001, 21998>,
    <21995, 21998, 22002>    <21995, 22002, 21999>,
    <21995, 21999, 22003>    <22004, 22012, 22005>,
    <22004, 22005, 22009>    <22004, 22009, 22006>,
    <22004, 22006, 22010>    <22004, 22010, 22007>,
    <22004, 22007, 22011>    <22004, 22011, 22008>,
    <22004, 22008, 22012>    <22013, 22021, 22014>,
    <22013, 22014, 22018>    <22013, 22018, 22015>,
    <22013, 22015, 22019>    <22013, 22019, 22016>,
    <22013, 22016, 22020>    <22013, 22020, 22017>,
    <22013, 22017, 22021>    <22022, 22030, 22023>,
    <22022, 22023, 22027>    <22022, 22027, 22024>,
    <22022, 22024, 22028>    <22022, 22028, 22025>,
    <22022, 22025, 22029>    <22022, 22029, 22026>,
    <22022, 22026, 22030>    <22031, 22039, 22032>,
    <22031, 22032, 22036>    <22031, 22036, 22033>,
    <22031, 22033, 22037>    <22031, 22037, 22034>,
    <22031, 22034, 22038>    <22031, 22038, 22035>,
    <22031, 22035, 22039>    <22040, 22048, 22041>,
    <22040, 22041, 22045>    <22040, 22045, 22042>,
    <22040, 22042, 22046>    <22040, 22046, 22043>,
    <22040, 22043, 22047>    <22040, 22047, 22044>,
    <22040, 22044, 22048>    <22049, 22057, 22050>,
    <22049, 22050, 22054>    <22049, 22054, 22051>,
    <22049, 22051, 22055>    <22049, 22055, 22052>,
    <22049, 22052, 22056>    <22049, 22056, 22053>,
    <22049, 22053, 22057>    <22058, 22066, 22059>,
    <22058, 22059, 22063>    <22058, 22063, 22060>,
    <22058, 22060, 22064>    <22058, 22064, 22061>,
    <22058, 22061, 22065>    <22058, 22065, 22062>,
    <22058, 22062, 22066>    <22067, 22075, 22068>,
    <22067, 22068, 22072>    <22067, 22072, 22069>,
    <22067, 22069, 22073>    <22067, 22073, 22070>,
    <22067, 22070, 22074>    <22067, 22074, 22071>,
    <22067, 22071, 22075>    <22076, 22084, 22077>,
    <22076, 22077, 22081>    <22076, 22081, 22078>,
    <22076, 22078, 22082>    <22076, 22082, 22079>,
    <22076, 22079, 22083>    <22076, 22083, 22080>,
    <22076, 22080, 22084>    <22085, 22093, 22086>,
    <22085, 22086, 22090>    <22085, 22090, 22087>,
    <22085, 22087, 22091>    <22085, 22091, 22088>,
    <22085, 22088, 22092>    <22085, 22092, 22089>,
    <22085, 22089, 22093>    <22094, 22102, 22095>,
    <22094, 22095, 22099>    <22094, 22099, 22096>,
    <22094, 22096, 22100>    <22094, 22100, 22097>,
    <22094, 22097, 22101>    <22094, 22101, 22098>,
    <22094, 22098, 22102>    <22103, 22111, 22104>,
    <22103, 22104, 22108>    <22103, 22108, 22105>,
    <22103, 22105, 22109>    <22103, 22109, 22106>,
    <22103, 22106, 22110>    <22103, 22110, 22107>,
    <22103, 22107, 22111>    <22112, 22120, 22113>,
    <22112, 22113, 22117>    <22112, 22117, 22114>,
    <22112, 22114, 22118>    <22112, 22118, 22115>,
    <22112, 22115, 22119>    <22112, 22119, 22116>,
    <22112, 22116, 22120>    <22121, 22129, 22122>,
    <22121, 22122, 22126>    <22121, 22126, 22123>,
    <22121, 22123, 22127>    <22121, 22127, 22124>,
    <22121, 22124, 22128>    <22121, 22128, 22125>,
    <22121, 22125, 22129>    <22130, 22138, 22131>,
    <22130, 22131, 22135>    <22130, 22135, 22132>,
    <22130, 22132, 22136>    <22130, 22136, 22133>,
    <22130, 22133, 22137>    <22130, 22137, 22134>,
    <22130, 22134, 22138>    <22139, 22147, 22140>,
    <22139, 22140, 22144>    <22139, 22144, 22141>,
    <22139, 22141, 22145>    <22139, 22145, 22142>,
    <22139, 22142, 22146>    <22139, 22146, 22143>,
    <22139, 22143, 22147>    <22148, 22156, 22149>,
    <22148, 22149, 22153>    <22148, 22153, 22150>,
    <22148, 22150, 22154>    <22148, 22154, 22151>,
    <22148, 22151, 22155>    <22148, 22155, 22152>,
    <22148, 22152, 22156>    <22157, 22165, 22158>,
    <22157, 22158, 22162>    <22157, 22162, 22159>,
    <22157, 22159, 22163>    <22157, 22163, 22160>,
    <22157, 22160, 22164>    <22157, 22164, 22161>,
    <22157, 22161, 22165>    <22166, 22174, 22167>,
    <22166, 22167, 22171>    <22166, 22171, 22168>,
    <22166, 22168, 22172>    <22166, 22172, 22169>,
    <22166, 22169, 22173>    <22166, 22173, 22170>,
    <22166, 22170, 22174>    <22175, 22183, 22176>,
    <22175, 22176, 22180>    <22175, 22180, 22177>,
    <22175, 22177, 22181>    <22175, 22181, 22178>,
    <22175, 22178, 22182>    <22175, 22182, 22179>,
    <22175, 22179, 22183>    <22184, 22192, 22185>,
    <22184, 22185, 22189>    <22184, 22189, 22186>,
    <22184, 22186, 22190>    <22184, 22190, 22187>,
    <22184, 22187, 22191>    <22184, 22191, 22188>,
    <22184, 22188, 22192>    <22193, 22201, 22194>,
    <22193, 22194, 22198>    <22193, 22198, 22195>,
    <22193, 22195, 22199>    <22193, 22199, 22196>,
    <22193, 22196, 22200>    <22193, 22200, 22197>,
    <22193, 22197, 22201>    <22202, 22210, 22203>,
    <22202, 22203, 22207>    <22202, 22207, 22204>,
    <22202, 22204, 22208>    <22202, 22208, 22205>,
    <22202, 22205, 22209>    <22202, 22209, 22206>,
    <22202, 22206, 22210>    <22211, 22219, 22212>,
    <22211, 22212, 22216>    <22211, 22216, 22213>,
    <22211, 22213, 22217>    <22211, 22217, 22214>,
    <22211, 22214, 22218>    <22211, 22218, 22215>,
    <22211, 22215, 22219>    <22220, 22228, 22221>,
    <22220, 22221, 22225>    <22220, 22225, 22222>,
    <22220, 22222, 22226>    <22220, 22226, 22223>,
    <22220, 22223, 22227>    <22220, 22227, 22224>,
    <22220, 22224, 22228>    <22229, 22237, 22230>,
    <22229, 22230, 22234>    <22229, 22234, 22231>,
    <22229, 22231, 22235>    <22229, 22235, 22232>,
    <22229, 22232, 22236>    <22229, 22236, 22233>,
    <22229, 22233, 22237>    <22238, 22246, 22239>,
    <22238, 22239, 22243>    <22238, 22243, 22240>,
    <22238, 22240, 22244>    <22238, 22244, 22241>,
    <22238, 22241, 22245>    <22238, 22245, 22242>,
    <22238, 22242, 22246>    <22247, 22255, 22248>,
    <22247, 22248, 22252>    <22247, 22252, 22249>,
    <22247, 22249, 22253>    <22247, 22253, 22250>,
    <22247, 22250, 22254>    <22247, 22254, 22251>,
    <22247, 22251, 22255>    <22256, 22264, 22257>,
    <22256, 22257, 22261>    <22256, 22261, 22258>,
    <22256, 22258, 22262>    <22256, 22262, 22259>,
    <22256, 22259, 22263>    <22256, 22263, 22260>,
    <22256, 22260, 22264>    <22265, 22273, 22266>,
    <22265, 22266, 22270>    <22265, 22270, 22267>,
    <22265, 22267, 22271>    <22265, 22271, 22268>,
    <22265, 22268, 22272>    <22265, 22272, 22269>,
    <22265, 22269, 22273>    <22274, 22282, 22275>,
    <22274, 22275, 22279>    <22274, 22279, 22276>,
    <22274, 22276, 22280>    <22274, 22280, 22277>,
    <22274, 22277, 22281>    <22274, 22281, 22278>,
    <22274, 22278, 22282>    <22283, 22291, 22284>,
    <22283, 22284, 22288>    <22283, 22288, 22285>,
    <22283, 22285, 22289>    <22283, 22289, 22286>,
    <22283, 22286, 22290>    <22283, 22290, 22287>,
    <22283, 22287, 22291>    <22292, 22300, 22293>,
    <22292, 22293, 22297>    <22292, 22297, 22294>,
    <22292, 22294, 22298>    <22292, 22298, 22295>,
    <22292, 22295, 22299>    <22292, 22299, 22296>,
    <22292, 22296, 22300>    <22301, 22309, 22302>,
    <22301, 22302, 22306>    <22301, 22306, 22303>,
    <22301, 22303, 22307>    <22301, 22307, 22304>,
    <22301, 22304, 22308>    <22301, 22308, 22305>,
    <22301, 22305, 22309>    <22310, 22318, 22311>,
    <22310, 22311, 22315>    <22310, 22315, 22312>,
    <22310, 22312, 22316>    <22310, 22316, 22313>,
    <22310, 22313, 22317>    <22310, 22317, 22314>,
    <22310, 22314, 22318>    <22319, 22327, 22320>,
    <22319, 22320, 22324>    <22319, 22324, 22321>,
    <22319, 22321, 22325>    <22319, 22325, 22322>,
    <22319, 22322, 22326>    <22319, 22326, 22323>,
    <22319, 22323, 22327>    <22328, 22336, 22329>,
    <22328, 22329, 22333>    <22328, 22333, 22330>,
    <22328, 22330, 22334>    <22328, 22334, 22331>,
    <22328, 22331, 22335>    <22328, 22335, 22332>,
    <22328, 22332, 22336>    <22337, 22345, 22338>,
    <22337, 22338, 22342>    <22337, 22342, 22339>,
    <22337, 22339, 22343>    <22337, 22343, 22340>,
    <22337, 22340, 22344>    <22337, 22344, 22341>,
    <22337, 22341, 22345>    <22346, 22354, 22347>,
    <22346, 22347, 22351>    <22346, 22351, 22348>,
    <22346, 22348, 22352>    <22346, 22352, 22349>,
    <22346, 22349, 22353>    <22346, 22353, 22350>,
    <22346, 22350, 22354>    <22355, 22363, 22356>,
    <22355, 22356, 22360>    <22355, 22360, 22357>,
    <22355, 22357, 22361>    <22355, 22361, 22358>,
    <22355, 22358, 22362>    <22355, 22362, 22359>,
    <22355, 22359, 22363>    <22364, 22372, 22365>,
    <22364, 22365, 22369>    <22364, 22369, 22366>,
    <22364, 22366, 22370>    <22364, 22370, 22367>,
    <22364, 22367, 22371>    <22364, 22371, 22368>,
    <22364, 22368, 22372>    <22373, 22381, 22374>,
    <22373, 22374, 22378>    <22373, 22378, 22375>,
    <22373, 22375, 22379>    <22373, 22379, 22376>,
    <22373, 22376, 22380>    <22373, 22380, 22377>,
    <22373, 22377, 22381>    <22382, 22390, 22383>,
    <22382, 22383, 22387>    <22382, 22387, 22384>,
    <22382, 22384, 22388>    <22382, 22388, 22385>,
    <22382, 22385, 22389>    <22382, 22389, 22386>,
    <22382, 22386, 22390>    <22391, 22399, 22392>,
    <22391, 22392, 22396>    <22391, 22396, 22393>,
    <22391, 22393, 22397>    <22391, 22397, 22394>,
    <22391, 22394, 22398>    <22391, 22398, 22395>,
    <22391, 22395, 22399>    <22400, 22408, 22401>,
    <22400, 22401, 22405>    <22400, 22405, 22402>,
    <22400, 22402, 22406>    <22400, 22406, 22403>,
    <22400, 22403, 22407>    <22400, 22407, 22404>,
    <22400, 22404, 22408>    <22409, 22417, 22410>,
    <22409, 22410, 22414>    <22409, 22414, 22411>,
    <22409, 22411, 22415>    <22409, 22415, 22412>,
    <22409, 22412, 22416>    <22409, 22416, 22413>,
    <22409, 22413, 22417>    <22418, 22426, 22419>,
    <22418, 22419, 22423>    <22418, 22423, 22420>,
    <22418, 22420, 22424>    <22418, 22424, 22421>,
    <22418, 22421, 22425>    <22418, 22425, 22422>,
    <22418, 22422, 22426>    <22427, 22435, 22428>,
    <22427, 22428, 22432>    <22427, 22432, 22429>,
    <22427, 22429, 22433>    <22427, 22433, 22430>,
    <22427, 22430, 22434>    <22427, 22434, 22431>,
    <22427, 22431, 22435>    <22436, 22444, 22437>,
    <22436, 22437, 22441>    <22436, 22441, 22438>,
    <22436, 22438, 22442>    <22436, 22442, 22439>,
    <22436, 22439, 22443>    <22436, 22443, 22440>,
    <22436, 22440, 22444>    <22445, 22453, 22446>,
    <22445, 22446, 22450>    <22445, 22450, 22447>,
    <22445, 22447, 22451>    <22445, 22451, 22448>,
    <22445, 22448, 22452>    <22445, 22452, 22449>,
    <22445, 22449, 22453>    <22454, 22462, 22455>,
    <22454, 22455, 22459>    <22454, 22459, 22456>,
    <22454, 22456, 22460>    <22454, 22460, 22457>,
    <22454, 22457, 22461>    <22454, 22461, 22458>,
    <22454, 22458, 22462>    <22463, 22471, 22464>,
    <22463, 22464, 22468>    <22463, 22468, 22465>,
    <22463, 22465, 22469>    <22463, 22469, 22466>,
    <22463, 22466, 22470>    <22463, 22470, 22467>,
    <22463, 22467, 22471>    <22472, 22480, 22473>,
    <22472, 22473, 22477>    <22472, 22477, 22474>,
    <22472, 22474, 22478>    <22472, 22478, 22475>,
    <22472, 22475, 22479>    <22472, 22479, 22476>,
    <22472, 22476, 22480>    <22481, 22489, 22482>,
    <22481, 22482, 22486>    <22481, 22486, 22483>,
    <22481, 22483, 22487>    <22481, 22487, 22484>,
    <22481, 22484, 22488>    <22481, 22488, 22485>,
    <22481, 22485, 22489>    <22490, 22498, 22491>,
    <22490, 22491, 22495>    <22490, 22495, 22492>,
    <22490, 22492, 22496>    <22490, 22496, 22493>,
    <22490, 22493, 22497>    <22490, 22497, 22494>,
    <22490, 22494, 22498>    <22499, 22507, 22500>,
    <22499, 22500, 22504>    <22499, 22504, 22501>,
    <22499, 22501, 22505>    <22499, 22505, 22502>,
    <22499, 22502, 22506>    <22499, 22506, 22503>,
    <22499, 22503, 22507>    <22508, 22516, 22509>,
    <22508, 22509, 22513>    <22508, 22513, 22510>,
    <22508, 22510, 22514>    <22508, 22514, 22511>,
    <22508, 22511, 22515>    <22508, 22515, 22512>,
    <22508, 22512, 22516>    <22517, 22525, 22518>,
    <22517, 22518, 22522>    <22517, 22522, 22519>,
    <22517, 22519, 22523>    <22517, 22523, 22520>,
    <22517, 22520, 22524>    <22517, 22524, 22521>,
    <22517, 22521, 22525>    <22526, 22534, 22527>,
    <22526, 22527, 22531>    <22526, 22531, 22528>,
    <22526, 22528, 22532>    <22526, 22532, 22529>,
    <22526, 22529, 22533>    <22526, 22533, 22530>,
    <22526, 22530, 22534>    <22535, 22543, 22536>,
    <22535, 22536, 22540>    <22535, 22540, 22537>,
    <22535, 22537, 22541>    <22535, 22541, 22538>,
    <22535, 22538, 22542>    <22535, 22542, 22539>,
    <22535, 22539, 22543>    <22544, 22552, 22545>,
    <22544, 22545, 22549>    <22544, 22549, 22546>,
    <22544, 22546, 22550>    <22544, 22550, 22547>,
    <22544, 22547, 22551>    <22544, 22551, 22548>,
    <22544, 22548, 22552>    <22553, 22561, 22554>,
    <22553, 22554, 22558>    <22553, 22558, 22555>,
    <22553, 22555, 22559>    <22553, 22559, 22556>,
    <22553, 22556, 22560>    <22553, 22560, 22557>,
    <22553, 22557, 22561>    <22562, 22570, 22563>,
    <22562, 22563, 22567>    <22562, 22567, 22564>,
    <22562, 22564, 22568>    <22562, 22568, 22565>,
    <22562, 22565, 22569>    <22562, 22569, 22566>,
    <22562, 22566, 22570>    <22571, 22579, 22572>,
    <22571, 22572, 22576>    <22571, 22576, 22573>,
    <22571, 22573, 22577>    <22571, 22577, 22574>,
    <22571, 22574, 22578>    <22571, 22578, 22575>,
    <22571, 22575, 22579>    <22580, 22588, 22581>,
    <22580, 22581, 22585>    <22580, 22585, 22582>,
    <22580, 22582, 22586>    <22580, 22586, 22583>,
    <22580, 22583, 22587>    <22580, 22587, 22584>,
    <22580, 22584, 22588>    <22589, 22597, 22590>,
    <22589, 22590, 22594>    <22589, 22594, 22591>,
    <22589, 22591, 22595>    <22589, 22595, 22592>,
    <22589, 22592, 22596>    <22589, 22596, 22593>,
    <22589, 22593, 22597>    <22598, 22606, 22599>,
    <22598, 22599, 22603>    <22598, 22603, 22600>,
    <22598, 22600, 22604>    <22598, 22604, 22601>,
    <22598, 22601, 22605>    <22598, 22605, 22602>,
    <22598, 22602, 22606>    <22607, 22615, 22608>,
    <22607, 22608, 22612>    <22607, 22612, 22609>,
    <22607, 22609, 22613>    <22607, 22613, 22610>,
    <22607, 22610, 22614>    <22607, 22614, 22611>,
    <22607, 22611, 22615>    <22616, 22624, 22617>,
    <22616, 22617, 22621>    <22616, 22621, 22618>,
    <22616, 22618, 22622>    <22616, 22622, 22619>,
    <22616, 22619, 22623>    <22616, 22623, 22620>,
    <22616, 22620, 22624>    <22625, 22633, 22626>,
    <22625, 22626, 22630>    <22625, 22630, 22627>,
    <22625, 22627, 22631>    <22625, 22631, 22628>,
    <22625, 22628, 22632>    <22625, 22632, 22629>,
    <22625, 22629, 22633>    <22634, 22642, 22635>,
    <22634, 22635, 22639>    <22634, 22639, 22636>,
    <22634, 22636, 22640>    <22634, 22640, 22637>,
    <22634, 22637, 22641>    <22634, 22641, 22638>,
    <22634, 22638, 22642>    <22643, 22651, 22644>,
    <22643, 22644, 22648>    <22643, 22648, 22645>,
    <22643, 22645, 22649>    <22643, 22649, 22646>,
    <22643, 22646, 22650>    <22643, 22650, 22647>,
    <22643, 22647, 22651>    <22652, 22660, 22653>,
    <22652, 22653, 22657>    <22652, 22657, 22654>,
    <22652, 22654, 22658>    <22652, 22658, 22655>,
    <22652, 22655, 22659>    <22652, 22659, 22656>,
    <22652, 22656, 22660>    <22661, 22669, 22662>,
    <22661, 22662, 22666>    <22661, 22666, 22663>,
    <22661, 22663, 22667>    <22661, 22667, 22664>,
    <22661, 22664, 22668>    <22661, 22668, 22665>,
    <22661, 22665, 22669>    <22670, 22678, 22671>,
    <22670, 22671, 22675>    <22670, 22675, 22672>,
    <22670, 22672, 22676>    <22670, 22676, 22673>,
    <22670, 22673, 22677>    <22670, 22677, 22674>,
    <22670, 22674, 22678>    <22679, 22687, 22680>,
    <22679, 22680, 22684>    <22679, 22684, 22681>,
    <22679, 22681, 22685>    <22679, 22685, 22682>,
    <22679, 22682, 22686>    <22679, 22686, 22683>,
    <22679, 22683, 22687>    <22688, 22696, 22689>,
    <22688, 22689, 22693>    <22688, 22693, 22690>,
    <22688, 22690, 22694>    <22688, 22694, 22691>,
    <22688, 22691, 22695>    <22688, 22695, 22692>,
    <22688, 22692, 22696>    <22697, 22705, 22698>,
    <22697, 22698, 22702>    <22697, 22702, 22699>,
    <22697, 22699, 22703>    <22697, 22703, 22700>,
    <22697, 22700, 22704>    <22697, 22704, 22701>,
    <22697, 22701, 22705>    <22706, 22714, 22707>,
    <22706, 22707, 22711>    <22706, 22711, 22708>,
    <22706, 22708, 22712>    <22706, 22712, 22709>,
    <22706, 22709, 22713>    <22706, 22713, 22710>,
    <22706, 22710, 22714>    <22715, 22723, 22716>,
    <22715, 22716, 22720>    <22715, 22720, 22717>,
    <22715, 22717, 22721>    <22715, 22721, 22718>,
    <22715, 22718, 22722>    <22715, 22722, 22719>,
    <22715, 22719, 22723>    <22724, 22732, 22725>,
    <22724, 22725, 22729>    <22724, 22729, 22726>,
    <22724, 22726, 22730>    <22724, 22730, 22727>,
    <22724, 22727, 22731>    <22724, 22731, 22728>,
    <22724, 22728, 22732>    <22733, 22741, 22734>,
    <22733, 22734, 22738>    <22733, 22738, 22735>,
    <22733, 22735, 22739>    <22733, 22739, 22736>,
    <22733, 22736, 22740>    <22733, 22740, 22737>,
    <22733, 22737, 22741>    <22742, 22750, 22743>,
    <22742, 22743, 22747>    <22742, 22747, 22744>,
    <22742, 22744, 22748>    <22742, 22748, 22745>,
    <22742, 22745, 22749>    <22742, 22749, 22746>,
    <22742, 22746, 22750>    <22751, 22759, 22752>,
    <22751, 22752, 22756>    <22751, 22756, 22753>,
    <22751, 22753, 22757>    <22751, 22757, 22754>,
    <22751, 22754, 22758>    <22751, 22758, 22755>,
    <22751, 22755, 22759>    <22760, 22768, 22761>,
    <22760, 22761, 22765>    <22760, 22765, 22762>,
    <22760, 22762, 22766>    <22760, 22766, 22763>,
    <22760, 22763, 22767>    <22760, 22767, 22764>,
    <22760, 22764, 22768>    <22769, 22777, 22770>,
    <22769, 22770, 22774>    <22769, 22774, 22771>,
    <22769, 22771, 22775>    <22769, 22775, 22772>,
    <22769, 22772, 22776>    <22769, 22776, 22773>,
    <22769, 22773, 22777>    <22778, 22786, 22779>,
    <22778, 22779, 22783>    <22778, 22783, 22780>,
    <22778, 22780, 22784>    <22778, 22784, 22781>,
    <22778, 22781, 22785>    <22778, 22785, 22782>,
    <22778, 22782, 22786>    <22787, 22795, 22788>,
    <22787, 22788, 22792>    <22787, 22792, 22789>,
    <22787, 22789, 22793>    <22787, 22793, 22790>,
    <22787, 22790, 22794>    <22787, 22794, 22791>,
    <22787, 22791, 22795>    <22796, 22804, 22797>,
    <22796, 22797, 22801>    <22796, 22801, 22798>,
    <22796, 22798, 22802>    <22796, 22802, 22799>,
    <22796, 22799, 22803>    <22796, 22803, 22800>,
    <22796, 22800, 22804>    <22805, 22813, 22806>,
    <22805, 22806, 22810>    <22805, 22810, 22807>,
    <22805, 22807, 22811>    <22805, 22811, 22808>,
    <22805, 22808, 22812>    <22805, 22812, 22809>,
    <22805, 22809, 22813>    <22814, 22822, 22815>,
    <22814, 22815, 22819>    <22814, 22819, 22816>,
    <22814, 22816, 22820>    <22814, 22820, 22817>,
    <22814, 22817, 22821>    <22814, 22821, 22818>,
    <22814, 22818, 22822>    <22823, 22831, 22824>,
    <22823, 22824, 22828>    <22823, 22828, 22825>,
    <22823, 22825, 22829>    <22823, 22829, 22826>,
    <22823, 22826, 22830>    <22823, 22830, 22827>,
    <22823, 22827, 22831>    <22832, 22840, 22833>,
    <22832, 22833, 22837>    <22832, 22837, 22834>,
    <22832, 22834, 22838>    <22832, 22838, 22835>,
    <22832, 22835, 22839>    <22832, 22839, 22836>,
    <22832, 22836, 22840>    <22841, 22849, 22842>,
    <22841, 22842, 22846>    <22841, 22846, 22843>,
    <22841, 22843, 22847>    <22841, 22847, 22844>,
    <22841, 22844, 22848>    <22841, 22848, 22845>,
    <22841, 22845, 22849>    <22850, 22858, 22851>,
    <22850, 22851, 22855>    <22850, 22855, 22852>,
    <22850, 22852, 22856>    <22850, 22856, 22853>,
    <22850, 22853, 22857>    <22850, 22857, 22854>,
    <22850, 22854, 22858>    <22859, 22867, 22860>,
    <22859, 22860, 22864>    <22859, 22864, 22861>,
    <22859, 22861, 22865>    <22859, 22865, 22862>,
    <22859, 22862, 22866>    <22859, 22866, 22863>,
    <22859, 22863, 22867>    <22868, 22876, 22869>,
    <22868, 22869, 22873>    <22868, 22873, 22870>,
    <22868, 22870, 22874>    <22868, 22874, 22871>,
    <22868, 22871, 22875>    <22868, 22875, 22872>,
    <22868, 22872, 22876>    <22877, 22885, 22878>,
    <22877, 22878, 22882>    <22877, 22882, 22879>,
    <22877, 22879, 22883>    <22877, 22883, 22880>,
    <22877, 22880, 22884>    <22877, 22884, 22881>,
    <22877, 22881, 22885>    <22886, 22894, 22887>,
    <22886, 22887, 22891>    <22886, 22891, 22888>,
    <22886, 22888, 22892>    <22886, 22892, 22889>,
    <22886, 22889, 22893>    <22886, 22893, 22890>,
    <22886, 22890, 22894>    <22895, 22903, 22896>,
    <22895, 22896, 22900>    <22895, 22900, 22897>,
    <22895, 22897, 22901>    <22895, 22901, 22898>,
    <22895, 22898, 22902>    <22895, 22902, 22899>,
    <22895, 22899, 22903>    <22904, 22912, 22905>,
    <22904, 22905, 22909>    <22904, 22909, 22906>,
    <22904, 22906, 22910>    <22904, 22910, 22907>,
    <22904, 22907, 22911>    <22904, 22911, 22908>,
    <22904, 22908, 22912>    <22913, 22921, 22914>,
    <22913, 22914, 22918>    <22913, 22918, 22915>,
    <22913, 22915, 22919>    <22913, 22919, 22916>,
    <22913, 22916, 22920>    <22913, 22920, 22917>,
    <22913, 22917, 22921>    <22922, 22930, 22923>,
    <22922, 22923, 22927>    <22922, 22927, 22924>,
    <22922, 22924, 22928>    <22922, 22928, 22925>,
    <22922, 22925, 22929>    <22922, 22929, 22926>,
    <22922, 22926, 22930>    <22931, 22939, 22932>,
    <22931, 22932, 22936>    <22931, 22936, 22933>,
    <22931, 22933, 22937>    <22931, 22937, 22934>,
    <22931, 22934, 22938>    <22931, 22938, 22935>,
    <22931, 22935, 22939>    <22940, 22948, 22941>,
    <22940, 22941, 22945>    <22940, 22945, 22942>,
    <22940, 22942, 22946>    <22940, 22946, 22943>,
    <22940, 22943, 22947>    <22940, 22947, 22944>,
    <22940, 22944, 22948>    <22949, 22957, 22950>,
    <22949, 22950, 22954>    <22949, 22954, 22951>,
    <22949, 22951, 22955>    <22949, 22955, 22952>,
    <22949, 22952, 22956>    <22949, 22956, 22953>,
    <22949, 22953, 22957>    <22958, 22966, 22959>,
    <22958, 22959, 22963>    <22958, 22963, 22960>,
    <22958, 22960, 22964>    <22958, 22964, 22961>,
    <22958, 22961, 22965>    <22958, 22965, 22962>,
    <22958, 22962, 22966>    <22967, 22975, 22968>,
    <22967, 22968, 22972>    <22967, 22972, 22969>,
    <22967, 22969, 22973>    <22967, 22973, 22970>,
    <22967, 22970, 22974>    <22967, 22974, 22971>,
    <22967, 22971, 22975>    <22976, 22984, 22977>,
    <22976, 22977, 22981>    <22976, 22981, 22978>,
    <22976, 22978, 22982>    <22976, 22982, 22979>,
    <22976, 22979, 22983>    <22976, 22983, 22980>,
    <22976, 22980, 22984>    <22985, 22993, 22986>,
    <22985, 22986, 22990>    <22985, 22990, 22987>,
    <22985, 22987, 22991>    <22985, 22991, 22988>,
    <22985, 22988, 22992>    <22985, 22992, 22989>,
    <22985, 22989, 22993>    <22994, 23002, 22995>,
    <22994, 22995, 22999>    <22994, 22999, 22996>,
    <22994, 22996, 23000>    <22994, 23000, 22997>,
    <22994, 22997, 23001>    <22994, 23001, 22998>,
    <22994, 22998, 23002>    <23003, 23011, 23004>,
    <23003, 23004, 23008>    <23003, 23008, 23005>,
    <23003, 23005, 23009>    <23003, 23009, 23006>,
    <23003, 23006, 23010>    <23003, 23010, 23007>,
    <23003, 23007, 23011>    <23012, 23020, 23013>,
    <23012, 23013, 23017>    <23012, 23017, 23014>,
    <23012, 23014, 23018>    <23012, 23018, 23015>,
    <23012, 23015, 23019>    <23012, 23019, 23016>,
    <23012, 23016, 23020>    <23021, 23029, 23022>,
    <23021, 23022, 23026>    <23021, 23026, 23023>,
    <23021, 23023, 23027>    <23021, 23027, 23024>,
    <23021, 23024, 23028>    <23021, 23028, 23025>,
    <23021, 23025, 23029>    <23030, 23038, 23031>,
    <23030, 23031, 23035>    <23030, 23035, 23032>,
    <23030, 23032, 23036>    <23030, 23036, 23033>,
    <23030, 23033, 23037>    <23030, 23037, 23034>,
    <23030, 23034, 23038>    <23039, 23047, 23040>,
    <23039, 23040, 23044>    <23039, 23044, 23041>,
    <23039, 23041, 23045>    <23039, 23045, 23042>,
    <23039, 23042, 23046>    <23039, 23046, 23043>,
    <23039, 23043, 23047>    <23048, 23056, 23049>,
    <23048, 23049, 23053>    <23048, 23053, 23050>,
    <23048, 23050, 23054>    <23048, 23054, 23051>,
    <23048, 23051, 23055>    <23048, 23055, 23052>,
    <23048, 23052, 23056>    <23057, 23065, 23058>,
    <23057, 23058, 23062>    <23057, 23062, 23059>,
    <23057, 23059, 23063>    <23057, 23063, 23060>,
    <23057, 23060, 23064>    <23057, 23064, 23061>,
    <23057, 23061, 23065>    <23066, 23074, 23067>,
    <23066, 23067, 23071>    <23066, 23071, 23068>,
    <23066, 23068, 23072>    <23066, 23072, 23069>,
    <23066, 23069, 23073>    <23066, 23073, 23070>,
    <23066, 23070, 23074>    <23075, 23083, 23076>,
    <23075, 23076, 23080>    <23075, 23080, 23077>,
    <23075, 23077, 23081>    <23075, 23081, 23078>,
    <23075, 23078, 23082>    <23075, 23082, 23079>,
    <23075, 23079, 23083>    <23084, 23092, 23085>,
    <23084, 23085, 23089>    <23084, 23089, 23086>,
    <23084, 23086, 23090>    <23084, 23090, 23087>,
    <23084, 23087, 23091>    <23084, 23091, 23088>,
    <23084, 23088, 23092>    <23093, 23101, 23094>,
    <23093, 23094, 23098>    <23093, 23098, 23095>,
    <23093, 23095, 23099>    <23093, 23099, 23096>,
    <23093, 23096, 23100>    <23093, 23100, 23097>,
    <23093, 23097, 23101>    <23102, 23110, 23103>,
    <23102, 23103, 23107>    <23102, 23107, 23104>,
    <23102, 23104, 23108>    <23102, 23108, 23105>,
    <23102, 23105, 23109>    <23102, 23109, 23106>,
    <23102, 23106, 23110>    <23111, 23119, 23112>,
    <23111, 23112, 23116>    <23111, 23116, 23113>,
    <23111, 23113, 23117>    <23111, 23117, 23114>,
    <23111, 23114, 23118>    <23111, 23118, 23115>,
    <23111, 23115, 23119>    <23120, 23128, 23121>,
    <23120, 23121, 23125>    <23120, 23125, 23122>,
    <23120, 23122, 23126>    <23120, 23126, 23123>,
    <23120, 23123, 23127>    <23120, 23127, 23124>,
    <23120, 23124, 23128>    <23129, 23137, 23130>,
    <23129, 23130, 23134>    <23129, 23134, 23131>,
    <23129, 23131, 23135>    <23129, 23135, 23132>,
    <23129, 23132, 23136>    <23129, 23136, 23133>,
    <23129, 23133, 23137>    <23138, 23146, 23139>,
    <23138, 23139, 23143>    <23138, 23143, 23140>,
    <23138, 23140, 23144>    <23138, 23144, 23141>,
    <23138, 23141, 23145>    <23138, 23145, 23142>,
    <23138, 23142, 23146>    <23147, 23155, 23148>,
    <23147, 23148, 23152>    <23147, 23152, 23149>,
    <23147, 23149, 23153>    <23147, 23153, 23150>,
    <23147, 23150, 23154>    <23147, 23154, 23151>,
    <23147, 23151, 23155>    <23156, 23164, 23157>,
    <23156, 23157, 23161>    <23156, 23161, 23158>,
    <23156, 23158, 23162>    <23156, 23162, 23159>,
    <23156, 23159, 23163>    <23156, 23163, 23160>,
    <23156, 23160, 23164>    <23165, 23173, 23166>,
    <23165, 23166, 23170>    <23165, 23170, 23167>,
    <23165, 23167, 23171>    <23165, 23171, 23168>,
    <23165, 23168, 23172>    <23165, 23172, 23169>,
    <23165, 23169, 23173>    <23174, 23182, 23175>,
    <23174, 23175, 23179>    <23174, 23179, 23176>,
    <23174, 23176, 23180>    <23174, 23180, 23177>,
    <23174, 23177, 23181>    <23174, 23181, 23178>,
    <23174, 23178, 23182>    <23183, 23191, 23184>,
    <23183, 23184, 23188>    <23183, 23188, 23185>,
    <23183, 23185, 23189>    <23183, 23189, 23186>,
    <23183, 23186, 23190>    <23183, 23190, 23187>,
    <23183, 23187, 23191>    <23192, 23200, 23193>,
    <23192, 23193, 23197>    <23192, 23197, 23194>,
    <23192, 23194, 23198>    <23192, 23198, 23195>,
    <23192, 23195, 23199>    <23192, 23199, 23196>,
    <23192, 23196, 23200>    <23201, 23209, 23202>,
    <23201, 23202, 23206>    <23201, 23206, 23203>,
    <23201, 23203, 23207>    <23201, 23207, 23204>,
    <23201, 23204, 23208>    <23201, 23208, 23205>,
    <23201, 23205, 23209>    <23210, 23218, 23211>,
    <23210, 23211, 23215>    <23210, 23215, 23212>,
    <23210, 23212, 23216>    <23210, 23216, 23213>,
    <23210, 23213, 23217>    <23210, 23217, 23214>,
    <23210, 23214, 23218>    <23219, 23227, 23220>,
    <23219, 23220, 23224>    <23219, 23224, 23221>,
    <23219, 23221, 23225>    <23219, 23225, 23222>,
    <23219, 23222, 23226>    <23219, 23226, 23223>,
    <23219, 23223, 23227>    <23228, 23236, 23229>,
    <23228, 23229, 23233>    <23228, 23233, 23230>,
    <23228, 23230, 23234>    <23228, 23234, 23231>,
    <23228, 23231, 23235>    <23228, 23235, 23232>,
    <23228, 23232, 23236>    <23237, 23245, 23238>,
    <23237, 23238, 23242>    <23237, 23242, 23239>,
    <23237, 23239, 23243>    <23237, 23243, 23240>,
    <23237, 23240, 23244>    <23237, 23244, 23241>,
    <23237, 23241, 23245>    <23246, 23254, 23247>,
    <23246, 23247, 23251>    <23246, 23251, 23248>,
    <23246, 23248, 23252>    <23246, 23252, 23249>,
    <23246, 23249, 23253>    <23246, 23253, 23250>,
    <23246, 23250, 23254>    <23255, 23263, 23256>,
    <23255, 23256, 23260>    <23255, 23260, 23257>,
    <23255, 23257, 23261>    <23255, 23261, 23258>,
    <23255, 23258, 23262>    <23255, 23262, 23259>,
    <23255, 23259, 23263>    <23264, 23272, 23265>,
    <23264, 23265, 23269>    <23264, 23269, 23266>,
    <23264, 23266, 23270>    <23264, 23270, 23267>,
    <23264, 23267, 23271>    <23264, 23271, 23268>,
    <23264, 23268, 23272>    <23273, 23281, 23274>,
    <23273, 23274, 23278>    <23273, 23278, 23275>,
    <23273, 23275, 23279>    <23273, 23279, 23276>,
    <23273, 23276, 23280>    <23273, 23280, 23277>,
    <23273, 23277, 23281>    <23282, 23290, 23283>,
    <23282, 23283, 23287>    <23282, 23287, 23284>,
    <23282, 23284, 23288>    <23282, 23288, 23285>,
    <23282, 23285, 23289>    <23282, 23289, 23286>,
    <23282, 23286, 23290>    <23291, 23299, 23292>,
    <23291, 23292, 23296>    <23291, 23296, 23293>,
    <23291, 23293, 23297>    <23291, 23297, 23294>,
    <23291, 23294, 23298>    <23291, 23298, 23295>,
    <23291, 23295, 23299>    <23300, 23308, 23301>,
    <23300, 23301, 23305>    <23300, 23305, 23302>,
    <23300, 23302, 23306>    <23300, 23306, 23303>,
    <23300, 23303, 23307>    <23300, 23307, 23304>,
    <23300, 23304, 23308>    <23309, 23317, 23310>,
    <23309, 23310, 23314>    <23309, 23314, 23311>,
    <23309, 23311, 23315>    <23309, 23315, 23312>,
    <23309, 23312, 23316>    <23309, 23316, 23313>,
    <23309, 23313, 23317>    <23318, 23326, 23319>,
    <23318, 23319, 23323>    <23318, 23323, 23320>,
    <23318, 23320, 23324>    <23318, 23324, 23321>,
    <23318, 23321, 23325>    <23318, 23325, 23322>,
    <23318, 23322, 23326>    <23327, 23335, 23328>,
    <23327, 23328, 23332>    <23327, 23332, 23329>,
    <23327, 23329, 23333>    <23327, 23333, 23330>,
    <23327, 23330, 23334>    <23327, 23334, 23331>,
    <23327, 23331, 23335>    <23336, 23344, 23337>,
    <23336, 23337, 23341>    <23336, 23341, 23338>,
    <23336, 23338, 23342>    <23336, 23342, 23339>,
    <23336, 23339, 23343>    <23336, 23343, 23340>,
    <23336, 23340, 23344>    <23345, 23353, 23346>,
    <23345, 23346, 23350>    <23345, 23350, 23347>,
    <23345, 23347, 23351>    <23345, 23351, 23348>,
    <23345, 23348, 23352>    <23345, 23352, 23349>,
    <23345, 23349, 23353>    <23354, 23362, 23355>,
    <23354, 23355, 23359>    <23354, 23359, 23356>,
    <23354, 23356, 23360>    <23354, 23360, 23357>,
    <23354, 23357, 23361>    <23354, 23361, 23358>,
    <23354, 23358, 23362>    <23363, 23371, 23364>,
    <23363, 23364, 23368>    <23363, 23368, 23365>,
    <23363, 23365, 23369>    <23363, 23369, 23366>,
    <23363, 23366, 23370>    <23363, 23370, 23367>,
    <23363, 23367, 23371>    <23372, 23380, 23373>,
    <23372, 23373, 23377>    <23372, 23377, 23374>,
    <23372, 23374, 23378>    <23372, 23378, 23375>,
    <23372, 23375, 23379>    <23372, 23379, 23376>,
    <23372, 23376, 23380>    <23381, 23389, 23382>,
    <23381, 23382, 23386>    <23381, 23386, 23383>,
    <23381, 23383, 23387>    <23381, 23387, 23384>,
    <23381, 23384, 23388>    <23381, 23388, 23385>,
    <23381, 23385, 23389>    <23390, 23398, 23391>,
    <23390, 23391, 23395>    <23390, 23395, 23392>,
    <23390, 23392, 23396>    <23390, 23396, 23393>,
    <23390, 23393, 23397>    <23390, 23397, 23394>,
    <23390, 23394, 23398>    <23399, 23407, 23400>,
    <23399, 23400, 23404>    <23399, 23404, 23401>,
    <23399, 23401, 23405>    <23399, 23405, 23402>,
    <23399, 23402, 23406>    <23399, 23406, 23403>,
    <23399, 23403, 23407>    <23408, 23416, 23409>,
    <23408, 23409, 23413>    <23408, 23413, 23410>,
    <23408, 23410, 23414>    <23408, 23414, 23411>,
    <23408, 23411, 23415>    <23408, 23415, 23412>,
    <23408, 23412, 23416>    <23417, 23425, 23418>,
    <23417, 23418, 23422>    <23417, 23422, 23419>,
    <23417, 23419, 23423>    <23417, 23423, 23420>,
    <23417, 23420, 23424>    <23417, 23424, 23421>,
    <23417, 23421, 23425>    <23426, 23434, 23427>,
    <23426, 23427, 23431>    <23426, 23431, 23428>,
    <23426, 23428, 23432>    <23426, 23432, 23429>,
    <23426, 23429, 23433>    <23426, 23433, 23430>,
    <23426, 23430, 23434>    <23435, 23443, 23436>,
    <23435, 23436, 23440>    <23435, 23440, 23437>,
    <23435, 23437, 23441>    <23435, 23441, 23438>,
    <23435, 23438, 23442>    <23435, 23442, 23439>,
    <23435, 23439, 23443>    <23444, 23452, 23445>,
    <23444, 23445, 23449>    <23444, 23449, 23446>,
    <23444, 23446, 23450>    <23444, 23450, 23447>,
    <23444, 23447, 23451>    <23444, 23451, 23448>,
    <23444, 23448, 23452>    <23453, 23461, 23454>,
    <23453, 23454, 23458>    <23453, 23458, 23455>,
    <23453, 23455, 23459>    <23453, 23459, 23456>,
    <23453, 23456, 23460>    <23453, 23460, 23457>,
    <23453, 23457, 23461>    <23462, 23470, 23463>,
    <23462, 23463, 23467>    <23462, 23467, 23464>,
    <23462, 23464, 23468>    <23462, 23468, 23465>,
    <23462, 23465, 23469>    <23462, 23469, 23466>,
    <23462, 23466, 23470>    <23471, 23479, 23472>,
    <23471, 23472, 23476>    <23471, 23476, 23473>,
    <23471, 23473, 23477>    <23471, 23477, 23474>,
    <23471, 23474, 23478>    <23471, 23478, 23475>,
    <23471, 23475, 23479>    <23480, 23488, 23481>,
    <23480, 23481, 23485>    <23480, 23485, 23482>,
    <23480, 23482, 23486>    <23480, 23486, 23483>,
    <23480, 23483, 23487>    <23480, 23487, 23484>,
    <23480, 23484, 23488>    <23489, 23497, 23490>,
    <23489, 23490, 23494>    <23489, 23494, 23491>,
    <23489, 23491, 23495>    <23489, 23495, 23492>,
    <23489, 23492, 23496>    <23489, 23496, 23493>,
    <23489, 23493, 23497>    <23498, 23506, 23499>,
    <23498, 23499, 23503>    <23498, 23503, 23500>,
    <23498, 23500, 23504>    <23498, 23504, 23501>,
    <23498, 23501, 23505>    <23498, 23505, 23502>,
    <23498, 23502, 23506>    <23507, 23515, 23508>,
    <23507, 23508, 23512>    <23507, 23512, 23509>,
    <23507, 23509, 23513>    <23507, 23513, 23510>,
    <23507, 23510, 23514>    <23507, 23514, 23511>,
    <23507, 23511, 23515>    <23516, 23524, 23517>,
    <23516, 23517, 23521>    <23516, 23521, 23518>,
    <23516, 23518, 23522>    <23516, 23522, 23519>,
    <23516, 23519, 23523>    <23516, 23523, 23520>,
    <23516, 23520, 23524>    <23525, 23533, 23526>,
    <23525, 23526, 23530>    <23525, 23530, 23527>,
    <23525, 23527, 23531>    <23525, 23531, 23528>,
    <23525, 23528, 23532>    <23525, 23532, 23529>,
    <23525, 23529, 23533>    <23534, 23542, 23535>,
    <23534, 23535, 23539>    <23534, 23539, 23536>,
    <23534, 23536, 23540>    <23534, 23540, 23537>,
    <23534, 23537, 23541>    <23534, 23541, 23538>,
    <23534, 23538, 23542>    <23543, 23551, 23544>,
    <23543, 23544, 23548>    <23543, 23548, 23545>,
    <23543, 23545, 23549>    <23543, 23549, 23546>,
    <23543, 23546, 23550>    <23543, 23550, 23547>,
    <23543, 23547, 23551>    <23552, 23560, 23553>,
    <23552, 23553, 23557>    <23552, 23557, 23554>,
    <23552, 23554, 23558>    <23552, 23558, 23555>,
    <23552, 23555, 23559>    <23552, 23559, 23556>,
    <23552, 23556, 23560>    <23561, 23569, 23562>,
    <23561, 23562, 23566>    <23561, 23566, 23563>,
    <23561, 23563, 23567>    <23561, 23567, 23564>,
    <23561, 23564, 23568>    <23561, 23568, 23565>,
    <23561, 23565, 23569>    <23570, 23578, 23571>,
    <23570, 23571, 23575>    <23570, 23575, 23572>,
    <23570, 23572, 23576>    <23570, 23576, 23573>,
    <23570, 23573, 23577>    <23570, 23577, 23574>,
    <23570, 23574, 23578>    <23579, 23587, 23580>,
    <23579, 23580, 23584>    <23579, 23584, 23581>,
    <23579, 23581, 23585>    <23579, 23585, 23582>,
    <23579, 23582, 23586>    <23579, 23586, 23583>,
    <23579, 23583, 23587>    <23588, 23596, 23589>,
    <23588, 23589, 23593>    <23588, 23593, 23590>,
    <23588, 23590, 23594>    <23588, 23594, 23591>,
    <23588, 23591, 23595>    <23588, 23595, 23592>,
    <23588, 23592, 23596>    <23597, 23605, 23598>,
    <23597, 23598, 23602>    <23597, 23602, 23599>,
    <23597, 23599, 23603>    <23597, 23603, 23600>,
    <23597, 23600, 23604>    <23597, 23604, 23601>,
    <23597, 23601, 23605>    <23606, 23614, 23607>,
    <23606, 23607, 23611>    <23606, 23611, 23608>,
    <23606, 23608, 23612>    <23606, 23612, 23609>,
    <23606, 23609, 23613>    <23606, 23613, 23610>,
    <23606, 23610, 23614>    <23615, 23623, 23616>,
    <23615, 23616, 23620>    <23615, 23620, 23617>,
    <23615, 23617, 23621>    <23615, 23621, 23618>,
    <23615, 23618, 23622>    <23615, 23622, 23619>,
    <23615, 23619, 23623>    <23624, 23632, 23625>,
    <23624, 23625, 23629>    <23624, 23629, 23626>,
    <23624, 23626, 23630>    <23624, 23630, 23627>,
    <23624, 23627, 23631>    <23624, 23631, 23628>,
    <23624, 23628, 23632>    <23633, 23641, 23634>,
    <23633, 23634, 23638>    <23633, 23638, 23635>,
    <23633, 23635, 23639>    <23633, 23639, 23636>,
    <23633, 23636, 23640>    <23633, 23640, 23637>,
    <23633, 23637, 23641>    <23642, 23650, 23643>,
    <23642, 23643, 23647>    <23642, 23647, 23644>,
    <23642, 23644, 23648>    <23642, 23648, 23645>,
    <23642, 23645, 23649>    <23642, 23649, 23646>,
    <23642, 23646, 23650>    <23651, 23659, 23652>,
    <23651, 23652, 23656>    <23651, 23656, 23653>,
    <23651, 23653, 23657>    <23651, 23657, 23654>,
    <23651, 23654, 23658>    <23651, 23658, 23655>,
    <23651, 23655, 23659>    <23660, 23668, 23661>,
    <23660, 23661, 23665>    <23660, 23665, 23662>,
    <23660, 23662, 23666>    <23660, 23666, 23663>,
    <23660, 23663, 23667>    <23660, 23667, 23664>,
    <23660, 23664, 23668>    <23669, 23677, 23670>,
    <23669, 23670, 23674>    <23669, 23674, 23671>,
    <23669, 23671, 23675>    <23669, 23675, 23672>,
    <23669, 23672, 23676>    <23669, 23676, 23673>,
    <23669, 23673, 23677>    <23678, 23686, 23679>,
    <23678, 23679, 23683>    <23678, 23683, 23680>,
    <23678, 23680, 23684>    <23678, 23684, 23681>,
    <23678, 23681, 23685>    <23678, 23685, 23682>,
    <23678, 23682, 23686>    <23687, 23695, 23688>,
    <23687, 23688, 23692>    <23687, 23692, 23689>,
    <23687, 23689, 23693>    <23687, 23693, 23690>,
    <23687, 23690, 23694>    <23687, 23694, 23691>,
    <23687, 23691, 23695>    <23696, 23704, 23697>,
    <23696, 23697, 23701>    <23696, 23701, 23698>,
    <23696, 23698, 23702>    <23696, 23702, 23699>,
    <23696, 23699, 23703>    <23696, 23703, 23700>,
    <23696, 23700, 23704>    <23705, 23713, 23706>,
    <23705, 23706, 23710>    <23705, 23710, 23707>,
    <23705, 23707, 23711>    <23705, 23711, 23708>,
    <23705, 23708, 23712>    <23705, 23712, 23709>,
    <23705, 23709, 23713>    <23714, 23722, 23715>,
    <23714, 23715, 23719>    <23714, 23719, 23716>,
    <23714, 23716, 23720>    <23714, 23720, 23717>,
    <23714, 23717, 23721>    <23714, 23721, 23718>,
    <23714, 23718, 23722>    <23723, 23731, 23724>,
    <23723, 23724, 23728>    <23723, 23728, 23725>,
    <23723, 23725, 23729>    <23723, 23729, 23726>,
    <23723, 23726, 23730>    <23723, 23730, 23727>,
    <23723, 23727, 23731>    <23732, 23740, 23733>,
    <23732, 23733, 23737>    <23732, 23737, 23734>,
    <23732, 23734, 23738>    <23732, 23738, 23735>,
    <23732, 23735, 23739>    <23732, 23739, 23736>,
    <23732, 23736, 23740>    <23741, 23749, 23742>,
    <23741, 23742, 23746>    <23741, 23746, 23743>,
    <23741, 23743, 23747>    <23741, 23747, 23744>,
    <23741, 23744, 23748>    <23741, 23748, 23745>,
    <23741, 23745, 23749>    <23750, 23758, 23751>,
    <23750, 23751, 23755>    <23750, 23755, 23752>,
    <23750, 23752, 23756>    <23750, 23756, 23753>,
    <23750, 23753, 23757>    <23750, 23757, 23754>,
    <23750, 23754, 23758>    <23759, 23767, 23760>,
    <23759, 23760, 23764>    <23759, 23764, 23761>,
    <23759, 23761, 23765>    <23759, 23765, 23762>,
    <23759, 23762, 23766>    <23759, 23766, 23763>,
    <23759, 23763, 23767>    <23768, 23776, 23769>,
    <23768, 23769, 23773>    <23768, 23773, 23770>,
    <23768, 23770, 23774>    <23768, 23774, 23771>,
    <23768, 23771, 23775>    <23768, 23775, 23772>,
    <23768, 23772, 23776>    <23777, 23785, 23778>,
    <23777, 23778, 23782>    <23777, 23782, 23779>,
    <23777, 23779, 23783>    <23777, 23783, 23780>,
    <23777, 23780, 23784>    <23777, 23784, 23781>,
    <23777, 23781, 23785>    <23786, 23794, 23787>,
    <23786, 23787, 23791>    <23786, 23791, 23788>,
    <23786, 23788, 23792>    <23786, 23792, 23789>,
    <23786, 23789, 23793>    <23786, 23793, 23790>,
    <23786, 23790, 23794>    <23795, 23803, 23796>,
    <23795, 23796, 23800>    <23795, 23800, 23797>,
    <23795, 23797, 23801>    <23795, 23801, 23798>,
    <23795, 23798, 23802>    <23795, 23802, 23799>,
    <23795, 23799, 23803>    <23804, 23812, 23805>,
    <23804, 23805, 23809>    <23804, 23809, 23806>,
    <23804, 23806, 23810>    <23804, 23810, 23807>,
    <23804, 23807, 23811>    <23804, 23811, 23808>,
    <23804, 23808, 23812>    <23813, 23821, 23814>,
    <23813, 23814, 23818>    <23813, 23818, 23815>,
    <23813, 23815, 23819>    <23813, 23819, 23816>,
    <23813, 23816, 23820>    <23813, 23820, 23817>,
    <23813, 23817, 23821>    <23822, 23830, 23823>,
    <23822, 23823, 23827>    <23822, 23827, 23824>,
    <23822, 23824, 23828>    <23822, 23828, 23825>,
    <23822, 23825, 23829>    <23822, 23829, 23826>,
    <23822, 23826, 23830>    <23831, 23839, 23832>,
    <23831, 23832, 23836>    <23831, 23836, 23833>,
    <23831, 23833, 23837>    <23831, 23837, 23834>,
    <23831, 23834, 23838>    <23831, 23838, 23835>,
    <23831, 23835, 23839>    <23840, 23848, 23841>,
    <23840, 23841, 23845>    <23840, 23845, 23842>,
    <23840, 23842, 23846>    <23840, 23846, 23843>,
    <23840, 23843, 23847>    <23840, 23847, 23844>,
    <23840, 23844, 23848>    <23849, 23857, 23850>,
    <23849, 23850, 23854>    <23849, 23854, 23851>,
    <23849, 23851, 23855>    <23849, 23855, 23852>,
    <23849, 23852, 23856>    <23849, 23856, 23853>,
    <23849, 23853, 23857>    <23858, 23866, 23859>,
    <23858, 23859, 23863>    <23858, 23863, 23860>,
    <23858, 23860, 23864>    <23858, 23864, 23861>,
    <23858, 23861, 23865>    <23858, 23865, 23862>,
    <23858, 23862, 23866>    <23867, 23875, 23868>,
    <23867, 23868, 23872>    <23867, 23872, 23869>,
    <23867, 23869, 23873>    <23867, 23873, 23870>,
    <23867, 23870, 23874>    <23867, 23874, 23871>,
    <23867, 23871, 23875>    <23876, 23884, 23877>,
    <23876, 23877, 23881>    <23876, 23881, 23878>,
    <23876, 23878, 23882>    <23876, 23882, 23879>,
    <23876, 23879, 23883>    <23876, 23883, 23880>,
    <23876, 23880, 23884>    <23885, 23893, 23886>,
    <23885, 23886, 23890>    <23885, 23890, 23887>,
    <23885, 23887, 23891>    <23885, 23891, 23888>,
    <23885, 23888, 23892>    <23885, 23892, 23889>,
    <23885, 23889, 23893>    <23894, 23902, 23895>,
    <23894, 23895, 23899>    <23894, 23899, 23896>,
    <23894, 23896, 23900>    <23894, 23900, 23897>,
    <23894, 23897, 23901>    <23894, 23901, 23898>,
    <23894, 23898, 23902>    <23903, 23911, 23904>,
    <23903, 23904, 23908>    <23903, 23908, 23905>,
    <23903, 23905, 23909>    <23903, 23909, 23906>,
    <23903, 23906, 23910>    <23903, 23910, 23907>,
    <23903, 23907, 23911>    <23912, 23920, 23913>,
    <23912, 23913, 23917>    <23912, 23917, 23914>,
    <23912, 23914, 23918>    <23912, 23918, 23915>,
    <23912, 23915, 23919>    <23912, 23919, 23916>,
    <23912, 23916, 23920>    <23921, 23929, 23922>,
    <23921, 23922, 23926>    <23921, 23926, 23923>,
    <23921, 23923, 23927>    <23921, 23927, 23924>,
    <23921, 23924, 23928>    <23921, 23928, 23925>,
    <23921, 23925, 23929>    <23930, 23938, 23931>,
    <23930, 23931, 23935>    <23930, 23935, 23932>,
    <23930, 23932, 23936>    <23930, 23936, 23933>,
    <23930, 23933, 23937>    <23930, 23937, 23934>,
    <23930, 23934, 23938>    <23939, 23947, 23940>,
    <23939, 23940, 23944>    <23939, 23944, 23941>,
    <23939, 23941, 23945>    <23939, 23945, 23942>,
    <23939, 23942, 23946>    <23939, 23946, 23943>,
    <23939, 23943, 23947>    <23948, 23956, 23949>,
    <23948, 23949, 23953>    <23948, 23953, 23950>,
    <23948, 23950, 23954>    <23948, 23954, 23951>,
    <23948, 23951, 23955>    <23948, 23955, 23952>,
    <23948, 23952, 23956>    <23957, 23965, 23958>,
    <23957, 23958, 23962>    <23957, 23962, 23959>,
    <23957, 23959, 23963>    <23957, 23963, 23960>,
    <23957, 23960, 23964>    <23957, 23964, 23961>,
    <23957, 23961, 23965>    <23966, 23974, 23967>,
    <23966, 23967, 23971>    <23966, 23971, 23968>,
    <23966, 23968, 23972>    <23966, 23972, 23969>,
    <23966, 23969, 23973>    <23966, 23973, 23970>,
    <23966, 23970, 23974>    <23975, 23983, 23976>,
    <23975, 23976, 23980>    <23975, 23980, 23977>,
    <23975, 23977, 23981>    <23975, 23981, 23978>,
    <23975, 23978, 23982>    <23975, 23982, 23979>,
    <23975, 23979, 23983>    <23984, 23992, 23985>,
    <23984, 23985, 23989>    <23984, 23989, 23986>,
    <23984, 23986, 23990>    <23984, 23990, 23987>,
    <23984, 23987, 23991>    <23984, 23991, 23988>,
    <23984, 23988, 23992>    <23993, 24001, 23994>,
    <23993, 23994, 23998>    <23993, 23998, 23995>,
    <23993, 23995, 23999>    <23993, 23999, 23996>,
    <23993, 23996, 24000>    <23993, 24000, 23997>,
    <23993, 23997, 24001>    <24002, 24010, 24003>,
    <24002, 24003, 24007>    <24002, 24007, 24004>,
    <24002, 24004, 24008>    <24002, 24008, 24005>,
    <24002, 24005, 24009>    <24002, 24009, 24006>,
    <24002, 24006, 24010>    <24011, 24019, 24012>,
    <24011, 24012, 24016>    <24011, 24016, 24013>,
    <24011, 24013, 24017>    <24011, 24017, 24014>,
    <24011, 24014, 24018>    <24011, 24018, 24015>,
    <24011, 24015, 24019>    <24020, 24028, 24021>,
    <24020, 24021, 24025>    <24020, 24025, 24022>,
    <24020, 24022, 24026>    <24020, 24026, 24023>,
    <24020, 24023, 24027>    <24020, 24027, 24024>,
    <24020, 24024, 24028>    <24029, 24037, 24030>,
    <24029, 24030, 24034>    <24029, 24034, 24031>,
    <24029, 24031, 24035>    <24029, 24035, 24032>,
    <24029, 24032, 24036>    <24029, 24036, 24033>,
    <24029, 24033, 24037>    <24038, 24046, 24039>,
    <24038, 24039, 24043>    <24038, 24043, 24040>,
    <24038, 24040, 24044>    <24038, 24044, 24041>,
    <24038, 24041, 24045>    <24038, 24045, 24042>,
    <24038, 24042, 24046>    <24047, 24055, 24048>,
    <24047, 24048, 24052>    <24047, 24052, 24049>,
    <24047, 24049, 24053>    <24047, 24053, 24050>,
    <24047, 24050, 24054>    <24047, 24054, 24051>,
    <24047, 24051, 24055>    <24056, 24064, 24057>,
    <24056, 24057, 24061>    <24056, 24061, 24058>,
    <24056, 24058, 24062>    <24056, 24062, 24059>,
    <24056, 24059, 24063>    <24056, 24063, 24060>,
    <24056, 24060, 24064>    <24065, 24073, 24066>,
    <24065, 24066, 24070>    <24065, 24070, 24067>,
    <24065, 24067, 24071>    <24065, 24071, 24068>,
    <24065, 24068, 24072>    <24065, 24072, 24069>,
    <24065, 24069, 24073>    <24074, 24082, 24075>,
    <24074, 24075, 24079>    <24074, 24079, 24076>,
    <24074, 24076, 24080>    <24074, 24080, 24077>,
    <24074, 24077, 24081>    <24074, 24081, 24078>,
    <24074, 24078, 24082>    <24083, 24091, 24084>,
    <24083, 24084, 24088>    <24083, 24088, 24085>,
    <24083, 24085, 24089>    <24083, 24089, 24086>,
    <24083, 24086, 24090>    <24083, 24090, 24087>,
    <24083, 24087, 24091>    <24092, 24100, 24093>,
    <24092, 24093, 24097>    <24092, 24097, 24094>,
    <24092, 24094, 24098>    <24092, 24098, 24095>,
    <24092, 24095, 24099>    <24092, 24099, 24096>,
    <24092, 24096, 24100>    <24101, 24109, 24102>,
    <24101, 24102, 24106>    <24101, 24106, 24103>,
    <24101, 24103, 24107>    <24101, 24107, 24104>,
    <24101, 24104, 24108>    <24101, 24108, 24105>,
    <24101, 24105, 24109>    <24110, 24118, 24111>,
    <24110, 24111, 24115>    <24110, 24115, 24112>,
    <24110, 24112, 24116>    <24110, 24116, 24113>,
    <24110, 24113, 24117>    <24110, 24117, 24114>,
    <24110, 24114, 24118>    <24119, 24127, 24120>,
    <24119, 24120, 24124>    <24119, 24124, 24121>,
    <24119, 24121, 24125>    <24119, 24125, 24122>,
    <24119, 24122, 24126>    <24119, 24126, 24123>,
    <24119, 24123, 24127>    <24128, 24136, 24129>,
    <24128, 24129, 24133>    <24128, 24133, 24130>,
    <24128, 24130, 24134>    <24128, 24134, 24131>,
    <24128, 24131, 24135>    <24128, 24135, 24132>,
    <24128, 24132, 24136>    <24137, 24145, 24138>,
    <24137, 24138, 24142>    <24137, 24142, 24139>,
    <24137, 24139, 24143>    <24137, 24143, 24140>,
    <24137, 24140, 24144>    <24137, 24144, 24141>,
    <24137, 24141, 24145>    <24146, 24154, 24147>,
    <24146, 24147, 24151>    <24146, 24151, 24148>,
    <24146, 24148, 24152>    <24146, 24152, 24149>,
    <24146, 24149, 24153>    <24146, 24153, 24150>,
    <24146, 24150, 24154>    <24155, 24163, 24156>,
    <24155, 24156, 24160>    <24155, 24160, 24157>,
    <24155, 24157, 24161>    <24155, 24161, 24158>,
    <24155, 24158, 24162>    <24155, 24162, 24159>,
    <24155, 24159, 24163>    <24164, 24172, 24165>,
    <24164, 24165, 24169>    <24164, 24169, 24166>,
    <24164, 24166, 24170>    <24164, 24170, 24167>,
    <24164, 24167, 24171>    <24164, 24171, 24168>,
    <24164, 24168, 24172>    <24173, 24181, 24174>,
    <24173, 24174, 24178>    <24173, 24178, 24175>,
    <24173, 24175, 24179>    <24173, 24179, 24176>,
    <24173, 24176, 24180>    <24173, 24180, 24177>,
    <24173, 24177, 24181>    <24182, 24190, 24183>,
    <24182, 24183, 24187>    <24182, 24187, 24184>,
    <24182, 24184, 24188>    <24182, 24188, 24185>,
    <24182, 24185, 24189>    <24182, 24189, 24186>,
    <24182, 24186, 24190>    <24191, 24199, 24192>,
    <24191, 24192, 24196>    <24191, 24196, 24193>,
    <24191, 24193, 24197>    <24191, 24197, 24194>,
    <24191, 24194, 24198>    <24191, 24198, 24195>,
    <24191, 24195, 24199>    <24200, 24208, 24201>,
    <24200, 24201, 24205>    <24200, 24205, 24202>,
    <24200, 24202, 24206>    <24200, 24206, 24203>,
    <24200, 24203, 24207>    <24200, 24207, 24204>,
    <24200, 24204, 24208>    <24209, 24217, 24210>,
    <24209, 24210, 24214>    <24209, 24214, 24211>,
    <24209, 24211, 24215>    <24209, 24215, 24212>,
    <24209, 24212, 24216>    <24209, 24216, 24213>,
    <24209, 24213, 24217>    <24218, 24226, 24219>,
    <24218, 24219, 24223>    <24218, 24223, 24220>,
    <24218, 24220, 24224>    <24218, 24224, 24221>,
    <24218, 24221, 24225>    <24218, 24225, 24222>,
    <24218, 24222, 24226>    <24227, 24235, 24228>,
    <24227, 24228, 24232>    <24227, 24232, 24229>,
    <24227, 24229, 24233>    <24227, 24233, 24230>,
    <24227, 24230, 24234>    <24227, 24234, 24231>,
    <24227, 24231, 24235>    <24236, 24244, 24237>,
    <24236, 24237, 24241>    <24236, 24241, 24238>,
    <24236, 24238, 24242>    <24236, 24242, 24239>,
    <24236, 24239, 24243>    <24236, 24243, 24240>,
    <24236, 24240, 24244>    <24245, 24253, 24246>,
    <24245, 24246, 24250>    <24245, 24250, 24247>,
    <24245, 24247, 24251>    <24245, 24251, 24248>,
    <24245, 24248, 24252>    <24245, 24252, 24249>,
    <24245, 24249, 24253>    <24254, 24262, 24255>,
    <24254, 24255, 24259>    <24254, 24259, 24256>,
    <24254, 24256, 24260>    <24254, 24260, 24257>,
    <24254, 24257, 24261>    <24254, 24261, 24258>,
    <24254, 24258, 24262>    <24263, 24271, 24264>,
    <24263, 24264, 24268>    <24263, 24268, 24265>,
    <24263, 24265, 24269>    <24263, 24269, 24266>,
    <24263, 24266, 24270>    <24263, 24270, 24267>,
    <24263, 24267, 24271>    <24272, 24280, 24273>,
    <24272, 24273, 24277>    <24272, 24277, 24274>,
    <24272, 24274, 24278>    <24272, 24278, 24275>,
    <24272, 24275, 24279>    <24272, 24279, 24276>,
    <24272, 24276, 24280>    <24281, 24289, 24282>,
    <24281, 24282, 24286>    <24281, 24286, 24283>,
    <24281, 24283, 24287>    <24281, 24287, 24284>,
    <24281, 24284, 24288>    <24281, 24288, 24285>,
    <24281, 24285, 24289>    <24290, 24298, 24291>,
    <24290, 24291, 24295>    <24290, 24295, 24292>,
    <24290, 24292, 24296>    <24290, 24296, 24293>,
    <24290, 24293, 24297>    <24290, 24297, 24294>,
    <24290, 24294, 24298>    <24299, 24307, 24300>,
    <24299, 24300, 24304>    <24299, 24304, 24301>,
    <24299, 24301, 24305>    <24299, 24305, 24302>,
    <24299, 24302, 24306>    <24299, 24306, 24303>,
    <24299, 24303, 24307>    <24308, 24316, 24309>,
    <24308, 24309, 24313>    <24308, 24313, 24310>,
    <24308, 24310, 24314>    <24308, 24314, 24311>,
    <24308, 24311, 24315>    <24308, 24315, 24312>,
    <24308, 24312, 24316>    <24317, 24325, 24318>,
    <24317, 24318, 24322>    <24317, 24322, 24319>,
    <24317, 24319, 24323>    <24317, 24323, 24320>,
    <24317, 24320, 24324>    <24317, 24324, 24321>,
    <24317, 24321, 24325>    <24326, 24334, 24327>,
    <24326, 24327, 24331>    <24326, 24331, 24328>,
    <24326, 24328, 24332>    <24326, 24332, 24329>,
    <24326, 24329, 24333>    <24326, 24333, 24330>,
    <24326, 24330, 24334>    <24335, 24343, 24336>,
    <24335, 24336, 24340>    <24335, 24340, 24337>,
    <24335, 24337, 24341>    <24335, 24341, 24338>,
    <24335, 24338, 24342>    <24335, 24342, 24339>,
    <24335, 24339, 24343>    <24344, 24352, 24345>,
    <24344, 24345, 24349>    <24344, 24349, 24346>,
    <24344, 24346, 24350>    <24344, 24350, 24347>,
    <24344, 24347, 24351>    <24344, 24351, 24348>,
    <24344, 24348, 24352>    <24353, 24361, 24354>,
    <24353, 24354, 24358>    <24353, 24358, 24355>,
    <24353, 24355, 24359>    <24353, 24359, 24356>,
    <24353, 24356, 24360>    <24353, 24360, 24357>,
    <24353, 24357, 24361>    <24362, 24370, 24363>,
    <24362, 24363, 24367>    <24362, 24367, 24364>,
    <24362, 24364, 24368>    <24362, 24368, 24365>,
    <24362, 24365, 24369>    <24362, 24369, 24366>,
    <24362, 24366, 24370>    <24371, 24379, 24372>,
    <24371, 24372, 24376>    <24371, 24376, 24373>,
    <24371, 24373, 24377>    <24371, 24377, 24374>,
    <24371, 24374, 24378>    <24371, 24378, 24375>,
    <24371, 24375, 24379>    <24380, 24388, 24381>,
    <24380, 24381, 24385>    <24380, 24385, 24382>,
    <24380, 24382, 24386>    <24380, 24386, 24383>,
    <24380, 24383, 24387>    <24380, 24387, 24384>,
    <24380, 24384, 24388>    <24389, 24397, 24390>,
    <24389, 24390, 24394>    <24389, 24394, 24391>,
    <24389, 24391, 24395>    <24389, 24395, 24392>,
    <24389, 24392, 24396>    <24389, 24396, 24393>,
    <24389, 24393, 24397>    <24398, 24406, 24399>,
    <24398, 24399, 24403>    <24398, 24403, 24400>,
    <24398, 24400, 24404>    <24398, 24404, 24401>,
    <24398, 24401, 24405>    <24398, 24405, 24402>,
    <24398, 24402, 24406>    <24407, 24415, 24408>,
    <24407, 24408, 24412>    <24407, 24412, 24409>,
    <24407, 24409, 24413>    <24407, 24413, 24410>,
    <24407, 24410, 24414>    <24407, 24414, 24411>,
    <24407, 24411, 24415>    <24416, 24424, 24417>,
    <24416, 24417, 24421>    <24416, 24421, 24418>,
    <24416, 24418, 24422>    <24416, 24422, 24419>,
    <24416, 24419, 24423>    <24416, 24423, 24420>,
    <24416, 24420, 24424>    <24425, 24433, 24426>,
    <24425, 24426, 24430>    <24425, 24430, 24427>,
    <24425, 24427, 24431>    <24425, 24431, 24428>,
    <24425, 24428, 24432>    <24425, 24432, 24429>,
    <24425, 24429, 24433>    <24434, 24442, 24435>,
    <24434, 24435, 24439>    <24434, 24439, 24436>,
    <24434, 24436, 24440>    <24434, 24440, 24437>,
    <24434, 24437, 24441>    <24434, 24441, 24438>,
    <24434, 24438, 24442>    <24443, 24451, 24444>,
    <24443, 24444, 24448>    <24443, 24448, 24445>,
    <24443, 24445, 24449>    <24443, 24449, 24446>,
    <24443, 24446, 24450>    <24443, 24450, 24447>,
    <24443, 24447, 24451>    <24452, 24460, 24453>,
    <24452, 24453, 24457>    <24452, 24457, 24454>,
    <24452, 24454, 24458>    <24452, 24458, 24455>,
    <24452, 24455, 24459>    <24452, 24459, 24456>,
    <24452, 24456, 24460>    <24461, 24469, 24462>,
    <24461, 24462, 24466>    <24461, 24466, 24463>,
    <24461, 24463, 24467>    <24461, 24467, 24464>,
    <24461, 24464, 24468>    <24461, 24468, 24465>,
    <24461, 24465, 24469>    <24470, 24478, 24471>,
    <24470, 24471, 24475>    <24470, 24475, 24472>,
    <24470, 24472, 24476>    <24470, 24476, 24473>,
    <24470, 24473, 24477>    <24470, 24477, 24474>,
    <24470, 24474, 24478>    <24479, 24487, 24480>,
    <24479, 24480, 24484>    <24479, 24484, 24481>,
    <24479, 24481, 24485>    <24479, 24485, 24482>,
    <24479, 24482, 24486>    <24479, 24486, 24483>,
    <24479, 24483, 24487>    <24488, 24496, 24489>,
    <24488, 24489, 24493>    <24488, 24493, 24490>,
    <24488, 24490, 24494>    <24488, 24494, 24491>,
    <24488, 24491, 24495>    <24488, 24495, 24492>,
    <24488, 24492, 24496>    <24497, 24505, 24498>,
    <24497, 24498, 24502>    <24497, 24502, 24499>,
    <24497, 24499, 24503>    <24497, 24503, 24500>,
    <24497, 24500, 24504>    <24497, 24504, 24501>,
    <24497, 24501, 24505>    <24506, 24514, 24507>,
    <24506, 24507, 24511>    <24506, 24511, 24508>,
    <24506, 24508, 24512>    <24506, 24512, 24509>,
    <24506, 24509, 24513>    <24506, 24513, 24510>,
    <24506, 24510, 24514>    <24515, 24523, 24516>,
    <24515, 24516, 24520>    <24515, 24520, 24517>,
    <24515, 24517, 24521>    <24515, 24521, 24518>,
    <24515, 24518, 24522>    <24515, 24522, 24519>,
    <24515, 24519, 24523>    <24524, 24532, 24525>,
    <24524, 24525, 24529>    <24524, 24529, 24526>,
    <24524, 24526, 24530>    <24524, 24530, 24527>,
    <24524, 24527, 24531>    <24524, 24531, 24528>,
    <24524, 24528, 24532>    <24533, 24541, 24534>,
    <24533, 24534, 24538>    <24533, 24538, 24535>,
    <24533, 24535, 24539>    <24533, 24539, 24536>,
    <24533, 24536, 24540>    <24533, 24540, 24537>,
    <24533, 24537, 24541>    <24542, 24550, 24543>,
    <24542, 24543, 24547>    <24542, 24547, 24544>,
    <24542, 24544, 24548>    <24542, 24548, 24545>,
    <24542, 24545, 24549>    <24542, 24549, 24546>,
    <24542, 24546, 24550>    <24551, 24559, 24552>,
    <24551, 24552, 24556>    <24551, 24556, 24553>,
    <24551, 24553, 24557>    <24551, 24557, 24554>,
    <24551, 24554, 24558>    <24551, 24558, 24555>,
    <24551, 24555, 24559>    <24560, 24568, 24561>,
    <24560, 24561, 24565>    <24560, 24565, 24562>,
    <24560, 24562, 24566>    <24560, 24566, 24563>,
    <24560, 24563, 24567>    <24560, 24567, 24564>,
    <24560, 24564, 24568>    <24569, 24577, 24570>,
    <24569, 24570, 24574>    <24569, 24574, 24571>,
    <24569, 24571, 24575>    <24569, 24575, 24572>,
    <24569, 24572, 24576>    <24569, 24576, 24573>,
    <24569, 24573, 24577>    <24578, 24586, 24579>,
    <24578, 24579, 24583>    <24578, 24583, 24580>,
    <24578, 24580, 24584>    <24578, 24584, 24581>,
    <24578, 24581, 24585>    <24578, 24585, 24582>,
    <24578, 24582, 24586>    <24587, 24595, 24588>,
    <24587, 24588, 24592>    <24587, 24592, 24589>,
    <24587, 24589, 24593>    <24587, 24593, 24590>,
    <24587, 24590, 24594>    <24587, 24594, 24591>,
    <24587, 24591, 24595>    <24596, 24604, 24597>,
    <24596, 24597, 24601>    <24596, 24601, 24598>,
    <24596, 24598, 24602>    <24596, 24602, 24599>,
    <24596, 24599, 24603>    <24596, 24603, 24600>,
    <24596, 24600, 24604>    <24605, 24613, 24606>,
    <24605, 24606, 24610>    <24605, 24610, 24607>,
    <24605, 24607, 24611>    <24605, 24611, 24608>,
    <24605, 24608, 24612>    <24605, 24612, 24609>,
    <24605, 24609, 24613>    <24614, 24622, 24615>,
    <24614, 24615, 24619>    <24614, 24619, 24616>,
    <24614, 24616, 24620>    <24614, 24620, 24617>,
    <24614, 24617, 24621>    <24614, 24621, 24618>,
    <24614, 24618, 24622>    <24623, 24631, 24624>,
    <24623, 24624, 24628>    <24623, 24628, 24625>,
    <24623, 24625, 24629>    <24623, 24629, 24626>,
    <24623, 24626, 24630>    <24623, 24630, 24627>,
    <24623, 24627, 24631>    <24632, 24640, 24633>,
    <24632, 24633, 24637>    <24632, 24637, 24634>,
    <24632, 24634, 24638>    <24632, 24638, 24635>,
    <24632, 24635, 24639>    <24632, 24639, 24636>,
    <24632, 24636, 24640>    <24641, 24649, 24642>,
    <24641, 24642, 24646>    <24641, 24646, 24643>,
    <24641, 24643, 24647>    <24641, 24647, 24644>,
    <24641, 24644, 24648>    <24641, 24648, 24645>,
    <24641, 24645, 24649>    <24650, 24658, 24651>,
    <24650, 24651, 24655>    <24650, 24655, 24652>,
    <24650, 24652, 24656>    <24650, 24656, 24653>,
    <24650, 24653, 24657>    <24650, 24657, 24654>,
    <24650, 24654, 24658>    <24659, 24667, 24660>,
    <24659, 24660, 24664>    <24659, 24664, 24661>,
    <24659, 24661, 24665>    <24659, 24665, 24662>,
    <24659, 24662, 24666>    <24659, 24666, 24663>,
    <24659, 24663, 24667>    <24668, 24676, 24669>,
    <24668, 24669, 24673>    <24668, 24673, 24670>,
    <24668, 24670, 24674>    <24668, 24674, 24671>,
    <24668, 24671, 24675>    <24668, 24675, 24672>,
    <24668, 24672, 24676>    <24677, 24685, 24678>,
    <24677, 24678, 24682>    <24677, 24682, 24679>,
    <24677, 24679, 24683>    <24677, 24683, 24680>,
    <24677, 24680, 24684>    <24677, 24684, 24681>,
    <24677, 24681, 24685>    <24686, 24694, 24687>,
    <24686, 24687, 24691>    <24686, 24691, 24688>,
    <24686, 24688, 24692>    <24686, 24692, 24689>,
    <24686, 24689, 24693>    <24686, 24693, 24690>,
    <24686, 24690, 24694>    <24695, 24703, 24696>,
    <24695, 24696, 24700>    <24695, 24700, 24697>,
    <24695, 24697, 24701>    <24695, 24701, 24698>,
    <24695, 24698, 24702>    <24695, 24702, 24699>,
    <24695, 24699, 24703>    <24704, 24712, 24705>,
    <24704, 24705, 24709>    <24704, 24709, 24706>,
    <24704, 24706, 24710>    <24704, 24710, 24707>,
    <24704, 24707, 24711>    <24704, 24711, 24708>,
    <24704, 24708, 24712>    <24713, 24721, 24714>,
    <24713, 24714, 24718>    <24713, 24718, 24715>,
    <24713, 24715, 24719>    <24713, 24719, 24716>,
    <24713, 24716, 24720>    <24713, 24720, 24717>,
    <24713, 24717, 24721>    <24722, 24730, 24723>,
    <24722, 24723, 24727>    <24722, 24727, 24724>,
    <24722, 24724, 24728>    <24722, 24728, 24725>,
    <24722, 24725, 24729>    <24722, 24729, 24726>,
    <24722, 24726, 24730>    <24731, 24739, 24732>,
    <24731, 24732, 24736>    <24731, 24736, 24733>,
    <24731, 24733, 24737>    <24731, 24737, 24734>,
    <24731, 24734, 24738>    <24731, 24738, 24735>,
    <24731, 24735, 24739>    <24740, 24748, 24741>,
    <24740, 24741, 24745>    <24740, 24745, 24742>,
    <24740, 24742, 24746>    <24740, 24746, 24743>,
    <24740, 24743, 24747>    <24740, 24747, 24744>,
    <24740, 24744, 24748>    <24749, 24757, 24750>,
    <24749, 24750, 24754>    <24749, 24754, 24751>,
    <24749, 24751, 24755>    <24749, 24755, 24752>,
    <24749, 24752, 24756>    <24749, 24756, 24753>,
    <24749, 24753, 24757>    <24758, 24766, 24759>,
    <24758, 24759, 24763>    <24758, 24763, 24760>,
    <24758, 24760, 24764>    <24758, 24764, 24761>,
    <24758, 24761, 24765>    <24758, 24765, 24762>,
    <24758, 24762, 24766>    <24767, 24775, 24768>,
    <24767, 24768, 24772>    <24767, 24772, 24769>,
    <24767, 24769, 24773>    <24767, 24773, 24770>,
    <24767, 24770, 24774>    <24767, 24774, 24771>,
    <24767, 24771, 24775>    <24776, 24784, 24777>,
    <24776, 24777, 24781>    <24776, 24781, 24778>,
    <24776, 24778, 24782>    <24776, 24782, 24779>,
    <24776, 24779, 24783>    <24776, 24783, 24780>,
    <24776, 24780, 24784>    <24785, 24793, 24786>,
    <24785, 24786, 24790>    <24785, 24790, 24787>,
    <24785, 24787, 24791>    <24785, 24791, 24788>,
    <24785, 24788, 24792>    <24785, 24792, 24789>,
    <24785, 24789, 24793>    <24794, 24802, 24795>,
    <24794, 24795, 24799>    <24794, 24799, 24796>,
    <24794, 24796, 24800>    <24794, 24800, 24797>,
    <24794, 24797, 24801>    <24794, 24801, 24798>,
    <24794, 24798, 24802>    <24803, 24811, 24804>,
    <24803, 24804, 24808>    <24803, 24808, 24805>,
    <24803, 24805, 24809>    <24803, 24809, 24806>,
    <24803, 24806, 24810>    <24803, 24810, 24807>,
    <24803, 24807, 24811>    <24812, 24820, 24813>,
    <24812, 24813, 24817>    <24812, 24817, 24814>,
    <24812, 24814, 24818>    <24812, 24818, 24815>,
    <24812, 24815, 24819>    <24812, 24819, 24816>,
    <24812, 24816, 24820>    <24821, 24829, 24822>,
    <24821, 24822, 24826>    <24821, 24826, 24823>,
    <24821, 24823, 24827>    <24821, 24827, 24824>,
    <24821, 24824, 24828>    <24821, 24828, 24825>,
    <24821, 24825, 24829>    <24830, 24838, 24831>,
    <24830, 24831, 24835>    <24830, 24835, 24832>,
    <24830, 24832, 24836>    <24830, 24836, 24833>,
    <24830, 24833, 24837>    <24830, 24837, 24834>,
    <24830, 24834, 24838>    <24839, 24847, 24840>,
    <24839, 24840, 24844>    <24839, 24844, 24841>,
    <24839, 24841, 24845>    <24839, 24845, 24842>,
    <24839, 24842, 24846>    <24839, 24846, 24843>,
    <24839, 24843, 24847>    <24848, 24856, 24849>,
    <24848, 24849, 24853>    <24848, 24853, 24850>,
    <24848, 24850, 24854>    <24848, 24854, 24851>,
    <24848, 24851, 24855>    <24848, 24855, 24852>,
    <24848, 24852, 24856>    <24857, 24865, 24858>,
    <24857, 24858, 24862>    <24857, 24862, 24859>,
    <24857, 24859, 24863>    <24857, 24863, 24860>,
    <24857, 24860, 24864>    <24857, 24864, 24861>,
    <24857, 24861, 24865>    <24866, 24874, 24867>,
    <24866, 24867, 24871>    <24866, 24871, 24868>,
    <24866, 24868, 24872>    <24866, 24872, 24869>,
    <24866, 24869, 24873>    <24866, 24873, 24870>,
    <24866, 24870, 24874>    <24875, 24883, 24876>,
    <24875, 24876, 24880>    <24875, 24880, 24877>,
    <24875, 24877, 24881>    <24875, 24881, 24878>,
    <24875, 24878, 24882>    <24875, 24882, 24879>,
    <24875, 24879, 24883>    <24884, 24892, 24885>,
    <24884, 24885, 24889>    <24884, 24889, 24886>,
    <24884, 24886, 24890>    <24884, 24890, 24887>,
    <24884, 24887, 24891>    <24884, 24891, 24888>,
    <24884, 24888, 24892>    <24893, 24901, 24894>,
    <24893, 24894, 24898>    <24893, 24898, 24895>,
    <24893, 24895, 24899>    <24893, 24899, 24896>,
    <24893, 24896, 24900>    <24893, 24900, 24897>,
    <24893, 24897, 24901>    <24902, 24910, 24903>,
    <24902, 24903, 24907>    <24902, 24907, 24904>,
    <24902, 24904, 24908>    <24902, 24908, 24905>,
    <24902, 24905, 24909>    <24902, 24909, 24906>,
    <24902, 24906, 24910>    <24911, 24919, 24912>,
    <24911, 24912, 24916>    <24911, 24916, 24913>,
    <24911, 24913, 24917>    <24911, 24917, 24914>,
    <24911, 24914, 24918>    <24911, 24918, 24915>,
    <24911, 24915, 24919>    <24920, 24928, 24921>,
    <24920, 24921, 24925>    <24920, 24925, 24922>,
    <24920, 24922, 24926>    <24920, 24926, 24923>,
    <24920, 24923, 24927>    <24920, 24927, 24924>,
    <24920, 24924, 24928>    <24929, 24937, 24930>,
    <24929, 24930, 24934>    <24929, 24934, 24931>,
    <24929, 24931, 24935>    <24929, 24935, 24932>,
    <24929, 24932, 24936>    <24929, 24936, 24933>,
    <24929, 24933, 24937>    <24938, 24946, 24939>,
    <24938, 24939, 24943>    <24938, 24943, 24940>,
    <24938, 24940, 24944>    <24938, 24944, 24941>,
    <24938, 24941, 24945>    <24938, 24945, 24942>,
    <24938, 24942, 24946>    <24947, 24955, 24948>,
    <24947, 24948, 24952>    <24947, 24952, 24949>,
    <24947, 24949, 24953>    <24947, 24953, 24950>,
    <24947, 24950, 24954>    <24947, 24954, 24951>,
    <24947, 24951, 24955>    <24956, 24964, 24957>,
    <24956, 24957, 24961>    <24956, 24961, 24958>,
    <24956, 24958, 24962>    <24956, 24962, 24959>,
    <24956, 24959, 24963>    <24956, 24963, 24960>,
    <24956, 24960, 24964>    <24965, 24973, 24966>,
    <24965, 24966, 24970>    <24965, 24970, 24967>,
    <24965, 24967, 24971>    <24965, 24971, 24968>,
    <24965, 24968, 24972>    <24965, 24972, 24969>,
    <24965, 24969, 24973>    <24974, 24982, 24975>,
    <24974, 24975, 24979>    <24974, 24979, 24976>,
    <24974, 24976, 24980>    <24974, 24980, 24977>,
    <24974, 24977, 24981>    <24974, 24981, 24978>,
    <24974, 24978, 24982>    <24983, 24991, 24984>,
    <24983, 24984, 24988>    <24983, 24988, 24985>,
    <24983, 24985, 24989>    <24983, 24989, 24986>,
    <24983, 24986, 24990>    <24983, 24990, 24987>,
    <24983, 24987, 24991>    <24992, 25000, 24993>,
    <24992, 24993, 24997>    <24992, 24997, 24994>,
    <24992, 24994, 24998>    <24992, 24998, 24995>,
    <24992, 24995, 24999>    <24992, 24999, 24996>,
    <24992, 24996, 25000>    <25001, 25009, 25002>,
    <25001, 25002, 25006>    <25001, 25006, 25003>,
    <25001, 25003, 25007>    <25001, 25007, 25004>,
    <25001, 25004, 25008>    <25001, 25008, 25005>,
    <25001, 25005, 25009>    <25010, 25018, 25011>,
    <25010, 25011, 25015>    <25010, 25015, 25012>,
    <25010, 25012, 25016>    <25010, 25016, 25013>,
    <25010, 25013, 25017>    <25010, 25017, 25014>,
    <25010, 25014, 25018>    <25019, 25027, 25020>,
    <25019, 25020, 25024>    <25019, 25024, 25021>,
    <25019, 25021, 25025>    <25019, 25025, 25022>,
    <25019, 25022, 25026>    <25019, 25026, 25023>,
    <25019, 25023, 25027>    <25028, 25036, 25029>,
    <25028, 25029, 25033>    <25028, 25033, 25030>,
    <25028, 25030, 25034>    <25028, 25034, 25031>,
    <25028, 25031, 25035>    <25028, 25035, 25032>,
    <25028, 25032, 25036>    <25037, 25045, 25038>,
    <25037, 25038, 25042>    <25037, 25042, 25039>,
    <25037, 25039, 25043>    <25037, 25043, 25040>,
    <25037, 25040, 25044>    <25037, 25044, 25041>,
    <25037, 25041, 25045>    <25046, 25054, 25047>,
    <25046, 25047, 25051>    <25046, 25051, 25048>,
    <25046, 25048, 25052>    <25046, 25052, 25049>,
    <25046, 25049, 25053>    <25046, 25053, 25050>,
    <25046, 25050, 25054>    <25055, 25063, 25056>,
    <25055, 25056, 25060>    <25055, 25060, 25057>,
    <25055, 25057, 25061>    <25055, 25061, 25058>,
    <25055, 25058, 25062>    <25055, 25062, 25059>,
    <25055, 25059, 25063>    <25064, 25072, 25065>,
    <25064, 25065, 25069>    <25064, 25069, 25066>,
    <25064, 25066, 25070>    <25064, 25070, 25067>,
    <25064, 25067, 25071>    <25064, 25071, 25068>,
    <25064, 25068, 25072>    <25073, 25081, 25074>,
    <25073, 25074, 25078>    <25073, 25078, 25075>,
    <25073, 25075, 25079>    <25073, 25079, 25076>,
    <25073, 25076, 25080>    <25073, 25080, 25077>,
    <25073, 25077, 25081>    <25082, 25090, 25083>,
    <25082, 25083, 25087>    <25082, 25087, 25084>,
    <25082, 25084, 25088>    <25082, 25088, 25085>,
    <25082, 25085, 25089>    <25082, 25089, 25086>,
    <25082, 25086, 25090>    <25091, 25099, 25092>,
    <25091, 25092, 25096>    <25091, 25096, 25093>,
    <25091, 25093, 25097>    <25091, 25097, 25094>,
    <25091, 25094, 25098>    <25091, 25098, 25095>,
    <25091, 25095, 25099>    <25100, 25108, 25101>,
    <25100, 25101, 25105>    <25100, 25105, 25102>,
    <25100, 25102, 25106>    <25100, 25106, 25103>,
    <25100, 25103, 25107>    <25100, 25107, 25104>,
    <25100, 25104, 25108>    <25109, 25117, 25110>,
    <25109, 25110, 25114>    <25109, 25114, 25111>,
    <25109, 25111, 25115>    <25109, 25115, 25112>,
    <25109, 25112, 25116>    <25109, 25116, 25113>,
    <25109, 25113, 25117>    <25118, 25126, 25119>,
    <25118, 25119, 25123>    <25118, 25123, 25120>,
    <25118, 25120, 25124>    <25118, 25124, 25121>,
    <25118, 25121, 25125>    <25118, 25125, 25122>,
    <25118, 25122, 25126>    <25127, 25135, 25128>,
    <25127, 25128, 25132>    <25127, 25132, 25129>,
    <25127, 25129, 25133>    <25127, 25133, 25130>,
    <25127, 25130, 25134>    <25127, 25134, 25131>,
    <25127, 25131, 25135>    <25136, 25144, 25137>,
    <25136, 25137, 25141>    <25136, 25141, 25138>,
    <25136, 25138, 25142>    <25136, 25142, 25139>,
    <25136, 25139, 25143>    <25136, 25143, 25140>,
    <25136, 25140, 25144>    <25145, 25153, 25146>,
    <25145, 25146, 25150>    <25145, 25150, 25147>,
    <25145, 25147, 25151>    <25145, 25151, 25148>,
    <25145, 25148, 25152>    <25145, 25152, 25149>,
    <25145, 25149, 25153>    <25154, 25162, 25155>,
    <25154, 25155, 25159>    <25154, 25159, 25156>,
    <25154, 25156, 25160>    <25154, 25160, 25157>,
    <25154, 25157, 25161>    <25154, 25161, 25158>,
    <25154, 25158, 25162>    <25163, 25171, 25164>,
    <25163, 25164, 25168>    <25163, 25168, 25165>,
    <25163, 25165, 25169>    <25163, 25169, 25166>,
    <25163, 25166, 25170>    <25163, 25170, 25167>,
    <25163, 25167, 25171>    <25172, 25180, 25173>,
    <25172, 25173, 25177>    <25172, 25177, 25174>,
    <25172, 25174, 25178>    <25172, 25178, 25175>,
    <25172, 25175, 25179>    <25172, 25179, 25176>,
    <25172, 25176, 25180>    <25181, 25189, 25182>,
    <25181, 25182, 25186>    <25181, 25186, 25183>,
    <25181, 25183, 25187>    <25181, 25187, 25184>,
    <25181, 25184, 25188>    <25181, 25188, 25185>,
    <25181, 25185, 25189>    <25190, 25198, 25191>,
    <25190, 25191, 25195>    <25190, 25195, 25192>,
    <25190, 25192, 25196>    <25190, 25196, 25193>,
    <25190, 25193, 25197>    <25190, 25197, 25194>,
    <25190, 25194, 25198>    <25199, 25207, 25200>,
    <25199, 25200, 25204>    <25199, 25204, 25201>,
    <25199, 25201, 25205>    <25199, 25205, 25202>,
    <25199, 25202, 25206>    <25199, 25206, 25203>,
    <25199, 25203, 25207>    <25208, 25216, 25209>,
    <25208, 25209, 25213>    <25208, 25213, 25210>,
    <25208, 25210, 25214>    <25208, 25214, 25211>,
    <25208, 25211, 25215>    <25208, 25215, 25212>,
    <25208, 25212, 25216>    <25217, 25225, 25218>,
    <25217, 25218, 25222>    <25217, 25222, 25219>,
    <25217, 25219, 25223>    <25217, 25223, 25220>,
    <25217, 25220, 25224>    <25217, 25224, 25221>,
    <25217, 25221, 25225>    <25226, 25234, 25227>,
    <25226, 25227, 25231>    <25226, 25231, 25228>,
    <25226, 25228, 25232>    <25226, 25232, 25229>,
    <25226, 25229, 25233>    <25226, 25233, 25230>,
    <25226, 25230, 25234>    <25235, 25243, 25236>,
    <25235, 25236, 25240>    <25235, 25240, 25237>,
    <25235, 25237, 25241>    <25235, 25241, 25238>,
    <25235, 25238, 25242>    <25235, 25242, 25239>,
    <25235, 25239, 25243>    <25244, 25252, 25245>,
    <25244, 25245, 25249>    <25244, 25249, 25246>,
    <25244, 25246, 25250>    <25244, 25250, 25247>,
    <25244, 25247, 25251>    <25244, 25251, 25248>,
    <25244, 25248, 25252>    <25253, 25261, 25254>,
    <25253, 25254, 25258>    <25253, 25258, 25255>,
    <25253, 25255, 25259>    <25253, 25259, 25256>,
    <25253, 25256, 25260>    <25253, 25260, 25257>,
    <25253, 25257, 25261>    <25262, 25270, 25263>,
    <25262, 25263, 25267>    <25262, 25267, 25264>,
    <25262, 25264, 25268>    <25262, 25268, 25265>,
    <25262, 25265, 25269>    <25262, 25269, 25266>,
    <25262, 25266, 25270>    <25271, 25279, 25272>,
    <25271, 25272, 25276>    <25271, 25276, 25273>,
    <25271, 25273, 25277>    <25271, 25277, 25274>,
    <25271, 25274, 25278>    <25271, 25278, 25275>,
    <25271, 25275, 25279>    <25280, 25288, 25281>,
    <25280, 25281, 25285>    <25280, 25285, 25282>,
    <25280, 25282, 25286>    <25280, 25286, 25283>,
    <25280, 25283, 25287>    <25280, 25287, 25284>,
    <25280, 25284, 25288>    <25289, 25297, 25290>,
    <25289, 25290, 25294>    <25289, 25294, 25291>,
    <25289, 25291, 25295>    <25289, 25295, 25292>,
    <25289, 25292, 25296>    <25289, 25296, 25293>,
    <25289, 25293, 25297>    <25298, 25306, 25299>,
    <25298, 25299, 25303>    <25298, 25303, 25300>,
    <25298, 25300, 25304>    <25298, 25304, 25301>,
    <25298, 25301, 25305>    <25298, 25305, 25302>,
    <25298, 25302, 25306>    <25307, 25315, 25308>,
    <25307, 25308, 25312>    <25307, 25312, 25309>,
    <25307, 25309, 25313>    <25307, 25313, 25310>,
    <25307, 25310, 25314>    <25307, 25314, 25311>,
    <25307, 25311, 25315>    <25316, 25324, 25317>,
    <25316, 25317, 25321>    <25316, 25321, 25318>,
    <25316, 25318, 25322>    <25316, 25322, 25319>,
    <25316, 25319, 25323>    <25316, 25323, 25320>,
    <25316, 25320, 25324>    <25325, 25333, 25326>,
    <25325, 25326, 25330>    <25325, 25330, 25327>,
    <25325, 25327, 25331>    <25325, 25331, 25328>,
    <25325, 25328, 25332>    <25325, 25332, 25329>,
    <25325, 25329, 25333>    <25334, 25342, 25335>,
    <25334, 25335, 25339>    <25334, 25339, 25336>,
    <25334, 25336, 25340>    <25334, 25340, 25337>,
    <25334, 25337, 25341>    <25334, 25341, 25338>,
    <25334, 25338, 25342>    <25343, 25351, 25344>,
    <25343, 25344, 25348>    <25343, 25348, 25345>,
    <25343, 25345, 25349>    <25343, 25349, 25346>,
    <25343, 25346, 25350>    <25343, 25350, 25347>,
    <25343, 25347, 25351>    <25352, 25360, 25353>,
    <25352, 25353, 25357>    <25352, 25357, 25354>,
    <25352, 25354, 25358>    <25352, 25358, 25355>,
    <25352, 25355, 25359>    <25352, 25359, 25356>,
    <25352, 25356, 25360>    <25361, 25369, 25362>,
    <25361, 25362, 25366>    <25361, 25366, 25363>,
    <25361, 25363, 25367>    <25361, 25367, 25364>,
    <25361, 25364, 25368>    <25361, 25368, 25365>,
    <25361, 25365, 25369>    <25370, 25378, 25371>,
    <25370, 25371, 25375>    <25370, 25375, 25372>,
    <25370, 25372, 25376>    <25370, 25376, 25373>,
    <25370, 25373, 25377>    <25370, 25377, 25374>,
    <25370, 25374, 25378>    <25379, 25387, 25380>,
    <25379, 25380, 25384>    <25379, 25384, 25381>,
    <25379, 25381, 25385>    <25379, 25385, 25382>,
    <25379, 25382, 25386>    <25379, 25386, 25383>,
    <25379, 25383, 25387>    <25388, 25396, 25389>,
    <25388, 25389, 25393>    <25388, 25393, 25390>,
    <25388, 25390, 25394>    <25388, 25394, 25391>,
    <25388, 25391, 25395>    <25388, 25395, 25392>,
    <25388, 25392, 25396>    <25397, 25405, 25398>,
    <25397, 25398, 25402>    <25397, 25402, 25399>,
    <25397, 25399, 25403>    <25397, 25403, 25400>,
    <25397, 25400, 25404>    <25397, 25404, 25401>,
    <25397, 25401, 25405>    <25406, 25414, 25407>,
    <25406, 25407, 25411>    <25406, 25411, 25408>,
    <25406, 25408, 25412>    <25406, 25412, 25409>,
    <25406, 25409, 25413>    <25406, 25413, 25410>,
    <25406, 25410, 25414>    <25415, 25423, 25416>,
    <25415, 25416, 25420>    <25415, 25420, 25417>,
    <25415, 25417, 25421>    <25415, 25421, 25418>,
    <25415, 25418, 25422>    <25415, 25422, 25419>,
    <25415, 25419, 25423>    <25424, 25432, 25425>,
    <25424, 25425, 25429>    <25424, 25429, 25426>,
    <25424, 25426, 25430>    <25424, 25430, 25427>,
    <25424, 25427, 25431>    <25424, 25431, 25428>,
    <25424, 25428, 25432>    <25433, 25441, 25434>,
    <25433, 25434, 25438>    <25433, 25438, 25435>,
    <25433, 25435, 25439>    <25433, 25439, 25436>,
    <25433, 25436, 25440>    <25433, 25440, 25437>,
    <25433, 25437, 25441>    <25442, 25450, 25443>,
    <25442, 25443, 25447>    <25442, 25447, 25444>,
    <25442, 25444, 25448>    <25442, 25448, 25445>,
    <25442, 25445, 25449>    <25442, 25449, 25446>,
    <25442, 25446, 25450>    <25451, 25459, 25452>,
    <25451, 25452, 25456>    <25451, 25456, 25453>,
    <25451, 25453, 25457>    <25451, 25457, 25454>,
    <25451, 25454, 25458>    <25451, 25458, 25455>,
    <25451, 25455, 25459>    <25460, 25468, 25461>,
    <25460, 25461, 25465>    <25460, 25465, 25462>,
    <25460, 25462, 25466>    <25460, 25466, 25463>,
    <25460, 25463, 25467>    <25460, 25467, 25464>,
    <25460, 25464, 25468>    <25469, 25477, 25470>,
    <25469, 25470, 25474>    <25469, 25474, 25471>,
    <25469, 25471, 25475>    <25469, 25475, 25472>,
    <25469, 25472, 25476>    <25469, 25476, 25473>,
    <25469, 25473, 25477>    <25478, 25486, 25479>,
    <25478, 25479, 25483>    <25478, 25483, 25480>,
    <25478, 25480, 25484>    <25478, 25484, 25481>,
    <25478, 25481, 25485>    <25478, 25485, 25482>,
    <25478, 25482, 25486>    <25487, 25495, 25488>,
    <25487, 25488, 25492>    <25487, 25492, 25489>,
    <25487, 25489, 25493>    <25487, 25493, 25490>,
    <25487, 25490, 25494>    <25487, 25494, 25491>,
    <25487, 25491, 25495>    <25496, 25504, 25497>,
    <25496, 25497, 25501>    <25496, 25501, 25498>,
    <25496, 25498, 25502>    <25496, 25502, 25499>,
    <25496, 25499, 25503>    <25496, 25503, 25500>,
    <25496, 25500, 25504>    <25505, 25513, 25506>,
    <25505, 25506, 25510>    <25505, 25510, 25507>,
    <25505, 25507, 25511>    <25505, 25511, 25508>,
    <25505, 25508, 25512>    <25505, 25512, 25509>,
    <25505, 25509, 25513>    <25514, 25522, 25515>,
    <25514, 25515, 25519>    <25514, 25519, 25516>,
    <25514, 25516, 25520>    <25514, 25520, 25517>,
    <25514, 25517, 25521>    <25514, 25521, 25518>,
    <25514, 25518, 25522>    <25523, 25531, 25524>,
    <25523, 25524, 25528>    <25523, 25528, 25525>,
    <25523, 25525, 25529>    <25523, 25529, 25526>,
    <25523, 25526, 25530>    <25523, 25530, 25527>,
    <25523, 25527, 25531>    <25532, 25540, 25533>,
    <25532, 25533, 25537>    <25532, 25537, 25534>,
    <25532, 25534, 25538>    <25532, 25538, 25535>,
    <25532, 25535, 25539>    <25532, 25539, 25536>,
    <25532, 25536, 25540>    <25541, 25549, 25542>,
    <25541, 25542, 25546>    <25541, 25546, 25543>,
    <25541, 25543, 25547>    <25541, 25547, 25544>,
    <25541, 25544, 25548>    <25541, 25548, 25545>,
    <25541, 25545, 25549>    <25550, 25558, 25551>,
    <25550, 25551, 25555>    <25550, 25555, 25552>,
    <25550, 25552, 25556>    <25550, 25556, 25553>,
    <25550, 25553, 25557>    <25550, 25557, 25554>,
    <25550, 25554, 25558>    <25559, 25567, 25560>,
    <25559, 25560, 25564>    <25559, 25564, 25561>,
    <25559, 25561, 25565>    <25559, 25565, 25562>,
    <25559, 25562, 25566>    <25559, 25566, 25563>,
    <25559, 25563, 25567>    <25568, 25576, 25569>,
    <25568, 25569, 25573>    <25568, 25573, 25570>,
    <25568, 25570, 25574>    <25568, 25574, 25571>,
    <25568, 25571, 25575>    <25568, 25575, 25572>,
    <25568, 25572, 25576>    <25577, 25585, 25578>,
    <25577, 25578, 25582>    <25577, 25582, 25579>,
    <25577, 25579, 25583>    <25577, 25583, 25580>,
    <25577, 25580, 25584>    <25577, 25584, 25581>,
    <25577, 25581, 25585>    <25586, 25594, 25587>,
    <25586, 25587, 25591>    <25586, 25591, 25588>,
    <25586, 25588, 25592>    <25586, 25592, 25589>,
    <25586, 25589, 25593>    <25586, 25593, 25590>,
    <25586, 25590, 25594>    <25595, 25603, 25596>,
    <25595, 25596, 25600>    <25595, 25600, 25597>,
    <25595, 25597, 25601>    <25595, 25601, 25598>,
    <25595, 25598, 25602>    <25595, 25602, 25599>,
    <25595, 25599, 25603>    <25604, 25612, 25605>,
    <25604, 25605, 25609>    <25604, 25609, 25606>,
    <25604, 25606, 25610>    <25604, 25610, 25607>,
    <25604, 25607, 25611>    <25604, 25611, 25608>,
    <25604, 25608, 25612>    <25613, 25621, 25614>,
    <25613, 25614, 25618>    <25613, 25618, 25615>,
    <25613, 25615, 25619>    <25613, 25619, 25616>,
    <25613, 25616, 25620>    <25613, 25620, 25617>,
    <25613, 25617, 25621>    <25622, 25630, 25623>,
    <25622, 25623, 25627>    <25622, 25627, 25624>,
    <25622, 25624, 25628>    <25622, 25628, 25625>,
    <25622, 25625, 25629>    <25622, 25629, 25626>,
    <25622, 25626, 25630>    <25631, 25639, 25632>,
    <25631, 25632, 25636>    <25631, 25636, 25633>,
    <25631, 25633, 25637>    <25631, 25637, 25634>,
    <25631, 25634, 25638>    <25631, 25638, 25635>,
    <25631, 25635, 25639>    <25640, 25648, 25641>,
    <25640, 25641, 25645>    <25640, 25645, 25642>,
    <25640, 25642, 25646>    <25640, 25646, 25643>,
    <25640, 25643, 25647>    <25640, 25647, 25644>,
    <25640, 25644, 25648>    <25649, 25657, 25650>,
    <25649, 25650, 25654>    <25649, 25654, 25651>,
    <25649, 25651, 25655>    <25649, 25655, 25652>,
    <25649, 25652, 25656>    <25649, 25656, 25653>,
    <25649, 25653, 25657>    <25658, 25666, 25659>,
    <25658, 25659, 25663>    <25658, 25663, 25660>,
    <25658, 25660, 25664>    <25658, 25664, 25661>,
    <25658, 25661, 25665>    <25658, 25665, 25662>,
    <25658, 25662, 25666>    <25667, 25675, 25668>,
    <25667, 25668, 25672>    <25667, 25672, 25669>,
    <25667, 25669, 25673>    <25667, 25673, 25670>,
    <25667, 25670, 25674>    <25667, 25674, 25671>,
    <25667, 25671, 25675>    <25676, 25684, 25677>,
    <25676, 25677, 25681>    <25676, 25681, 25678>,
    <25676, 25678, 25682>    <25676, 25682, 25679>,
    <25676, 25679, 25683>    <25676, 25683, 25680>,
    <25676, 25680, 25684>    <25685, 25693, 25686>,
    <25685, 25686, 25690>    <25685, 25690, 25687>,
    <25685, 25687, 25691>    <25685, 25691, 25688>,
    <25685, 25688, 25692>    <25685, 25692, 25689>,
    <25685, 25689, 25693>    <25694, 25702, 25695>,
    <25694, 25695, 25699>    <25694, 25699, 25696>,
    <25694, 25696, 25700>    <25694, 25700, 25697>,
    <25694, 25697, 25701>    <25694, 25701, 25698>,
    <25694, 25698, 25702>    <25703, 25711, 25704>,
    <25703, 25704, 25708>    <25703, 25708, 25705>,
    <25703, 25705, 25709>    <25703, 25709, 25706>,
    <25703, 25706, 25710>    <25703, 25710, 25707>,
    <25703, 25707, 25711>    <25712, 25720, 25713>,
    <25712, 25713, 25717>    <25712, 25717, 25714>,
    <25712, 25714, 25718>    <25712, 25718, 25715>,
    <25712, 25715, 25719>    <25712, 25719, 25716>,
    <25712, 25716, 25720>    <25721, 25729, 25722>,
    <25721, 25722, 25726>    <25721, 25726, 25723>,
    <25721, 25723, 25727>    <25721, 25727, 25724>,
    <25721, 25724, 25728>    <25721, 25728, 25725>,
    <25721, 25725, 25729>    <25730, 25738, 25731>,
    <25730, 25731, 25735>    <25730, 25735, 25732>,
    <25730, 25732, 25736>    <25730, 25736, 25733>,
    <25730, 25733, 25737>    <25730, 25737, 25734>,
    <25730, 25734, 25738>    <25739, 25747, 25740>,
    <25739, 25740, 25744>    <25739, 25744, 25741>,
    <25739, 25741, 25745>    <25739, 25745, 25742>,
    <25739, 25742, 25746>    <25739, 25746, 25743>,
    <25739, 25743, 25747>    <25748, 25756, 25749>,
    <25748, 25749, 25753>    <25748, 25753, 25750>,
    <25748, 25750, 25754>    <25748, 25754, 25751>,
    <25748, 25751, 25755>    <25748, 25755, 25752>,
    <25748, 25752, 25756>    <25757, 25765, 25758>,
    <25757, 25758, 25762>    <25757, 25762, 25759>,
    <25757, 25759, 25763>    <25757, 25763, 25760>,
    <25757, 25760, 25764>    <25757, 25764, 25761>,
    <25757, 25761, 25765>    <25766, 25774, 25767>,
    <25766, 25767, 25771>    <25766, 25771, 25768>,
    <25766, 25768, 25772>    <25766, 25772, 25769>,
    <25766, 25769, 25773>    <25766, 25773, 25770>,
    <25766, 25770, 25774>    <25775, 25783, 25776>,
    <25775, 25776, 25780>    <25775, 25780, 25777>,
    <25775, 25777, 25781>    <25775, 25781, 25778>,
    <25775, 25778, 25782>    <25775, 25782, 25779>,
    <25775, 25779, 25783>    <25784, 25792, 25785>,
    <25784, 25785, 25789>    <25784, 25789, 25786>,
    <25784, 25786, 25790>    <25784, 25790, 25787>,
    <25784, 25787, 25791>    <25784, 25791, 25788>,
    <25784, 25788, 25792>    <25793, 25801, 25794>,
    <25793, 25794, 25798>    <25793, 25798, 25795>,
    <25793, 25795, 25799>    <25793, 25799, 25796>,
    <25793, 25796, 25800>    <25793, 25800, 25797>,
    <25793, 25797, 25801>    <25802, 25810, 25803>,
    <25802, 25803, 25807>    <25802, 25807, 25804>,
    <25802, 25804, 25808>    <25802, 25808, 25805>,
    <25802, 25805, 25809>    <25802, 25809, 25806>,
    <25802, 25806, 25810>    <25811, 25819, 25812>,
    <25811, 25812, 25816>    <25811, 25816, 25813>,
    <25811, 25813, 25817>    <25811, 25817, 25814>,
    <25811, 25814, 25818>    <25811, 25818, 25815>,
    <25811, 25815, 25819>    <25820, 25828, 25821>,
    <25820, 25821, 25825>    <25820, 25825, 25822>,
    <25820, 25822, 25826>    <25820, 25826, 25823>,
    <25820, 25823, 25827>    <25820, 25827, 25824>,
    <25820, 25824, 25828>    <25829, 25837, 25830>,
    <25829, 25830, 25834>    <25829, 25834, 25831>,
    <25829, 25831, 25835>    <25829, 25835, 25832>,
    <25829, 25832, 25836>    <25829, 25836, 25833>,
    <25829, 25833, 25837>    <25838, 25846, 25839>,
    <25838, 25839, 25843>    <25838, 25843, 25840>,
    <25838, 25840, 25844>    <25838, 25844, 25841>,
    <25838, 25841, 25845>    <25838, 25845, 25842>,
    <25838, 25842, 25846>    <25847, 25855, 25848>,
    <25847, 25848, 25852>    <25847, 25852, 25849>,
    <25847, 25849, 25853>    <25847, 25853, 25850>,
    <25847, 25850, 25854>    <25847, 25854, 25851>,
    <25847, 25851, 25855>    <25856, 25864, 25857>,
    <25856, 25857, 25861>    <25856, 25861, 25858>,
    <25856, 25858, 25862>    <25856, 25862, 25859>,
    <25856, 25859, 25863>    <25856, 25863, 25860>,
    <25856, 25860, 25864>    <25865, 25873, 25866>,
    <25865, 25866, 25870>    <25865, 25870, 25867>,
    <25865, 25867, 25871>    <25865, 25871, 25868>,
    <25865, 25868, 25872>    <25865, 25872, 25869>,
    <25865, 25869, 25873>    <25874, 25882, 25875>,
    <25874, 25875, 25879>    <25874, 25879, 25876>,
    <25874, 25876, 25880>    <25874, 25880, 25877>,
    <25874, 25877, 25881>    <25874, 25881, 25878>,
    <25874, 25878, 25882>    <25883, 25891, 25884>,
    <25883, 25884, 25888>    <25883, 25888, 25885>,
    <25883, 25885, 25889>    <25883, 25889, 25886>,
    <25883, 25886, 25890>    <25883, 25890, 25887>,
    <25883, 25887, 25891>    <25892, 25900, 25893>,
    <25892, 25893, 25897>    <25892, 25897, 25894>,
    <25892, 25894, 25898>    <25892, 25898, 25895>,
    <25892, 25895, 25899>    <25892, 25899, 25896>,
    <25892, 25896, 25900>    <25901, 25909, 25902>,
    <25901, 25902, 25906>    <25901, 25906, 25903>,
    <25901, 25903, 25907>    <25901, 25907, 25904>,
    <25901, 25904, 25908>    <25901, 25908, 25905>,
    <25901, 25905, 25909>    <25910, 25918, 25911>,
    <25910, 25911, 25915>    <25910, 25915, 25912>,
    <25910, 25912, 25916>    <25910, 25916, 25913>,
    <25910, 25913, 25917>    <25910, 25917, 25914>,
    <25910, 25914, 25918>    <25919, 25927, 25920>,
    <25919, 25920, 25924>    <25919, 25924, 25921>,
    <25919, 25921, 25925>    <25919, 25925, 25922>,
    <25919, 25922, 25926>    <25919, 25926, 25923>,
    <25919, 25923, 25927>    <25928, 25936, 25929>,
    <25928, 25929, 25933>    <25928, 25933, 25930>,
    <25928, 25930, 25934>    <25928, 25934, 25931>,
    <25928, 25931, 25935>    <25928, 25935, 25932>,
    <25928, 25932, 25936>    <25937, 25945, 25938>,
    <25937, 25938, 25942>    <25937, 25942, 25939>,
    <25937, 25939, 25943>    <25937, 25943, 25940>,
    <25937, 25940, 25944>    <25937, 25944, 25941>,
    <25937, 25941, 25945>    <25946, 25954, 25947>,
    <25946, 25947, 25951>    <25946, 25951, 25948>,
    <25946, 25948, 25952>    <25946, 25952, 25949>,
    <25946, 25949, 25953>    <25946, 25953, 25950>,
    <25946, 25950, 25954>    <25955, 25963, 25956>,
    <25955, 25956, 25960>    <25955, 25960, 25957>,
    <25955, 25957, 25961>    <25955, 25961, 25958>,
    <25955, 25958, 25962>    <25955, 25962, 25959>,
    <25955, 25959, 25963>    <25964, 25972, 25965>,
    <25964, 25965, 25969>    <25964, 25969, 25966>,
    <25964, 25966, 25970>    <25964, 25970, 25967>,
    <25964, 25967, 25971>    <25964, 25971, 25968>,
    <25964, 25968, 25972>    <25973, 25981, 25974>,
    <25973, 25974, 25978>    <25973, 25978, 25975>,
    <25973, 25975, 25979>    <25973, 25979, 25976>,
    <25973, 25976, 25980>    <25973, 25980, 25977>,
    <25973, 25977, 25981>    <25982, 25990, 25983>,
    <25982, 25983, 25987>    <25982, 25987, 25984>,
    <25982, 25984, 25988>    <25982, 25988, 25985>,
    <25982, 25985, 25989>    <25982, 25989, 25986>,
    <25982, 25986, 25990>    <25991, 25999, 25992>,
    <25991, 25992, 25996>    <25991, 25996, 25993>,
    <25991, 25993, 25997>    <25991, 25997, 25994>,
    <25991, 25994, 25998>    <25991, 25998, 25995>,
    <25991, 25995, 25999>    <26000, 26008, 26001>,
    <26000, 26001, 26005>    <26000, 26005, 26002>,
    <26000, 26002, 26006>    <26000, 26006, 26003>,
    <26000, 26003, 26007>    <26000, 26007, 26004>,
    <26000, 26004, 26008>    <26009, 26017, 26010>,
    <26009, 26010, 26014>    <26009, 26014, 26011>,
    <26009, 26011, 26015>    <26009, 26015, 26012>,
    <26009, 26012, 26016>    <26009, 26016, 26013>,
    <26009, 26013, 26017>    <26018, 26026, 26019>,
    <26018, 26019, 26023>    <26018, 26023, 26020>,
    <26018, 26020, 26024>    <26018, 26024, 26021>,
    <26018, 26021, 26025>    <26018, 26025, 26022>,
    <26018, 26022, 26026>    <26027, 26035, 26028>,
    <26027, 26028, 26032>    <26027, 26032, 26029>,
    <26027, 26029, 26033>    <26027, 26033, 26030>,
    <26027, 26030, 26034>    <26027, 26034, 26031>,
    <26027, 26031, 26035>    <26036, 26044, 26037>,
    <26036, 26037, 26041>    <26036, 26041, 26038>,
    <26036, 26038, 26042>    <26036, 26042, 26039>,
    <26036, 26039, 26043>    <26036, 26043, 26040>,
    <26036, 26040, 26044>    <26045, 26053, 26046>,
    <26045, 26046, 26050>    <26045, 26050, 26047>,
    <26045, 26047, 26051>    <26045, 26051, 26048>,
    <26045, 26048, 26052>    <26045, 26052, 26049>,
    <26045, 26049, 26053>    <26054, 26062, 26055>,
    <26054, 26055, 26059>    <26054, 26059, 26056>,
    <26054, 26056, 26060>    <26054, 26060, 26057>,
    <26054, 26057, 26061>    <26054, 26061, 26058>,
    <26054, 26058, 26062>    <26063, 26071, 26064>,
    <26063, 26064, 26068>    <26063, 26068, 26065>,
    <26063, 26065, 26069>    <26063, 26069, 26066>,
    <26063, 26066, 26070>    <26063, 26070, 26067>,
    <26063, 26067, 26071>    <26072, 26080, 26073>,
    <26072, 26073, 26077>    <26072, 26077, 26074>,
    <26072, 26074, 26078>    <26072, 26078, 26075>,
    <26072, 26075, 26079>    <26072, 26079, 26076>,
    <26072, 26076, 26080>    <26081, 26089, 26082>,
    <26081, 26082, 26086>    <26081, 26086, 26083>,
    <26081, 26083, 26087>    <26081, 26087, 26084>,
    <26081, 26084, 26088>    <26081, 26088, 26085>,
    <26081, 26085, 26089>    <26090, 26098, 26091>,
    <26090, 26091, 26095>    <26090, 26095, 26092>,
    <26090, 26092, 26096>    <26090, 26096, 26093>,
    <26090, 26093, 26097>    <26090, 26097, 26094>,
    <26090, 26094, 26098>    <26099, 26107, 26100>,
    <26099, 26100, 26104>    <26099, 26104, 26101>,
    <26099, 26101, 26105>    <26099, 26105, 26102>,
    <26099, 26102, 26106>    <26099, 26106, 26103>,
    <26099, 26103, 26107>    <26108, 26116, 26109>,
    <26108, 26109, 26113>    <26108, 26113, 26110>,
    <26108, 26110, 26114>    <26108, 26114, 26111>,
    <26108, 26111, 26115>    <26108, 26115, 26112>,
    <26108, 26112, 26116>    <26117, 26125, 26118>,
    <26117, 26118, 26122>    <26117, 26122, 26119>,
    <26117, 26119, 26123>    <26117, 26123, 26120>,
    <26117, 26120, 26124>    <26117, 26124, 26121>,
    <26117, 26121, 26125>    <26126, 26134, 26127>,
    <26126, 26127, 26131>    <26126, 26131, 26128>,
    <26126, 26128, 26132>    <26126, 26132, 26129>,
    <26126, 26129, 26133>    <26126, 26133, 26130>,
    <26126, 26130, 26134>    <26135, 26143, 26136>,
    <26135, 26136, 26140>    <26135, 26140, 26137>,
    <26135, 26137, 26141>    <26135, 26141, 26138>,
    <26135, 26138, 26142>    <26135, 26142, 26139>,
    <26135, 26139, 26143>    <26144, 26152, 26145>,
    <26144, 26145, 26149>    <26144, 26149, 26146>,
    <26144, 26146, 26150>    <26144, 26150, 26147>,
    <26144, 26147, 26151>    <26144, 26151, 26148>,
    <26144, 26148, 26152>    <26153, 26161, 26154>,
    <26153, 26154, 26158>    <26153, 26158, 26155>,
    <26153, 26155, 26159>    <26153, 26159, 26156>,
    <26153, 26156, 26160>    <26153, 26160, 26157>,
    <26153, 26157, 26161>    <26162, 26170, 26163>,
    <26162, 26163, 26167>    <26162, 26167, 26164>,
    <26162, 26164, 26168>    <26162, 26168, 26165>,
    <26162, 26165, 26169>    <26162, 26169, 26166>,
    <26162, 26166, 26170>    <26171, 26179, 26172>,
    <26171, 26172, 26176>    <26171, 26176, 26173>,
    <26171, 26173, 26177>    <26171, 26177, 26174>,
    <26171, 26174, 26178>    <26171, 26178, 26175>,
    <26171, 26175, 26179>    <26180, 26188, 26181>,
    <26180, 26181, 26185>    <26180, 26185, 26182>,
    <26180, 26182, 26186>    <26180, 26186, 26183>,
    <26180, 26183, 26187>    <26180, 26187, 26184>,
    <26180, 26184, 26188>    <26189, 26197, 26190>,
    <26189, 26190, 26194>    <26189, 26194, 26191>,
    <26189, 26191, 26195>    <26189, 26195, 26192>,
    <26189, 26192, 26196>    <26189, 26196, 26193>,
    <26189, 26193, 26197>    <26198, 26206, 26199>,
    <26198, 26199, 26203>    <26198, 26203, 26200>,
    <26198, 26200, 26204>    <26198, 26204, 26201>,
    <26198, 26201, 26205>    <26198, 26205, 26202>,
    <26198, 26202, 26206>    <26207, 26215, 26208>,
    <26207, 26208, 26212>    <26207, 26212, 26209>,
    <26207, 26209, 26213>    <26207, 26213, 26210>,
    <26207, 26210, 26214>    <26207, 26214, 26211>,
    <26207, 26211, 26215>    <26216, 26224, 26217>,
    <26216, 26217, 26221>    <26216, 26221, 26218>,
    <26216, 26218, 26222>    <26216, 26222, 26219>,
    <26216, 26219, 26223>    <26216, 26223, 26220>,
    <26216, 26220, 26224>    <26225, 26233, 26226>,
    <26225, 26226, 26230>    <26225, 26230, 26227>,
    <26225, 26227, 26231>    <26225, 26231, 26228>,
    <26225, 26228, 26232>    <26225, 26232, 26229>,
    <26225, 26229, 26233>    <26234, 26242, 26235>,
    <26234, 26235, 26239>    <26234, 26239, 26236>,
    <26234, 26236, 26240>    <26234, 26240, 26237>,
    <26234, 26237, 26241>    <26234, 26241, 26238>,
    <26234, 26238, 26242>    <26243, 26251, 26244>,
    <26243, 26244, 26248>    <26243, 26248, 26245>,
    <26243, 26245, 26249>    <26243, 26249, 26246>,
    <26243, 26246, 26250>    <26243, 26250, 26247>,
    <26243, 26247, 26251>    <26252, 26260, 26253>,
    <26252, 26253, 26257>    <26252, 26257, 26254>,
    <26252, 26254, 26258>    <26252, 26258, 26255>,
    <26252, 26255, 26259>    <26252, 26259, 26256>,
    <26252, 26256, 26260>    <26261, 26269, 26262>,
    <26261, 26262, 26266>    <26261, 26266, 26263>,
    <26261, 26263, 26267>    <26261, 26267, 26264>,
    <26261, 26264, 26268>    <26261, 26268, 26265>,
    <26261, 26265, 26269>    <26270, 26278, 26271>,
    <26270, 26271, 26275>    <26270, 26275, 26272>,
    <26270, 26272, 26276>    <26270, 26276, 26273>,
    <26270, 26273, 26277>    <26270, 26277, 26274>,
    <26270, 26274, 26278>    <26279, 26287, 26280>,
    <26279, 26280, 26284>    <26279, 26284, 26281>,
    <26279, 26281, 26285>    <26279, 26285, 26282>,
    <26279, 26282, 26286>    <26279, 26286, 26283>,
    <26279, 26283, 26287>    <26288, 26296, 26289>,
    <26288, 26289, 26293>    <26288, 26293, 26290>,
    <26288, 26290, 26294>    <26288, 26294, 26291>,
    <26288, 26291, 26295>    <26288, 26295, 26292>,
    <26288, 26292, 26296>    <26297, 26305, 26298>,
    <26297, 26298, 26302>    <26297, 26302, 26299>,
    <26297, 26299, 26303>    <26297, 26303, 26300>,
    <26297, 26300, 26304>    <26297, 26304, 26301>,
    <26297, 26301, 26305>    <26306, 26314, 26307>,
    <26306, 26307, 26311>    <26306, 26311, 26308>,
    <26306, 26308, 26312>    <26306, 26312, 26309>,
    <26306, 26309, 26313>    <26306, 26313, 26310>,
    <26306, 26310, 26314>    <26315, 26323, 26316>,
    <26315, 26316, 26320>    <26315, 26320, 26317>,
    <26315, 26317, 26321>    <26315, 26321, 26318>,
    <26315, 26318, 26322>    <26315, 26322, 26319>,
    <26315, 26319, 26323>    <26324, 26332, 26325>,
    <26324, 26325, 26329>    <26324, 26329, 26326>,
    <26324, 26326, 26330>    <26324, 26330, 26327>,
    <26324, 26327, 26331>    <26324, 26331, 26328>,
    <26324, 26328, 26332>    <26333, 26341, 26334>,
    <26333, 26334, 26338>    <26333, 26338, 26335>,
    <26333, 26335, 26339>    <26333, 26339, 26336>,
    <26333, 26336, 26340>    <26333, 26340, 26337>,
    <26333, 26337, 26341>    <26342, 26350, 26343>,
    <26342, 26343, 26347>    <26342, 26347, 26344>,
    <26342, 26344, 26348>    <26342, 26348, 26345>,
    <26342, 26345, 26349>    <26342, 26349, 26346>,
    <26342, 26346, 26350>    <26351, 26359, 26352>,
    <26351, 26352, 26356>    <26351, 26356, 26353>,
    <26351, 26353, 26357>    <26351, 26357, 26354>,
    <26351, 26354, 26358>    <26351, 26358, 26355>,
    <26351, 26355, 26359>    <26360, 26368, 26361>,
    <26360, 26361, 26365>    <26360, 26365, 26362>,
    <26360, 26362, 26366>    <26360, 26366, 26363>,
    <26360, 26363, 26367>    <26360, 26367, 26364>,
    <26360, 26364, 26368>    <26369, 26377, 26370>,
    <26369, 26370, 26374>    <26369, 26374, 26371>,
    <26369, 26371, 26375>    <26369, 26375, 26372>,
    <26369, 26372, 26376>    <26369, 26376, 26373>,
    <26369, 26373, 26377>    <26378, 26386, 26379>,
    <26378, 26379, 26383>    <26378, 26383, 26380>,
    <26378, 26380, 26384>    <26378, 26384, 26381>,
    <26378, 26381, 26385>    <26378, 26385, 26382>,
    <26378, 26382, 26386>    <26387, 26395, 26388>,
    <26387, 26388, 26392>    <26387, 26392, 26389>,
    <26387, 26389, 26393>    <26387, 26393, 26390>,
    <26387, 26390, 26394>    <26387, 26394, 26391>,
    <26387, 26391, 26395>    <26396, 26404, 26397>,
    <26396, 26397, 26401>    <26396, 26401, 26398>,
    <26396, 26398, 26402>    <26396, 26402, 26399>,
    <26396, 26399, 26403>    <26396, 26403, 26400>,
    <26396, 26400, 26404>    <26405, 26413, 26406>,
    <26405, 26406, 26410>    <26405, 26410, 26407>,
    <26405, 26407, 26411>    <26405, 26411, 26408>,
    <26405, 26408, 26412>    <26405, 26412, 26409>,
    <26405, 26409, 26413>    <26414, 26422, 26415>,
    <26414, 26415, 26419>    <26414, 26419, 26416>,
    <26414, 26416, 26420>    <26414, 26420, 26417>,
    <26414, 26417, 26421>    <26414, 26421, 26418>,
    <26414, 26418, 26422>    <26423, 26431, 26424>,
    <26423, 26424, 26428>    <26423, 26428, 26425>,
    <26423, 26425, 26429>    <26423, 26429, 26426>,
    <26423, 26426, 26430>    <26423, 26430, 26427>,
    <26423, 26427, 26431>    <26432, 26440, 26433>,
    <26432, 26433, 26437>    <26432, 26437, 26434>,
    <26432, 26434, 26438>    <26432, 26438, 26435>,
    <26432, 26435, 26439>    <26432, 26439, 26436>,
    <26432, 26436, 26440>    <26441, 26449, 26442>,
    <26441, 26442, 26446>    <26441, 26446, 26443>,
    <26441, 26443, 26447>    <26441, 26447, 26444>,
    <26441, 26444, 26448>    <26441, 26448, 26445>,
    <26441, 26445, 26449>    <26450, 26458, 26451>,
    <26450, 26451, 26455>    <26450, 26455, 26452>,
    <26450, 26452, 26456>    <26450, 26456, 26453>,
    <26450, 26453, 26457>    <26450, 26457, 26454>,
    <26450, 26454, 26458>    <26459, 26467, 26460>,
    <26459, 26460, 26464>    <26459, 26464, 26461>,
    <26459, 26461, 26465>    <26459, 26465, 26462>,
    <26459, 26462, 26466>    <26459, 26466, 26463>,
    <26459, 26463, 26467>    <26468, 26476, 26469>,
    <26468, 26469, 26473>    <26468, 26473, 26470>,
    <26468, 26470, 26474>    <26468, 26474, 26471>,
    <26468, 26471, 26475>    <26468, 26475, 26472>,
    <26468, 26472, 26476>    <26477, 26485, 26478>,
    <26477, 26478, 26482>    <26477, 26482, 26479>,
    <26477, 26479, 26483>    <26477, 26483, 26480>,
    <26477, 26480, 26484>    <26477, 26484, 26481>,
    <26477, 26481, 26485>    <26486, 26494, 26487>,
    <26486, 26487, 26491>    <26486, 26491, 26488>,
    <26486, 26488, 26492>    <26486, 26492, 26489>,
    <26486, 26489, 26493>    <26486, 26493, 26490>,
    <26486, 26490, 26494>    <26495, 26503, 26496>,
    <26495, 26496, 26500>    <26495, 26500, 26497>,
    <26495, 26497, 26501>    <26495, 26501, 26498>,
    <26495, 26498, 26502>    <26495, 26502, 26499>,
    <26495, 26499, 26503>    <26504, 26512, 26505>,
    <26504, 26505, 26509>    <26504, 26509, 26506>,
    <26504, 26506, 26510>    <26504, 26510, 26507>,
    <26504, 26507, 26511>    <26504, 26511, 26508>,
    <26504, 26508, 26512>    <26513, 26521, 26514>,
    <26513, 26514, 26518>    <26513, 26518, 26515>,
    <26513, 26515, 26519>    <26513, 26519, 26516>,
    <26513, 26516, 26520>    <26513, 26520, 26517>,
    <26513, 26517, 26521>    <26522, 26530, 26523>,
    <26522, 26523, 26527>    <26522, 26527, 26524>,
    <26522, 26524, 26528>    <26522, 26528, 26525>,
    <26522, 26525, 26529>    <26522, 26529, 26526>,
    <26522, 26526, 26530>    <26531, 26539, 26532>,
    <26531, 26532, 26536>    <26531, 26536, 26533>,
    <26531, 26533, 26537>    <26531, 26537, 26534>,
    <26531, 26534, 26538>    <26531, 26538, 26535>,
    <26531, 26535, 26539>    <26540, 26548, 26541>,
    <26540, 26541, 26545>    <26540, 26545, 26542>,
    <26540, 26542, 26546>    <26540, 26546, 26543>,
    <26540, 26543, 26547>    <26540, 26547, 26544>,
    <26540, 26544, 26548>    <26549, 26557, 26550>,
    <26549, 26550, 26554>    <26549, 26554, 26551>,
    <26549, 26551, 26555>    <26549, 26555, 26552>,
    <26549, 26552, 26556>    <26549, 26556, 26553>,
    <26549, 26553, 26557>    <26558, 26566, 26559>,
    <26558, 26559, 26563>    <26558, 26563, 26560>,
    <26558, 26560, 26564>    <26558, 26564, 26561>,
    <26558, 26561, 26565>    <26558, 26565, 26562>,
    <26558, 26562, 26566>    <26567, 26575, 26568>,
    <26567, 26568, 26572>    <26567, 26572, 26569>,
    <26567, 26569, 26573>    <26567, 26573, 26570>,
    <26567, 26570, 26574>    <26567, 26574, 26571>,
    <26567, 26571, 26575>    <26576, 26584, 26577>,
    <26576, 26577, 26581>    <26576, 26581, 26578>,
    <26576, 26578, 26582>    <26576, 26582, 26579>,
    <26576, 26579, 26583>    <26576, 26583, 26580>,
    <26576, 26580, 26584>    <26585, 26593, 26586>,
    <26585, 26586, 26590>    <26585, 26590, 26587>,
    <26585, 26587, 26591>    <26585, 26591, 26588>,
    <26585, 26588, 26592>    <26585, 26592, 26589>,
    <26585, 26589, 26593>    <26594, 26602, 26595>,
    <26594, 26595, 26599>    <26594, 26599, 26596>,
    <26594, 26596, 26600>    <26594, 26600, 26597>,
    <26594, 26597, 26601>    <26594, 26601, 26598>,
    <26594, 26598, 26602>    <26603, 26611, 26604>,
    <26603, 26604, 26608>    <26603, 26608, 26605>,
    <26603, 26605, 26609>    <26603, 26609, 26606>,
    <26603, 26606, 26610>    <26603, 26610, 26607>,
    <26603, 26607, 26611>    <26612, 26620, 26613>,
    <26612, 26613, 26617>    <26612, 26617, 26614>,
    <26612, 26614, 26618>    <26612, 26618, 26615>,
    <26612, 26615, 26619>    <26612, 26619, 26616>,
    <26612, 26616, 26620>    <26621, 26629, 26622>,
    <26621, 26622, 26626>    <26621, 26626, 26623>,
    <26621, 26623, 26627>    <26621, 26627, 26624>,
    <26621, 26624, 26628>    <26621, 26628, 26625>,
    <26621, 26625, 26629>    <26630, 26638, 26631>,
    <26630, 26631, 26635>    <26630, 26635, 26632>,
    <26630, 26632, 26636>    <26630, 26636, 26633>,
    <26630, 26633, 26637>    <26630, 26637, 26634>,
    <26630, 26634, 26638>    <26639, 26647, 26640>,
    <26639, 26640, 26644>    <26639, 26644, 26641>,
    <26639, 26641, 26645>    <26639, 26645, 26642>,
    <26639, 26642, 26646>    <26639, 26646, 26643>,
    <26639, 26643, 26647>    <26648, 26656, 26649>,
    <26648, 26649, 26653>    <26648, 26653, 26650>,
    <26648, 26650, 26654>    <26648, 26654, 26651>,
    <26648, 26651, 26655>    <26648, 26655, 26652>,
    <26648, 26652, 26656>    <26657, 26665, 26658>,
    <26657, 26658, 26662>    <26657, 26662, 26659>,
    <26657, 26659, 26663>    <26657, 26663, 26660>,
    <26657, 26660, 26664>    <26657, 26664, 26661>,
    <26657, 26661, 26665>    <26666, 26674, 26667>,
    <26666, 26667, 26671>    <26666, 26671, 26668>,
    <26666, 26668, 26672>    <26666, 26672, 26669>,
    <26666, 26669, 26673>    <26666, 26673, 26670>,
    <26666, 26670, 26674>    <26675, 26683, 26676>,
    <26675, 26676, 26680>    <26675, 26680, 26677>,
    <26675, 26677, 26681>    <26675, 26681, 26678>,
    <26675, 26678, 26682>    <26675, 26682, 26679>,
    <26675, 26679, 26683>    <26684, 26692, 26685>,
    <26684, 26685, 26689>    <26684, 26689, 26686>,
    <26684, 26686, 26690>    <26684, 26690, 26687>,
    <26684, 26687, 26691>    <26684, 26691, 26688>,
    <26684, 26688, 26692>    <26693, 26701, 26694>,
    <26693, 26694, 26698>    <26693, 26698, 26695>,
    <26693, 26695, 26699>    <26693, 26699, 26696>,
    <26693, 26696, 26700>    <26693, 26700, 26697>,
    <26693, 26697, 26701>    <26702, 26710, 26703>,
    <26702, 26703, 26707>    <26702, 26707, 26704>,
    <26702, 26704, 26708>    <26702, 26708, 26705>,
    <26702, 26705, 26709>    <26702, 26709, 26706>,
    <26702, 26706, 26710>    <26711, 26719, 26712>,
    <26711, 26712, 26716>    <26711, 26716, 26713>,
    <26711, 26713, 26717>    <26711, 26717, 26714>,
    <26711, 26714, 26718>    <26711, 26718, 26715>,
    <26711, 26715, 26719>    <26720, 26728, 26721>,
    <26720, 26721, 26725>    <26720, 26725, 26722>,
    <26720, 26722, 26726>    <26720, 26726, 26723>,
    <26720, 26723, 26727>    <26720, 26727, 26724>,
    <26720, 26724, 26728>    <26729, 26737, 26730>,
    <26729, 26730, 26734>    <26729, 26734, 26731>,
    <26729, 26731, 26735>    <26729, 26735, 26732>,
    <26729, 26732, 26736>    <26729, 26736, 26733>,
    <26729, 26733, 26737>    <26738, 26746, 26739>,
    <26738, 26739, 26743>    <26738, 26743, 26740>,
    <26738, 26740, 26744>    <26738, 26744, 26741>,
    <26738, 26741, 26745>    <26738, 26745, 26742>,
    <26738, 26742, 26746>    <26747, 26755, 26748>,
    <26747, 26748, 26752>    <26747, 26752, 26749>,
    <26747, 26749, 26753>    <26747, 26753, 26750>,
    <26747, 26750, 26754>    <26747, 26754, 26751>,
    <26747, 26751, 26755>    <26756, 26764, 26757>,
    <26756, 26757, 26761>    <26756, 26761, 26758>,
    <26756, 26758, 26762>    <26756, 26762, 26759>,
    <26756, 26759, 26763>    <26756, 26763, 26760>,
    <26756, 26760, 26764>    <26765, 26773, 26766>,
    <26765, 26766, 26770>    <26765, 26770, 26767>,
    <26765, 26767, 26771>    <26765, 26771, 26768>,
    <26765, 26768, 26772>    <26765, 26772, 26769>,
    <26765, 26769, 26773>    <26774, 26782, 26775>,
    <26774, 26775, 26779>    <26774, 26779, 26776>,
    <26774, 26776, 26780>    <26774, 26780, 26777>,
    <26774, 26777, 26781>    <26774, 26781, 26778>,
    <26774, 26778, 26782>    <26783, 26791, 26784>,
    <26783, 26784, 26788>    <26783, 26788, 26785>,
    <26783, 26785, 26789>    <26783, 26789, 26786>,
    <26783, 26786, 26790>    <26783, 26790, 26787>,
    <26783, 26787, 26791>    <26792, 26800, 26793>,
    <26792, 26793, 26797>    <26792, 26797, 26794>,
    <26792, 26794, 26798>    <26792, 26798, 26795>,
    <26792, 26795, 26799>    <26792, 26799, 26796>,
    <26792, 26796, 26800>    <26801, 26809, 26802>,
    <26801, 26802, 26806>    <26801, 26806, 26803>,
    <26801, 26803, 26807>    <26801, 26807, 26804>,
    <26801, 26804, 26808>    <26801, 26808, 26805>,
    <26801, 26805, 26809>    <26810, 26818, 26811>,
    <26810, 26811, 26815>    <26810, 26815, 26812>,
    <26810, 26812, 26816>    <26810, 26816, 26813>,
    <26810, 26813, 26817>    <26810, 26817, 26814>,
    <26810, 26814, 26818>    <26819, 26827, 26820>,
    <26819, 26820, 26824>    <26819, 26824, 26821>,
    <26819, 26821, 26825>    <26819, 26825, 26822>,
    <26819, 26822, 26826>    <26819, 26826, 26823>,
    <26819, 26823, 26827>    <26828, 26836, 26829>,
    <26828, 26829, 26833>    <26828, 26833, 26830>,
    <26828, 26830, 26834>    <26828, 26834, 26831>,
    <26828, 26831, 26835>    <26828, 26835, 26832>,
    <26828, 26832, 26836>    <26837, 26845, 26838>,
    <26837, 26838, 26842>    <26837, 26842, 26839>,
    <26837, 26839, 26843>    <26837, 26843, 26840>,
    <26837, 26840, 26844>    <26837, 26844, 26841>,
    <26837, 26841, 26845>    <26846, 26854, 26847>,
    <26846, 26847, 26851>    <26846, 26851, 26848>,
    <26846, 26848, 26852>    <26846, 26852, 26849>,
    <26846, 26849, 26853>    <26846, 26853, 26850>,
    <26846, 26850, 26854>    <26855, 26863, 26856>,
    <26855, 26856, 26860>    <26855, 26860, 26857>,
    <26855, 26857, 26861>    <26855, 26861, 26858>,
    <26855, 26858, 26862>    <26855, 26862, 26859>,
    <26855, 26859, 26863>    <26864, 26872, 26865>,
    <26864, 26865, 26869>    <26864, 26869, 26866>,
    <26864, 26866, 26870>    <26864, 26870, 26867>,
    <26864, 26867, 26871>    <26864, 26871, 26868>,
    <26864, 26868, 26872>    <26873, 26881, 26874>,
    <26873, 26874, 26878>    <26873, 26878, 26875>,
    <26873, 26875, 26879>    <26873, 26879, 26876>,
    <26873, 26876, 26880>    <26873, 26880, 26877>,
    <26873, 26877, 26881>    <26882, 26890, 26883>,
    <26882, 26883, 26887>    <26882, 26887, 26884>,
    <26882, 26884, 26888>    <26882, 26888, 26885>,
    <26882, 26885, 26889>    <26882, 26889, 26886>,
    <26882, 26886, 26890>    <26891, 26899, 26892>,
    <26891, 26892, 26896>    <26891, 26896, 26893>,
    <26891, 26893, 26897>    <26891, 26897, 26894>,
    <26891, 26894, 26898>    <26891, 26898, 26895>,
    <26891, 26895, 26899>    <26900, 26908, 26901>,
    <26900, 26901, 26905>    <26900, 26905, 26902>,
    <26900, 26902, 26906>    <26900, 26906, 26903>,
    <26900, 26903, 26907>    <26900, 26907, 26904>,
    <26900, 26904, 26908>    <26909, 26917, 26910>,
    <26909, 26910, 26914>    <26909, 26914, 26911>,
    <26909, 26911, 26915>    <26909, 26915, 26912>,
    <26909, 26912, 26916>    <26909, 26916, 26913>,
    <26909, 26913, 26917>    <26918, 26926, 26919>,
    <26918, 26919, 26923>    <26918, 26923, 26920>,
    <26918, 26920, 26924>    <26918, 26924, 26921>,
    <26918, 26921, 26925>    <26918, 26925, 26922>,
    <26918, 26922, 26926>    <26927, 26935, 26928>,
    <26927, 26928, 26932>    <26927, 26932, 26929>,
    <26927, 26929, 26933>    <26927, 26933, 26930>,
    <26927, 26930, 26934>    <26927, 26934, 26931>,
    <26927, 26931, 26935>    <26936, 26944, 26937>,
    <26936, 26937, 26941>    <26936, 26941, 26938>,
    <26936, 26938, 26942>    <26936, 26942, 26939>,
    <26936, 26939, 26943>    <26936, 26943, 26940>,
    <26936, 26940, 26944>    <26945, 26953, 26946>,
    <26945, 26946, 26950>    <26945, 26950, 26947>,
    <26945, 26947, 26951>    <26945, 26951, 26948>,
    <26945, 26948, 26952>    <26945, 26952, 26949>,
    <26945, 26949, 26953>    <26954, 26962, 26955>,
    <26954, 26955, 26959>    <26954, 26959, 26956>,
    <26954, 26956, 26960>    <26954, 26960, 26957>,
    <26954, 26957, 26961>    <26954, 26961, 26958>,
    <26954, 26958, 26962>    <26963, 26971, 26964>,
    <26963, 26964, 26968>    <26963, 26968, 26965>,
    <26963, 26965, 26969>    <26963, 26969, 26966>,
    <26963, 26966, 26970>    <26963, 26970, 26967>,
    <26963, 26967, 26971>    <26972, 26980, 26973>,
    <26972, 26973, 26977>    <26972, 26977, 26974>,
    <26972, 26974, 26978>    <26972, 26978, 26975>,
    <26972, 26975, 26979>    <26972, 26979, 26976>,
    <26972, 26976, 26980>    <26981, 26989, 26982>,
    <26981, 26982, 26986>    <26981, 26986, 26983>,
    <26981, 26983, 26987>    <26981, 26987, 26984>,
    <26981, 26984, 26988>    <26981, 26988, 26985>,
    <26981, 26985, 26989>    <26990, 26998, 26991>,
    <26990, 26991, 26995>    <26990, 26995, 26992>,
    <26990, 26992, 26996>    <26990, 26996, 26993>,
    <26990, 26993, 26997>    <26990, 26997, 26994>,
    <26990, 26994, 26998>    <26999, 27007, 27000>,
    <26999, 27000, 27004>    <26999, 27004, 27001>,
    <26999, 27001, 27005>    <26999, 27005, 27002>,
    <26999, 27002, 27006>    <26999, 27006, 27003>,
    <26999, 27003, 27007>    <27008, 27016, 27009>,
    <27008, 27009, 27013>    <27008, 27013, 27010>,
    <27008, 27010, 27014>    <27008, 27014, 27011>,
    <27008, 27011, 27015>    <27008, 27015, 27012>,
    <27008, 27012, 27016>    <27017, 27025, 27018>,
    <27017, 27018, 27022>    <27017, 27022, 27019>,
    <27017, 27019, 27023>    <27017, 27023, 27020>,
    <27017, 27020, 27024>    <27017, 27024, 27021>,
    <27017, 27021, 27025>    <27026, 27034, 27027>,
    <27026, 27027, 27031>    <27026, 27031, 27028>,
    <27026, 27028, 27032>    <27026, 27032, 27029>,
    <27026, 27029, 27033>    <27026, 27033, 27030>,
    <27026, 27030, 27034>    <27035, 27043, 27036>,
    <27035, 27036, 27040>    <27035, 27040, 27037>,
    <27035, 27037, 27041>    <27035, 27041, 27038>,
    <27035, 27038, 27042>    <27035, 27042, 27039>,
    <27035, 27039, 27043>    <27044, 27052, 27045>,
    <27044, 27045, 27049>    <27044, 27049, 27046>,
    <27044, 27046, 27050>    <27044, 27050, 27047>,
    <27044, 27047, 27051>    <27044, 27051, 27048>,
    <27044, 27048, 27052>    <27053, 27061, 27054>,
    <27053, 27054, 27058>    <27053, 27058, 27055>,
    <27053, 27055, 27059>    <27053, 27059, 27056>,
    <27053, 27056, 27060>    <27053, 27060, 27057>,
    <27053, 27057, 27061>    <27062, 27070, 27063>,
    <27062, 27063, 27067>    <27062, 27067, 27064>,
    <27062, 27064, 27068>    <27062, 27068, 27065>,
    <27062, 27065, 27069>    <27062, 27069, 27066>,
    <27062, 27066, 27070>    <27071, 27079, 27072>,
    <27071, 27072, 27076>    <27071, 27076, 27073>,
    <27071, 27073, 27077>    <27071, 27077, 27074>,
    <27071, 27074, 27078>    <27071, 27078, 27075>,
    <27071, 27075, 27079>    <27080, 27088, 27081>,
    <27080, 27081, 27085>    <27080, 27085, 27082>,
    <27080, 27082, 27086>    <27080, 27086, 27083>,
    <27080, 27083, 27087>    <27080, 27087, 27084>,
    <27080, 27084, 27088>    <27089, 27097, 27090>,
    <27089, 27090, 27094>    <27089, 27094, 27091>,
    <27089, 27091, 27095>    <27089, 27095, 27092>,
    <27089, 27092, 27096>    <27089, 27096, 27093>,
    <27089, 27093, 27097>    <27098, 27106, 27099>,
    <27098, 27099, 27103>    <27098, 27103, 27100>,
    <27098, 27100, 27104>    <27098, 27104, 27101>,
    <27098, 27101, 27105>    <27098, 27105, 27102>,
    <27098, 27102, 27106>    <27107, 27115, 27108>,
    <27107, 27108, 27112>    <27107, 27112, 27109>,
    <27107, 27109, 27113>    <27107, 27113, 27110>,
    <27107, 27110, 27114>    <27107, 27114, 27111>,
    <27107, 27111, 27115>    <27116, 27124, 27117>,
    <27116, 27117, 27121>    <27116, 27121, 27118>,
    <27116, 27118, 27122>    <27116, 27122, 27119>,
    <27116, 27119, 27123>    <27116, 27123, 27120>,
    <27116, 27120, 27124>    <27125, 27133, 27126>,
    <27125, 27126, 27130>    <27125, 27130, 27127>,
    <27125, 27127, 27131>    <27125, 27131, 27128>,
    <27125, 27128, 27132>    <27125, 27132, 27129>,
    <27125, 27129, 27133>    <27134, 27142, 27135>,
    <27134, 27135, 27139>    <27134, 27139, 27136>,
    <27134, 27136, 27140>    <27134, 27140, 27137>,
    <27134, 27137, 27141>    <27134, 27141, 27138>,
    <27134, 27138, 27142>    <27143, 27151, 27144>,
    <27143, 27144, 27148>    <27143, 27148, 27145>,
    <27143, 27145, 27149>    <27143, 27149, 27146>,
    <27143, 27146, 27150>    <27143, 27150, 27147>,
    <27143, 27147, 27151>    <27152, 27160, 27153>,
    <27152, 27153, 27157>    <27152, 27157, 27154>,
    <27152, 27154, 27158>    <27152, 27158, 27155>,
    <27152, 27155, 27159>    <27152, 27159, 27156>,
    <27152, 27156, 27160>    <27161, 27169, 27162>,
    <27161, 27162, 27166>    <27161, 27166, 27163>,
    <27161, 27163, 27167>    <27161, 27167, 27164>,
    <27161, 27164, 27168>    <27161, 27168, 27165>,
    <27161, 27165, 27169>    <27170, 27178, 27171>,
    <27170, 27171, 27175>    <27170, 27175, 27172>,
    <27170, 27172, 27176>    <27170, 27176, 27173>,
    <27170, 27173, 27177>    <27170, 27177, 27174>,
    <27170, 27174, 27178>    <27179, 27187, 27180>,
    <27179, 27180, 27184>    <27179, 27184, 27181>,
    <27179, 27181, 27185>    <27179, 27185, 27182>,
    <27179, 27182, 27186>    <27179, 27186, 27183>,
    <27179, 27183, 27187>    <27188, 27196, 27189>,
    <27188, 27189, 27193>    <27188, 27193, 27190>,
    <27188, 27190, 27194>    <27188, 27194, 27191>,
    <27188, 27191, 27195>    <27188, 27195, 27192>,
    <27188, 27192, 27196>    <27197, 27205, 27198>,
    <27197, 27198, 27202>    <27197, 27202, 27199>,
    <27197, 27199, 27203>    <27197, 27203, 27200>,
    <27197, 27200, 27204>    <27197, 27204, 27201>,
    <27197, 27201, 27205>    <27206, 27214, 27207>,
    <27206, 27207, 27211>    <27206, 27211, 27208>,
    <27206, 27208, 27212>    <27206, 27212, 27209>,
    <27206, 27209, 27213>    <27206, 27213, 27210>,
    <27206, 27210, 27214>    <27215, 27223, 27216>,
    <27215, 27216, 27220>    <27215, 27220, 27217>,
    <27215, 27217, 27221>    <27215, 27221, 27218>,
    <27215, 27218, 27222>    <27215, 27222, 27219>,
    <27215, 27219, 27223>    <27224, 27232, 27225>,
    <27224, 27225, 27229>    <27224, 27229, 27226>,
    <27224, 27226, 27230>    <27224, 27230, 27227>,
    <27224, 27227, 27231>    <27224, 27231, 27228>,
    <27224, 27228, 27232>    <27233, 27241, 27234>,
    <27233, 27234, 27238>    <27233, 27238, 27235>,
    <27233, 27235, 27239>    <27233, 27239, 27236>,
    <27233, 27236, 27240>    <27233, 27240, 27237>,
    <27233, 27237, 27241>    <27242, 27250, 27243>,
    <27242, 27243, 27247>    <27242, 27247, 27244>,
    <27242, 27244, 27248>    <27242, 27248, 27245>,
    <27242, 27245, 27249>    <27242, 27249, 27246>,
    <27242, 27246, 27250>    <27251, 27259, 27252>,
    <27251, 27252, 27256>    <27251, 27256, 27253>,
    <27251, 27253, 27257>    <27251, 27257, 27254>,
    <27251, 27254, 27258>    <27251, 27258, 27255>,
    <27251, 27255, 27259>    <27260, 27268, 27261>,
    <27260, 27261, 27265>    <27260, 27265, 27262>,
    <27260, 27262, 27266>    <27260, 27266, 27263>,
    <27260, 27263, 27267>    <27260, 27267, 27264>,
    <27260, 27264, 27268>    <27269, 27277, 27270>,
    <27269, 27270, 27274>    <27269, 27274, 27271>,
    <27269, 27271, 27275>    <27269, 27275, 27272>,
    <27269, 27272, 27276>    <27269, 27276, 27273>,
    <27269, 27273, 27277>    <27278, 27286, 27279>,
    <27278, 27279, 27283>    <27278, 27283, 27280>,
    <27278, 27280, 27284>    <27278, 27284, 27281>,
    <27278, 27281, 27285>    <27278, 27285, 27282>,
    <27278, 27282, 27286>    <27287, 27295, 27288>,
    <27287, 27288, 27292>    <27287, 27292, 27289>,
    <27287, 27289, 27293>    <27287, 27293, 27290>,
    <27287, 27290, 27294>    <27287, 27294, 27291>,
    <27287, 27291, 27295>    <27296, 27304, 27297>,
    <27296, 27297, 27301>    <27296, 27301, 27298>,
    <27296, 27298, 27302>    <27296, 27302, 27299>,
    <27296, 27299, 27303>    <27296, 27303, 27300>,
    <27296, 27300, 27304>    <27305, 27313, 27306>,
    <27305, 27306, 27310>    <27305, 27310, 27307>,
    <27305, 27307, 27311>    <27305, 27311, 27308>,
    <27305, 27308, 27312>    <27305, 27312, 27309>,
    <27305, 27309, 27313>    <27314, 27322, 27315>,
    <27314, 27315, 27319>    <27314, 27319, 27316>,
    <27314, 27316, 27320>    <27314, 27320, 27317>,
    <27314, 27317, 27321>    <27314, 27321, 27318>,
    <27314, 27318, 27322>    <27323, 27331, 27324>,
    <27323, 27324, 27328>    <27323, 27328, 27325>,
    <27323, 27325, 27329>    <27323, 27329, 27326>,
    <27323, 27326, 27330>    <27323, 27330, 27327>,
    <27323, 27327, 27331>    <27332, 27340, 27333>,
    <27332, 27333, 27337>    <27332, 27337, 27334>,
    <27332, 27334, 27338>    <27332, 27338, 27335>,
    <27332, 27335, 27339>    <27332, 27339, 27336>,
    <27332, 27336, 27340>    <27341, 27349, 27342>,
    <27341, 27342, 27346>    <27341, 27346, 27343>,
    <27341, 27343, 27347>    <27341, 27347, 27344>,
    <27341, 27344, 27348>    <27341, 27348, 27345>,
    <27341, 27345, 27349>    <27350, 27358, 27351>,
    <27350, 27351, 27355>    <27350, 27355, 27352>,
    <27350, 27352, 27356>    <27350, 27356, 27353>,
    <27350, 27353, 27357>    <27350, 27357, 27354>,
    <27350, 27354, 27358>    <27359, 27367, 27360>,
    <27359, 27360, 27364>    <27359, 27364, 27361>,
    <27359, 27361, 27365>    <27359, 27365, 27362>,
    <27359, 27362, 27366>    <27359, 27366, 27363>,
    <27359, 27363, 27367>    <27368, 27376, 27369>,
    <27368, 27369, 27373>    <27368, 27373, 27370>,
    <27368, 27370, 27374>    <27368, 27374, 27371>,
    <27368, 27371, 27375>    <27368, 27375, 27372>,
    <27368, 27372, 27376>    <27377, 27385, 27378>,
    <27377, 27378, 27382>    <27377, 27382, 27379>,
    <27377, 27379, 27383>    <27377, 27383, 27380>,
    <27377, 27380, 27384>    <27377, 27384, 27381>,
    <27377, 27381, 27385>    <27386, 27394, 27387>,
    <27386, 27387, 27391>    <27386, 27391, 27388>,
    <27386, 27388, 27392>    <27386, 27392, 27389>,
    <27386, 27389, 27393>    <27386, 27393, 27390>,
    <27386, 27390, 27394>    <27395, 27403, 27396>,
    <27395, 27396, 27400>    <27395, 27400, 27397>,
    <27395, 27397, 27401>    <27395, 27401, 27398>,
    <27395, 27398, 27402>    <27395, 27402, 27399>,
    <27395, 27399, 27403>    <27404, 27412, 27405>,
    <27404, 27405, 27409>    <27404, 27409, 27406>,
    <27404, 27406, 27410>    <27404, 27410, 27407>,
    <27404, 27407, 27411>    <27404, 27411, 27408>,
    <27404, 27408, 27412>    <27413, 27421, 27414>,
    <27413, 27414, 27418>    <27413, 27418, 27415>,
    <27413, 27415, 27419>    <27413, 27419, 27416>,
    <27413, 27416, 27420>    <27413, 27420, 27417>,
    <27413, 27417, 27421>    <27422, 27430, 27423>,
    <27422, 27423, 27427>    <27422, 27427, 27424>,
    <27422, 27424, 27428>    <27422, 27428, 27425>,
    <27422, 27425, 27429>    <27422, 27429, 27426>,
    <27422, 27426, 27430>    <27431, 27439, 27432>,
    <27431, 27432, 27436>    <27431, 27436, 27433>,
    <27431, 27433, 27437>    <27431, 27437, 27434>,
    <27431, 27434, 27438>    <27431, 27438, 27435>,
    <27431, 27435, 27439>    <27440, 27448, 27441>,
    <27440, 27441, 27445>    <27440, 27445, 27442>,
    <27440, 27442, 27446>    <27440, 27446, 27443>,
    <27440, 27443, 27447>    <27440, 27447, 27444>,
    <27440, 27444, 27448>    <27449, 27457, 27450>,
    <27449, 27450, 27454>    <27449, 27454, 27451>,
    <27449, 27451, 27455>    <27449, 27455, 27452>,
    <27449, 27452, 27456>    <27449, 27456, 27453>,
    <27449, 27453, 27457>    <27458, 27466, 27459>,
    <27458, 27459, 27463>    <27458, 27463, 27460>,
    <27458, 27460, 27464>    <27458, 27464, 27461>,
    <27458, 27461, 27465>    <27458, 27465, 27462>,
    <27458, 27462, 27466>    <27467, 27475, 27468>,
    <27467, 27468, 27472>    <27467, 27472, 27469>,
    <27467, 27469, 27473>    <27467, 27473, 27470>,
    <27467, 27470, 27474>    <27467, 27474, 27471>,
    <27467, 27471, 27475>    <27476, 27484, 27477>,
    <27476, 27477, 27481>    <27476, 27481, 27478>,
    <27476, 27478, 27482>    <27476, 27482, 27479>,
    <27476, 27479, 27483>    <27476, 27483, 27480>,
    <27476, 27480, 27484>    <27485, 27493, 27486>,
    <27485, 27486, 27490>    <27485, 27490, 27487>,
    <27485, 27487, 27491>    <27485, 27491, 27488>,
    <27485, 27488, 27492>    <27485, 27492, 27489>,
    <27485, 27489, 27493>    <27494, 27502, 27495>,
    <27494, 27495, 27499>    <27494, 27499, 27496>,
    <27494, 27496, 27500>    <27494, 27500, 27497>,
    <27494, 27497, 27501>    <27494, 27501, 27498>,
    <27494, 27498, 27502>    <27503, 27511, 27504>,
    <27503, 27504, 27508>    <27503, 27508, 27505>,
    <27503, 27505, 27509>    <27503, 27509, 27506>,
    <27503, 27506, 27510>    <27503, 27510, 27507>,
    <27503, 27507, 27511>    <27512, 27520, 27513>,
    <27512, 27513, 27517>    <27512, 27517, 27514>,
    <27512, 27514, 27518>    <27512, 27518, 27515>,
    <27512, 27515, 27519>    <27512, 27519, 27516>,
    <27512, 27516, 27520>    <27521, 27529, 27522>,
    <27521, 27522, 27526>    <27521, 27526, 27523>,
    <27521, 27523, 27527>    <27521, 27527, 27524>,
    <27521, 27524, 27528>    <27521, 27528, 27525>,
    <27521, 27525, 27529>    <27530, 27538, 27531>,
    <27530, 27531, 27535>    <27530, 27535, 27532>,
    <27530, 27532, 27536>    <27530, 27536, 27533>,
    <27530, 27533, 27537>    <27530, 27537, 27534>,
    <27530, 27534, 27538>    <27539, 27547, 27540>,
    <27539, 27540, 27544>    <27539, 27544, 27541>,
    <27539, 27541, 27545>    <27539, 27545, 27542>,
    <27539, 27542, 27546>    <27539, 27546, 27543>,
    <27539, 27543, 27547>    <27548, 27556, 27549>,
    <27548, 27549, 27553>    <27548, 27553, 27550>,
    <27548, 27550, 27554>    <27548, 27554, 27551>,
    <27548, 27551, 27555>    <27548, 27555, 27552>,
    <27548, 27552, 27556>    <27557, 27565, 27558>,
    <27557, 27558, 27562>    <27557, 27562, 27559>,
    <27557, 27559, 27563>    <27557, 27563, 27560>,
    <27557, 27560, 27564>    <27557, 27564, 27561>,
    <27557, 27561, 27565>    <27566, 27574, 27567>,
    <27566, 27567, 27571>    <27566, 27571, 27568>,
    <27566, 27568, 27572>    <27566, 27572, 27569>,
    <27566, 27569, 27573>    <27566, 27573, 27570>,
    <27566, 27570, 27574>    <27575, 27583, 27576>,
    <27575, 27576, 27580>    <27575, 27580, 27577>,
    <27575, 27577, 27581>    <27575, 27581, 27578>,
    <27575, 27578, 27582>    <27575, 27582, 27579>,
    <27575, 27579, 27583>    <27584, 27592, 27585>,
    <27584, 27585, 27589>    <27584, 27589, 27586>,
    <27584, 27586, 27590>    <27584, 27590, 27587>,
    <27584, 27587, 27591>    <27584, 27591, 27588>,
    <27584, 27588, 27592>    <27593, 27601, 27594>,
    <27593, 27594, 27598>    <27593, 27598, 27595>,
    <27593, 27595, 27599>    <27593, 27599, 27596>,
    <27593, 27596, 27600>    <27593, 27600, 27597>,
    <27593, 27597, 27601>    <27602, 27610, 27603>,
    <27602, 27603, 27607>    <27602, 27607, 27604>,
    <27602, 27604, 27608>    <27602, 27608, 27605>,
    <27602, 27605, 27609>    <27602, 27609, 27606>,
    <27602, 27606, 27610>    <27611, 27619, 27612>,
    <27611, 27612, 27616>    <27611, 27616, 27613>,
    <27611, 27613, 27617>    <27611, 27617, 27614>,
    <27611, 27614, 27618>    <27611, 27618, 27615>,
    <27611, 27615, 27619>    <27620, 27628, 27621>,
    <27620, 27621, 27625>    <27620, 27625, 27622>,
    <27620, 27622, 27626>    <27620, 27626, 27623>,
    <27620, 27623, 27627>    <27620, 27627, 27624>,
    <27620, 27624, 27628>    <27629, 27637, 27630>,
    <27629, 27630, 27634>    <27629, 27634, 27631>,
    <27629, 27631, 27635>    <27629, 27635, 27632>,
    <27629, 27632, 27636>    <27629, 27636, 27633>,
    <27629, 27633, 27637>    <27638, 27646, 27639>,
    <27638, 27639, 27643>    <27638, 27643, 27640>,
    <27638, 27640, 27644>    <27638, 27644, 27641>,
    <27638, 27641, 27645>    <27638, 27645, 27642>,
    <27638, 27642, 27646>    <27647, 27655, 27648>,
    <27647, 27648, 27652>    <27647, 27652, 27649>,
    <27647, 27649, 27653>    <27647, 27653, 27650>,
    <27647, 27650, 27654>    <27647, 27654, 27651>,
    <27647, 27651, 27655>    <27656, 27664, 27657>,
    <27656, 27657, 27661>    <27656, 27661, 27658>,
    <27656, 27658, 27662>    <27656, 27662, 27659>,
    <27656, 27659, 27663>    <27656, 27663, 27660>,
    <27656, 27660, 27664>    <27665, 27673, 27666>,
    <27665, 27666, 27670>    <27665, 27670, 27667>,
    <27665, 27667, 27671>    <27665, 27671, 27668>,
    <27665, 27668, 27672>    <27665, 27672, 27669>,
    <27665, 27669, 27673>    <27674, 27682, 27675>,
    <27674, 27675, 27679>    <27674, 27679, 27676>,
    <27674, 27676, 27680>    <27674, 27680, 27677>,
    <27674, 27677, 27681>    <27674, 27681, 27678>,
    <27674, 27678, 27682>    <27683, 27691, 27684>,
    <27683, 27684, 27688>    <27683, 27688, 27685>,
    <27683, 27685, 27689>    <27683, 27689, 27686>,
    <27683, 27686, 27690>    <27683, 27690, 27687>,
    <27683, 27687, 27691>    <27692, 27700, 27693>,
    <27692, 27693, 27697>    <27692, 27697, 27694>,
    <27692, 27694, 27698>    <27692, 27698, 27695>,
    <27692, 27695, 27699>    <27692, 27699, 27696>,
    <27692, 27696, 27700>    <27701, 27709, 27702>,
    <27701, 27702, 27706>    <27701, 27706, 27703>,
    <27701, 27703, 27707>    <27701, 27707, 27704>,
    <27701, 27704, 27708>    <27701, 27708, 27705>,
    <27701, 27705, 27709>    <27710, 27718, 27711>,
    <27710, 27711, 27715>    <27710, 27715, 27712>,
    <27710, 27712, 27716>    <27710, 27716, 27713>,
    <27710, 27713, 27717>    <27710, 27717, 27714>,
    <27710, 27714, 27718>    <27719, 27727, 27720>,
    <27719, 27720, 27724>    <27719, 27724, 27721>,
    <27719, 27721, 27725>    <27719, 27725, 27722>,
    <27719, 27722, 27726>    <27719, 27726, 27723>,
    <27719, 27723, 27727>    <27728, 27736, 27729>,
    <27728, 27729, 27733>    <27728, 27733, 27730>,
    <27728, 27730, 27734>    <27728, 27734, 27731>,
    <27728, 27731, 27735>    <27728, 27735, 27732>,
    <27728, 27732, 27736>    <27737, 27745, 27738>,
    <27737, 27738, 27742>    <27737, 27742, 27739>,
    <27737, 27739, 27743>    <27737, 27743, 27740>,
    <27737, 27740, 27744>    <27737, 27744, 27741>,
    <27737, 27741, 27745>    <27746, 27754, 27747>,
    <27746, 27747, 27751>    <27746, 27751, 27748>,
    <27746, 27748, 27752>    <27746, 27752, 27749>,
    <27746, 27749, 27753>    <27746, 27753, 27750>,
    <27746, 27750, 27754>    <27755, 27763, 27756>,
    <27755, 27756, 27760>    <27755, 27760, 27757>,
    <27755, 27757, 27761>    <27755, 27761, 27758>,
    <27755, 27758, 27762>    <27755, 27762, 27759>,
    <27755, 27759, 27763>    <27764, 27772, 27765>,
    <27764, 27765, 27769>    <27764, 27769, 27766>,
    <27764, 27766, 27770>    <27764, 27770, 27767>,
    <27764, 27767, 27771>    <27764, 27771, 27768>,
    <27764, 27768, 27772>    <27773, 27781, 27774>,
    <27773, 27774, 27778>    <27773, 27778, 27775>,
    <27773, 27775, 27779>    <27773, 27779, 27776>,
    <27773, 27776, 27780>    <27773, 27780, 27777>,
    <27773, 27777, 27781>    <27782, 27790, 27783>,
    <27782, 27783, 27787>    <27782, 27787, 27784>,
    <27782, 27784, 27788>    <27782, 27788, 27785>,
    <27782, 27785, 27789>    <27782, 27789, 27786>,
    <27782, 27786, 27790>    <27791, 27799, 27792>,
    <27791, 27792, 27796>    <27791, 27796, 27793>,
    <27791, 27793, 27797>    <27791, 27797, 27794>,
    <27791, 27794, 27798>    <27791, 27798, 27795>,
    <27791, 27795, 27799>    <27800, 27808, 27801>,
    <27800, 27801, 27805>    <27800, 27805, 27802>,
    <27800, 27802, 27806>    <27800, 27806, 27803>,
    <27800, 27803, 27807>    <27800, 27807, 27804>,
    <27800, 27804, 27808>    <27809, 27817, 27810>,
    <27809, 27810, 27814>    <27809, 27814, 27811>,
    <27809, 27811, 27815>    <27809, 27815, 27812>,
    <27809, 27812, 27816>    <27809, 27816, 27813>,
    <27809, 27813, 27817>    <27818, 27826, 27819>,
    <27818, 27819, 27823>    <27818, 27823, 27820>,
    <27818, 27820, 27824>    <27818, 27824, 27821>,
    <27818, 27821, 27825>    <27818, 27825, 27822>,
    <27818, 27822, 27826>    <27827, 27835, 27828>,
    <27827, 27828, 27832>    <27827, 27832, 27829>,
    <27827, 27829, 27833>    <27827, 27833, 27830>,
    <27827, 27830, 27834>    <27827, 27834, 27831>,
    <27827, 27831, 27835>    <27836, 27844, 27837>,
    <27836, 27837, 27841>    <27836, 27841, 27838>,
    <27836, 27838, 27842>    <27836, 27842, 27839>,
    <27836, 27839, 27843>    <27836, 27843, 27840>,
    <27836, 27840, 27844>    <27845, 27853, 27846>,
    <27845, 27846, 27850>    <27845, 27850, 27847>,
    <27845, 27847, 27851>    <27845, 27851, 27848>,
    <27845, 27848, 27852>    <27845, 27852, 27849>,
    <27845, 27849, 27853>    <27854, 27862, 27855>,
    <27854, 27855, 27859>    <27854, 27859, 27856>,
    <27854, 27856, 27860>    <27854, 27860, 27857>,
    <27854, 27857, 27861>    <27854, 27861, 27858>,
    <27854, 27858, 27862>    <27863, 27871, 27864>,
    <27863, 27864, 27868>    <27863, 27868, 27865>,
    <27863, 27865, 27869>    <27863, 27869, 27866>,
    <27863, 27866, 27870>    <27863, 27870, 27867>,
    <27863, 27867, 27871>    <27872, 27880, 27873>,
    <27872, 27873, 27877>    <27872, 27877, 27874>,
    <27872, 27874, 27878>    <27872, 27878, 27875>,
    <27872, 27875, 27879>    <27872, 27879, 27876>,
    <27872, 27876, 27880>    <27881, 27889, 27882>,
    <27881, 27882, 27886>    <27881, 27886, 27883>,
    <27881, 27883, 27887>    <27881, 27887, 27884>,
    <27881, 27884, 27888>    <27881, 27888, 27885>,
    <27881, 27885, 27889>    <27890, 27898, 27891>,
    <27890, 27891, 27895>    <27890, 27895, 27892>,
    <27890, 27892, 27896>    <27890, 27896, 27893>,
    <27890, 27893, 27897>    <27890, 27897, 27894>,
    <27890, 27894, 27898>    <27899, 27907, 27900>,
    <27899, 27900, 27904>    <27899, 27904, 27901>,
    <27899, 27901, 27905>    <27899, 27905, 27902>,
    <27899, 27902, 27906>    <27899, 27906, 27903>,
    <27899, 27903, 27907>    <27908, 27916, 27909>,
    <27908, 27909, 27913>    <27908, 27913, 27910>,
    <27908, 27910, 27914>    <27908, 27914, 27911>,
    <27908, 27911, 27915>    <27908, 27915, 27912>,
    <27908, 27912, 27916>    <27917, 27925, 27918>,
    <27917, 27918, 27922>    <27917, 27922, 27919>,
    <27917, 27919, 27923>    <27917, 27923, 27920>,
    <27917, 27920, 27924>    <27917, 27924, 27921>,
    <27917, 27921, 27925>    <27926, 27934, 27927>,
    <27926, 27927, 27931>    <27926, 27931, 27928>,
    <27926, 27928, 27932>    <27926, 27932, 27929>,
    <27926, 27929, 27933>    <27926, 27933, 27930>,
    <27926, 27930, 27934>    <27935, 27943, 27936>,
    <27935, 27936, 27940>    <27935, 27940, 27937>,
    <27935, 27937, 27941>    <27935, 27941, 27938>,
    <27935, 27938, 27942>    <27935, 27942, 27939>,
    <27935, 27939, 27943>    <27944, 27952, 27945>,
    <27944, 27945, 27949>    <27944, 27949, 27946>,
    <27944, 27946, 27950>    <27944, 27950, 27947>,
    <27944, 27947, 27951>    <27944, 27951, 27948>,
    <27944, 27948, 27952>    <27953, 27961, 27954>,
    <27953, 27954, 27958>    <27953, 27958, 27955>,
    <27953, 27955, 27959>    <27953, 27959, 27956>,
    <27953, 27956, 27960>    <27953, 27960, 27957>,
    <27953, 27957, 27961>    <27962, 27970, 27963>,
    <27962, 27963, 27967>    <27962, 27967, 27964>,
    <27962, 27964, 27968>    <27962, 27968, 27965>,
    <27962, 27965, 27969>    <27962, 27969, 27966>,
    <27962, 27966, 27970>    <27971, 27979, 27972>,
    <27971, 27972, 27976>    <27971, 27976, 27973>,
    <27971, 27973, 27977>    <27971, 27977, 27974>,
    <27971, 27974, 27978>    <27971, 27978, 27975>,
    <27971, 27975, 27979>    <27980, 27988, 27981>,
    <27980, 27981, 27985>    <27980, 27985, 27982>,
    <27980, 27982, 27986>    <27980, 27986, 27983>,
    <27980, 27983, 27987>    <27980, 27987, 27984>,
    <27980, 27984, 27988>    <27989, 27997, 27990>,
    <27989, 27990, 27994>    <27989, 27994, 27991>,
    <27989, 27991, 27995>    <27989, 27995, 27992>,
    <27989, 27992, 27996>    <27989, 27996, 27993>,
    <27989, 27993, 27997>    <27998, 28006, 27999>,
    <27998, 27999, 28003>    <27998, 28003, 28000>,
    <27998, 28000, 28004>    <27998, 28004, 28001>,
    <27998, 28001, 28005>    <27998, 28005, 28002>,
    <27998, 28002, 28006>    <28007, 28015, 28008>,
    <28007, 28008, 28012>    <28007, 28012, 28009>,
    <28007, 28009, 28013>    <28007, 28013, 28010>,
    <28007, 28010, 28014>    <28007, 28014, 28011>,
    <28007, 28011, 28015>    <28016, 28024, 28017>,
    <28016, 28017, 28021>    <28016, 28021, 28018>,
    <28016, 28018, 28022>    <28016, 28022, 28019>,
    <28016, 28019, 28023>    <28016, 28023, 28020>,
    <28016, 28020, 28024>    <28025, 28033, 28026>,
    <28025, 28026, 28030>    <28025, 28030, 28027>,
    <28025, 28027, 28031>    <28025, 28031, 28028>,
    <28025, 28028, 28032>    <28025, 28032, 28029>,
    <28025, 28029, 28033>    <28034, 28042, 28035>,
    <28034, 28035, 28039>    <28034, 28039, 28036>,
    <28034, 28036, 28040>    <28034, 28040, 28037>,
    <28034, 28037, 28041>    <28034, 28041, 28038>,
    <28034, 28038, 28042>    <28043, 28051, 28044>,
    <28043, 28044, 28048>    <28043, 28048, 28045>,
    <28043, 28045, 28049>    <28043, 28049, 28046>,
    <28043, 28046, 28050>    <28043, 28050, 28047>,
    <28043, 28047, 28051>    <28052, 28060, 28053>,
    <28052, 28053, 28057>    <28052, 28057, 28054>,
    <28052, 28054, 28058>    <28052, 28058, 28055>,
    <28052, 28055, 28059>    <28052, 28059, 28056>,
    <28052, 28056, 28060>    <28061, 28069, 28062>,
    <28061, 28062, 28066>    <28061, 28066, 28063>,
    <28061, 28063, 28067>    <28061, 28067, 28064>,
    <28061, 28064, 28068>    <28061, 28068, 28065>,
    <28061, 28065, 28069>    <28070, 28078, 28071>,
    <28070, 28071, 28075>    <28070, 28075, 28072>,
    <28070, 28072, 28076>    <28070, 28076, 28073>,
    <28070, 28073, 28077>    <28070, 28077, 28074>,
    <28070, 28074, 28078>    <28079, 28087, 28080>,
    <28079, 28080, 28084>    <28079, 28084, 28081>,
    <28079, 28081, 28085>    <28079, 28085, 28082>,
    <28079, 28082, 28086>    <28079, 28086, 28083>,
    <28079, 28083, 28087>    <28088, 28096, 28089>,
    <28088, 28089, 28093>    <28088, 28093, 28090>,
    <28088, 28090, 28094>    <28088, 28094, 28091>,
    <28088, 28091, 28095>    <28088, 28095, 28092>,
    <28088, 28092, 28096>    <28097, 28105, 28098>,
    <28097, 28098, 28102>    <28097, 28102, 28099>,
    <28097, 28099, 28103>    <28097, 28103, 28100>,
    <28097, 28100, 28104>    <28097, 28104, 28101>,
    <28097, 28101, 28105>    <28106, 28114, 28107>,
    <28106, 28107, 28111>    <28106, 28111, 28108>,
    <28106, 28108, 28112>    <28106, 28112, 28109>,
    <28106, 28109, 28113>    <28106, 28113, 28110>,
    <28106, 28110, 28114>    <28115, 28123, 28116>,
    <28115, 28116, 28120>    <28115, 28120, 28117>,
    <28115, 28117, 28121>    <28115, 28121, 28118>,
    <28115, 28118, 28122>    <28115, 28122, 28119>,
    <28115, 28119, 28123>    <28124, 28132, 28125>,
    <28124, 28125, 28129>    <28124, 28129, 28126>,
    <28124, 28126, 28130>    <28124, 28130, 28127>,
    <28124, 28127, 28131>    <28124, 28131, 28128>,
    <28124, 28128, 28132>    <28133, 28141, 28134>,
    <28133, 28134, 28138>    <28133, 28138, 28135>,
    <28133, 28135, 28139>    <28133, 28139, 28136>,
    <28133, 28136, 28140>    <28133, 28140, 28137>,
    <28133, 28137, 28141>    <28142, 28150, 28143>,
    <28142, 28143, 28147>    <28142, 28147, 28144>,
    <28142, 28144, 28148>    <28142, 28148, 28145>,
    <28142, 28145, 28149>    <28142, 28149, 28146>,
    <28142, 28146, 28150>    <28151, 28159, 28152>,
    <28151, 28152, 28156>    <28151, 28156, 28153>,
    <28151, 28153, 28157>    <28151, 28157, 28154>,
    <28151, 28154, 28158>    <28151, 28158, 28155>,
    <28151, 28155, 28159>    <28160, 28168, 28161>,
    <28160, 28161, 28165>    <28160, 28165, 28162>,
    <28160, 28162, 28166>    <28160, 28166, 28163>,
    <28160, 28163, 28167>    <28160, 28167, 28164>,
    <28160, 28164, 28168>    <28169, 28177, 28170>,
    <28169, 28170, 28174>    <28169, 28174, 28171>,
    <28169, 28171, 28175>    <28169, 28175, 28172>,
    <28169, 28172, 28176>    <28169, 28176, 28173>,
    <28169, 28173, 28177>    <28178, 28186, 28179>,
    <28178, 28179, 28183>    <28178, 28183, 28180>,
    <28178, 28180, 28184>    <28178, 28184, 28181>,
    <28178, 28181, 28185>    <28178, 28185, 28182>,
    <28178, 28182, 28186>    <28187, 28195, 28188>,
    <28187, 28188, 28192>    <28187, 28192, 28189>,
    <28187, 28189, 28193>    <28187, 28193, 28190>,
    <28187, 28190, 28194>    <28187, 28194, 28191>,
    <28187, 28191, 28195>    <28196, 28204, 28197>,
    <28196, 28197, 28201>    <28196, 28201, 28198>,
    <28196, 28198, 28202>    <28196, 28202, 28199>,
    <28196, 28199, 28203>    <28196, 28203, 28200>,
    <28196, 28200, 28204>    <28205, 28213, 28206>,
    <28205, 28206, 28210>    <28205, 28210, 28207>,
    <28205, 28207, 28211>    <28205, 28211, 28208>,
    <28205, 28208, 28212>    <28205, 28212, 28209>,
    <28205, 28209, 28213>    <28214, 28222, 28215>,
    <28214, 28215, 28219>    <28214, 28219, 28216>,
    <28214, 28216, 28220>    <28214, 28220, 28217>,
    <28214, 28217, 28221>    <28214, 28221, 28218>,
    <28214, 28218, 28222>    <28223, 28231, 28224>,
    <28223, 28224, 28228>    <28223, 28228, 28225>,
    <28223, 28225, 28229>    <28223, 28229, 28226>,
    <28223, 28226, 28230>    <28223, 28230, 28227>,
    <28223, 28227, 28231>    <28232, 28240, 28233>,
    <28232, 28233, 28237>    <28232, 28237, 28234>,
    <28232, 28234, 28238>    <28232, 28238, 28235>,
    <28232, 28235, 28239>    <28232, 28239, 28236>,
    <28232, 28236, 28240>    <28241, 28249, 28242>,
    <28241, 28242, 28246>    <28241, 28246, 28243>,
    <28241, 28243, 28247>    <28241, 28247, 28244>,
    <28241, 28244, 28248>    <28241, 28248, 28245>,
    <28241, 28245, 28249>    <28250, 28258, 28251>,
    <28250, 28251, 28255>    <28250, 28255, 28252>,
    <28250, 28252, 28256>    <28250, 28256, 28253>,
    <28250, 28253, 28257>    <28250, 28257, 28254>,
    <28250, 28254, 28258>    <28259, 28267, 28260>,
    <28259, 28260, 28264>    <28259, 28264, 28261>,
    <28259, 28261, 28265>    <28259, 28265, 28262>,
    <28259, 28262, 28266>    <28259, 28266, 28263>,
    <28259, 28263, 28267>    <28268, 28276, 28269>,
    <28268, 28269, 28273>    <28268, 28273, 28270>,
    <28268, 28270, 28274>    <28268, 28274, 28271>,
    <28268, 28271, 28275>    <28268, 28275, 28272>,
    <28268, 28272, 28276>    <28277, 28285, 28278>,
    <28277, 28278, 28282>    <28277, 28282, 28279>,
    <28277, 28279, 28283>    <28277, 28283, 28280>,
    <28277, 28280, 28284>    <28277, 28284, 28281>,
    <28277, 28281, 28285>    <28286, 28294, 28287>,
    <28286, 28287, 28291>    <28286, 28291, 28288>,
    <28286, 28288, 28292>    <28286, 28292, 28289>,
    <28286, 28289, 28293>    <28286, 28293, 28290>,
    <28286, 28290, 28294>    <28295, 28303, 28296>,
    <28295, 28296, 28300>    <28295, 28300, 28297>,
    <28295, 28297, 28301>    <28295, 28301, 28298>,
    <28295, 28298, 28302>    <28295, 28302, 28299>,
    <28295, 28299, 28303>    <28304, 28312, 28305>,
    <28304, 28305, 28309>    <28304, 28309, 28306>,
    <28304, 28306, 28310>    <28304, 28310, 28307>,
    <28304, 28307, 28311>    <28304, 28311, 28308>,
    <28304, 28308, 28312>    <28313, 28321, 28314>,
    <28313, 28314, 28318>    <28313, 28318, 28315>,
    <28313, 28315, 28319>    <28313, 28319, 28316>,
    <28313, 28316, 28320>    <28313, 28320, 28317>,
    <28313, 28317, 28321>    <28322, 28330, 28323>,
    <28322, 28323, 28327>    <28322, 28327, 28324>,
    <28322, 28324, 28328>    <28322, 28328, 28325>,
    <28322, 28325, 28329>    <28322, 28329, 28326>,
    <28322, 28326, 28330>    <28331, 28339, 28332>,
    <28331, 28332, 28336>    <28331, 28336, 28333>,
    <28331, 28333, 28337>    <28331, 28337, 28334>,
    <28331, 28334, 28338>    <28331, 28338, 28335>,
    <28331, 28335, 28339>    <28340, 28348, 28341>,
    <28340, 28341, 28345>    <28340, 28345, 28342>,
    <28340, 28342, 28346>    <28340, 28346, 28343>,
    <28340, 28343, 28347>    <28340, 28347, 28344>,
    <28340, 28344, 28348>    <28349, 28357, 28350>,
    <28349, 28350, 28354>    <28349, 28354, 28351>,
    <28349, 28351, 28355>    <28349, 28355, 28352>,
    <28349, 28352, 28356>    <28349, 28356, 28353>,
    <28349, 28353, 28357>    <28358, 28366, 28359>,
    <28358, 28359, 28363>    <28358, 28363, 28360>,
    <28358, 28360, 28364>    <28358, 28364, 28361>,
    <28358, 28361, 28365>    <28358, 28365, 28362>,
    <28358, 28362, 28366>    <28367, 28375, 28368>,
    <28367, 28368, 28372>    <28367, 28372, 28369>,
    <28367, 28369, 28373>    <28367, 28373, 28370>,
    <28367, 28370, 28374>    <28367, 28374, 28371>,
    <28367, 28371, 28375>    <28376, 28384, 28377>,
    <28376, 28377, 28381>    <28376, 28381, 28378>,
    <28376, 28378, 28382>    <28376, 28382, 28379>,
    <28376, 28379, 28383>    <28376, 28383, 28380>,
    <28376, 28380, 28384>    <28385, 28393, 28386>,
    <28385, 28386, 28390>    <28385, 28390, 28387>,
    <28385, 28387, 28391>    <28385, 28391, 28388>,
    <28385, 28388, 28392>    <28385, 28392, 28389>,
    <28385, 28389, 28393>    <28394, 28402, 28395>,
    <28394, 28395, 28399>    <28394, 28399, 28396>,
    <28394, 28396, 28400>    <28394, 28400, 28397>,
    <28394, 28397, 28401>    <28394, 28401, 28398>,
    <28394, 28398, 28402>    <28403, 28411, 28404>,
    <28403, 28404, 28408>    <28403, 28408, 28405>,
    <28403, 28405, 28409>    <28403, 28409, 28406>,
    <28403, 28406, 28410>    <28403, 28410, 28407>,
    <28403, 28407, 28411>    <28412, 28420, 28413>,
    <28412, 28413, 28417>    <28412, 28417, 28414>,
    <28412, 28414, 28418>    <28412, 28418, 28415>,
    <28412, 28415, 28419>    <28412, 28419, 28416>,
    <28412, 28416, 28420>    <28421, 28429, 28422>,
    <28421, 28422, 28426>    <28421, 28426, 28423>,
    <28421, 28423, 28427>    <28421, 28427, 28424>,
    <28421, 28424, 28428>    <28421, 28428, 28425>,
    <28421, 28425, 28429>    <28430, 28438, 28431>,
    <28430, 28431, 28435>    <28430, 28435, 28432>,
    <28430, 28432, 28436>    <28430, 28436, 28433>,
    <28430, 28433, 28437>    <28430, 28437, 28434>,
    <28430, 28434, 28438>    <28439, 28447, 28440>,
    <28439, 28440, 28444>    <28439, 28444, 28441>,
    <28439, 28441, 28445>    <28439, 28445, 28442>,
    <28439, 28442, 28446>    <28439, 28446, 28443>,
    <28439, 28443, 28447>    <28448, 28456, 28449>,
    <28448, 28449, 28453>    <28448, 28453, 28450>,
    <28448, 28450, 28454>    <28448, 28454, 28451>,
    <28448, 28451, 28455>    <28448, 28455, 28452>,
    <28448, 28452, 28456>    <28457, 28465, 28458>,
    <28457, 28458, 28462>    <28457, 28462, 28459>,
    <28457, 28459, 28463>    <28457, 28463, 28460>,
    <28457, 28460, 28464>    <28457, 28464, 28461>,
    <28457, 28461, 28465>    <28466, 28474, 28467>,
    <28466, 28467, 28471>    <28466, 28471, 28468>,
    <28466, 28468, 28472>    <28466, 28472, 28469>,
    <28466, 28469, 28473>    <28466, 28473, 28470>,
    <28466, 28470, 28474>    <28475, 28483, 28476>,
    <28475, 28476, 28480>    <28475, 28480, 28477>,
    <28475, 28477, 28481>    <28475, 28481, 28478>,
    <28475, 28478, 28482>    <28475, 28482, 28479>,
    <28475, 28479, 28483>    <28484, 28492, 28485>,
    <28484, 28485, 28489>    <28484, 28489, 28486>,
    <28484, 28486, 28490>    <28484, 28490, 28487>,
    <28484, 28487, 28491>    <28484, 28491, 28488>,
    <28484, 28488, 28492>    <28493, 28501, 28494>,
    <28493, 28494, 28498>    <28493, 28498, 28495>,
    <28493, 28495, 28499>    <28493, 28499, 28496>,
    <28493, 28496, 28500>    <28493, 28500, 28497>,
    <28493, 28497, 28501>    <28502, 28510, 28503>,
    <28502, 28503, 28507>    <28502, 28507, 28504>,
    <28502, 28504, 28508>    <28502, 28508, 28505>,
    <28502, 28505, 28509>    <28502, 28509, 28506>,
    <28502, 28506, 28510>    <28511, 28519, 28512>,
    <28511, 28512, 28516>    <28511, 28516, 28513>,
    <28511, 28513, 28517>    <28511, 28517, 28514>,
    <28511, 28514, 28518>    <28511, 28518, 28515>,
    <28511, 28515, 28519>    <28520, 28528, 28521>,
    <28520, 28521, 28525>    <28520, 28525, 28522>,
    <28520, 28522, 28526>    <28520, 28526, 28523>,
    <28520, 28523, 28527>    <28520, 28527, 28524>,
    <28520, 28524, 28528>    <28529, 28537, 28530>,
    <28529, 28530, 28534>    <28529, 28534, 28531>,
    <28529, 28531, 28535>    <28529, 28535, 28532>,
    <28529, 28532, 28536>    <28529, 28536, 28533>,
    <28529, 28533, 28537>    <28538, 28546, 28539>,
    <28538, 28539, 28543>    <28538, 28543, 28540>,
    <28538, 28540, 28544>    <28538, 28544, 28541>,
    <28538, 28541, 28545>    <28538, 28545, 28542>,
    <28538, 28542, 28546>    <28547, 28555, 28548>,
    <28547, 28548, 28552>    <28547, 28552, 28549>,
    <28547, 28549, 28553>    <28547, 28553, 28550>,
    <28547, 28550, 28554>    <28547, 28554, 28551>,
    <28547, 28551, 28555>    <28556, 28564, 28557>,
    <28556, 28557, 28561>    <28556, 28561, 28558>,
    <28556, 28558, 28562>    <28556, 28562, 28559>,
    <28556, 28559, 28563>    <28556, 28563, 28560>,
    <28556, 28560, 28564>    <28565, 28573, 28566>,
    <28565, 28566, 28570>    <28565, 28570, 28567>,
    <28565, 28567, 28571>    <28565, 28571, 28568>,
    <28565, 28568, 28572>    <28565, 28572, 28569>,
    <28565, 28569, 28573>    <28574, 28582, 28575>,
    <28574, 28575, 28579>    <28574, 28579, 28576>,
    <28574, 28576, 28580>    <28574, 28580, 28577>,
    <28574, 28577, 28581>    <28574, 28581, 28578>,
    <28574, 28578, 28582>    <28583, 28591, 28584>,
    <28583, 28584, 28588>    <28583, 28588, 28585>,
    <28583, 28585, 28589>    <28583, 28589, 28586>,
    <28583, 28586, 28590>    <28583, 28590, 28587>,
    <28583, 28587, 28591>    <28592, 28600, 28593>,
    <28592, 28593, 28597>    <28592, 28597, 28594>,
    <28592, 28594, 28598>    <28592, 28598, 28595>,
    <28592, 28595, 28599>    <28592, 28599, 28596>,
    <28592, 28596, 28600>    <28601, 28609, 28602>,
    <28601, 28602, 28606>    <28601, 28606, 28603>,
    <28601, 28603, 28607>    <28601, 28607, 28604>,
    <28601, 28604, 28608>    <28601, 28608, 28605>,
    <28601, 28605, 28609>    <28610, 28618, 28611>,
    <28610, 28611, 28615>    <28610, 28615, 28612>,
    <28610, 28612, 28616>    <28610, 28616, 28613>,
    <28610, 28613, 28617>    <28610, 28617, 28614>,
    <28610, 28614, 28618>    <28619, 28627, 28620>,
    <28619, 28620, 28624>    <28619, 28624, 28621>,
    <28619, 28621, 28625>    <28619, 28625, 28622>,
    <28619, 28622, 28626>    <28619, 28626, 28623>,
    <28619, 28623, 28627>    <28628, 28636, 28629>,
    <28628, 28629, 28633>    <28628, 28633, 28630>,
    <28628, 28630, 28634>    <28628, 28634, 28631>,
    <28628, 28631, 28635>    <28628, 28635, 28632>,
    <28628, 28632, 28636>    <28637, 28645, 28638>,
    <28637, 28638, 28642>    <28637, 28642, 28639>,
    <28637, 28639, 28643>    <28637, 28643, 28640>,
    <28637, 28640, 28644>    <28637, 28644, 28641>,
    <28637, 28641, 28645>    <28646, 28654, 28647>,
    <28646, 28647, 28651>    <28646, 28651, 28648>,
    <28646, 28648, 28652>    <28646, 28652, 28649>,
    <28646, 28649, 28653>    <28646, 28653, 28650>,
    <28646, 28650, 28654>    <28655, 28663, 28656>,
    <28655, 28656, 28660>    <28655, 28660, 28657>,
    <28655, 28657, 28661>    <28655, 28661, 28658>,
    <28655, 28658, 28662>    <28655, 28662, 28659>,
    <28655, 28659, 28663>    <28664, 28672, 28665>,
    <28664, 28665, 28669>    <28664, 28669, 28666>,
    <28664, 28666, 28670>    <28664, 28670, 28667>,
    <28664, 28667, 28671>    <28664, 28671, 28668>,
    <28664, 28668, 28672>    <28673, 28681, 28674>,
    <28673, 28674, 28678>    <28673, 28678, 28675>,
    <28673, 28675, 28679>    <28673, 28679, 28676>,
    <28673, 28676, 28680>    <28673, 28680, 28677>,
    <28673, 28677, 28681>    <28682, 28690, 28683>,
    <28682, 28683, 28687>    <28682, 28687, 28684>,
    <28682, 28684, 28688>    <28682, 28688, 28685>,
    <28682, 28685, 28689>    <28682, 28689, 28686>,
    <28682, 28686, 28690>    <28691, 28699, 28692>,
    <28691, 28692, 28696>    <28691, 28696, 28693>,
    <28691, 28693, 28697>    <28691, 28697, 28694>,
    <28691, 28694, 28698>    <28691, 28698, 28695>,
    <28691, 28695, 28699>    <28700, 28708, 28701>,
    <28700, 28701, 28705>    <28700, 28705, 28702>,
    <28700, 28702, 28706>    <28700, 28706, 28703>,
    <28700, 28703, 28707>    <28700, 28707, 28704>,
    <28700, 28704, 28708>    <28709, 28717, 28710>,
    <28709, 28710, 28714>    <28709, 28714, 28711>,
    <28709, 28711, 28715>    <28709, 28715, 28712>,
    <28709, 28712, 28716>    <28709, 28716, 28713>,
    <28709, 28713, 28717>    <28718, 28726, 28719>,
    <28718, 28719, 28723>    <28718, 28723, 28720>,
    <28718, 28720, 28724>    <28718, 28724, 28721>,
    <28718, 28721, 28725>    <28718, 28725, 28722>,
    <28718, 28722, 28726>    <28727, 28735, 28728>,
    <28727, 28728, 28732>    <28727, 28732, 28729>,
    <28727, 28729, 28733>    <28727, 28733, 28730>,
    <28727, 28730, 28734>    <28727, 28734, 28731>,
    <28727, 28731, 28735>    <28736, 28744, 28737>,
    <28736, 28737, 28741>    <28736, 28741, 28738>,
    <28736, 28738, 28742>    <28736, 28742, 28739>,
    <28736, 28739, 28743>    <28736, 28743, 28740>,
    <28736, 28740, 28744>    <28745, 28753, 28746>,
    <28745, 28746, 28750>    <28745, 28750, 28747>,
    <28745, 28747, 28751>    <28745, 28751, 28748>,
    <28745, 28748, 28752>    <28745, 28752, 28749>,
    <28745, 28749, 28753>    <28754, 28762, 28755>,
    <28754, 28755, 28759>    <28754, 28759, 28756>,
    <28754, 28756, 28760>    <28754, 28760, 28757>,
    <28754, 28757, 28761>    <28754, 28761, 28758>,
    <28754, 28758, 28762>    <28763, 28771, 28764>,
    <28763, 28764, 28768>    <28763, 28768, 28765>,
    <28763, 28765, 28769>    <28763, 28769, 28766>,
    <28763, 28766, 28770>    <28763, 28770, 28767>,
    <28763, 28767, 28771>    <28772, 28780, 28773>,
    <28772, 28773, 28777>    <28772, 28777, 28774>,
    <28772, 28774, 28778>    <28772, 28778, 28775>,
    <28772, 28775, 28779>    <28772, 28779, 28776>,
    <28772, 28776, 28780>    <28781, 28789, 28782>,
    <28781, 28782, 28786>    <28781, 28786, 28783>,
    <28781, 28783, 28787>    <28781, 28787, 28784>,
    <28781, 28784, 28788>    <28781, 28788, 28785>,
    <28781, 28785, 28789>    <28790, 28798, 28791>,
    <28790, 28791, 28795>    <28790, 28795, 28792>,
    <28790, 28792, 28796>    <28790, 28796, 28793>,
    <28790, 28793, 28797>    <28790, 28797, 28794>,
    <28790, 28794, 28798>    <28799, 28807, 28800>,
    <28799, 28800, 28804>    <28799, 28804, 28801>,
    <28799, 28801, 28805>    <28799, 28805, 28802>,
    <28799, 28802, 28806>    <28799, 28806, 28803>,
    <28799, 28803, 28807>    <28808, 28816, 28809>,
    <28808, 28809, 28813>    <28808, 28813, 28810>,
    <28808, 28810, 28814>    <28808, 28814, 28811>,
    <28808, 28811, 28815>    <28808, 28815, 28812>,
    <28808, 28812, 28816>    <28817, 28825, 28818>,
    <28817, 28818, 28822>    <28817, 28822, 28819>,
    <28817, 28819, 28823>    <28817, 28823, 28820>,
    <28817, 28820, 28824>    <28817, 28824, 28821>,
    <28817, 28821, 28825>    <28826, 28834, 28827>,
    <28826, 28827, 28831>    <28826, 28831, 28828>,
    <28826, 28828, 28832>    <28826, 28832, 28829>,
    <28826, 28829, 28833>    <28826, 28833, 28830>,
    <28826, 28830, 28834>    <28835, 28843, 28836>,
    <28835, 28836, 28840>    <28835, 28840, 28837>,
    <28835, 28837, 28841>    <28835, 28841, 28838>,
    <28835, 28838, 28842>    <28835, 28842, 28839>,
    <28835, 28839, 28843>    <28844, 28852, 28845>,
    <28844, 28845, 28849>    <28844, 28849, 28846>,
    <28844, 28846, 28850>    <28844, 28850, 28847>,
    <28844, 28847, 28851>    <28844, 28851, 28848>,
    <28844, 28848, 28852>    <28853, 28861, 28854>,
    <28853, 28854, 28858>    <28853, 28858, 28855>,
    <28853, 28855, 28859>    <28853, 28859, 28856>,
    <28853, 28856, 28860>    <28853, 28860, 28857>,
    <28853, 28857, 28861>    <28862, 28870, 28863>,
    <28862, 28863, 28867>    <28862, 28867, 28864>,
    <28862, 28864, 28868>    <28862, 28868, 28865>,
    <28862, 28865, 28869>    <28862, 28869, 28866>,
    <28862, 28866, 28870>    <28871, 28879, 28872>,
    <28871, 28872, 28876>    <28871, 28876, 28873>,
    <28871, 28873, 28877>    <28871, 28877, 28874>,
    <28871, 28874, 28878>    <28871, 28878, 28875>,
    <28871, 28875, 28879>    <28880, 28888, 28881>,
    <28880, 28881, 28885>    <28880, 28885, 28882>,
    <28880, 28882, 28886>    <28880, 28886, 28883>,
    <28880, 28883, 28887>    <28880, 28887, 28884>,
    <28880, 28884, 28888>    <28889, 28897, 28890>,
    <28889, 28890, 28894>    <28889, 28894, 28891>,
    <28889, 28891, 28895>    <28889, 28895, 28892>,
    <28889, 28892, 28896>    <28889, 28896, 28893>,
    <28889, 28893, 28897>    <28898, 28906, 28899>,
    <28898, 28899, 28903>    <28898, 28903, 28900>,
    <28898, 28900, 28904>    <28898, 28904, 28901>,
    <28898, 28901, 28905>    <28898, 28905, 28902>,
    <28898, 28902, 28906>    <28907, 28915, 28908>,
    <28907, 28908, 28912>    <28907, 28912, 28909>,
    <28907, 28909, 28913>    <28907, 28913, 28910>,
    <28907, 28910, 28914>    <28907, 28914, 28911>,
    <28907, 28911, 28915>    <28916, 28924, 28917>,
    <28916, 28917, 28921>    <28916, 28921, 28918>,
    <28916, 28918, 28922>    <28916, 28922, 28919>,
    <28916, 28919, 28923>    <28916, 28923, 28920>,
    <28916, 28920, 28924>    <28925, 28933, 28926>,
    <28925, 28926, 28930>    <28925, 28930, 28927>,
    <28925, 28927, 28931>    <28925, 28931, 28928>,
    <28925, 28928, 28932>    <28925, 28932, 28929>,
    <28925, 28929, 28933>    <28934, 28942, 28935>,
    <28934, 28935, 28939>    <28934, 28939, 28936>,
    <28934, 28936, 28940>    <28934, 28940, 28937>,
    <28934, 28937, 28941>    <28934, 28941, 28938>,
    <28934, 28938, 28942>    <28943, 28951, 28944>,
    <28943, 28944, 28948>    <28943, 28948, 28945>,
    <28943, 28945, 28949>    <28943, 28949, 28946>,
    <28943, 28946, 28950>    <28943, 28950, 28947>,
    <28943, 28947, 28951>    <28952, 28960, 28953>,
    <28952, 28953, 28957>    <28952, 28957, 28954>,
    <28952, 28954, 28958>    <28952, 28958, 28955>,
    <28952, 28955, 28959>    <28952, 28959, 28956>,
    <28952, 28956, 28960>    <28961, 28969, 28962>,
    <28961, 28962, 28966>    <28961, 28966, 28963>,
    <28961, 28963, 28967>    <28961, 28967, 28964>,
    <28961, 28964, 28968>    <28961, 28968, 28965>,
    <28961, 28965, 28969>    <28970, 28978, 28971>,
    <28970, 28971, 28975>    <28970, 28975, 28972>,
    <28970, 28972, 28976>    <28970, 28976, 28973>,
    <28970, 28973, 28977>    <28970, 28977, 28974>,
    <28970, 28974, 28978>    <28979, 28987, 28980>,
    <28979, 28980, 28984>    <28979, 28984, 28981>,
    <28979, 28981, 28985>    <28979, 28985, 28982>,
    <28979, 28982, 28986>    <28979, 28986, 28983>,
    <28979, 28983, 28987>    <28988, 28996, 28989>,
    <28988, 28989, 28993>    <28988, 28993, 28990>,
    <28988, 28990, 28994>    <28988, 28994, 28991>,
    <28988, 28991, 28995>    <28988, 28995, 28992>,
    <28988, 28992, 28996>    <28997, 29005, 28998>,
    <28997, 28998, 29002>    <28997, 29002, 28999>,
    <28997, 28999, 29003>    <28997, 29003, 29000>,
    <28997, 29000, 29004>    <28997, 29004, 29001>,
    <28997, 29001, 29005>    <29006, 29014, 29007>,
    <29006, 29007, 29011>    <29006, 29011, 29008>,
    <29006, 29008, 29012>    <29006, 29012, 29009>,
    <29006, 29009, 29013>    <29006, 29013, 29010>,
    <29006, 29010, 29014>    <29015, 29023, 29016>,
    <29015, 29016, 29020>    <29015, 29020, 29017>,
    <29015, 29017, 29021>    <29015, 29021, 29018>,
    <29015, 29018, 29022>    <29015, 29022, 29019>,
    <29015, 29019, 29023>    <29024, 29032, 29025>,
    <29024, 29025, 29029>    <29024, 29029, 29026>,
    <29024, 29026, 29030>    <29024, 29030, 29027>,
    <29024, 29027, 29031>    <29024, 29031, 29028>,
    <29024, 29028, 29032>    <29033, 29041, 29034>,
    <29033, 29034, 29038>    <29033, 29038, 29035>,
    <29033, 29035, 29039>    <29033, 29039, 29036>,
    <29033, 29036, 29040>    <29033, 29040, 29037>,
    <29033, 29037, 29041>    <29042, 29050, 29043>,
    <29042, 29043, 29047>    <29042, 29047, 29044>,
    <29042, 29044, 29048>    <29042, 29048, 29045>,
    <29042, 29045, 29049>    <29042, 29049, 29046>,
    <29042, 29046, 29050>    <29051, 29059, 29052>,
    <29051, 29052, 29056>    <29051, 29056, 29053>,
    <29051, 29053, 29057>    <29051, 29057, 29054>,
    <29051, 29054, 29058>    <29051, 29058, 29055>,
    <29051, 29055, 29059>    <29060, 29068, 29061>,
    <29060, 29061, 29065>    <29060, 29065, 29062>,
    <29060, 29062, 29066>    <29060, 29066, 29063>,
    <29060, 29063, 29067>    <29060, 29067, 29064>,
    <29060, 29064, 29068>    <29069, 29077, 29070>,
    <29069, 29070, 29074>    <29069, 29074, 29071>,
    <29069, 29071, 29075>    <29069, 29075, 29072>,
    <29069, 29072, 29076>    <29069, 29076, 29073>,
    <29069, 29073, 29077>    <29078, 29086, 29079>,
    <29078, 29079, 29083>    <29078, 29083, 29080>,
    <29078, 29080, 29084>    <29078, 29084, 29081>,
    <29078, 29081, 29085>    <29078, 29085, 29082>,
    <29078, 29082, 29086>    <29087, 29095, 29088>,
    <29087, 29088, 29092>    <29087, 29092, 29089>,
    <29087, 29089, 29093>    <29087, 29093, 29090>,
    <29087, 29090, 29094>    <29087, 29094, 29091>,
    <29087, 29091, 29095>    <29096, 29104, 29097>,
    <29096, 29097, 29101>    <29096, 29101, 29098>,
    <29096, 29098, 29102>    <29096, 29102, 29099>,
    <29096, 29099, 29103>    <29096, 29103, 29100>,
    <29096, 29100, 29104>    <29105, 29113, 29106>,
    <29105, 29106, 29110>    <29105, 29110, 29107>,
    <29105, 29107, 29111>    <29105, 29111, 29108>,
    <29105, 29108, 29112>    <29105, 29112, 29109>,
    <29105, 29109, 29113>    <29114, 29122, 29115>,
    <29114, 29115, 29119>    <29114, 29119, 29116>,
    <29114, 29116, 29120>    <29114, 29120, 29117>,
    <29114, 29117, 29121>    <29114, 29121, 29118>,
    <29114, 29118, 29122>    <29123, 29131, 29124>,
    <29123, 29124, 29128>    <29123, 29128, 29125>,
    <29123, 29125, 29129>    <29123, 29129, 29126>,
    <29123, 29126, 29130>    <29123, 29130, 29127>,
    <29123, 29127, 29131>    <29132, 29140, 29133>,
    <29132, 29133, 29137>    <29132, 29137, 29134>,
    <29132, 29134, 29138>    <29132, 29138, 29135>,
    <29132, 29135, 29139>    <29132, 29139, 29136>,
    <29132, 29136, 29140>    <29141, 29149, 29142>,
    <29141, 29142, 29146>    <29141, 29146, 29143>,
    <29141, 29143, 29147>    <29141, 29147, 29144>,
    <29141, 29144, 29148>    <29141, 29148, 29145>,
    <29141, 29145, 29149>    <29150, 29158, 29151>,
    <29150, 29151, 29155>    <29150, 29155, 29152>,
    <29150, 29152, 29156>    <29150, 29156, 29153>,
    <29150, 29153, 29157>    <29150, 29157, 29154>,
    <29150, 29154, 29158>    <29159, 29167, 29160>,
    <29159, 29160, 29164>    <29159, 29164, 29161>,
    <29159, 29161, 29165>    <29159, 29165, 29162>,
    <29159, 29162, 29166>    <29159, 29166, 29163>,
    <29159, 29163, 29167>    <29168, 29176, 29169>,
    <29168, 29169, 29173>    <29168, 29173, 29170>,
    <29168, 29170, 29174>    <29168, 29174, 29171>,
    <29168, 29171, 29175>    <29168, 29175, 29172>,
    <29168, 29172, 29176>    <29177, 29185, 29178>,
    <29177, 29178, 29182>    <29177, 29182, 29179>,
    <29177, 29179, 29183>    <29177, 29183, 29180>,
    <29177, 29180, 29184>    <29177, 29184, 29181>,
    <29177, 29181, 29185>    <29186, 29194, 29187>,
    <29186, 29187, 29191>    <29186, 29191, 29188>,
    <29186, 29188, 29192>    <29186, 29192, 29189>,
    <29186, 29189, 29193>    <29186, 29193, 29190>,
    <29186, 29190, 29194>    <29195, 29203, 29196>,
    <29195, 29196, 29200>    <29195, 29200, 29197>,
    <29195, 29197, 29201>    <29195, 29201, 29198>,
    <29195, 29198, 29202>    <29195, 29202, 29199>,
    <29195, 29199, 29203>    <29204, 29212, 29205>,
    <29204, 29205, 29209>    <29204, 29209, 29206>,
    <29204, 29206, 29210>    <29204, 29210, 29207>,
    <29204, 29207, 29211>    <29204, 29211, 29208>,
    <29204, 29208, 29212>    <29213, 29221, 29214>,
    <29213, 29214, 29218>    <29213, 29218, 29215>,
    <29213, 29215, 29219>    <29213, 29219, 29216>,
    <29213, 29216, 29220>    <29213, 29220, 29217>,
    <29213, 29217, 29221>    <29222, 29230, 29223>,
    <29222, 29223, 29227>    <29222, 29227, 29224>,
    <29222, 29224, 29228>    <29222, 29228, 29225>,
    <29222, 29225, 29229>    <29222, 29229, 29226>,
    <29222, 29226, 29230>    <29231, 29239, 29232>,
    <29231, 29232, 29236>    <29231, 29236, 29233>,
    <29231, 29233, 29237>    <29231, 29237, 29234>,
    <29231, 29234, 29238>    <29231, 29238, 29235>,
    <29231, 29235, 29239>    <29240, 29248, 29241>,
    <29240, 29241, 29245>    <29240, 29245, 29242>,
    <29240, 29242, 29246>    <29240, 29246, 29243>,
    <29240, 29243, 29247>    <29240, 29247, 29244>,
    <29240, 29244, 29248>    <29249, 29257, 29250>,
    <29249, 29250, 29254>    <29249, 29254, 29251>,
    <29249, 29251, 29255>    <29249, 29255, 29252>,
    <29249, 29252, 29256>    <29249, 29256, 29253>,
    <29249, 29253, 29257>    <29258, 29266, 29259>,
    <29258, 29259, 29263>    <29258, 29263, 29260>,
    <29258, 29260, 29264>    <29258, 29264, 29261>,
    <29258, 29261, 29265>    <29258, 29265, 29262>,
    <29258, 29262, 29266>    <29267, 29275, 29268>,
    <29267, 29268, 29272>    <29267, 29272, 29269>,
    <29267, 29269, 29273>    <29267, 29273, 29270>,
    <29267, 29270, 29274>    <29267, 29274, 29271>,
    <29267, 29271, 29275>    <29276, 29284, 29277>,
    <29276, 29277, 29281>    <29276, 29281, 29278>,
    <29276, 29278, 29282>    <29276, 29282, 29279>,
    <29276, 29279, 29283>    <29276, 29283, 29280>,
    <29276, 29280, 29284>    <29285, 29293, 29286>,
    <29285, 29286, 29290>    <29285, 29290, 29287>,
    <29285, 29287, 29291>    <29285, 29291, 29288>,
    <29285, 29288, 29292>    <29285, 29292, 29289>,
    <29285, 29289, 29293>    <29294, 29302, 29295>,
    <29294, 29295, 29299>    <29294, 29299, 29296>,
    <29294, 29296, 29300>    <29294, 29300, 29297>,
    <29294, 29297, 29301>    <29294, 29301, 29298>,
    <29294, 29298, 29302>    <29303, 29311, 29304>,
    <29303, 29304, 29308>    <29303, 29308, 29305>,
    <29303, 29305, 29309>    <29303, 29309, 29306>,
    <29303, 29306, 29310>    <29303, 29310, 29307>,
    <29303, 29307, 29311>    <29312, 29320, 29313>,
    <29312, 29313, 29317>    <29312, 29317, 29314>,
    <29312, 29314, 29318>    <29312, 29318, 29315>,
    <29312, 29315, 29319>    <29312, 29319, 29316>,
    <29312, 29316, 29320>    <29321, 29329, 29322>,
    <29321, 29322, 29326>    <29321, 29326, 29323>,
    <29321, 29323, 29327>    <29321, 29327, 29324>,
    <29321, 29324, 29328>    <29321, 29328, 29325>,
    <29321, 29325, 29329>    <29330, 29338, 29331>,
    <29330, 29331, 29335>    <29330, 29335, 29332>,
    <29330, 29332, 29336>    <29330, 29336, 29333>,
    <29330, 29333, 29337>    <29330, 29337, 29334>,
    <29330, 29334, 29338>    <29339, 29347, 29340>,
    <29339, 29340, 29344>    <29339, 29344, 29341>,
    <29339, 29341, 29345>    <29339, 29345, 29342>,
    <29339, 29342, 29346>    <29339, 29346, 29343>,
    <29339, 29343, 29347>    <29348, 29356, 29349>,
    <29348, 29349, 29353>    <29348, 29353, 29350>,
    <29348, 29350, 29354>    <29348, 29354, 29351>,
    <29348, 29351, 29355>    <29348, 29355, 29352>,
    <29348, 29352, 29356>    <29357, 29365, 29358>,
    <29357, 29358, 29362>    <29357, 29362, 29359>,
    <29357, 29359, 29363>    <29357, 29363, 29360>,
    <29357, 29360, 29364>    <29357, 29364, 29361>,
    <29357, 29361, 29365>    <29366, 29374, 29367>,
    <29366, 29367, 29371>    <29366, 29371, 29368>,
    <29366, 29368, 29372>    <29366, 29372, 29369>,
    <29366, 29369, 29373>    <29366, 29373, 29370>,
    <29366, 29370, 29374>    <29375, 29383, 29376>,
    <29375, 29376, 29380>    <29375, 29380, 29377>,
    <29375, 29377, 29381>    <29375, 29381, 29378>,
    <29375, 29378, 29382>    <29375, 29382, 29379>,
    <29375, 29379, 29383>    <29384, 29392, 29385>,
    <29384, 29385, 29389>    <29384, 29389, 29386>,
    <29384, 29386, 29390>    <29384, 29390, 29387>,
    <29384, 29387, 29391>    <29384, 29391, 29388>,
    <29384, 29388, 29392>    <29393, 29401, 29394>,
    <29393, 29394, 29398>    <29393, 29398, 29395>,
    <29393, 29395, 29399>    <29393, 29399, 29396>,
    <29393, 29396, 29400>    <29393, 29400, 29397>,
    <29393, 29397, 29401>    <29402, 29410, 29403>,
    <29402, 29403, 29407>    <29402, 29407, 29404>,
    <29402, 29404, 29408>    <29402, 29408, 29405>,
    <29402, 29405, 29409>    <29402, 29409, 29406>,
    <29402, 29406, 29410>    <29411, 29419, 29412>,
    <29411, 29412, 29416>    <29411, 29416, 29413>,
    <29411, 29413, 29417>    <29411, 29417, 29414>,
    <29411, 29414, 29418>    <29411, 29418, 29415>,
    <29411, 29415, 29419>    <29420, 29428, 29421>,
    <29420, 29421, 29425>    <29420, 29425, 29422>,
    <29420, 29422, 29426>    <29420, 29426, 29423>,
    <29420, 29423, 29427>    <29420, 29427, 29424>,
    <29420, 29424, 29428>    <29429, 29437, 29430>,
    <29429, 29430, 29434>    <29429, 29434, 29431>,
    <29429, 29431, 29435>    <29429, 29435, 29432>,
    <29429, 29432, 29436>    <29429, 29436, 29433>,
    <29429, 29433, 29437>    <29438, 29446, 29439>,
    <29438, 29439, 29443>    <29438, 29443, 29440>,
    <29438, 29440, 29444>    <29438, 29444, 29441>,
    <29438, 29441, 29445>    <29438, 29445, 29442>,
    <29438, 29442, 29446>    <29447, 29455, 29448>,
    <29447, 29448, 29452>    <29447, 29452, 29449>,
    <29447, 29449, 29453>    <29447, 29453, 29450>,
    <29447, 29450, 29454>    <29447, 29454, 29451>,
    <29447, 29451, 29455>    <29456, 29464, 29457>,
    <29456, 29457, 29461>    <29456, 29461, 29458>,
    <29456, 29458, 29462>    <29456, 29462, 29459>,
    <29456, 29459, 29463>    <29456, 29463, 29460>,
    <29456, 29460, 29464>    <29465, 29473, 29466>,
    <29465, 29466, 29470>    <29465, 29470, 29467>,
    <29465, 29467, 29471>    <29465, 29471, 29468>,
    <29465, 29468, 29472>    <29465, 29472, 29469>,
    <29465, 29469, 29473>    <29474, 29482, 29475>,
    <29474, 29475, 29479>    <29474, 29479, 29476>,
    <29474, 29476, 29480>    <29474, 29480, 29477>,
    <29474, 29477, 29481>    <29474, 29481, 29478>,
    <29474, 29478, 29482>    <29483, 29491, 29484>,
    <29483, 29484, 29488>    <29483, 29488, 29485>,
    <29483, 29485, 29489>    <29483, 29489, 29486>,
    <29483, 29486, 29490>    <29483, 29490, 29487>,
    <29483, 29487, 29491>    <29492, 29500, 29493>,
    <29492, 29493, 29497>    <29492, 29497, 29494>,
    <29492, 29494, 29498>    <29492, 29498, 29495>,
    <29492, 29495, 29499>    <29492, 29499, 29496>,
    <29492, 29496, 29500>    <29501, 29509, 29502>,
    <29501, 29502, 29506>    <29501, 29506, 29503>,
    <29501, 29503, 29507>    <29501, 29507, 29504>,
    <29501, 29504, 29508>    <29501, 29508, 29505>,
    <29501, 29505, 29509>    <29510, 29518, 29511>,
    <29510, 29511, 29515>    <29510, 29515, 29512>,
    <29510, 29512, 29516>    <29510, 29516, 29513>,
    <29510, 29513, 29517>    <29510, 29517, 29514>,
    <29510, 29514, 29518>    <29519, 29527, 29520>,
    <29519, 29520, 29524>    <29519, 29524, 29521>,
    <29519, 29521, 29525>    <29519, 29525, 29522>,
    <29519, 29522, 29526>    <29519, 29526, 29523>,
    <29519, 29523, 29527>    <29528, 29536, 29529>,
    <29528, 29529, 29533>    <29528, 29533, 29530>,
    <29528, 29530, 29534>    <29528, 29534, 29531>,
    <29528, 29531, 29535>    <29528, 29535, 29532>,
    <29528, 29532, 29536>    <29537, 29545, 29538>,
    <29537, 29538, 29542>    <29537, 29542, 29539>,
    <29537, 29539, 29543>    <29537, 29543, 29540>,
    <29537, 29540, 29544>    <29537, 29544, 29541>,
    <29537, 29541, 29545>    <29546, 29554, 29547>,
    <29546, 29547, 29551>    <29546, 29551, 29548>,
    <29546, 29548, 29552>    <29546, 29552, 29549>,
    <29546, 29549, 29553>    <29546, 29553, 29550>,
    <29546, 29550, 29554>    <29555, 29563, 29556>,
    <29555, 29556, 29560>    <29555, 29560, 29557>,
    <29555, 29557, 29561>    <29555, 29561, 29558>,
    <29555, 29558, 29562>    <29555, 29562, 29559>,
    <29555, 29559, 29563>    <29564, 29572, 29565>,
    <29564, 29565, 29569>    <29564, 29569, 29566>,
    <29564, 29566, 29570>    <29564, 29570, 29567>,
    <29564, 29567, 29571>    <29564, 29571, 29568>,
    <29564, 29568, 29572>    <29573, 29581, 29574>,
    <29573, 29574, 29578>    <29573, 29578, 29575>,
    <29573, 29575, 29579>    <29573, 29579, 29576>,
    <29573, 29576, 29580>    <29573, 29580, 29577>,
    <29573, 29577, 29581>    <29582, 29590, 29583>,
    <29582, 29583, 29587>    <29582, 29587, 29584>,
    <29582, 29584, 29588>    <29582, 29588, 29585>,
    <29582, 29585, 29589>    <29582, 29589, 29586>,
    <29582, 29586, 29590>    <29591, 29599, 29592>,
    <29591, 29592, 29596>    <29591, 29596, 29593>,
    <29591, 29593, 29597>    <29591, 29597, 29594>,
    <29591, 29594, 29598>    <29591, 29598, 29595>,
    <29591, 29595, 29599>    <29600, 29608, 29601>,
    <29600, 29601, 29605>    <29600, 29605, 29602>,
    <29600, 29602, 29606>    <29600, 29606, 29603>,
    <29600, 29603, 29607>    <29600, 29607, 29604>,
    <29600, 29604, 29608>    <29609, 29617, 29610>,
    <29609, 29610, 29614>    <29609, 29614, 29611>,
    <29609, 29611, 29615>    <29609, 29615, 29612>,
    <29609, 29612, 29616>    <29609, 29616, 29613>,
    <29609, 29613, 29617>    <29618, 29626, 29619>,
    <29618, 29619, 29623>    <29618, 29623, 29620>,
    <29618, 29620, 29624>    <29618, 29624, 29621>,
    <29618, 29621, 29625>    <29618, 29625, 29622>,
    <29618, 29622, 29626>    <29627, 29635, 29628>,
    <29627, 29628, 29632>    <29627, 29632, 29629>,
    <29627, 29629, 29633>    <29627, 29633, 29630>,
    <29627, 29630, 29634>    <29627, 29634, 29631>,
    <29627, 29631, 29635>    <29636, 29644, 29637>,
    <29636, 29637, 29641>    <29636, 29641, 29638>,
    <29636, 29638, 29642>    <29636, 29642, 29639>,
    <29636, 29639, 29643>    <29636, 29643, 29640>,
    <29636, 29640, 29644>    <29645, 29653, 29646>,
    <29645, 29646, 29650>    <29645, 29650, 29647>,
    <29645, 29647, 29651>    <29645, 29651, 29648>,
    <29645, 29648, 29652>    <29645, 29652, 29649>,
    <29645, 29649, 29653>    <29654, 29662, 29655>,
    <29654, 29655, 29659>    <29654, 29659, 29656>,
    <29654, 29656, 29660>    <29654, 29660, 29657>,
    <29654, 29657, 29661>    <29654, 29661, 29658>,
    <29654, 29658, 29662>    <29663, 29671, 29664>,
    <29663, 29664, 29668>    <29663, 29668, 29665>,
    <29663, 29665, 29669>    <29663, 29669, 29666>,
    <29663, 29666, 29670>    <29663, 29670, 29667>,
    <29663, 29667, 29671>    <29672, 29680, 29673>,
    <29672, 29673, 29677>    <29672, 29677, 29674>,
    <29672, 29674, 29678>    <29672, 29678, 29675>,
    <29672, 29675, 29679>    <29672, 29679, 29676>,
    <29672, 29676, 29680>    <29681, 29689, 29682>,
    <29681, 29682, 29686>    <29681, 29686, 29683>,
    <29681, 29683, 29687>    <29681, 29687, 29684>,
    <29681, 29684, 29688>    <29681, 29688, 29685>,
    <29681, 29685, 29689>    <29690, 29698, 29691>,
    <29690, 29691, 29695>    <29690, 29695, 29692>,
    <29690, 29692, 29696>    <29690, 29696, 29693>,
    <29690, 29693, 29697>    <29690, 29697, 29694>,
    <29690, 29694, 29698>    <29699, 29707, 29700>,
    <29699, 29700, 29704>    <29699, 29704, 29701>,
    <29699, 29701, 29705>    <29699, 29705, 29702>,
    <29699, 29702, 29706>    <29699, 29706, 29703>,
    <29699, 29703, 29707>    <29708, 29716, 29709>,
    <29708, 29709, 29713>    <29708, 29713, 29710>,
    <29708, 29710, 29714>    <29708, 29714, 29711>,
    <29708, 29711, 29715>    <29708, 29715, 29712>,
    <29708, 29712, 29716>    <29717, 29725, 29718>,
    <29717, 29718, 29722>    <29717, 29722, 29719>,
    <29717, 29719, 29723>    <29717, 29723, 29720>,
    <29717, 29720, 29724>    <29717, 29724, 29721>,
    <29717, 29721, 29725>    <29726, 29734, 29727>,
    <29726, 29727, 29731>    <29726, 29731, 29728>,
    <29726, 29728, 29732>    <29726, 29732, 29729>,
    <29726, 29729, 29733>    <29726, 29733, 29730>,
    <29726, 29730, 29734>    <29735, 29743, 29736>,
    <29735, 29736, 29740>    <29735, 29740, 29737>,
    <29735, 29737, 29741>    <29735, 29741, 29738>,
    <29735, 29738, 29742>    <29735, 29742, 29739>,
    <29735, 29739, 29743>    <29744, 29752, 29745>,
    <29744, 29745, 29749>    <29744, 29749, 29746>,
    <29744, 29746, 29750>    <29744, 29750, 29747>,
    <29744, 29747, 29751>    <29744, 29751, 29748>,
    <29744, 29748, 29752>    <29753, 29761, 29754>,
    <29753, 29754, 29758>    <29753, 29758, 29755>,
    <29753, 29755, 29759>    <29753, 29759, 29756>,
    <29753, 29756, 29760>    <29753, 29760, 29757>,
    <29753, 29757, 29761>    <29762, 29770, 29763>,
    <29762, 29763, 29767>    <29762, 29767, 29764>,
    <29762, 29764, 29768>    <29762, 29768, 29765>,
    <29762, 29765, 29769>    <29762, 29769, 29766>,
    <29762, 29766, 29770>    <29771, 29779, 29772>,
    <29771, 29772, 29776>    <29771, 29776, 29773>,
    <29771, 29773, 29777>    <29771, 29777, 29774>,
    <29771, 29774, 29778>    <29771, 29778, 29775>,
    <29771, 29775, 29779>    <29780, 29788, 29781>,
    <29780, 29781, 29785>    <29780, 29785, 29782>,
    <29780, 29782, 29786>    <29780, 29786, 29783>,
    <29780, 29783, 29787>    <29780, 29787, 29784>,
    <29780, 29784, 29788>    <29789, 29797, 29790>,
    <29789, 29790, 29794>    <29789, 29794, 29791>,
    <29789, 29791, 29795>    <29789, 29795, 29792>,
    <29789, 29792, 29796>    <29789, 29796, 29793>,
    <29789, 29793, 29797>    <29798, 29806, 29799>,
    <29798, 29799, 29803>    <29798, 29803, 29800>,
    <29798, 29800, 29804>    <29798, 29804, 29801>,
    <29798, 29801, 29805>    <29798, 29805, 29802>,
    <29798, 29802, 29806>    <29807, 29815, 29808>,
    <29807, 29808, 29812>    <29807, 29812, 29809>,
    <29807, 29809, 29813>    <29807, 29813, 29810>,
    <29807, 29810, 29814>    <29807, 29814, 29811>,
    <29807, 29811, 29815>    <29816, 29824, 29817>,
    <29816, 29817, 29821>    <29816, 29821, 29818>,
    <29816, 29818, 29822>    <29816, 29822, 29819>,
    <29816, 29819, 29823>    <29816, 29823, 29820>,
    <29816, 29820, 29824>    <29825, 29833, 29826>,
    <29825, 29826, 29830>    <29825, 29830, 29827>,
    <29825, 29827, 29831>    <29825, 29831, 29828>,
    <29825, 29828, 29832>    <29825, 29832, 29829>,
    <29825, 29829, 29833>    <29834, 29842, 29835>,
    <29834, 29835, 29839>    <29834, 29839, 29836>,
    <29834, 29836, 29840>    <29834, 29840, 29837>,
    <29834, 29837, 29841>    <29834, 29841, 29838>,
    <29834, 29838, 29842>    <29843, 29851, 29844>,
    <29843, 29844, 29848>    <29843, 29848, 29845>,
    <29843, 29845, 29849>    <29843, 29849, 29846>,
    <29843, 29846, 29850>    <29843, 29850, 29847>,
    <29843, 29847, 29851>    <29852, 29860, 29853>,
    <29852, 29853, 29857>    <29852, 29857, 29854>,
    <29852, 29854, 29858>    <29852, 29858, 29855>,
    <29852, 29855, 29859>    <29852, 29859, 29856>,
    <29852, 29856, 29860>    <29861, 29869, 29862>,
    <29861, 29862, 29866>    <29861, 29866, 29863>,
    <29861, 29863, 29867>    <29861, 29867, 29864>,
    <29861, 29864, 29868>    <29861, 29868, 29865>,
    <29861, 29865, 29869>    <29870, 29878, 29871>,
    <29870, 29871, 29875>    <29870, 29875, 29872>,
    <29870, 29872, 29876>    <29870, 29876, 29873>,
    <29870, 29873, 29877>    <29870, 29877, 29874>,
    <29870, 29874, 29878>    <29879, 29887, 29880>,
    <29879, 29880, 29884>    <29879, 29884, 29881>,
    <29879, 29881, 29885>    <29879, 29885, 29882>,
    <29879, 29882, 29886>    <29879, 29886, 29883>,
    <29879, 29883, 29887>    <29888, 29896, 29889>,
    <29888, 29889, 29893>    <29888, 29893, 29890>,
    <29888, 29890, 29894>    <29888, 29894, 29891>,
    <29888, 29891, 29895>    <29888, 29895, 29892>,
    <29888, 29892, 29896>    <29897, 29905, 29898>,
    <29897, 29898, 29902>    <29897, 29902, 29899>,
    <29897, 29899, 29903>    <29897, 29903, 29900>,
    <29897, 29900, 29904>    <29897, 29904, 29901>,
    <29897, 29901, 29905>    <29906, 29914, 29907>,
    <29906, 29907, 29911>    <29906, 29911, 29908>,
    <29906, 29908, 29912>    <29906, 29912, 29909>,
    <29906, 29909, 29913>    <29906, 29913, 29910>,
    <29906, 29910, 29914>    <29915, 29923, 29916>,
    <29915, 29916, 29920>    <29915, 29920, 29917>,
    <29915, 29917, 29921>    <29915, 29921, 29918>,
    <29915, 29918, 29922>    <29915, 29922, 29919>,
    <29915, 29919, 29923>    <29924, 29932, 29925>,
    <29924, 29925, 29929>    <29924, 29929, 29926>,
    <29924, 29926, 29930>    <29924, 29930, 29927>,
    <29924, 29927, 29931>    <29924, 29931, 29928>,
    <29924, 29928, 29932>    <29933, 29941, 29934>,
    <29933, 29934, 29938>    <29933, 29938, 29935>,
    <29933, 29935, 29939>    <29933, 29939, 29936>,
    <29933, 29936, 29940>    <29933, 29940, 29937>,
    <29933, 29937, 29941>    <29942, 29950, 29943>,
    <29942, 29943, 29947>    <29942, 29947, 29944>,
    <29942, 29944, 29948>    <29942, 29948, 29945>,
    <29942, 29945, 29949>    <29942, 29949, 29946>,
    <29942, 29946, 29950>    <29951, 29959, 29952>,
    <29951, 29952, 29956>    <29951, 29956, 29953>,
    <29951, 29953, 29957>    <29951, 29957, 29954>,
    <29951, 29954, 29958>    <29951, 29958, 29955>,
    <29951, 29955, 29959>    <29960, 29968, 29961>,
    <29960, 29961, 29965>    <29960, 29965, 29962>,
    <29960, 29962, 29966>    <29960, 29966, 29963>,
    <29960, 29963, 29967>    <29960, 29967, 29964>,
    <29960, 29964, 29968>    <29969, 29977, 29970>,
    <29969, 29970, 29974>    <29969, 29974, 29971>,
    <29969, 29971, 29975>    <29969, 29975, 29972>,
    <29969, 29972, 29976>    <29969, 29976, 29973>,
    <29969, 29973, 29977>    <29978, 29986, 29979>,
    <29978, 29979, 29983>    <29978, 29983, 29980>,
    <29978, 29980, 29984>    <29978, 29984, 29981>,
    <29978, 29981, 29985>    <29978, 29985, 29982>,
    <29978, 29982, 29986>    <29987, 29995, 29988>,
    <29987, 29988, 29992>    <29987, 29992, 29989>,
    <29987, 29989, 29993>    <29987, 29993, 29990>,
    <29987, 29990, 29994>    <29987, 29994, 29991>,
    <29987, 29991, 29995>    <29996, 30004, 29997>,
    <29996, 29997, 30001>    <29996, 30001, 29998>,
    <29996, 29998, 30002>    <29996, 30002, 29999>,
    <29996, 29999, 30003>    <29996, 30003, 30000>,
    <29996, 30000, 30004>    <30005, 30013, 30006>,
    <30005, 30006, 30010>    <30005, 30010, 30007>,
    <30005, 30007, 30011>    <30005, 30011, 30008>,
    <30005, 30008, 30012>    <30005, 30012, 30009>,
    <30005, 30009, 30013>    <30014, 30022, 30015>,
    <30014, 30015, 30019>    <30014, 30019, 30016>,
    <30014, 30016, 30020>    <30014, 30020, 30017>,
    <30014, 30017, 30021>    <30014, 30021, 30018>,
    <30014, 30018, 30022>    <30023, 30031, 30024>,
    <30023, 30024, 30028>    <30023, 30028, 30025>,
    <30023, 30025, 30029>    <30023, 30029, 30026>,
    <30023, 30026, 30030>    <30023, 30030, 30027>,
    <30023, 30027, 30031>    <30032, 30040, 30033>,
    <30032, 30033, 30037>    <30032, 30037, 30034>,
    <30032, 30034, 30038>    <30032, 30038, 30035>,
    <30032, 30035, 30039>    <30032, 30039, 30036>,
    <30032, 30036, 30040>    <30041, 30049, 30042>,
    <30041, 30042, 30046>    <30041, 30046, 30043>,
    <30041, 30043, 30047>    <30041, 30047, 30044>,
    <30041, 30044, 30048>    <30041, 30048, 30045>,
    <30041, 30045, 30049>    <30050, 30058, 30051>,
    <30050, 30051, 30055>    <30050, 30055, 30052>,
    <30050, 30052, 30056>    <30050, 30056, 30053>,
    <30050, 30053, 30057>    <30050, 30057, 30054>,
    <30050, 30054, 30058>    <30059, 30067, 30060>,
    <30059, 30060, 30064>    <30059, 30064, 30061>,
    <30059, 30061, 30065>    <30059, 30065, 30062>,
    <30059, 30062, 30066>    <30059, 30066, 30063>,
    <30059, 30063, 30067>    <30068, 30076, 30069>,
    <30068, 30069, 30073>    <30068, 30073, 30070>,
    <30068, 30070, 30074>    <30068, 30074, 30071>,
    <30068, 30071, 30075>    <30068, 30075, 30072>,
    <30068, 30072, 30076>    <30077, 30085, 30078>,
    <30077, 30078, 30082>    <30077, 30082, 30079>,
    <30077, 30079, 30083>    <30077, 30083, 30080>,
    <30077, 30080, 30084>    <30077, 30084, 30081>,
    <30077, 30081, 30085>    <30086, 30094, 30087>,
    <30086, 30087, 30091>    <30086, 30091, 30088>,
    <30086, 30088, 30092>    <30086, 30092, 30089>,
    <30086, 30089, 30093>    <30086, 30093, 30090>,
    <30086, 30090, 30094>    <30095, 30103, 30096>,
    <30095, 30096, 30100>    <30095, 30100, 30097>,
    <30095, 30097, 30101>    <30095, 30101, 30098>,
    <30095, 30098, 30102>    <30095, 30102, 30099>,
    <30095, 30099, 30103>    <30104, 30112, 30105>,
    <30104, 30105, 30109>    <30104, 30109, 30106>,
    <30104, 30106, 30110>    <30104, 30110, 30107>,
    <30104, 30107, 30111>    <30104, 30111, 30108>,
    <30104, 30108, 30112>    <30113, 30121, 30114>,
    <30113, 30114, 30118>    <30113, 30118, 30115>,
    <30113, 30115, 30119>    <30113, 30119, 30116>,
    <30113, 30116, 30120>    <30113, 30120, 30117>,
    <30113, 30117, 30121>    <30122, 30130, 30123>,
    <30122, 30123, 30127>    <30122, 30127, 30124>,
    <30122, 30124, 30128>    <30122, 30128, 30125>,
    <30122, 30125, 30129>    <30122, 30129, 30126>,
    <30122, 30126, 30130>    <30131, 30139, 30132>,
    <30131, 30132, 30136>    <30131, 30136, 30133>,
    <30131, 30133, 30137>    <30131, 30137, 30134>,
    <30131, 30134, 30138>    <30131, 30138, 30135>,
    <30131, 30135, 30139>    <30140, 30148, 30141>,
    <30140, 30141, 30145>    <30140, 30145, 30142>,
    <30140, 30142, 30146>    <30140, 30146, 30143>,
    <30140, 30143, 30147>    <30140, 30147, 30144>,
    <30140, 30144, 30148>    <30149, 30157, 30150>,
    <30149, 30150, 30154>    <30149, 30154, 30151>,
    <30149, 30151, 30155>    <30149, 30155, 30152>,
    <30149, 30152, 30156>    <30149, 30156, 30153>,
    <30149, 30153, 30157>    <30158, 30166, 30159>,
    <30158, 30159, 30163>    <30158, 30163, 30160>,
    <30158, 30160, 30164>    <30158, 30164, 30161>,
    <30158, 30161, 30165>    <30158, 30165, 30162>,
    <30158, 30162, 30166>    <30167, 30175, 30168>,
    <30167, 30168, 30172>    <30167, 30172, 30169>,
    <30167, 30169, 30173>    <30167, 30173, 30170>,
    <30167, 30170, 30174>    <30167, 30174, 30171>,
    <30167, 30171, 30175>    <30176, 30184, 30177>,
    <30176, 30177, 30181>    <30176, 30181, 30178>,
    <30176, 30178, 30182>    <30176, 30182, 30179>,
    <30176, 30179, 30183>    <30176, 30183, 30180>,
    <30176, 30180, 30184>    <30185, 30193, 30186>,
    <30185, 30186, 30190>    <30185, 30190, 30187>,
    <30185, 30187, 30191>    <30185, 30191, 30188>,
    <30185, 30188, 30192>    <30185, 30192, 30189>,
    <30185, 30189, 30193>    <30194, 30202, 30195>,
    <30194, 30195, 30199>    <30194, 30199, 30196>,
    <30194, 30196, 30200>    <30194, 30200, 30197>,
    <30194, 30197, 30201>    <30194, 30201, 30198>,
    <30194, 30198, 30202>    <30203, 30211, 30204>,
    <30203, 30204, 30208>    <30203, 30208, 30205>,
    <30203, 30205, 30209>    <30203, 30209, 30206>,
    <30203, 30206, 30210>    <30203, 30210, 30207>,
    <30203, 30207, 30211>    <30212, 30220, 30213>,
    <30212, 30213, 30217>    <30212, 30217, 30214>,
    <30212, 30214, 30218>    <30212, 30218, 30215>,
    <30212, 30215, 30219>    <30212, 30219, 30216>,
    <30212, 30216, 30220>    <30221, 30229, 30222>,
    <30221, 30222, 30226>    <30221, 30226, 30223>,
    <30221, 30223, 30227>    <30221, 30227, 30224>,
    <30221, 30224, 30228>    <30221, 30228, 30225>,
    <30221, 30225, 30229>    <30230, 30238, 30231>,
    <30230, 30231, 30235>    <30230, 30235, 30232>,
    <30230, 30232, 30236>    <30230, 30236, 30233>,
    <30230, 30233, 30237>    <30230, 30237, 30234>,
    <30230, 30234, 30238>    <30239, 30247, 30240>,
    <30239, 30240, 30244>    <30239, 30244, 30241>,
    <30239, 30241, 30245>    <30239, 30245, 30242>,
    <30239, 30242, 30246>    <30239, 30246, 30243>,
    <30239, 30243, 30247>    <30248, 30256, 30249>,
    <30248, 30249, 30253>    <30248, 30253, 30250>,
    <30248, 30250, 30254>    <30248, 30254, 30251>,
    <30248, 30251, 30255>    <30248, 30255, 30252>,
    <30248, 30252, 30256>    <30257, 30265, 30258>,
    <30257, 30258, 30262>    <30257, 30262, 30259>,
    <30257, 30259, 30263>    <30257, 30263, 30260>,
    <30257, 30260, 30264>    <30257, 30264, 30261>,
    <30257, 30261, 30265>    <30266, 30274, 30267>,
    <30266, 30267, 30271>    <30266, 30271, 30268>,
    <30266, 30268, 30272>    <30266, 30272, 30269>,
    <30266, 30269, 30273>    <30266, 30273, 30270>,
    <30266, 30270, 30274>    <30275, 30283, 30276>,
    <30275, 30276, 30280>    <30275, 30280, 30277>,
    <30275, 30277, 30281>    <30275, 30281, 30278>,
    <30275, 30278, 30282>    <30275, 30282, 30279>,
    <30275, 30279, 30283>    <30284, 30292, 30285>,
    <30284, 30285, 30289>    <30284, 30289, 30286>,
    <30284, 30286, 30290>    <30284, 30290, 30287>,
    <30284, 30287, 30291>    <30284, 30291, 30288>,
    <30284, 30288, 30292>    <30293, 30301, 30294>,
    <30293, 30294, 30298>    <30293, 30298, 30295>,
    <30293, 30295, 30299>    <30293, 30299, 30296>,
    <30293, 30296, 30300>    <30293, 30300, 30297>,
    <30293, 30297, 30301>    <30302, 30310, 30303>,
    <30302, 30303, 30307>    <30302, 30307, 30304>,
    <30302, 30304, 30308>    <30302, 30308, 30305>,
    <30302, 30305, 30309>    <30302, 30309, 30306>,
    <30302, 30306, 30310>    <30311, 30319, 30312>,
    <30311, 30312, 30316>    <30311, 30316, 30313>,
    <30311, 30313, 30317>    <30311, 30317, 30314>,
    <30311, 30314, 30318>    <30311, 30318, 30315>,
    <30311, 30315, 30319>    <30320, 30328, 30321>,
    <30320, 30321, 30325>    <30320, 30325, 30322>,
    <30320, 30322, 30326>    <30320, 30326, 30323>,
    <30320, 30323, 30327>    <30320, 30327, 30324>,
    <30320, 30324, 30328>    <30329, 30337, 30330>,
    <30329, 30330, 30334>    <30329, 30334, 30331>,
    <30329, 30331, 30335>    <30329, 30335, 30332>,
    <30329, 30332, 30336>    <30329, 30336, 30333>,
    <30329, 30333, 30337>    <30338, 30346, 30339>,
    <30338, 30339, 30343>    <30338, 30343, 30340>,
    <30338, 30340, 30344>    <30338, 30344, 30341>,
    <30338, 30341, 30345>    <30338, 30345, 30342>,
    <30338, 30342, 30346>    <30347, 30355, 30348>,
    <30347, 30348, 30352>    <30347, 30352, 30349>,
    <30347, 30349, 30353>    <30347, 30353, 30350>,
    <30347, 30350, 30354>    <30347, 30354, 30351>,
    <30347, 30351, 30355>    <30356, 30364, 30357>,
    <30356, 30357, 30361>    <30356, 30361, 30358>,
    <30356, 30358, 30362>    <30356, 30362, 30359>,
    <30356, 30359, 30363>    <30356, 30363, 30360>,
    <30356, 30360, 30364>    <30365, 30373, 30366>,
    <30365, 30366, 30370>    <30365, 30370, 30367>,
    <30365, 30367, 30371>    <30365, 30371, 30368>,
    <30365, 30368, 30372>    <30365, 30372, 30369>,
    <30365, 30369, 30373>    <30374, 30382, 30375>,
    <30374, 30375, 30379>    <30374, 30379, 30376>,
    <30374, 30376, 30380>    <30374, 30380, 30377>,
    <30374, 30377, 30381>    <30374, 30381, 30378>,
    <30374, 30378, 30382>    <30383, 30391, 30384>,
    <30383, 30384, 30388>    <30383, 30388, 30385>,
    <30383, 30385, 30389>    <30383, 30389, 30386>,
    <30383, 30386, 30390>    <30383, 30390, 30387>,
    <30383, 30387, 30391>    <30392, 30400, 30393>,
    <30392, 30393, 30397>    <30392, 30397, 30394>,
    <30392, 30394, 30398>    <30392, 30398, 30395>,
    <30392, 30395, 30399>    <30392, 30399, 30396>,
    <30392, 30396, 30400>    <30401, 30409, 30402>,
    <30401, 30402, 30406>    <30401, 30406, 30403>,
    <30401, 30403, 30407>    <30401, 30407, 30404>,
    <30401, 30404, 30408>    <30401, 30408, 30405>,
    <30401, 30405, 30409>    <30410, 30418, 30411>,
    <30410, 30411, 30415>    <30410, 30415, 30412>,
    <30410, 30412, 30416>    <30410, 30416, 30413>,
    <30410, 30413, 30417>    <30410, 30417, 30414>,
    <30410, 30414, 30418>    <30419, 30427, 30420>,
    <30419, 30420, 30424>    <30419, 30424, 30421>,
    <30419, 30421, 30425>    <30419, 30425, 30422>,
    <30419, 30422, 30426>    <30419, 30426, 30423>,
    <30419, 30423, 30427>    <30428, 30436, 30429>,
    <30428, 30429, 30433>    <30428, 30433, 30430>,
    <30428, 30430, 30434>    <30428, 30434, 30431>,
    <30428, 30431, 30435>    <30428, 30435, 30432>,
    <30428, 30432, 30436>    <30437, 30445, 30438>,
    <30437, 30438, 30442>    <30437, 30442, 30439>,
    <30437, 30439, 30443>    <30437, 30443, 30440>,
    <30437, 30440, 30444>    <30437, 30444, 30441>,
    <30437, 30441, 30445>    <30446, 30454, 30447>,
    <30446, 30447, 30451>    <30446, 30451, 30448>,
    <30446, 30448, 30452>    <30446, 30452, 30449>,
    <30446, 30449, 30453>    <30446, 30453, 30450>,
    <30446, 30450, 30454>    <30455, 30463, 30456>,
    <30455, 30456, 30460>    <30455, 30460, 30457>,
    <30455, 30457, 30461>    <30455, 30461, 30458>,
    <30455, 30458, 30462>    <30455, 30462, 30459>,
    <30455, 30459, 30463>    <30464, 30472, 30465>,
    <30464, 30465, 30469>    <30464, 30469, 30466>,
    <30464, 30466, 30470>    <30464, 30470, 30467>,
    <30464, 30467, 30471>    <30464, 30471, 30468>,
    <30464, 30468, 30472>    <30473, 30481, 30474>,
    <30473, 30474, 30478>    <30473, 30478, 30475>,
    <30473, 30475, 30479>    <30473, 30479, 30476>,
    <30473, 30476, 30480>    <30473, 30480, 30477>,
    <30473, 30477, 30481>    <30482, 30490, 30483>,
    <30482, 30483, 30487>    <30482, 30487, 30484>,
    <30482, 30484, 30488>    <30482, 30488, 30485>,
    <30482, 30485, 30489>    <30482, 30489, 30486>,
    <30482, 30486, 30490>    <30491, 30499, 30492>,
    <30491, 30492, 30496>    <30491, 30496, 30493>,
    <30491, 30493, 30497>    <30491, 30497, 30494>,
    <30491, 30494, 30498>    <30491, 30498, 30495>,
    <30491, 30495, 30499>    <30500, 30508, 30501>,
    <30500, 30501, 30505>    <30500, 30505, 30502>,
    <30500, 30502, 30506>    <30500, 30506, 30503>,
    <30500, 30503, 30507>    <30500, 30507, 30504>,
    <30500, 30504, 30508>    <30509, 30517, 30510>,
    <30509, 30510, 30514>    <30509, 30514, 30511>,
    <30509, 30511, 30515>    <30509, 30515, 30512>,
    <30509, 30512, 30516>    <30509, 30516, 30513>,
    <30509, 30513, 30517>    <30518, 30526, 30519>,
    <30518, 30519, 30523>    <30518, 30523, 30520>,
    <30518, 30520, 30524>    <30518, 30524, 30521>,
    <30518, 30521, 30525>    <30518, 30525, 30522>,
    <30518, 30522, 30526>    <30527, 30535, 30528>,
    <30527, 30528, 30532>    <30527, 30532, 30529>,
    <30527, 30529, 30533>    <30527, 30533, 30530>,
    <30527, 30530, 30534>    <30527, 30534, 30531>,
    <30527, 30531, 30535>    <30536, 30544, 30537>,
    <30536, 30537, 30541>    <30536, 30541, 30538>,
    <30536, 30538, 30542>    <30536, 30542, 30539>,
    <30536, 30539, 30543>    <30536, 30543, 30540>,
    <30536, 30540, 30544>    <30545, 30553, 30546>,
    <30545, 30546, 30550>    <30545, 30550, 30547>,
    <30545, 30547, 30551>    <30545, 30551, 30548>,
    <30545, 30548, 30552>    <30545, 30552, 30549>,
    <30545, 30549, 30553>    <30554, 30562, 30555>,
    <30554, 30555, 30559>    <30554, 30559, 30556>,
    <30554, 30556, 30560>    <30554, 30560, 30557>,
    <30554, 30557, 30561>    <30554, 30561, 30558>,
    <30554, 30558, 30562>    <30563, 30571, 30564>,
    <30563, 30564, 30568>    <30563, 30568, 30565>,
    <30563, 30565, 30569>    <30563, 30569, 30566>,
    <30563, 30566, 30570>    <30563, 30570, 30567>,
    <30563, 30567, 30571>    <30572, 30580, 30573>,
    <30572, 30573, 30577>    <30572, 30577, 30574>,
    <30572, 30574, 30578>    <30572, 30578, 30575>,
    <30572, 30575, 30579>    <30572, 30579, 30576>,
    <30572, 30576, 30580>    <30581, 30589, 30582>,
    <30581, 30582, 30586>    <30581, 30586, 30583>,
    <30581, 30583, 30587>    <30581, 30587, 30584>,
    <30581, 30584, 30588>    <30581, 30588, 30585>,
    <30581, 30585, 30589>    <30590, 30598, 30591>,
    <30590, 30591, 30595>    <30590, 30595, 30592>,
    <30590, 30592, 30596>    <30590, 30596, 30593>,
    <30590, 30593, 30597>    <30590, 30597, 30594>,
    <30590, 30594, 30598>    <30599, 30607, 30600>,
    <30599, 30600, 30604>    <30599, 30604, 30601>,
    <30599, 30601, 30605>    <30599, 30605, 30602>,
    <30599, 30602, 30606>    <30599, 30606, 30603>,
    <30599, 30603, 30607>    <30608, 30616, 30609>,
    <30608, 30609, 30613>    <30608, 30613, 30610>,
    <30608, 30610, 30614>    <30608, 30614, 30611>,
    <30608, 30611, 30615>    <30608, 30615, 30612>,
    <30608, 30612, 30616>    <30617, 30625, 30618>,
    <30617, 30618, 30622>    <30617, 30622, 30619>,
    <30617, 30619, 30623>    <30617, 30623, 30620>,
    <30617, 30620, 30624>    <30617, 30624, 30621>,
    <30617, 30621, 30625>    <30626, 30634, 30627>,
    <30626, 30627, 30631>    <30626, 30631, 30628>,
    <30626, 30628, 30632>    <30626, 30632, 30629>,
    <30626, 30629, 30633>    <30626, 30633, 30630>,
    <30626, 30630, 30634>    <30635, 30643, 30636>,
    <30635, 30636, 30640>    <30635, 30640, 30637>,
    <30635, 30637, 30641>    <30635, 30641, 30638>,
    <30635, 30638, 30642>    <30635, 30642, 30639>,
    <30635, 30639, 30643>    <30644, 30652, 30645>,
    <30644, 30645, 30649>    <30644, 30649, 30646>,
    <30644, 30646, 30650>    <30644, 30650, 30647>,
    <30644, 30647, 30651>    <30644, 30651, 30648>,
    <30644, 30648, 30652>    <30653, 30661, 30654>,
    <30653, 30654, 30658>    <30653, 30658, 30655>,
    <30653, 30655, 30659>    <30653, 30659, 30656>,
    <30653, 30656, 30660>    <30653, 30660, 30657>,
    <30653, 30657, 30661>    <30662, 30670, 30663>,
    <30662, 30663, 30667>    <30662, 30667, 30664>,
    <30662, 30664, 30668>    <30662, 30668, 30665>,
    <30662, 30665, 30669>    <30662, 30669, 30666>,
    <30662, 30666, 30670>    <30671, 30679, 30672>,
    <30671, 30672, 30676>    <30671, 30676, 30673>,
    <30671, 30673, 30677>    <30671, 30677, 30674>,
    <30671, 30674, 30678>    <30671, 30678, 30675>,
    <30671, 30675, 30679>    <30680, 30688, 30681>,
    <30680, 30681, 30685>    <30680, 30685, 30682>,
    <30680, 30682, 30686>    <30680, 30686, 30683>,
    <30680, 30683, 30687>    <30680, 30687, 30684>,
    <30680, 30684, 30688>    <30689, 30697, 30690>,
    <30689, 30690, 30694>    <30689, 30694, 30691>,
    <30689, 30691, 30695>    <30689, 30695, 30692>,
    <30689, 30692, 30696>    <30689, 30696, 30693>,
    <30689, 30693, 30697>    <30698, 30706, 30699>,
    <30698, 30699, 30703>    <30698, 30703, 30700>,
    <30698, 30700, 30704>    <30698, 30704, 30701>,
    <30698, 30701, 30705>    <30698, 30705, 30702>,
    <30698, 30702, 30706>    <30707, 30715, 30708>,
    <30707, 30708, 30712>    <30707, 30712, 30709>,
    <30707, 30709, 30713>    <30707, 30713, 30710>,
    <30707, 30710, 30714>    <30707, 30714, 30711>,
    <30707, 30711, 30715>    <30716, 30724, 30717>,
    <30716, 30717, 30721>    <30716, 30721, 30718>,
    <30716, 30718, 30722>    <30716, 30722, 30719>,
    <30716, 30719, 30723>    <30716, 30723, 30720>,
    <30716, 30720, 30724>    <30725, 30733, 30726>,
    <30725, 30726, 30730>    <30725, 30730, 30727>,
    <30725, 30727, 30731>    <30725, 30731, 30728>,
    <30725, 30728, 30732>    <30725, 30732, 30729>,
    <30725, 30729, 30733>    <30734, 30742, 30735>,
    <30734, 30735, 30739>    <30734, 30739, 30736>,
    <30734, 30736, 30740>    <30734, 30740, 30737>,
    <30734, 30737, 30741>    <30734, 30741, 30738>,
    <30734, 30738, 30742>    <30743, 30751, 30744>,
    <30743, 30744, 30748>    <30743, 30748, 30745>,
    <30743, 30745, 30749>    <30743, 30749, 30746>,
    <30743, 30746, 30750>    <30743, 30750, 30747>,
    <30743, 30747, 30751>    <30752, 30760, 30753>,
    <30752, 30753, 30757>    <30752, 30757, 30754>,
    <30752, 30754, 30758>    <30752, 30758, 30755>,
    <30752, 30755, 30759>    <30752, 30759, 30756>,
    <30752, 30756, 30760>    <30761, 30769, 30762>,
    <30761, 30762, 30766>    <30761, 30766, 30763>,
    <30761, 30763, 30767>    <30761, 30767, 30764>,
    <30761, 30764, 30768>    <30761, 30768, 30765>,
    <30761, 30765, 30769>    <30770, 30778, 30771>,
    <30770, 30771, 30775>    <30770, 30775, 30772>,
    <30770, 30772, 30776>    <30770, 30776, 30773>,
    <30770, 30773, 30777>    <30770, 30777, 30774>,
    <30770, 30774, 30778>    <30779, 30787, 30780>,
    <30779, 30780, 30784>    <30779, 30784, 30781>,
    <30779, 30781, 30785>    <30779, 30785, 30782>,
    <30779, 30782, 30786>    <30779, 30786, 30783>,
    <30779, 30783, 30787>    <30788, 30796, 30789>,
    <30788, 30789, 30793>    <30788, 30793, 30790>,
    <30788, 30790, 30794>    <30788, 30794, 30791>,
    <30788, 30791, 30795>    <30788, 30795, 30792>,
    <30788, 30792, 30796>    <30797, 30805, 30798>,
    <30797, 30798, 30802>    <30797, 30802, 30799>,
    <30797, 30799, 30803>    <30797, 30803, 30800>,
    <30797, 30800, 30804>    <30797, 30804, 30801>,
    <30797, 30801, 30805>    <30806, 30814, 30807>,
    <30806, 30807, 30811>    <30806, 30811, 30808>,
    <30806, 30808, 30812>    <30806, 30812, 30809>,
    <30806, 30809, 30813>    <30806, 30813, 30810>,
    <30806, 30810, 30814>    <30815, 30823, 30816>,
    <30815, 30816, 30820>    <30815, 30820, 30817>,
    <30815, 30817, 30821>    <30815, 30821, 30818>,
    <30815, 30818, 30822>    <30815, 30822, 30819>,
    <30815, 30819, 30823>    <30824, 30832, 30825>,
    <30824, 30825, 30829>    <30824, 30829, 30826>,
    <30824, 30826, 30830>    <30824, 30830, 30827>,
    <30824, 30827, 30831>    <30824, 30831, 30828>,
    <30824, 30828, 30832>    <30833, 30841, 30834>,
    <30833, 30834, 30838>    <30833, 30838, 30835>,
    <30833, 30835, 30839>    <30833, 30839, 30836>,
    <30833, 30836, 30840>    <30833, 30840, 30837>,
    <30833, 30837, 30841>    <30842, 30850, 30843>,
    <30842, 30843, 30847>    <30842, 30847, 30844>,
    <30842, 30844, 30848>    <30842, 30848, 30845>,
    <30842, 30845, 30849>    <30842, 30849, 30846>,
    <30842, 30846, 30850>    <30851, 30859, 30852>,
    <30851, 30852, 30856>    <30851, 30856, 30853>,
    <30851, 30853, 30857>    <30851, 30857, 30854>,
    <30851, 30854, 30858>    <30851, 30858, 30855>,
    <30851, 30855, 30859>    <30860, 30868, 30861>,
    <30860, 30861, 30865>    <30860, 30865, 30862>,
    <30860, 30862, 30866>    <30860, 30866, 30863>,
    <30860, 30863, 30867>    <30860, 30867, 30864>,
    <30860, 30864, 30868>    <30869, 30877, 30870>,
    <30869, 30870, 30874>    <30869, 30874, 30871>,
    <30869, 30871, 30875>    <30869, 30875, 30872>,
    <30869, 30872, 30876>    <30869, 30876, 30873>,
    <30869, 30873, 30877>    <30878, 30886, 30879>,
    <30878, 30879, 30883>    <30878, 30883, 30880>,
    <30878, 30880, 30884>    <30878, 30884, 30881>,
    <30878, 30881, 30885>    <30878, 30885, 30882>,
    <30878, 30882, 30886>    <30887, 30895, 30888>,
    <30887, 30888, 30892>    <30887, 30892, 30889>,
    <30887, 30889, 30893>    <30887, 30893, 30890>,
    <30887, 30890, 30894>    <30887, 30894, 30891>,
    <30887, 30891, 30895>    <30896, 30904, 30897>,
    <30896, 30897, 30901>    <30896, 30901, 30898>,
    <30896, 30898, 30902>    <30896, 30902, 30899>,
    <30896, 30899, 30903>    <30896, 30903, 30900>,
    <30896, 30900, 30904>    <30905, 30913, 30906>,
    <30905, 30906, 30910>    <30905, 30910, 30907>,
    <30905, 30907, 30911>    <30905, 30911, 30908>,
    <30905, 30908, 30912>    <30905, 30912, 30909>,
    <30905, 30909, 30913>    <30914, 30922, 30915>,
    <30914, 30915, 30919>    <30914, 30919, 30916>,
    <30914, 30916, 30920>    <30914, 30920, 30917>,
    <30914, 30917, 30921>    <30914, 30921, 30918>,
    <30914, 30918, 30922>    <30923, 30931, 30924>,
    <30923, 30924, 30928>    <30923, 30928, 30925>,
    <30923, 30925, 30929>    <30923, 30929, 30926>,
    <30923, 30926, 30930>    <30923, 30930, 30927>,
    <30923, 30927, 30931>    <30932, 30940, 30933>,
    <30932, 30933, 30937>    <30932, 30937, 30934>,
    <30932, 30934, 30938>    <30932, 30938, 30935>,
    <30932, 30935, 30939>    <30932, 30939, 30936>,
    <30932, 30936, 30940>    <30941, 30949, 30942>,
    <30941, 30942, 30946>    <30941, 30946, 30943>,
    <30941, 30943, 30947>    <30941, 30947, 30944>,
    <30941, 30944, 30948>    <30941, 30948, 30945>,
    <30941, 30945, 30949>    <30950, 30958, 30951>,
    <30950, 30951, 30955>    <30950, 30955, 30952>,
    <30950, 30952, 30956>    <30950, 30956, 30953>,
    <30950, 30953, 30957>    <30950, 30957, 30954>,
    <30950, 30954, 30958>    <30959, 30967, 30960>,
    <30959, 30960, 30964>    <30959, 30964, 30961>,
    <30959, 30961, 30965>    <30959, 30965, 30962>,
    <30959, 30962, 30966>    <30959, 30966, 30963>,
    <30959, 30963, 30967>    <30968, 30976, 30969>,
    <30968, 30969, 30973>    <30968, 30973, 30970>,
    <30968, 30970, 30974>    <30968, 30974, 30971>,
    <30968, 30971, 30975>    <30968, 30975, 30972>,
    <30968, 30972, 30976>    <30977, 30985, 30978>,
    <30977, 30978, 30982>    <30977, 30982, 30979>,
    <30977, 30979, 30983>    <30977, 30983, 30980>,
    <30977, 30980, 30984>    <30977, 30984, 30981>,
    <30977, 30981, 30985>    <30986, 30994, 30987>,
    <30986, 30987, 30991>    <30986, 30991, 30988>,
    <30986, 30988, 30992>    <30986, 30992, 30989>,
    <30986, 30989, 30993>    <30986, 30993, 30990>,
    <30986, 30990, 30994>    <30995, 31003, 30996>,
    <30995, 30996, 31000>    <30995, 31000, 30997>,
    <30995, 30997, 31001>    <30995, 31001, 30998>,
    <30995, 30998, 31002>    <30995, 31002, 30999>,
    <30995, 30999, 31003>    <31004, 31012, 31005>,
    <31004, 31005, 31009>    <31004, 31009, 31006>,
    <31004, 31006, 31010>    <31004, 31010, 31007>,
    <31004, 31007, 31011>    <31004, 31011, 31008>,
    <31004, 31008, 31012>    <31013, 31021, 31014>,
    <31013, 31014, 31018>    <31013, 31018, 31015>,
    <31013, 31015, 31019>    <31013, 31019, 31016>,
    <31013, 31016, 31020>    <31013, 31020, 31017>,
    <31013, 31017, 31021>    <31022, 31030, 31023>,
    <31022, 31023, 31027>    <31022, 31027, 31024>,
    <31022, 31024, 31028>    <31022, 31028, 31025>,
    <31022, 31025, 31029>    <31022, 31029, 31026>,
    <31022, 31026, 31030>    <31031, 31039, 31032>,
    <31031, 31032, 31036>    <31031, 31036, 31033>,
    <31031, 31033, 31037>    <31031, 31037, 31034>,
    <31031, 31034, 31038>    <31031, 31038, 31035>,
    <31031, 31035, 31039>    <31040, 31048, 31041>,
    <31040, 31041, 31045>    <31040, 31045, 31042>,
    <31040, 31042, 31046>    <31040, 31046, 31043>,
    <31040, 31043, 31047>    <31040, 31047, 31044>,
    <31040, 31044, 31048>    <31049, 31057, 31050>,
    <31049, 31050, 31054>    <31049, 31054, 31051>,
    <31049, 31051, 31055>    <31049, 31055, 31052>,
    <31049, 31052, 31056>    <31049, 31056, 31053>,
    <31049, 31053, 31057>    <31058, 31066, 31059>,
    <31058, 31059, 31063>    <31058, 31063, 31060>,
    <31058, 31060, 31064>    <31058, 31064, 31061>,
    <31058, 31061, 31065>    <31058, 31065, 31062>,
    <31058, 31062, 31066>    <31067, 31075, 31068>,
    <31067, 31068, 31072>    <31067, 31072, 31069>,
    <31067, 31069, 31073>    <31067, 31073, 31070>,
    <31067, 31070, 31074>    <31067, 31074, 31071>,
    <31067, 31071, 31075>    <31076, 31084, 31077>,
    <31076, 31077, 31081>    <31076, 31081, 31078>,
    <31076, 31078, 31082>    <31076, 31082, 31079>,
    <31076, 31079, 31083>    <31076, 31083, 31080>,
    <31076, 31080, 31084>    <31085, 31093, 31086>,
    <31085, 31086, 31090>    <31085, 31090, 31087>,
    <31085, 31087, 31091>    <31085, 31091, 31088>,
    <31085, 31088, 31092>    <31085, 31092, 31089>,
    <31085, 31089, 31093>    <31094, 31102, 31095>,
    <31094, 31095, 31099>    <31094, 31099, 31096>,
    <31094, 31096, 31100>    <31094, 31100, 31097>,
    <31094, 31097, 31101>    <31094, 31101, 31098>,
    <31094, 31098, 31102>    <31103, 31111, 31104>,
    <31103, 31104, 31108>    <31103, 31108, 31105>,
    <31103, 31105, 31109>    <31103, 31109, 31106>,
    <31103, 31106, 31110>    <31103, 31110, 31107>,
    <31103, 31107, 31111>    <31112, 31120, 31113>,
    <31112, 31113, 31117>    <31112, 31117, 31114>,
    <31112, 31114, 31118>    <31112, 31118, 31115>,
    <31112, 31115, 31119>    <31112, 31119, 31116>,
    <31112, 31116, 31120>    <31121, 31129, 31122>,
    <31121, 31122, 31126>    <31121, 31126, 31123>,
    <31121, 31123, 31127>    <31121, 31127, 31124>,
    <31121, 31124, 31128>    <31121, 31128, 31125>,
    <31121, 31125, 31129>    <31130, 31138, 31131>,
    <31130, 31131, 31135>    <31130, 31135, 31132>,
    <31130, 31132, 31136>    <31130, 31136, 31133>,
    <31130, 31133, 31137>    <31130, 31137, 31134>,
    <31130, 31134, 31138>    <31139, 31147, 31140>,
    <31139, 31140, 31144>    <31139, 31144, 31141>,
    <31139, 31141, 31145>    <31139, 31145, 31142>,
    <31139, 31142, 31146>    <31139, 31146, 31143>,
    <31139, 31143, 31147>    <31148, 31156, 31149>,
    <31148, 31149, 31153>    <31148, 31153, 31150>,
    <31148, 31150, 31154>    <31148, 31154, 31151>,
    <31148, 31151, 31155>    <31148, 31155, 31152>,
    <31148, 31152, 31156>    <31157, 31165, 31158>,
    <31157, 31158, 31162>    <31157, 31162, 31159>,
    <31157, 31159, 31163>    <31157, 31163, 31160>,
    <31157, 31160, 31164>    <31157, 31164, 31161>,
    <31157, 31161, 31165>    <31166, 31174, 31167>,
    <31166, 31167, 31171>    <31166, 31171, 31168>,
    <31166, 31168, 31172>    <31166, 31172, 31169>,
    <31166, 31169, 31173>    <31166, 31173, 31170>,
    <31166, 31170, 31174>    <31175, 31183, 31176>,
    <31175, 31176, 31180>    <31175, 31180, 31177>,
    <31175, 31177, 31181>    <31175, 31181, 31178>,
    <31175, 31178, 31182>    <31175, 31182, 31179>,
    <31175, 31179, 31183>    <31184, 31192, 31185>,
    <31184, 31185, 31189>    <31184, 31189, 31186>,
    <31184, 31186, 31190>    <31184, 31190, 31187>,
    <31184, 31187, 31191>    <31184, 31191, 31188>,
    <31184, 31188, 31192>    <31193, 31201, 31194>,
    <31193, 31194, 31198>    <31193, 31198, 31195>,
    <31193, 31195, 31199>    <31193, 31199, 31196>,
    <31193, 31196, 31200>    <31193, 31200, 31197>,
    <31193, 31197, 31201>    <31202, 31210, 31203>,
    <31202, 31203, 31207>    <31202, 31207, 31204>,
    <31202, 31204, 31208>    <31202, 31208, 31205>,
    <31202, 31205, 31209>    <31202, 31209, 31206>,
    <31202, 31206, 31210>    <31211, 31219, 31212>,
    <31211, 31212, 31216>    <31211, 31216, 31213>,
    <31211, 31213, 31217>    <31211, 31217, 31214>,
    <31211, 31214, 31218>    <31211, 31218, 31215>,
    <31211, 31215, 31219>    <31220, 31228, 31221>,
    <31220, 31221, 31225>    <31220, 31225, 31222>,
    <31220, 31222, 31226>    <31220, 31226, 31223>,
    <31220, 31223, 31227>    <31220, 31227, 31224>,
    <31220, 31224, 31228>    <31229, 31237, 31230>,
    <31229, 31230, 31234>    <31229, 31234, 31231>,
    <31229, 31231, 31235>    <31229, 31235, 31232>,
    <31229, 31232, 31236>    <31229, 31236, 31233>,
    <31229, 31233, 31237>    <31238, 31246, 31239>,
    <31238, 31239, 31243>    <31238, 31243, 31240>,
    <31238, 31240, 31244>    <31238, 31244, 31241>,
    <31238, 31241, 31245>    <31238, 31245, 31242>,
    <31238, 31242, 31246>    <31247, 31255, 31248>,
    <31247, 31248, 31252>    <31247, 31252, 31249>,
    <31247, 31249, 31253>    <31247, 31253, 31250>,
    <31247, 31250, 31254>    <31247, 31254, 31251>,
    <31247, 31251, 31255>    <31256, 31264, 31257>,
    <31256, 31257, 31261>    <31256, 31261, 31258>,
    <31256, 31258, 31262>    <31256, 31262, 31259>,
    <31256, 31259, 31263>    <31256, 31263, 31260>,
    <31256, 31260, 31264>    <31265, 31273, 31266>,
    <31265, 31266, 31270>    <31265, 31270, 31267>,
    <31265, 31267, 31271>    <31265, 31271, 31268>,
    <31265, 31268, 31272>    <31265, 31272, 31269>,
    <31265, 31269, 31273>    <31274, 31282, 31275>,
    <31274, 31275, 31279>    <31274, 31279, 31276>,
    <31274, 31276, 31280>    <31274, 31280, 31277>,
    <31274, 31277, 31281>    <31274, 31281, 31278>,
    <31274, 31278, 31282>    <31283, 31291, 31284>,
    <31283, 31284, 31288>    <31283, 31288, 31285>,
    <31283, 31285, 31289>    <31283, 31289, 31286>,
    <31283, 31286, 31290>    <31283, 31290, 31287>,
    <31283, 31287, 31291>    <31292, 31300, 31293>,
    <31292, 31293, 31297>    <31292, 31297, 31294>,
    <31292, 31294, 31298>    <31292, 31298, 31295>,
    <31292, 31295, 31299>    <31292, 31299, 31296>,
    <31292, 31296, 31300>    <31301, 31309, 31302>,
    <31301, 31302, 31306>    <31301, 31306, 31303>,
    <31301, 31303, 31307>    <31301, 31307, 31304>,
    <31301, 31304, 31308>    <31301, 31308, 31305>,
    <31301, 31305, 31309>    <31310, 31318, 31311>,
    <31310, 31311, 31315>    <31310, 31315, 31312>,
    <31310, 31312, 31316>    <31310, 31316, 31313>,
    <31310, 31313, 31317>    <31310, 31317, 31314>,
    <31310, 31314, 31318>    <31319, 31327, 31320>,
    <31319, 31320, 31324>    <31319, 31324, 31321>,
    <31319, 31321, 31325>    <31319, 31325, 31322>,
    <31319, 31322, 31326>    <31319, 31326, 31323>,
    <31319, 31323, 31327>    <31328, 31336, 31329>,
    <31328, 31329, 31333>    <31328, 31333, 31330>,
    <31328, 31330, 31334>    <31328, 31334, 31331>,
    <31328, 31331, 31335>    <31328, 31335, 31332>,
    <31328, 31332, 31336>    <31337, 31345, 31338>,
    <31337, 31338, 31342>    <31337, 31342, 31339>,
    <31337, 31339, 31343>    <31337, 31343, 31340>,
    <31337, 31340, 31344>    <31337, 31344, 31341>,
    <31337, 31341, 31345>    <31346, 31354, 31347>,
    <31346, 31347, 31351>    <31346, 31351, 31348>,
    <31346, 31348, 31352>    <31346, 31352, 31349>,
    <31346, 31349, 31353>    <31346, 31353, 31350>,
    <31346, 31350, 31354>    <31355, 31363, 31356>,
    <31355, 31356, 31360>    <31355, 31360, 31357>,
    <31355, 31357, 31361>    <31355, 31361, 31358>,
    <31355, 31358, 31362>    <31355, 31362, 31359>,
    <31355, 31359, 31363>    <31364, 31372, 31365>,
    <31364, 31365, 31369>    <31364, 31369, 31366>,
    <31364, 31366, 31370>    <31364, 31370, 31367>,
    <31364, 31367, 31371>    <31364, 31371, 31368>,
    <31364, 31368, 31372>    <31373, 31381, 31374>,
    <31373, 31374, 31378>    <31373, 31378, 31375>,
    <31373, 31375, 31379>    <31373, 31379, 31376>,
    <31373, 31376, 31380>    <31373, 31380, 31377>,
    <31373, 31377, 31381>    <31382, 31390, 31383>,
    <31382, 31383, 31387>    <31382, 31387, 31384>,
    <31382, 31384, 31388>    <31382, 31388, 31385>,
    <31382, 31385, 31389>    <31382, 31389, 31386>,
    <31382, 31386, 31390>    <31391, 31399, 31392>,
    <31391, 31392, 31396>    <31391, 31396, 31393>,
    <31391, 31393, 31397>    <31391, 31397, 31394>,
    <31391, 31394, 31398>    <31391, 31398, 31395>,
    <31391, 31395, 31399>    <31400, 31408, 31401>,
    <31400, 31401, 31405>    <31400, 31405, 31402>,
    <31400, 31402, 31406>    <31400, 31406, 31403>,
    <31400, 31403, 31407>    <31400, 31407, 31404>,
    <31400, 31404, 31408>    <31409, 31417, 31410>,
    <31409, 31410, 31414>    <31409, 31414, 31411>,
    <31409, 31411, 31415>    <31409, 31415, 31412>,
    <31409, 31412, 31416>    <31409, 31416, 31413>,
    <31409, 31413, 31417>    <31418, 31426, 31419>,
    <31418, 31419, 31423>    <31418, 31423, 31420>,
    <31418, 31420, 31424>    <31418, 31424, 31421>,
    <31418, 31421, 31425>    <31418, 31425, 31422>,
    <31418, 31422, 31426>    <31427, 31435, 31428>,
    <31427, 31428, 31432>    <31427, 31432, 31429>,
    <31427, 31429, 31433>    <31427, 31433, 31430>,
    <31427, 31430, 31434>    <31427, 31434, 31431>,
    <31427, 31431, 31435>    <31436, 31444, 31437>,
    <31436, 31437, 31441>    <31436, 31441, 31438>,
    <31436, 31438, 31442>    <31436, 31442, 31439>,
    <31436, 31439, 31443>    <31436, 31443, 31440>,
    <31436, 31440, 31444>    <31445, 31453, 31446>,
    <31445, 31446, 31450>    <31445, 31450, 31447>,
    <31445, 31447, 31451>    <31445, 31451, 31448>,
    <31445, 31448, 31452>    <31445, 31452, 31449>,
    <31445, 31449, 31453>    <31454, 31462, 31455>,
    <31454, 31455, 31459>    <31454, 31459, 31456>,
    <31454, 31456, 31460>    <31454, 31460, 31457>,
    <31454, 31457, 31461>    <31454, 31461, 31458>,
    <31454, 31458, 31462>    <31463, 31471, 31464>,
    <31463, 31464, 31468>    <31463, 31468, 31465>,
    <31463, 31465, 31469>    <31463, 31469, 31466>,
    <31463, 31466, 31470>    <31463, 31470, 31467>,
    <31463, 31467, 31471>    <31472, 31480, 31473>,
    <31472, 31473, 31477>    <31472, 31477, 31474>,
    <31472, 31474, 31478>    <31472, 31478, 31475>,
    <31472, 31475, 31479>    <31472, 31479, 31476>,
    <31472, 31476, 31480>    <31481, 31489, 31482>,
    <31481, 31482, 31486>    <31481, 31486, 31483>,
    <31481, 31483, 31487>    <31481, 31487, 31484>,
    <31481, 31484, 31488>    <31481, 31488, 31485>,
    <31481, 31485, 31489>    <31490, 31498, 31491>,
    <31490, 31491, 31495>    <31490, 31495, 31492>,
    <31490, 31492, 31496>    <31490, 31496, 31493>,
    <31490, 31493, 31497>    <31490, 31497, 31494>,
    <31490, 31494, 31498>    <31499, 31507, 31500>,
    <31499, 31500, 31504>    <31499, 31504, 31501>,
    <31499, 31501, 31505>    <31499, 31505, 31502>,
    <31499, 31502, 31506>    <31499, 31506, 31503>,
    <31499, 31503, 31507>    <31508, 31516, 31509>,
    <31508, 31509, 31513>    <31508, 31513, 31510>,
    <31508, 31510, 31514>    <31508, 31514, 31511>,
    <31508, 31511, 31515>    <31508, 31515, 31512>,
    <31508, 31512, 31516>    <31517, 31525, 31518>,
    <31517, 31518, 31522>    <31517, 31522, 31519>,
    <31517, 31519, 31523>    <31517, 31523, 31520>,
    <31517, 31520, 31524>    <31517, 31524, 31521>,
    <31517, 31521, 31525>    <31526, 31534, 31527>,
    <31526, 31527, 31531>    <31526, 31531, 31528>,
    <31526, 31528, 31532>    <31526, 31532, 31529>,
    <31526, 31529, 31533>    <31526, 31533, 31530>,
    <31526, 31530, 31534>    <31535, 31543, 31536>,
    <31535, 31536, 31540>    <31535, 31540, 31537>,
    <31535, 31537, 31541>    <31535, 31541, 31538>,
    <31535, 31538, 31542>    <31535, 31542, 31539>,
    <31535, 31539, 31543>    <31544, 31552, 31545>,
    <31544, 31545, 31549>    <31544, 31549, 31546>,
    <31544, 31546, 31550>    <31544, 31550, 31547>,
    <31544, 31547, 31551>    <31544, 31551, 31548>,
    <31544, 31548, 31552>    <31553, 31561, 31554>,
    <31553, 31554, 31558>    <31553, 31558, 31555>,
    <31553, 31555, 31559>    <31553, 31559, 31556>,
    <31553, 31556, 31560>    <31553, 31560, 31557>,
    <31553, 31557, 31561>    <31562, 31570, 31563>,
    <31562, 31563, 31567>    <31562, 31567, 31564>,
    <31562, 31564, 31568>    <31562, 31568, 31565>,
    <31562, 31565, 31569>    <31562, 31569, 31566>,
    <31562, 31566, 31570>    <31571, 31579, 31572>,
    <31571, 31572, 31576>    <31571, 31576, 31573>,
    <31571, 31573, 31577>    <31571, 31577, 31574>,
    <31571, 31574, 31578>    <31571, 31578, 31575>,
    <31571, 31575, 31579>    <31580, 31588, 31581>,
    <31580, 31581, 31585>    <31580, 31585, 31582>,
    <31580, 31582, 31586>    <31580, 31586, 31583>,
    <31580, 31583, 31587>    <31580, 31587, 31584>,
    <31580, 31584, 31588>    <31589, 31597, 31590>,
    <31589, 31590, 31594>    <31589, 31594, 31591>,
    <31589, 31591, 31595>    <31589, 31595, 31592>,
    <31589, 31592, 31596>    <31589, 31596, 31593>,
    <31589, 31593, 31597>    <31598, 31606, 31599>,
    <31598, 31599, 31603>    <31598, 31603, 31600>,
    <31598, 31600, 31604>    <31598, 31604, 31601>,
    <31598, 31601, 31605>    <31598, 31605, 31602>,
    <31598, 31602, 31606>    <31607, 31615, 31608>,
    <31607, 31608, 31612>    <31607, 31612, 31609>,
    <31607, 31609, 31613>    <31607, 31613, 31610>,
    <31607, 31610, 31614>    <31607, 31614, 31611>,
    <31607, 31611, 31615>    <31616, 31624, 31617>,
    <31616, 31617, 31621>    <31616, 31621, 31618>,
    <31616, 31618, 31622>    <31616, 31622, 31619>,
    <31616, 31619, 31623>    <31616, 31623, 31620>,
    <31616, 31620, 31624>    <31625, 31633, 31626>,
    <31625, 31626, 31630>    <31625, 31630, 31627>,
    <31625, 31627, 31631>    <31625, 31631, 31628>,
    <31625, 31628, 31632>    <31625, 31632, 31629>,
    <31625, 31629, 31633>    <31634, 31642, 31635>,
    <31634, 31635, 31639>    <31634, 31639, 31636>,
    <31634, 31636, 31640>    <31634, 31640, 31637>,
    <31634, 31637, 31641>    <31634, 31641, 31638>,
    <31634, 31638, 31642>    <31643, 31651, 31644>,
    <31643, 31644, 31648>    <31643, 31648, 31645>,
    <31643, 31645, 31649>    <31643, 31649, 31646>,
    <31643, 31646, 31650>    <31643, 31650, 31647>,
    <31643, 31647, 31651>    <31652, 31660, 31653>,
    <31652, 31653, 31657>    <31652, 31657, 31654>,
    <31652, 31654, 31658>    <31652, 31658, 31655>,
    <31652, 31655, 31659>    <31652, 31659, 31656>,
    <31652, 31656, 31660>    <31661, 31669, 31662>,
    <31661, 31662, 31666>    <31661, 31666, 31663>,
    <31661, 31663, 31667>    <31661, 31667, 31664>,
    <31661, 31664, 31668>    <31661, 31668, 31665>,
    <31661, 31665, 31669>    <31670, 31678, 31671>,
    <31670, 31671, 31675>    <31670, 31675, 31672>,
    <31670, 31672, 31676>    <31670, 31676, 31673>,
    <31670, 31673, 31677>    <31670, 31677, 31674>,
    <31670, 31674, 31678>    <31679, 31687, 31680>,
    <31679, 31680, 31684>    <31679, 31684, 31681>,
    <31679, 31681, 31685>    <31679, 31685, 31682>,
    <31679, 31682, 31686>    <31679, 31686, 31683>,
    <31679, 31683, 31687>    <31688, 31696, 31689>,
    <31688, 31689, 31693>    <31688, 31693, 31690>,
    <31688, 31690, 31694>    <31688, 31694, 31691>,
    <31688, 31691, 31695>    <31688, 31695, 31692>,
    <31688, 31692, 31696>    <31697, 31705, 31698>,
    <31697, 31698, 31702>    <31697, 31702, 31699>,
    <31697, 31699, 31703>    <31697, 31703, 31700>,
    <31697, 31700, 31704>    <31697, 31704, 31701>,
    <31697, 31701, 31705>    <31706, 31714, 31707>,
    <31706, 31707, 31711>    <31706, 31711, 31708>,
    <31706, 31708, 31712>    <31706, 31712, 31709>,
    <31706, 31709, 31713>    <31706, 31713, 31710>,
    <31706, 31710, 31714>    <31715, 31723, 31716>,
    <31715, 31716, 31720>    <31715, 31720, 31717>,
    <31715, 31717, 31721>    <31715, 31721, 31718>,
    <31715, 31718, 31722>    <31715, 31722, 31719>,
    <31715, 31719, 31723>    <31724, 31732, 31725>,
    <31724, 31725, 31729>    <31724, 31729, 31726>,
    <31724, 31726, 31730>    <31724, 31730, 31727>,
    <31724, 31727, 31731>    <31724, 31731, 31728>,
    <31724, 31728, 31732>    <31733, 31741, 31734>,
    <31733, 31734, 31738>    <31733, 31738, 31735>,
    <31733, 31735, 31739>    <31733, 31739, 31736>,
    <31733, 31736, 31740>    <31733, 31740, 31737>,
    <31733, 31737, 31741>    <31742, 31750, 31743>,
    <31742, 31743, 31747>    <31742, 31747, 31744>,
    <31742, 31744, 31748>    <31742, 31748, 31745>,
    <31742, 31745, 31749>    <31742, 31749, 31746>,
    <31742, 31746, 31750>    <31751, 31759, 31752>,
    <31751, 31752, 31756>    <31751, 31756, 31753>,
    <31751, 31753, 31757>    <31751, 31757, 31754>,
    <31751, 31754, 31758>    <31751, 31758, 31755>,
    <31751, 31755, 31759>    <31760, 31768, 31761>,
    <31760, 31761, 31765>    <31760, 31765, 31762>,
    <31760, 31762, 31766>    <31760, 31766, 31763>,
    <31760, 31763, 31767>    <31760, 31767, 31764>,
    <31760, 31764, 31768>    <31769, 31777, 31770>,
    <31769, 31770, 31774>    <31769, 31774, 31771>,
    <31769, 31771, 31775>    <31769, 31775, 31772>,
    <31769, 31772, 31776>    <31769, 31776, 31773>,
    <31769, 31773, 31777>    <31778, 31786, 31779>,
    <31778, 31779, 31783>    <31778, 31783, 31780>,
    <31778, 31780, 31784>    <31778, 31784, 31781>,
    <31778, 31781, 31785>    <31778, 31785, 31782>,
    <31778, 31782, 31786>    <31787, 31795, 31788>,
    <31787, 31788, 31792>    <31787, 31792, 31789>,
    <31787, 31789, 31793>    <31787, 31793, 31790>,
    <31787, 31790, 31794>    <31787, 31794, 31791>,
    <31787, 31791, 31795>    <31796, 31804, 31797>,
    <31796, 31797, 31801>    <31796, 31801, 31798>,
    <31796, 31798, 31802>    <31796, 31802, 31799>,
    <31796, 31799, 31803>    <31796, 31803, 31800>,
    <31796, 31800, 31804>    <31805, 31813, 31806>,
    <31805, 31806, 31810>    <31805, 31810, 31807>,
    <31805, 31807, 31811>    <31805, 31811, 31808>,
    <31805, 31808, 31812>    <31805, 31812, 31809>,
    <31805, 31809, 31813>    <31814, 31822, 31815>,
    <31814, 31815, 31819>    <31814, 31819, 31816>,
    <31814, 31816, 31820>    <31814, 31820, 31817>,
    <31814, 31817, 31821>    <31814, 31821, 31818>,
    <31814, 31818, 31822>    <31823, 31831, 31824>,
    <31823, 31824, 31828>    <31823, 31828, 31825>,
    <31823, 31825, 31829>    <31823, 31829, 31826>,
    <31823, 31826, 31830>    <31823, 31830, 31827>,
    <31823, 31827, 31831>    <31832, 31840, 31833>,
    <31832, 31833, 31837>    <31832, 31837, 31834>,
    <31832, 31834, 31838>    <31832, 31838, 31835>,
    <31832, 31835, 31839>    <31832, 31839, 31836>,
    <31832, 31836, 31840>    <31841, 31849, 31842>,
    <31841, 31842, 31846>    <31841, 31846, 31843>,
    <31841, 31843, 31847>    <31841, 31847, 31844>,
    <31841, 31844, 31848>    <31841, 31848, 31845>,
    <31841, 31845, 31849>    <31850, 31858, 31851>,
    <31850, 31851, 31855>    <31850, 31855, 31852>,
    <31850, 31852, 31856>    <31850, 31856, 31853>,
    <31850, 31853, 31857>    <31850, 31857, 31854>,
    <31850, 31854, 31858>    <31859, 31867, 31860>,
    <31859, 31860, 31864>    <31859, 31864, 31861>,
    <31859, 31861, 31865>    <31859, 31865, 31862>,
    <31859, 31862, 31866>    <31859, 31866, 31863>,
    <31859, 31863, 31867>    <31868, 31876, 31869>,
    <31868, 31869, 31873>    <31868, 31873, 31870>,
    <31868, 31870, 31874>    <31868, 31874, 31871>,
    <31868, 31871, 31875>    <31868, 31875, 31872>,
    <31868, 31872, 31876>    <31877, 31885, 31878>,
    <31877, 31878, 31882>    <31877, 31882, 31879>,
    <31877, 31879, 31883>    <31877, 31883, 31880>,
    <31877, 31880, 31884>    <31877, 31884, 31881>,
    <31877, 31881, 31885>    <31886, 31894, 31887>,
    <31886, 31887, 31891>    <31886, 31891, 31888>,
    <31886, 31888, 31892>    <31886, 31892, 31889>,
    <31886, 31889, 31893>    <31886, 31893, 31890>,
    <31886, 31890, 31894>    <31895, 31903, 31896>,
    <31895, 31896, 31900>    <31895, 31900, 31897>,
    <31895, 31897, 31901>    <31895, 31901, 31898>,
    <31895, 31898, 31902>    <31895, 31902, 31899>,
    <31895, 31899, 31903>    <31904, 31912, 31905>,
    <31904, 31905, 31909>    <31904, 31909, 31906>,
    <31904, 31906, 31910>    <31904, 31910, 31907>,
    <31904, 31907, 31911>    <31904, 31911, 31908>,
    <31904, 31908, 31912>    <31913, 31921, 31914>,
    <31913, 31914, 31918>    <31913, 31918, 31915>,
    <31913, 31915, 31919>    <31913, 31919, 31916>,
    <31913, 31916, 31920>    <31913, 31920, 31917>,
    <31913, 31917, 31921>    <31922, 31930, 31923>,
    <31922, 31923, 31927>    <31922, 31927, 31924>,
    <31922, 31924, 31928>    <31922, 31928, 31925>,
    <31922, 31925, 31929>    <31922, 31929, 31926>,
    <31922, 31926, 31930>    <31931, 31939, 31932>,
    <31931, 31932, 31936>    <31931, 31936, 31933>,
    <31931, 31933, 31937>    <31931, 31937, 31934>,
    <31931, 31934, 31938>    <31931, 31938, 31935>,
    <31931, 31935, 31939>    <31940, 31948, 31941>,
    <31940, 31941, 31945>    <31940, 31945, 31942>,
    <31940, 31942, 31946>    <31940, 31946, 31943>,
    <31940, 31943, 31947>    <31940, 31947, 31944>,
    <31940, 31944, 31948>    <31949, 31957, 31950>,
    <31949, 31950, 31954>    <31949, 31954, 31951>,
    <31949, 31951, 31955>    <31949, 31955, 31952>,
    <31949, 31952, 31956>    <31949, 31956, 31953>,
    <31949, 31953, 31957>    <31958, 31966, 31959>,
    <31958, 31959, 31963>    <31958, 31963, 31960>,
    <31958, 31960, 31964>    <31958, 31964, 31961>,
    <31958, 31961, 31965>    <31958, 31965, 31962>,
    <31958, 31962, 31966>    <31967, 31975, 31968>,
    <31967, 31968, 31972>    <31967, 31972, 31969>,
    <31967, 31969, 31973>    <31967, 31973, 31970>,
    <31967, 31970, 31974>    <31967, 31974, 31971>,
    <31967, 31971, 31975>    <31976, 31984, 31977>,
    <31976, 31977, 31981>    <31976, 31981, 31978>,
    <31976, 31978, 31982>    <31976, 31982, 31979>,
    <31976, 31979, 31983>    <31976, 31983, 31980>,
    <31976, 31980, 31984>    <31985, 31993, 31986>,
    <31985, 31986, 31990>    <31985, 31990, 31987>,
    <31985, 31987, 31991>    <31985, 31991, 31988>,
    <31985, 31988, 31992>    <31985, 31992, 31989>,
    <31985, 31989, 31993>    <31994, 32002, 31995>,
    <31994, 31995, 31999>    <31994, 31999, 31996>,
    <31994, 31996, 32000>    <31994, 32000, 31997>,
    <31994, 31997, 32001>    <31994, 32001, 31998>,
    <31994, 31998, 32002>    <32003, 32011, 32004>,
    <32003, 32004, 32008>    <32003, 32008, 32005>,
    <32003, 32005, 32009>    <32003, 32009, 32006>,
    <32003, 32006, 32010>    <32003, 32010, 32007>,
    <32003, 32007, 32011>    <32012, 32020, 32013>,
    <32012, 32013, 32017>    <32012, 32017, 32014>,
    <32012, 32014, 32018>    <32012, 32018, 32015>,
    <32012, 32015, 32019>    <32012, 32019, 32016>,
    <32012, 32016, 32020>    <32021, 32029, 32022>,
    <32021, 32022, 32026>    <32021, 32026, 32023>,
    <32021, 32023, 32027>    <32021, 32027, 32024>,
    <32021, 32024, 32028>    <32021, 32028, 32025>,
    <32021, 32025, 32029>    <32030, 32038, 32031>,
    <32030, 32031, 32035>    <32030, 32035, 32032>,
    <32030, 32032, 32036>    <32030, 32036, 32033>,
    <32030, 32033, 32037>    <32030, 32037, 32034>,
    <32030, 32034, 32038>    <32039, 32047, 32040>,
    <32039, 32040, 32044>    <32039, 32044, 32041>,
    <32039, 32041, 32045>    <32039, 32045, 32042>,
    <32039, 32042, 32046>    <32039, 32046, 32043>,
    <32039, 32043, 32047>    <32048, 32056, 32049>,
    <32048, 32049, 32053>    <32048, 32053, 32050>,
    <32048, 32050, 32054>    <32048, 32054, 32051>,
    <32048, 32051, 32055>    <32048, 32055, 32052>,
    <32048, 32052, 32056>    <32057, 32065, 32058>,
    <32057, 32058, 32062>    <32057, 32062, 32059>,
    <32057, 32059, 32063>    <32057, 32063, 32060>,
    <32057, 32060, 32064>    <32057, 32064, 32061>,
    <32057, 32061, 32065>    <32066, 32074, 32067>,
    <32066, 32067, 32071>    <32066, 32071, 32068>,
    <32066, 32068, 32072>    <32066, 32072, 32069>,
    <32066, 32069, 32073>    <32066, 32073, 32070>,
    <32066, 32070, 32074>    <32075, 32083, 32076>,
    <32075, 32076, 32080>    <32075, 32080, 32077>,
    <32075, 32077, 32081>    <32075, 32081, 32078>,
    <32075, 32078, 32082>    <32075, 32082, 32079>,
    <32075, 32079, 32083>    <32084, 32092, 32085>,
    <32084, 32085, 32089>    <32084, 32089, 32086>,
    <32084, 32086, 32090>    <32084, 32090, 32087>,
    <32084, 32087, 32091>    <32084, 32091, 32088>,
    <32084, 32088, 32092>    <32093, 32101, 32094>,
    <32093, 32094, 32098>    <32093, 32098, 32095>,
    <32093, 32095, 32099>    <32093, 32099, 32096>,
    <32093, 32096, 32100>    <32093, 32100, 32097>,
    <32093, 32097, 32101>    <32102, 32110, 32103>,
    <32102, 32103, 32107>    <32102, 32107, 32104>,
    <32102, 32104, 32108>    <32102, 32108, 32105>,
    <32102, 32105, 32109>    <32102, 32109, 32106>,
    <32102, 32106, 32110>    <32111, 32119, 32112>,
    <32111, 32112, 32116>    <32111, 32116, 32113>,
    <32111, 32113, 32117>    <32111, 32117, 32114>,
    <32111, 32114, 32118>    <32111, 32118, 32115>,
    <32111, 32115, 32119>    <32120, 32128, 32121>,
    <32120, 32121, 32125>    <32120, 32125, 32122>,
    <32120, 32122, 32126>    <32120, 32126, 32123>,
    <32120, 32123, 32127>    <32120, 32127, 32124>,
    <32120, 32124, 32128>    <32129, 32137, 32130>,
    <32129, 32130, 32134>    <32129, 32134, 32131>,
    <32129, 32131, 32135>    <32129, 32135, 32132>,
    <32129, 32132, 32136>    <32129, 32136, 32133>,
    <32129, 32133, 32137>    <32138, 32146, 32139>,
    <32138, 32139, 32143>    <32138, 32143, 32140>,
    <32138, 32140, 32144>    <32138, 32144, 32141>,
    <32138, 32141, 32145>    <32138, 32145, 32142>,
    <32138, 32142, 32146>    <32147, 32155, 32148>,
    <32147, 32148, 32152>    <32147, 32152, 32149>,
    <32147, 32149, 32153>    <32147, 32153, 32150>,
    <32147, 32150, 32154>    <32147, 32154, 32151>,
    <32147, 32151, 32155>    <32156, 32164, 32157>,
    <32156, 32157, 32161>    <32156, 32161, 32158>,
    <32156, 32158, 32162>    <32156, 32162, 32159>,
    <32156, 32159, 32163>    <32156, 32163, 32160>,
    <32156, 32160, 32164>    <32165, 32173, 32166>,
    <32165, 32166, 32170>    <32165, 32170, 32167>,
    <32165, 32167, 32171>    <32165, 32171, 32168>,
    <32165, 32168, 32172>    <32165, 32172, 32169>,
    <32165, 32169, 32173>    <32174, 32182, 32175>,
    <32174, 32175, 32179>    <32174, 32179, 32176>,
    <32174, 32176, 32180>    <32174, 32180, 32177>,
    <32174, 32177, 32181>    <32174, 32181, 32178>,
    <32174, 32178, 32182>    <32183, 32191, 32184>,
    <32183, 32184, 32188>    <32183, 32188, 32185>,
    <32183, 32185, 32189>    <32183, 32189, 32186>,
    <32183, 32186, 32190>    <32183, 32190, 32187>,
    <32183, 32187, 32191>    <32192, 32200, 32193>,
    <32192, 32193, 32197>    <32192, 32197, 32194>,
    <32192, 32194, 32198>    <32192, 32198, 32195>,
    <32192, 32195, 32199>    <32192, 32199, 32196>,
    <32192, 32196, 32200>    <32201, 32209, 32202>,
    <32201, 32202, 32206>    <32201, 32206, 32203>,
    <32201, 32203, 32207>    <32201, 32207, 32204>,
    <32201, 32204, 32208>    <32201, 32208, 32205>,
    <32201, 32205, 32209>    <32210, 32218, 32211>,
    <32210, 32211, 32215>    <32210, 32215, 32212>,
    <32210, 32212, 32216>    <32210, 32216, 32213>,
    <32210, 32213, 32217>    <32210, 32217, 32214>,
    <32210, 32214, 32218>    <32219, 32227, 32220>,
    <32219, 32220, 32224>    <32219, 32224, 32221>,
    <32219, 32221, 32225>    <32219, 32225, 32222>,
    <32219, 32222, 32226>    <32219, 32226, 32223>,
    <32219, 32223, 32227>    <32228, 32236, 32229>,
    <32228, 32229, 32233>    <32228, 32233, 32230>,
    <32228, 32230, 32234>    <32228, 32234, 32231>,
    <32228, 32231, 32235>    <32228, 32235, 32232>,
    <32228, 32232, 32236>    <32237, 32245, 32238>,
    <32237, 32238, 32242>    <32237, 32242, 32239>,
    <32237, 32239, 32243>    <32237, 32243, 32240>,
    <32237, 32240, 32244>    <32237, 32244, 32241>,
    <32237, 32241, 32245>    <32246, 32254, 32247>,
    <32246, 32247, 32251>    <32246, 32251, 32248>,
    <32246, 32248, 32252>    <32246, 32252, 32249>,
    <32246, 32249, 32253>    <32246, 32253, 32250>,
    <32246, 32250, 32254>    <32255, 32263, 32256>,
    <32255, 32256, 32260>    <32255, 32260, 32257>,
    <32255, 32257, 32261>    <32255, 32261, 32258>,
    <32255, 32258, 32262>    <32255, 32262, 32259>,
    <32255, 32259, 32263>    <32264, 32272, 32265>,
    <32264, 32265, 32269>    <32264, 32269, 32266>,
    <32264, 32266, 32270>    <32264, 32270, 32267>,
    <32264, 32267, 32271>    <32264, 32271, 32268>,
    <32264, 32268, 32272>    <32273, 32281, 32274>,
    <32273, 32274, 32278>    <32273, 32278, 32275>,
    <32273, 32275, 32279>    <32273, 32279, 32276>,
    <32273, 32276, 32280>    <32273, 32280, 32277>,
    <32273, 32277, 32281>    <32282, 32290, 32283>,
    <32282, 32283, 32287>    <32282, 32287, 32284>,
    <32282, 32284, 32288>    <32282, 32288, 32285>,
    <32282, 32285, 32289>    <32282, 32289, 32286>,
    <32282, 32286, 32290>    <32291, 32299, 32292>,
    <32291, 32292, 32296>    <32291, 32296, 32293>,
    <32291, 32293, 32297>    <32291, 32297, 32294>,
    <32291, 32294, 32298>    <32291, 32298, 32295>,
    <32291, 32295, 32299>    <32300, 32308, 32301>,
    <32300, 32301, 32305>    <32300, 32305, 32302>,
    <32300, 32302, 32306>    <32300, 32306, 32303>,
    <32300, 32303, 32307>    <32300, 32307, 32304>,
    <32300, 32304, 32308>    <32309, 32317, 32310>,
    <32309, 32310, 32314>    <32309, 32314, 32311>,
    <32309, 32311, 32315>    <32309, 32315, 32312>,
    <32309, 32312, 32316>    <32309, 32316, 32313>,
    <32309, 32313, 32317>    <32318, 32326, 32319>,
    <32318, 32319, 32323>    <32318, 32323, 32320>,
    <32318, 32320, 32324>    <32318, 32324, 32321>,
    <32318, 32321, 32325>    <32318, 32325, 32322>,
    <32318, 32322, 32326>    <32327, 32335, 32328>,
    <32327, 32328, 32332>    <32327, 32332, 32329>,
    <32327, 32329, 32333>    <32327, 32333, 32330>,
    <32327, 32330, 32334>    <32327, 32334, 32331>,
    <32327, 32331, 32335>    <32336, 32344, 32337>,
    <32336, 32337, 32341>    <32336, 32341, 32338>,
    <32336, 32338, 32342>    <32336, 32342, 32339>,
    <32336, 32339, 32343>    <32336, 32343, 32340>,
    <32336, 32340, 32344>    <32345, 32353, 32346>,
    <32345, 32346, 32350>    <32345, 32350, 32347>,
    <32345, 32347, 32351>    <32345, 32351, 32348>,
    <32345, 32348, 32352>    <32345, 32352, 32349>,
    <32345, 32349, 32353>    <32354, 32362, 32355>,
    <32354, 32355, 32359>    <32354, 32359, 32356>,
    <32354, 32356, 32360>    <32354, 32360, 32357>,
    <32354, 32357, 32361>    <32354, 32361, 32358>,
    <32354, 32358, 32362>    <32363, 32371, 32364>,
    <32363, 32364, 32368>    <32363, 32368, 32365>,
    <32363, 32365, 32369>    <32363, 32369, 32366>,
    <32363, 32366, 32370>    <32363, 32370, 32367>,
    <32363, 32367, 32371>    <32372, 32380, 32373>,
    <32372, 32373, 32377>    <32372, 32377, 32374>,
    <32372, 32374, 32378>    <32372, 32378, 32375>,
    <32372, 32375, 32379>    <32372, 32379, 32376>,
    <32372, 32376, 32380>    <32381, 32389, 32382>,
    <32381, 32382, 32386>    <32381, 32386, 32383>,
    <32381, 32383, 32387>    <32381, 32387, 32384>,
    <32381, 32384, 32388>    <32381, 32388, 32385>,
    <32381, 32385, 32389>    <32390, 32398, 32391>,
    <32390, 32391, 32395>    <32390, 32395, 32392>,
    <32390, 32392, 32396>    <32390, 32396, 32393>,
    <32390, 32393, 32397>    <32390, 32397, 32394>,
    <32390, 32394, 32398>    <32399, 32407, 32400>,
    <32399, 32400, 32404>    <32399, 32404, 32401>,
    <32399, 32401, 32405>    <32399, 32405, 32402>,
    <32399, 32402, 32406>    <32399, 32406, 32403>,
    <32399, 32403, 32407>    <32408, 32416, 32409>,
    <32408, 32409, 32413>    <32408, 32413, 32410>,
    <32408, 32410, 32414>    <32408, 32414, 32411>,
    <32408, 32411, 32415>    <32408, 32415, 32412>,
    <32408, 32412, 32416>    <32417, 32425, 32418>,
    <32417, 32418, 32422>    <32417, 32422, 32419>,
    <32417, 32419, 32423>    <32417, 32423, 32420>,
    <32417, 32420, 32424>    <32417, 32424, 32421>,
    <32417, 32421, 32425>    <32426, 32434, 32427>,
    <32426, 32427, 32431>    <32426, 32431, 32428>,
    <32426, 32428, 32432>    <32426, 32432, 32429>,
    <32426, 32429, 32433>    <32426, 32433, 32430>,
    <32426, 32430, 32434>    <32435, 32443, 32436>,
    <32435, 32436, 32440>    <32435, 32440, 32437>,
    <32435, 32437, 32441>    <32435, 32441, 32438>,
    <32435, 32438, 32442>    <32435, 32442, 32439>,
    <32435, 32439, 32443>    <32444, 32452, 32445>,
    <32444, 32445, 32449>    <32444, 32449, 32446>,
    <32444, 32446, 32450>    <32444, 32450, 32447>,
    <32444, 32447, 32451>    <32444, 32451, 32448>,
    <32444, 32448, 32452>    <32453, 32461, 32454>,
    <32453, 32454, 32458>    <32453, 32458, 32455>,
    <32453, 32455, 32459>    <32453, 32459, 32456>,
    <32453, 32456, 32460>    <32453, 32460, 32457>,
    <32453, 32457, 32461>    <32462, 32470, 32463>,
    <32462, 32463, 32467>    <32462, 32467, 32464>,
    <32462, 32464, 32468>    <32462, 32468, 32465>,
    <32462, 32465, 32469>    <32462, 32469, 32466>,
    <32462, 32466, 32470>    <32471, 32479, 32472>,
    <32471, 32472, 32476>    <32471, 32476, 32473>,
    <32471, 32473, 32477>    <32471, 32477, 32474>,
    <32471, 32474, 32478>    <32471, 32478, 32475>,
    <32471, 32475, 32479>    <32480, 32488, 32481>,
    <32480, 32481, 32485>    <32480, 32485, 32482>,
    <32480, 32482, 32486>    <32480, 32486, 32483>,
    <32480, 32483, 32487>    <32480, 32487, 32484>,
    <32480, 32484, 32488>    <32489, 32497, 32490>,
    <32489, 32490, 32494>    <32489, 32494, 32491>,
    <32489, 32491, 32495>    <32489, 32495, 32492>,
    <32489, 32492, 32496>    <32489, 32496, 32493>,
    <32489, 32493, 32497>    <32498, 32506, 32499>,
    <32498, 32499, 32503>    <32498, 32503, 32500>,
    <32498, 32500, 32504>    <32498, 32504, 32501>,
    <32498, 32501, 32505>    <32498, 32505, 32502>,
    <32498, 32502, 32506>    <32507, 32515, 32508>,
    <32507, 32508, 32512>    <32507, 32512, 32509>,
    <32507, 32509, 32513>    <32507, 32513, 32510>,
    <32507, 32510, 32514>    <32507, 32514, 32511>,
    <32507, 32511, 32515>    <32516, 32524, 32517>,
    <32516, 32517, 32521>    <32516, 32521, 32518>,
    <32516, 32518, 32522>    <32516, 32522, 32519>,
    <32516, 32519, 32523>    <32516, 32523, 32520>,
    <32516, 32520, 32524>    <32525, 32533, 32526>,
    <32525, 32526, 32530>    <32525, 32530, 32527>,
    <32525, 32527, 32531>    <32525, 32531, 32528>,
    <32525, 32528, 32532>    <32525, 32532, 32529>,
    <32525, 32529, 32533>    <32534, 32542, 32535>,
    <32534, 32535, 32539>    <32534, 32539, 32536>,
    <32534, 32536, 32540>    <32534, 32540, 32537>,
    <32534, 32537, 32541>    <32534, 32541, 32538>,
    <32534, 32538, 32542>    <32543, 32551, 32544>,
    <32543, 32544, 32548>    <32543, 32548, 32545>,
    <32543, 32545, 32549>    <32543, 32549, 32546>,
    <32543, 32546, 32550>    <32543, 32550, 32547>,
    <32543, 32547, 32551>    <32552, 32560, 32553>,
    <32552, 32553, 32557>    <32552, 32557, 32554>,
    <32552, 32554, 32558>    <32552, 32558, 32555>,
    <32552, 32555, 32559>    <32552, 32559, 32556>,
    <32552, 32556, 32560>    <32561, 32569, 32562>,
    <32561, 32562, 32566>    <32561, 32566, 32563>,
    <32561, 32563, 32567>    <32561, 32567, 32564>,
    <32561, 32564, 32568>    <32561, 32568, 32565>,
    <32561, 32565, 32569>    <32570, 32578, 32571>,
    <32570, 32571, 32575>    <32570, 32575, 32572>,
    <32570, 32572, 32576>    <32570, 32576, 32573>,
    <32570, 32573, 32577>    <32570, 32577, 32574>,
    <32570, 32574, 32578>    <32579, 32587, 32580>,
    <32579, 32580, 32584>    <32579, 32584, 32581>,
    <32579, 32581, 32585>    <32579, 32585, 32582>,
    <32579, 32582, 32586>    <32579, 32586, 32583>,
    <32579, 32583, 32587>    <32588, 32596, 32589>,
    <32588, 32589, 32593>    <32588, 32593, 32590>,
    <32588, 32590, 32594>    <32588, 32594, 32591>,
    <32588, 32591, 32595>    <32588, 32595, 32592>,
    <32588, 32592, 32596>    <32597, 32605, 32598>,
    <32597, 32598, 32602>    <32597, 32602, 32599>,
    <32597, 32599, 32603>    <32597, 32603, 32600>,
    <32597, 32600, 32604>    <32597, 32604, 32601>,
    <32597, 32601, 32605>    <32606, 32614, 32607>,
    <32606, 32607, 32611>    <32606, 32611, 32608>,
    <32606, 32608, 32612>    <32606, 32612, 32609>,
    <32606, 32609, 32613>    <32606, 32613, 32610>,
    <32606, 32610, 32614>    <32615, 32623, 32616>,
    <32615, 32616, 32620>    <32615, 32620, 32617>,
    <32615, 32617, 32621>    <32615, 32621, 32618>,
    <32615, 32618, 32622>    <32615, 32622, 32619>,
    <32615, 32619, 32623>    <32624, 32632, 32625>,
    <32624, 32625, 32629>    <32624, 32629, 32626>,
    <32624, 32626, 32630>    <32624, 32630, 32627>,
    <32624, 32627, 32631>    <32624, 32631, 32628>,
    <32624, 32628, 32632>    <32633, 32641, 32634>,
    <32633, 32634, 32638>    <32633, 32638, 32635>,
    <32633, 32635, 32639>    <32633, 32639, 32636>,
    <32633, 32636, 32640>    <32633, 32640, 32637>,
    <32633, 32637, 32641>    <32642, 32650, 32643>,
    <32642, 32643, 32647>    <32642, 32647, 32644>,
    <32642, 32644, 32648>    <32642, 32648, 32645>,
    <32642, 32645, 32649>    <32642, 32649, 32646>,
    <32642, 32646, 32650>    <32651, 32659, 32652>,
    <32651, 32652, 32656>    <32651, 32656, 32653>,
    <32651, 32653, 32657>    <32651, 32657, 32654>,
    <32651, 32654, 32658>    <32651, 32658, 32655>,
    <32651, 32655, 32659>    <32660, 32668, 32661>,
    <32660, 32661, 32665>    <32660, 32665, 32662>,
    <32660, 32662, 32666>    <32660, 32666, 32663>,
    <32660, 32663, 32667>    <32660, 32667, 32664>,
    <32660, 32664, 32668>    <32669, 32677, 32670>,
    <32669, 32670, 32674>    <32669, 32674, 32671>,
    <32669, 32671, 32675>    <32669, 32675, 32672>,
    <32669, 32672, 32676>    <32669, 32676, 32673>,
    <32669, 32673, 32677>    <32678, 32686, 32679>,
    <32678, 32679, 32683>    <32678, 32683, 32680>,
    <32678, 32680, 32684>    <32678, 32684, 32681>,
    <32678, 32681, 32685>    <32678, 32685, 32682>,
    <32678, 32682, 32686>    <32687, 32695, 32688>,
    <32687, 32688, 32692>    <32687, 32692, 32689>,
    <32687, 32689, 32693>    <32687, 32693, 32690>,
    <32687, 32690, 32694>    <32687, 32694, 32691>,
    <32687, 32691, 32695>    <32696, 32704, 32697>,
    <32696, 32697, 32701>    <32696, 32701, 32698>,
    <32696, 32698, 32702>    <32696, 32702, 32699>,
    <32696, 32699, 32703>    <32696, 32703, 32700>,
    <32696, 32700, 32704>    <32705, 32713, 32706>,
    <32705, 32706, 32710>    <32705, 32710, 32707>,
    <32705, 32707, 32711>    <32705, 32711, 32708>,
    <32705, 32708, 32712>    <32705, 32712, 32709>,
    <32705, 32709, 32713>    <32714, 32722, 32715>,
    <32714, 32715, 32719>    <32714, 32719, 32716>,
    <32714, 32716, 32720>    <32714, 32720, 32717>,
    <32714, 32717, 32721>    <32714, 32721, 32718>,
    <32714, 32718, 32722>    <32723, 32731, 32724>,
    <32723, 32724, 32728>    <32723, 32728, 32725>,
    <32723, 32725, 32729>    <32723, 32729, 32726>,
    <32723, 32726, 32730>    <32723, 32730, 32727>,
    <32723, 32727, 32731>    <32732, 32740, 32733>,
    <32732, 32733, 32737>    <32732, 32737, 32734>,
    <32732, 32734, 32738>    <32732, 32738, 32735>,
    <32732, 32735, 32739>    <32732, 32739, 32736>,
    <32732, 32736, 32740>    <32741, 32749, 32742>,
    <32741, 32742, 32746>    <32741, 32746, 32743>,
    <32741, 32743, 32747>    <32741, 32747, 32744>,
    <32741, 32744, 32748>    <32741, 32748, 32745>,
    <32741, 32745, 32749>    <32750, 32758, 32751>,
    <32750, 32751, 32755>    <32750, 32755, 32752>,
    <32750, 32752, 32756>    <32750, 32756, 32753>,
    <32750, 32753, 32757>    <32750, 32757, 32754>,
    <32750, 32754, 32758>    <32759, 32767, 32760>,
    <32759, 32760, 32764>    <32759, 32764, 32761>,
    <32759, 32761, 32765>    <32759, 32765, 32762>,
    <32759, 32762, 32766>    <32759, 32766, 32763>,
    <32759, 32763, 32767>    <32768, 32776, 32769>,
    <32768, 32769, 32773>    <32768, 32773, 32770>,
    <32768, 32770, 32774>    <32768, 32774, 32771>,
    <32768, 32771, 32775>    <32768, 32775, 32772>,
    <32768, 32772, 32776>    <32777, 32785, 32778>,
    <32777, 32778, 32782>    <32777, 32782, 32779>,
    <32777, 32779, 32783>    <32777, 32783, 32780>,
    <32777, 32780, 32784>    <32777, 32784, 32781>,
    <32777, 32781, 32785>    <32786, 32794, 32787>,
    <32786, 32787, 32791>    <32786, 32791, 32788>,
    <32786, 32788, 32792>    <32786, 32792, 32789>,
    <32786, 32789, 32793>    <32786, 32793, 32790>,
    <32786, 32790, 32794>    <32795, 32803, 32796>,
    <32795, 32796, 32800>    <32795, 32800, 32797>,
    <32795, 32797, 32801>    <32795, 32801, 32798>,
    <32795, 32798, 32802>    <32795, 32802, 32799>,
    <32795, 32799, 32803>    <32804, 32812, 32805>,
    <32804, 32805, 32809>    <32804, 32809, 32806>,
    <32804, 32806, 32810>    <32804, 32810, 32807>,
    <32804, 32807, 32811>    <32804, 32811, 32808>,
    <32804, 32808, 32812>    <32813, 32821, 32814>,
    <32813, 32814, 32818>    <32813, 32818, 32815>,
    <32813, 32815, 32819>    <32813, 32819, 32816>,
    <32813, 32816, 32820>    <32813, 32820, 32817>,
    <32813, 32817, 32821>    <32822, 32830, 32823>,
    <32822, 32823, 32827>    <32822, 32827, 32824>,
    <32822, 32824, 32828>    <32822, 32828, 32825>,
    <32822, 32825, 32829>    <32822, 32829, 32826>,
    <32822, 32826, 32830>    <32831, 32839, 32832>,
    <32831, 32832, 32836>    <32831, 32836, 32833>,
    <32831, 32833, 32837>    <32831, 32837, 32834>,
    <32831, 32834, 32838>    <32831, 32838, 32835>,
    <32831, 32835, 32839>    <32840, 32848, 32841>,
    <32840, 32841, 32845>    <32840, 32845, 32842>,
    <32840, 32842, 32846>    <32840, 32846, 32843>,
    <32840, 32843, 32847>    <32840, 32847, 32844>,
    <32840, 32844, 32848>    <32849, 32857, 32850>,
    <32849, 32850, 32854>    <32849, 32854, 32851>,
    <32849, 32851, 32855>    <32849, 32855, 32852>,
    <32849, 32852, 32856>    <32849, 32856, 32853>,
    <32849, 32853, 32857>    <32858, 32866, 32859>,
    <32858, 32859, 32863>    <32858, 32863, 32860>,
    <32858, 32860, 32864>    <32858, 32864, 32861>,
    <32858, 32861, 32865>    <32858, 32865, 32862>,
    <32858, 32862, 32866>    <32867, 32875, 32868>,
    <32867, 32868, 32872>    <32867, 32872, 32869>,
    <32867, 32869, 32873>    <32867, 32873, 32870>,
    <32867, 32870, 32874>    <32867, 32874, 32871>,
    <32867, 32871, 32875>    <32876, 32884, 32877>,
    <32876, 32877, 32881>    <32876, 32881, 32878>,
    <32876, 32878, 32882>    <32876, 32882, 32879>,
    <32876, 32879, 32883>    <32876, 32883, 32880>,
    <32876, 32880, 32884>    <32885, 32893, 32886>,
    <32885, 32886, 32890>    <32885, 32890, 32887>,
    <32885, 32887, 32891>    <32885, 32891, 32888>,
    <32885, 32888, 32892>    <32885, 32892, 32889>,
    <32885, 32889, 32893>    <32894, 32902, 32895>,
    <32894, 32895, 32899>    <32894, 32899, 32896>,
    <32894, 32896, 32900>    <32894, 32900, 32897>,
    <32894, 32897, 32901>    <32894, 32901, 32898>,
    <32894, 32898, 32902>    <32903, 32911, 32904>,
    <32903, 32904, 32908>    <32903, 32908, 32905>,
    <32903, 32905, 32909>    <32903, 32909, 32906>,
    <32903, 32906, 32910>    <32903, 32910, 32907>,
    <32903, 32907, 32911>    <32912, 32920, 32913>,
    <32912, 32913, 32917>    <32912, 32917, 32914>,
    <32912, 32914, 32918>    <32912, 32918, 32915>,
    <32912, 32915, 32919>    <32912, 32919, 32916>,
    <32912, 32916, 32920>    <32921, 32929, 32922>,
    <32921, 32922, 32926>    <32921, 32926, 32923>,
    <32921, 32923, 32927>    <32921, 32927, 32924>,
    <32921, 32924, 32928>    <32921, 32928, 32925>,
    <32921, 32925, 32929>    <32930, 32938, 32931>,
    <32930, 32931, 32935>    <32930, 32935, 32932>,
    <32930, 32932, 32936>    <32930, 32936, 32933>,
    <32930, 32933, 32937>    <32930, 32937, 32934>,
    <32930, 32934, 32938>    <32939, 32947, 32940>,
    <32939, 32940, 32944>    <32939, 32944, 32941>,
    <32939, 32941, 32945>    <32939, 32945, 32942>,
    <32939, 32942, 32946>    <32939, 32946, 32943>,
    <32939, 32943, 32947>    <32948, 32956, 32949>,
    <32948, 32949, 32953>    <32948, 32953, 32950>,
    <32948, 32950, 32954>    <32948, 32954, 32951>,
    <32948, 32951, 32955>    <32948, 32955, 32952>,
    <32948, 32952, 32956>    <32957, 32965, 32958>,
    <32957, 32958, 32962>    <32957, 32962, 32959>,
    <32957, 32959, 32963>    <32957, 32963, 32960>,
    <32957, 32960, 32964>    <32957, 32964, 32961>,
    <32957, 32961, 32965>    <32966, 32974, 32967>,
    <32966, 32967, 32971>    <32966, 32971, 32968>,
    <32966, 32968, 32972>    <32966, 32972, 32969>,
    <32966, 32969, 32973>    <32966, 32973, 32970>,
    <32966, 32970, 32974>    <32975, 32983, 32976>,
    <32975, 32976, 32980>    <32975, 32980, 32977>,
    <32975, 32977, 32981>    <32975, 32981, 32978>,
    <32975, 32978, 32982>    <32975, 32982, 32979>,
    <32975, 32979, 32983>    <32984, 32992, 32985>,
    <32984, 32985, 32989>    <32984, 32989, 32986>,
    <32984, 32986, 32990>    <32984, 32990, 32987>,
    <32984, 32987, 32991>    <32984, 32991, 32988>,
    <32984, 32988, 32992>    <32993, 33001, 32994>,
    <32993, 32994, 32998>    <32993, 32998, 32995>,
    <32993, 32995, 32999>    <32993, 32999, 32996>,
    <32993, 32996, 33000>    <32993, 33000, 32997>,
    <32993, 32997, 33001>    <33002, 33010, 33003>,
    <33002, 33003, 33007>    <33002, 33007, 33004>,
    <33002, 33004, 33008>    <33002, 33008, 33005>,
    <33002, 33005, 33009>    <33002, 33009, 33006>,
    <33002, 33006, 33010>    <33011, 33019, 33012>,
    <33011, 33012, 33016>    <33011, 33016, 33013>,
    <33011, 33013, 33017>    <33011, 33017, 33014>,
    <33011, 33014, 33018>    <33011, 33018, 33015>,
    <33011, 33015, 33019>    <33020, 33028, 33021>,
    <33020, 33021, 33025>    <33020, 33025, 33022>,
    <33020, 33022, 33026>    <33020, 33026, 33023>,
    <33020, 33023, 33027>    <33020, 33027, 33024>,
    <33020, 33024, 33028>    <33029, 33037, 33030>,
    <33029, 33030, 33034>    <33029, 33034, 33031>,
    <33029, 33031, 33035>    <33029, 33035, 33032>,
    <33029, 33032, 33036>    <33029, 33036, 33033>,
    <33029, 33033, 33037>    <33038, 33046, 33039>,
    <33038, 33039, 33043>    <33038, 33043, 33040>,
    <33038, 33040, 33044>    <33038, 33044, 33041>,
    <33038, 33041, 33045>    <33038, 33045, 33042>,
    <33038, 33042, 33046>    <33047, 33055, 33048>,
    <33047, 33048, 33052>    <33047, 33052, 33049>,
    <33047, 33049, 33053>    <33047, 33053, 33050>,
    <33047, 33050, 33054>    <33047, 33054, 33051>,
    <33047, 33051, 33055>    <33056, 33064, 33057>,
    <33056, 33057, 33061>    <33056, 33061, 33058>,
    <33056, 33058, 33062>    <33056, 33062, 33059>,
    <33056, 33059, 33063>    <33056, 33063, 33060>,
    <33056, 33060, 33064>    <33065, 33073, 33066>,
    <33065, 33066, 33070>    <33065, 33070, 33067>,
    <33065, 33067, 33071>    <33065, 33071, 33068>,
    <33065, 33068, 33072>    <33065, 33072, 33069>,
    <33065, 33069, 33073>    <33074, 33082, 33075>,
    <33074, 33075, 33079>    <33074, 33079, 33076>,
    <33074, 33076, 33080>    <33074, 33080, 33077>,
    <33074, 33077, 33081>    <33074, 33081, 33078>,
    <33074, 33078, 33082>    <33083, 33091, 33084>,
    <33083, 33084, 33088>    <33083, 33088, 33085>,
    <33083, 33085, 33089>    <33083, 33089, 33086>,
    <33083, 33086, 33090>    <33083, 33090, 33087>,
    <33083, 33087, 33091>    <33092, 33100, 33093>,
    <33092, 33093, 33097>    <33092, 33097, 33094>,
    <33092, 33094, 33098>    <33092, 33098, 33095>,
    <33092, 33095, 33099>    <33092, 33099, 33096>,
    <33092, 33096, 33100>    <33101, 33109, 33102>,
    <33101, 33102, 33106>    <33101, 33106, 33103>,
    <33101, 33103, 33107>    <33101, 33107, 33104>,
    <33101, 33104, 33108>    <33101, 33108, 33105>,
    <33101, 33105, 33109>    <33110, 33118, 33111>,
    <33110, 33111, 33115>    <33110, 33115, 33112>,
    <33110, 33112, 33116>    <33110, 33116, 33113>,
    <33110, 33113, 33117>    <33110, 33117, 33114>,
    <33110, 33114, 33118>    <33119, 33127, 33120>,
    <33119, 33120, 33124>    <33119, 33124, 33121>,
    <33119, 33121, 33125>    <33119, 33125, 33122>,
    <33119, 33122, 33126>    <33119, 33126, 33123>,
    <33119, 33123, 33127>    <33128, 33136, 33129>,
    <33128, 33129, 33133>    <33128, 33133, 33130>,
    <33128, 33130, 33134>    <33128, 33134, 33131>,
    <33128, 33131, 33135>    <33128, 33135, 33132>,
    <33128, 33132, 33136>    <33137, 33145, 33138>,
    <33137, 33138, 33142>    <33137, 33142, 33139>,
    <33137, 33139, 33143>    <33137, 33143, 33140>,
    <33137, 33140, 33144>    <33137, 33144, 33141>,
    <33137, 33141, 33145>    <33146, 33154, 33147>,
    <33146, 33147, 33151>    <33146, 33151, 33148>,
    <33146, 33148, 33152>    <33146, 33152, 33149>,
    <33146, 33149, 33153>    <33146, 33153, 33150>,
    <33146, 33150, 33154>    <33155, 33163, 33156>,
    <33155, 33156, 33160>    <33155, 33160, 33157>,
    <33155, 33157, 33161>    <33155, 33161, 33158>,
    <33155, 33158, 33162>    <33155, 33162, 33159>,
    <33155, 33159, 33163>    <33164, 33172, 33165>,
    <33164, 33165, 33169>    <33164, 33169, 33166>,
    <33164, 33166, 33170>    <33164, 33170, 33167>,
    <33164, 33167, 33171>    <33164, 33171, 33168>,
    <33164, 33168, 33172>    <33173, 33181, 33174>,
    <33173, 33174, 33178>    <33173, 33178, 33175>,
    <33173, 33175, 33179>    <33173, 33179, 33176>,
    <33173, 33176, 33180>    <33173, 33180, 33177>,
    <33173, 33177, 33181>    <33182, 33190, 33183>,
    <33182, 33183, 33187>    <33182, 33187, 33184>,
    <33182, 33184, 33188>    <33182, 33188, 33185>,
    <33182, 33185, 33189>    <33182, 33189, 33186>,
    <33182, 33186, 33190>    <33191, 33199, 33192>,
    <33191, 33192, 33196>    <33191, 33196, 33193>,
    <33191, 33193, 33197>    <33191, 33197, 33194>,
    <33191, 33194, 33198>    <33191, 33198, 33195>,
    <33191, 33195, 33199>    <33200, 33208, 33201>,
    <33200, 33201, 33205>    <33200, 33205, 33202>,
    <33200, 33202, 33206>    <33200, 33206, 33203>,
    <33200, 33203, 33207>    <33200, 33207, 33204>,
    <33200, 33204, 33208>    <33209, 33217, 33210>,
    <33209, 33210, 33214>    <33209, 33214, 33211>,
    <33209, 33211, 33215>    <33209, 33215, 33212>,
    <33209, 33212, 33216>    <33209, 33216, 33213>,
    <33209, 33213, 33217>    <33218, 33226, 33219>,
    <33218, 33219, 33223>    <33218, 33223, 33220>,
    <33218, 33220, 33224>    <33218, 33224, 33221>,
    <33218, 33221, 33225>    <33218, 33225, 33222>,
    <33218, 33222, 33226>    <33227, 33235, 33228>,
    <33227, 33228, 33232>    <33227, 33232, 33229>,
    <33227, 33229, 33233>    <33227, 33233, 33230>,
    <33227, 33230, 33234>    <33227, 33234, 33231>,
    <33227, 33231, 33235>    <33236, 33244, 33237>,
    <33236, 33237, 33241>    <33236, 33241, 33238>,
    <33236, 33238, 33242>    <33236, 33242, 33239>,
    <33236, 33239, 33243>    <33236, 33243, 33240>,
    <33236, 33240, 33244>    <33245, 33253, 33246>,
    <33245, 33246, 33250>    <33245, 33250, 33247>,
    <33245, 33247, 33251>    <33245, 33251, 33248>,
    <33245, 33248, 33252>    <33245, 33252, 33249>,
    <33245, 33249, 33253>    <33254, 33262, 33255>,
    <33254, 33255, 33259>    <33254, 33259, 33256>,
    <33254, 33256, 33260>    <33254, 33260, 33257>,
    <33254, 33257, 33261>    <33254, 33261, 33258>,
    <33254, 33258, 33262>    <33263, 33271, 33264>,
    <33263, 33264, 33268>    <33263, 33268, 33265>,
    <33263, 33265, 33269>    <33263, 33269, 33266>,
    <33263, 33266, 33270>    <33263, 33270, 33267>,
    <33263, 33267, 33271>    <33272, 33280, 33273>,
    <33272, 33273, 33277>    <33272, 33277, 33274>,
    <33272, 33274, 33278>    <33272, 33278, 33275>,
    <33272, 33275, 33279>    <33272, 33279, 33276>,
    <33272, 33276, 33280>    <33281, 33289, 33282>,
    <33281, 33282, 33286>    <33281, 33286, 33283>,
    <33281, 33283, 33287>    <33281, 33287, 33284>,
    <33281, 33284, 33288>    <33281, 33288, 33285>,
    <33281, 33285, 33289>    <33290, 33298, 33291>,
    <33290, 33291, 33295>    <33290, 33295, 33292>,
    <33290, 33292, 33296>    <33290, 33296, 33293>,
    <33290, 33293, 33297>    <33290, 33297, 33294>,
    <33290, 33294, 33298>    <33299, 33307, 33300>,
    <33299, 33300, 33304>    <33299, 33304, 33301>,
    <33299, 33301, 33305>    <33299, 33305, 33302>,
    <33299, 33302, 33306>    <33299, 33306, 33303>,
    <33299, 33303, 33307>    <33308, 33316, 33309>,
    <33308, 33309, 33313>    <33308, 33313, 33310>,
    <33308, 33310, 33314>    <33308, 33314, 33311>,
    <33308, 33311, 33315>    <33308, 33315, 33312>,
    <33308, 33312, 33316>    <33317, 33325, 33318>,
    <33317, 33318, 33322>    <33317, 33322, 33319>,
    <33317, 33319, 33323>    <33317, 33323, 33320>,
    <33317, 33320, 33324>    <33317, 33324, 33321>,
    <33317, 33321, 33325>    <33326, 33334, 33327>,
    <33326, 33327, 33331>    <33326, 33331, 33328>,
    <33326, 33328, 33332>    <33326, 33332, 33329>,
    <33326, 33329, 33333>    <33326, 33333, 33330>,
    <33326, 33330, 33334>    <33335, 33343, 33336>,
    <33335, 33336, 33340>    <33335, 33340, 33337>,
    <33335, 33337, 33341>    <33335, 33341, 33338>,
    <33335, 33338, 33342>    <33335, 33342, 33339>,
    <33335, 33339, 33343>    <33344, 33352, 33345>,
    <33344, 33345, 33349>    <33344, 33349, 33346>,
    <33344, 33346, 33350>    <33344, 33350, 33347>,
    <33344, 33347, 33351>    <33344, 33351, 33348>,
    <33344, 33348, 33352>    <33353, 33361, 33354>,
    <33353, 33354, 33358>    <33353, 33358, 33355>,
    <33353, 33355, 33359>    <33353, 33359, 33356>,
    <33353, 33356, 33360>    <33353, 33360, 33357>,
    <33353, 33357, 33361>    <33362, 33370, 33363>,
    <33362, 33363, 33367>    <33362, 33367, 33364>,
    <33362, 33364, 33368>    <33362, 33368, 33365>,
    <33362, 33365, 33369>    <33362, 33369, 33366>,
    <33362, 33366, 33370>    <33371, 33379, 33372>,
    <33371, 33372, 33376>    <33371, 33376, 33373>,
    <33371, 33373, 33377>    <33371, 33377, 33374>,
    <33371, 33374, 33378>    <33371, 33378, 33375>,
    <33371, 33375, 33379>    <33380, 33388, 33381>,
    <33380, 33381, 33385>    <33380, 33385, 33382>,
    <33380, 33382, 33386>    <33380, 33386, 33383>,
    <33380, 33383, 33387>    <33380, 33387, 33384>,
    <33380, 33384, 33388>    <33389, 33397, 33390>,
    <33389, 33390, 33394>    <33389, 33394, 33391>,
    <33389, 33391, 33395>    <33389, 33395, 33392>,
    <33389, 33392, 33396>    <33389, 33396, 33393>,
    <33389, 33393, 33397>    <33398, 33406, 33399>,
    <33398, 33399, 33403>    <33398, 33403, 33400>,
    <33398, 33400, 33404>    <33398, 33404, 33401>,
    <33398, 33401, 33405>    <33398, 33405, 33402>,
    <33398, 33402, 33406>    <33407, 33415, 33408>,
    <33407, 33408, 33412>    <33407, 33412, 33409>,
    <33407, 33409, 33413>    <33407, 33413, 33410>,
    <33407, 33410, 33414>    <33407, 33414, 33411>,
    <33407, 33411, 33415>    <33416, 33424, 33417>,
    <33416, 33417, 33421>    <33416, 33421, 33418>,
    <33416, 33418, 33422>    <33416, 33422, 33419>,
    <33416, 33419, 33423>    <33416, 33423, 33420>,
    <33416, 33420, 33424>    <33425, 33433, 33426>,
    <33425, 33426, 33430>    <33425, 33430, 33427>,
    <33425, 33427, 33431>    <33425, 33431, 33428>,
    <33425, 33428, 33432>    <33425, 33432, 33429>,
    <33425, 33429, 33433>    <33434, 33442, 33435>,
    <33434, 33435, 33439>    <33434, 33439, 33436>,
    <33434, 33436, 33440>    <33434, 33440, 33437>,
    <33434, 33437, 33441>    <33434, 33441, 33438>,
    <33434, 33438, 33442>    <33443, 33451, 33444>,
    <33443, 33444, 33448>    <33443, 33448, 33445>,
    <33443, 33445, 33449>    <33443, 33449, 33446>,
    <33443, 33446, 33450>    <33443, 33450, 33447>,
    <33443, 33447, 33451>    <33452, 33460, 33453>,
    <33452, 33453, 33457>    <33452, 33457, 33454>,
    <33452, 33454, 33458>    <33452, 33458, 33455>,
    <33452, 33455, 33459>    <33452, 33459, 33456>,
    <33452, 33456, 33460>    <33461, 33469, 33462>,
    <33461, 33462, 33466>    <33461, 33466, 33463>,
    <33461, 33463, 33467>    <33461, 33467, 33464>,
    <33461, 33464, 33468>    <33461, 33468, 33465>,
    <33461, 33465, 33469>    <33470, 33478, 33471>,
    <33470, 33471, 33475>    <33470, 33475, 33472>,
    <33470, 33472, 33476>    <33470, 33476, 33473>,
    <33470, 33473, 33477>    <33470, 33477, 33474>,
    <33470, 33474, 33478>    <33479, 33487, 33480>,
    <33479, 33480, 33484>    <33479, 33484, 33481>,
    <33479, 33481, 33485>    <33479, 33485, 33482>,
    <33479, 33482, 33486>    <33479, 33486, 33483>,
    <33479, 33483, 33487>    <33488, 33496, 33489>,
    <33488, 33489, 33493>    <33488, 33493, 33490>,
    <33488, 33490, 33494>    <33488, 33494, 33491>,
    <33488, 33491, 33495>    <33488, 33495, 33492>,
    <33488, 33492, 33496>    <33497, 33505, 33498>,
    <33497, 33498, 33502>    <33497, 33502, 33499>,
    <33497, 33499, 33503>    <33497, 33503, 33500>,
    <33497, 33500, 33504>    <33497, 33504, 33501>,
    <33497, 33501, 33505>    <33506, 33514, 33507>,
    <33506, 33507, 33511>    <33506, 33511, 33508>,
    <33506, 33508, 33512>    <33506, 33512, 33509>,
    <33506, 33509, 33513>    <33506, 33513, 33510>,
    <33506, 33510, 33514>    <33515, 33523, 33516>,
    <33515, 33516, 33520>    <33515, 33520, 33517>,
    <33515, 33517, 33521>    <33515, 33521, 33518>,
    <33515, 33518, 33522>    <33515, 33522, 33519>,
    <33515, 33519, 33523>    <33524, 33532, 33525>,
    <33524, 33525, 33529>    <33524, 33529, 33526>,
    <33524, 33526, 33530>    <33524, 33530, 33527>,
    <33524, 33527, 33531>    <33524, 33531, 33528>,
    <33524, 33528, 33532>    <33533, 33541, 33534>,
    <33533, 33534, 33538>    <33533, 33538, 33535>,
    <33533, 33535, 33539>    <33533, 33539, 33536>,
    <33533, 33536, 33540>    <33533, 33540, 33537>,
    <33533, 33537, 33541>    <33542, 33550, 33543>,
    <33542, 33543, 33547>    <33542, 33547, 33544>,
    <33542, 33544, 33548>    <33542, 33548, 33545>,
    <33542, 33545, 33549>    <33542, 33549, 33546>,
    <33542, 33546, 33550>    <33551, 33559, 33552>,
    <33551, 33552, 33556>    <33551, 33556, 33553>,
    <33551, 33553, 33557>    <33551, 33557, 33554>,
    <33551, 33554, 33558>    <33551, 33558, 33555>,
    <33551, 33555, 33559>    <33560, 33568, 33561>,
    <33560, 33561, 33565>    <33560, 33565, 33562>,
    <33560, 33562, 33566>    <33560, 33566, 33563>,
    <33560, 33563, 33567>    <33560, 33567, 33564>,
    <33560, 33564, 33568>    <33569, 33577, 33570>,
    <33569, 33570, 33574>    <33569, 33574, 33571>,
    <33569, 33571, 33575>    <33569, 33575, 33572>,
    <33569, 33572, 33576>    <33569, 33576, 33573>,
    <33569, 33573, 33577>    <33578, 33586, 33579>,
    <33578, 33579, 33583>    <33578, 33583, 33580>,
    <33578, 33580, 33584>    <33578, 33584, 33581>,
    <33578, 33581, 33585>    <33578, 33585, 33582>,
    <33578, 33582, 33586>    <33587, 33595, 33588>,
    <33587, 33588, 33592>    <33587, 33592, 33589>,
    <33587, 33589, 33593>    <33587, 33593, 33590>,
    <33587, 33590, 33594>    <33587, 33594, 33591>,
    <33587, 33591, 33595>    <33596, 33604, 33597>,
    <33596, 33597, 33601>    <33596, 33601, 33598>,
    <33596, 33598, 33602>    <33596, 33602, 33599>,
    <33596, 33599, 33603>    <33596, 33603, 33600>,
    <33596, 33600, 33604>    <33605, 33613, 33606>,
    <33605, 33606, 33610>    <33605, 33610, 33607>,
    <33605, 33607, 33611>    <33605, 33611, 33608>,
    <33605, 33608, 33612>    <33605, 33612, 33609>,
    <33605, 33609, 33613>    <33614, 33622, 33615>,
    <33614, 33615, 33619>    <33614, 33619, 33616>,
    <33614, 33616, 33620>    <33614, 33620, 33617>,
    <33614, 33617, 33621>    <33614, 33621, 33618>,
    <33614, 33618, 33622>    <33623, 33631, 33624>,
    <33623, 33624, 33628>    <33623, 33628, 33625>,
    <33623, 33625, 33629>    <33623, 33629, 33626>,
    <33623, 33626, 33630>    <33623, 33630, 33627>,
    <33623, 33627, 33631>    <33632, 33640, 33633>,
    <33632, 33633, 33637>    <33632, 33637, 33634>,
    <33632, 33634, 33638>    <33632, 33638, 33635>,
    <33632, 33635, 33639>    <33632, 33639, 33636>,
    <33632, 33636, 33640>    <33641, 33649, 33642>,
    <33641, 33642, 33646>    <33641, 33646, 33643>,
    <33641, 33643, 33647>    <33641, 33647, 33644>,
    <33641, 33644, 33648>    <33641, 33648, 33645>,
    <33641, 33645, 33649>    <33650, 33658, 33651>,
    <33650, 33651, 33655>    <33650, 33655, 33652>,
    <33650, 33652, 33656>    <33650, 33656, 33653>,
    <33650, 33653, 33657>    <33650, 33657, 33654>,
    <33650, 33654, 33658>    <33659, 33667, 33660>,
    <33659, 33660, 33664>    <33659, 33664, 33661>,
    <33659, 33661, 33665>    <33659, 33665, 33662>,
    <33659, 33662, 33666>    <33659, 33666, 33663>,
    <33659, 33663, 33667>    <33668, 33676, 33669>,
    <33668, 33669, 33673>    <33668, 33673, 33670>,
    <33668, 33670, 33674>    <33668, 33674, 33671>,
    <33668, 33671, 33675>    <33668, 33675, 33672>,
    <33668, 33672, 33676>    <33677, 33685, 33678>,
    <33677, 33678, 33682>    <33677, 33682, 33679>,
    <33677, 33679, 33683>    <33677, 33683, 33680>,
    <33677, 33680, 33684>    <33677, 33684, 33681>,
    <33677, 33681, 33685>    <33686, 33694, 33687>,
    <33686, 33687, 33691>    <33686, 33691, 33688>,
    <33686, 33688, 33692>    <33686, 33692, 33689>,
    <33686, 33689, 33693>    <33686, 33693, 33690>,
    <33686, 33690, 33694>    <33695, 33703, 33696>,
    <33695, 33696, 33700>    <33695, 33700, 33697>,
    <33695, 33697, 33701>    <33695, 33701, 33698>,
    <33695, 33698, 33702>    <33695, 33702, 33699>,
    <33695, 33699, 33703>    <33704, 33712, 33705>,
    <33704, 33705, 33709>    <33704, 33709, 33706>,
    <33704, 33706, 33710>    <33704, 33710, 33707>,
    <33704, 33707, 33711>    <33704, 33711, 33708>,
    <33704, 33708, 33712>    <33713, 33721, 33714>,
    <33713, 33714, 33718>    <33713, 33718, 33715>,
    <33713, 33715, 33719>    <33713, 33719, 33716>,
    <33713, 33716, 33720>    <33713, 33720, 33717>,
    <33713, 33717, 33721>    <33722, 33730, 33723>,
    <33722, 33723, 33727>    <33722, 33727, 33724>,
    <33722, 33724, 33728>    <33722, 33728, 33725>,
    <33722, 33725, 33729>    <33722, 33729, 33726>,
    <33722, 33726, 33730>    <33731, 33739, 33732>,
    <33731, 33732, 33736>    <33731, 33736, 33733>,
    <33731, 33733, 33737>    <33731, 33737, 33734>,
    <33731, 33734, 33738>    <33731, 33738, 33735>,
    <33731, 33735, 33739>    <33740, 33748, 33741>,
    <33740, 33741, 33745>    <33740, 33745, 33742>,
    <33740, 33742, 33746>    <33740, 33746, 33743>,
    <33740, 33743, 33747>    <33740, 33747, 33744>,
    <33740, 33744, 33748>    <33749, 33757, 33750>,
    <33749, 33750, 33754>    <33749, 33754, 33751>,
    <33749, 33751, 33755>    <33749, 33755, 33752>,
    <33749, 33752, 33756>    <33749, 33756, 33753>,
    <33749, 33753, 33757>    <33758, 33766, 33759>,
    <33758, 33759, 33763>    <33758, 33763, 33760>,
    <33758, 33760, 33764>    <33758, 33764, 33761>,
    <33758, 33761, 33765>    <33758, 33765, 33762>,
    <33758, 33762, 33766>    <33767, 33775, 33768>,
    <33767, 33768, 33772>    <33767, 33772, 33769>,
    <33767, 33769, 33773>    <33767, 33773, 33770>,
    <33767, 33770, 33774>    <33767, 33774, 33771>,
    <33767, 33771, 33775>    <33776, 33784, 33777>,
    <33776, 33777, 33781>    <33776, 33781, 33778>,
    <33776, 33778, 33782>    <33776, 33782, 33779>,
    <33776, 33779, 33783>    <33776, 33783, 33780>,
    <33776, 33780, 33784>    <33785, 33793, 33786>,
    <33785, 33786, 33790>    <33785, 33790, 33787>,
    <33785, 33787, 33791>    <33785, 33791, 33788>,
    <33785, 33788, 33792>    <33785, 33792, 33789>,
    <33785, 33789, 33793>    <33794, 33802, 33795>,
    <33794, 33795, 33799>    <33794, 33799, 33796>,
    <33794, 33796, 33800>    <33794, 33800, 33797>,
    <33794, 33797, 33801>    <33794, 33801, 33798>,
    <33794, 33798, 33802>    <33803, 33811, 33804>,
    <33803, 33804, 33808>    <33803, 33808, 33805>,
    <33803, 33805, 33809>    <33803, 33809, 33806>,
    <33803, 33806, 33810>    <33803, 33810, 33807>,
    <33803, 33807, 33811>    <33812, 33820, 33813>,
    <33812, 33813, 33817>    <33812, 33817, 33814>,
    <33812, 33814, 33818>    <33812, 33818, 33815>,
    <33812, 33815, 33819>    <33812, 33819, 33816>,
    <33812, 33816, 33820>    <33821, 33829, 33822>,
    <33821, 33822, 33826>    <33821, 33826, 33823>,
    <33821, 33823, 33827>    <33821, 33827, 33824>,
    <33821, 33824, 33828>    <33821, 33828, 33825>,
    <33821, 33825, 33829>    <33830, 33838, 33831>,
    <33830, 33831, 33835>    <33830, 33835, 33832>,
    <33830, 33832, 33836>    <33830, 33836, 33833>,
    <33830, 33833, 33837>    <33830, 33837, 33834>,
    <33830, 33834, 33838>    <33839, 33847, 33840>,
    <33839, 33840, 33844>    <33839, 33844, 33841>,
    <33839, 33841, 33845>    <33839, 33845, 33842>,
    <33839, 33842, 33846>    <33839, 33846, 33843>,
    <33839, 33843, 33847>    <33848, 33856, 33849>,
    <33848, 33849, 33853>    <33848, 33853, 33850>,
    <33848, 33850, 33854>    <33848, 33854, 33851>,
    <33848, 33851, 33855>    <33848, 33855, 33852>,
    <33848, 33852, 33856>    <33857, 33865, 33858>,
    <33857, 33858, 33862>    <33857, 33862, 33859>,
    <33857, 33859, 33863>    <33857, 33863, 33860>,
    <33857, 33860, 33864>    <33857, 33864, 33861>,
    <33857, 33861, 33865>    <33866, 33874, 33867>,
    <33866, 33867, 33871>    <33866, 33871, 33868>,
    <33866, 33868, 33872>    <33866, 33872, 33869>,
    <33866, 33869, 33873>    <33866, 33873, 33870>,
    <33866, 33870, 33874>    <33875, 33883, 33876>,
    <33875, 33876, 33880>    <33875, 33880, 33877>,
    <33875, 33877, 33881>    <33875, 33881, 33878>,
    <33875, 33878, 33882>    <33875, 33882, 33879>,
    <33875, 33879, 33883>    <33884, 33892, 33885>,
    <33884, 33885, 33889>    <33884, 33889, 33886>,
    <33884, 33886, 33890>    <33884, 33890, 33887>,
    <33884, 33887, 33891>    <33884, 33891, 33888>,
    <33884, 33888, 33892>    <33893, 33901, 33894>,
    <33893, 33894, 33898>    <33893, 33898, 33895>,
    <33893, 33895, 33899>    <33893, 33899, 33896>,
    <33893, 33896, 33900>    <33893, 33900, 33897>,
    <33893, 33897, 33901>    <33902, 33910, 33903>,
    <33902, 33903, 33907>    <33902, 33907, 33904>,
    <33902, 33904, 33908>    <33902, 33908, 33905>,
    <33902, 33905, 33909>    <33902, 33909, 33906>,
    <33902, 33906, 33910>    <33911, 33919, 33912>,
    <33911, 33912, 33916>    <33911, 33916, 33913>,
    <33911, 33913, 33917>    <33911, 33917, 33914>,
    <33911, 33914, 33918>    <33911, 33918, 33915>,
    <33911, 33915, 33919>    <33920, 33928, 33921>,
    <33920, 33921, 33925>    <33920, 33925, 33922>,
    <33920, 33922, 33926>    <33920, 33926, 33923>,
    <33920, 33923, 33927>    <33920, 33927, 33924>,
    <33920, 33924, 33928>    <33929, 33937, 33930>,
    <33929, 33930, 33934>    <33929, 33934, 33931>,
    <33929, 33931, 33935>    <33929, 33935, 33932>,
    <33929, 33932, 33936>    <33929, 33936, 33933>,
    <33929, 33933, 33937>    <33938, 33946, 33939>,
    <33938, 33939, 33943>    <33938, 33943, 33940>,
    <33938, 33940, 33944>    <33938, 33944, 33941>,
    <33938, 33941, 33945>    <33938, 33945, 33942>,
    <33938, 33942, 33946>    <33947, 33955, 33948>,
    <33947, 33948, 33952>    <33947, 33952, 33949>,
    <33947, 33949, 33953>    <33947, 33953, 33950>,
    <33947, 33950, 33954>    <33947, 33954, 33951>,
    <33947, 33951, 33955>    <33956, 33964, 33957>,
    <33956, 33957, 33961>    <33956, 33961, 33958>,
    <33956, 33958, 33962>    <33956, 33962, 33959>,
    <33956, 33959, 33963>    <33956, 33963, 33960>,
    <33956, 33960, 33964>    <33965, 33973, 33966>,
    <33965, 33966, 33970>    <33965, 33970, 33967>,
    <33965, 33967, 33971>    <33965, 33971, 33968>,
    <33965, 33968, 33972>    <33965, 33972, 33969>,
    <33965, 33969, 33973>    <33974, 33982, 33975>,
    <33974, 33975, 33979>    <33974, 33979, 33976>,
    <33974, 33976, 33980>    <33974, 33980, 33977>,
    <33974, 33977, 33981>    <33974, 33981, 33978>,
    <33974, 33978, 33982>    <33983, 33991, 33984>,
    <33983, 33984, 33988>    <33983, 33988, 33985>,
    <33983, 33985, 33989>    <33983, 33989, 33986>,
    <33983, 33986, 33990>    <33983, 33990, 33987>,
    <33983, 33987, 33991>    <33992, 34000, 33993>,
    <33992, 33993, 33997>    <33992, 33997, 33994>,
    <33992, 33994, 33998>    <33992, 33998, 33995>,
    <33992, 33995, 33999>    <33992, 33999, 33996>,
    <33992, 33996, 34000>    <34001, 34009, 34002>,
    <34001, 34002, 34006>    <34001, 34006, 34003>,
    <34001, 34003, 34007>    <34001, 34007, 34004>,
    <34001, 34004, 34008>    <34001, 34008, 34005>,
    <34001, 34005, 34009>    <34010, 34018, 34011>,
    <34010, 34011, 34015>    <34010, 34015, 34012>,
    <34010, 34012, 34016>    <34010, 34016, 34013>,
    <34010, 34013, 34017>    <34010, 34017, 34014>,
    <34010, 34014, 34018>    <34019, 34027, 34020>,
    <34019, 34020, 34024>    <34019, 34024, 34021>,
    <34019, 34021, 34025>    <34019, 34025, 34022>,
    <34019, 34022, 34026>    <34019, 34026, 34023>,
    <34019, 34023, 34027>    <34028, 34036, 34029>,
    <34028, 34029, 34033>    <34028, 34033, 34030>,
    <34028, 34030, 34034>    <34028, 34034, 34031>,
    <34028, 34031, 34035>    <34028, 34035, 34032>,
    <34028, 34032, 34036>    <34037, 34045, 34038>,
    <34037, 34038, 34042>    <34037, 34042, 34039>,
    <34037, 34039, 34043>    <34037, 34043, 34040>,
    <34037, 34040, 34044>    <34037, 34044, 34041>,
    <34037, 34041, 34045>    <34046, 34054, 34047>,
    <34046, 34047, 34051>    <34046, 34051, 34048>,
    <34046, 34048, 34052>    <34046, 34052, 34049>,
    <34046, 34049, 34053>    <34046, 34053, 34050>,
    <34046, 34050, 34054>    <34055, 34063, 34056>,
    <34055, 34056, 34060>    <34055, 34060, 34057>,
    <34055, 34057, 34061>    <34055, 34061, 34058>,
    <34055, 34058, 34062>    <34055, 34062, 34059>,
    <34055, 34059, 34063>    <34064, 34072, 34065>,
    <34064, 34065, 34069>    <34064, 34069, 34066>,
    <34064, 34066, 34070>    <34064, 34070, 34067>,
    <34064, 34067, 34071>    <34064, 34071, 34068>,
    <34064, 34068, 34072>    <34073, 34081, 34074>,
    <34073, 34074, 34078>    <34073, 34078, 34075>,
    <34073, 34075, 34079>    <34073, 34079, 34076>,
    <34073, 34076, 34080>    <34073, 34080, 34077>,
    <34073, 34077, 34081>    <34082, 34090, 34083>,
    <34082, 34083, 34087>    <34082, 34087, 34084>,
    <34082, 34084, 34088>    <34082, 34088, 34085>,
    <34082, 34085, 34089>    <34082, 34089, 34086>,
    <34082, 34086, 34090>    <34091, 34099, 34092>,
    <34091, 34092, 34096>    <34091, 34096, 34093>,
    <34091, 34093, 34097>    <34091, 34097, 34094>,
    <34091, 34094, 34098>    <34091, 34098, 34095>,
    <34091, 34095, 34099>    <34100, 34108, 34101>,
    <34100, 34101, 34105>    <34100, 34105, 34102>,
    <34100, 34102, 34106>    <34100, 34106, 34103>,
    <34100, 34103, 34107>    <34100, 34107, 34104>,
    <34100, 34104, 34108>    <34109, 34117, 34110>,
    <34109, 34110, 34114>    <34109, 34114, 34111>,
    <34109, 34111, 34115>    <34109, 34115, 34112>,
    <34109, 34112, 34116>    <34109, 34116, 34113>,
    <34109, 34113, 34117>    <34118, 34126, 34119>,
    <34118, 34119, 34123>    <34118, 34123, 34120>,
    <34118, 34120, 34124>    <34118, 34124, 34121>,
    <34118, 34121, 34125>    <34118, 34125, 34122>,
    <34118, 34122, 34126>    <34127, 34135, 34128>,
    <34127, 34128, 34132>    <34127, 34132, 34129>,
    <34127, 34129, 34133>    <34127, 34133, 34130>,
    <34127, 34130, 34134>    <34127, 34134, 34131>,
    <34127, 34131, 34135>    <34136, 34144, 34137>,
    <34136, 34137, 34141>    <34136, 34141, 34138>,
    <34136, 34138, 34142>    <34136, 34142, 34139>,
    <34136, 34139, 34143>    <34136, 34143, 34140>,
    <34136, 34140, 34144>    <34145, 34153, 34146>,
    <34145, 34146, 34150>    <34145, 34150, 34147>,
    <34145, 34147, 34151>    <34145, 34151, 34148>,
    <34145, 34148, 34152>    <34145, 34152, 34149>,
    <34145, 34149, 34153>    <34154, 34162, 34155>,
    <34154, 34155, 34159>    <34154, 34159, 34156>,
    <34154, 34156, 34160>    <34154, 34160, 34157>,
    <34154, 34157, 34161>    <34154, 34161, 34158>,
    <34154, 34158, 34162>    <34163, 34171, 34164>,
    <34163, 34164, 34168>    <34163, 34168, 34165>,
    <34163, 34165, 34169>    <34163, 34169, 34166>,
    <34163, 34166, 34170>    <34163, 34170, 34167>,
    <34163, 34167, 34171>    <34172, 34180, 34173>,
    <34172, 34173, 34177>    <34172, 34177, 34174>,
    <34172, 34174, 34178>    <34172, 34178, 34175>,
    <34172, 34175, 34179>    <34172, 34179, 34176>,
    <34172, 34176, 34180>    <34181, 34189, 34182>,
    <34181, 34182, 34186>    <34181, 34186, 34183>,
    <34181, 34183, 34187>    <34181, 34187, 34184>,
    <34181, 34184, 34188>    <34181, 34188, 34185>,
    <34181, 34185, 34189>    <34190, 34198, 34191>,
    <34190, 34191, 34195>    <34190, 34195, 34192>,
    <34190, 34192, 34196>    <34190, 34196, 34193>,
    <34190, 34193, 34197>    <34190, 34197, 34194>,
    <34190, 34194, 34198>    <34199, 34207, 34200>,
    <34199, 34200, 34204>    <34199, 34204, 34201>,
    <34199, 34201, 34205>    <34199, 34205, 34202>,
    <34199, 34202, 34206>    <34199, 34206, 34203>,
    <34199, 34203, 34207>    <34208, 34216, 34209>,
    <34208, 34209, 34213>    <34208, 34213, 34210>,
    <34208, 34210, 34214>    <34208, 34214, 34211>,
    <34208, 34211, 34215>    <34208, 34215, 34212>,
    <34208, 34212, 34216>    <34217, 34225, 34218>,
    <34217, 34218, 34222>    <34217, 34222, 34219>,
    <34217, 34219, 34223>    <34217, 34223, 34220>,
    <34217, 34220, 34224>    <34217, 34224, 34221>,
    <34217, 34221, 34225>    <34226, 34234, 34227>,
    <34226, 34227, 34231>    <34226, 34231, 34228>,
    <34226, 34228, 34232>    <34226, 34232, 34229>,
    <34226, 34229, 34233>    <34226, 34233, 34230>,
    <34226, 34230, 34234>    <34235, 34243, 34236>,
    <34235, 34236, 34240>    <34235, 34240, 34237>,
    <34235, 34237, 34241>    <34235, 34241, 34238>,
    <34235, 34238, 34242>    <34235, 34242, 34239>,
    <34235, 34239, 34243>    <34244, 34252, 34245>,
    <34244, 34245, 34249>    <34244, 34249, 34246>,
    <34244, 34246, 34250>    <34244, 34250, 34247>,
    <34244, 34247, 34251>    <34244, 34251, 34248>,
    <34244, 34248, 34252>    <34253, 34261, 34254>,
    <34253, 34254, 34258>    <34253, 34258, 34255>,
    <34253, 34255, 34259>    <34253, 34259, 34256>,
    <34253, 34256, 34260>    <34253, 34260, 34257>,
    <34253, 34257, 34261>    <34262, 34270, 34263>,
    <34262, 34263, 34267>    <34262, 34267, 34264>,
    <34262, 34264, 34268>    <34262, 34268, 34265>,
    <34262, 34265, 34269>    <34262, 34269, 34266>,
    <34262, 34266, 34270>    <34271, 34279, 34272>,
    <34271, 34272, 34276>    <34271, 34276, 34273>,
    <34271, 34273, 34277>    <34271, 34277, 34274>,
    <34271, 34274, 34278>    <34271, 34278, 34275>,
    <34271, 34275, 34279>    <34280, 34288, 34281>,
    <34280, 34281, 34285>    <34280, 34285, 34282>,
    <34280, 34282, 34286>    <34280, 34286, 34283>,
    <34280, 34283, 34287>    <34280, 34287, 34284>,
    <34280, 34284, 34288>    <34289, 34297, 34290>,
    <34289, 34290, 34294>    <34289, 34294, 34291>,
    <34289, 34291, 34295>    <34289, 34295, 34292>,
    <34289, 34292, 34296>    <34289, 34296, 34293>,
    <34289, 34293, 34297>    <34298, 34306, 34299>,
    <34298, 34299, 34303>    <34298, 34303, 34300>,
    <34298, 34300, 34304>    <34298, 34304, 34301>,
    <34298, 34301, 34305>    <34298, 34305, 34302>,
    <34298, 34302, 34306>    <34307, 34315, 34308>,
    <34307, 34308, 34312>    <34307, 34312, 34309>,
    <34307, 34309, 34313>    <34307, 34313, 34310>,
    <34307, 34310, 34314>    <34307, 34314, 34311>,
    <34307, 34311, 34315>    <34316, 34324, 34317>,
    <34316, 34317, 34321>    <34316, 34321, 34318>,
    <34316, 34318, 34322>    <34316, 34322, 34319>,
    <34316, 34319, 34323>    <34316, 34323, 34320>,
    <34316, 34320, 34324>    <34325, 34333, 34326>,
    <34325, 34326, 34330>    <34325, 34330, 34327>,
    <34325, 34327, 34331>    <34325, 34331, 34328>,
    <34325, 34328, 34332>    <34325, 34332, 34329>,
    <34325, 34329, 34333>    <34334, 34342, 34335>,
    <34334, 34335, 34339>    <34334, 34339, 34336>,
    <34334, 34336, 34340>    <34334, 34340, 34337>,
    <34334, 34337, 34341>    <34334, 34341, 34338>,
    <34334, 34338, 34342>    <34343, 34351, 34344>,
    <34343, 34344, 34348>    <34343, 34348, 34345>,
    <34343, 34345, 34349>    <34343, 34349, 34346>,
    <34343, 34346, 34350>    <34343, 34350, 34347>,
    <34343, 34347, 34351>    <34352, 34360, 34353>,
    <34352, 34353, 34357>    <34352, 34357, 34354>,
    <34352, 34354, 34358>    <34352, 34358, 34355>,
    <34352, 34355, 34359>    <34352, 34359, 34356>,
    <34352, 34356, 34360>    <34361, 34369, 34362>,
    <34361, 34362, 34366>    <34361, 34366, 34363>,
    <34361, 34363, 34367>    <34361, 34367, 34364>,
    <34361, 34364, 34368>    <34361, 34368, 34365>,
    <34361, 34365, 34369>    <34370, 34378, 34371>,
    <34370, 34371, 34375>    <34370, 34375, 34372>,
    <34370, 34372, 34376>    <34370, 34376, 34373>,
    <34370, 34373, 34377>    <34370, 34377, 34374>,
    <34370, 34374, 34378>    <34379, 34387, 34380>,
    <34379, 34380, 34384>    <34379, 34384, 34381>,
    <34379, 34381, 34385>    <34379, 34385, 34382>,
    <34379, 34382, 34386>    <34379, 34386, 34383>,
    <34379, 34383, 34387>    <34388, 34396, 34389>,
    <34388, 34389, 34393>    <34388, 34393, 34390>,
    <34388, 34390, 34394>    <34388, 34394, 34391>,
    <34388, 34391, 34395>    <34388, 34395, 34392>,
    <34388, 34392, 34396>    <34397, 34405, 34398>,
    <34397, 34398, 34402>    <34397, 34402, 34399>,
    <34397, 34399, 34403>    <34397, 34403, 34400>,
    <34397, 34400, 34404>    <34397, 34404, 34401>,
    <34397, 34401, 34405>    <34406, 34414, 34407>,
    <34406, 34407, 34411>    <34406, 34411, 34408>,
    <34406, 34408, 34412>    <34406, 34412, 34409>,
    <34406, 34409, 34413>    <34406, 34413, 34410>,
    <34406, 34410, 34414>    <34415, 34423, 34416>,
    <34415, 34416, 34420>    <34415, 34420, 34417>,
    <34415, 34417, 34421>    <34415, 34421, 34418>,
    <34415, 34418, 34422>    <34415, 34422, 34419>,
    <34415, 34419, 34423>    <34424, 34432, 34425>,
    <34424, 34425, 34429>    <34424, 34429, 34426>,
    <34424, 34426, 34430>    <34424, 34430, 34427>,
    <34424, 34427, 34431>    <34424, 34431, 34428>,
    <34424, 34428, 34432>    <34433, 34441, 34434>,
    <34433, 34434, 34438>    <34433, 34438, 34435>,
    <34433, 34435, 34439>    <34433, 34439, 34436>,
    <34433, 34436, 34440>    <34433, 34440, 34437>,
    <34433, 34437, 34441>    <34442, 34450, 34443>,
    <34442, 34443, 34447>    <34442, 34447, 34444>,
    <34442, 34444, 34448>    <34442, 34448, 34445>,
    <34442, 34445, 34449>    <34442, 34449, 34446>,
    <34442, 34446, 34450>    <34451, 34459, 34452>,
    <34451, 34452, 34456>    <34451, 34456, 34453>,
    <34451, 34453, 34457>    <34451, 34457, 34454>,
    <34451, 34454, 34458>    <34451, 34458, 34455>,
    <34451, 34455, 34459>    <34460, 34468, 34461>,
    <34460, 34461, 34465>    <34460, 34465, 34462>,
    <34460, 34462, 34466>    <34460, 34466, 34463>,
    <34460, 34463, 34467>    <34460, 34467, 34464>,
    <34460, 34464, 34468>    <34469, 34477, 34470>,
    <34469, 34470, 34474>    <34469, 34474, 34471>,
    <34469, 34471, 34475>    <34469, 34475, 34472>,
    <34469, 34472, 34476>    <34469, 34476, 34473>,
    <34469, 34473, 34477>    <34478, 34486, 34479>,
    <34478, 34479, 34483>    <34478, 34483, 34480>,
    <34478, 34480, 34484>    <34478, 34484, 34481>,
    <34478, 34481, 34485>    <34478, 34485, 34482>,
    <34478, 34482, 34486>    <34487, 34495, 34488>,
    <34487, 34488, 34492>    <34487, 34492, 34489>,
    <34487, 34489, 34493>    <34487, 34493, 34490>,
    <34487, 34490, 34494>    <34487, 34494, 34491>,
    <34487, 34491, 34495>    <34496, 34504, 34497>,
    <34496, 34497, 34501>    <34496, 34501, 34498>,
    <34496, 34498, 34502>    <34496, 34502, 34499>,
    <34496, 34499, 34503>    <34496, 34503, 34500>,
    <34496, 34500, 34504>    <34505, 34513, 34506>,
    <34505, 34506, 34510>    <34505, 34510, 34507>,
    <34505, 34507, 34511>    <34505, 34511, 34508>,
    <34505, 34508, 34512>    <34505, 34512, 34509>,
    <34505, 34509, 34513>    <34514, 34522, 34515>,
    <34514, 34515, 34519>    <34514, 34519, 34516>,
    <34514, 34516, 34520>    <34514, 34520, 34517>,
    <34514, 34517, 34521>    <34514, 34521, 34518>,
    <34514, 34518, 34522>    <34523, 34531, 34524>,
    <34523, 34524, 34528>    <34523, 34528, 34525>,
    <34523, 34525, 34529>    <34523, 34529, 34526>,
    <34523, 34526, 34530>    <34523, 34530, 34527>,
    <34523, 34527, 34531>    <34532, 34540, 34533>,
    <34532, 34533, 34537>    <34532, 34537, 34534>,
    <34532, 34534, 34538>    <34532, 34538, 34535>,
    <34532, 34535, 34539>    <34532, 34539, 34536>,
    <34532, 34536, 34540>    <34541, 34549, 34542>,
    <34541, 34542, 34546>    <34541, 34546, 34543>,
    <34541, 34543, 34547>    <34541, 34547, 34544>,
    <34541, 34544, 34548>    <34541, 34548, 34545>,
    <34541, 34545, 34549>    <34550, 34558, 34551>,
    <34550, 34551, 34555>    <34550, 34555, 34552>,
    <34550, 34552, 34556>    <34550, 34556, 34553>,
    <34550, 34553, 34557>    <34550, 34557, 34554>,
    <34550, 34554, 34558>    <34559, 34567, 34560>,
    <34559, 34560, 34564>    <34559, 34564, 34561>,
    <34559, 34561, 34565>    <34559, 34565, 34562>,
    <34559, 34562, 34566>    <34559, 34566, 34563>,
    <34559, 34563, 34567>    <34568, 34576, 34569>,
    <34568, 34569, 34573>    <34568, 34573, 34570>,
    <34568, 34570, 34574>    <34568, 34574, 34571>,
    <34568, 34571, 34575>    <34568, 34575, 34572>,
    <34568, 34572, 34576>    <34577, 34585, 34578>,
    <34577, 34578, 34582>    <34577, 34582, 34579>,
    <34577, 34579, 34583>    <34577, 34583, 34580>,
    <34577, 34580, 34584>    <34577, 34584, 34581>,
    <34577, 34581, 34585>    <34586, 34594, 34587>,
    <34586, 34587, 34591>    <34586, 34591, 34588>,
    <34586, 34588, 34592>    <34586, 34592, 34589>,
    <34586, 34589, 34593>    <34586, 34593, 34590>,
    <34586, 34590, 34594>    <34595, 34603, 34596>,
    <34595, 34596, 34600>    <34595, 34600, 34597>,
    <34595, 34597, 34601>    <34595, 34601, 34598>,
    <34595, 34598, 34602>    <34595, 34602, 34599>,
    <34595, 34599, 34603>    <34604, 34612, 34605>,
    <34604, 34605, 34609>    <34604, 34609, 34606>,
    <34604, 34606, 34610>    <34604, 34610, 34607>,
    <34604, 34607, 34611>    <34604, 34611, 34608>,
    <34604, 34608, 34612>    <34613, 34621, 34614>,
    <34613, 34614, 34618>    <34613, 34618, 34615>,
    <34613, 34615, 34619>    <34613, 34619, 34616>,
    <34613, 34616, 34620>    <34613, 34620, 34617>,
    <34613, 34617, 34621>    <34622, 34630, 34623>,
    <34622, 34623, 34627>    <34622, 34627, 34624>,
    <34622, 34624, 34628>    <34622, 34628, 34625>,
    <34622, 34625, 34629>    <34622, 34629, 34626>,
    <34622, 34626, 34630>    <34631, 34639, 34632>,
    <34631, 34632, 34636>    <34631, 34636, 34633>,
    <34631, 34633, 34637>    <34631, 34637, 34634>,
    <34631, 34634, 34638>    <34631, 34638, 34635>,
    <34631, 34635, 34639>    <34640, 34648, 34641>,
    <34640, 34641, 34645>    <34640, 34645, 34642>,
    <34640, 34642, 34646>    <34640, 34646, 34643>,
    <34640, 34643, 34647>    <34640, 34647, 34644>,
    <34640, 34644, 34648>    <34649, 34657, 34650>,
    <34649, 34650, 34654>    <34649, 34654, 34651>,
    <34649, 34651, 34655>    <34649, 34655, 34652>,
    <34649, 34652, 34656>    <34649, 34656, 34653>,
    <34649, 34653, 34657>    <34658, 34666, 34659>,
    <34658, 34659, 34663>    <34658, 34663, 34660>,
    <34658, 34660, 34664>    <34658, 34664, 34661>,
    <34658, 34661, 34665>    <34658, 34665, 34662>,
    <34658, 34662, 34666>    <34667, 34675, 34668>,
    <34667, 34668, 34672>    <34667, 34672, 34669>,
    <34667, 34669, 34673>    <34667, 34673, 34670>,
    <34667, 34670, 34674>    <34667, 34674, 34671>,
    <34667, 34671, 34675>    <34676, 34684, 34677>,
    <34676, 34677, 34681>    <34676, 34681, 34678>,
    <34676, 34678, 34682>    <34676, 34682, 34679>,
    <34676, 34679, 34683>    <34676, 34683, 34680>,
    <34676, 34680, 34684>    <34685, 34693, 34686>,
    <34685, 34686, 34690>    <34685, 34690, 34687>,
    <34685, 34687, 34691>    <34685, 34691, 34688>,
    <34685, 34688, 34692>    <34685, 34692, 34689>,
    <34685, 34689, 34693>    <34694, 34702, 34695>,
    <34694, 34695, 34699>    <34694, 34699, 34696>,
    <34694, 34696, 34700>    <34694, 34700, 34697>,
    <34694, 34697, 34701>    <34694, 34701, 34698>,
    <34694, 34698, 34702>    <34703, 34711, 34704>,
    <34703, 34704, 34708>    <34703, 34708, 34705>,
    <34703, 34705, 34709>    <34703, 34709, 34706>,
    <34703, 34706, 34710>    <34703, 34710, 34707>,
    <34703, 34707, 34711>    <34712, 34720, 34713>,
    <34712, 34713, 34717>    <34712, 34717, 34714>,
    <34712, 34714, 34718>    <34712, 34718, 34715>,
    <34712, 34715, 34719>    <34712, 34719, 34716>,
    <34712, 34716, 34720>    <34721, 34729, 34722>,
    <34721, 34722, 34726>    <34721, 34726, 34723>,
    <34721, 34723, 34727>    <34721, 34727, 34724>,
    <34721, 34724, 34728>    <34721, 34728, 34725>,
    <34721, 34725, 34729>    <34730, 34738, 34731>,
    <34730, 34731, 34735>    <34730, 34735, 34732>,
    <34730, 34732, 34736>    <34730, 34736, 34733>,
    <34730, 34733, 34737>    <34730, 34737, 34734>,
    <34730, 34734, 34738>    <34739, 34747, 34740>,
    <34739, 34740, 34744>    <34739, 34744, 34741>,
    <34739, 34741, 34745>    <34739, 34745, 34742>,
    <34739, 34742, 34746>    <34739, 34746, 34743>,
    <34739, 34743, 34747>    <34748, 34756, 34749>,
    <34748, 34749, 34753>    <34748, 34753, 34750>,
    <34748, 34750, 34754>    <34748, 34754, 34751>,
    <34748, 34751, 34755>    <34748, 34755, 34752>,
    <34748, 34752, 34756>    <34757, 34765, 34758>,
    <34757, 34758, 34762>    <34757, 34762, 34759>,
    <34757, 34759, 34763>    <34757, 34763, 34760>,
    <34757, 34760, 34764>    <34757, 34764, 34761>,
    <34757, 34761, 34765>    <34766, 34774, 34767>,
    <34766, 34767, 34771>    <34766, 34771, 34768>,
    <34766, 34768, 34772>    <34766, 34772, 34769>,
    <34766, 34769, 34773>    <34766, 34773, 34770>,
    <34766, 34770, 34774>    <34775, 34783, 34776>,
    <34775, 34776, 34780>    <34775, 34780, 34777>,
    <34775, 34777, 34781>    <34775, 34781, 34778>,
    <34775, 34778, 34782>    <34775, 34782, 34779>,
    <34775, 34779, 34783>    <34784, 34792, 34785>,
    <34784, 34785, 34789>    <34784, 34789, 34786>,
    <34784, 34786, 34790>    <34784, 34790, 34787>,
    <34784, 34787, 34791>    <34784, 34791, 34788>,
    <34784, 34788, 34792>    <34793, 34801, 34794>,
    <34793, 34794, 34798>    <34793, 34798, 34795>,
    <34793, 34795, 34799>    <34793, 34799, 34796>,
    <34793, 34796, 34800>    <34793, 34800, 34797>,
    <34793, 34797, 34801>    <34802, 34810, 34803>,
    <34802, 34803, 34807>    <34802, 34807, 34804>,
    <34802, 34804, 34808>    <34802, 34808, 34805>,
    <34802, 34805, 34809>    <34802, 34809, 34806>,
    <34802, 34806, 34810>    <34811, 34819, 34812>,
    <34811, 34812, 34816>    <34811, 34816, 34813>,
    <34811, 34813, 34817>    <34811, 34817, 34814>,
    <34811, 34814, 34818>    <34811, 34818, 34815>,
    <34811, 34815, 34819>    <34820, 34828, 34821>,
    <34820, 34821, 34825>    <34820, 34825, 34822>,
    <34820, 34822, 34826>    <34820, 34826, 34823>,
    <34820, 34823, 34827>    <34820, 34827, 34824>,
    <34820, 34824, 34828>    <34829, 34837, 34830>,
    <34829, 34830, 34834>    <34829, 34834, 34831>,
    <34829, 34831, 34835>    <34829, 34835, 34832>,
    <34829, 34832, 34836>    <34829, 34836, 34833>,
    <34829, 34833, 34837>    <34838, 34846, 34839>,
    <34838, 34839, 34843>    <34838, 34843, 34840>,
    <34838, 34840, 34844>    <34838, 34844, 34841>,
    <34838, 34841, 34845>    <34838, 34845, 34842>,
    <34838, 34842, 34846>    <34847, 34855, 34848>,
    <34847, 34848, 34852>    <34847, 34852, 34849>,
    <34847, 34849, 34853>    <34847, 34853, 34850>,
    <34847, 34850, 34854>    <34847, 34854, 34851>,
    <34847, 34851, 34855>    <34856, 34864, 34857>,
    <34856, 34857, 34861>    <34856, 34861, 34858>,
    <34856, 34858, 34862>    <34856, 34862, 34859>,
    <34856, 34859, 34863>    <34856, 34863, 34860>,
    <34856, 34860, 34864>    <34865, 34873, 34866>,
    <34865, 34866, 34870>    <34865, 34870, 34867>,
    <34865, 34867, 34871>    <34865, 34871, 34868>,
    <34865, 34868, 34872>    <34865, 34872, 34869>,
    <34865, 34869, 34873>    <34874, 34882, 34875>,
    <34874, 34875, 34879>    <34874, 34879, 34876>,
    <34874, 34876, 34880>    <34874, 34880, 34877>,
    <34874, 34877, 34881>    <34874, 34881, 34878>,
    <34874, 34878, 34882>    <34883, 34891, 34884>,
    <34883, 34884, 34888>    <34883, 34888, 34885>,
    <34883, 34885, 34889>    <34883, 34889, 34886>,
    <34883, 34886, 34890>    <34883, 34890, 34887>,
    <34883, 34887, 34891>    <34892, 34900, 34893>,
    <34892, 34893, 34897>    <34892, 34897, 34894>,
    <34892, 34894, 34898>    <34892, 34898, 34895>,
    <34892, 34895, 34899>    <34892, 34899, 34896>,
    <34892, 34896, 34900>    <34901, 34909, 34902>,
    <34901, 34902, 34906>    <34901, 34906, 34903>,
    <34901, 34903, 34907>    <34901, 34907, 34904>,
    <34901, 34904, 34908>    <34901, 34908, 34905>,
    <34901, 34905, 34909>    <34910, 34918, 34911>,
    <34910, 34911, 34915>    <34910, 34915, 34912>,
    <34910, 34912, 34916>    <34910, 34916, 34913>,
    <34910, 34913, 34917>    <34910, 34917, 34914>,
    <34910, 34914, 34918>    <34919, 34927, 34920>,
    <34919, 34920, 34924>    <34919, 34924, 34921>,
    <34919, 34921, 34925>    <34919, 34925, 34922>,
    <34919, 34922, 34926>    <34919, 34926, 34923>,
    <34919, 34923, 34927>    <34928, 34936, 34929>,
    <34928, 34929, 34933>    <34928, 34933, 34930>,
    <34928, 34930, 34934>    <34928, 34934, 34931>,
    <34928, 34931, 34935>    <34928, 34935, 34932>,
    <34928, 34932, 34936>    <34937, 34945, 34938>,
    <34937, 34938, 34942>    <34937, 34942, 34939>,
    <34937, 34939, 34943>    <34937, 34943, 34940>,
    <34937, 34940, 34944>    <34937, 34944, 34941>,
    <34937, 34941, 34945>    <34946, 34954, 34947>,
    <34946, 34947, 34951>    <34946, 34951, 34948>,
    <34946, 34948, 34952>    <34946, 34952, 34949>,
    <34946, 34949, 34953>    <34946, 34953, 34950>,
    <34946, 34950, 34954>    <34955, 34963, 34956>,
    <34955, 34956, 34960>    <34955, 34960, 34957>,
    <34955, 34957, 34961>    <34955, 34961, 34958>,
    <34955, 34958, 34962>    <34955, 34962, 34959>,
    <34955, 34959, 34963>    <34964, 34972, 34965>,
    <34964, 34965, 34969>    <34964, 34969, 34966>,
    <34964, 34966, 34970>    <34964, 34970, 34967>,
    <34964, 34967, 34971>    <34964, 34971, 34968>,
    <34964, 34968, 34972>    <34973, 34981, 34974>,
    <34973, 34974, 34978>    <34973, 34978, 34975>,
    <34973, 34975, 34979>    <34973, 34979, 34976>,
    <34973, 34976, 34980>    <34973, 34980, 34977>,
    <34973, 34977, 34981>    <34982, 34990, 34983>,
    <34982, 34983, 34987>    <34982, 34987, 34984>,
    <34982, 34984, 34988>    <34982, 34988, 34985>,
    <34982, 34985, 34989>    <34982, 34989, 34986>,
    <34982, 34986, 34990>    <34991, 34999, 34992>,
    <34991, 34992, 34996>    <34991, 34996, 34993>,
    <34991, 34993, 34997>    <34991, 34997, 34994>,
    <34991, 34994, 34998>    <34991, 34998, 34995>,
    <34991, 34995, 34999>    <35000, 35008, 35001>,
    <35000, 35001, 35005>    <35000, 35005, 35002>,
    <35000, 35002, 35006>    <35000, 35006, 35003>,
    <35000, 35003, 35007>    <35000, 35007, 35004>,
    <35000, 35004, 35008>    <35009, 35017, 35010>,
    <35009, 35010, 35014>    <35009, 35014, 35011>,
    <35009, 35011, 35015>    <35009, 35015, 35012>,
    <35009, 35012, 35016>    <35009, 35016, 35013>,
    <35009, 35013, 35017>    <35018, 35026, 35019>,
    <35018, 35019, 35023>    <35018, 35023, 35020>,
    <35018, 35020, 35024>    <35018, 35024, 35021>,
    <35018, 35021, 35025>    <35018, 35025, 35022>,
    <35018, 35022, 35026>    <35027, 35035, 35028>,
    <35027, 35028, 35032>    <35027, 35032, 35029>,
    <35027, 35029, 35033>    <35027, 35033, 35030>,
    <35027, 35030, 35034>    <35027, 35034, 35031>,
    <35027, 35031, 35035>    <35036, 35044, 35037>,
    <35036, 35037, 35041>    <35036, 35041, 35038>,
    <35036, 35038, 35042>    <35036, 35042, 35039>,
    <35036, 35039, 35043>    <35036, 35043, 35040>,
    <35036, 35040, 35044>    <35045, 35053, 35046>,
    <35045, 35046, 35050>    <35045, 35050, 35047>,
    <35045, 35047, 35051>    <35045, 35051, 35048>,
    <35045, 35048, 35052>    <35045, 35052, 35049>,
    <35045, 35049, 35053>    <35054, 35062, 35055>,
    <35054, 35055, 35059>    <35054, 35059, 35056>,
    <35054, 35056, 35060>    <35054, 35060, 35057>,
    <35054, 35057, 35061>    <35054, 35061, 35058>,
    <35054, 35058, 35062>    <35063, 35071, 35064>,
    <35063, 35064, 35068>    <35063, 35068, 35065>,
    <35063, 35065, 35069>    <35063, 35069, 35066>,
    <35063, 35066, 35070>    <35063, 35070, 35067>,
    <35063, 35067, 35071>    <35072, 35080, 35073>,
    <35072, 35073, 35077>    <35072, 35077, 35074>,
    <35072, 35074, 35078>    <35072, 35078, 35075>,
    <35072, 35075, 35079>    <35072, 35079, 35076>,
    <35072, 35076, 35080>    <35081, 35089, 35082>,
    <35081, 35082, 35086>    <35081, 35086, 35083>,
    <35081, 35083, 35087>    <35081, 35087, 35084>,
    <35081, 35084, 35088>    <35081, 35088, 35085>,
    <35081, 35085, 35089>    <35090, 35098, 35091>,
    <35090, 35091, 35095>    <35090, 35095, 35092>,
    <35090, 35092, 35096>    <35090, 35096, 35093>,
    <35090, 35093, 35097>    <35090, 35097, 35094>,
    <35090, 35094, 35098>    <35099, 35107, 35100>,
    <35099, 35100, 35104>    <35099, 35104, 35101>,
    <35099, 35101, 35105>    <35099, 35105, 35102>,
    <35099, 35102, 35106>    <35099, 35106, 35103>,
    <35099, 35103, 35107>    <35108, 35116, 35109>,
    <35108, 35109, 35113>    <35108, 35113, 35110>,
    <35108, 35110, 35114>    <35108, 35114, 35111>,
    <35108, 35111, 35115>    <35108, 35115, 35112>,
    <35108, 35112, 35116>    <35117, 35125, 35118>,
    <35117, 35118, 35122>    <35117, 35122, 35119>,
    <35117, 35119, 35123>    <35117, 35123, 35120>,
    <35117, 35120, 35124>    <35117, 35124, 35121>,
    <35117, 35121, 35125>    <35126, 35134, 35127>,
    <35126, 35127, 35131>    <35126, 35131, 35128>,
    <35126, 35128, 35132>    <35126, 35132, 35129>,
    <35126, 35129, 35133>    <35126, 35133, 35130>,
    <35126, 35130, 35134>    <35135, 35143, 35136>,
    <35135, 35136, 35140>    <35135, 35140, 35137>,
    <35135, 35137, 35141>    <35135, 35141, 35138>,
    <35135, 35138, 35142>    <35135, 35142, 35139>,
    <35135, 35139, 35143>    <35144, 35152, 35145>,
    <35144, 35145, 35149>    <35144, 35149, 35146>,
    <35144, 35146, 35150>    <35144, 35150, 35147>,
    <35144, 35147, 35151>    <35144, 35151, 35148>,
    <35144, 35148, 35152>    <35153, 35161, 35154>,
    <35153, 35154, 35158>    <35153, 35158, 35155>,
    <35153, 35155, 35159>    <35153, 35159, 35156>,
    <35153, 35156, 35160>    <35153, 35160, 35157>,
    <35153, 35157, 35161>    <35162, 35170, 35163>,
    <35162, 35163, 35167>    <35162, 35167, 35164>,
    <35162, 35164, 35168>    <35162, 35168, 35165>,
    <35162, 35165, 35169>    <35162, 35169, 35166>,
    <35162, 35166, 35170>    <35171, 35179, 35172>,
    <35171, 35172, 35176>    <35171, 35176, 35173>,
    <35171, 35173, 35177>    <35171, 35177, 35174>,
    <35171, 35174, 35178>    <35171, 35178, 35175>,
    <35171, 35175, 35179>    <35180, 35188, 35181>,
    <35180, 35181, 35185>    <35180, 35185, 35182>,
    <35180, 35182, 35186>    <35180, 35186, 35183>,
    <35180, 35183, 35187>    <35180, 35187, 35184>,
    <35180, 35184, 35188>    <35189, 35197, 35190>,
    <35189, 35190, 35194>    <35189, 35194, 35191>,
    <35189, 35191, 35195>    <35189, 35195, 35192>,
    <35189, 35192, 35196>    <35189, 35196, 35193>,
    <35189, 35193, 35197>    <35198, 35206, 35199>,
    <35198, 35199, 35203>    <35198, 35203, 35200>,
    <35198, 35200, 35204>    <35198, 35204, 35201>,
    <35198, 35201, 35205>    <35198, 35205, 35202>,
    <35198, 35202, 35206>    <35207, 35215, 35208>,
    <35207, 35208, 35212>    <35207, 35212, 35209>,
    <35207, 35209, 35213>    <35207, 35213, 35210>,
    <35207, 35210, 35214>    <35207, 35214, 35211>,
    <35207, 35211, 35215>    <35216, 35224, 35217>,
    <35216, 35217, 35221>    <35216, 35221, 35218>,
    <35216, 35218, 35222>    <35216, 35222, 35219>,
    <35216, 35219, 35223>    <35216, 35223, 35220>,
    <35216, 35220, 35224>    <35225, 35233, 35226>,
    <35225, 35226, 35230>    <35225, 35230, 35227>,
    <35225, 35227, 35231>    <35225, 35231, 35228>,
    <35225, 35228, 35232>    <35225, 35232, 35229>,
    <35225, 35229, 35233>    <35234, 35242, 35235>,
    <35234, 35235, 35239>    <35234, 35239, 35236>,
    <35234, 35236, 35240>    <35234, 35240, 35237>,
    <35234, 35237, 35241>    <35234, 35241, 35238>,
    <35234, 35238, 35242>    <35243, 35251, 35244>,
    <35243, 35244, 35248>    <35243, 35248, 35245>,
    <35243, 35245, 35249>    <35243, 35249, 35246>,
    <35243, 35246, 35250>    <35243, 35250, 35247>,
    <35243, 35247, 35251>    <35252, 35260, 35253>,
    <35252, 35253, 35257>    <35252, 35257, 35254>,
    <35252, 35254, 35258>    <35252, 35258, 35255>,
    <35252, 35255, 35259>    <35252, 35259, 35256>,
    <35252, 35256, 35260>    <35261, 35269, 35262>,
    <35261, 35262, 35266>    <35261, 35266, 35263>,
    <35261, 35263, 35267>    <35261, 35267, 35264>,
    <35261, 35264, 35268>    <35261, 35268, 35265>,
    <35261, 35265, 35269>    <35270, 35278, 35271>,
    <35270, 35271, 35275>    <35270, 35275, 35272>,
    <35270, 35272, 35276>    <35270, 35276, 35273>,
    <35270, 35273, 35277>    <35270, 35277, 35274>,
    <35270, 35274, 35278>    <35279, 35287, 35280>,
    <35279, 35280, 35284>    <35279, 35284, 35281>,
    <35279, 35281, 35285>    <35279, 35285, 35282>,
    <35279, 35282, 35286>    <35279, 35286, 35283>,
    <35279, 35283, 35287>    <35288, 35296, 35289>,
    <35288, 35289, 35293>    <35288, 35293, 35290>,
    <35288, 35290, 35294>    <35288, 35294, 35291>,
    <35288, 35291, 35295>    <35288, 35295, 35292>,
    <35288, 35292, 35296>    <35297, 35305, 35298>,
    <35297, 35298, 35302>    <35297, 35302, 35299>,
    <35297, 35299, 35303>    <35297, 35303, 35300>,
    <35297, 35300, 35304>    <35297, 35304, 35301>,
    <35297, 35301, 35305>    <35306, 35314, 35307>,
    <35306, 35307, 35311>    <35306, 35311, 35308>,
    <35306, 35308, 35312>    <35306, 35312, 35309>,
    <35306, 35309, 35313>    <35306, 35313, 35310>,
    <35306, 35310, 35314>    <35315, 35323, 35316>,
    <35315, 35316, 35320>    <35315, 35320, 35317>,
    <35315, 35317, 35321>    <35315, 35321, 35318>,
    <35315, 35318, 35322>    <35315, 35322, 35319>,
    <35315, 35319, 35323>    <35324, 35332, 35325>,
    <35324, 35325, 35329>    <35324, 35329, 35326>,
    <35324, 35326, 35330>    <35324, 35330, 35327>,
    <35324, 35327, 35331>    <35324, 35331, 35328>,
    <35324, 35328, 35332>    <35333, 35341, 35334>,
    <35333, 35334, 35338>    <35333, 35338, 35335>,
    <35333, 35335, 35339>    <35333, 35339, 35336>,
    <35333, 35336, 35340>    <35333, 35340, 35337>,
    <35333, 35337, 35341>    <35342, 35350, 35343>,
    <35342, 35343, 35347>    <35342, 35347, 35344>,
    <35342, 35344, 35348>    <35342, 35348, 35345>,
    <35342, 35345, 35349>    <35342, 35349, 35346>,
    <35342, 35346, 35350>    <35351, 35359, 35352>,
    <35351, 35352, 35356>    <35351, 35356, 35353>,
    <35351, 35353, 35357>    <35351, 35357, 35354>,
    <35351, 35354, 35358>    <35351, 35358, 35355>,
    <35351, 35355, 35359>    <35360, 35368, 35361>,
    <35360, 35361, 35365>    <35360, 35365, 35362>,
    <35360, 35362, 35366>    <35360, 35366, 35363>,
    <35360, 35363, 35367>    <35360, 35367, 35364>,
    <35360, 35364, 35368>    <35369, 35377, 35370>,
    <35369, 35370, 35374>    <35369, 35374, 35371>,
    <35369, 35371, 35375>    <35369, 35375, 35372>,
    <35369, 35372, 35376>    <35369, 35376, 35373>,
    <35369, 35373, 35377>    <35378, 35386, 35379>,
    <35378, 35379, 35383>    <35378, 35383, 35380>,
    <35378, 35380, 35384>    <35378, 35384, 35381>,
    <35378, 35381, 35385>    <35378, 35385, 35382>,
    <35378, 35382, 35386>    <35387, 35395, 35388>,
    <35387, 35388, 35392>    <35387, 35392, 35389>,
    <35387, 35389, 35393>    <35387, 35393, 35390>,
    <35387, 35390, 35394>    <35387, 35394, 35391>,
    <35387, 35391, 35395>    <35396, 35404, 35397>,
    <35396, 35397, 35401>    <35396, 35401, 35398>,
    <35396, 35398, 35402>    <35396, 35402, 35399>,
    <35396, 35399, 35403>    <35396, 35403, 35400>,
    <35396, 35400, 35404>    <35405, 35413, 35406>,
    <35405, 35406, 35410>    <35405, 35410, 35407>,
    <35405, 35407, 35411>    <35405, 35411, 35408>,
    <35405, 35408, 35412>    <35405, 35412, 35409>,
    <35405, 35409, 35413>    <35414, 35422, 35415>,
    <35414, 35415, 35419>    <35414, 35419, 35416>,
    <35414, 35416, 35420>    <35414, 35420, 35417>,
    <35414, 35417, 35421>    <35414, 35421, 35418>,
    <35414, 35418, 35422>    <35423, 35431, 35424>,
    <35423, 35424, 35428>    <35423, 35428, 35425>,
    <35423, 35425, 35429>    <35423, 35429, 35426>,
    <35423, 35426, 35430>    <35423, 35430, 35427>,
    <35423, 35427, 35431>    <35432, 35440, 35433>,
    <35432, 35433, 35437>    <35432, 35437, 35434>,
    <35432, 35434, 35438>    <35432, 35438, 35435>,
    <35432, 35435, 35439>    <35432, 35439, 35436>,
    <35432, 35436, 35440>    <35441, 35449, 35442>,
    <35441, 35442, 35446>    <35441, 35446, 35443>,
    <35441, 35443, 35447>    <35441, 35447, 35444>,
    <35441, 35444, 35448>    <35441, 35448, 35445>,
    <35441, 35445, 35449>    <35450, 35458, 35451>,
    <35450, 35451, 35455>    <35450, 35455, 35452>,
    <35450, 35452, 35456>    <35450, 35456, 35453>,
    <35450, 35453, 35457>    <35450, 35457, 35454>,
    <35450, 35454, 35458>    <35459, 35467, 35460>,
    <35459, 35460, 35464>    <35459, 35464, 35461>,
    <35459, 35461, 35465>    <35459, 35465, 35462>,
    <35459, 35462, 35466>    <35459, 35466, 35463>,
    <35459, 35463, 35467>    <35468, 35476, 35469>,
    <35468, 35469, 35473>    <35468, 35473, 35470>,
    <35468, 35470, 35474>    <35468, 35474, 35471>,
    <35468, 35471, 35475>    <35468, 35475, 35472>,
    <35468, 35472, 35476>    <35477, 35485, 35478>,
    <35477, 35478, 35482>    <35477, 35482, 35479>,
    <35477, 35479, 35483>    <35477, 35483, 35480>,
    <35477, 35480, 35484>    <35477, 35484, 35481>,
    <35477, 35481, 35485>    <35486, 35494, 35487>,
    <35486, 35487, 35491>    <35486, 35491, 35488>,
    <35486, 35488, 35492>    <35486, 35492, 35489>,
    <35486, 35489, 35493>    <35486, 35493, 35490>,
    <35486, 35490, 35494>    <35495, 35503, 35496>,
    <35495, 35496, 35500>    <35495, 35500, 35497>,
    <35495, 35497, 35501>    <35495, 35501, 35498>,
    <35495, 35498, 35502>    <35495, 35502, 35499>,
    <35495, 35499, 35503>    <35504, 35512, 35505>,
    <35504, 35505, 35509>    <35504, 35509, 35506>,
    <35504, 35506, 35510>    <35504, 35510, 35507>,
    <35504, 35507, 35511>    <35504, 35511, 35508>,
    <35504, 35508, 35512>    <35513, 35521, 35514>,
    <35513, 35514, 35518>    <35513, 35518, 35515>,
    <35513, 35515, 35519>    <35513, 35519, 35516>,
    <35513, 35516, 35520>    <35513, 35520, 35517>,
    <35513, 35517, 35521>    <35522, 35530, 35523>,
    <35522, 35523, 35527>    <35522, 35527, 35524>,
    <35522, 35524, 35528>    <35522, 35528, 35525>,
    <35522, 35525, 35529>    <35522, 35529, 35526>,
    <35522, 35526, 35530>    <35531, 35539, 35532>,
    <35531, 35532, 35536>    <35531, 35536, 35533>,
    <35531, 35533, 35537>    <35531, 35537, 35534>,
    <35531, 35534, 35538>    <35531, 35538, 35535>,
    <35531, 35535, 35539>    <35540, 35548, 35541>,
    <35540, 35541, 35545>    <35540, 35545, 35542>,
    <35540, 35542, 35546>    <35540, 35546, 35543>,
    <35540, 35543, 35547>    <35540, 35547, 35544>,
    <35540, 35544, 35548>    <35549, 35557, 35550>,
    <35549, 35550, 35554>    <35549, 35554, 35551>,
    <35549, 35551, 35555>    <35549, 35555, 35552>,
    <35549, 35552, 35556>    <35549, 35556, 35553>,
    <35549, 35553, 35557>    <35558, 35566, 35559>,
    <35558, 35559, 35563>    <35558, 35563, 35560>,
    <35558, 35560, 35564>    <35558, 35564, 35561>,
    <35558, 35561, 35565>    <35558, 35565, 35562>,
    <35558, 35562, 35566>    <35567, 35575, 35568>,
    <35567, 35568, 35572>    <35567, 35572, 35569>,
    <35567, 35569, 35573>    <35567, 35573, 35570>,
    <35567, 35570, 35574>    <35567, 35574, 35571>,
    <35567, 35571, 35575>    <35576, 35584, 35577>,
    <35576, 35577, 35581>    <35576, 35581, 35578>,
    <35576, 35578, 35582>    <35576, 35582, 35579>,
    <35576, 35579, 35583>    <35576, 35583, 35580>,
    <35576, 35580, 35584>    <35585, 35593, 35586>,
    <35585, 35586, 35590>    <35585, 35590, 35587>,
    <35585, 35587, 35591>    <35585, 35591, 35588>,
    <35585, 35588, 35592>    <35585, 35592, 35589>,
    <35585, 35589, 35593>    <35594, 35602, 35595>,
    <35594, 35595, 35599>    <35594, 35599, 35596>,
    <35594, 35596, 35600>    <35594, 35600, 35597>,
    <35594, 35597, 35601>    <35594, 35601, 35598>,
    <35594, 35598, 35602>    <35603, 35611, 35604>,
    <35603, 35604, 35608>    <35603, 35608, 35605>,
    <35603, 35605, 35609>    <35603, 35609, 35606>,
    <35603, 35606, 35610>    <35603, 35610, 35607>,
    <35603, 35607, 35611>    <35612, 35620, 35613>,
    <35612, 35613, 35617>    <35612, 35617, 35614>,
    <35612, 35614, 35618>    <35612, 35618, 35615>,
    <35612, 35615, 35619>    <35612, 35619, 35616>,
    <35612, 35616, 35620>    <35621, 35629, 35622>,
    <35621, 35622, 35626>    <35621, 35626, 35623>,
    <35621, 35623, 35627>    <35621, 35627, 35624>,
    <35621, 35624, 35628>    <35621, 35628, 35625>,
    <35621, 35625, 35629>    <35630, 35638, 35631>,
    <35630, 35631, 35635>    <35630, 35635, 35632>,
    <35630, 35632, 35636>    <35630, 35636, 35633>,
    <35630, 35633, 35637>    <35630, 35637, 35634>,
    <35630, 35634, 35638>    <35639, 35647, 35640>,
    <35639, 35640, 35644>    <35639, 35644, 35641>,
    <35639, 35641, 35645>    <35639, 35645, 35642>,
    <35639, 35642, 35646>    <35639, 35646, 35643>,
    <35639, 35643, 35647>    <35648, 35656, 35649>,
    <35648, 35649, 35653>    <35648, 35653, 35650>,
    <35648, 35650, 35654>    <35648, 35654, 35651>,
    <35648, 35651, 35655>    <35648, 35655, 35652>,
    <35648, 35652, 35656>    <35657, 35665, 35658>,
    <35657, 35658, 35662>    <35657, 35662, 35659>,
    <35657, 35659, 35663>    <35657, 35663, 35660>,
    <35657, 35660, 35664>    <35657, 35664, 35661>,
    <35657, 35661, 35665>    <35666, 35674, 35667>,
    <35666, 35667, 35671>    <35666, 35671, 35668>,
    <35666, 35668, 35672>    <35666, 35672, 35669>,
    <35666, 35669, 35673>    <35666, 35673, 35670>,
    <35666, 35670, 35674>    <35675, 35683, 35676>,
    <35675, 35676, 35680>    <35675, 35680, 35677>,
    <35675, 35677, 35681>    <35675, 35681, 35678>,
    <35675, 35678, 35682>    <35675, 35682, 35679>,
    <35675, 35679, 35683>    <35684, 35692, 35685>,
    <35684, 35685, 35689>    <35684, 35689, 35686>,
    <35684, 35686, 35690>    <35684, 35690, 35687>,
    <35684, 35687, 35691>    <35684, 35691, 35688>,
    <35684, 35688, 35692>    <35693, 35701, 35694>,
    <35693, 35694, 35698>    <35693, 35698, 35695>,
    <35693, 35695, 35699>    <35693, 35699, 35696>,
    <35693, 35696, 35700>    <35693, 35700, 35697>,
    <35693, 35697, 35701>    <35702, 35710, 35703>,
    <35702, 35703, 35707>    <35702, 35707, 35704>,
    <35702, 35704, 35708>    <35702, 35708, 35705>,
    <35702, 35705, 35709>    <35702, 35709, 35706>,
    <35702, 35706, 35710>    <35711, 35719, 35712>,
    <35711, 35712, 35716>    <35711, 35716, 35713>,
    <35711, 35713, 35717>    <35711, 35717, 35714>,
    <35711, 35714, 35718>    <35711, 35718, 35715>,
    <35711, 35715, 35719>    <35720, 35728, 35721>,
    <35720, 35721, 35725>    <35720, 35725, 35722>,
    <35720, 35722, 35726>    <35720, 35726, 35723>,
    <35720, 35723, 35727>    <35720, 35727, 35724>,
    <35720, 35724, 35728>    <35729, 35737, 35730>,
    <35729, 35730, 35734>    <35729, 35734, 35731>,
    <35729, 35731, 35735>    <35729, 35735, 35732>,
    <35729, 35732, 35736>    <35729, 35736, 35733>,
    <35729, 35733, 35737>    <35738, 35746, 35739>,
    <35738, 35739, 35743>    <35738, 35743, 35740>,
    <35738, 35740, 35744>    <35738, 35744, 35741>,
    <35738, 35741, 35745>    <35738, 35745, 35742>,
    <35738, 35742, 35746>    <35747, 35755, 35748>,
    <35747, 35748, 35752>    <35747, 35752, 35749>,
    <35747, 35749, 35753>    <35747, 35753, 35750>,
    <35747, 35750, 35754>    <35747, 35754, 35751>,
    <35747, 35751, 35755>    <35756, 35764, 35757>,
    <35756, 35757, 35761>    <35756, 35761, 35758>,
    <35756, 35758, 35762>    <35756, 35762, 35759>,
    <35756, 35759, 35763>    <35756, 35763, 35760>,
    <35756, 35760, 35764>    <35765, 35773, 35766>,
    <35765, 35766, 35770>    <35765, 35770, 35767>,
    <35765, 35767, 35771>    <35765, 35771, 35768>,
    <35765, 35768, 35772>    <35765, 35772, 35769>,
    <35765, 35769, 35773>    <35774, 35782, 35775>,
    <35774, 35775, 35779>    <35774, 35779, 35776>,
    <35774, 35776, 35780>    <35774, 35780, 35777>,
    <35774, 35777, 35781>    <35774, 35781, 35778>,
    <35774, 35778, 35782>    <35783, 35791, 35784>,
    <35783, 35784, 35788>    <35783, 35788, 35785>,
    <35783, 35785, 35789>    <35783, 35789, 35786>,
    <35783, 35786, 35790>    <35783, 35790, 35787>,
    <35783, 35787, 35791>    <35792, 35800, 35793>,
    <35792, 35793, 35797>    <35792, 35797, 35794>,
    <35792, 35794, 35798>    <35792, 35798, 35795>,
    <35792, 35795, 35799>    <35792, 35799, 35796>,
    <35792, 35796, 35800>    <35801, 35809, 35802>,
    <35801, 35802, 35806>    <35801, 35806, 35803>,
    <35801, 35803, 35807>    <35801, 35807, 35804>,
    <35801, 35804, 35808>    <35801, 35808, 35805>,
    <35801, 35805, 35809>    <35810, 35818, 35811>,
    <35810, 35811, 35815>    <35810, 35815, 35812>,
    <35810, 35812, 35816>    <35810, 35816, 35813>,
    <35810, 35813, 35817>    <35810, 35817, 35814>,
    <35810, 35814, 35818>    <35819, 35827, 35820>,
    <35819, 35820, 35824>    <35819, 35824, 35821>,
    <35819, 35821, 35825>    <35819, 35825, 35822>,
    <35819, 35822, 35826>    <35819, 35826, 35823>,
    <35819, 35823, 35827>    <35828, 35836, 35829>,
    <35828, 35829, 35833>    <35828, 35833, 35830>,
    <35828, 35830, 35834>    <35828, 35834, 35831>,
    <35828, 35831, 35835>    <35828, 35835, 35832>,
    <35828, 35832, 35836>    <35837, 35845, 35838>,
    <35837, 35838, 35842>    <35837, 35842, 35839>,
    <35837, 35839, 35843>    <35837, 35843, 35840>,
    <35837, 35840, 35844>    <35837, 35844, 35841>,
    <35837, 35841, 35845>    <35846, 35854, 35847>,
    <35846, 35847, 35851>    <35846, 35851, 35848>,
    <35846, 35848, 35852>    <35846, 35852, 35849>,
    <35846, 35849, 35853>    <35846, 35853, 35850>,
    <35846, 35850, 35854>    <35855, 35863, 35856>,
    <35855, 35856, 35860>    <35855, 35860, 35857>,
    <35855, 35857, 35861>    <35855, 35861, 35858>,
    <35855, 35858, 35862>    <35855, 35862, 35859>,
    <35855, 35859, 35863>    <35864, 35872, 35865>,
    <35864, 35865, 35869>    <35864, 35869, 35866>,
    <35864, 35866, 35870>    <35864, 35870, 35867>,
    <35864, 35867, 35871>    <35864, 35871, 35868>,
    <35864, 35868, 35872>    <35873, 35881, 35874>,
    <35873, 35874, 35878>    <35873, 35878, 35875>,
    <35873, 35875, 35879>    <35873, 35879, 35876>,
    <35873, 35876, 35880>    <35873, 35880, 35877>,
    <35873, 35877, 35881>    <35882, 35890, 35883>,
    <35882, 35883, 35887>    <35882, 35887, 35884>,
    <35882, 35884, 35888>    <35882, 35888, 35885>,
    <35882, 35885, 35889>    <35882, 35889, 35886>,
    <35882, 35886, 35890>    <35891, 35899, 35892>,
    <35891, 35892, 35896>    <35891, 35896, 35893>,
    <35891, 35893, 35897>    <35891, 35897, 35894>,
    <35891, 35894, 35898>    <35891, 35898, 35895>,
    <35891, 35895, 35899>    <35900, 35908, 35901>,
    <35900, 35901, 35905>    <35900, 35905, 35902>,
    <35900, 35902, 35906>    <35900, 35906, 35903>,
    <35900, 35903, 35907>    <35900, 35907, 35904>,
    <35900, 35904, 35908>    <35909, 35917, 35910>,
    <35909, 35910, 35914>    <35909, 35914, 35911>,
    <35909, 35911, 35915>    <35909, 35915, 35912>,
    <35909, 35912, 35916>    <35909, 35916, 35913>,
    <35909, 35913, 35917>    <35918, 35926, 35919>,
    <35918, 35919, 35923>    <35918, 35923, 35920>,
    <35918, 35920, 35924>    <35918, 35924, 35921>,
    <35918, 35921, 35925>    <35918, 35925, 35922>,
    <35918, 35922, 35926>    <35927, 35935, 35928>,
    <35927, 35928, 35932>    <35927, 35932, 35929>,
    <35927, 35929, 35933>    <35927, 35933, 35930>,
    <35927, 35930, 35934>    <35927, 35934, 35931>,
    <35927, 35931, 35935>    <35936, 35944, 35937>,
    <35936, 35937, 35941>    <35936, 35941, 35938>,
    <35936, 35938, 35942>    <35936, 35942, 35939>,
    <35936, 35939, 35943>    <35936, 35943, 35940>,
    <35936, 35940, 35944>    <35945, 35953, 35946>,
    <35945, 35946, 35950>    <35945, 35950, 35947>,
    <35945, 35947, 35951>    <35945, 35951, 35948>,
    <35945, 35948, 35952>    <35945, 35952, 35949>,
    <35945, 35949, 35953>    <35954, 35962, 35955>,
    <35954, 35955, 35959>    <35954, 35959, 35956>,
    <35954, 35956, 35960>    <35954, 35960, 35957>,
    <35954, 35957, 35961>    <35954, 35961, 35958>,
    <35954, 35958, 35962>    <35963, 35971, 35964>,
    <35963, 35964, 35968>    <35963, 35968, 35965>,
    <35963, 35965, 35969>    <35963, 35969, 35966>,
    <35963, 35966, 35970>    <35963, 35970, 35967>,
    <35963, 35967, 35971>    <35972, 35980, 35973>,
    <35972, 35973, 35977>    <35972, 35977, 35974>,
    <35972, 35974, 35978>    <35972, 35978, 35975>,
    <35972, 35975, 35979>    <35972, 35979, 35976>,
    <35972, 35976, 35980>    <35981, 35989, 35982>,
    <35981, 35982, 35986>    <35981, 35986, 35983>,
    <35981, 35983, 35987>    <35981, 35987, 35984>,
    <35981, 35984, 35988>    <35981, 35988, 35985>,
    <35981, 35985, 35989>    <35990, 35998, 35991>,
    <35990, 35991, 35995>    <35990, 35995, 35992>,
    <35990, 35992, 35996>    <35990, 35996, 35993>,
    <35990, 35993, 35997>    <35990, 35997, 35994>,
    <35990, 35994, 35998>    <35999, 36007, 36000>,
    <35999, 36000, 36004>    <35999, 36004, 36001>,
    <35999, 36001, 36005>    <35999, 36005, 36002>,
    <35999, 36002, 36006>    <35999, 36006, 36003>,
    <35999, 36003, 36007>    <36008, 36016, 36009>,
    <36008, 36009, 36013>    <36008, 36013, 36010>,
    <36008, 36010, 36014>    <36008, 36014, 36011>,
    <36008, 36011, 36015>    <36008, 36015, 36012>,
    <36008, 36012, 36016>    <36017, 36025, 36018>,
    <36017, 36018, 36022>    <36017, 36022, 36019>,
    <36017, 36019, 36023>    <36017, 36023, 36020>,
    <36017, 36020, 36024>    <36017, 36024, 36021>,
    <36017, 36021, 36025>    <36026, 36034, 36027>,
    <36026, 36027, 36031>    <36026, 36031, 36028>,
    <36026, 36028, 36032>    <36026, 36032, 36029>,
    <36026, 36029, 36033>    <36026, 36033, 36030>,
    <36026, 36030, 36034>    <36035, 36043, 36036>,
    <36035, 36036, 36040>    <36035, 36040, 36037>,
    <36035, 36037, 36041>    <36035, 36041, 36038>,
    <36035, 36038, 36042>    <36035, 36042, 36039>,
    <36035, 36039, 36043>    <36044, 36052, 36045>,
    <36044, 36045, 36049>    <36044, 36049, 36046>,
    <36044, 36046, 36050>    <36044, 36050, 36047>,
    <36044, 36047, 36051>    <36044, 36051, 36048>,
    <36044, 36048, 36052>    <36053, 36061, 36054>,
    <36053, 36054, 36058>    <36053, 36058, 36055>,
    <36053, 36055, 36059>    <36053, 36059, 36056>,
    <36053, 36056, 36060>    <36053, 36060, 36057>,
    <36053, 36057, 36061>    <36062, 36070, 36063>,
    <36062, 36063, 36067>    <36062, 36067, 36064>,
    <36062, 36064, 36068>    <36062, 36068, 36065>,
    <36062, 36065, 36069>    <36062, 36069, 36066>,
    <36062, 36066, 36070>    <36071, 36079, 36072>,
    <36071, 36072, 36076>    <36071, 36076, 36073>,
    <36071, 36073, 36077>    <36071, 36077, 36074>,
    <36071, 36074, 36078>    <36071, 36078, 36075>,
    <36071, 36075, 36079>    <36080, 36088, 36081>,
    <36080, 36081, 36085>    <36080, 36085, 36082>,
    <36080, 36082, 36086>    <36080, 36086, 36083>,
    <36080, 36083, 36087>    <36080, 36087, 36084>,
    <36080, 36084, 36088>    <36089, 36097, 36090>,
    <36089, 36090, 36094>    <36089, 36094, 36091>,
    <36089, 36091, 36095>    <36089, 36095, 36092>,
    <36089, 36092, 36096>    <36089, 36096, 36093>,
    <36089, 36093, 36097>    <36098, 36106, 36099>,
    <36098, 36099, 36103>    <36098, 36103, 36100>,
    <36098, 36100, 36104>    <36098, 36104, 36101>,
    <36098, 36101, 36105>    <36098, 36105, 36102>,
    <36098, 36102, 36106>    <36107, 36115, 36108>,
    <36107, 36108, 36112>    <36107, 36112, 36109>,
    <36107, 36109, 36113>    <36107, 36113, 36110>,
    <36107, 36110, 36114>    <36107, 36114, 36111>,
    <36107, 36111, 36115>    <36116, 36124, 36117>,
    <36116, 36117, 36121>    <36116, 36121, 36118>,
    <36116, 36118, 36122>    <36116, 36122, 36119>,
    <36116, 36119, 36123>    <36116, 36123, 36120>,
    <36116, 36120, 36124>    <36125, 36133, 36126>,
    <36125, 36126, 36130>    <36125, 36130, 36127>,
    <36125, 36127, 36131>    <36125, 36131, 36128>,
    <36125, 36128, 36132>    <36125, 36132, 36129>,
    <36125, 36129, 36133>    <36134, 36142, 36135>,
    <36134, 36135, 36139>    <36134, 36139, 36136>,
    <36134, 36136, 36140>    <36134, 36140, 36137>,
    <36134, 36137, 36141>    <36134, 36141, 36138>,
    <36134, 36138, 36142>    <36143, 36151, 36144>,
    <36143, 36144, 36148>    <36143, 36148, 36145>,
    <36143, 36145, 36149>    <36143, 36149, 36146>,
    <36143, 36146, 36150>    <36143, 36150, 36147>,
    <36143, 36147, 36151>    <36152, 36160, 36153>,
    <36152, 36153, 36157>    <36152, 36157, 36154>,
    <36152, 36154, 36158>    <36152, 36158, 36155>,
    <36152, 36155, 36159>    <36152, 36159, 36156>,
    <36152, 36156, 36160>    <36161, 36169, 36162>,
    <36161, 36162, 36166>    <36161, 36166, 36163>,
    <36161, 36163, 36167>    <36161, 36167, 36164>,
    <36161, 36164, 36168>    <36161, 36168, 36165>,
    <36161, 36165, 36169>    <36170, 36178, 36171>,
    <36170, 36171, 36175>    <36170, 36175, 36172>,
    <36170, 36172, 36176>    <36170, 36176, 36173>,
    <36170, 36173, 36177>    <36170, 36177, 36174>,
    <36170, 36174, 36178>    <36179, 36187, 36180>,
    <36179, 36180, 36184>    <36179, 36184, 36181>,
    <36179, 36181, 36185>    <36179, 36185, 36182>,
    <36179, 36182, 36186>    <36179, 36186, 36183>,
    <36179, 36183, 36187>    <36188, 36196, 36189>,
    <36188, 36189, 36193>    <36188, 36193, 36190>,
    <36188, 36190, 36194>    <36188, 36194, 36191>,
    <36188, 36191, 36195>    <36188, 36195, 36192>,
    <36188, 36192, 36196>    <36197, 36205, 36198>,
    <36197, 36198, 36202>    <36197, 36202, 36199>,
    <36197, 36199, 36203>    <36197, 36203, 36200>,
    <36197, 36200, 36204>    <36197, 36204, 36201>,
    <36197, 36201, 36205>    <36206, 36214, 36207>,
    <36206, 36207, 36211>    <36206, 36211, 36208>,
    <36206, 36208, 36212>    <36206, 36212, 36209>,
    <36206, 36209, 36213>    <36206, 36213, 36210>,
    <36206, 36210, 36214>    <36215, 36223, 36216>,
    <36215, 36216, 36220>    <36215, 36220, 36217>,
    <36215, 36217, 36221>    <36215, 36221, 36218>,
    <36215, 36218, 36222>    <36215, 36222, 36219>,
    <36215, 36219, 36223>    <36224, 36232, 36225>,
    <36224, 36225, 36229>    <36224, 36229, 36226>,
    <36224, 36226, 36230>    <36224, 36230, 36227>,
    <36224, 36227, 36231>    <36224, 36231, 36228>,
    <36224, 36228, 36232>    <36233, 36241, 36234>,
    <36233, 36234, 36238>    <36233, 36238, 36235>,
    <36233, 36235, 36239>    <36233, 36239, 36236>,
    <36233, 36236, 36240>    <36233, 36240, 36237>,
    <36233, 36237, 36241>    <36242, 36250, 36243>,
    <36242, 36243, 36247>    <36242, 36247, 36244>,
    <36242, 36244, 36248>    <36242, 36248, 36245>,
    <36242, 36245, 36249>    <36242, 36249, 36246>,
    <36242, 36246, 36250>    <36251, 36259, 36252>,
    <36251, 36252, 36256>    <36251, 36256, 36253>,
    <36251, 36253, 36257>    <36251, 36257, 36254>,
    <36251, 36254, 36258>    <36251, 36258, 36255>,
    <36251, 36255, 36259>    <36260, 36268, 36261>,
    <36260, 36261, 36265>    <36260, 36265, 36262>,
    <36260, 36262, 36266>    <36260, 36266, 36263>,
    <36260, 36263, 36267>    <36260, 36267, 36264>,
    <36260, 36264, 36268>    <36269, 36277, 36270>,
    <36269, 36270, 36274>    <36269, 36274, 36271>,
    <36269, 36271, 36275>    <36269, 36275, 36272>,
    <36269, 36272, 36276>    <36269, 36276, 36273>,
    <36269, 36273, 36277>    <36278, 36286, 36279>,
    <36278, 36279, 36283>    <36278, 36283, 36280>,
    <36278, 36280, 36284>    <36278, 36284, 36281>,
    <36278, 36281, 36285>    <36278, 36285, 36282>,
    <36278, 36282, 36286>    <36287, 36295, 36288>,
    <36287, 36288, 36292>    <36287, 36292, 36289>,
    <36287, 36289, 36293>    <36287, 36293, 36290>,
    <36287, 36290, 36294>    <36287, 36294, 36291>,
    <36287, 36291, 36295>    <36296, 36304, 36297>,
    <36296, 36297, 36301>    <36296, 36301, 36298>,
    <36296, 36298, 36302>    <36296, 36302, 36299>,
    <36296, 36299, 36303>    <36296, 36303, 36300>,
    <36296, 36300, 36304>    <36305, 36313, 36306>,
    <36305, 36306, 36310>    <36305, 36310, 36307>,
    <36305, 36307, 36311>    <36305, 36311, 36308>,
    <36305, 36308, 36312>    <36305, 36312, 36309>,
    <36305, 36309, 36313>    <36314, 36322, 36315>,
    <36314, 36315, 36319>    <36314, 36319, 36316>,
    <36314, 36316, 36320>    <36314, 36320, 36317>,
    <36314, 36317, 36321>    <36314, 36321, 36318>,
    <36314, 36318, 36322>    <36323, 36331, 36324>,
    <36323, 36324, 36328>    <36323, 36328, 36325>,
    <36323, 36325, 36329>    <36323, 36329, 36326>,
    <36323, 36326, 36330>    <36323, 36330, 36327>,
    <36323, 36327, 36331>    <36332, 36340, 36333>,
    <36332, 36333, 36337>    <36332, 36337, 36334>,
    <36332, 36334, 36338>    <36332, 36338, 36335>,
    <36332, 36335, 36339>    <36332, 36339, 36336>,
    <36332, 36336, 36340>    <36341, 36349, 36342>,
    <36341, 36342, 36346>    <36341, 36346, 36343>,
    <36341, 36343, 36347>    <36341, 36347, 36344>,
    <36341, 36344, 36348>    <36341, 36348, 36345>,
    <36341, 36345, 36349>    <36350, 36358, 36351>,
    <36350, 36351, 36355>    <36350, 36355, 36352>,
    <36350, 36352, 36356>    <36350, 36356, 36353>,
    <36350, 36353, 36357>    <36350, 36357, 36354>,
    <36350, 36354, 36358>    <36359, 36367, 36360>,
    <36359, 36360, 36364>    <36359, 36364, 36361>,
    <36359, 36361, 36365>    <36359, 36365, 36362>,
    <36359, 36362, 36366>    <36359, 36366, 36363>,
    <36359, 36363, 36367>    <36368, 36376, 36369>,
    <36368, 36369, 36373>    <36368, 36373, 36370>,
    <36368, 36370, 36374>    <36368, 36374, 36371>,
    <36368, 36371, 36375>    <36368, 36375, 36372>,
    <36368, 36372, 36376>    <36377, 36385, 36378>,
    <36377, 36378, 36382>    <36377, 36382, 36379>,
    <36377, 36379, 36383>    <36377, 36383, 36380>,
    <36377, 36380, 36384>    <36377, 36384, 36381>,
    <36377, 36381, 36385>    <36386, 36394, 36387>,
    <36386, 36387, 36391>    <36386, 36391, 36388>,
    <36386, 36388, 36392>    <36386, 36392, 36389>,
    <36386, 36389, 36393>    <36386, 36393, 36390>,
    <36386, 36390, 36394>    <36395, 36403, 36396>,
    <36395, 36396, 36400>    <36395, 36400, 36397>,
    <36395, 36397, 36401>    <36395, 36401, 36398>,
    <36395, 36398, 36402>    <36395, 36402, 36399>,
    <36395, 36399, 36403>    <36404, 36412, 36405>,
    <36404, 36405, 36409>    <36404, 36409, 36406>,
    <36404, 36406, 36410>    <36404, 36410, 36407>,
    <36404, 36407, 36411>    <36404, 36411, 36408>,
    <36404, 36408, 36412>    <36413, 36421, 36414>,
    <36413, 36414, 36418>    <36413, 36418, 36415>,
    <36413, 36415, 36419>    <36413, 36419, 36416>,
    <36413, 36416, 36420>    <36413, 36420, 36417>,
    <36413, 36417, 36421>    <36422, 36430, 36423>,
    <36422, 36423, 36427>    <36422, 36427, 36424>,
    <36422, 36424, 36428>    <36422, 36428, 36425>,
    <36422, 36425, 36429>    <36422, 36429, 36426>,
    <36422, 36426, 36430>    <36431, 36439, 36432>,
    <36431, 36432, 36436>    <36431, 36436, 36433>,
    <36431, 36433, 36437>    <36431, 36437, 36434>,
    <36431, 36434, 36438>    <36431, 36438, 36435>,
    <36431, 36435, 36439>    <36440, 36448, 36441>,
    <36440, 36441, 36445>    <36440, 36445, 36442>,
    <36440, 36442, 36446>    <36440, 36446, 36443>,
    <36440, 36443, 36447>    <36440, 36447, 36444>,
    <36440, 36444, 36448>    <36449, 36457, 36450>,
    <36449, 36450, 36454>    <36449, 36454, 36451>,
    <36449, 36451, 36455>    <36449, 36455, 36452>,
    <36449, 36452, 36456>    <36449, 36456, 36453>,
    <36449, 36453, 36457>    <36458, 36466, 36459>,
    <36458, 36459, 36463>    <36458, 36463, 36460>,
    <36458, 36460, 36464>    <36458, 36464, 36461>,
    <36458, 36461, 36465>    <36458, 36465, 36462>,
    <36458, 36462, 36466>    <36467, 36475, 36468>,
    <36467, 36468, 36472>    <36467, 36472, 36469>,
    <36467, 36469, 36473>    <36467, 36473, 36470>,
    <36467, 36470, 36474>    <36467, 36474, 36471>,
    <36467, 36471, 36475>    <36476, 36484, 36477>,
    <36476, 36477, 36481>    <36476, 36481, 36478>,
    <36476, 36478, 36482>    <36476, 36482, 36479>,
    <36476, 36479, 36483>    <36476, 36483, 36480>,
    <36476, 36480, 36484>    <36485, 36493, 36486>,
    <36485, 36486, 36490>    <36485, 36490, 36487>,
    <36485, 36487, 36491>    <36485, 36491, 36488>,
    <36485, 36488, 36492>    <36485, 36492, 36489>,
    <36485, 36489, 36493>    <36494, 36502, 36495>,
    <36494, 36495, 36499>    <36494, 36499, 36496>,
    <36494, 36496, 36500>    <36494, 36500, 36497>,
    <36494, 36497, 36501>    <36494, 36501, 36498>,
    <36494, 36498, 36502>    <36503, 36511, 36504>,
    <36503, 36504, 36508>    <36503, 36508, 36505>,
    <36503, 36505, 36509>    <36503, 36509, 36506>,
    <36503, 36506, 36510>    <36503, 36510, 36507>,
    <36503, 36507, 36511>    <36512, 36520, 36513>,
    <36512, 36513, 36517>    <36512, 36517, 36514>,
    <36512, 36514, 36518>    <36512, 36518, 36515>,
    <36512, 36515, 36519>    <36512, 36519, 36516>,
    <36512, 36516, 36520>    <36521, 36529, 36522>,
    <36521, 36522, 36526>    <36521, 36526, 36523>,
    <36521, 36523, 36527>    <36521, 36527, 36524>,
    <36521, 36524, 36528>    <36521, 36528, 36525>,
    <36521, 36525, 36529>    <36530, 36538, 36531>,
    <36530, 36531, 36535>    <36530, 36535, 36532>,
    <36530, 36532, 36536>    <36530, 36536, 36533>,
    <36530, 36533, 36537>    <36530, 36537, 36534>,
    <36530, 36534, 36538>    <36539, 36547, 36540>,
    <36539, 36540, 36544>    <36539, 36544, 36541>,
    <36539, 36541, 36545>    <36539, 36545, 36542>,
    <36539, 36542, 36546>    <36539, 36546, 36543>,
    <36539, 36543, 36547>    <36548, 36556, 36549>,
    <36548, 36549, 36553>    <36548, 36553, 36550>,
    <36548, 36550, 36554>    <36548, 36554, 36551>,
    <36548, 36551, 36555>    <36548, 36555, 36552>,
    <36548, 36552, 36556>    <36557, 36565, 36558>,
    <36557, 36558, 36562>    <36557, 36562, 36559>,
    <36557, 36559, 36563>    <36557, 36563, 36560>,
    <36557, 36560, 36564>    <36557, 36564, 36561>,
    <36557, 36561, 36565>    <36566, 36574, 36567>,
    <36566, 36567, 36571>    <36566, 36571, 36568>,
    <36566, 36568, 36572>    <36566, 36572, 36569>,
    <36566, 36569, 36573>    <36566, 36573, 36570>,
    <36566, 36570, 36574>    <36575, 36583, 36576>,
    <36575, 36576, 36580>    <36575, 36580, 36577>,
    <36575, 36577, 36581>    <36575, 36581, 36578>,
    <36575, 36578, 36582>    <36575, 36582, 36579>,
    <36575, 36579, 36583>    <36584, 36592, 36585>,
    <36584, 36585, 36589>    <36584, 36589, 36586>,
    <36584, 36586, 36590>    <36584, 36590, 36587>,
    <36584, 36587, 36591>    <36584, 36591, 36588>,
    <36584, 36588, 36592>    <36593, 36601, 36594>,
    <36593, 36594, 36598>    <36593, 36598, 36595>,
    <36593, 36595, 36599>    <36593, 36599, 36596>,
    <36593, 36596, 36600>    <36593, 36600, 36597>,
    <36593, 36597, 36601>    <36602, 36610, 36603>,
    <36602, 36603, 36607>    <36602, 36607, 36604>,
    <36602, 36604, 36608>    <36602, 36608, 36605>,
    <36602, 36605, 36609>    <36602, 36609, 36606>,
    <36602, 36606, 36610>    <36611, 36619, 36612>,
    <36611, 36612, 36616>    <36611, 36616, 36613>,
    <36611, 36613, 36617>    <36611, 36617, 36614>,
    <36611, 36614, 36618>    <36611, 36618, 36615>,
    <36611, 36615, 36619>    <36620, 36628, 36621>,
    <36620, 36621, 36625>    <36620, 36625, 36622>,
    <36620, 36622, 36626>    <36620, 36626, 36623>,
    <36620, 36623, 36627>    <36620, 36627, 36624>,
    <36620, 36624, 36628>    <36629, 36637, 36630>,
    <36629, 36630, 36634>    <36629, 36634, 36631>,
    <36629, 36631, 36635>    <36629, 36635, 36632>,
    <36629, 36632, 36636>    <36629, 36636, 36633>,
    <36629, 36633, 36637>    <36638, 36646, 36639>,
    <36638, 36639, 36643>    <36638, 36643, 36640>,
    <36638, 36640, 36644>    <36638, 36644, 36641>,
    <36638, 36641, 36645>    <36638, 36645, 36642>,
    <36638, 36642, 36646>    <36647, 36655, 36648>,
    <36647, 36648, 36652>    <36647, 36652, 36649>,
    <36647, 36649, 36653>    <36647, 36653, 36650>,
    <36647, 36650, 36654>    <36647, 36654, 36651>,
    <36647, 36651, 36655>    <36656, 36664, 36657>,
    <36656, 36657, 36661>    <36656, 36661, 36658>,
    <36656, 36658, 36662>    <36656, 36662, 36659>,
    <36656, 36659, 36663>    <36656, 36663, 36660>,
    <36656, 36660, 36664>    <36665, 36673, 36666>,
    <36665, 36666, 36670>    <36665, 36670, 36667>,
    <36665, 36667, 36671>    <36665, 36671, 36668>,
    <36665, 36668, 36672>    <36665, 36672, 36669>,
    <36665, 36669, 36673>    <36674, 36682, 36675>,
    <36674, 36675, 36679>    <36674, 36679, 36676>,
    <36674, 36676, 36680>    <36674, 36680, 36677>,
    <36674, 36677, 36681>    <36674, 36681, 36678>,
    <36674, 36678, 36682>    <36683, 36691, 36684>,
    <36683, 36684, 36688>    <36683, 36688, 36685>,
    <36683, 36685, 36689>    <36683, 36689, 36686>,
    <36683, 36686, 36690>    <36683, 36690, 36687>,
    <36683, 36687, 36691>    <36692, 36700, 36693>,
    <36692, 36693, 36697>    <36692, 36697, 36694>,
    <36692, 36694, 36698>    <36692, 36698, 36695>,
    <36692, 36695, 36699>    <36692, 36699, 36696>,
    <36692, 36696, 36700>    <36701, 36709, 36702>,
    <36701, 36702, 36706>    <36701, 36706, 36703>,
    <36701, 36703, 36707>    <36701, 36707, 36704>,
    <36701, 36704, 36708>    <36701, 36708, 36705>,
    <36701, 36705, 36709>    <36710, 36718, 36711>,
    <36710, 36711, 36715>    <36710, 36715, 36712>,
    <36710, 36712, 36716>    <36710, 36716, 36713>,
    <36710, 36713, 36717>    <36710, 36717, 36714>,
    <36710, 36714, 36718>    <36719, 36727, 36720>,
    <36719, 36720, 36724>    <36719, 36724, 36721>,
    <36719, 36721, 36725>    <36719, 36725, 36722>,
    <36719, 36722, 36726>    <36719, 36726, 36723>,
    <36719, 36723, 36727>    <36728, 36736, 36729>,
    <36728, 36729, 36733>    <36728, 36733, 36730>,
    <36728, 36730, 36734>    <36728, 36734, 36731>,
    <36728, 36731, 36735>    <36728, 36735, 36732>,
    <36728, 36732, 36736>    <36737, 36745, 36738>,
    <36737, 36738, 36742>    <36737, 36742, 36739>,
    <36737, 36739, 36743>    <36737, 36743, 36740>,
    <36737, 36740, 36744>    <36737, 36744, 36741>,
    <36737, 36741, 36745>    <36746, 36754, 36747>,
    <36746, 36747, 36751>    <36746, 36751, 36748>,
    <36746, 36748, 36752>    <36746, 36752, 36749>,
    <36746, 36749, 36753>    <36746, 36753, 36750>,
    <36746, 36750, 36754>    <36755, 36763, 36756>,
    <36755, 36756, 36760>    <36755, 36760, 36757>,
    <36755, 36757, 36761>    <36755, 36761, 36758>,
    <36755, 36758, 36762>    <36755, 36762, 36759>,
    <36755, 36759, 36763>    <36764, 36772, 36765>,
    <36764, 36765, 36769>    <36764, 36769, 36766>,
    <36764, 36766, 36770>    <36764, 36770, 36767>,
    <36764, 36767, 36771>    <36764, 36771, 36768>,
    <36764, 36768, 36772>    <36773, 36781, 36774>,
    <36773, 36774, 36778>    <36773, 36778, 36775>,
    <36773, 36775, 36779>    <36773, 36779, 36776>,
    <36773, 36776, 36780>    <36773, 36780, 36777>,
    <36773, 36777, 36781>    <36782, 36790, 36783>,
    <36782, 36783, 36787>    <36782, 36787, 36784>,
    <36782, 36784, 36788>    <36782, 36788, 36785>,
    <36782, 36785, 36789>    <36782, 36789, 36786>,
    <36782, 36786, 36790>    <36791, 36799, 36792>,
    <36791, 36792, 36796>    <36791, 36796, 36793>,
    <36791, 36793, 36797>    <36791, 36797, 36794>,
    <36791, 36794, 36798>    <36791, 36798, 36795>,
    <36791, 36795, 36799>    <36800, 36808, 36801>,
    <36800, 36801, 36805>    <36800, 36805, 36802>,
    <36800, 36802, 36806>    <36800, 36806, 36803>,
    <36800, 36803, 36807>    <36800, 36807, 36804>,
    <36800, 36804, 36808>    <36809, 36817, 36810>,
    <36809, 36810, 36814>    <36809, 36814, 36811>,
    <36809, 36811, 36815>    <36809, 36815, 36812>,
    <36809, 36812, 36816>    <36809, 36816, 36813>,
    <36809, 36813, 36817>    <36818, 36826, 36819>,
    <36818, 36819, 36823>    <36818, 36823, 36820>,
    <36818, 36820, 36824>    <36818, 36824, 36821>,
    <36818, 36821, 36825>    <36818, 36825, 36822>,
    <36818, 36822, 36826>    <36827, 36835, 36828>,
    <36827, 36828, 36832>    <36827, 36832, 36829>,
    <36827, 36829, 36833>    <36827, 36833, 36830>,
    <36827, 36830, 36834>    <36827, 36834, 36831>,
    <36827, 36831, 36835>    <36836, 36844, 36837>,
    <36836, 36837, 36841>    <36836, 36841, 36838>,
    <36836, 36838, 36842>    <36836, 36842, 36839>,
    <36836, 36839, 36843>    <36836, 36843, 36840>,
    <36836, 36840, 36844>    <36845, 36853, 36846>,
    <36845, 36846, 36850>    <36845, 36850, 36847>,
    <36845, 36847, 36851>    <36845, 36851, 36848>,
    <36845, 36848, 36852>    <36845, 36852, 36849>,
    <36845, 36849, 36853>    <36854, 36862, 36855>,
    <36854, 36855, 36859>    <36854, 36859, 36856>,
    <36854, 36856, 36860>    <36854, 36860, 36857>,
    <36854, 36857, 36861>    <36854, 36861, 36858>,
    <36854, 36858, 36862>    <36863, 36871, 36864>,
    <36863, 36864, 36868>    <36863, 36868, 36865>,
    <36863, 36865, 36869>    <36863, 36869, 36866>,
    <36863, 36866, 36870>    <36863, 36870, 36867>,
    <36863, 36867, 36871>    <36872, 36880, 36873>,
    <36872, 36873, 36877>    <36872, 36877, 36874>,
    <36872, 36874, 36878>    <36872, 36878, 36875>,
    <36872, 36875, 36879>    <36872, 36879, 36876>,
    <36872, 36876, 36880>    <36881, 36889, 36882>,
    <36881, 36882, 36886>    <36881, 36886, 36883>,
    <36881, 36883, 36887>    <36881, 36887, 36884>,
    <36881, 36884, 36888>    <36881, 36888, 36885>,
    <36881, 36885, 36889>    <36890, 36898, 36891>,
    <36890, 36891, 36895>    <36890, 36895, 36892>,
    <36890, 36892, 36896>    <36890, 36896, 36893>,
    <36890, 36893, 36897>    <36890, 36897, 36894>,
    <36890, 36894, 36898>    <36899, 36907, 36900>,
    <36899, 36900, 36904>    <36899, 36904, 36901>,
    <36899, 36901, 36905>    <36899, 36905, 36902>,
    <36899, 36902, 36906>    <36899, 36906, 36903>,
    <36899, 36903, 36907>    <36908, 36916, 36909>,
    <36908, 36909, 36913>    <36908, 36913, 36910>,
    <36908, 36910, 36914>    <36908, 36914, 36911>,
    <36908, 36911, 36915>    <36908, 36915, 36912>,
    <36908, 36912, 36916>    <36917, 36925, 36918>,
    <36917, 36918, 36922>    <36917, 36922, 36919>,
    <36917, 36919, 36923>    <36917, 36923, 36920>,
    <36917, 36920, 36924>    <36917, 36924, 36921>,
    <36917, 36921, 36925>    <36926, 36934, 36927>,
    <36926, 36927, 36931>    <36926, 36931, 36928>,
    <36926, 36928, 36932>    <36926, 36932, 36929>,
    <36926, 36929, 36933>    <36926, 36933, 36930>,
    <36926, 36930, 36934>    <36935, 36943, 36936>,
    <36935, 36936, 36940>    <36935, 36940, 36937>,
    <36935, 36937, 36941>    <36935, 36941, 36938>,
    <36935, 36938, 36942>    <36935, 36942, 36939>,
    <36935, 36939, 36943>    <36944, 36952, 36945>,
    <36944, 36945, 36949>    <36944, 36949, 36946>,
    <36944, 36946, 36950>    <36944, 36950, 36947>,
    <36944, 36947, 36951>    <36944, 36951, 36948>,
    <36944, 36948, 36952>    <36953, 36961, 36954>,
    <36953, 36954, 36958>    <36953, 36958, 36955>,
    <36953, 36955, 36959>    <36953, 36959, 36956>,
    <36953, 36956, 36960>    <36953, 36960, 36957>,
    <36953, 36957, 36961>    <36962, 36970, 36963>,
    <36962, 36963, 36967>    <36962, 36967, 36964>,
    <36962, 36964, 36968>    <36962, 36968, 36965>,
    <36962, 36965, 36969>    <36962, 36969, 36966>,
    <36962, 36966, 36970>    <36971, 36979, 36972>,
    <36971, 36972, 36976>    <36971, 36976, 36973>,
    <36971, 36973, 36977>    <36971, 36977, 36974>,
    <36971, 36974, 36978>    <36971, 36978, 36975>,
    <36971, 36975, 36979>    <36980, 36988, 36981>,
    <36980, 36981, 36985>    <36980, 36985, 36982>,
    <36980, 36982, 36986>    <36980, 36986, 36983>,
    <36980, 36983, 36987>    <36980, 36987, 36984>,
    <36980, 36984, 36988>    <36989, 36997, 36990>,
    <36989, 36990, 36994>    <36989, 36994, 36991>,
    <36989, 36991, 36995>    <36989, 36995, 36992>,
    <36989, 36992, 36996>    <36989, 36996, 36993>,
    <36989, 36993, 36997>    <36998, 37006, 36999>,
    <36998, 36999, 37003>    <36998, 37003, 37000>,
    <36998, 37000, 37004>    <36998, 37004, 37001>,
    <36998, 37001, 37005>    <36998, 37005, 37002>,
    <36998, 37002, 37006>    <37007, 37015, 37008>,
    <37007, 37008, 37012>    <37007, 37012, 37009>,
    <37007, 37009, 37013>    <37007, 37013, 37010>,
    <37007, 37010, 37014>    <37007, 37014, 37011>,
    <37007, 37011, 37015>    <37016, 37024, 37017>,
    <37016, 37017, 37021>    <37016, 37021, 37018>,
    <37016, 37018, 37022>    <37016, 37022, 37019>,
    <37016, 37019, 37023>    <37016, 37023, 37020>,
    <37016, 37020, 37024>    <37025, 37033, 37026>,
    <37025, 37026, 37030>    <37025, 37030, 37027>,
    <37025, 37027, 37031>    <37025, 37031, 37028>,
    <37025, 37028, 37032>    <37025, 37032, 37029>,
    <37025, 37029, 37033>    <37034, 37042, 37035>,
    <37034, 37035, 37039>    <37034, 37039, 37036>,
    <37034, 37036, 37040>    <37034, 37040, 37037>,
    <37034, 37037, 37041>    <37034, 37041, 37038>,
    <37034, 37038, 37042>    <37043, 37051, 37044>,
    <37043, 37044, 37048>    <37043, 37048, 37045>,
    <37043, 37045, 37049>    <37043, 37049, 37046>,
    <37043, 37046, 37050>    <37043, 37050, 37047>,
    <37043, 37047, 37051>    <37052, 37060, 37053>,
    <37052, 37053, 37057>    <37052, 37057, 37054>,
    <37052, 37054, 37058>    <37052, 37058, 37055>,
    <37052, 37055, 37059>    <37052, 37059, 37056>,
    <37052, 37056, 37060>    <37061, 37069, 37062>,
    <37061, 37062, 37066>    <37061, 37066, 37063>,
    <37061, 37063, 37067>    <37061, 37067, 37064>,
    <37061, 37064, 37068>    <37061, 37068, 37065>,
    <37061, 37065, 37069>    <37070, 37078, 37071>,
    <37070, 37071, 37075>    <37070, 37075, 37072>,
    <37070, 37072, 37076>    <37070, 37076, 37073>,
    <37070, 37073, 37077>    <37070, 37077, 37074>,
    <37070, 37074, 37078>    <37079, 37087, 37080>,
    <37079, 37080, 37084>    <37079, 37084, 37081>,
    <37079, 37081, 37085>    <37079, 37085, 37082>,
    <37079, 37082, 37086>    <37079, 37086, 37083>,
    <37079, 37083, 37087>    <37088, 37096, 37089>,
    <37088, 37089, 37093>    <37088, 37093, 37090>,
    <37088, 37090, 37094>    <37088, 37094, 37091>,
    <37088, 37091, 37095>    <37088, 37095, 37092>,
    <37088, 37092, 37096>    <37097, 37105, 37098>,
    <37097, 37098, 37102>    <37097, 37102, 37099>,
    <37097, 37099, 37103>    <37097, 37103, 37100>,
    <37097, 37100, 37104>    <37097, 37104, 37101>,
    <37097, 37101, 37105>    <37106, 37114, 37107>,
    <37106, 37107, 37111>    <37106, 37111, 37108>,
    <37106, 37108, 37112>    <37106, 37112, 37109>,
    <37106, 37109, 37113>    <37106, 37113, 37110>,
    <37106, 37110, 37114>    <37115, 37123, 37116>,
    <37115, 37116, 37120>    <37115, 37120, 37117>,
    <37115, 37117, 37121>    <37115, 37121, 37118>,
    <37115, 37118, 37122>    <37115, 37122, 37119>,
    <37115, 37119, 37123>    <37124, 37132, 37125>,
    <37124, 37125, 37129>    <37124, 37129, 37126>,
    <37124, 37126, 37130>    <37124, 37130, 37127>,
    <37124, 37127, 37131>    <37124, 37131, 37128>,
    <37124, 37128, 37132>    <37133, 37141, 37134>,
    <37133, 37134, 37138>    <37133, 37138, 37135>,
    <37133, 37135, 37139>    <37133, 37139, 37136>,
    <37133, 37136, 37140>    <37133, 37140, 37137>,
    <37133, 37137, 37141>    <37142, 37150, 37143>,
    <37142, 37143, 37147>    <37142, 37147, 37144>,
    <37142, 37144, 37148>    <37142, 37148, 37145>,
    <37142, 37145, 37149>    <37142, 37149, 37146>,
    <37142, 37146, 37150>    <37151, 37159, 37152>,
    <37151, 37152, 37156>    <37151, 37156, 37153>,
    <37151, 37153, 37157>    <37151, 37157, 37154>,
    <37151, 37154, 37158>    <37151, 37158, 37155>,
    <37151, 37155, 37159>    <37160, 37168, 37161>,
    <37160, 37161, 37165>    <37160, 37165, 37162>,
    <37160, 37162, 37166>    <37160, 37166, 37163>,
    <37160, 37163, 37167>    <37160, 37167, 37164>,
    <37160, 37164, 37168>    <37169, 37177, 37170>,
    <37169, 37170, 37174>    <37169, 37174, 37171>,
    <37169, 37171, 37175>    <37169, 37175, 37172>,
    <37169, 37172, 37176>    <37169, 37176, 37173>,
    <37169, 37173, 37177>    <37178, 37186, 37179>,
    <37178, 37179, 37183>    <37178, 37183, 37180>,
    <37178, 37180, 37184>    <37178, 37184, 37181>,
    <37178, 37181, 37185>    <37178, 37185, 37182>,
    <37178, 37182, 37186>    <37187, 37195, 37188>,
    <37187, 37188, 37192>    <37187, 37192, 37189>,
    <37187, 37189, 37193>    <37187, 37193, 37190>,
    <37187, 37190, 37194>    <37187, 37194, 37191>,
    <37187, 37191, 37195>    <37196, 37204, 37197>,
    <37196, 37197, 37201>    <37196, 37201, 37198>,
    <37196, 37198, 37202>    <37196, 37202, 37199>,
    <37196, 37199, 37203>    <37196, 37203, 37200>,
    <37196, 37200, 37204>    <37205, 37213, 37206>,
    <37205, 37206, 37210>    <37205, 37210, 37207>,
    <37205, 37207, 37211>    <37205, 37211, 37208>,
    <37205, 37208, 37212>    <37205, 37212, 37209>,
    <37205, 37209, 37213>    <37214, 37222, 37215>,
    <37214, 37215, 37219>    <37214, 37219, 37216>,
    <37214, 37216, 37220>    <37214, 37220, 37217>,
    <37214, 37217, 37221>    <37214, 37221, 37218>,
    <37214, 37218, 37222>    <37223, 37231, 37224>,
    <37223, 37224, 37228>    <37223, 37228, 37225>,
    <37223, 37225, 37229>    <37223, 37229, 37226>,
    <37223, 37226, 37230>    <37223, 37230, 37227>,
    <37223, 37227, 37231>    <37232, 37240, 37233>,
    <37232, 37233, 37237>    <37232, 37237, 37234>,
    <37232, 37234, 37238>    <37232, 37238, 37235>,
    <37232, 37235, 37239>    <37232, 37239, 37236>,
    <37232, 37236, 37240>    <37241, 37249, 37242>,
    <37241, 37242, 37246>    <37241, 37246, 37243>,
    <37241, 37243, 37247>    <37241, 37247, 37244>,
    <37241, 37244, 37248>    <37241, 37248, 37245>,
    <37241, 37245, 37249>    <37250, 37258, 37251>,
    <37250, 37251, 37255>    <37250, 37255, 37252>,
    <37250, 37252, 37256>    <37250, 37256, 37253>,
    <37250, 37253, 37257>    <37250, 37257, 37254>,
    <37250, 37254, 37258>    <37259, 37267, 37260>,
    <37259, 37260, 37264>    <37259, 37264, 37261>,
    <37259, 37261, 37265>    <37259, 37265, 37262>,
    <37259, 37262, 37266>    <37259, 37266, 37263>,
    <37259, 37263, 37267>    <37268, 37276, 37269>,
    <37268, 37269, 37273>    <37268, 37273, 37270>,
    <37268, 37270, 37274>    <37268, 37274, 37271>,
    <37268, 37271, 37275>    <37268, 37275, 37272>,
    <37268, 37272, 37276>    <37277, 37285, 37278>,
    <37277, 37278, 37282>    <37277, 37282, 37279>,
    <37277, 37279, 37283>    <37277, 37283, 37280>,
    <37277, 37280, 37284>    <37277, 37284, 37281>,
    <37277, 37281, 37285>    <37286, 37294, 37287>,
    <37286, 37287, 37291>    <37286, 37291, 37288>,
    <37286, 37288, 37292>    <37286, 37292, 37289>,
    <37286, 37289, 37293>    <37286, 37293, 37290>,
    <37286, 37290, 37294>    <37295, 37303, 37296>,
    <37295, 37296, 37300>    <37295, 37300, 37297>,
    <37295, 37297, 37301>    <37295, 37301, 37298>,
    <37295, 37298, 37302>    <37295, 37302, 37299>,
    <37295, 37299, 37303>    <37304, 37312, 37305>,
    <37304, 37305, 37309>    <37304, 37309, 37306>,
    <37304, 37306, 37310>    <37304, 37310, 37307>,
    <37304, 37307, 37311>    <37304, 37311, 37308>,
    <37304, 37308, 37312>    <37313, 37321, 37314>,
    <37313, 37314, 37318>    <37313, 37318, 37315>,
    <37313, 37315, 37319>    <37313, 37319, 37316>,
    <37313, 37316, 37320>    <37313, 37320, 37317>,
    <37313, 37317, 37321>    <37322, 37330, 37323>,
    <37322, 37323, 37327>    <37322, 37327, 37324>,
    <37322, 37324, 37328>    <37322, 37328, 37325>,
    <37322, 37325, 37329>    <37322, 37329, 37326>,
    <37322, 37326, 37330>    <37331, 37339, 37332>,
    <37331, 37332, 37336>    <37331, 37336, 37333>,
    <37331, 37333, 37337>    <37331, 37337, 37334>,
    <37331, 37334, 37338>    <37331, 37338, 37335>,
    <37331, 37335, 37339>    <37340, 37348, 37341>,
    <37340, 37341, 37345>    <37340, 37345, 37342>,
    <37340, 37342, 37346>    <37340, 37346, 37343>,
    <37340, 37343, 37347>    <37340, 37347, 37344>,
    <37340, 37344, 37348>    <37349, 37357, 37350>,
    <37349, 37350, 37354>    <37349, 37354, 37351>,
    <37349, 37351, 37355>    <37349, 37355, 37352>,
    <37349, 37352, 37356>    <37349, 37356, 37353>,
    <37349, 37353, 37357>    <37358, 37366, 37359>,
    <37358, 37359, 37363>    <37358, 37363, 37360>,
    <37358, 37360, 37364>    <37358, 37364, 37361>,
    <37358, 37361, 37365>    <37358, 37365, 37362>,
    <37358, 37362, 37366>    <37367, 37375, 37368>,
    <37367, 37368, 37372>    <37367, 37372, 37369>,
    <37367, 37369, 37373>    <37367, 37373, 37370>,
    <37367, 37370, 37374>    <37367, 37374, 37371>,
    <37367, 37371, 37375>    <37376, 37384, 37377>,
    <37376, 37377, 37381>    <37376, 37381, 37378>,
    <37376, 37378, 37382>    <37376, 37382, 37379>,
    <37376, 37379, 37383>    <37376, 37383, 37380>,
    <37376, 37380, 37384>    <37385, 37393, 37386>,
    <37385, 37386, 37390>    <37385, 37390, 37387>,
    <37385, 37387, 37391>    <37385, 37391, 37388>,
    <37385, 37388, 37392>    <37385, 37392, 37389>,
    <37385, 37389, 37393>    <37394, 37402, 37395>,
    <37394, 37395, 37399>    <37394, 37399, 37396>,
    <37394, 37396, 37400>    <37394, 37400, 37397>,
    <37394, 37397, 37401>    <37394, 37401, 37398>,
    <37394, 37398, 37402>    <37403, 37411, 37404>,
    <37403, 37404, 37408>    <37403, 37408, 37405>,
    <37403, 37405, 37409>    <37403, 37409, 37406>,
    <37403, 37406, 37410>    <37403, 37410, 37407>,
    <37403, 37407, 37411>    <37412, 37420, 37413>,
    <37412, 37413, 37417>    <37412, 37417, 37414>,
    <37412, 37414, 37418>    <37412, 37418, 37415>,
    <37412, 37415, 37419>    <37412, 37419, 37416>,
    <37412, 37416, 37420>    <37421, 37429, 37422>,
    <37421, 37422, 37426>    <37421, 37426, 37423>,
    <37421, 37423, 37427>    <37421, 37427, 37424>,
    <37421, 37424, 37428>    <37421, 37428, 37425>,
    <37421, 37425, 37429>    <37430, 37438, 37431>,
    <37430, 37431, 37435>    <37430, 37435, 37432>,
    <37430, 37432, 37436>    <37430, 37436, 37433>,
    <37430, 37433, 37437>    <37430, 37437, 37434>,
    <37430, 37434, 37438>    <37439, 37447, 37440>,
    <37439, 37440, 37444>    <37439, 37444, 37441>,
    <37439, 37441, 37445>    <37439, 37445, 37442>,
    <37439, 37442, 37446>    <37439, 37446, 37443>,
    <37439, 37443, 37447>    <37448, 37456, 37449>,
    <37448, 37449, 37453>    <37448, 37453, 37450>,
    <37448, 37450, 37454>    <37448, 37454, 37451>,
    <37448, 37451, 37455>    <37448, 37455, 37452>,
    <37448, 37452, 37456>    <37457, 37465, 37458>,
    <37457, 37458, 37462>    <37457, 37462, 37459>,
    <37457, 37459, 37463>    <37457, 37463, 37460>,
    <37457, 37460, 37464>    <37457, 37464, 37461>,
    <37457, 37461, 37465>    <37466, 37474, 37467>,
    <37466, 37467, 37471>    <37466, 37471, 37468>,
    <37466, 37468, 37472>    <37466, 37472, 37469>,
    <37466, 37469, 37473>    <37466, 37473, 37470>,
    <37466, 37470, 37474>    <37475, 37483, 37476>,
    <37475, 37476, 37480>    <37475, 37480, 37477>,
    <37475, 37477, 37481>    <37475, 37481, 37478>,
    <37475, 37478, 37482>    <37475, 37482, 37479>,
    <37475, 37479, 37483>    <37484, 37492, 37485>,
    <37484, 37485, 37489>    <37484, 37489, 37486>,
    <37484, 37486, 37490>    <37484, 37490, 37487>,
    <37484, 37487, 37491>    <37484, 37491, 37488>,
    <37484, 37488, 37492>    <37493, 37501, 37494>,
    <37493, 37494, 37498>    <37493, 37498, 37495>,
    <37493, 37495, 37499>    <37493, 37499, 37496>,
    <37493, 37496, 37500>    <37493, 37500, 37497>,
    <37493, 37497, 37501>    <37502, 37510, 37503>,
    <37502, 37503, 37507>    <37502, 37507, 37504>,
    <37502, 37504, 37508>    <37502, 37508, 37505>,
    <37502, 37505, 37509>    <37502, 37509, 37506>,
    <37502, 37506, 37510>    <37511, 37519, 37512>,
    <37511, 37512, 37516>    <37511, 37516, 37513>,
    <37511, 37513, 37517>    <37511, 37517, 37514>,
    <37511, 37514, 37518>    <37511, 37518, 37515>,
    <37511, 37515, 37519>    <37520, 37528, 37521>,
    <37520, 37521, 37525>    <37520, 37525, 37522>,
    <37520, 37522, 37526>    <37520, 37526, 37523>,
    <37520, 37523, 37527>    <37520, 37527, 37524>,
    <37520, 37524, 37528>    <37529, 37537, 37530>,
    <37529, 37530, 37534>    <37529, 37534, 37531>,
    <37529, 37531, 37535>    <37529, 37535, 37532>,
    <37529, 37532, 37536>    <37529, 37536, 37533>,
    <37529, 37533, 37537>    <37538, 37546, 37539>,
    <37538, 37539, 37543>    <37538, 37543, 37540>,
    <37538, 37540, 37544>    <37538, 37544, 37541>,
    <37538, 37541, 37545>    <37538, 37545, 37542>,
    <37538, 37542, 37546>    <37547, 37555, 37548>,
    <37547, 37548, 37552>    <37547, 37552, 37549>,
    <37547, 37549, 37553>    <37547, 37553, 37550>,
    <37547, 37550, 37554>    <37547, 37554, 37551>,
    <37547, 37551, 37555>    <37556, 37564, 37557>,
    <37556, 37557, 37561>    <37556, 37561, 37558>,
    <37556, 37558, 37562>    <37556, 37562, 37559>,
    <37556, 37559, 37563>    <37556, 37563, 37560>,
    <37556, 37560, 37564>    <37565, 37573, 37566>,
    <37565, 37566, 37570>    <37565, 37570, 37567>,
    <37565, 37567, 37571>    <37565, 37571, 37568>,
    <37565, 37568, 37572>    <37565, 37572, 37569>,
    <37565, 37569, 37573>    <37574, 37582, 37575>,
    <37574, 37575, 37579>    <37574, 37579, 37576>,
    <37574, 37576, 37580>    <37574, 37580, 37577>,
    <37574, 37577, 37581>    <37574, 37581, 37578>,
    <37574, 37578, 37582>    <37583, 37591, 37584>,
    <37583, 37584, 37588>    <37583, 37588, 37585>,
    <37583, 37585, 37589>    <37583, 37589, 37586>,
    <37583, 37586, 37590>    <37583, 37590, 37587>,
    <37583, 37587, 37591>    <37592, 37600, 37593>,
    <37592, 37593, 37597>    <37592, 37597, 37594>,
    <37592, 37594, 37598>    <37592, 37598, 37595>,
    <37592, 37595, 37599>    <37592, 37599, 37596>,
    <37592, 37596, 37600>    <37601, 37609, 37602>,
    <37601, 37602, 37606>    <37601, 37606, 37603>,
    <37601, 37603, 37607>    <37601, 37607, 37604>,
    <37601, 37604, 37608>    <37601, 37608, 37605>,
    <37601, 37605, 37609>    <37610, 37618, 37611>,
    <37610, 37611, 37615>    <37610, 37615, 37612>,
    <37610, 37612, 37616>    <37610, 37616, 37613>,
    <37610, 37613, 37617>    <37610, 37617, 37614>,
    <37610, 37614, 37618>    <37619, 37627, 37620>,
    <37619, 37620, 37624>    <37619, 37624, 37621>,
    <37619, 37621, 37625>    <37619, 37625, 37622>,
    <37619, 37622, 37626>    <37619, 37626, 37623>,
    <37619, 37623, 37627>    <37628, 37636, 37629>,
    <37628, 37629, 37633>    <37628, 37633, 37630>,
    <37628, 37630, 37634>    <37628, 37634, 37631>,
    <37628, 37631, 37635>    <37628, 37635, 37632>,
    <37628, 37632, 37636>    <37637, 37645, 37638>,
    <37637, 37638, 37642>    <37637, 37642, 37639>,
    <37637, 37639, 37643>    <37637, 37643, 37640>,
    <37637, 37640, 37644>    <37637, 37644, 37641>,
    <37637, 37641, 37645>    <37646, 37654, 37647>,
    <37646, 37647, 37651>    <37646, 37651, 37648>,
    <37646, 37648, 37652>    <37646, 37652, 37649>,
    <37646, 37649, 37653>    <37646, 37653, 37650>,
    <37646, 37650, 37654>    <37655, 37663, 37656>,
    <37655, 37656, 37660>    <37655, 37660, 37657>,
    <37655, 37657, 37661>    <37655, 37661, 37658>,
    <37655, 37658, 37662>    <37655, 37662, 37659>,
    <37655, 37659, 37663>    <37664, 37672, 37665>,
    <37664, 37665, 37669>    <37664, 37669, 37666>,
    <37664, 37666, 37670>    <37664, 37670, 37667>,
    <37664, 37667, 37671>    <37664, 37671, 37668>,
    <37664, 37668, 37672>    <37673, 37681, 37674>,
    <37673, 37674, 37678>    <37673, 37678, 37675>,
    <37673, 37675, 37679>    <37673, 37679, 37676>,
    <37673, 37676, 37680>    <37673, 37680, 37677>,
    <37673, 37677, 37681>    <37682, 37690, 37683>,
    <37682, 37683, 37687>    <37682, 37687, 37684>,
    <37682, 37684, 37688>    <37682, 37688, 37685>,
    <37682, 37685, 37689>    <37682, 37689, 37686>,
    <37682, 37686, 37690>    <37691, 37699, 37692>,
    <37691, 37692, 37696>    <37691, 37696, 37693>,
    <37691, 37693, 37697>    <37691, 37697, 37694>,
    <37691, 37694, 37698>    <37691, 37698, 37695>,
    <37691, 37695, 37699>    <37700, 37708, 37701>,
    <37700, 37701, 37705>    <37700, 37705, 37702>,
    <37700, 37702, 37706>    <37700, 37706, 37703>,
    <37700, 37703, 37707>    <37700, 37707, 37704>,
    <37700, 37704, 37708>    <37709, 37717, 37710>,
    <37709, 37710, 37714>    <37709, 37714, 37711>,
    <37709, 37711, 37715>    <37709, 37715, 37712>,
    <37709, 37712, 37716>    <37709, 37716, 37713>,
    <37709, 37713, 37717>    <37718, 37726, 37719>,
    <37718, 37719, 37723>    <37718, 37723, 37720>,
    <37718, 37720, 37724>    <37718, 37724, 37721>,
    <37718, 37721, 37725>    <37718, 37725, 37722>,
    <37718, 37722, 37726>    <37727, 37735, 37728>,
    <37727, 37728, 37732>    <37727, 37732, 37729>,
    <37727, 37729, 37733>    <37727, 37733, 37730>,
    <37727, 37730, 37734>    <37727, 37734, 37731>,
    <37727, 37731, 37735>    <37736, 37744, 37737>,
    <37736, 37737, 37741>    <37736, 37741, 37738>,
    <37736, 37738, 37742>    <37736, 37742, 37739>,
    <37736, 37739, 37743>    <37736, 37743, 37740>,
    <37736, 37740, 37744>    <37745, 37753, 37746>,
    <37745, 37746, 37750>    <37745, 37750, 37747>,
    <37745, 37747, 37751>    <37745, 37751, 37748>,
    <37745, 37748, 37752>    <37745, 37752, 37749>,
    <37745, 37749, 37753>    <37754, 37762, 37755>,
    <37754, 37755, 37759>    <37754, 37759, 37756>,
    <37754, 37756, 37760>    <37754, 37760, 37757>,
    <37754, 37757, 37761>    <37754, 37761, 37758>,
    <37754, 37758, 37762>    <37763, 37771, 37764>,
    <37763, 37764, 37768>    <37763, 37768, 37765>,
    <37763, 37765, 37769>    <37763, 37769, 37766>,
    <37763, 37766, 37770>    <37763, 37770, 37767>,
    <37763, 37767, 37771>    <37772, 37780, 37773>,
    <37772, 37773, 37777>    <37772, 37777, 37774>,
    <37772, 37774, 37778>    <37772, 37778, 37775>,
    <37772, 37775, 37779>    <37772, 37779, 37776>,
    <37772, 37776, 37780>    <37781, 37789, 37782>,
    <37781, 37782, 37786>    <37781, 37786, 37783>,
    <37781, 37783, 37787>    <37781, 37787, 37784>,
    <37781, 37784, 37788>    <37781, 37788, 37785>,
    <37781, 37785, 37789>    <37790, 37798, 37791>,
    <37790, 37791, 37795>    <37790, 37795, 37792>,
    <37790, 37792, 37796>    <37790, 37796, 37793>,
    <37790, 37793, 37797>    <37790, 37797, 37794>,
    <37790, 37794, 37798>    <37799, 37807, 37800>,
    <37799, 37800, 37804>    <37799, 37804, 37801>,
    <37799, 37801, 37805>    <37799, 37805, 37802>,
    <37799, 37802, 37806>    <37799, 37806, 37803>,
    <37799, 37803, 37807>    <37808, 37816, 37809>,
    <37808, 37809, 37813>    <37808, 37813, 37810>,
    <37808, 37810, 37814>    <37808, 37814, 37811>,
    <37808, 37811, 37815>    <37808, 37815, 37812>,
    <37808, 37812, 37816>    <37817, 37825, 37818>,
    <37817, 37818, 37822>    <37817, 37822, 37819>,
    <37817, 37819, 37823>    <37817, 37823, 37820>,
    <37817, 37820, 37824>    <37817, 37824, 37821>,
    <37817, 37821, 37825>    <37826, 37834, 37827>,
    <37826, 37827, 37831>    <37826, 37831, 37828>,
    <37826, 37828, 37832>    <37826, 37832, 37829>,
    <37826, 37829, 37833>    <37826, 37833, 37830>,
    <37826, 37830, 37834>    <37835, 37843, 37836>,
    <37835, 37836, 37840>    <37835, 37840, 37837>,
    <37835, 37837, 37841>    <37835, 37841, 37838>,
    <37835, 37838, 37842>    <37835, 37842, 37839>,
    <37835, 37839, 37843>    <37844, 37852, 37845>,
    <37844, 37845, 37849>    <37844, 37849, 37846>,
    <37844, 37846, 37850>    <37844, 37850, 37847>,
    <37844, 37847, 37851>    <37844, 37851, 37848>,
    <37844, 37848, 37852>    <37853, 37861, 37854>,
    <37853, 37854, 37858>    <37853, 37858, 37855>,
    <37853, 37855, 37859>    <37853, 37859, 37856>,
    <37853, 37856, 37860>    <37853, 37860, 37857>,
    <37853, 37857, 37861>    <37862, 37870, 37863>,
    <37862, 37863, 37867>    <37862, 37867, 37864>,
    <37862, 37864, 37868>    <37862, 37868, 37865>,
    <37862, 37865, 37869>    <37862, 37869, 37866>,
    <37862, 37866, 37870>    <37871, 37879, 37872>,
    <37871, 37872, 37876>    <37871, 37876, 37873>,
    <37871, 37873, 37877>    <37871, 37877, 37874>,
    <37871, 37874, 37878>    <37871, 37878, 37875>,
    <37871, 37875, 37879>    <37880, 37888, 37881>,
    <37880, 37881, 37885>    <37880, 37885, 37882>,
    <37880, 37882, 37886>    <37880, 37886, 37883>,
    <37880, 37883, 37887>    <37880, 37887, 37884>,
    <37880, 37884, 37888>    <37889, 37897, 37890>,
    <37889, 37890, 37894>    <37889, 37894, 37891>,
    <37889, 37891, 37895>    <37889, 37895, 37892>,
    <37889, 37892, 37896>    <37889, 37896, 37893>,
    <37889, 37893, 37897>    <37898, 37906, 37899>,
    <37898, 37899, 37903>    <37898, 37903, 37900>,
    <37898, 37900, 37904>    <37898, 37904, 37901>,
    <37898, 37901, 37905>    <37898, 37905, 37902>,
    <37898, 37902, 37906>    <37907, 37915, 37908>,
    <37907, 37908, 37912>    <37907, 37912, 37909>,
    <37907, 37909, 37913>    <37907, 37913, 37910>,
    <37907, 37910, 37914>    <37907, 37914, 37911>,
    <37907, 37911, 37915>    <37916, 37924, 37917>,
    <37916, 37917, 37921>    <37916, 37921, 37918>,
    <37916, 37918, 37922>    <37916, 37922, 37919>,
    <37916, 37919, 37923>    <37916, 37923, 37920>,
    <37916, 37920, 37924>    <37925, 37933, 37926>,
    <37925, 37926, 37930>    <37925, 37930, 37927>,
    <37925, 37927, 37931>    <37925, 37931, 37928>,
    <37925, 37928, 37932>    <37925, 37932, 37929>,
    <37925, 37929, 37933>    <37934, 37942, 37935>,
    <37934, 37935, 37939>    <37934, 37939, 37936>,
    <37934, 37936, 37940>    <37934, 37940, 37937>,
    <37934, 37937, 37941>    <37934, 37941, 37938>,
    <37934, 37938, 37942>    <37943, 37951, 37944>,
    <37943, 37944, 37948>    <37943, 37948, 37945>,
    <37943, 37945, 37949>    <37943, 37949, 37946>,
    <37943, 37946, 37950>    <37943, 37950, 37947>,
    <37943, 37947, 37951>    <37952, 37960, 37953>,
    <37952, 37953, 37957>    <37952, 37957, 37954>,
    <37952, 37954, 37958>    <37952, 37958, 37955>,
    <37952, 37955, 37959>    <37952, 37959, 37956>,
    <37952, 37956, 37960>    <37961, 37969, 37962>,
    <37961, 37962, 37966>    <37961, 37966, 37963>,
    <37961, 37963, 37967>    <37961, 37967, 37964>,
    <37961, 37964, 37968>    <37961, 37968, 37965>,
    <37961, 37965, 37969>    <37970, 37978, 37971>,
    <37970, 37971, 37975>    <37970, 37975, 37972>,
    <37970, 37972, 37976>    <37970, 37976, 37973>,
    <37970, 37973, 37977>    <37970, 37977, 37974>,
    <37970, 37974, 37978>    <37979, 37987, 37980>,
    <37979, 37980, 37984>    <37979, 37984, 37981>,
    <37979, 37981, 37985>    <37979, 37985, 37982>,
    <37979, 37982, 37986>    <37979, 37986, 37983>,
    <37979, 37983, 37987>    <37988, 37996, 37989>,
    <37988, 37989, 37993>    <37988, 37993, 37990>,
    <37988, 37990, 37994>    <37988, 37994, 37991>,
    <37988, 37991, 37995>    <37988, 37995, 37992>,
    <37988, 37992, 37996>    <37997, 38005, 37998>,
    <37997, 37998, 38002>    <37997, 38002, 37999>,
    <37997, 37999, 38003>    <37997, 38003, 38000>,
    <37997, 38000, 38004>    <37997, 38004, 38001>,
    <37997, 38001, 38005>    <38006, 38014, 38007>,
    <38006, 38007, 38011>    <38006, 38011, 38008>,
    <38006, 38008, 38012>    <38006, 38012, 38009>,
    <38006, 38009, 38013>    <38006, 38013, 38010>,
    <38006, 38010, 38014>    <38015, 38023, 38016>,
    <38015, 38016, 38020>    <38015, 38020, 38017>,
    <38015, 38017, 38021>    <38015, 38021, 38018>,
    <38015, 38018, 38022>    <38015, 38022, 38019>,
    <38015, 38019, 38023>    <38024, 38032, 38025>,
    <38024, 38025, 38029>    <38024, 38029, 38026>,
    <38024, 38026, 38030>    <38024, 38030, 38027>,
    <38024, 38027, 38031>    <38024, 38031, 38028>,
    <38024, 38028, 38032>    <38033, 38041, 38034>,
    <38033, 38034, 38038>    <38033, 38038, 38035>,
    <38033, 38035, 38039>    <38033, 38039, 38036>,
    <38033, 38036, 38040>    <38033, 38040, 38037>,
    <38033, 38037, 38041>    <38042, 38050, 38043>,
    <38042, 38043, 38047>    <38042, 38047, 38044>,
    <38042, 38044, 38048>    <38042, 38048, 38045>,
    <38042, 38045, 38049>    <38042, 38049, 38046>,
    <38042, 38046, 38050>    <38051, 38059, 38052>,
    <38051, 38052, 38056>    <38051, 38056, 38053>,
    <38051, 38053, 38057>    <38051, 38057, 38054>,
    <38051, 38054, 38058>    <38051, 38058, 38055>,
    <38051, 38055, 38059>    <38060, 38068, 38061>,
    <38060, 38061, 38065>    <38060, 38065, 38062>,
    <38060, 38062, 38066>    <38060, 38066, 38063>,
    <38060, 38063, 38067>    <38060, 38067, 38064>,
    <38060, 38064, 38068>    <38069, 38077, 38070>,
    <38069, 38070, 38074>    <38069, 38074, 38071>,
    <38069, 38071, 38075>    <38069, 38075, 38072>,
    <38069, 38072, 38076>    <38069, 38076, 38073>,
    <38069, 38073, 38077>    <38078, 38086, 38079>,
    <38078, 38079, 38083>    <38078, 38083, 38080>,
    <38078, 38080, 38084>    <38078, 38084, 38081>,
    <38078, 38081, 38085>    <38078, 38085, 38082>,
    <38078, 38082, 38086>    <38087, 38095, 38088>,
    <38087, 38088, 38092>    <38087, 38092, 38089>,
    <38087, 38089, 38093>    <38087, 38093, 38090>,
    <38087, 38090, 38094>    <38087, 38094, 38091>,
    <38087, 38091, 38095>    <38096, 38104, 38097>,
    <38096, 38097, 38101>    <38096, 38101, 38098>,
    <38096, 38098, 38102>    <38096, 38102, 38099>,
    <38096, 38099, 38103>    <38096, 38103, 38100>,
    <38096, 38100, 38104>    <38105, 38113, 38106>,
    <38105, 38106, 38110>    <38105, 38110, 38107>,
    <38105, 38107, 38111>    <38105, 38111, 38108>,
    <38105, 38108, 38112>    <38105, 38112, 38109>,
    <38105, 38109, 38113>    <38114, 38122, 38115>,
    <38114, 38115, 38119>    <38114, 38119, 38116>,
    <38114, 38116, 38120>    <38114, 38120, 38117>,
    <38114, 38117, 38121>    <38114, 38121, 38118>,
    <38114, 38118, 38122>    <38123, 38131, 38124>,
    <38123, 38124, 38128>    <38123, 38128, 38125>,
    <38123, 38125, 38129>    <38123, 38129, 38126>,
    <38123, 38126, 38130>    <38123, 38130, 38127>,
    <38123, 38127, 38131>    <38132, 38140, 38133>,
    <38132, 38133, 38137>    <38132, 38137, 38134>,
    <38132, 38134, 38138>    <38132, 38138, 38135>,
    <38132, 38135, 38139>    <38132, 38139, 38136>,
    <38132, 38136, 38140>    <38141, 38149, 38142>,
    <38141, 38142, 38146>    <38141, 38146, 38143>,
    <38141, 38143, 38147>    <38141, 38147, 38144>,
    <38141, 38144, 38148>    <38141, 38148, 38145>,
    <38141, 38145, 38149>    <38150, 38158, 38151>,
    <38150, 38151, 38155>    <38150, 38155, 38152>,
    <38150, 38152, 38156>    <38150, 38156, 38153>,
    <38150, 38153, 38157>    <38150, 38157, 38154>,
    <38150, 38154, 38158>    <38159, 38167, 38160>,
    <38159, 38160, 38164>    <38159, 38164, 38161>,
    <38159, 38161, 38165>    <38159, 38165, 38162>,
    <38159, 38162, 38166>    <38159, 38166, 38163>,
    <38159, 38163, 38167>    <38168, 38176, 38169>,
    <38168, 38169, 38173>    <38168, 38173, 38170>,
    <38168, 38170, 38174>    <38168, 38174, 38171>,
    <38168, 38171, 38175>    <38168, 38175, 38172>,
    <38168, 38172, 38176>    <38177, 38185, 38178>,
    <38177, 38178, 38182>    <38177, 38182, 38179>,
    <38177, 38179, 38183>    <38177, 38183, 38180>,
    <38177, 38180, 38184>    <38177, 38184, 38181>,
    <38177, 38181, 38185>    <38186, 38194, 38187>,
    <38186, 38187, 38191>    <38186, 38191, 38188>,
    <38186, 38188, 38192>    <38186, 38192, 38189>,
    <38186, 38189, 38193>    <38186, 38193, 38190>,
    <38186, 38190, 38194>    <38195, 38203, 38196>,
    <38195, 38196, 38200>    <38195, 38200, 38197>,
    <38195, 38197, 38201>    <38195, 38201, 38198>,
    <38195, 38198, 38202>    <38195, 38202, 38199>,
    <38195, 38199, 38203>    <38204, 38212, 38205>,
    <38204, 38205, 38209>    <38204, 38209, 38206>,
    <38204, 38206, 38210>    <38204, 38210, 38207>,
    <38204, 38207, 38211>    <38204, 38211, 38208>,
    <38204, 38208, 38212>    <38213, 38221, 38214>,
    <38213, 38214, 38218>    <38213, 38218, 38215>,
    <38213, 38215, 38219>    <38213, 38219, 38216>,
    <38213, 38216, 38220>    <38213, 38220, 38217>,
    <38213, 38217, 38221>    <38222, 38230, 38223>,
    <38222, 38223, 38227>    <38222, 38227, 38224>,
    <38222, 38224, 38228>    <38222, 38228, 38225>,
    <38222, 38225, 38229>    <38222, 38229, 38226>,
    <38222, 38226, 38230>    <38231, 38239, 38232>,
    <38231, 38232, 38236>    <38231, 38236, 38233>,
    <38231, 38233, 38237>    <38231, 38237, 38234>,
    <38231, 38234, 38238>    <38231, 38238, 38235>,
    <38231, 38235, 38239>    <38240, 38248, 38241>,
    <38240, 38241, 38245>    <38240, 38245, 38242>,
    <38240, 38242, 38246>    <38240, 38246, 38243>,
    <38240, 38243, 38247>    <38240, 38247, 38244>,
    <38240, 38244, 38248>    <38249, 38257, 38250>,
    <38249, 38250, 38254>    <38249, 38254, 38251>,
    <38249, 38251, 38255>    <38249, 38255, 38252>,
    <38249, 38252, 38256>    <38249, 38256, 38253>,
    <38249, 38253, 38257>    <38258, 38266, 38259>,
    <38258, 38259, 38263>    <38258, 38263, 38260>,
    <38258, 38260, 38264>    <38258, 38264, 38261>,
    <38258, 38261, 38265>    <38258, 38265, 38262>,
    <38258, 38262, 38266>    <38267, 38275, 38268>,
    <38267, 38268, 38272>    <38267, 38272, 38269>,
    <38267, 38269, 38273>    <38267, 38273, 38270>,
    <38267, 38270, 38274>    <38267, 38274, 38271>,
    <38267, 38271, 38275>    <38276, 38284, 38277>,
    <38276, 38277, 38281>    <38276, 38281, 38278>,
    <38276, 38278, 38282>    <38276, 38282, 38279>,
    <38276, 38279, 38283>    <38276, 38283, 38280>,
    <38276, 38280, 38284>    <38285, 38293, 38286>,
    <38285, 38286, 38290>    <38285, 38290, 38287>,
    <38285, 38287, 38291>    <38285, 38291, 38288>,
    <38285, 38288, 38292>    <38285, 38292, 38289>,
    <38285, 38289, 38293>    <38294, 38302, 38295>,
    <38294, 38295, 38299>    <38294, 38299, 38296>,
    <38294, 38296, 38300>    <38294, 38300, 38297>,
    <38294, 38297, 38301>    <38294, 38301, 38298>,
    <38294, 38298, 38302>    <38303, 38311, 38304>,
    <38303, 38304, 38308>    <38303, 38308, 38305>,
    <38303, 38305, 38309>    <38303, 38309, 38306>,
    <38303, 38306, 38310>    <38303, 38310, 38307>,
    <38303, 38307, 38311>    <38312, 38320, 38313>,
    <38312, 38313, 38317>    <38312, 38317, 38314>,
    <38312, 38314, 38318>    <38312, 38318, 38315>,
    <38312, 38315, 38319>    <38312, 38319, 38316>,
    <38312, 38316, 38320>    <38321, 38329, 38322>,
    <38321, 38322, 38326>    <38321, 38326, 38323>,
    <38321, 38323, 38327>    <38321, 38327, 38324>,
    <38321, 38324, 38328>    <38321, 38328, 38325>,
    <38321, 38325, 38329>    <38330, 38338, 38331>,
    <38330, 38331, 38335>    <38330, 38335, 38332>,
    <38330, 38332, 38336>    <38330, 38336, 38333>,
    <38330, 38333, 38337>    <38330, 38337, 38334>,
    <38330, 38334, 38338>    <38339, 38347, 38340>,
    <38339, 38340, 38344>    <38339, 38344, 38341>,
    <38339, 38341, 38345>    <38339, 38345, 38342>,
    <38339, 38342, 38346>    <38339, 38346, 38343>,
    <38339, 38343, 38347>    <38348, 38356, 38349>,
    <38348, 38349, 38353>    <38348, 38353, 38350>,
    <38348, 38350, 38354>    <38348, 38354, 38351>,
    <38348, 38351, 38355>    <38348, 38355, 38352>,
    <38348, 38352, 38356>    <38357, 38365, 38358>,
    <38357, 38358, 38362>    <38357, 38362, 38359>,
    <38357, 38359, 38363>    <38357, 38363, 38360>,
    <38357, 38360, 38364>    <38357, 38364, 38361>,
    <38357, 38361, 38365>    <38366, 38374, 38367>,
    <38366, 38367, 38371>    <38366, 38371, 38368>,
    <38366, 38368, 38372>    <38366, 38372, 38369>,
    <38366, 38369, 38373>    <38366, 38373, 38370>,
    <38366, 38370, 38374>    <38375, 38383, 38376>,
    <38375, 38376, 38380>    <38375, 38380, 38377>,
    <38375, 38377, 38381>    <38375, 38381, 38378>,
    <38375, 38378, 38382>    <38375, 38382, 38379>,
    <38375, 38379, 38383>    <38384, 38392, 38385>,
    <38384, 38385, 38389>    <38384, 38389, 38386>,
    <38384, 38386, 38390>    <38384, 38390, 38387>,
    <38384, 38387, 38391>    <38384, 38391, 38388>,
    <38384, 38388, 38392>    <38393, 38401, 38394>,
    <38393, 38394, 38398>    <38393, 38398, 38395>,
    <38393, 38395, 38399>    <38393, 38399, 38396>,
    <38393, 38396, 38400>    <38393, 38400, 38397>,
    <38393, 38397, 38401>    <38402, 38410, 38403>,
    <38402, 38403, 38407>    <38402, 38407, 38404>,
    <38402, 38404, 38408>    <38402, 38408, 38405>,
    <38402, 38405, 38409>    <38402, 38409, 38406>,
    <38402, 38406, 38410>    <38411, 38419, 38412>,
    <38411, 38412, 38416>    <38411, 38416, 38413>,
    <38411, 38413, 38417>    <38411, 38417, 38414>,
    <38411, 38414, 38418>    <38411, 38418, 38415>,
    <38411, 38415, 38419>    <38420, 38428, 38421>,
    <38420, 38421, 38425>    <38420, 38425, 38422>,
    <38420, 38422, 38426>    <38420, 38426, 38423>,
    <38420, 38423, 38427>    <38420, 38427, 38424>,
    <38420, 38424, 38428>    <38429, 38437, 38430>,
    <38429, 38430, 38434>    <38429, 38434, 38431>,
    <38429, 38431, 38435>    <38429, 38435, 38432>,
    <38429, 38432, 38436>    <38429, 38436, 38433>,
    <38429, 38433, 38437>    <38438, 38446, 38439>,
    <38438, 38439, 38443>    <38438, 38443, 38440>,
    <38438, 38440, 38444>    <38438, 38444, 38441>,
    <38438, 38441, 38445>    <38438, 38445, 38442>,
    <38438, 38442, 38446>    <38447, 38455, 38448>,
    <38447, 38448, 38452>    <38447, 38452, 38449>,
    <38447, 38449, 38453>    <38447, 38453, 38450>,
    <38447, 38450, 38454>    <38447, 38454, 38451>,
    <38447, 38451, 38455>    <38456, 38464, 38457>,
    <38456, 38457, 38461>    <38456, 38461, 38458>,
    <38456, 38458, 38462>    <38456, 38462, 38459>,
    <38456, 38459, 38463>    <38456, 38463, 38460>,
    <38456, 38460, 38464>    <38465, 38473, 38466>,
    <38465, 38466, 38470>    <38465, 38470, 38467>,
    <38465, 38467, 38471>    <38465, 38471, 38468>,
    <38465, 38468, 38472>    <38465, 38472, 38469>,
    <38465, 38469, 38473>    <38474, 38482, 38475>,
    <38474, 38475, 38479>    <38474, 38479, 38476>,
    <38474, 38476, 38480>    <38474, 38480, 38477>,
    <38474, 38477, 38481>    <38474, 38481, 38478>,
    <38474, 38478, 38482>    <38483, 38491, 38484>,
    <38483, 38484, 38488>    <38483, 38488, 38485>,
    <38483, 38485, 38489>    <38483, 38489, 38486>,
    <38483, 38486, 38490>    <38483, 38490, 38487>,
    <38483, 38487, 38491>    <38492, 38500, 38493>,
    <38492, 38493, 38497>    <38492, 38497, 38494>,
    <38492, 38494, 38498>    <38492, 38498, 38495>,
    <38492, 38495, 38499>    <38492, 38499, 38496>,
    <38492, 38496, 38500>    <38501, 38509, 38502>,
    <38501, 38502, 38506>    <38501, 38506, 38503>,
    <38501, 38503, 38507>    <38501, 38507, 38504>,
    <38501, 38504, 38508>    <38501, 38508, 38505>,
    <38501, 38505, 38509>    <38510, 38518, 38511>,
    <38510, 38511, 38515>    <38510, 38515, 38512>,
    <38510, 38512, 38516>    <38510, 38516, 38513>,
    <38510, 38513, 38517>    <38510, 38517, 38514>,
    <38510, 38514, 38518>    <38519, 38527, 38520>,
    <38519, 38520, 38524>    <38519, 38524, 38521>,
    <38519, 38521, 38525>    <38519, 38525, 38522>,
    <38519, 38522, 38526>    <38519, 38526, 38523>,
    <38519, 38523, 38527>    <38528, 38536, 38529>,
    <38528, 38529, 38533>    <38528, 38533, 38530>,
    <38528, 38530, 38534>    <38528, 38534, 38531>,
    <38528, 38531, 38535>    <38528, 38535, 38532>,
    <38528, 38532, 38536>    <38537, 38545, 38538>,
    <38537, 38538, 38542>    <38537, 38542, 38539>,
    <38537, 38539, 38543>    <38537, 38543, 38540>,
    <38537, 38540, 38544>    <38537, 38544, 38541>,
    <38537, 38541, 38545>    <38546, 38554, 38547>,
    <38546, 38547, 38551>    <38546, 38551, 38548>,
    <38546, 38548, 38552>    <38546, 38552, 38549>,
    <38546, 38549, 38553>    <38546, 38553, 38550>,
    <38546, 38550, 38554>    <38555, 38563, 38556>,
    <38555, 38556, 38560>    <38555, 38560, 38557>,
    <38555, 38557, 38561>    <38555, 38561, 38558>,
    <38555, 38558, 38562>    <38555, 38562, 38559>,
    <38555, 38559, 38563>    <38564, 38572, 38565>,
    <38564, 38565, 38569>    <38564, 38569, 38566>,
    <38564, 38566, 38570>    <38564, 38570, 38567>,
    <38564, 38567, 38571>    <38564, 38571, 38568>,
    <38564, 38568, 38572>    <38573, 38581, 38574>,
    <38573, 38574, 38578>    <38573, 38578, 38575>,
    <38573, 38575, 38579>    <38573, 38579, 38576>,
    <38573, 38576, 38580>    <38573, 38580, 38577>,
    <38573, 38577, 38581>    <38582, 38590, 38583>,
    <38582, 38583, 38587>    <38582, 38587, 38584>,
    <38582, 38584, 38588>    <38582, 38588, 38585>,
    <38582, 38585, 38589>    <38582, 38589, 38586>,
    <38582, 38586, 38590>    <38591, 38599, 38592>,
    <38591, 38592, 38596>    <38591, 38596, 38593>,
    <38591, 38593, 38597>    <38591, 38597, 38594>,
    <38591, 38594, 38598>    <38591, 38598, 38595>,
    <38591, 38595, 38599>    <38600, 38608, 38601>,
    <38600, 38601, 38605>    <38600, 38605, 38602>,
    <38600, 38602, 38606>    <38600, 38606, 38603>,
    <38600, 38603, 38607>    <38600, 38607, 38604>,
    <38600, 38604, 38608>    <38609, 38617, 38610>,
    <38609, 38610, 38614>    <38609, 38614, 38611>,
    <38609, 38611, 38615>    <38609, 38615, 38612>,
    <38609, 38612, 38616>    <38609, 38616, 38613>,
    <38609, 38613, 38617>    <38618, 38626, 38619>,
    <38618, 38619, 38623>    <38618, 38623, 38620>,
    <38618, 38620, 38624>    <38618, 38624, 38621>,
    <38618, 38621, 38625>    <38618, 38625, 38622>,
    <38618, 38622, 38626>    <38627, 38635, 38628>,
    <38627, 38628, 38632>    <38627, 38632, 38629>,
    <38627, 38629, 38633>    <38627, 38633, 38630>,
    <38627, 38630, 38634>    <38627, 38634, 38631>,
    <38627, 38631, 38635>    <38636, 38644, 38637>,
    <38636, 38637, 38641>    <38636, 38641, 38638>,
    <38636, 38638, 38642>    <38636, 38642, 38639>,
    <38636, 38639, 38643>    <38636, 38643, 38640>,
    <38636, 38640, 38644>    <38645, 38653, 38646>,
    <38645, 38646, 38650>    <38645, 38650, 38647>,
    <38645, 38647, 38651>    <38645, 38651, 38648>,
    <38645, 38648, 38652>    <38645, 38652, 38649>,
    <38645, 38649, 38653>    <38654, 38662, 38655>,
    <38654, 38655, 38659>    <38654, 38659, 38656>,
    <38654, 38656, 38660>    <38654, 38660, 38657>,
    <38654, 38657, 38661>    <38654, 38661, 38658>,
    <38654, 38658, 38662>    <38663, 38671, 38664>,
    <38663, 38664, 38668>    <38663, 38668, 38665>,
    <38663, 38665, 38669>    <38663, 38669, 38666>,
    <38663, 38666, 38670>    <38663, 38670, 38667>,
    <38663, 38667, 38671>    <38672, 38680, 38673>,
    <38672, 38673, 38677>    <38672, 38677, 38674>,
    <38672, 38674, 38678>    <38672, 38678, 38675>,
    <38672, 38675, 38679>    <38672, 38679, 38676>,
    <38672, 38676, 38680>    <38681, 38689, 38682>,
    <38681, 38682, 38686>    <38681, 38686, 38683>,
    <38681, 38683, 38687>    <38681, 38687, 38684>,
    <38681, 38684, 38688>    <38681, 38688, 38685>,
    <38681, 38685, 38689>    <38690, 38698, 38691>,
    <38690, 38691, 38695>    <38690, 38695, 38692>,
    <38690, 38692, 38696>    <38690, 38696, 38693>,
    <38690, 38693, 38697>    <38690, 38697, 38694>,
    <38690, 38694, 38698>    <38699, 38707, 38700>,
    <38699, 38700, 38704>    <38699, 38704, 38701>,
    <38699, 38701, 38705>    <38699, 38705, 38702>,
    <38699, 38702, 38706>    <38699, 38706, 38703>,
    <38699, 38703, 38707>    <38708, 38716, 38709>,
    <38708, 38709, 38713>    <38708, 38713, 38710>,
    <38708, 38710, 38714>    <38708, 38714, 38711>,
    <38708, 38711, 38715>    <38708, 38715, 38712>,
    <38708, 38712, 38716>    <38717, 38725, 38718>,
    <38717, 38718, 38722>    <38717, 38722, 38719>,
    <38717, 38719, 38723>    <38717, 38723, 38720>,
    <38717, 38720, 38724>    <38717, 38724, 38721>,
    <38717, 38721, 38725>    <38726, 38734, 38727>,
    <38726, 38727, 38731>    <38726, 38731, 38728>,
    <38726, 38728, 38732>    <38726, 38732, 38729>,
    <38726, 38729, 38733>    <38726, 38733, 38730>,
    <38726, 38730, 38734>    <38735, 38743, 38736>,
    <38735, 38736, 38740>    <38735, 38740, 38737>,
    <38735, 38737, 38741>    <38735, 38741, 38738>,
    <38735, 38738, 38742>    <38735, 38742, 38739>,
    <38735, 38739, 38743>    <38744, 38752, 38745>,
    <38744, 38745, 38749>    <38744, 38749, 38746>,
    <38744, 38746, 38750>    <38744, 38750, 38747>,
    <38744, 38747, 38751>    <38744, 38751, 38748>,
    <38744, 38748, 38752>    <38753, 38761, 38754>,
    <38753, 38754, 38758>    <38753, 38758, 38755>,
    <38753, 38755, 38759>    <38753, 38759, 38756>,
    <38753, 38756, 38760>    <38753, 38760, 38757>,
    <38753, 38757, 38761>    <38762, 38770, 38763>,
    <38762, 38763, 38767>    <38762, 38767, 38764>,
    <38762, 38764, 38768>    <38762, 38768, 38765>,
    <38762, 38765, 38769>    <38762, 38769, 38766>,
    <38762, 38766, 38770>    <38771, 38779, 38772>,
    <38771, 38772, 38776>    <38771, 38776, 38773>,
    <38771, 38773, 38777>    <38771, 38777, 38774>,
    <38771, 38774, 38778>    <38771, 38778, 38775>,
    <38771, 38775, 38779>    <38780, 38788, 38781>,
    <38780, 38781, 38785>    <38780, 38785, 38782>,
    <38780, 38782, 38786>    <38780, 38786, 38783>,
    <38780, 38783, 38787>    <38780, 38787, 38784>,
    <38780, 38784, 38788>    <38789, 38797, 38790>,
    <38789, 38790, 38794>    <38789, 38794, 38791>,
    <38789, 38791, 38795>    <38789, 38795, 38792>,
    <38789, 38792, 38796>    <38789, 38796, 38793>,
    <38789, 38793, 38797>    <38798, 38806, 38799>,
    <38798, 38799, 38803>    <38798, 38803, 38800>,
    <38798, 38800, 38804>    <38798, 38804, 38801>,
    <38798, 38801, 38805>    <38798, 38805, 38802>,
    <38798, 38802, 38806>    <38807, 38815, 38808>,
    <38807, 38808, 38812>    <38807, 38812, 38809>,
    <38807, 38809, 38813>    <38807, 38813, 38810>,
    <38807, 38810, 38814>    <38807, 38814, 38811>,
    <38807, 38811, 38815>    <38816, 38824, 38817>,
    <38816, 38817, 38821>    <38816, 38821, 38818>,
    <38816, 38818, 38822>    <38816, 38822, 38819>,
    <38816, 38819, 38823>    <38816, 38823, 38820>,
    <38816, 38820, 38824>    <38825, 38833, 38826>,
    <38825, 38826, 38830>    <38825, 38830, 38827>,
    <38825, 38827, 38831>    <38825, 38831, 38828>,
    <38825, 38828, 38832>    <38825, 38832, 38829>,
    <38825, 38829, 38833>    <38834, 38842, 38835>,
    <38834, 38835, 38839>    <38834, 38839, 38836>,
    <38834, 38836, 38840>    <38834, 38840, 38837>,
    <38834, 38837, 38841>    <38834, 38841, 38838>,
    <38834, 38838, 38842>    <38843, 38851, 38844>,
    <38843, 38844, 38848>    <38843, 38848, 38845>,
    <38843, 38845, 38849>    <38843, 38849, 38846>,
    <38843, 38846, 38850>    <38843, 38850, 38847>,
    <38843, 38847, 38851>    <38852, 38860, 38853>,
    <38852, 38853, 38857>    <38852, 38857, 38854>,
    <38852, 38854, 38858>    <38852, 38858, 38855>,
    <38852, 38855, 38859>    <38852, 38859, 38856>,
    <38852, 38856, 38860>    <38861, 38869, 38862>,
    <38861, 38862, 38866>    <38861, 38866, 38863>,
    <38861, 38863, 38867>    <38861, 38867, 38864>,
    <38861, 38864, 38868>    <38861, 38868, 38865>,
    <38861, 38865, 38869>    <38870, 38878, 38871>,
    <38870, 38871, 38875>    <38870, 38875, 38872>,
    <38870, 38872, 38876>    <38870, 38876, 38873>,
    <38870, 38873, 38877>    <38870, 38877, 38874>,
    <38870, 38874, 38878>    <38879, 38887, 38880>,
    <38879, 38880, 38884>    <38879, 38884, 38881>,
    <38879, 38881, 38885>    <38879, 38885, 38882>,
    <38879, 38882, 38886>    <38879, 38886, 38883>,
    <38879, 38883, 38887>    <38888, 38896, 38889>,
    <38888, 38889, 38893>    <38888, 38893, 38890>,
    <38888, 38890, 38894>    <38888, 38894, 38891>,
    <38888, 38891, 38895>    <38888, 38895, 38892>,
    <38888, 38892, 38896>    <38897, 38905, 38898>,
    <38897, 38898, 38902>    <38897, 38902, 38899>,
    <38897, 38899, 38903>    <38897, 38903, 38900>,
    <38897, 38900, 38904>    <38897, 38904, 38901>,
    <38897, 38901, 38905>    <38906, 38914, 38907>,
    <38906, 38907, 38911>    <38906, 38911, 38908>,
    <38906, 38908, 38912>    <38906, 38912, 38909>,
    <38906, 38909, 38913>    <38906, 38913, 38910>,
    <38906, 38910, 38914>    <38915, 38923, 38916>,
    <38915, 38916, 38920>    <38915, 38920, 38917>,
    <38915, 38917, 38921>    <38915, 38921, 38918>,
    <38915, 38918, 38922>    <38915, 38922, 38919>,
    <38915, 38919, 38923>    <38924, 38932, 38925>,
    <38924, 38925, 38929>    <38924, 38929, 38926>,
    <38924, 38926, 38930>    <38924, 38930, 38927>,
    <38924, 38927, 38931>    <38924, 38931, 38928>,
    <38924, 38928, 38932>    <38933, 38941, 38934>,
    <38933, 38934, 38938>    <38933, 38938, 38935>,
    <38933, 38935, 38939>    <38933, 38939, 38936>,
    <38933, 38936, 38940>    <38933, 38940, 38937>,
    <38933, 38937, 38941>    <38942, 38950, 38943>,
    <38942, 38943, 38947>    <38942, 38947, 38944>,
    <38942, 38944, 38948>    <38942, 38948, 38945>,
    <38942, 38945, 38949>    <38942, 38949, 38946>,
    <38942, 38946, 38950>    <38951, 38959, 38952>,
    <38951, 38952, 38956>    <38951, 38956, 38953>,
    <38951, 38953, 38957>    <38951, 38957, 38954>,
    <38951, 38954, 38958>    <38951, 38958, 38955>,
    <38951, 38955, 38959>    <38960, 38968, 38961>,
    <38960, 38961, 38965>    <38960, 38965, 38962>,
    <38960, 38962, 38966>    <38960, 38966, 38963>,
    <38960, 38963, 38967>    <38960, 38967, 38964>,
    <38960, 38964, 38968>    <38969, 38977, 38970>,
    <38969, 38970, 38974>    <38969, 38974, 38971>,
    <38969, 38971, 38975>    <38969, 38975, 38972>,
    <38969, 38972, 38976>    <38969, 38976, 38973>,
    <38969, 38973, 38977>    <38978, 38986, 38979>,
    <38978, 38979, 38983>    <38978, 38983, 38980>,
    <38978, 38980, 38984>    <38978, 38984, 38981>,
    <38978, 38981, 38985>    <38978, 38985, 38982>,
    <38978, 38982, 38986>    <38987, 38995, 38988>,
    <38987, 38988, 38992>    <38987, 38992, 38989>,
    <38987, 38989, 38993>    <38987, 38993, 38990>,
    <38987, 38990, 38994>    <38987, 38994, 38991>,
    <38987, 38991, 38995>    <38996, 39004, 38997>,
    <38996, 38997, 39001>    <38996, 39001, 38998>,
    <38996, 38998, 39002>    <38996, 39002, 38999>,
    <38996, 38999, 39003>    <38996, 39003, 39000>,
    <38996, 39000, 39004>    <39005, 39013, 39006>,
    <39005, 39006, 39010>    <39005, 39010, 39007>,
    <39005, 39007, 39011>    <39005, 39011, 39008>,
    <39005, 39008, 39012>    <39005, 39012, 39009>,
    <39005, 39009, 39013>    <39014, 39022, 39015>,
    <39014, 39015, 39019>    <39014, 39019, 39016>,
    <39014, 39016, 39020>    <39014, 39020, 39017>,
    <39014, 39017, 39021>    <39014, 39021, 39018>,
    <39014, 39018, 39022>    <39023, 39031, 39024>,
    <39023, 39024, 39028>    <39023, 39028, 39025>,
    <39023, 39025, 39029>    <39023, 39029, 39026>,
    <39023, 39026, 39030>    <39023, 39030, 39027>,
    <39023, 39027, 39031>    <39032, 39040, 39033>,
    <39032, 39033, 39037>    <39032, 39037, 39034>,
    <39032, 39034, 39038>    <39032, 39038, 39035>,
    <39032, 39035, 39039>    <39032, 39039, 39036>,
    <39032, 39036, 39040>    <39041, 39049, 39042>,
    <39041, 39042, 39046>    <39041, 39046, 39043>,
    <39041, 39043, 39047>    <39041, 39047, 39044>,
    <39041, 39044, 39048>    <39041, 39048, 39045>,
    <39041, 39045, 39049>    <39050, 39058, 39051>,
    <39050, 39051, 39055>    <39050, 39055, 39052>,
    <39050, 39052, 39056>    <39050, 39056, 39053>,
    <39050, 39053, 39057>    <39050, 39057, 39054>,
    <39050, 39054, 39058>    <39059, 39067, 39060>,
    <39059, 39060, 39064>    <39059, 39064, 39061>,
    <39059, 39061, 39065>    <39059, 39065, 39062>,
    <39059, 39062, 39066>    <39059, 39066, 39063>,
    <39059, 39063, 39067>    <39068, 39076, 39069>,
    <39068, 39069, 39073>    <39068, 39073, 39070>,
    <39068, 39070, 39074>    <39068, 39074, 39071>,
    <39068, 39071, 39075>    <39068, 39075, 39072>,
    <39068, 39072, 39076>    <39077, 39085, 39078>,
    <39077, 39078, 39082>    <39077, 39082, 39079>,
    <39077, 39079, 39083>    <39077, 39083, 39080>,
    <39077, 39080, 39084>    <39077, 39084, 39081>,
    <39077, 39081, 39085>    <39086, 39094, 39087>,
    <39086, 39087, 39091>    <39086, 39091, 39088>,
    <39086, 39088, 39092>    <39086, 39092, 39089>,
    <39086, 39089, 39093>    <39086, 39093, 39090>,
    <39086, 39090, 39094>    <39095, 39103, 39096>,
    <39095, 39096, 39100>    <39095, 39100, 39097>,
    <39095, 39097, 39101>    <39095, 39101, 39098>,
    <39095, 39098, 39102>    <39095, 39102, 39099>,
    <39095, 39099, 39103>    <39104, 39112, 39105>,
    <39104, 39105, 39109>    <39104, 39109, 39106>,
    <39104, 39106, 39110>    <39104, 39110, 39107>,
    <39104, 39107, 39111>    <39104, 39111, 39108>,
    <39104, 39108, 39112>    <39113, 39121, 39114>,
    <39113, 39114, 39118>    <39113, 39118, 39115>,
    <39113, 39115, 39119>    <39113, 39119, 39116>,
    <39113, 39116, 39120>    <39113, 39120, 39117>,
    <39113, 39117, 39121>    <39122, 39130, 39123>,
    <39122, 39123, 39127>    <39122, 39127, 39124>,
    <39122, 39124, 39128>    <39122, 39128, 39125>,
    <39122, 39125, 39129>    <39122, 39129, 39126>,
    <39122, 39126, 39130>    <39131, 39139, 39132>,
    <39131, 39132, 39136>    <39131, 39136, 39133>,
    <39131, 39133, 39137>    <39131, 39137, 39134>,
    <39131, 39134, 39138>    <39131, 39138, 39135>,
    <39131, 39135, 39139>    <39140, 39148, 39141>,
    <39140, 39141, 39145>    <39140, 39145, 39142>,
    <39140, 39142, 39146>    <39140, 39146, 39143>,
    <39140, 39143, 39147>    <39140, 39147, 39144>,
    <39140, 39144, 39148>    <39149, 39157, 39150>,
    <39149, 39150, 39154>    <39149, 39154, 39151>,
    <39149, 39151, 39155>    <39149, 39155, 39152>,
    <39149, 39152, 39156>    <39149, 39156, 39153>,
    <39149, 39153, 39157>    <39158, 39166, 39159>,
    <39158, 39159, 39163>    <39158, 39163, 39160>,
    <39158, 39160, 39164>    <39158, 39164, 39161>,
    <39158, 39161, 39165>    <39158, 39165, 39162>,
    <39158, 39162, 39166>    <39167, 39175, 39168>,
    <39167, 39168, 39172>    <39167, 39172, 39169>,
    <39167, 39169, 39173>    <39167, 39173, 39170>,
    <39167, 39170, 39174>    <39167, 39174, 39171>,
    <39167, 39171, 39175>    <39176, 39184, 39177>,
    <39176, 39177, 39181>    <39176, 39181, 39178>,
    <39176, 39178, 39182>    <39176, 39182, 39179>,
    <39176, 39179, 39183>    <39176, 39183, 39180>,
    <39176, 39180, 39184>    <39185, 39193, 39186>,
    <39185, 39186, 39190>    <39185, 39190, 39187>,
    <39185, 39187, 39191>    <39185, 39191, 39188>,
    <39185, 39188, 39192>    <39185, 39192, 39189>,
    <39185, 39189, 39193>    <39194, 39202, 39195>,
    <39194, 39195, 39199>    <39194, 39199, 39196>,
    <39194, 39196, 39200>    <39194, 39200, 39197>,
    <39194, 39197, 39201>    <39194, 39201, 39198>,
    <39194, 39198, 39202>    <39203, 39211, 39204>,
    <39203, 39204, 39208>    <39203, 39208, 39205>,
    <39203, 39205, 39209>    <39203, 39209, 39206>,
    <39203, 39206, 39210>    <39203, 39210, 39207>,
    <39203, 39207, 39211>    <39212, 39220, 39213>,
    <39212, 39213, 39217>    <39212, 39217, 39214>,
    <39212, 39214, 39218>    <39212, 39218, 39215>,
    <39212, 39215, 39219>    <39212, 39219, 39216>,
    <39212, 39216, 39220>    <39221, 39229, 39222>,
    <39221, 39222, 39226>    <39221, 39226, 39223>,
    <39221, 39223, 39227>    <39221, 39227, 39224>,
    <39221, 39224, 39228>    <39221, 39228, 39225>,
    <39221, 39225, 39229>    <39230, 39238, 39231>,
    <39230, 39231, 39235>    <39230, 39235, 39232>,
    <39230, 39232, 39236>    <39230, 39236, 39233>,
    <39230, 39233, 39237>    <39230, 39237, 39234>,
    <39230, 39234, 39238>    <39239, 39247, 39240>,
    <39239, 39240, 39244>    <39239, 39244, 39241>,
    <39239, 39241, 39245>    <39239, 39245, 39242>,
    <39239, 39242, 39246>    <39239, 39246, 39243>,
    <39239, 39243, 39247>    <39248, 39256, 39249>,
    <39248, 39249, 39253>    <39248, 39253, 39250>,
    <39248, 39250, 39254>    <39248, 39254, 39251>,
    <39248, 39251, 39255>    <39248, 39255, 39252>,
    <39248, 39252, 39256>    <39257, 39265, 39258>,
    <39257, 39258, 39262>    <39257, 39262, 39259>,
    <39257, 39259, 39263>    <39257, 39263, 39260>,
    <39257, 39260, 39264>    <39257, 39264, 39261>,
    <39257, 39261, 39265>    <39266, 39274, 39267>,
    <39266, 39267, 39271>    <39266, 39271, 39268>,
    <39266, 39268, 39272>    <39266, 39272, 39269>,
    <39266, 39269, 39273>    <39266, 39273, 39270>,
    <39266, 39270, 39274>    <39275, 39283, 39276>,
    <39275, 39276, 39280>    <39275, 39280, 39277>,
    <39275, 39277, 39281>    <39275, 39281, 39278>,
    <39275, 39278, 39282>    <39275, 39282, 39279>,
    <39275, 39279, 39283>    <39284, 39292, 39285>,
    <39284, 39285, 39289>    <39284, 39289, 39286>,
    <39284, 39286, 39290>    <39284, 39290, 39287>,
    <39284, 39287, 39291>    <39284, 39291, 39288>,
    <39284, 39288, 39292>    <39293, 39301, 39294>,
    <39293, 39294, 39298>    <39293, 39298, 39295>,
    <39293, 39295, 39299>    <39293, 39299, 39296>,
    <39293, 39296, 39300>    <39293, 39300, 39297>,
    <39293, 39297, 39301>    <39302, 39310, 39303>,
    <39302, 39303, 39307>    <39302, 39307, 39304>,
    <39302, 39304, 39308>    <39302, 39308, 39305>,
    <39302, 39305, 39309>    <39302, 39309, 39306>,
    <39302, 39306, 39310>    <39311, 39319, 39312>,
    <39311, 39312, 39316>    <39311, 39316, 39313>,
    <39311, 39313, 39317>    <39311, 39317, 39314>,
    <39311, 39314, 39318>    <39311, 39318, 39315>,
    <39311, 39315, 39319>    <39320, 39328, 39321>,
    <39320, 39321, 39325>    <39320, 39325, 39322>,
    <39320, 39322, 39326>    <39320, 39326, 39323>,
    <39320, 39323, 39327>    <39320, 39327, 39324>,
    <39320, 39324, 39328>    <39329, 39337, 39330>,
    <39329, 39330, 39334>    <39329, 39334, 39331>,
    <39329, 39331, 39335>    <39329, 39335, 39332>,
    <39329, 39332, 39336>    <39329, 39336, 39333>,
    <39329, 39333, 39337>    <39338, 39346, 39339>,
    <39338, 39339, 39343>    <39338, 39343, 39340>,
    <39338, 39340, 39344>    <39338, 39344, 39341>,
    <39338, 39341, 39345>    <39338, 39345, 39342>,
    <39338, 39342, 39346>    <39347, 39355, 39348>,
    <39347, 39348, 39352>    <39347, 39352, 39349>,
    <39347, 39349, 39353>    <39347, 39353, 39350>,
    <39347, 39350, 39354>    <39347, 39354, 39351>,
    <39347, 39351, 39355>    <39356, 39364, 39357>,
    <39356, 39357, 39361>    <39356, 39361, 39358>,
    <39356, 39358, 39362>    <39356, 39362, 39359>,
    <39356, 39359, 39363>    <39356, 39363, 39360>,
    <39356, 39360, 39364>    <39365, 39373, 39366>,
    <39365, 39366, 39370>    <39365, 39370, 39367>,
    <39365, 39367, 39371>    <39365, 39371, 39368>,
    <39365, 39368, 39372>    <39365, 39372, 39369>,
    <39365, 39369, 39373>    <39374, 39382, 39375>,
    <39374, 39375, 39379>    <39374, 39379, 39376>,
    <39374, 39376, 39380>    <39374, 39380, 39377>,
    <39374, 39377, 39381>    <39374, 39381, 39378>,
    <39374, 39378, 39382>    <39383, 39391, 39384>,
    <39383, 39384, 39388>    <39383, 39388, 39385>,
    <39383, 39385, 39389>    <39383, 39389, 39386>,
    <39383, 39386, 39390>    <39383, 39390, 39387>,
    <39383, 39387, 39391>    <39392, 39400, 39393>,
    <39392, 39393, 39397>    <39392, 39397, 39394>,
    <39392, 39394, 39398>    <39392, 39398, 39395>,
    <39392, 39395, 39399>    <39392, 39399, 39396>,
    <39392, 39396, 39400>    <39401, 39409, 39402>,
    <39401, 39402, 39406>    <39401, 39406, 39403>,
    <39401, 39403, 39407>    <39401, 39407, 39404>,
    <39401, 39404, 39408>    <39401, 39408, 39405>,
    <39401, 39405, 39409>    <39410, 39418, 39411>,
    <39410, 39411, 39415>    <39410, 39415, 39412>,
    <39410, 39412, 39416>    <39410, 39416, 39413>,
    <39410, 39413, 39417>    <39410, 39417, 39414>,
    <39410, 39414, 39418>    <39419, 39427, 39420>,
    <39419, 39420, 39424>    <39419, 39424, 39421>,
    <39419, 39421, 39425>    <39419, 39425, 39422>,
    <39419, 39422, 39426>    <39419, 39426, 39423>,
    <39419, 39423, 39427>    <39428, 39436, 39429>,
    <39428, 39429, 39433>    <39428, 39433, 39430>,
    <39428, 39430, 39434>    <39428, 39434, 39431>,
    <39428, 39431, 39435>    <39428, 39435, 39432>,
    <39428, 39432, 39436>    <39437, 39445, 39438>,
    <39437, 39438, 39442>    <39437, 39442, 39439>,
    <39437, 39439, 39443>    <39437, 39443, 39440>,
    <39437, 39440, 39444>    <39437, 39444, 39441>,
    <39437, 39441, 39445>    <39446, 39454, 39447>,
    <39446, 39447, 39451>    <39446, 39451, 39448>,
    <39446, 39448, 39452>    <39446, 39452, 39449>,
    <39446, 39449, 39453>    <39446, 39453, 39450>,
    <39446, 39450, 39454>    <39455, 39463, 39456>,
    <39455, 39456, 39460>    <39455, 39460, 39457>,
    <39455, 39457, 39461>    <39455, 39461, 39458>,
    <39455, 39458, 39462>    <39455, 39462, 39459>,
    <39455, 39459, 39463>    <39464, 39472, 39465>,
    <39464, 39465, 39469>    <39464, 39469, 39466>,
    <39464, 39466, 39470>    <39464, 39470, 39467>,
    <39464, 39467, 39471>    <39464, 39471, 39468>,
    <39464, 39468, 39472>    <39473, 39481, 39474>,
    <39473, 39474, 39478>    <39473, 39478, 39475>,
    <39473, 39475, 39479>    <39473, 39479, 39476>,
    <39473, 39476, 39480>    <39473, 39480, 39477>,
    <39473, 39477, 39481>    <39482, 39490, 39483>,
    <39482, 39483, 39487>    <39482, 39487, 39484>,
    <39482, 39484, 39488>    <39482, 39488, 39485>,
    <39482, 39485, 39489>    <39482, 39489, 39486>,
    <39482, 39486, 39490>    <39491, 39499, 39492>,
    <39491, 39492, 39496>    <39491, 39496, 39493>,
    <39491, 39493, 39497>    <39491, 39497, 39494>,
    <39491, 39494, 39498>    <39491, 39498, 39495>,
    <39491, 39495, 39499>    <39500, 39508, 39501>,
    <39500, 39501, 39505>    <39500, 39505, 39502>,
    <39500, 39502, 39506>    <39500, 39506, 39503>,
    <39500, 39503, 39507>    <39500, 39507, 39504>,
    <39500, 39504, 39508>    <39509, 39517, 39510>,
    <39509, 39510, 39514>    <39509, 39514, 39511>,
    <39509, 39511, 39515>    <39509, 39515, 39512>,
    <39509, 39512, 39516>    <39509, 39516, 39513>,
    <39509, 39513, 39517>    <39518, 39526, 39519>,
    <39518, 39519, 39523>    <39518, 39523, 39520>,
    <39518, 39520, 39524>    <39518, 39524, 39521>,
    <39518, 39521, 39525>    <39518, 39525, 39522>,
    <39518, 39522, 39526>    <39527, 39535, 39528>,
    <39527, 39528, 39532>    <39527, 39532, 39529>,
    <39527, 39529, 39533>    <39527, 39533, 39530>,
    <39527, 39530, 39534>    <39527, 39534, 39531>,
    <39527, 39531, 39535>    <39536, 39544, 39537>,
    <39536, 39537, 39541>    <39536, 39541, 39538>,
    <39536, 39538, 39542>    <39536, 39542, 39539>,
    <39536, 39539, 39543>    <39536, 39543, 39540>,
    <39536, 39540, 39544>    <39545, 39553, 39546>,
    <39545, 39546, 39550>    <39545, 39550, 39547>,
    <39545, 39547, 39551>    <39545, 39551, 39548>,
    <39545, 39548, 39552>    <39545, 39552, 39549>,
    <39545, 39549, 39553>    <39554, 39562, 39555>,
    <39554, 39555, 39559>    <39554, 39559, 39556>,
    <39554, 39556, 39560>    <39554, 39560, 39557>,
    <39554, 39557, 39561>    <39554, 39561, 39558>,
    <39554, 39558, 39562>    <39563, 39571, 39564>,
    <39563, 39564, 39568>    <39563, 39568, 39565>,
    <39563, 39565, 39569>    <39563, 39569, 39566>,
    <39563, 39566, 39570>    <39563, 39570, 39567>,
    <39563, 39567, 39571>    <39572, 39580, 39573>,
    <39572, 39573, 39577>    <39572, 39577, 39574>,
    <39572, 39574, 39578>    <39572, 39578, 39575>,
    <39572, 39575, 39579>    <39572, 39579, 39576>,
    <39572, 39576, 39580>    <39581, 39589, 39582>,
    <39581, 39582, 39586>    <39581, 39586, 39583>,
    <39581, 39583, 39587>    <39581, 39587, 39584>,
    <39581, 39584, 39588>    <39581, 39588, 39585>,
    <39581, 39585, 39589>    <39590, 39598, 39591>,
    <39590, 39591, 39595>    <39590, 39595, 39592>,
    <39590, 39592, 39596>    <39590, 39596, 39593>,
    <39590, 39593, 39597>    <39590, 39597, 39594>,
    <39590, 39594, 39598>    <39599, 39607, 39600>,
    <39599, 39600, 39604>    <39599, 39604, 39601>,
    <39599, 39601, 39605>    <39599, 39605, 39602>,
    <39599, 39602, 39606>    <39599, 39606, 39603>,
    <39599, 39603, 39607>    <39608, 39616, 39609>,
    <39608, 39609, 39613>    <39608, 39613, 39610>,
    <39608, 39610, 39614>    <39608, 39614, 39611>,
    <39608, 39611, 39615>    <39608, 39615, 39612>,
    <39608, 39612, 39616>    <39617, 39625, 39618>,
    <39617, 39618, 39622>    <39617, 39622, 39619>,
    <39617, 39619, 39623>    <39617, 39623, 39620>,
    <39617, 39620, 39624>    <39617, 39624, 39621>,
    <39617, 39621, 39625>    <39626, 39634, 39627>,
    <39626, 39627, 39631>    <39626, 39631, 39628>,
    <39626, 39628, 39632>    <39626, 39632, 39629>,
    <39626, 39629, 39633>    <39626, 39633, 39630>,
    <39626, 39630, 39634>    <39635, 39643, 39636>,
    <39635, 39636, 39640>    <39635, 39640, 39637>,
    <39635, 39637, 39641>    <39635, 39641, 39638>,
    <39635, 39638, 39642>    <39635, 39642, 39639>,
    <39635, 39639, 39643>    <39644, 39652, 39645>,
    <39644, 39645, 39649>    <39644, 39649, 39646>,
    <39644, 39646, 39650>    <39644, 39650, 39647>,
    <39644, 39647, 39651>    <39644, 39651, 39648>,
    <39644, 39648, 39652>    <39653, 39661, 39654>,
    <39653, 39654, 39658>    <39653, 39658, 39655>,
    <39653, 39655, 39659>    <39653, 39659, 39656>,
    <39653, 39656, 39660>    <39653, 39660, 39657>,
    <39653, 39657, 39661>    <39662, 39670, 39663>,
    <39662, 39663, 39667>    <39662, 39667, 39664>,
    <39662, 39664, 39668>    <39662, 39668, 39665>,
    <39662, 39665, 39669>    <39662, 39669, 39666>,
    <39662, 39666, 39670>    <39671, 39679, 39672>,
    <39671, 39672, 39676>    <39671, 39676, 39673>,
    <39671, 39673, 39677>    <39671, 39677, 39674>,
    <39671, 39674, 39678>    <39671, 39678, 39675>,
    <39671, 39675, 39679>    <39680, 39688, 39681>,
    <39680, 39681, 39685>    <39680, 39685, 39682>,
    <39680, 39682, 39686>    <39680, 39686, 39683>,
    <39680, 39683, 39687>    <39680, 39687, 39684>,
    <39680, 39684, 39688>    <39689, 39697, 39690>,
    <39689, 39690, 39694>    <39689, 39694, 39691>,
    <39689, 39691, 39695>    <39689, 39695, 39692>,
    <39689, 39692, 39696>    <39689, 39696, 39693>,
    <39689, 39693, 39697>    <39698, 39706, 39699>,
    <39698, 39699, 39703>    <39698, 39703, 39700>,
    <39698, 39700, 39704>    <39698, 39704, 39701>,
    <39698, 39701, 39705>    <39698, 39705, 39702>,
    <39698, 39702, 39706>    <39707, 39715, 39708>,
    <39707, 39708, 39712>    <39707, 39712, 39709>,
    <39707, 39709, 39713>    <39707, 39713, 39710>,
    <39707, 39710, 39714>    <39707, 39714, 39711>,
    <39707, 39711, 39715>    <39716, 39724, 39717>,
    <39716, 39717, 39721>    <39716, 39721, 39718>,
    <39716, 39718, 39722>    <39716, 39722, 39719>,
    <39716, 39719, 39723>    <39716, 39723, 39720>,
    <39716, 39720, 39724>    <39725, 39733, 39726>,
    <39725, 39726, 39730>    <39725, 39730, 39727>,
    <39725, 39727, 39731>    <39725, 39731, 39728>,
    <39725, 39728, 39732>    <39725, 39732, 39729>,
    <39725, 39729, 39733>    <39734, 39742, 39735>,
    <39734, 39735, 39739>    <39734, 39739, 39736>,
    <39734, 39736, 39740>    <39734, 39740, 39737>,
    <39734, 39737, 39741>    <39734, 39741, 39738>,
    <39734, 39738, 39742>    <39743, 39751, 39744>,
    <39743, 39744, 39748>    <39743, 39748, 39745>,
    <39743, 39745, 39749>    <39743, 39749, 39746>,
    <39743, 39746, 39750>    <39743, 39750, 39747>,
    <39743, 39747, 39751>    <39752, 39760, 39753>,
    <39752, 39753, 39757>    <39752, 39757, 39754>,
    <39752, 39754, 39758>    <39752, 39758, 39755>,
    <39752, 39755, 39759>    <39752, 39759, 39756>,
    <39752, 39756, 39760>    <39761, 39769, 39762>,
    <39761, 39762, 39766>    <39761, 39766, 39763>,
    <39761, 39763, 39767>    <39761, 39767, 39764>,
    <39761, 39764, 39768>    <39761, 39768, 39765>,
    <39761, 39765, 39769>    <39770, 39778, 39771>,
    <39770, 39771, 39775>    <39770, 39775, 39772>,
    <39770, 39772, 39776>    <39770, 39776, 39773>,
    <39770, 39773, 39777>    <39770, 39777, 39774>,
    <39770, 39774, 39778>    <39779, 39787, 39780>,
    <39779, 39780, 39784>    <39779, 39784, 39781>,
    <39779, 39781, 39785>    <39779, 39785, 39782>,
    <39779, 39782, 39786>    <39779, 39786, 39783>,
    <39779, 39783, 39787>    <39788, 39796, 39789>,
    <39788, 39789, 39793>    <39788, 39793, 39790>,
    <39788, 39790, 39794>    <39788, 39794, 39791>,
    <39788, 39791, 39795>    <39788, 39795, 39792>,
    <39788, 39792, 39796>    <39797, 39805, 39798>,
    <39797, 39798, 39802>    <39797, 39802, 39799>,
    <39797, 39799, 39803>    <39797, 39803, 39800>,
    <39797, 39800, 39804>    <39797, 39804, 39801>,
    <39797, 39801, 39805>    <39806, 39814, 39807>,
    <39806, 39807, 39811>    <39806, 39811, 39808>,
    <39806, 39808, 39812>    <39806, 39812, 39809>,
    <39806, 39809, 39813>    <39806, 39813, 39810>,
    <39806, 39810, 39814>    <39815, 39823, 39816>,
    <39815, 39816, 39820>    <39815, 39820, 39817>,
    <39815, 39817, 39821>    <39815, 39821, 39818>,
    <39815, 39818, 39822>    <39815, 39822, 39819>,
    <39815, 39819, 39823>    <39824, 39832, 39825>,
    <39824, 39825, 39829>    <39824, 39829, 39826>,
    <39824, 39826, 39830>    <39824, 39830, 39827>,
    <39824, 39827, 39831>    <39824, 39831, 39828>,
    <39824, 39828, 39832>    <39833, 39841, 39834>,
    <39833, 39834, 39838>    <39833, 39838, 39835>,
    <39833, 39835, 39839>    <39833, 39839, 39836>,
    <39833, 39836, 39840>    <39833, 39840, 39837>,
    <39833, 39837, 39841>    <39842, 39850, 39843>,
    <39842, 39843, 39847>    <39842, 39847, 39844>,
    <39842, 39844, 39848>    <39842, 39848, 39845>,
    <39842, 39845, 39849>    <39842, 39849, 39846>,
    <39842, 39846, 39850>    <39851, 39859, 39852>,
    <39851, 39852, 39856>    <39851, 39856, 39853>,
    <39851, 39853, 39857>    <39851, 39857, 39854>,
    <39851, 39854, 39858>    <39851, 39858, 39855>,
    <39851, 39855, 39859>    <39860, 39868, 39861>,
    <39860, 39861, 39865>    <39860, 39865, 39862>,
    <39860, 39862, 39866>    <39860, 39866, 39863>,
    <39860, 39863, 39867>    <39860, 39867, 39864>,
    <39860, 39864, 39868>    <39869, 39877, 39870>,
    <39869, 39870, 39874>    <39869, 39874, 39871>,
    <39869, 39871, 39875>    <39869, 39875, 39872>,
    <39869, 39872, 39876>    <39869, 39876, 39873>,
    <39869, 39873, 39877>    <39878, 39886, 39879>,
    <39878, 39879, 39883>    <39878, 39883, 39880>,
    <39878, 39880, 39884>    <39878, 39884, 39881>,
    <39878, 39881, 39885>    <39878, 39885, 39882>,
    <39878, 39882, 39886>    <39887, 39895, 39888>,
    <39887, 39888, 39892>    <39887, 39892, 39889>,
    <39887, 39889, 39893>    <39887, 39893, 39890>,
    <39887, 39890, 39894>    <39887, 39894, 39891>,
    <39887, 39891, 39895>    <39896, 39904, 39897>,
    <39896, 39897, 39901>    <39896, 39901, 39898>,
    <39896, 39898, 39902>    <39896, 39902, 39899>,
    <39896, 39899, 39903>    <39896, 39903, 39900>,
    <39896, 39900, 39904>    <39905, 39913, 39906>,
    <39905, 39906, 39910>    <39905, 39910, 39907>,
    <39905, 39907, 39911>    <39905, 39911, 39908>,
    <39905, 39908, 39912>    <39905, 39912, 39909>,
    <39905, 39909, 39913>    <39914, 39922, 39915>,
    <39914, 39915, 39919>    <39914, 39919, 39916>,
    <39914, 39916, 39920>    <39914, 39920, 39917>,
    <39914, 39917, 39921>    <39914, 39921, 39918>,
    <39914, 39918, 39922>    <39923, 39931, 39924>,
    <39923, 39924, 39928>    <39923, 39928, 39925>,
    <39923, 39925, 39929>    <39923, 39929, 39926>,
    <39923, 39926, 39930>    <39923, 39930, 39927>,
    <39923, 39927, 39931>    <39932, 39940, 39933>,
    <39932, 39933, 39937>    <39932, 39937, 39934>,
    <39932, 39934, 39938>    <39932, 39938, 39935>,
    <39932, 39935, 39939>    <39932, 39939, 39936>,
    <39932, 39936, 39940>    <39941, 39949, 39942>,
    <39941, 39942, 39946>    <39941, 39946, 39943>,
    <39941, 39943, 39947>    <39941, 39947, 39944>,
    <39941, 39944, 39948>    <39941, 39948, 39945>,
    <39941, 39945, 39949>    <39950, 39958, 39951>,
    <39950, 39951, 39955>    <39950, 39955, 39952>,
    <39950, 39952, 39956>    <39950, 39956, 39953>,
    <39950, 39953, 39957>    <39950, 39957, 39954>,
    <39950, 39954, 39958>    <39959, 39967, 39960>,
    <39959, 39960, 39964>    <39959, 39964, 39961>,
    <39959, 39961, 39965>    <39959, 39965, 39962>,
    <39959, 39962, 39966>    <39959, 39966, 39963>,
    <39959, 39963, 39967>    <39968, 39976, 39969>,
    <39968, 39969, 39973>    <39968, 39973, 39970>,
    <39968, 39970, 39974>    <39968, 39974, 39971>,
    <39968, 39971, 39975>    <39968, 39975, 39972>,
    <39968, 39972, 39976>    <39977, 39985, 39978>,
    <39977, 39978, 39982>    <39977, 39982, 39979>,
    <39977, 39979, 39983>    <39977, 39983, 39980>,
    <39977, 39980, 39984>    <39977, 39984, 39981>,
    <39977, 39981, 39985>    <39986, 39994, 39987>,
    <39986, 39987, 39991>    <39986, 39991, 39988>,
    <39986, 39988, 39992>    <39986, 39992, 39989>,
    <39986, 39989, 39993>    <39986, 39993, 39990>,
    <39986, 39990, 39994>    <39995, 40003, 39996>,
    <39995, 39996, 40000>    <39995, 40000, 39997>,
    <39995, 39997, 40001>    <39995, 40001, 39998>,
    <39995, 39998, 40002>    <39995, 40002, 39999>,
    <39995, 39999, 40003>    <40004, 40012, 40005>,
    <40004, 40005, 40009>    <40004, 40009, 40006>,
    <40004, 40006, 40010>    <40004, 40010, 40007>,
    <40004, 40007, 40011>    <40004, 40011, 40008>,
    <40004, 40008, 40012>    <40013, 40021, 40014>,
    <40013, 40014, 40018>    <40013, 40018, 40015>,
    <40013, 40015, 40019>    <40013, 40019, 40016>,
    <40013, 40016, 40020>    <40013, 40020, 40017>,
    <40013, 40017, 40021>    <40022, 40030, 40023>,
    <40022, 40023, 40027>    <40022, 40027, 40024>,
    <40022, 40024, 40028>    <40022, 40028, 40025>,
    <40022, 40025, 40029>    <40022, 40029, 40026>,
    <40022, 40026, 40030>    <40031, 40039, 40032>,
    <40031, 40032, 40036>    <40031, 40036, 40033>,
    <40031, 40033, 40037>    <40031, 40037, 40034>,
    <40031, 40034, 40038>    <40031, 40038, 40035>,
    <40031, 40035, 40039>    <40040, 40048, 40041>,
    <40040, 40041, 40045>    <40040, 40045, 40042>,
    <40040, 40042, 40046>    <40040, 40046, 40043>,
    <40040, 40043, 40047>    <40040, 40047, 40044>,
    <40040, 40044, 40048>    <40049, 40057, 40050>,
    <40049, 40050, 40054>    <40049, 40054, 40051>,
    <40049, 40051, 40055>    <40049, 40055, 40052>,
    <40049, 40052, 40056>    <40049, 40056, 40053>,
    <40049, 40053, 40057>    <40058, 40066, 40059>,
    <40058, 40059, 40063>    <40058, 40063, 40060>,
    <40058, 40060, 40064>    <40058, 40064, 40061>,
    <40058, 40061, 40065>    <40058, 40065, 40062>,
    <40058, 40062, 40066>    <40067, 40075, 40068>,
    <40067, 40068, 40072>    <40067, 40072, 40069>,
    <40067, 40069, 40073>    <40067, 40073, 40070>,
    <40067, 40070, 40074>    <40067, 40074, 40071>,
    <40067, 40071, 40075>    <40076, 40084, 40077>,
    <40076, 40077, 40081>    <40076, 40081, 40078>,
    <40076, 40078, 40082>    <40076, 40082, 40079>,
    <40076, 40079, 40083>    <40076, 40083, 40080>,
    <40076, 40080, 40084>    <40085, 40093, 40086>,
    <40085, 40086, 40090>    <40085, 40090, 40087>,
    <40085, 40087, 40091>    <40085, 40091, 40088>,
    <40085, 40088, 40092>    <40085, 40092, 40089>,
    <40085, 40089, 40093>    <40094, 40102, 40095>,
    <40094, 40095, 40099>    <40094, 40099, 40096>,
    <40094, 40096, 40100>    <40094, 40100, 40097>,
    <40094, 40097, 40101>    <40094, 40101, 40098>,
    <40094, 40098, 40102>    <40103, 40111, 40104>,
    <40103, 40104, 40108>    <40103, 40108, 40105>,
    <40103, 40105, 40109>    <40103, 40109, 40106>,
    <40103, 40106, 40110>    <40103, 40110, 40107>,
    <40103, 40107, 40111>    <40112, 40120, 40113>,
    <40112, 40113, 40117>    <40112, 40117, 40114>,
    <40112, 40114, 40118>    <40112, 40118, 40115>,
    <40112, 40115, 40119>    <40112, 40119, 40116>,
    <40112, 40116, 40120>    <40121, 40129, 40122>,
    <40121, 40122, 40126>    <40121, 40126, 40123>,
    <40121, 40123, 40127>    <40121, 40127, 40124>,
    <40121, 40124, 40128>    <40121, 40128, 40125>,
    <40121, 40125, 40129>    <40130, 40138, 40131>,
    <40130, 40131, 40135>    <40130, 40135, 40132>,
    <40130, 40132, 40136>    <40130, 40136, 40133>,
    <40130, 40133, 40137>    <40130, 40137, 40134>,
    <40130, 40134, 40138>    <40139, 40147, 40140>,
    <40139, 40140, 40144>    <40139, 40144, 40141>,
    <40139, 40141, 40145>    <40139, 40145, 40142>,
    <40139, 40142, 40146>    <40139, 40146, 40143>,
    <40139, 40143, 40147>    <40148, 40156, 40149>,
    <40148, 40149, 40153>    <40148, 40153, 40150>,
    <40148, 40150, 40154>    <40148, 40154, 40151>,
    <40148, 40151, 40155>    <40148, 40155, 40152>,
    <40148, 40152, 40156>    <40157, 40165, 40158>,
    <40157, 40158, 40162>    <40157, 40162, 40159>,
    <40157, 40159, 40163>    <40157, 40163, 40160>,
    <40157, 40160, 40164>    <40157, 40164, 40161>,
    <40157, 40161, 40165>    <40166, 40174, 40167>,
    <40166, 40167, 40171>    <40166, 40171, 40168>,
    <40166, 40168, 40172>    <40166, 40172, 40169>,
    <40166, 40169, 40173>    <40166, 40173, 40170>,
    <40166, 40170, 40174>    <40175, 40183, 40176>,
    <40175, 40176, 40180>    <40175, 40180, 40177>,
    <40175, 40177, 40181>    <40175, 40181, 40178>,
    <40175, 40178, 40182>    <40175, 40182, 40179>,
    <40175, 40179, 40183>    <40184, 40192, 40185>,
    <40184, 40185, 40189>    <40184, 40189, 40186>,
    <40184, 40186, 40190>    <40184, 40190, 40187>,
    <40184, 40187, 40191>    <40184, 40191, 40188>,
    <40184, 40188, 40192>    <40193, 40201, 40194>,
    <40193, 40194, 40198>    <40193, 40198, 40195>,
    <40193, 40195, 40199>    <40193, 40199, 40196>,
    <40193, 40196, 40200>    <40193, 40200, 40197>,
    <40193, 40197, 40201>    <40202, 40210, 40203>,
    <40202, 40203, 40207>    <40202, 40207, 40204>,
    <40202, 40204, 40208>    <40202, 40208, 40205>,
    <40202, 40205, 40209>    <40202, 40209, 40206>,
    <40202, 40206, 40210>    <40211, 40219, 40212>,
    <40211, 40212, 40216>    <40211, 40216, 40213>,
    <40211, 40213, 40217>    <40211, 40217, 40214>,
    <40211, 40214, 40218>    <40211, 40218, 40215>,
    <40211, 40215, 40219>    <40220, 40228, 40221>,
    <40220, 40221, 40225>    <40220, 40225, 40222>,
    <40220, 40222, 40226>    <40220, 40226, 40223>,
    <40220, 40223, 40227>    <40220, 40227, 40224>,
    <40220, 40224, 40228>    <40229, 40237, 40230>,
    <40229, 40230, 40234>    <40229, 40234, 40231>,
    <40229, 40231, 40235>    <40229, 40235, 40232>,
    <40229, 40232, 40236>    <40229, 40236, 40233>,
    <40229, 40233, 40237>    <40238, 40246, 40239>,
    <40238, 40239, 40243>    <40238, 40243, 40240>,
    <40238, 40240, 40244>    <40238, 40244, 40241>,
    <40238, 40241, 40245>    <40238, 40245, 40242>,
    <40238, 40242, 40246>    <40247, 40255, 40248>,
    <40247, 40248, 40252>    <40247, 40252, 40249>,
    <40247, 40249, 40253>    <40247, 40253, 40250>,
    <40247, 40250, 40254>    <40247, 40254, 40251>,
    <40247, 40251, 40255>    <40256, 40264, 40257>,
    <40256, 40257, 40261>    <40256, 40261, 40258>,
    <40256, 40258, 40262>    <40256, 40262, 40259>,
    <40256, 40259, 40263>    <40256, 40263, 40260>,
    <40256, 40260, 40264>    <40265, 40273, 40266>,
    <40265, 40266, 40270>    <40265, 40270, 40267>,
    <40265, 40267, 40271>    <40265, 40271, 40268>,
    <40265, 40268, 40272>    <40265, 40272, 40269>,
    <40265, 40269, 40273>    <40274, 40282, 40275>,
    <40274, 40275, 40279>    <40274, 40279, 40276>,
    <40274, 40276, 40280>    <40274, 40280, 40277>,
    <40274, 40277, 40281>    <40274, 40281, 40278>,
    <40274, 40278, 40282>    <40283, 40291, 40284>,
    <40283, 40284, 40288>    <40283, 40288, 40285>,
    <40283, 40285, 40289>    <40283, 40289, 40286>,
    <40283, 40286, 40290>    <40283, 40290, 40287>,
    <40283, 40287, 40291>    <40292, 40300, 40293>,
    <40292, 40293, 40297>    <40292, 40297, 40294>,
    <40292, 40294, 40298>    <40292, 40298, 40295>,
    <40292, 40295, 40299>    <40292, 40299, 40296>,
    <40292, 40296, 40300>    <40301, 40309, 40302>,
    <40301, 40302, 40306>    <40301, 40306, 40303>,
    <40301, 40303, 40307>    <40301, 40307, 40304>,
    <40301, 40304, 40308>    <40301, 40308, 40305>,
    <40301, 40305, 40309>    <40310, 40318, 40311>,
    <40310, 40311, 40315>    <40310, 40315, 40312>,
    <40310, 40312, 40316>    <40310, 40316, 40313>,
    <40310, 40313, 40317>    <40310, 40317, 40314>,
    <40310, 40314, 40318>    <40319, 40327, 40320>,
    <40319, 40320, 40324>    <40319, 40324, 40321>,
    <40319, 40321, 40325>    <40319, 40325, 40322>,
    <40319, 40322, 40326>    <40319, 40326, 40323>,
    <40319, 40323, 40327>    <40328, 40336, 40329>,
    <40328, 40329, 40333>    <40328, 40333, 40330>,
    <40328, 40330, 40334>    <40328, 40334, 40331>,
    <40328, 40331, 40335>    <40328, 40335, 40332>,
    <40328, 40332, 40336>    <40337, 40345, 40338>,
    <40337, 40338, 40342>    <40337, 40342, 40339>,
    <40337, 40339, 40343>    <40337, 40343, 40340>,
    <40337, 40340, 40344>    <40337, 40344, 40341>,
    <40337, 40341, 40345>    <40346, 40354, 40347>,
    <40346, 40347, 40351>    <40346, 40351, 40348>,
    <40346, 40348, 40352>    <40346, 40352, 40349>,
    <40346, 40349, 40353>    <40346, 40353, 40350>,
    <40346, 40350, 40354>    <40355, 40363, 40356>,
    <40355, 40356, 40360>    <40355, 40360, 40357>,
    <40355, 40357, 40361>    <40355, 40361, 40358>,
    <40355, 40358, 40362>    <40355, 40362, 40359>,
    <40355, 40359, 40363>    <40364, 40372, 40365>,
    <40364, 40365, 40369>    <40364, 40369, 40366>,
    <40364, 40366, 40370>    <40364, 40370, 40367>,
    <40364, 40367, 40371>    <40364, 40371, 40368>,
    <40364, 40368, 40372>    <40373, 40381, 40374>,
    <40373, 40374, 40378>    <40373, 40378, 40375>,
    <40373, 40375, 40379>    <40373, 40379, 40376>,
    <40373, 40376, 40380>    <40373, 40380, 40377>,
    <40373, 40377, 40381>    <40382, 40390, 40383>,
    <40382, 40383, 40387>    <40382, 40387, 40384>,
    <40382, 40384, 40388>    <40382, 40388, 40385>,
    <40382, 40385, 40389>    <40382, 40389, 40386>,
    <40382, 40386, 40390>    <40391, 40399, 40392>,
    <40391, 40392, 40396>    <40391, 40396, 40393>,
    <40391, 40393, 40397>    <40391, 40397, 40394>,
    <40391, 40394, 40398>    <40391, 40398, 40395>,
    <40391, 40395, 40399>    <40400, 40408, 40401>,
    <40400, 40401, 40405>    <40400, 40405, 40402>,
    <40400, 40402, 40406>    <40400, 40406, 40403>,
    <40400, 40403, 40407>    <40400, 40407, 40404>,
    <40400, 40404, 40408>    <40409, 40417, 40410>,
    <40409, 40410, 40414>    <40409, 40414, 40411>,
    <40409, 40411, 40415>    <40409, 40415, 40412>,
    <40409, 40412, 40416>    <40409, 40416, 40413>,
    <40409, 40413, 40417>    <40418, 40426, 40419>,
    <40418, 40419, 40423>    <40418, 40423, 40420>,
    <40418, 40420, 40424>    <40418, 40424, 40421>,
    <40418, 40421, 40425>    <40418, 40425, 40422>,
    <40418, 40422, 40426>    <40427, 40435, 40428>,
    <40427, 40428, 40432>    <40427, 40432, 40429>,
    <40427, 40429, 40433>    <40427, 40433, 40430>,
    <40427, 40430, 40434>    <40427, 40434, 40431>,
    <40427, 40431, 40435>    <40436, 40444, 40437>,
    <40436, 40437, 40441>    <40436, 40441, 40438>,
    <40436, 40438, 40442>    <40436, 40442, 40439>,
    <40436, 40439, 40443>    <40436, 40443, 40440>,
    <40436, 40440, 40444>    <40445, 40453, 40446>,
    <40445, 40446, 40450>    <40445, 40450, 40447>,
    <40445, 40447, 40451>    <40445, 40451, 40448>,
    <40445, 40448, 40452>    <40445, 40452, 40449>,
    <40445, 40449, 40453>    <40454, 40462, 40455>,
    <40454, 40455, 40459>    <40454, 40459, 40456>,
    <40454, 40456, 40460>    <40454, 40460, 40457>,
    <40454, 40457, 40461>    <40454, 40461, 40458>,
    <40454, 40458, 40462>    <40463, 40471, 40464>,
    <40463, 40464, 40468>    <40463, 40468, 40465>,
    <40463, 40465, 40469>    <40463, 40469, 40466>,
    <40463, 40466, 40470>    <40463, 40470, 40467>,
    <40463, 40467, 40471>    <40472, 40480, 40473>,
    <40472, 40473, 40477>    <40472, 40477, 40474>,
    <40472, 40474, 40478>    <40472, 40478, 40475>,
    <40472, 40475, 40479>    <40472, 40479, 40476>,
    <40472, 40476, 40480>    <40481, 40489, 40482>,
    <40481, 40482, 40486>    <40481, 40486, 40483>,
    <40481, 40483, 40487>    <40481, 40487, 40484>,
    <40481, 40484, 40488>    <40481, 40488, 40485>,
    <40481, 40485, 40489>    <40490, 40498, 40491>,
    <40490, 40491, 40495>    <40490, 40495, 40492>,
    <40490, 40492, 40496>    <40490, 40496, 40493>,
    <40490, 40493, 40497>    <40490, 40497, 40494>,
    <40490, 40494, 40498>    <40499, 40507, 40500>,
    <40499, 40500, 40504>    <40499, 40504, 40501>,
    <40499, 40501, 40505>    <40499, 40505, 40502>,
    <40499, 40502, 40506>    <40499, 40506, 40503>,
    <40499, 40503, 40507>    <40508, 40516, 40509>,
    <40508, 40509, 40513>    <40508, 40513, 40510>,
    <40508, 40510, 40514>    <40508, 40514, 40511>,
    <40508, 40511, 40515>    <40508, 40515, 40512>,
    <40508, 40512, 40516>    <40517, 40525, 40518>,
    <40517, 40518, 40522>    <40517, 40522, 40519>,
    <40517, 40519, 40523>    <40517, 40523, 40520>,
    <40517, 40520, 40524>    <40517, 40524, 40521>,
    <40517, 40521, 40525>    <40526, 40534, 40527>,
    <40526, 40527, 40531>    <40526, 40531, 40528>,
    <40526, 40528, 40532>    <40526, 40532, 40529>,
    <40526, 40529, 40533>    <40526, 40533, 40530>,
    <40526, 40530, 40534>    <40535, 40543, 40536>,
    <40535, 40536, 40540>    <40535, 40540, 40537>,
    <40535, 40537, 40541>    <40535, 40541, 40538>,
    <40535, 40538, 40542>    <40535, 40542, 40539>,
    <40535, 40539, 40543>    <40544, 40552, 40545>,
    <40544, 40545, 40549>    <40544, 40549, 40546>,
    <40544, 40546, 40550>    <40544, 40550, 40547>,
    <40544, 40547, 40551>    <40544, 40551, 40548>,
    <40544, 40548, 40552>    <40553, 40561, 40554>,
    <40553, 40554, 40558>    <40553, 40558, 40555>,
    <40553, 40555, 40559>    <40553, 40559, 40556>,
    <40553, 40556, 40560>    <40553, 40560, 40557>,
    <40553, 40557, 40561>    <40562, 40570, 40563>,
    <40562, 40563, 40567>    <40562, 40567, 40564>,
    <40562, 40564, 40568>    <40562, 40568, 40565>,
    <40562, 40565, 40569>    <40562, 40569, 40566>,
    <40562, 40566, 40570>    <40571, 40579, 40572>,
    <40571, 40572, 40576>    <40571, 40576, 40573>,
    <40571, 40573, 40577>    <40571, 40577, 40574>,
    <40571, 40574, 40578>    <40571, 40578, 40575>,
    <40571, 40575, 40579>    <40580, 40588, 40581>,
    <40580, 40581, 40585>    <40580, 40585, 40582>,
    <40580, 40582, 40586>    <40580, 40586, 40583>,
    <40580, 40583, 40587>    <40580, 40587, 40584>,
    <40580, 40584, 40588>    <40589, 40597, 40590>,
    <40589, 40590, 40594>    <40589, 40594, 40591>,
    <40589, 40591, 40595>    <40589, 40595, 40592>,
    <40589, 40592, 40596>    <40589, 40596, 40593>,
    <40589, 40593, 40597>    <40598, 40606, 40599>,
    <40598, 40599, 40603>    <40598, 40603, 40600>,
    <40598, 40600, 40604>    <40598, 40604, 40601>,
    <40598, 40601, 40605>    <40598, 40605, 40602>,
    <40598, 40602, 40606>    <40607, 40615, 40608>,
    <40607, 40608, 40612>    <40607, 40612, 40609>,
    <40607, 40609, 40613>    <40607, 40613, 40610>,
    <40607, 40610, 40614>    <40607, 40614, 40611>,
    <40607, 40611, 40615>    <40616, 40624, 40617>,
    <40616, 40617, 40621>    <40616, 40621, 40618>,
    <40616, 40618, 40622>    <40616, 40622, 40619>,
    <40616, 40619, 40623>    <40616, 40623, 40620>,
    <40616, 40620, 40624>    <40625, 40633, 40626>,
    <40625, 40626, 40630>    <40625, 40630, 40627>,
    <40625, 40627, 40631>    <40625, 40631, 40628>,
    <40625, 40628, 40632>    <40625, 40632, 40629>,
    <40625, 40629, 40633>    <40634, 40642, 40635>,
    <40634, 40635, 40639>    <40634, 40639, 40636>,
    <40634, 40636, 40640>    <40634, 40640, 40637>,
    <40634, 40637, 40641>    <40634, 40641, 40638>,
    <40634, 40638, 40642>    <40643, 40651, 40644>,
    <40643, 40644, 40648>    <40643, 40648, 40645>,
    <40643, 40645, 40649>    <40643, 40649, 40646>,
    <40643, 40646, 40650>    <40643, 40650, 40647>,
    <40643, 40647, 40651>    <40652, 40660, 40653>,
    <40652, 40653, 40657>    <40652, 40657, 40654>,
    <40652, 40654, 40658>    <40652, 40658, 40655>,
    <40652, 40655, 40659>    <40652, 40659, 40656>,
    <40652, 40656, 40660>    <40661, 40669, 40662>,
    <40661, 40662, 40666>    <40661, 40666, 40663>,
    <40661, 40663, 40667>    <40661, 40667, 40664>,
    <40661, 40664, 40668>    <40661, 40668, 40665>,
    <40661, 40665, 40669>    <40670, 40678, 40671>,
    <40670, 40671, 40675>    <40670, 40675, 40672>,
    <40670, 40672, 40676>    <40670, 40676, 40673>,
    <40670, 40673, 40677>    <40670, 40677, 40674>,
    <40670, 40674, 40678>    <40679, 40687, 40680>,
    <40679, 40680, 40684>    <40679, 40684, 40681>,
    <40679, 40681, 40685>    <40679, 40685, 40682>,
    <40679, 40682, 40686>    <40679, 40686, 40683>,
    <40679, 40683, 40687>    <40688, 40696, 40689>,
    <40688, 40689, 40693>    <40688, 40693, 40690>,
    <40688, 40690, 40694>    <40688, 40694, 40691>,
    <40688, 40691, 40695>    <40688, 40695, 40692>,
    <40688, 40692, 40696>    <40697, 40705, 40698>,
    <40697, 40698, 40702>    <40697, 40702, 40699>,
    <40697, 40699, 40703>    <40697, 40703, 40700>,
    <40697, 40700, 40704>    <40697, 40704, 40701>,
    <40697, 40701, 40705>    <40706, 40714, 40707>,
    <40706, 40707, 40711>    <40706, 40711, 40708>,
    <40706, 40708, 40712>    <40706, 40712, 40709>,
    <40706, 40709, 40713>    <40706, 40713, 40710>,
    <40706, 40710, 40714>    <40715, 40723, 40716>,
    <40715, 40716, 40720>    <40715, 40720, 40717>,
    <40715, 40717, 40721>    <40715, 40721, 40718>,
    <40715, 40718, 40722>    <40715, 40722, 40719>,
    <40715, 40719, 40723>    <40724, 40732, 40725>,
    <40724, 40725, 40729>    <40724, 40729, 40726>,
    <40724, 40726, 40730>    <40724, 40730, 40727>,
    <40724, 40727, 40731>    <40724, 40731, 40728>,
    <40724, 40728, 40732>    <40733, 40741, 40734>,
    <40733, 40734, 40738>    <40733, 40738, 40735>,
    <40733, 40735, 40739>    <40733, 40739, 40736>,
    <40733, 40736, 40740>    <40733, 40740, 40737>,
    <40733, 40737, 40741>    <40742, 40750, 40743>,
    <40742, 40743, 40747>    <40742, 40747, 40744>,
    <40742, 40744, 40748>    <40742, 40748, 40745>,
    <40742, 40745, 40749>    <40742, 40749, 40746>,
    <40742, 40746, 40750>    <40751, 40759, 40752>,
    <40751, 40752, 40756>    <40751, 40756, 40753>,
    <40751, 40753, 40757>    <40751, 40757, 40754>,
    <40751, 40754, 40758>    <40751, 40758, 40755>,
    <40751, 40755, 40759>    <40760, 40768, 40761>,
    <40760, 40761, 40765>    <40760, 40765, 40762>,
    <40760, 40762, 40766>    <40760, 40766, 40763>,
    <40760, 40763, 40767>    <40760, 40767, 40764>,
    <40760, 40764, 40768>    <40769, 40777, 40770>,
    <40769, 40770, 40774>    <40769, 40774, 40771>,
    <40769, 40771, 40775>    <40769, 40775, 40772>,
    <40769, 40772, 40776>    <40769, 40776, 40773>,
    <40769, 40773, 40777>    <40778, 40786, 40779>,
    <40778, 40779, 40783>    <40778, 40783, 40780>,
    <40778, 40780, 40784>    <40778, 40784, 40781>,
    <40778, 40781, 40785>    <40778, 40785, 40782>,
    <40778, 40782, 40786>    <40787, 40795, 40788>,
    <40787, 40788, 40792>    <40787, 40792, 40789>,
    <40787, 40789, 40793>    <40787, 40793, 40790>,
    <40787, 40790, 40794>    <40787, 40794, 40791>,
    <40787, 40791, 40795>    <40796, 40804, 40797>,
    <40796, 40797, 40801>    <40796, 40801, 40798>,
    <40796, 40798, 40802>    <40796, 40802, 40799>,
    <40796, 40799, 40803>    <40796, 40803, 40800>,
    <40796, 40800, 40804>    <40805, 40813, 40806>,
    <40805, 40806, 40810>    <40805, 40810, 40807>,
    <40805, 40807, 40811>    <40805, 40811, 40808>,
    <40805, 40808, 40812>    <40805, 40812, 40809>,
    <40805, 40809, 40813>    <40814, 40822, 40815>,
    <40814, 40815, 40819>    <40814, 40819, 40816>,
    <40814, 40816, 40820>    <40814, 40820, 40817>,
    <40814, 40817, 40821>    <40814, 40821, 40818>,
    <40814, 40818, 40822>    <40823, 40831, 40824>,
    <40823, 40824, 40828>    <40823, 40828, 40825>,
    <40823, 40825, 40829>    <40823, 40829, 40826>,
    <40823, 40826, 40830>    <40823, 40830, 40827>,
    <40823, 40827, 40831>    <40832, 40840, 40833>,
    <40832, 40833, 40837>    <40832, 40837, 40834>,
    <40832, 40834, 40838>    <40832, 40838, 40835>,
    <40832, 40835, 40839>    <40832, 40839, 40836>,
    <40832, 40836, 40840>    <40841, 40849, 40842>,
    <40841, 40842, 40846>    <40841, 40846, 40843>,
    <40841, 40843, 40847>    <40841, 40847, 40844>,
    <40841, 40844, 40848>    <40841, 40848, 40845>,
    <40841, 40845, 40849>    <40850, 40858, 40851>,
    <40850, 40851, 40855>    <40850, 40855, 40852>,
    <40850, 40852, 40856>    <40850, 40856, 40853>,
    <40850, 40853, 40857>    <40850, 40857, 40854>,
    <40850, 40854, 40858>    <40859, 40867, 40860>,
    <40859, 40860, 40864>    <40859, 40864, 40861>,
    <40859, 40861, 40865>    <40859, 40865, 40862>,
    <40859, 40862, 40866>    <40859, 40866, 40863>,
    <40859, 40863, 40867>    <40868, 40876, 40869>,
    <40868, 40869, 40873>    <40868, 40873, 40870>,
    <40868, 40870, 40874>    <40868, 40874, 40871>,
    <40868, 40871, 40875>    <40868, 40875, 40872>,
    <40868, 40872, 40876>    <40877, 40885, 40878>,
    <40877, 40878, 40882>    <40877, 40882, 40879>,
    <40877, 40879, 40883>    <40877, 40883, 40880>,
    <40877, 40880, 40884>    <40877, 40884, 40881>,
    <40877, 40881, 40885>    <40886, 40894, 40887>,
    <40886, 40887, 40891>    <40886, 40891, 40888>,
    <40886, 40888, 40892>    <40886, 40892, 40889>,
    <40886, 40889, 40893>    <40886, 40893, 40890>,
    <40886, 40890, 40894>    <40895, 40903, 40896>,
    <40895, 40896, 40900>    <40895, 40900, 40897>,
    <40895, 40897, 40901>    <40895, 40901, 40898>,
    <40895, 40898, 40902>    <40895, 40902, 40899>,
    <40895, 40899, 40903>    <40904, 40912, 40905>,
    <40904, 40905, 40909>    <40904, 40909, 40906>,
    <40904, 40906, 40910>    <40904, 40910, 40907>,
    <40904, 40907, 40911>    <40904, 40911, 40908>,
    <40904, 40908, 40912>    <40913, 40921, 40914>,
    <40913, 40914, 40918>    <40913, 40918, 40915>,
    <40913, 40915, 40919>    <40913, 40919, 40916>,
    <40913, 40916, 40920>    <40913, 40920, 40917>,
    <40913, 40917, 40921>    <40922, 40930, 40923>,
    <40922, 40923, 40927>    <40922, 40927, 40924>,
    <40922, 40924, 40928>    <40922, 40928, 40925>,
    <40922, 40925, 40929>    <40922, 40929, 40926>,
    <40922, 40926, 40930>    <40931, 40939, 40932>,
    <40931, 40932, 40936>    <40931, 40936, 40933>,
    <40931, 40933, 40937>    <40931, 40937, 40934>,
    <40931, 40934, 40938>    <40931, 40938, 40935>,
    <40931, 40935, 40939>    <40940, 40948, 40941>,
    <40940, 40941, 40945>    <40940, 40945, 40942>,
    <40940, 40942, 40946>    <40940, 40946, 40943>,
    <40940, 40943, 40947>    <40940, 40947, 40944>,
    <40940, 40944, 40948>    <40949, 40957, 40950>,
    <40949, 40950, 40954>    <40949, 40954, 40951>,
    <40949, 40951, 40955>    <40949, 40955, 40952>,
    <40949, 40952, 40956>    <40949, 40956, 40953>,
    <40949, 40953, 40957>    <40958, 40966, 40959>,
    <40958, 40959, 40963>    <40958, 40963, 40960>,
    <40958, 40960, 40964>    <40958, 40964, 40961>,
    <40958, 40961, 40965>    <40958, 40965, 40962>,
    <40958, 40962, 40966>    <40967, 40975, 40968>,
    <40967, 40968, 40972>    <40967, 40972, 40969>,
    <40967, 40969, 40973>    <40967, 40973, 40970>,
    <40967, 40970, 40974>    <40967, 40974, 40971>,
    <40967, 40971, 40975>    <40976, 40984, 40977>,
    <40976, 40977, 40981>    <40976, 40981, 40978>,
    <40976, 40978, 40982>    <40976, 40982, 40979>,
    <40976, 40979, 40983>    <40976, 40983, 40980>,
    <40976, 40980, 40984>    <40985, 40993, 40986>,
    <40985, 40986, 40990>    <40985, 40990, 40987>,
    <40985, 40987, 40991>    <40985, 40991, 40988>,
    <40985, 40988, 40992>    <40985, 40992, 40989>,
    <40985, 40989, 40993>    <40994, 41002, 40995>,
    <40994, 40995, 40999>    <40994, 40999, 40996>,
    <40994, 40996, 41000>    <40994, 41000, 40997>,
    <40994, 40997, 41001>    <40994, 41001, 40998>,
    <40994, 40998, 41002>    <41003, 41011, 41004>,
    <41003, 41004, 41008>    <41003, 41008, 41005>,
    <41003, 41005, 41009>    <41003, 41009, 41006>,
    <41003, 41006, 41010>    <41003, 41010, 41007>,
    <41003, 41007, 41011>    <41012, 41020, 41013>,
    <41012, 41013, 41017>    <41012, 41017, 41014>,
    <41012, 41014, 41018>    <41012, 41018, 41015>,
    <41012, 41015, 41019>    <41012, 41019, 41016>,
    <41012, 41016, 41020>    <41021, 41029, 41022>,
    <41021, 41022, 41026>    <41021, 41026, 41023>,
    <41021, 41023, 41027>    <41021, 41027, 41024>,
    <41021, 41024, 41028>    <41021, 41028, 41025>,
    <41021, 41025, 41029>    <41030, 41038, 41031>,
    <41030, 41031, 41035>    <41030, 41035, 41032>,
    <41030, 41032, 41036>    <41030, 41036, 41033>,
    <41030, 41033, 41037>    <41030, 41037, 41034>,
    <41030, 41034, 41038>    <41039, 41047, 41040>,
    <41039, 41040, 41044>    <41039, 41044, 41041>,
    <41039, 41041, 41045>    <41039, 41045, 41042>,
    <41039, 41042, 41046>    <41039, 41046, 41043>,
    <41039, 41043, 41047>    <41048, 41056, 41049>,
    <41048, 41049, 41053>    <41048, 41053, 41050>,
    <41048, 41050, 41054>    <41048, 41054, 41051>,
    <41048, 41051, 41055>    <41048, 41055, 41052>,
    <41048, 41052, 41056>    <41057, 41065, 41058>,
    <41057, 41058, 41062>    <41057, 41062, 41059>,
    <41057, 41059, 41063>    <41057, 41063, 41060>,
    <41057, 41060, 41064>    <41057, 41064, 41061>,
    <41057, 41061, 41065>    <41066, 41074, 41067>,
    <41066, 41067, 41071>    <41066, 41071, 41068>,
    <41066, 41068, 41072>    <41066, 41072, 41069>,
    <41066, 41069, 41073>    <41066, 41073, 41070>,
    <41066, 41070, 41074>    <41075, 41083, 41076>,
    <41075, 41076, 41080>    <41075, 41080, 41077>,
    <41075, 41077, 41081>    <41075, 41081, 41078>,
    <41075, 41078, 41082>    <41075, 41082, 41079>,
    <41075, 41079, 41083>    <41084, 41092, 41085>,
    <41084, 41085, 41089>    <41084, 41089, 41086>,
    <41084, 41086, 41090>    <41084, 41090, 41087>,
    <41084, 41087, 41091>    <41084, 41091, 41088>,
    <41084, 41088, 41092>    <41093, 41101, 41094>,
    <41093, 41094, 41098>    <41093, 41098, 41095>,
    <41093, 41095, 41099>    <41093, 41099, 41096>,
    <41093, 41096, 41100>    <41093, 41100, 41097>,
    <41093, 41097, 41101>    <41102, 41110, 41103>,
    <41102, 41103, 41107>    <41102, 41107, 41104>,
    <41102, 41104, 41108>    <41102, 41108, 41105>,
    <41102, 41105, 41109>    <41102, 41109, 41106>,
    <41102, 41106, 41110>    <41111, 41119, 41112>,
    <41111, 41112, 41116>    <41111, 41116, 41113>,
    <41111, 41113, 41117>    <41111, 41117, 41114>,
    <41111, 41114, 41118>    <41111, 41118, 41115>,
    <41111, 41115, 41119>    <41120, 41128, 41121>,
    <41120, 41121, 41125>    <41120, 41125, 41122>,
    <41120, 41122, 41126>    <41120, 41126, 41123>,
    <41120, 41123, 41127>    <41120, 41127, 41124>,
    <41120, 41124, 41128>    <41129, 41137, 41130>,
    <41129, 41130, 41134>    <41129, 41134, 41131>,
    <41129, 41131, 41135>    <41129, 41135, 41132>,
    <41129, 41132, 41136>    <41129, 41136, 41133>,
    <41129, 41133, 41137>    <41138, 41146, 41139>,
    <41138, 41139, 41143>    <41138, 41143, 41140>,
    <41138, 41140, 41144>    <41138, 41144, 41141>,
    <41138, 41141, 41145>    <41138, 41145, 41142>,
    <41138, 41142, 41146>    <41147, 41155, 41148>,
    <41147, 41148, 41152>    <41147, 41152, 41149>,
    <41147, 41149, 41153>    <41147, 41153, 41150>,
    <41147, 41150, 41154>    <41147, 41154, 41151>,
    <41147, 41151, 41155>    <41156, 41164, 41157>,
    <41156, 41157, 41161>    <41156, 41161, 41158>,
    <41156, 41158, 41162>    <41156, 41162, 41159>,
    <41156, 41159, 41163>    <41156, 41163, 41160>,
    <41156, 41160, 41164>    <41165, 41173, 41166>,
    <41165, 41166, 41170>    <41165, 41170, 41167>,
    <41165, 41167, 41171>    <41165, 41171, 41168>,
    <41165, 41168, 41172>    <41165, 41172, 41169>,
    <41165, 41169, 41173>    <41174, 41182, 41175>,
    <41174, 41175, 41179>    <41174, 41179, 41176>,
    <41174, 41176, 41180>    <41174, 41180, 41177>,
    <41174, 41177, 41181>    <41174, 41181, 41178>,
    <41174, 41178, 41182>    <41183, 41191, 41184>,
    <41183, 41184, 41188>    <41183, 41188, 41185>,
    <41183, 41185, 41189>    <41183, 41189, 41186>,
    <41183, 41186, 41190>    <41183, 41190, 41187>,
    <41183, 41187, 41191>    <41192, 41200, 41193>,
    <41192, 41193, 41197>    <41192, 41197, 41194>,
    <41192, 41194, 41198>    <41192, 41198, 41195>,
    <41192, 41195, 41199>    <41192, 41199, 41196>,
    <41192, 41196, 41200>    <41201, 41209, 41202>,
    <41201, 41202, 41206>    <41201, 41206, 41203>,
    <41201, 41203, 41207>    <41201, 41207, 41204>,
    <41201, 41204, 41208>    <41201, 41208, 41205>,
    <41201, 41205, 41209>    <41210, 41218, 41211>,
    <41210, 41211, 41215>    <41210, 41215, 41212>,
    <41210, 41212, 41216>    <41210, 41216, 41213>,
    <41210, 41213, 41217>    <41210, 41217, 41214>,
    <41210, 41214, 41218>    <41219, 41227, 41220>,
    <41219, 41220, 41224>    <41219, 41224, 41221>,
    <41219, 41221, 41225>    <41219, 41225, 41222>,
    <41219, 41222, 41226>    <41219, 41226, 41223>,
    <41219, 41223, 41227>    <41228, 41236, 41229>,
    <41228, 41229, 41233>    <41228, 41233, 41230>,
    <41228, 41230, 41234>    <41228, 41234, 41231>,
    <41228, 41231, 41235>    <41228, 41235, 41232>,
    <41228, 41232, 41236>    <41237, 41245, 41238>,
    <41237, 41238, 41242>    <41237, 41242, 41239>,
    <41237, 41239, 41243>    <41237, 41243, 41240>,
    <41237, 41240, 41244>    <41237, 41244, 41241>,
    <41237, 41241, 41245>    <41246, 41254, 41247>,
    <41246, 41247, 41251>    <41246, 41251, 41248>,
    <41246, 41248, 41252>    <41246, 41252, 41249>,
    <41246, 41249, 41253>    <41246, 41253, 41250>,
    <41246, 41250, 41254>    <41255, 41263, 41256>,
    <41255, 41256, 41260>    <41255, 41260, 41257>,
    <41255, 41257, 41261>    <41255, 41261, 41258>,
    <41255, 41258, 41262>    <41255, 41262, 41259>,
    <41255, 41259, 41263>    <41264, 41272, 41265>,
    <41264, 41265, 41269>    <41264, 41269, 41266>,
    <41264, 41266, 41270>    <41264, 41270, 41267>,
    <41264, 41267, 41271>    <41264, 41271, 41268>,
    <41264, 41268, 41272>    <41273, 41281, 41274>,
    <41273, 41274, 41278>    <41273, 41278, 41275>,
    <41273, 41275, 41279>    <41273, 41279, 41276>,
    <41273, 41276, 41280>    <41273, 41280, 41277>,
    <41273, 41277, 41281>    <41282, 41290, 41283>,
    <41282, 41283, 41287>    <41282, 41287, 41284>,
    <41282, 41284, 41288>    <41282, 41288, 41285>,
    <41282, 41285, 41289>    <41282, 41289, 41286>,
    <41282, 41286, 41290>    <41291, 41299, 41292>,
    <41291, 41292, 41296>    <41291, 41296, 41293>,
    <41291, 41293, 41297>    <41291, 41297, 41294>,
    <41291, 41294, 41298>    <41291, 41298, 41295>,
    <41291, 41295, 41299>    <41300, 41308, 41301>,
    <41300, 41301, 41305>    <41300, 41305, 41302>,
    <41300, 41302, 41306>    <41300, 41306, 41303>,
    <41300, 41303, 41307>    <41300, 41307, 41304>,
    <41300, 41304, 41308>    <41309, 41317, 41310>,
    <41309, 41310, 41314>    <41309, 41314, 41311>,
    <41309, 41311, 41315>    <41309, 41315, 41312>,
    <41309, 41312, 41316>    <41309, 41316, 41313>,
    <41309, 41313, 41317>    <41318, 41326, 41319>,
    <41318, 41319, 41323>    <41318, 41323, 41320>,
    <41318, 41320, 41324>    <41318, 41324, 41321>,
    <41318, 41321, 41325>    <41318, 41325, 41322>,
    <41318, 41322, 41326>    <41327, 41335, 41328>,
    <41327, 41328, 41332>    <41327, 41332, 41329>,
    <41327, 41329, 41333>    <41327, 41333, 41330>,
    <41327, 41330, 41334>    <41327, 41334, 41331>,
    <41327, 41331, 41335>    <41336, 41344, 41337>,
    <41336, 41337, 41341>    <41336, 41341, 41338>,
    <41336, 41338, 41342>    <41336, 41342, 41339>,
    <41336, 41339, 41343>    <41336, 41343, 41340>,
    <41336, 41340, 41344>    <41345, 41353, 41346>,
    <41345, 41346, 41350>    <41345, 41350, 41347>,
    <41345, 41347, 41351>    <41345, 41351, 41348>,
    <41345, 41348, 41352>    <41345, 41352, 41349>,
    <41345, 41349, 41353>    <41354, 41362, 41355>,
    <41354, 41355, 41359>    <41354, 41359, 41356>,
    <41354, 41356, 41360>    <41354, 41360, 41357>,
    <41354, 41357, 41361>    <41354, 41361, 41358>,
    <41354, 41358, 41362>    <41363, 41371, 41364>,
    <41363, 41364, 41368>    <41363, 41368, 41365>,
    <41363, 41365, 41369>    <41363, 41369, 41366>,
    <41363, 41366, 41370>    <41363, 41370, 41367>,
    <41363, 41367, 41371>    <41372, 41380, 41373>,
    <41372, 41373, 41377>    <41372, 41377, 41374>,
    <41372, 41374, 41378>    <41372, 41378, 41375>,
    <41372, 41375, 41379>    <41372, 41379, 41376>,
    <41372, 41376, 41380>    <41381, 41389, 41382>,
    <41381, 41382, 41386>    <41381, 41386, 41383>,
    <41381, 41383, 41387>    <41381, 41387, 41384>,
    <41381, 41384, 41388>    <41381, 41388, 41385>,
    <41381, 41385, 41389>    <41390, 41398, 41391>,
    <41390, 41391, 41395>    <41390, 41395, 41392>,
    <41390, 41392, 41396>    <41390, 41396, 41393>,
    <41390, 41393, 41397>    <41390, 41397, 41394>,
    <41390, 41394, 41398>    <41399, 41407, 41400>,
    <41399, 41400, 41404>    <41399, 41404, 41401>,
    <41399, 41401, 41405>    <41399, 41405, 41402>,
    <41399, 41402, 41406>    <41399, 41406, 41403>,
    <41399, 41403, 41407>    <41408, 41416, 41409>,
    <41408, 41409, 41413>    <41408, 41413, 41410>,
    <41408, 41410, 41414>    <41408, 41414, 41411>,
    <41408, 41411, 41415>    <41408, 41415, 41412>,
    <41408, 41412, 41416>    <41417, 41425, 41418>,
    <41417, 41418, 41422>    <41417, 41422, 41419>,
    <41417, 41419, 41423>    <41417, 41423, 41420>,
    <41417, 41420, 41424>    <41417, 41424, 41421>,
    <41417, 41421, 41425>    <41426, 41434, 41427>,
    <41426, 41427, 41431>    <41426, 41431, 41428>,
    <41426, 41428, 41432>    <41426, 41432, 41429>,
    <41426, 41429, 41433>    <41426, 41433, 41430>,
    <41426, 41430, 41434>    <41435, 41443, 41436>,
    <41435, 41436, 41440>    <41435, 41440, 41437>,
    <41435, 41437, 41441>    <41435, 41441, 41438>,
    <41435, 41438, 41442>    <41435, 41442, 41439>,
    <41435, 41439, 41443>    <41444, 41452, 41445>,
    <41444, 41445, 41449>    <41444, 41449, 41446>,
    <41444, 41446, 41450>    <41444, 41450, 41447>,
    <41444, 41447, 41451>    <41444, 41451, 41448>,
    <41444, 41448, 41452>    <41453, 41461, 41454>,
    <41453, 41454, 41458>    <41453, 41458, 41455>,
    <41453, 41455, 41459>    <41453, 41459, 41456>,
    <41453, 41456, 41460>    <41453, 41460, 41457>,
    <41453, 41457, 41461>    <41462, 41470, 41463>,
    <41462, 41463, 41467>    <41462, 41467, 41464>,
    <41462, 41464, 41468>    <41462, 41468, 41465>,
    <41462, 41465, 41469>    <41462, 41469, 41466>,
    <41462, 41466, 41470>    <41471, 41479, 41472>,
    <41471, 41472, 41476>    <41471, 41476, 41473>,
    <41471, 41473, 41477>    <41471, 41477, 41474>,
    <41471, 41474, 41478>    <41471, 41478, 41475>,
    <41471, 41475, 41479>    <41480, 41488, 41481>,
    <41480, 41481, 41485>    <41480, 41485, 41482>,
    <41480, 41482, 41486>    <41480, 41486, 41483>,
    <41480, 41483, 41487>    <41480, 41487, 41484>,
    <41480, 41484, 41488>    <41489, 41497, 41490>,
    <41489, 41490, 41494>    <41489, 41494, 41491>,
    <41489, 41491, 41495>    <41489, 41495, 41492>,
    <41489, 41492, 41496>    <41489, 41496, 41493>,
    <41489, 41493, 41497>    <41498, 41506, 41499>,
    <41498, 41499, 41503>    <41498, 41503, 41500>,
    <41498, 41500, 41504>    <41498, 41504, 41501>,
    <41498, 41501, 41505>    <41498, 41505, 41502>,
    <41498, 41502, 41506>    <41507, 41515, 41508>,
    <41507, 41508, 41512>    <41507, 41512, 41509>,
    <41507, 41509, 41513>    <41507, 41513, 41510>,
    <41507, 41510, 41514>    <41507, 41514, 41511>,
    <41507, 41511, 41515>    <41516, 41524, 41517>,
    <41516, 41517, 41521>    <41516, 41521, 41518>,
    <41516, 41518, 41522>    <41516, 41522, 41519>,
    <41516, 41519, 41523>    <41516, 41523, 41520>,
    <41516, 41520, 41524>    <41525, 41533, 41526>,
    <41525, 41526, 41530>    <41525, 41530, 41527>,
    <41525, 41527, 41531>    <41525, 41531, 41528>,
    <41525, 41528, 41532>    <41525, 41532, 41529>,
    <41525, 41529, 41533>    <41534, 41542, 41535>,
    <41534, 41535, 41539>    <41534, 41539, 41536>,
    <41534, 41536, 41540>    <41534, 41540, 41537>,
    <41534, 41537, 41541>    <41534, 41541, 41538>,
    <41534, 41538, 41542>    <41543, 41551, 41544>,
    <41543, 41544, 41548>    <41543, 41548, 41545>,
    <41543, 41545, 41549>    <41543, 41549, 41546>,
    <41543, 41546, 41550>    <41543, 41550, 41547>,
    <41543, 41547, 41551>    <41552, 41560, 41553>,
    <41552, 41553, 41557>    <41552, 41557, 41554>,
    <41552, 41554, 41558>    <41552, 41558, 41555>,
    <41552, 41555, 41559>    <41552, 41559, 41556>,
    <41552, 41556, 41560>    <41561, 41569, 41562>,
    <41561, 41562, 41566>    <41561, 41566, 41563>,
    <41561, 41563, 41567>    <41561, 41567, 41564>,
    <41561, 41564, 41568>    <41561, 41568, 41565>,
    <41561, 41565, 41569>    <41570, 41578, 41571>,
    <41570, 41571, 41575>    <41570, 41575, 41572>,
    <41570, 41572, 41576>    <41570, 41576, 41573>,
    <41570, 41573, 41577>    <41570, 41577, 41574>,
    <41570, 41574, 41578>    <41579, 41587, 41580>,
    <41579, 41580, 41584>    <41579, 41584, 41581>,
    <41579, 41581, 41585>    <41579, 41585, 41582>,
    <41579, 41582, 41586>    <41579, 41586, 41583>,
    <41579, 41583, 41587>    <41588, 41596, 41589>,
    <41588, 41589, 41593>    <41588, 41593, 41590>,
    <41588, 41590, 41594>    <41588, 41594, 41591>,
    <41588, 41591, 41595>    <41588, 41595, 41592>,
    <41588, 41592, 41596>    <41597, 41605, 41598>,
    <41597, 41598, 41602>    <41597, 41602, 41599>,
    <41597, 41599, 41603>    <41597, 41603, 41600>,
    <41597, 41600, 41604>    <41597, 41604, 41601>,
    <41597, 41601, 41605>    <41606, 41614, 41607>,
    <41606, 41607, 41611>    <41606, 41611, 41608>,
    <41606, 41608, 41612>    <41606, 41612, 41609>,
    <41606, 41609, 41613>    <41606, 41613, 41610>,
    <41606, 41610, 41614>    <41615, 41623, 41616>,
    <41615, 41616, 41620>    <41615, 41620, 41617>,
    <41615, 41617, 41621>    <41615, 41621, 41618>,
    <41615, 41618, 41622>    <41615, 41622, 41619>,
    <41615, 41619, 41623>    <41624, 41632, 41625>,
    <41624, 41625, 41629>    <41624, 41629, 41626>,
    <41624, 41626, 41630>    <41624, 41630, 41627>,
    <41624, 41627, 41631>    <41624, 41631, 41628>,
    <41624, 41628, 41632>    <41633, 41641, 41634>,
    <41633, 41634, 41638>    <41633, 41638, 41635>,
    <41633, 41635, 41639>    <41633, 41639, 41636>,
    <41633, 41636, 41640>    <41633, 41640, 41637>,
    <41633, 41637, 41641>    <41642, 41650, 41643>,
    <41642, 41643, 41647>    <41642, 41647, 41644>,
    <41642, 41644, 41648>    <41642, 41648, 41645>,
    <41642, 41645, 41649>    <41642, 41649, 41646>,
    <41642, 41646, 41650>    <41651, 41659, 41652>,
    <41651, 41652, 41656>    <41651, 41656, 41653>,
    <41651, 41653, 41657>    <41651, 41657, 41654>,
    <41651, 41654, 41658>    <41651, 41658, 41655>,
    <41651, 41655, 41659>    <41660, 41668, 41661>,
    <41660, 41661, 41665>    <41660, 41665, 41662>,
    <41660, 41662, 41666>    <41660, 41666, 41663>,
    <41660, 41663, 41667>    <41660, 41667, 41664>,
    <41660, 41664, 41668>    <41669, 41677, 41670>,
    <41669, 41670, 41674>    <41669, 41674, 41671>,
    <41669, 41671, 41675>    <41669, 41675, 41672>,
    <41669, 41672, 41676>    <41669, 41676, 41673>,
    <41669, 41673, 41677>    <41678, 41686, 41679>,
    <41678, 41679, 41683>    <41678, 41683, 41680>,
    <41678, 41680, 41684>    <41678, 41684, 41681>,
    <41678, 41681, 41685>    <41678, 41685, 41682>,
    <41678, 41682, 41686>    <41687, 41695, 41688>,
    <41687, 41688, 41692>    <41687, 41692, 41689>,
    <41687, 41689, 41693>    <41687, 41693, 41690>,
    <41687, 41690, 41694>    <41687, 41694, 41691>,
    <41687, 41691, 41695>    <41696, 41704, 41697>,
    <41696, 41697, 41701>    <41696, 41701, 41698>,
    <41696, 41698, 41702>    <41696, 41702, 41699>,
    <41696, 41699, 41703>    <41696, 41703, 41700>,
    <41696, 41700, 41704>    <41705, 41713, 41706>,
    <41705, 41706, 41710>    <41705, 41710, 41707>,
    <41705, 41707, 41711>    <41705, 41711, 41708>,
    <41705, 41708, 41712>    <41705, 41712, 41709>,
    <41705, 41709, 41713>    <41714, 41722, 41715>,
    <41714, 41715, 41719>    <41714, 41719, 41716>,
    <41714, 41716, 41720>    <41714, 41720, 41717>,
    <41714, 41717, 41721>    <41714, 41721, 41718>,
    <41714, 41718, 41722>    <41723, 41731, 41724>,
    <41723, 41724, 41728>    <41723, 41728, 41725>,
    <41723, 41725, 41729>    <41723, 41729, 41726>,
    <41723, 41726, 41730>    <41723, 41730, 41727>,
    <41723, 41727, 41731>    <41732, 41740, 41733>,
    <41732, 41733, 41737>    <41732, 41737, 41734>,
    <41732, 41734, 41738>    <41732, 41738, 41735>,
    <41732, 41735, 41739>    <41732, 41739, 41736>,
    <41732, 41736, 41740>    <41741, 41749, 41742>,
    <41741, 41742, 41746>    <41741, 41746, 41743>,
    <41741, 41743, 41747>    <41741, 41747, 41744>,
    <41741, 41744, 41748>    <41741, 41748, 41745>,
    <41741, 41745, 41749>    <41750, 41758, 41751>,
    <41750, 41751, 41755>    <41750, 41755, 41752>,
    <41750, 41752, 41756>    <41750, 41756, 41753>,
    <41750, 41753, 41757>    <41750, 41757, 41754>,
    <41750, 41754, 41758>    <41759, 41767, 41760>,
    <41759, 41760, 41764>    <41759, 41764, 41761>,
    <41759, 41761, 41765>    <41759, 41765, 41762>,
    <41759, 41762, 41766>    <41759, 41766, 41763>,
    <41759, 41763, 41767>    <41768, 41776, 41769>,
    <41768, 41769, 41773>    <41768, 41773, 41770>,
    <41768, 41770, 41774>    <41768, 41774, 41771>,
    <41768, 41771, 41775>    <41768, 41775, 41772>,
    <41768, 41772, 41776>    <41777, 41785, 41778>,
    <41777, 41778, 41782>    <41777, 41782, 41779>,
    <41777, 41779, 41783>    <41777, 41783, 41780>,
    <41777, 41780, 41784>    <41777, 41784, 41781>,
    <41777, 41781, 41785>    <41786, 41794, 41787>,
    <41786, 41787, 41791>    <41786, 41791, 41788>,
    <41786, 41788, 41792>    <41786, 41792, 41789>,
    <41786, 41789, 41793>    <41786, 41793, 41790>,
    <41786, 41790, 41794>    <41795, 41803, 41796>,
    <41795, 41796, 41800>    <41795, 41800, 41797>,
    <41795, 41797, 41801>    <41795, 41801, 41798>,
    <41795, 41798, 41802>    <41795, 41802, 41799>,
    <41795, 41799, 41803>    <41804, 41812, 41805>,
    <41804, 41805, 41809>    <41804, 41809, 41806>,
    <41804, 41806, 41810>    <41804, 41810, 41807>,
    <41804, 41807, 41811>    <41804, 41811, 41808>,
    <41804, 41808, 41812>    <41813, 41821, 41814>,
    <41813, 41814, 41818>    <41813, 41818, 41815>,
    <41813, 41815, 41819>    <41813, 41819, 41816>,
    <41813, 41816, 41820>    <41813, 41820, 41817>,
    <41813, 41817, 41821>    <41822, 41830, 41823>,
    <41822, 41823, 41827>    <41822, 41827, 41824>,
    <41822, 41824, 41828>    <41822, 41828, 41825>,
    <41822, 41825, 41829>    <41822, 41829, 41826>,
    <41822, 41826, 41830>    <41831, 41839, 41832>,
    <41831, 41832, 41836>    <41831, 41836, 41833>,
    <41831, 41833, 41837>    <41831, 41837, 41834>,
    <41831, 41834, 41838>    <41831, 41838, 41835>,
    <41831, 41835, 41839>    <41840, 41848, 41841>,
    <41840, 41841, 41845>    <41840, 41845, 41842>,
    <41840, 41842, 41846>    <41840, 41846, 41843>,
    <41840, 41843, 41847>    <41840, 41847, 41844>,
    <41840, 41844, 41848>    <41849, 41857, 41850>,
    <41849, 41850, 41854>    <41849, 41854, 41851>,
    <41849, 41851, 41855>    <41849, 41855, 41852>,
    <41849, 41852, 41856>    <41849, 41856, 41853>,
    <41849, 41853, 41857>    <41858, 41866, 41859>,
    <41858, 41859, 41863>    <41858, 41863, 41860>,
    <41858, 41860, 41864>    <41858, 41864, 41861>,
    <41858, 41861, 41865>    <41858, 41865, 41862>,
    <41858, 41862, 41866>    <41867, 41875, 41868>,
    <41867, 41868, 41872>    <41867, 41872, 41869>,
    <41867, 41869, 41873>    <41867, 41873, 41870>,
    <41867, 41870, 41874>    <41867, 41874, 41871>,
    <41867, 41871, 41875>    <41876, 41884, 41877>,
    <41876, 41877, 41881>    <41876, 41881, 41878>,
    <41876, 41878, 41882>    <41876, 41882, 41879>,
    <41876, 41879, 41883>    <41876, 41883, 41880>,
    <41876, 41880, 41884>    <41885, 41893, 41886>,
    <41885, 41886, 41890>    <41885, 41890, 41887>,
    <41885, 41887, 41891>    <41885, 41891, 41888>,
    <41885, 41888, 41892>    <41885, 41892, 41889>,
    <41885, 41889, 41893>    <41894, 41902, 41895>,
    <41894, 41895, 41899>    <41894, 41899, 41896>,
    <41894, 41896, 41900>    <41894, 41900, 41897>,
    <41894, 41897, 41901>    <41894, 41901, 41898>,
    <41894, 41898, 41902>    <41903, 41911, 41904>,
    <41903, 41904, 41908>    <41903, 41908, 41905>,
    <41903, 41905, 41909>    <41903, 41909, 41906>,
    <41903, 41906, 41910>    <41903, 41910, 41907>,
    <41903, 41907, 41911>    <41912, 41920, 41913>,
    <41912, 41913, 41917>    <41912, 41917, 41914>,
    <41912, 41914, 41918>    <41912, 41918, 41915>,
    <41912, 41915, 41919>    <41912, 41919, 41916>,
    <41912, 41916, 41920>    <41921, 41929, 41922>,
    <41921, 41922, 41926>    <41921, 41926, 41923>,
    <41921, 41923, 41927>    <41921, 41927, 41924>,
    <41921, 41924, 41928>    <41921, 41928, 41925>,
    <41921, 41925, 41929>    <41930, 41938, 41931>,
    <41930, 41931, 41935>    <41930, 41935, 41932>,
    <41930, 41932, 41936>    <41930, 41936, 41933>,
    <41930, 41933, 41937>    <41930, 41937, 41934>,
    <41930, 41934, 41938>    <41939, 41947, 41940>,
    <41939, 41940, 41944>    <41939, 41944, 41941>,
    <41939, 41941, 41945>    <41939, 41945, 41942>,
    <41939, 41942, 41946>    <41939, 41946, 41943>,
    <41939, 41943, 41947>    <41948, 41956, 41949>,
    <41948, 41949, 41953>    <41948, 41953, 41950>,
    <41948, 41950, 41954>    <41948, 41954, 41951>,
    <41948, 41951, 41955>    <41948, 41955, 41952>,
    <41948, 41952, 41956>    <41957, 41965, 41958>,
    <41957, 41958, 41962>    <41957, 41962, 41959>,
    <41957, 41959, 41963>    <41957, 41963, 41960>,
    <41957, 41960, 41964>    <41957, 41964, 41961>,
    <41957, 41961, 41965>    <41966, 41974, 41967>,
    <41966, 41967, 41971>    <41966, 41971, 41968>,
    <41966, 41968, 41972>    <41966, 41972, 41969>,
    <41966, 41969, 41973>    <41966, 41973, 41970>,
    <41966, 41970, 41974>    <41975, 41983, 41976>,
    <41975, 41976, 41980>    <41975, 41980, 41977>,
    <41975, 41977, 41981>    <41975, 41981, 41978>,
    <41975, 41978, 41982>    <41975, 41982, 41979>,
    <41975, 41979, 41983>    <41984, 41992, 41985>,
    <41984, 41985, 41989>    <41984, 41989, 41986>,
    <41984, 41986, 41990>    <41984, 41990, 41987>,
    <41984, 41987, 41991>    <41984, 41991, 41988>,
    <41984, 41988, 41992>    <41993, 42001, 41994>,
    <41993, 41994, 41998>    <41993, 41998, 41995>,
    <41993, 41995, 41999>    <41993, 41999, 41996>,
    <41993, 41996, 42000>    <41993, 42000, 41997>,
    <41993, 41997, 42001>    <42002, 42010, 42003>,
    <42002, 42003, 42007>    <42002, 42007, 42004>,
    <42002, 42004, 42008>    <42002, 42008, 42005>,
    <42002, 42005, 42009>    <42002, 42009, 42006>,
    <42002, 42006, 42010>    <42011, 42019, 42012>,
    <42011, 42012, 42016>    <42011, 42016, 42013>,
    <42011, 42013, 42017>    <42011, 42017, 42014>,
    <42011, 42014, 42018>    <42011, 42018, 42015>,
    <42011, 42015, 42019>    <42020, 42028, 42021>,
    <42020, 42021, 42025>    <42020, 42025, 42022>,
    <42020, 42022, 42026>    <42020, 42026, 42023>,
    <42020, 42023, 42027>    <42020, 42027, 42024>,
    <42020, 42024, 42028>    <42029, 42037, 42030>,
    <42029, 42030, 42034>    <42029, 42034, 42031>,
    <42029, 42031, 42035>    <42029, 42035, 42032>,
    <42029, 42032, 42036>    <42029, 42036, 42033>,
    <42029, 42033, 42037>    <42038, 42046, 42039>,
    <42038, 42039, 42043>    <42038, 42043, 42040>,
    <42038, 42040, 42044>    <42038, 42044, 42041>,
    <42038, 42041, 42045>    <42038, 42045, 42042>,
    <42038, 42042, 42046>    <42047, 42055, 42048>,
    <42047, 42048, 42052>    <42047, 42052, 42049>,
    <42047, 42049, 42053>    <42047, 42053, 42050>,
    <42047, 42050, 42054>    <42047, 42054, 42051>,
    <42047, 42051, 42055>    <42056, 42064, 42057>,
    <42056, 42057, 42061>    <42056, 42061, 42058>,
    <42056, 42058, 42062>    <42056, 42062, 42059>,
    <42056, 42059, 42063>    <42056, 42063, 42060>,
    <42056, 42060, 42064>    <42065, 42073, 42066>,
    <42065, 42066, 42070>    <42065, 42070, 42067>,
    <42065, 42067, 42071>    <42065, 42071, 42068>,
    <42065, 42068, 42072>    <42065, 42072, 42069>,
    <42065, 42069, 42073>    <42074, 42082, 42075>,
    <42074, 42075, 42079>    <42074, 42079, 42076>,
    <42074, 42076, 42080>    <42074, 42080, 42077>,
    <42074, 42077, 42081>    <42074, 42081, 42078>,
    <42074, 42078, 42082>    <42083, 42091, 42084>,
    <42083, 42084, 42088>    <42083, 42088, 42085>,
    <42083, 42085, 42089>    <42083, 42089, 42086>,
    <42083, 42086, 42090>    <42083, 42090, 42087>,
    <42083, 42087, 42091>    <42092, 42100, 42093>,
    <42092, 42093, 42097>    <42092, 42097, 42094>,
    <42092, 42094, 42098>    <42092, 42098, 42095>,
    <42092, 42095, 42099>    <42092, 42099, 42096>,
    <42092, 42096, 42100>    <42101, 42109, 42102>,
    <42101, 42102, 42106>    <42101, 42106, 42103>,
    <42101, 42103, 42107>    <42101, 42107, 42104>,
    <42101, 42104, 42108>    <42101, 42108, 42105>,
    <42101, 42105, 42109>    <42110, 42118, 42111>,
    <42110, 42111, 42115>    <42110, 42115, 42112>,
    <42110, 42112, 42116>    <42110, 42116, 42113>,
    <42110, 42113, 42117>    <42110, 42117, 42114>,
    <42110, 42114, 42118>    <42119, 42127, 42120>,
    <42119, 42120, 42124>    <42119, 42124, 42121>,
    <42119, 42121, 42125>    <42119, 42125, 42122>,
    <42119, 42122, 42126>    <42119, 42126, 42123>,
    <42119, 42123, 42127>    <42128, 42136, 42129>,
    <42128, 42129, 42133>    <42128, 42133, 42130>,
    <42128, 42130, 42134>    <42128, 42134, 42131>,
    <42128, 42131, 42135>    <42128, 42135, 42132>,
    <42128, 42132, 42136>    <42137, 42145, 42138>,
    <42137, 42138, 42142>    <42137, 42142, 42139>,
    <42137, 42139, 42143>    <42137, 42143, 42140>,
    <42137, 42140, 42144>    <42137, 42144, 42141>,
    <42137, 42141, 42145>    <42146, 42154, 42147>,
    <42146, 42147, 42151>    <42146, 42151, 42148>,
    <42146, 42148, 42152>    <42146, 42152, 42149>,
    <42146, 42149, 42153>    <42146, 42153, 42150>,
    <42146, 42150, 42154>    <42155, 42163, 42156>,
    <42155, 42156, 42160>    <42155, 42160, 42157>,
    <42155, 42157, 42161>    <42155, 42161, 42158>,
    <42155, 42158, 42162>    <42155, 42162, 42159>,
    <42155, 42159, 42163>    <42164, 42172, 42165>,
    <42164, 42165, 42169>    <42164, 42169, 42166>,
    <42164, 42166, 42170>    <42164, 42170, 42167>,
    <42164, 42167, 42171>    <42164, 42171, 42168>,
    <42164, 42168, 42172>    <42173, 42181, 42174>,
    <42173, 42174, 42178>    <42173, 42178, 42175>,
    <42173, 42175, 42179>    <42173, 42179, 42176>,
    <42173, 42176, 42180>    <42173, 42180, 42177>,
    <42173, 42177, 42181>    <42182, 42190, 42183>,
    <42182, 42183, 42187>    <42182, 42187, 42184>,
    <42182, 42184, 42188>    <42182, 42188, 42185>,
    <42182, 42185, 42189>    <42182, 42189, 42186>,
    <42182, 42186, 42190>    <42191, 42199, 42192>,
    <42191, 42192, 42196>    <42191, 42196, 42193>,
    <42191, 42193, 42197>    <42191, 42197, 42194>,
    <42191, 42194, 42198>    <42191, 42198, 42195>,
    <42191, 42195, 42199>    <42200, 42208, 42201>,
    <42200, 42201, 42205>    <42200, 42205, 42202>,
    <42200, 42202, 42206>    <42200, 42206, 42203>,
    <42200, 42203, 42207>    <42200, 42207, 42204>,
    <42200, 42204, 42208>    <42209, 42217, 42210>,
    <42209, 42210, 42214>    <42209, 42214, 42211>,
    <42209, 42211, 42215>    <42209, 42215, 42212>,
    <42209, 42212, 42216>    <42209, 42216, 42213>,
    <42209, 42213, 42217>    <42218, 42226, 42219>,
    <42218, 42219, 42223>    <42218, 42223, 42220>,
    <42218, 42220, 42224>    <42218, 42224, 42221>,
    <42218, 42221, 42225>    <42218, 42225, 42222>,
    <42218, 42222, 42226>    <42227, 42235, 42228>,
    <42227, 42228, 42232>    <42227, 42232, 42229>,
    <42227, 42229, 42233>    <42227, 42233, 42230>,
    <42227, 42230, 42234>    <42227, 42234, 42231>,
    <42227, 42231, 42235>    <42236, 42244, 42237>,
    <42236, 42237, 42241>    <42236, 42241, 42238>,
    <42236, 42238, 42242>    <42236, 42242, 42239>,
    <42236, 42239, 42243>    <42236, 42243, 42240>,
    <42236, 42240, 42244>    <42245, 42253, 42246>,
    <42245, 42246, 42250>    <42245, 42250, 42247>,
    <42245, 42247, 42251>    <42245, 42251, 42248>,
    <42245, 42248, 42252>    <42245, 42252, 42249>,
    <42245, 42249, 42253>    <42254, 42262, 42255>,
    <42254, 42255, 42259>    <42254, 42259, 42256>,
    <42254, 42256, 42260>    <42254, 42260, 42257>,
    <42254, 42257, 42261>    <42254, 42261, 42258>,
    <42254, 42258, 42262>    <42263, 42271, 42264>,
    <42263, 42264, 42268>    <42263, 42268, 42265>,
    <42263, 42265, 42269>    <42263, 42269, 42266>,
    <42263, 42266, 42270>    <42263, 42270, 42267>,
    <42263, 42267, 42271>    <42272, 42280, 42273>,
    <42272, 42273, 42277>    <42272, 42277, 42274>,
    <42272, 42274, 42278>    <42272, 42278, 42275>,
    <42272, 42275, 42279>    <42272, 42279, 42276>,
    <42272, 42276, 42280>    <42281, 42289, 42282>,
    <42281, 42282, 42286>    <42281, 42286, 42283>,
    <42281, 42283, 42287>    <42281, 42287, 42284>,
    <42281, 42284, 42288>    <42281, 42288, 42285>,
    <42281, 42285, 42289>    <42290, 42298, 42291>,
    <42290, 42291, 42295>    <42290, 42295, 42292>,
    <42290, 42292, 42296>    <42290, 42296, 42293>,
    <42290, 42293, 42297>    <42290, 42297, 42294>,
    <42290, 42294, 42298>    <42299, 42307, 42300>,
    <42299, 42300, 42304>    <42299, 42304, 42301>,
    <42299, 42301, 42305>    <42299, 42305, 42302>,
    <42299, 42302, 42306>    <42299, 42306, 42303>,
    <42299, 42303, 42307>    <42308, 42316, 42309>,
    <42308, 42309, 42313>    <42308, 42313, 42310>,
    <42308, 42310, 42314>    <42308, 42314, 42311>,
    <42308, 42311, 42315>    <42308, 42315, 42312>,
    <42308, 42312, 42316>    <42317, 42325, 42318>,
    <42317, 42318, 42322>    <42317, 42322, 42319>,
    <42317, 42319, 42323>    <42317, 42323, 42320>,
    <42317, 42320, 42324>    <42317, 42324, 42321>,
    <42317, 42321, 42325>    <42326, 42334, 42327>,
    <42326, 42327, 42331>    <42326, 42331, 42328>,
    <42326, 42328, 42332>    <42326, 42332, 42329>,
    <42326, 42329, 42333>    <42326, 42333, 42330>,
    <42326, 42330, 42334>    <42335, 42343, 42336>,
    <42335, 42336, 42340>    <42335, 42340, 42337>,
    <42335, 42337, 42341>    <42335, 42341, 42338>,
    <42335, 42338, 42342>    <42335, 42342, 42339>,
    <42335, 42339, 42343>    <42344, 42352, 42345>,
    <42344, 42345, 42349>    <42344, 42349, 42346>,
    <42344, 42346, 42350>    <42344, 42350, 42347>,
    <42344, 42347, 42351>    <42344, 42351, 42348>,
    <42344, 42348, 42352>    <42353, 42361, 42354>,
    <42353, 42354, 42358>    <42353, 42358, 42355>,
    <42353, 42355, 42359>    <42353, 42359, 42356>,
    <42353, 42356, 42360>    <42353, 42360, 42357>,
    <42353, 42357, 42361>    <42362, 42370, 42363>,
    <42362, 42363, 42367>    <42362, 42367, 42364>,
    <42362, 42364, 42368>    <42362, 42368, 42365>,
    <42362, 42365, 42369>    <42362, 42369, 42366>,
    <42362, 42366, 42370>    <42371, 42379, 42372>,
    <42371, 42372, 42376>    <42371, 42376, 42373>,
    <42371, 42373, 42377>    <42371, 42377, 42374>,
    <42371, 42374, 42378>    <42371, 42378, 42375>,
    <42371, 42375, 42379>    <42380, 42388, 42381>,
    <42380, 42381, 42385>    <42380, 42385, 42382>,
    <42380, 42382, 42386>    <42380, 42386, 42383>,
    <42380, 42383, 42387>    <42380, 42387, 42384>,
    <42380, 42384, 42388>    <42389, 42397, 42390>,
    <42389, 42390, 42394>    <42389, 42394, 42391>,
    <42389, 42391, 42395>    <42389, 42395, 42392>,
    <42389, 42392, 42396>    <42389, 42396, 42393>,
    <42389, 42393, 42397>    <42398, 42406, 42399>,
    <42398, 42399, 42403>    <42398, 42403, 42400>,
    <42398, 42400, 42404>    <42398, 42404, 42401>,
    <42398, 42401, 42405>    <42398, 42405, 42402>,
    <42398, 42402, 42406>    <42407, 42415, 42408>,
    <42407, 42408, 42412>    <42407, 42412, 42409>,
    <42407, 42409, 42413>    <42407, 42413, 42410>,
    <42407, 42410, 42414>    <42407, 42414, 42411>,
    <42407, 42411, 42415>    <42416, 42424, 42417>,
    <42416, 42417, 42421>    <42416, 42421, 42418>,
    <42416, 42418, 42422>    <42416, 42422, 42419>,
    <42416, 42419, 42423>    <42416, 42423, 42420>,
    <42416, 42420, 42424>    <42425, 42433, 42426>,
    <42425, 42426, 42430>    <42425, 42430, 42427>,
    <42425, 42427, 42431>    <42425, 42431, 42428>,
    <42425, 42428, 42432>    <42425, 42432, 42429>,
    <42425, 42429, 42433>    <42434, 42442, 42435>,
    <42434, 42435, 42439>    <42434, 42439, 42436>,
    <42434, 42436, 42440>    <42434, 42440, 42437>,
    <42434, 42437, 42441>    <42434, 42441, 42438>,
    <42434, 42438, 42442>    <42443, 42451, 42444>,
    <42443, 42444, 42448>    <42443, 42448, 42445>,
    <42443, 42445, 42449>    <42443, 42449, 42446>,
    <42443, 42446, 42450>    <42443, 42450, 42447>,
    <42443, 42447, 42451>    <42452, 42460, 42453>,
    <42452, 42453, 42457>    <42452, 42457, 42454>,
    <42452, 42454, 42458>    <42452, 42458, 42455>,
    <42452, 42455, 42459>    <42452, 42459, 42456>,
    <42452, 42456, 42460>    <42461, 42469, 42462>,
    <42461, 42462, 42466>    <42461, 42466, 42463>,
    <42461, 42463, 42467>    <42461, 42467, 42464>,
    <42461, 42464, 42468>    <42461, 42468, 42465>,
    <42461, 42465, 42469>    <42470, 42478, 42471>,
    <42470, 42471, 42475>    <42470, 42475, 42472>,
    <42470, 42472, 42476>    <42470, 42476, 42473>,
    <42470, 42473, 42477>    <42470, 42477, 42474>,
    <42470, 42474, 42478>    <42479, 42487, 42480>,
    <42479, 42480, 42484>    <42479, 42484, 42481>,
    <42479, 42481, 42485>    <42479, 42485, 42482>,
    <42479, 42482, 42486>    <42479, 42486, 42483>,
    <42479, 42483, 42487>    <42488, 42496, 42489>,
    <42488, 42489, 42493>    <42488, 42493, 42490>,
    <42488, 42490, 42494>    <42488, 42494, 42491>,
    <42488, 42491, 42495>    <42488, 42495, 42492>,
    <42488, 42492, 42496>    <42497, 42505, 42498>,
    <42497, 42498, 42502>    <42497, 42502, 42499>,
    <42497, 42499, 42503>    <42497, 42503, 42500>,
    <42497, 42500, 42504>    <42497, 42504, 42501>,
    <42497, 42501, 42505>    <42506, 42514, 42507>,
    <42506, 42507, 42511>    <42506, 42511, 42508>,
    <42506, 42508, 42512>    <42506, 42512, 42509>,
    <42506, 42509, 42513>    <42506, 42513, 42510>,
    <42506, 42510, 42514>    <42515, 42523, 42516>,
    <42515, 42516, 42520>    <42515, 42520, 42517>,
    <42515, 42517, 42521>    <42515, 42521, 42518>,
    <42515, 42518, 42522>    <42515, 42522, 42519>,
    <42515, 42519, 42523>    <42524, 42532, 42525>,
    <42524, 42525, 42529>    <42524, 42529, 42526>,
    <42524, 42526, 42530>    <42524, 42530, 42527>,
    <42524, 42527, 42531>    <42524, 42531, 42528>,
    <42524, 42528, 42532>    <42533, 42541, 42534>,
    <42533, 42534, 42538>    <42533, 42538, 42535>,
    <42533, 42535, 42539>    <42533, 42539, 42536>,
    <42533, 42536, 42540>    <42533, 42540, 42537>,
    <42533, 42537, 42541>    <42542, 42550, 42543>,
    <42542, 42543, 42547>    <42542, 42547, 42544>,
    <42542, 42544, 42548>    <42542, 42548, 42545>,
    <42542, 42545, 42549>    <42542, 42549, 42546>,
    <42542, 42546, 42550>    <42551, 42559, 42552>,
    <42551, 42552, 42556>    <42551, 42556, 42553>,
    <42551, 42553, 42557>    <42551, 42557, 42554>,
    <42551, 42554, 42558>    <42551, 42558, 42555>,
    <42551, 42555, 42559>    <42560, 42568, 42561>,
    <42560, 42561, 42565>    <42560, 42565, 42562>,
    <42560, 42562, 42566>    <42560, 42566, 42563>,
    <42560, 42563, 42567>    <42560, 42567, 42564>,
    <42560, 42564, 42568>    <42569, 42577, 42570>,
    <42569, 42570, 42574>    <42569, 42574, 42571>,
    <42569, 42571, 42575>    <42569, 42575, 42572>,
    <42569, 42572, 42576>    <42569, 42576, 42573>,
    <42569, 42573, 42577>    <42578, 42586, 42579>,
    <42578, 42579, 42583>    <42578, 42583, 42580>,
    <42578, 42580, 42584>    <42578, 42584, 42581>,
    <42578, 42581, 42585>    <42578, 42585, 42582>,
    <42578, 42582, 42586>    <42587, 42595, 42588>,
    <42587, 42588, 42592>    <42587, 42592, 42589>,
    <42587, 42589, 42593>    <42587, 42593, 42590>,
    <42587, 42590, 42594>    <42587, 42594, 42591>,
    <42587, 42591, 42595>    <42596, 42604, 42597>,
    <42596, 42597, 42601>    <42596, 42601, 42598>,
    <42596, 42598, 42602>    <42596, 42602, 42599>,
    <42596, 42599, 42603>    <42596, 42603, 42600>,
    <42596, 42600, 42604>    <42605, 42613, 42606>,
    <42605, 42606, 42610>    <42605, 42610, 42607>,
    <42605, 42607, 42611>    <42605, 42611, 42608>,
    <42605, 42608, 42612>    <42605, 42612, 42609>,
    <42605, 42609, 42613>    <42614, 42622, 42615>,
    <42614, 42615, 42619>    <42614, 42619, 42616>,
    <42614, 42616, 42620>    <42614, 42620, 42617>,
    <42614, 42617, 42621>    <42614, 42621, 42618>,
    <42614, 42618, 42622>    <42623, 42631, 42624>,
    <42623, 42624, 42628>    <42623, 42628, 42625>,
    <42623, 42625, 42629>    <42623, 42629, 42626>,
    <42623, 42626, 42630>    <42623, 42630, 42627>,
    <42623, 42627, 42631>    <42632, 42640, 42633>,
    <42632, 42633, 42637>    <42632, 42637, 42634>,
    <42632, 42634, 42638>    <42632, 42638, 42635>,
    <42632, 42635, 42639>    <42632, 42639, 42636>,
    <42632, 42636, 42640>    <42641, 42649, 42642>,
    <42641, 42642, 42646>    <42641, 42646, 42643>,
    <42641, 42643, 42647>    <42641, 42647, 42644>,
    <42641, 42644, 42648>    <42641, 42648, 42645>,
    <42641, 42645, 42649>    <42650, 42658, 42651>,
    <42650, 42651, 42655>    <42650, 42655, 42652>,
    <42650, 42652, 42656>    <42650, 42656, 42653>,
    <42650, 42653, 42657>    <42650, 42657, 42654>,
    <42650, 42654, 42658>    <42659, 42667, 42660>,
    <42659, 42660, 42664>    <42659, 42664, 42661>,
    <42659, 42661, 42665>    <42659, 42665, 42662>,
    <42659, 42662, 42666>    <42659, 42666, 42663>,
    <42659, 42663, 42667>    <42668, 42676, 42669>,
    <42668, 42669, 42673>    <42668, 42673, 42670>,
    <42668, 42670, 42674>    <42668, 42674, 42671>,
    <42668, 42671, 42675>    <42668, 42675, 42672>,
    <42668, 42672, 42676>    <42677, 42685, 42678>,
    <42677, 42678, 42682>    <42677, 42682, 42679>,
    <42677, 42679, 42683>    <42677, 42683, 42680>,
    <42677, 42680, 42684>    <42677, 42684, 42681>,
    <42677, 42681, 42685>    <42686, 42694, 42687>,
    <42686, 42687, 42691>    <42686, 42691, 42688>,
    <42686, 42688, 42692>    <42686, 42692, 42689>,
    <42686, 42689, 42693>    <42686, 42693, 42690>,
    <42686, 42690, 42694>    <42695, 42703, 42696>,
    <42695, 42696, 42700>    <42695, 42700, 42697>,
    <42695, 42697, 42701>    <42695, 42701, 42698>,
    <42695, 42698, 42702>    <42695, 42702, 42699>,
    <42695, 42699, 42703>    <42704, 42712, 42705>,
    <42704, 42705, 42709>    <42704, 42709, 42706>,
    <42704, 42706, 42710>    <42704, 42710, 42707>,
    <42704, 42707, 42711>    <42704, 42711, 42708>,
    <42704, 42708, 42712>    <42713, 42721, 42714>,
    <42713, 42714, 42718>    <42713, 42718, 42715>,
    <42713, 42715, 42719>    <42713, 42719, 42716>,
    <42713, 42716, 42720>    <42713, 42720, 42717>,
    <42713, 42717, 42721>    <42722, 42730, 42723>,
    <42722, 42723, 42727>    <42722, 42727, 42724>,
    <42722, 42724, 42728>    <42722, 42728, 42725>,
    <42722, 42725, 42729>    <42722, 42729, 42726>,
    <42722, 42726, 42730>    <42731, 42739, 42732>,
    <42731, 42732, 42736>    <42731, 42736, 42733>,
    <42731, 42733, 42737>    <42731, 42737, 42734>,
    <42731, 42734, 42738>    <42731, 42738, 42735>,
    <42731, 42735, 42739>    <42740, 42748, 42741>,
    <42740, 42741, 42745>    <42740, 42745, 42742>,
    <42740, 42742, 42746>    <42740, 42746, 42743>,
    <42740, 42743, 42747>    <42740, 42747, 42744>,
    <42740, 42744, 42748>    <42749, 42757, 42750>,
    <42749, 42750, 42754>    <42749, 42754, 42751>,
    <42749, 42751, 42755>    <42749, 42755, 42752>,
    <42749, 42752, 42756>    <42749, 42756, 42753>,
    <42749, 42753, 42757>    <42758, 42766, 42759>,
    <42758, 42759, 42763>    <42758, 42763, 42760>,
    <42758, 42760, 42764>    <42758, 42764, 42761>,
    <42758, 42761, 42765>    <42758, 42765, 42762>,
    <42758, 42762, 42766>    <42767, 42775, 42768>,
    <42767, 42768, 42772>    <42767, 42772, 42769>,
    <42767, 42769, 42773>    <42767, 42773, 42770>,
    <42767, 42770, 42774>    <42767, 42774, 42771>,
    <42767, 42771, 42775>    <42776, 42784, 42777>,
    <42776, 42777, 42781>    <42776, 42781, 42778>,
    <42776, 42778, 42782>    <42776, 42782, 42779>,
    <42776, 42779, 42783>    <42776, 42783, 42780>,
    <42776, 42780, 42784>    <42785, 42793, 42786>,
    <42785, 42786, 42790>    <42785, 42790, 42787>,
    <42785, 42787, 42791>    <42785, 42791, 42788>,
    <42785, 42788, 42792>    <42785, 42792, 42789>,
    <42785, 42789, 42793>    <42794, 42802, 42795>,
    <42794, 42795, 42799>    <42794, 42799, 42796>,
    <42794, 42796, 42800>    <42794, 42800, 42797>,
    <42794, 42797, 42801>    <42794, 42801, 42798>,
    <42794, 42798, 42802>    <42803, 42811, 42804>,
    <42803, 42804, 42808>    <42803, 42808, 42805>,
    <42803, 42805, 42809>    <42803, 42809, 42806>,
    <42803, 42806, 42810>    <42803, 42810, 42807>,
    <42803, 42807, 42811>    <42812, 42820, 42813>,
    <42812, 42813, 42817>    <42812, 42817, 42814>,
    <42812, 42814, 42818>    <42812, 42818, 42815>,
    <42812, 42815, 42819>    <42812, 42819, 42816>,
    <42812, 42816, 42820>    <42821, 42829, 42822>,
    <42821, 42822, 42826>    <42821, 42826, 42823>,
    <42821, 42823, 42827>    <42821, 42827, 42824>,
    <42821, 42824, 42828>    <42821, 42828, 42825>,
    <42821, 42825, 42829>    <42830, 42838, 42831>,
    <42830, 42831, 42835>    <42830, 42835, 42832>,
    <42830, 42832, 42836>    <42830, 42836, 42833>,
    <42830, 42833, 42837>    <42830, 42837, 42834>,
    <42830, 42834, 42838>    <42839, 42847, 42840>,
    <42839, 42840, 42844>    <42839, 42844, 42841>,
    <42839, 42841, 42845>    <42839, 42845, 42842>,
    <42839, 42842, 42846>    <42839, 42846, 42843>,
    <42839, 42843, 42847>    <42848, 42856, 42849>,
    <42848, 42849, 42853>    <42848, 42853, 42850>,
    <42848, 42850, 42854>    <42848, 42854, 42851>,
    <42848, 42851, 42855>    <42848, 42855, 42852>,
    <42848, 42852, 42856>    <42857, 42865, 42858>,
    <42857, 42858, 42862>    <42857, 42862, 42859>,
    <42857, 42859, 42863>    <42857, 42863, 42860>,
    <42857, 42860, 42864>    <42857, 42864, 42861>,
    <42857, 42861, 42865>    <42866, 42874, 42867>,
    <42866, 42867, 42871>    <42866, 42871, 42868>,
    <42866, 42868, 42872>    <42866, 42872, 42869>,
    <42866, 42869, 42873>    <42866, 42873, 42870>,
    <42866, 42870, 42874>    <42875, 42883, 42876>,
    <42875, 42876, 42880>    <42875, 42880, 42877>,
    <42875, 42877, 42881>    <42875, 42881, 42878>,
    <42875, 42878, 42882>    <42875, 42882, 42879>,
    <42875, 42879, 42883>    <42884, 42892, 42885>,
    <42884, 42885, 42889>    <42884, 42889, 42886>,
    <42884, 42886, 42890>    <42884, 42890, 42887>,
    <42884, 42887, 42891>    <42884, 42891, 42888>,
    <42884, 42888, 42892>    <42893, 42901, 42894>,
    <42893, 42894, 42898>    <42893, 42898, 42895>,
    <42893, 42895, 42899>    <42893, 42899, 42896>,
    <42893, 42896, 42900>    <42893, 42900, 42897>,
    <42893, 42897, 42901>    <42902, 42910, 42903>,
    <42902, 42903, 42907>    <42902, 42907, 42904>,
    <42902, 42904, 42908>    <42902, 42908, 42905>,
    <42902, 42905, 42909>    <42902, 42909, 42906>,
    <42902, 42906, 42910>    <42911, 42919, 42912>,
    <42911, 42912, 42916>    <42911, 42916, 42913>,
    <42911, 42913, 42917>    <42911, 42917, 42914>,
    <42911, 42914, 42918>    <42911, 42918, 42915>,
    <42911, 42915, 42919>    <42920, 42928, 42921>,
    <42920, 42921, 42925>    <42920, 42925, 42922>,
    <42920, 42922, 42926>    <42920, 42926, 42923>,
    <42920, 42923, 42927>    <42920, 42927, 42924>,
    <42920, 42924, 42928>    <42929, 42937, 42930>,
    <42929, 42930, 42934>    <42929, 42934, 42931>,
    <42929, 42931, 42935>    <42929, 42935, 42932>,
    <42929, 42932, 42936>    <42929, 42936, 42933>,
    <42929, 42933, 42937>    <42938, 42946, 42939>,
    <42938, 42939, 42943>    <42938, 42943, 42940>,
    <42938, 42940, 42944>    <42938, 42944, 42941>,
    <42938, 42941, 42945>    <42938, 42945, 42942>,
    <42938, 42942, 42946>    <42947, 42955, 42948>,
    <42947, 42948, 42952>    <42947, 42952, 42949>,
    <42947, 42949, 42953>    <42947, 42953, 42950>,
    <42947, 42950, 42954>    <42947, 42954, 42951>,
    <42947, 42951, 42955>    <42956, 42964, 42957>,
    <42956, 42957, 42961>    <42956, 42961, 42958>,
    <42956, 42958, 42962>    <42956, 42962, 42959>,
    <42956, 42959, 42963>    <42956, 42963, 42960>,
    <42956, 42960, 42964>    <42965, 42973, 42966>,
    <42965, 42966, 42970>    <42965, 42970, 42967>,
    <42965, 42967, 42971>    <42965, 42971, 42968>,
    <42965, 42968, 42972>    <42965, 42972, 42969>,
    <42965, 42969, 42973>    <42974, 42982, 42975>,
    <42974, 42975, 42979>    <42974, 42979, 42976>,
    <42974, 42976, 42980>    <42974, 42980, 42977>,
    <42974, 42977, 42981>    <42974, 42981, 42978>,
    <42974, 42978, 42982>    <42983, 42991, 42984>,
    <42983, 42984, 42988>    <42983, 42988, 42985>,
    <42983, 42985, 42989>    <42983, 42989, 42986>,
    <42983, 42986, 42990>    <42983, 42990, 42987>,
    <42983, 42987, 42991>    <42992, 43000, 42993>,
    <42992, 42993, 42997>    <42992, 42997, 42994>,
    <42992, 42994, 42998>    <42992, 42998, 42995>,
    <42992, 42995, 42999>    <42992, 42999, 42996>,
    <42992, 42996, 43000>    <43001, 43009, 43002>,
    <43001, 43002, 43006>    <43001, 43006, 43003>,
    <43001, 43003, 43007>    <43001, 43007, 43004>,
    <43001, 43004, 43008>    <43001, 43008, 43005>,
    <43001, 43005, 43009>    <43010, 43018, 43011>,
    <43010, 43011, 43015>    <43010, 43015, 43012>,
    <43010, 43012, 43016>    <43010, 43016, 43013>,
    <43010, 43013, 43017>    <43010, 43017, 43014>,
    <43010, 43014, 43018>    <43019, 43027, 43020>,
    <43019, 43020, 43024>    <43019, 43024, 43021>,
    <43019, 43021, 43025>    <43019, 43025, 43022>,
    <43019, 43022, 43026>    <43019, 43026, 43023>,
    <43019, 43023, 43027>    <43028, 43036, 43029>,
    <43028, 43029, 43033>    <43028, 43033, 43030>,
    <43028, 43030, 43034>    <43028, 43034, 43031>,
    <43028, 43031, 43035>    <43028, 43035, 43032>,
    <43028, 43032, 43036>    <43037, 43045, 43038>,
    <43037, 43038, 43042>    <43037, 43042, 43039>,
    <43037, 43039, 43043>    <43037, 43043, 43040>,
    <43037, 43040, 43044>    <43037, 43044, 43041>,
    <43037, 43041, 43045>    <43046, 43054, 43047>,
    <43046, 43047, 43051>    <43046, 43051, 43048>,
    <43046, 43048, 43052>    <43046, 43052, 43049>,
    <43046, 43049, 43053>    <43046, 43053, 43050>,
    <43046, 43050, 43054>    <43055, 43063, 43056>,
    <43055, 43056, 43060>    <43055, 43060, 43057>,
    <43055, 43057, 43061>    <43055, 43061, 43058>,
    <43055, 43058, 43062>    <43055, 43062, 43059>,
    <43055, 43059, 43063>    <43064, 43072, 43065>,
    <43064, 43065, 43069>    <43064, 43069, 43066>,
    <43064, 43066, 43070>    <43064, 43070, 43067>,
    <43064, 43067, 43071>    <43064, 43071, 43068>,
    <43064, 43068, 43072>    <43073, 43081, 43074>,
    <43073, 43074, 43078>    <43073, 43078, 43075>,
    <43073, 43075, 43079>    <43073, 43079, 43076>,
    <43073, 43076, 43080>    <43073, 43080, 43077>,
    <43073, 43077, 43081>    <43082, 43090, 43083>,
    <43082, 43083, 43087>    <43082, 43087, 43084>,
    <43082, 43084, 43088>    <43082, 43088, 43085>,
    <43082, 43085, 43089>    <43082, 43089, 43086>,
    <43082, 43086, 43090>    <43091, 43099, 43092>,
    <43091, 43092, 43096>    <43091, 43096, 43093>,
    <43091, 43093, 43097>    <43091, 43097, 43094>,
    <43091, 43094, 43098>    <43091, 43098, 43095>,
    <43091, 43095, 43099>    <43100, 43108, 43101>,
    <43100, 43101, 43105>    <43100, 43105, 43102>,
    <43100, 43102, 43106>    <43100, 43106, 43103>,
    <43100, 43103, 43107>    <43100, 43107, 43104>,
    <43100, 43104, 43108>    <43109, 43117, 43110>,
    <43109, 43110, 43114>    <43109, 43114, 43111>,
    <43109, 43111, 43115>    <43109, 43115, 43112>,
    <43109, 43112, 43116>    <43109, 43116, 43113>,
    <43109, 43113, 43117>    <43118, 43126, 43119>,
    <43118, 43119, 43123>    <43118, 43123, 43120>,
    <43118, 43120, 43124>    <43118, 43124, 43121>,
    <43118, 43121, 43125>    <43118, 43125, 43122>,
    <43118, 43122, 43126>    <43127, 43135, 43128>,
    <43127, 43128, 43132>    <43127, 43132, 43129>,
    <43127, 43129, 43133>    <43127, 43133, 43130>,
    <43127, 43130, 43134>    <43127, 43134, 43131>,
    <43127, 43131, 43135>    <43136, 43144, 43137>,
    <43136, 43137, 43141>    <43136, 43141, 43138>,
    <43136, 43138, 43142>    <43136, 43142, 43139>,
    <43136, 43139, 43143>    <43136, 43143, 43140>,
    <43136, 43140, 43144>    <43145, 43153, 43146>,
    <43145, 43146, 43150>    <43145, 43150, 43147>,
    <43145, 43147, 43151>    <43145, 43151, 43148>,
    <43145, 43148, 43152>    <43145, 43152, 43149>,
    <43145, 43149, 43153>    <43154, 43162, 43155>,
    <43154, 43155, 43159>    <43154, 43159, 43156>,
    <43154, 43156, 43160>    <43154, 43160, 43157>,
    <43154, 43157, 43161>    <43154, 43161, 43158>,
    <43154, 43158, 43162>    <43163, 43171, 43164>,
    <43163, 43164, 43168>    <43163, 43168, 43165>,
    <43163, 43165, 43169>    <43163, 43169, 43166>,
    <43163, 43166, 43170>    <43163, 43170, 43167>,
    <43163, 43167, 43171>    <43172, 43180, 43173>,
    <43172, 43173, 43177>    <43172, 43177, 43174>,
    <43172, 43174, 43178>    <43172, 43178, 43175>,
    <43172, 43175, 43179>    <43172, 43179, 43176>,
    <43172, 43176, 43180>    <43181, 43189, 43182>,
    <43181, 43182, 43186>    <43181, 43186, 43183>,
    <43181, 43183, 43187>    <43181, 43187, 43184>,
    <43181, 43184, 43188>    <43181, 43188, 43185>,
    <43181, 43185, 43189>    <43190, 43198, 43191>,
    <43190, 43191, 43195>    <43190, 43195, 43192>,
    <43190, 43192, 43196>    <43190, 43196, 43193>,
    <43190, 43193, 43197>    <43190, 43197, 43194>,
    <43190, 43194, 43198>    <43199, 43207, 43200>,
    <43199, 43200, 43204>    <43199, 43204, 43201>,
    <43199, 43201, 43205>    <43199, 43205, 43202>,
    <43199, 43202, 43206>    <43199, 43206, 43203>,
    <43199, 43203, 43207>    <43208, 43216, 43209>,
    <43208, 43209, 43213>    <43208, 43213, 43210>,
    <43208, 43210, 43214>    <43208, 43214, 43211>,
    <43208, 43211, 43215>    <43208, 43215, 43212>,
    <43208, 43212, 43216>    <43217, 43225, 43218>,
    <43217, 43218, 43222>    <43217, 43222, 43219>,
    <43217, 43219, 43223>    <43217, 43223, 43220>,
    <43217, 43220, 43224>    <43217, 43224, 43221>,
    <43217, 43221, 43225>    <43226, 43234, 43227>,
    <43226, 43227, 43231>    <43226, 43231, 43228>,
    <43226, 43228, 43232>    <43226, 43232, 43229>,
    <43226, 43229, 43233>    <43226, 43233, 43230>,
    <43226, 43230, 43234>    <43235, 43243, 43236>,
    <43235, 43236, 43240>    <43235, 43240, 43237>,
    <43235, 43237, 43241>    <43235, 43241, 43238>,
    <43235, 43238, 43242>    <43235, 43242, 43239>,
    <43235, 43239, 43243>    <43244, 43252, 43245>,
    <43244, 43245, 43249>    <43244, 43249, 43246>,
    <43244, 43246, 43250>    <43244, 43250, 43247>,
    <43244, 43247, 43251>    <43244, 43251, 43248>,
    <43244, 43248, 43252>    <43253, 43261, 43254>,
    <43253, 43254, 43258>    <43253, 43258, 43255>,
    <43253, 43255, 43259>    <43253, 43259, 43256>,
    <43253, 43256, 43260>    <43253, 43260, 43257>,
    <43253, 43257, 43261>    <43262, 43270, 43263>,
    <43262, 43263, 43267>    <43262, 43267, 43264>,
    <43262, 43264, 43268>    <43262, 43268, 43265>,
    <43262, 43265, 43269>    <43262, 43269, 43266>,
    <43262, 43266, 43270>    <43271, 43279, 43272>,
    <43271, 43272, 43276>    <43271, 43276, 43273>,
    <43271, 43273, 43277>    <43271, 43277, 43274>,
    <43271, 43274, 43278>    <43271, 43278, 43275>,
    <43271, 43275, 43279>    <43280, 43288, 43281>,
    <43280, 43281, 43285>    <43280, 43285, 43282>,
    <43280, 43282, 43286>    <43280, 43286, 43283>,
    <43280, 43283, 43287>    <43280, 43287, 43284>,
    <43280, 43284, 43288>    <43289, 43297, 43290>,
    <43289, 43290, 43294>    <43289, 43294, 43291>,
    <43289, 43291, 43295>    <43289, 43295, 43292>,
    <43289, 43292, 43296>    <43289, 43296, 43293>,
    <43289, 43293, 43297>    <43298, 43306, 43299>,
    <43298, 43299, 43303>    <43298, 43303, 43300>,
    <43298, 43300, 43304>    <43298, 43304, 43301>,
    <43298, 43301, 43305>    <43298, 43305, 43302>,
    <43298, 43302, 43306>    <43307, 43315, 43308>,
    <43307, 43308, 43312>    <43307, 43312, 43309>,
    <43307, 43309, 43313>    <43307, 43313, 43310>,
    <43307, 43310, 43314>    <43307, 43314, 43311>,
    <43307, 43311, 43315>    <43316, 43324, 43317>,
    <43316, 43317, 43321>    <43316, 43321, 43318>,
    <43316, 43318, 43322>    <43316, 43322, 43319>,
    <43316, 43319, 43323>    <43316, 43323, 43320>,
    <43316, 43320, 43324>    <43325, 43333, 43326>,
    <43325, 43326, 43330>    <43325, 43330, 43327>,
    <43325, 43327, 43331>    <43325, 43331, 43328>,
    <43325, 43328, 43332>    <43325, 43332, 43329>,
    <43325, 43329, 43333>    <43334, 43342, 43335>,
    <43334, 43335, 43339>    <43334, 43339, 43336>,
    <43334, 43336, 43340>    <43334, 43340, 43337>,
    <43334, 43337, 43341>    <43334, 43341, 43338>,
    <43334, 43338, 43342>    <43343, 43351, 43344>,
    <43343, 43344, 43348>    <43343, 43348, 43345>,
    <43343, 43345, 43349>    <43343, 43349, 43346>,
    <43343, 43346, 43350>    <43343, 43350, 43347>,
    <43343, 43347, 43351>    <43352, 43360, 43353>,
    <43352, 43353, 43357>    <43352, 43357, 43354>,
    <43352, 43354, 43358>    <43352, 43358, 43355>,
    <43352, 43355, 43359>    <43352, 43359, 43356>,
    <43352, 43356, 43360>    <43361, 43369, 43362>,
    <43361, 43362, 43366>    <43361, 43366, 43363>,
    <43361, 43363, 43367>    <43361, 43367, 43364>,
    <43361, 43364, 43368>    <43361, 43368, 43365>,
    <43361, 43365, 43369>    <43370, 43378, 43371>,
    <43370, 43371, 43375>    <43370, 43375, 43372>,
    <43370, 43372, 43376>    <43370, 43376, 43373>,
    <43370, 43373, 43377>    <43370, 43377, 43374>,
    <43370, 43374, 43378>    <43379, 43387, 43380>,
    <43379, 43380, 43384>    <43379, 43384, 43381>,
    <43379, 43381, 43385>    <43379, 43385, 43382>,
    <43379, 43382, 43386>    <43379, 43386, 43383>,
    <43379, 43383, 43387>    <43388, 43396, 43389>,
    <43388, 43389, 43393>    <43388, 43393, 43390>,
    <43388, 43390, 43394>    <43388, 43394, 43391>,
    <43388, 43391, 43395>    <43388, 43395, 43392>,
    <43388, 43392, 43396>    <43397, 43405, 43398>,
    <43397, 43398, 43402>    <43397, 43402, 43399>,
    <43397, 43399, 43403>    <43397, 43403, 43400>,
    <43397, 43400, 43404>    <43397, 43404, 43401>,
    <43397, 43401, 43405>    <43406, 43414, 43407>,
    <43406, 43407, 43411>    <43406, 43411, 43408>,
    <43406, 43408, 43412>    <43406, 43412, 43409>,
    <43406, 43409, 43413>    <43406, 43413, 43410>,
    <43406, 43410, 43414>    <43415, 43423, 43416>,
    <43415, 43416, 43420>    <43415, 43420, 43417>,
    <43415, 43417, 43421>    <43415, 43421, 43418>,
    <43415, 43418, 43422>    <43415, 43422, 43419>,
    <43415, 43419, 43423>    <43424, 43432, 43425>,
    <43424, 43425, 43429>    <43424, 43429, 43426>,
    <43424, 43426, 43430>    <43424, 43430, 43427>,
    <43424, 43427, 43431>    <43424, 43431, 43428>,
    <43424, 43428, 43432>    <43433, 43441, 43434>,
    <43433, 43434, 43438>    <43433, 43438, 43435>,
    <43433, 43435, 43439>    <43433, 43439, 43436>,
    <43433, 43436, 43440>    <43433, 43440, 43437>,
    <43433, 43437, 43441>    <43442, 43450, 43443>,
    <43442, 43443, 43447>    <43442, 43447, 43444>,
    <43442, 43444, 43448>    <43442, 43448, 43445>,
    <43442, 43445, 43449>    <43442, 43449, 43446>,
    <43442, 43446, 43450>    <43451, 43459, 43452>,
    <43451, 43452, 43456>    <43451, 43456, 43453>,
    <43451, 43453, 43457>    <43451, 43457, 43454>,
    <43451, 43454, 43458>    <43451, 43458, 43455>,
    <43451, 43455, 43459>    <43460, 43468, 43461>,
    <43460, 43461, 43465>    <43460, 43465, 43462>,
    <43460, 43462, 43466>    <43460, 43466, 43463>,
    <43460, 43463, 43467>    <43460, 43467, 43464>,
    <43460, 43464, 43468>    <43469, 43477, 43470>,
    <43469, 43470, 43474>    <43469, 43474, 43471>,
    <43469, 43471, 43475>    <43469, 43475, 43472>,
    <43469, 43472, 43476>    <43469, 43476, 43473>,
    <43469, 43473, 43477>    <43478, 43486, 43479>,
    <43478, 43479, 43483>    <43478, 43483, 43480>,
    <43478, 43480, 43484>    <43478, 43484, 43481>,
    <43478, 43481, 43485>    <43478, 43485, 43482>,
    <43478, 43482, 43486>    <43487, 43495, 43488>,
    <43487, 43488, 43492>    <43487, 43492, 43489>,
    <43487, 43489, 43493>    <43487, 43493, 43490>,
    <43487, 43490, 43494>    <43487, 43494, 43491>,
    <43487, 43491, 43495>    <43496, 43504, 43497>,
    <43496, 43497, 43501>    <43496, 43501, 43498>,
    <43496, 43498, 43502>    <43496, 43502, 43499>,
    <43496, 43499, 43503>    <43496, 43503, 43500>,
    <43496, 43500, 43504>    <43505, 43513, 43506>,
    <43505, 43506, 43510>    <43505, 43510, 43507>,
    <43505, 43507, 43511>    <43505, 43511, 43508>,
    <43505, 43508, 43512>    <43505, 43512, 43509>,
    <43505, 43509, 43513>    <43514, 43522, 43515>,
    <43514, 43515, 43519>    <43514, 43519, 43516>,
    <43514, 43516, 43520>    <43514, 43520, 43517>,
    <43514, 43517, 43521>    <43514, 43521, 43518>,
    <43514, 43518, 43522>    <43523, 43531, 43524>,
    <43523, 43524, 43528>    <43523, 43528, 43525>,
    <43523, 43525, 43529>    <43523, 43529, 43526>,
    <43523, 43526, 43530>    <43523, 43530, 43527>,
    <43523, 43527, 43531>    <43532, 43540, 43533>,
    <43532, 43533, 43537>    <43532, 43537, 43534>,
    <43532, 43534, 43538>    <43532, 43538, 43535>,
    <43532, 43535, 43539>    <43532, 43539, 43536>,
    <43532, 43536, 43540>    <43541, 43549, 43542>,
    <43541, 43542, 43546>    <43541, 43546, 43543>,
    <43541, 43543, 43547>    <43541, 43547, 43544>,
    <43541, 43544, 43548>    <43541, 43548, 43545>,
    <43541, 43545, 43549>    <43550, 43558, 43551>,
    <43550, 43551, 43555>    <43550, 43555, 43552>,
    <43550, 43552, 43556>    <43550, 43556, 43553>,
    <43550, 43553, 43557>    <43550, 43557, 43554>,
    <43550, 43554, 43558>    <43559, 43567, 43560>,
    <43559, 43560, 43564>    <43559, 43564, 43561>,
    <43559, 43561, 43565>    <43559, 43565, 43562>,
    <43559, 43562, 43566>    <43559, 43566, 43563>,
    <43559, 43563, 43567>    <43568, 43576, 43569>,
    <43568, 43569, 43573>    <43568, 43573, 43570>,
    <43568, 43570, 43574>    <43568, 43574, 43571>,
    <43568, 43571, 43575>    <43568, 43575, 43572>,
    <43568, 43572, 43576>    <43577, 43585, 43578>,
    <43577, 43578, 43582>    <43577, 43582, 43579>,
    <43577, 43579, 43583>    <43577, 43583, 43580>,
    <43577, 43580, 43584>    <43577, 43584, 43581>,
    <43577, 43581, 43585>    <43586, 43594, 43587>,
    <43586, 43587, 43591>    <43586, 43591, 43588>,
    <43586, 43588, 43592>    <43586, 43592, 43589>,
    <43586, 43589, 43593>    <43586, 43593, 43590>,
    <43586, 43590, 43594>    <43595, 43603, 43596>,
    <43595, 43596, 43600>    <43595, 43600, 43597>,
    <43595, 43597, 43601>    <43595, 43601, 43598>,
    <43595, 43598, 43602>    <43595, 43602, 43599>,
    <43595, 43599, 43603>    <43604, 43612, 43605>,
    <43604, 43605, 43609>    <43604, 43609, 43606>,
    <43604, 43606, 43610>    <43604, 43610, 43607>,
    <43604, 43607, 43611>    <43604, 43611, 43608>,
    <43604, 43608, 43612>    <43613, 43621, 43614>,
    <43613, 43614, 43618>    <43613, 43618, 43615>,
    <43613, 43615, 43619>    <43613, 43619, 43616>,
    <43613, 43616, 43620>    <43613, 43620, 43617>,
    <43613, 43617, 43621>    <43622, 43630, 43623>,
    <43622, 43623, 43627>    <43622, 43627, 43624>,
    <43622, 43624, 43628>    <43622, 43628, 43625>,
    <43622, 43625, 43629>    <43622, 43629, 43626>,
    <43622, 43626, 43630>    <43631, 43639, 43632>,
    <43631, 43632, 43636>    <43631, 43636, 43633>,
    <43631, 43633, 43637>    <43631, 43637, 43634>,
    <43631, 43634, 43638>    <43631, 43638, 43635>,
    <43631, 43635, 43639>    <43640, 43648, 43641>,
    <43640, 43641, 43645>    <43640, 43645, 43642>,
    <43640, 43642, 43646>    <43640, 43646, 43643>,
    <43640, 43643, 43647>    <43640, 43647, 43644>,
    <43640, 43644, 43648>    <43649, 43657, 43650>,
    <43649, 43650, 43654>    <43649, 43654, 43651>,
    <43649, 43651, 43655>    <43649, 43655, 43652>,
    <43649, 43652, 43656>    <43649, 43656, 43653>,
    <43649, 43653, 43657>    <43658, 43666, 43659>,
    <43658, 43659, 43663>    <43658, 43663, 43660>,
    <43658, 43660, 43664>    <43658, 43664, 43661>,
    <43658, 43661, 43665>    <43658, 43665, 43662>,
    <43658, 43662, 43666>    <43667, 43675, 43668>,
    <43667, 43668, 43672>    <43667, 43672, 43669>,
    <43667, 43669, 43673>    <43667, 43673, 43670>,
    <43667, 43670, 43674>    <43667, 43674, 43671>,
    <43667, 43671, 43675>    <43676, 43684, 43677>,
    <43676, 43677, 43681>    <43676, 43681, 43678>,
    <43676, 43678, 43682>    <43676, 43682, 43679>,
    <43676, 43679, 43683>    <43676, 43683, 43680>,
    <43676, 43680, 43684>    <43685, 43693, 43686>,
    <43685, 43686, 43690>    <43685, 43690, 43687>,
    <43685, 43687, 43691>    <43685, 43691, 43688>,
    <43685, 43688, 43692>    <43685, 43692, 43689>,
    <43685, 43689, 43693>    <43694, 43702, 43695>,
    <43694, 43695, 43699>    <43694, 43699, 43696>,
    <43694, 43696, 43700>    <43694, 43700, 43697>,
    <43694, 43697, 43701>    <43694, 43701, 43698>,
    <43694, 43698, 43702>    <43703, 43711, 43704>,
    <43703, 43704, 43708>    <43703, 43708, 43705>,
    <43703, 43705, 43709>    <43703, 43709, 43706>,
    <43703, 43706, 43710>    <43703, 43710, 43707>,
    <43703, 43707, 43711>    <43712, 43720, 43713>,
    <43712, 43713, 43717>    <43712, 43717, 43714>,
    <43712, 43714, 43718>    <43712, 43718, 43715>,
    <43712, 43715, 43719>    <43712, 43719, 43716>,
    <43712, 43716, 43720>    <43721, 43729, 43722>,
    <43721, 43722, 43726>    <43721, 43726, 43723>,
    <43721, 43723, 43727>    <43721, 43727, 43724>,
    <43721, 43724, 43728>    <43721, 43728, 43725>,
    <43721, 43725, 43729>    <43730, 43738, 43731>,
    <43730, 43731, 43735>    <43730, 43735, 43732>,
    <43730, 43732, 43736>    <43730, 43736, 43733>,
    <43730, 43733, 43737>    <43730, 43737, 43734>,
    <43730, 43734, 43738>    <43739, 43747, 43740>,
    <43739, 43740, 43744>    <43739, 43744, 43741>,
    <43739, 43741, 43745>    <43739, 43745, 43742>,
    <43739, 43742, 43746>    <43739, 43746, 43743>,
    <43739, 43743, 43747>    <43748, 43756, 43749>,
    <43748, 43749, 43753>    <43748, 43753, 43750>,
    <43748, 43750, 43754>    <43748, 43754, 43751>,
    <43748, 43751, 43755>    <43748, 43755, 43752>,
    <43748, 43752, 43756>    <43757, 43765, 43758>,
    <43757, 43758, 43762>    <43757, 43762, 43759>,
    <43757, 43759, 43763>    <43757, 43763, 43760>,
    <43757, 43760, 43764>    <43757, 43764, 43761>,
    <43757, 43761, 43765>    <43766, 43774, 43767>,
    <43766, 43767, 43771>    <43766, 43771, 43768>,
    <43766, 43768, 43772>    <43766, 43772, 43769>,
    <43766, 43769, 43773>    <43766, 43773, 43770>,
    <43766, 43770, 43774>    <43775, 43783, 43776>,
    <43775, 43776, 43780>    <43775, 43780, 43777>,
    <43775, 43777, 43781>    <43775, 43781, 43778>,
    <43775, 43778, 43782>    <43775, 43782, 43779>,
    <43775, 43779, 43783>    <43784, 43792, 43785>,
    <43784, 43785, 43789>    <43784, 43789, 43786>,
    <43784, 43786, 43790>    <43784, 43790, 43787>,
    <43784, 43787, 43791>    <43784, 43791, 43788>,
    <43784, 43788, 43792>    <43793, 43801, 43794>,
    <43793, 43794, 43798>    <43793, 43798, 43795>,
    <43793, 43795, 43799>    <43793, 43799, 43796>,
    <43793, 43796, 43800>    <43793, 43800, 43797>,
    <43793, 43797, 43801>    <43802, 43810, 43803>,
    <43802, 43803, 43807>    <43802, 43807, 43804>,
    <43802, 43804, 43808>    <43802, 43808, 43805>,
    <43802, 43805, 43809>    <43802, 43809, 43806>,
    <43802, 43806, 43810>    <43811, 43819, 43812>,
    <43811, 43812, 43816>    <43811, 43816, 43813>,
    <43811, 43813, 43817>    <43811, 43817, 43814>,
    <43811, 43814, 43818>    <43811, 43818, 43815>,
    <43811, 43815, 43819>    <43820, 43828, 43821>,
    <43820, 43821, 43825>    <43820, 43825, 43822>,
    <43820, 43822, 43826>    <43820, 43826, 43823>,
    <43820, 43823, 43827>    <43820, 43827, 43824>,
    <43820, 43824, 43828>    <43829, 43837, 43830>,
    <43829, 43830, 43834>    <43829, 43834, 43831>,
    <43829, 43831, 43835>    <43829, 43835, 43832>,
    <43829, 43832, 43836>    <43829, 43836, 43833>,
    <43829, 43833, 43837>    <43838, 43846, 43839>,
    <43838, 43839, 43843>    <43838, 43843, 43840>,
    <43838, 43840, 43844>    <43838, 43844, 43841>,
    <43838, 43841, 43845>    <43838, 43845, 43842>,
    <43838, 43842, 43846>    <43847, 43855, 43848>,
    <43847, 43848, 43852>    <43847, 43852, 43849>,
    <43847, 43849, 43853>    <43847, 43853, 43850>,
    <43847, 43850, 43854>    <43847, 43854, 43851>,
    <43847, 43851, 43855>    <43856, 43864, 43857>,
    <43856, 43857, 43861>    <43856, 43861, 43858>,
    <43856, 43858, 43862>    <43856, 43862, 43859>,
    <43856, 43859, 43863>    <43856, 43863, 43860>,
    <43856, 43860, 43864>    <43865, 43873, 43866>,
    <43865, 43866, 43870>    <43865, 43870, 43867>,
    <43865, 43867, 43871>    <43865, 43871, 43868>,
    <43865, 43868, 43872>    <43865, 43872, 43869>,
    <43865, 43869, 43873>    <43874, 43882, 43875>,
    <43874, 43875, 43879>    <43874, 43879, 43876>,
    <43874, 43876, 43880>    <43874, 43880, 43877>,
    <43874, 43877, 43881>    <43874, 43881, 43878>,
    <43874, 43878, 43882>    <43883, 43891, 43884>,
    <43883, 43884, 43888>    <43883, 43888, 43885>,
    <43883, 43885, 43889>    <43883, 43889, 43886>,
    <43883, 43886, 43890>    <43883, 43890, 43887>,
    <43883, 43887, 43891>    <43892, 43900, 43893>,
    <43892, 43893, 43897>    <43892, 43897, 43894>,
    <43892, 43894, 43898>    <43892, 43898, 43895>,
    <43892, 43895, 43899>    <43892, 43899, 43896>,
    <43892, 43896, 43900>    <43901, 43909, 43902>,
    <43901, 43902, 43906>    <43901, 43906, 43903>,
    <43901, 43903, 43907>    <43901, 43907, 43904>,
    <43901, 43904, 43908>    <43901, 43908, 43905>,
    <43901, 43905, 43909>    <43910, 43918, 43911>,
    <43910, 43911, 43915>    <43910, 43915, 43912>,
    <43910, 43912, 43916>    <43910, 43916, 43913>,
    <43910, 43913, 43917>    <43910, 43917, 43914>,
    <43910, 43914, 43918>    <43919, 43927, 43920>,
    <43919, 43920, 43924>    <43919, 43924, 43921>,
    <43919, 43921, 43925>    <43919, 43925, 43922>,
    <43919, 43922, 43926>    <43919, 43926, 43923>,
    <43919, 43923, 43927>    <43928, 43936, 43929>,
    <43928, 43929, 43933>    <43928, 43933, 43930>,
    <43928, 43930, 43934>    <43928, 43934, 43931>,
    <43928, 43931, 43935>    <43928, 43935, 43932>,
    <43928, 43932, 43936>    <43937, 43945, 43938>,
    <43937, 43938, 43942>    <43937, 43942, 43939>,
    <43937, 43939, 43943>    <43937, 43943, 43940>,
    <43937, 43940, 43944>    <43937, 43944, 43941>,
    <43937, 43941, 43945>    <43946, 43954, 43947>,
    <43946, 43947, 43951>    <43946, 43951, 43948>,
    <43946, 43948, 43952>    <43946, 43952, 43949>,
    <43946, 43949, 43953>    <43946, 43953, 43950>,
    <43946, 43950, 43954>    <43955, 43963, 43956>,
    <43955, 43956, 43960>    <43955, 43960, 43957>,
    <43955, 43957, 43961>    <43955, 43961, 43958>,
    <43955, 43958, 43962>    <43955, 43962, 43959>,
    <43955, 43959, 43963>    <43964, 43972, 43965>,
    <43964, 43965, 43969>    <43964, 43969, 43966>,
    <43964, 43966, 43970>    <43964, 43970, 43967>,
    <43964, 43967, 43971>    <43964, 43971, 43968>,
    <43964, 43968, 43972>    <43973, 43981, 43974>,
    <43973, 43974, 43978>    <43973, 43978, 43975>,
    <43973, 43975, 43979>    <43973, 43979, 43976>,
    <43973, 43976, 43980>    <43973, 43980, 43977>,
    <43973, 43977, 43981>    <43982, 43990, 43983>,
    <43982, 43983, 43987>    <43982, 43987, 43984>,
    <43982, 43984, 43988>    <43982, 43988, 43985>,
    <43982, 43985, 43989>    <43982, 43989, 43986>,
    <43982, 43986, 43990>    <43991, 43999, 43992>,
    <43991, 43992, 43996>    <43991, 43996, 43993>,
    <43991, 43993, 43997>    <43991, 43997, 43994>,
    <43991, 43994, 43998>    <43991, 43998, 43995>,
    <43991, 43995, 43999>    <44000, 44008, 44001>,
    <44000, 44001, 44005>    <44000, 44005, 44002>,
    <44000, 44002, 44006>    <44000, 44006, 44003>,
    <44000, 44003, 44007>    <44000, 44007, 44004>,
    <44000, 44004, 44008>    <44009, 44017, 44010>,
    <44009, 44010, 44014>    <44009, 44014, 44011>,
    <44009, 44011, 44015>    <44009, 44015, 44012>,
    <44009, 44012, 44016>    <44009, 44016, 44013>,
    <44009, 44013, 44017>    <44018, 44026, 44019>,
    <44018, 44019, 44023>    <44018, 44023, 44020>,
    <44018, 44020, 44024>    <44018, 44024, 44021>,
    <44018, 44021, 44025>    <44018, 44025, 44022>,
    <44018, 44022, 44026>    <44027, 44035, 44028>,
    <44027, 44028, 44032>    <44027, 44032, 44029>,
    <44027, 44029, 44033>    <44027, 44033, 44030>,
    <44027, 44030, 44034>    <44027, 44034, 44031>,
    <44027, 44031, 44035>    <44036, 44044, 44037>,
    <44036, 44037, 44041>    <44036, 44041, 44038>,
    <44036, 44038, 44042>    <44036, 44042, 44039>,
    <44036, 44039, 44043>    <44036, 44043, 44040>,
    <44036, 44040, 44044>    <44045, 44053, 44046>,
    <44045, 44046, 44050>    <44045, 44050, 44047>,
    <44045, 44047, 44051>    <44045, 44051, 44048>,
    <44045, 44048, 44052>    <44045, 44052, 44049>,
    <44045, 44049, 44053>    <44054, 44062, 44055>,
    <44054, 44055, 44059>    <44054, 44059, 44056>,
    <44054, 44056, 44060>    <44054, 44060, 44057>,
    <44054, 44057, 44061>    <44054, 44061, 44058>,
    <44054, 44058, 44062>    <44063, 44071, 44064>,
    <44063, 44064, 44068>    <44063, 44068, 44065>,
    <44063, 44065, 44069>    <44063, 44069, 44066>,
    <44063, 44066, 44070>    <44063, 44070, 44067>,
    <44063, 44067, 44071>    <44072, 44080, 44073>,
    <44072, 44073, 44077>    <44072, 44077, 44074>,
    <44072, 44074, 44078>    <44072, 44078, 44075>,
    <44072, 44075, 44079>    <44072, 44079, 44076>,
    <44072, 44076, 44080>    <44081, 44089, 44082>,
    <44081, 44082, 44086>    <44081, 44086, 44083>,
    <44081, 44083, 44087>    <44081, 44087, 44084>,
    <44081, 44084, 44088>    <44081, 44088, 44085>,
    <44081, 44085, 44089>    <44090, 44098, 44091>,
    <44090, 44091, 44095>    <44090, 44095, 44092>,
    <44090, 44092, 44096>    <44090, 44096, 44093>,
    <44090, 44093, 44097>    <44090, 44097, 44094>,
    <44090, 44094, 44098>    <44099, 44107, 44100>,
    <44099, 44100, 44104>    <44099, 44104, 44101>,
    <44099, 44101, 44105>    <44099, 44105, 44102>,
    <44099, 44102, 44106>    <44099, 44106, 44103>,
    <44099, 44103, 44107>    <44108, 44116, 44109>,
    <44108, 44109, 44113>    <44108, 44113, 44110>,
    <44108, 44110, 44114>    <44108, 44114, 44111>,
    <44108, 44111, 44115>    <44108, 44115, 44112>,
    <44108, 44112, 44116>    <44117, 44125, 44118>,
    <44117, 44118, 44122>    <44117, 44122, 44119>,
    <44117, 44119, 44123>    <44117, 44123, 44120>,
    <44117, 44120, 44124>    <44117, 44124, 44121>,
    <44117, 44121, 44125>    <44126, 44134, 44127>,
    <44126, 44127, 44131>    <44126, 44131, 44128>,
    <44126, 44128, 44132>    <44126, 44132, 44129>,
    <44126, 44129, 44133>    <44126, 44133, 44130>,
    <44126, 44130, 44134>    <44135, 44143, 44136>,
    <44135, 44136, 44140>    <44135, 44140, 44137>,
    <44135, 44137, 44141>    <44135, 44141, 44138>,
    <44135, 44138, 44142>    <44135, 44142, 44139>,
    <44135, 44139, 44143>    <44144, 44152, 44145>,
    <44144, 44145, 44149>    <44144, 44149, 44146>,
    <44144, 44146, 44150>    <44144, 44150, 44147>,
    <44144, 44147, 44151>    <44144, 44151, 44148>,
    <44144, 44148, 44152>    <44153, 44161, 44154>,
    <44153, 44154, 44158>    <44153, 44158, 44155>,
    <44153, 44155, 44159>    <44153, 44159, 44156>,
    <44153, 44156, 44160>    <44153, 44160, 44157>,
    <44153, 44157, 44161>    <44162, 44170, 44163>,
    <44162, 44163, 44167>    <44162, 44167, 44164>,
    <44162, 44164, 44168>    <44162, 44168, 44165>,
    <44162, 44165, 44169>    <44162, 44169, 44166>,
    <44162, 44166, 44170>    <44171, 44179, 44172>,
    <44171, 44172, 44176>    <44171, 44176, 44173>,
    <44171, 44173, 44177>    <44171, 44177, 44174>,
    <44171, 44174, 44178>    <44171, 44178, 44175>,
    <44171, 44175, 44179>    <44180, 44188, 44181>,
    <44180, 44181, 44185>    <44180, 44185, 44182>,
    <44180, 44182, 44186>    <44180, 44186, 44183>,
    <44180, 44183, 44187>    <44180, 44187, 44184>,
    <44180, 44184, 44188>    <44189, 44197, 44190>,
    <44189, 44190, 44194>    <44189, 44194, 44191>,
    <44189, 44191, 44195>    <44189, 44195, 44192>,
    <44189, 44192, 44196>    <44189, 44196, 44193>,
    <44189, 44193, 44197>    <44198, 44206, 44199>,
    <44198, 44199, 44203>    <44198, 44203, 44200>,
    <44198, 44200, 44204>    <44198, 44204, 44201>,
    <44198, 44201, 44205>    <44198, 44205, 44202>,
    <44198, 44202, 44206>    <44207, 44215, 44208>,
    <44207, 44208, 44212>    <44207, 44212, 44209>,
    <44207, 44209, 44213>    <44207, 44213, 44210>,
    <44207, 44210, 44214>    <44207, 44214, 44211>,
    <44207, 44211, 44215>    <44216, 44224, 44217>,
    <44216, 44217, 44221>    <44216, 44221, 44218>,
    <44216, 44218, 44222>    <44216, 44222, 44219>,
    <44216, 44219, 44223>    <44216, 44223, 44220>,
    <44216, 44220, 44224>    <44225, 44233, 44226>,
    <44225, 44226, 44230>    <44225, 44230, 44227>,
    <44225, 44227, 44231>    <44225, 44231, 44228>,
    <44225, 44228, 44232>    <44225, 44232, 44229>,
    <44225, 44229, 44233>    <44234, 44242, 44235>,
    <44234, 44235, 44239>    <44234, 44239, 44236>,
    <44234, 44236, 44240>    <44234, 44240, 44237>,
    <44234, 44237, 44241>    <44234, 44241, 44238>,
    <44234, 44238, 44242>    <44243, 44251, 44244>,
    <44243, 44244, 44248>    <44243, 44248, 44245>,
    <44243, 44245, 44249>    <44243, 44249, 44246>,
    <44243, 44246, 44250>    <44243, 44250, 44247>,
    <44243, 44247, 44251>    <44252, 44260, 44253>,
    <44252, 44253, 44257>    <44252, 44257, 44254>,
    <44252, 44254, 44258>    <44252, 44258, 44255>,
    <44252, 44255, 44259>    <44252, 44259, 44256>,
    <44252, 44256, 44260>    <44261, 44269, 44262>,
    <44261, 44262, 44266>    <44261, 44266, 44263>,
    <44261, 44263, 44267>    <44261, 44267, 44264>,
    <44261, 44264, 44268>    <44261, 44268, 44265>,
    <44261, 44265, 44269>    <44270, 44278, 44271>,
    <44270, 44271, 44275>    <44270, 44275, 44272>,
    <44270, 44272, 44276>    <44270, 44276, 44273>,
    <44270, 44273, 44277>    <44270, 44277, 44274>,
    <44270, 44274, 44278>    <44279, 44287, 44280>,
    <44279, 44280, 44284>    <44279, 44284, 44281>,
    <44279, 44281, 44285>    <44279, 44285, 44282>,
    <44279, 44282, 44286>    <44279, 44286, 44283>,
    <44279, 44283, 44287>    <44288, 44296, 44289>,
    <44288, 44289, 44293>    <44288, 44293, 44290>,
    <44288, 44290, 44294>    <44288, 44294, 44291>,
    <44288, 44291, 44295>    <44288, 44295, 44292>,
    <44288, 44292, 44296>    <44297, 44305, 44298>,
    <44297, 44298, 44302>    <44297, 44302, 44299>,
    <44297, 44299, 44303>    <44297, 44303, 44300>,
    <44297, 44300, 44304>    <44297, 44304, 44301>,
    <44297, 44301, 44305>    <44306, 44314, 44307>,
    <44306, 44307, 44311>    <44306, 44311, 44308>,
    <44306, 44308, 44312>    <44306, 44312, 44309>,
    <44306, 44309, 44313>    <44306, 44313, 44310>,
    <44306, 44310, 44314>    <44315, 44323, 44316>,
    <44315, 44316, 44320>    <44315, 44320, 44317>,
    <44315, 44317, 44321>    <44315, 44321, 44318>,
    <44315, 44318, 44322>    <44315, 44322, 44319>,
    <44315, 44319, 44323>    <44324, 44332, 44325>,
    <44324, 44325, 44329>    <44324, 44329, 44326>,
    <44324, 44326, 44330>    <44324, 44330, 44327>,
    <44324, 44327, 44331>    <44324, 44331, 44328>,
    <44324, 44328, 44332>    <44333, 44341, 44334>,
    <44333, 44334, 44338>    <44333, 44338, 44335>,
    <44333, 44335, 44339>    <44333, 44339, 44336>,
    <44333, 44336, 44340>    <44333, 44340, 44337>,
    <44333, 44337, 44341>    <44342, 44350, 44343>,
    <44342, 44343, 44347>    <44342, 44347, 44344>,
    <44342, 44344, 44348>    <44342, 44348, 44345>,
    <44342, 44345, 44349>    <44342, 44349, 44346>,
    <44342, 44346, 44350>    <44351, 44359, 44352>,
    <44351, 44352, 44356>    <44351, 44356, 44353>,
    <44351, 44353, 44357>    <44351, 44357, 44354>,
    <44351, 44354, 44358>    <44351, 44358, 44355>,
    <44351, 44355, 44359>    <44360, 44368, 44361>,
    <44360, 44361, 44365>    <44360, 44365, 44362>,
    <44360, 44362, 44366>    <44360, 44366, 44363>,
    <44360, 44363, 44367>    <44360, 44367, 44364>,
    <44360, 44364, 44368>    <44369, 44377, 44370>,
    <44369, 44370, 44374>    <44369, 44374, 44371>,
    <44369, 44371, 44375>    <44369, 44375, 44372>,
    <44369, 44372, 44376>    <44369, 44376, 44373>,
    <44369, 44373, 44377>    <44378, 44386, 44379>,
    <44378, 44379, 44383>    <44378, 44383, 44380>,
    <44378, 44380, 44384>    <44378, 44384, 44381>,
    <44378, 44381, 44385>    <44378, 44385, 44382>,
    <44378, 44382, 44386>    <44387, 44395, 44388>,
    <44387, 44388, 44392>    <44387, 44392, 44389>,
    <44387, 44389, 44393>    <44387, 44393, 44390>,
    <44387, 44390, 44394>    <44387, 44394, 44391>,
    <44387, 44391, 44395>    <44396, 44404, 44397>,
    <44396, 44397, 44401>    <44396, 44401, 44398>,
    <44396, 44398, 44402>    <44396, 44402, 44399>,
    <44396, 44399, 44403>    <44396, 44403, 44400>,
    <44396, 44400, 44404>    <44405, 44413, 44406>,
    <44405, 44406, 44410>    <44405, 44410, 44407>,
    <44405, 44407, 44411>    <44405, 44411, 44408>,
    <44405, 44408, 44412>    <44405, 44412, 44409>,
    <44405, 44409, 44413>    <44414, 44422, 44415>,
    <44414, 44415, 44419>    <44414, 44419, 44416>,
    <44414, 44416, 44420>    <44414, 44420, 44417>,
    <44414, 44417, 44421>    <44414, 44421, 44418>,
    <44414, 44418, 44422>    <44423, 44431, 44424>,
    <44423, 44424, 44428>    <44423, 44428, 44425>,
    <44423, 44425, 44429>    <44423, 44429, 44426>,
    <44423, 44426, 44430>    <44423, 44430, 44427>,
    <44423, 44427, 44431>    <44432, 44440, 44433>,
    <44432, 44433, 44437>    <44432, 44437, 44434>,
    <44432, 44434, 44438>    <44432, 44438, 44435>,
    <44432, 44435, 44439>    <44432, 44439, 44436>,
    <44432, 44436, 44440>    <44441, 44449, 44442>,
    <44441, 44442, 44446>    <44441, 44446, 44443>,
    <44441, 44443, 44447>    <44441, 44447, 44444>,
    <44441, 44444, 44448>    <44441, 44448, 44445>,
    <44441, 44445, 44449>    <44450, 44458, 44451>,
    <44450, 44451, 44455>    <44450, 44455, 44452>,
    <44450, 44452, 44456>    <44450, 44456, 44453>,
    <44450, 44453, 44457>    <44450, 44457, 44454>,
    <44450, 44454, 44458>    <44459, 44467, 44460>,
    <44459, 44460, 44464>    <44459, 44464, 44461>,
    <44459, 44461, 44465>    <44459, 44465, 44462>,
    <44459, 44462, 44466>    <44459, 44466, 44463>,
    <44459, 44463, 44467>    <44468, 44476, 44469>,
    <44468, 44469, 44473>    <44468, 44473, 44470>,
    <44468, 44470, 44474>    <44468, 44474, 44471>,
    <44468, 44471, 44475>    <44468, 44475, 44472>,
    <44468, 44472, 44476>    <44477, 44485, 44478>,
    <44477, 44478, 44482>    <44477, 44482, 44479>,
    <44477, 44479, 44483>    <44477, 44483, 44480>,
    <44477, 44480, 44484>    <44477, 44484, 44481>,
    <44477, 44481, 44485>    <44486, 44494, 44487>,
    <44486, 44487, 44491>    <44486, 44491, 44488>,
    <44486, 44488, 44492>    <44486, 44492, 44489>,
    <44486, 44489, 44493>    <44486, 44493, 44490>,
    <44486, 44490, 44494>    <44495, 44503, 44496>,
    <44495, 44496, 44500>    <44495, 44500, 44497>,
    <44495, 44497, 44501>    <44495, 44501, 44498>,
    <44495, 44498, 44502>    <44495, 44502, 44499>,
    <44495, 44499, 44503>    <44504, 44512, 44505>,
    <44504, 44505, 44509>    <44504, 44509, 44506>,
    <44504, 44506, 44510>    <44504, 44510, 44507>,
    <44504, 44507, 44511>    <44504, 44511, 44508>,
    <44504, 44508, 44512>    <44513, 44521, 44514>,
    <44513, 44514, 44518>    <44513, 44518, 44515>,
    <44513, 44515, 44519>    <44513, 44519, 44516>,
    <44513, 44516, 44520>    <44513, 44520, 44517>,
    <44513, 44517, 44521>    <44522, 44530, 44523>,
    <44522, 44523, 44527>    <44522, 44527, 44524>,
    <44522, 44524, 44528>    <44522, 44528, 44525>,
    <44522, 44525, 44529>    <44522, 44529, 44526>,
    <44522, 44526, 44530>    <44531, 44539, 44532>,
    <44531, 44532, 44536>    <44531, 44536, 44533>,
    <44531, 44533, 44537>    <44531, 44537, 44534>,
    <44531, 44534, 44538>    <44531, 44538, 44535>,
    <44531, 44535, 44539>    <44540, 44548, 44541>,
    <44540, 44541, 44545>    <44540, 44545, 44542>,
    <44540, 44542, 44546>    <44540, 44546, 44543>,
    <44540, 44543, 44547>    <44540, 44547, 44544>,
    <44540, 44544, 44548>    <44549, 44557, 44550>,
    <44549, 44550, 44554>    <44549, 44554, 44551>,
    <44549, 44551, 44555>    <44549, 44555, 44552>,
    <44549, 44552, 44556>    <44549, 44556, 44553>,
    <44549, 44553, 44557>    <44558, 44566, 44559>,
    <44558, 44559, 44563>    <44558, 44563, 44560>,
    <44558, 44560, 44564>    <44558, 44564, 44561>,
    <44558, 44561, 44565>    <44558, 44565, 44562>,
    <44558, 44562, 44566>    <44567, 44575, 44568>,
    <44567, 44568, 44572>    <44567, 44572, 44569>,
    <44567, 44569, 44573>    <44567, 44573, 44570>,
    <44567, 44570, 44574>    <44567, 44574, 44571>,
    <44567, 44571, 44575>    <44576, 44584, 44577>,
    <44576, 44577, 44581>    <44576, 44581, 44578>,
    <44576, 44578, 44582>    <44576, 44582, 44579>,
    <44576, 44579, 44583>    <44576, 44583, 44580>,
    <44576, 44580, 44584>    <44585, 44593, 44586>,
    <44585, 44586, 44590>    <44585, 44590, 44587>,
    <44585, 44587, 44591>    <44585, 44591, 44588>,
    <44585, 44588, 44592>    <44585, 44592, 44589>,
    <44585, 44589, 44593>    <44594, 44602, 44595>,
    <44594, 44595, 44599>    <44594, 44599, 44596>,
    <44594, 44596, 44600>    <44594, 44600, 44597>,
    <44594, 44597, 44601>    <44594, 44601, 44598>,
    <44594, 44598, 44602>    <44603, 44611, 44604>,
    <44603, 44604, 44608>    <44603, 44608, 44605>,
    <44603, 44605, 44609>    <44603, 44609, 44606>,
    <44603, 44606, 44610>    <44603, 44610, 44607>,
    <44603, 44607, 44611>    <44612, 44620, 44613>,
    <44612, 44613, 44617>    <44612, 44617, 44614>,
    <44612, 44614, 44618>    <44612, 44618, 44615>,
    <44612, 44615, 44619>    <44612, 44619, 44616>,
    <44612, 44616, 44620>    <44621, 44629, 44622>,
    <44621, 44622, 44626>    <44621, 44626, 44623>,
    <44621, 44623, 44627>    <44621, 44627, 44624>,
    <44621, 44624, 44628>    <44621, 44628, 44625>,
    <44621, 44625, 44629>    <44630, 44638, 44631>,
    <44630, 44631, 44635>    <44630, 44635, 44632>,
    <44630, 44632, 44636>    <44630, 44636, 44633>,
    <44630, 44633, 44637>    <44630, 44637, 44634>,
    <44630, 44634, 44638>    <44639, 44647, 44640>,
    <44639, 44640, 44644>    <44639, 44644, 44641>,
    <44639, 44641, 44645>    <44639, 44645, 44642>,
    <44639, 44642, 44646>    <44639, 44646, 44643>,
    <44639, 44643, 44647>    <44648, 44656, 44649>,
    <44648, 44649, 44653>    <44648, 44653, 44650>,
    <44648, 44650, 44654>    <44648, 44654, 44651>,
    <44648, 44651, 44655>    <44648, 44655, 44652>,
    <44648, 44652, 44656>    <44657, 44665, 44658>,
    <44657, 44658, 44662>    <44657, 44662, 44659>,
    <44657, 44659, 44663>    <44657, 44663, 44660>,
    <44657, 44660, 44664>    <44657, 44664, 44661>,
    <44657, 44661, 44665>    <44666, 44674, 44667>,
    <44666, 44667, 44671>    <44666, 44671, 44668>,
    <44666, 44668, 44672>    <44666, 44672, 44669>,
    <44666, 44669, 44673>    <44666, 44673, 44670>,
    <44666, 44670, 44674>    <44675, 44683, 44676>,
    <44675, 44676, 44680>    <44675, 44680, 44677>,
    <44675, 44677, 44681>    <44675, 44681, 44678>,
    <44675, 44678, 44682>    <44675, 44682, 44679>,
    <44675, 44679, 44683>    <44684, 44692, 44685>,
    <44684, 44685, 44689>    <44684, 44689, 44686>,
    <44684, 44686, 44690>    <44684, 44690, 44687>,
    <44684, 44687, 44691>    <44684, 44691, 44688>,
    <44684, 44688, 44692>    <44693, 44701, 44694>,
    <44693, 44694, 44698>    <44693, 44698, 44695>,
    <44693, 44695, 44699>    <44693, 44699, 44696>,
    <44693, 44696, 44700>    <44693, 44700, 44697>,
    <44693, 44697, 44701>    <44702, 44710, 44703>,
    <44702, 44703, 44707>    <44702, 44707, 44704>,
    <44702, 44704, 44708>    <44702, 44708, 44705>,
    <44702, 44705, 44709>    <44702, 44709, 44706>,
    <44702, 44706, 44710>    <44711, 44719, 44712>,
    <44711, 44712, 44716>    <44711, 44716, 44713>,
    <44711, 44713, 44717>    <44711, 44717, 44714>,
    <44711, 44714, 44718>    <44711, 44718, 44715>,
    <44711, 44715, 44719>    <44720, 44728, 44721>,
    <44720, 44721, 44725>    <44720, 44725, 44722>,
    <44720, 44722, 44726>    <44720, 44726, 44723>,
    <44720, 44723, 44727>    <44720, 44727, 44724>,
    <44720, 44724, 44728>    <44729, 44737, 44730>,
    <44729, 44730, 44734>    <44729, 44734, 44731>,
    <44729, 44731, 44735>    <44729, 44735, 44732>,
    <44729, 44732, 44736>    <44729, 44736, 44733>,
    <44729, 44733, 44737>    <44738, 44746, 44739>,
    <44738, 44739, 44743>    <44738, 44743, 44740>,
    <44738, 44740, 44744>    <44738, 44744, 44741>,
    <44738, 44741, 44745>    <44738, 44745, 44742>,
    <44738, 44742, 44746>    <44747, 44755, 44748>,
    <44747, 44748, 44752>    <44747, 44752, 44749>,
    <44747, 44749, 44753>    <44747, 44753, 44750>,
    <44747, 44750, 44754>    <44747, 44754, 44751>,
    <44747, 44751, 44755>    <44756, 44764, 44757>,
    <44756, 44757, 44761>    <44756, 44761, 44758>,
    <44756, 44758, 44762>    <44756, 44762, 44759>,
    <44756, 44759, 44763>    <44756, 44763, 44760>,
    <44756, 44760, 44764>    <44765, 44773, 44766>,
    <44765, 44766, 44770>    <44765, 44770, 44767>,
    <44765, 44767, 44771>    <44765, 44771, 44768>,
    <44765, 44768, 44772>    <44765, 44772, 44769>,
    <44765, 44769, 44773>    <44774, 44782, 44775>,
    <44774, 44775, 44779>    <44774, 44779, 44776>,
    <44774, 44776, 44780>    <44774, 44780, 44777>,
    <44774, 44777, 44781>    <44774, 44781, 44778>,
    <44774, 44778, 44782>    <44783, 44791, 44784>,
    <44783, 44784, 44788>    <44783, 44788, 44785>,
    <44783, 44785, 44789>    <44783, 44789, 44786>,
    <44783, 44786, 44790>    <44783, 44790, 44787>,
    <44783, 44787, 44791>    <44792, 44800, 44793>,
    <44792, 44793, 44797>    <44792, 44797, 44794>,
    <44792, 44794, 44798>    <44792, 44798, 44795>,
    <44792, 44795, 44799>    <44792, 44799, 44796>,
    <44792, 44796, 44800>    <44801, 44809, 44802>,
    <44801, 44802, 44806>    <44801, 44806, 44803>,
    <44801, 44803, 44807>    <44801, 44807, 44804>,
    <44801, 44804, 44808>    <44801, 44808, 44805>,
    <44801, 44805, 44809>    <44810, 44818, 44811>,
    <44810, 44811, 44815>    <44810, 44815, 44812>,
    <44810, 44812, 44816>    <44810, 44816, 44813>,
    <44810, 44813, 44817>    <44810, 44817, 44814>,
    <44810, 44814, 44818>    <44819, 44827, 44820>,
    <44819, 44820, 44824>    <44819, 44824, 44821>,
    <44819, 44821, 44825>    <44819, 44825, 44822>,
    <44819, 44822, 44826>    <44819, 44826, 44823>,
    <44819, 44823, 44827>    <44828, 44836, 44829>,
    <44828, 44829, 44833>    <44828, 44833, 44830>,
    <44828, 44830, 44834>    <44828, 44834, 44831>,
    <44828, 44831, 44835>    <44828, 44835, 44832>,
    <44828, 44832, 44836>    <44837, 44845, 44838>,
    <44837, 44838, 44842>    <44837, 44842, 44839>,
    <44837, 44839, 44843>    <44837, 44843, 44840>,
    <44837, 44840, 44844>    <44837, 44844, 44841>,
    <44837, 44841, 44845>    <44846, 44854, 44847>,
    <44846, 44847, 44851>    <44846, 44851, 44848>,
    <44846, 44848, 44852>    <44846, 44852, 44849>,
    <44846, 44849, 44853>    <44846, 44853, 44850>,
    <44846, 44850, 44854>    <44855, 44863, 44856>,
    <44855, 44856, 44860>    <44855, 44860, 44857>,
    <44855, 44857, 44861>    <44855, 44861, 44858>,
    <44855, 44858, 44862>    <44855, 44862, 44859>,
    <44855, 44859, 44863>    <44864, 44872, 44865>,
    <44864, 44865, 44869>    <44864, 44869, 44866>,
    <44864, 44866, 44870>    <44864, 44870, 44867>,
    <44864, 44867, 44871>    <44864, 44871, 44868>,
    <44864, 44868, 44872>    <44873, 44881, 44874>,
    <44873, 44874, 44878>    <44873, 44878, 44875>,
    <44873, 44875, 44879>    <44873, 44879, 44876>,
    <44873, 44876, 44880>    <44873, 44880, 44877>,
    <44873, 44877, 44881>    <44882, 44890, 44883>,
    <44882, 44883, 44887>    <44882, 44887, 44884>,
    <44882, 44884, 44888>    <44882, 44888, 44885>,
    <44882, 44885, 44889>    <44882, 44889, 44886>,
    <44882, 44886, 44890>    <44891, 44899, 44892>,
    <44891, 44892, 44896>    <44891, 44896, 44893>,
    <44891, 44893, 44897>    <44891, 44897, 44894>,
    <44891, 44894, 44898>    <44891, 44898, 44895>,
    <44891, 44895, 44899>    <44900, 44908, 44901>,
    <44900, 44901, 44905>    <44900, 44905, 44902>,
    <44900, 44902, 44906>    <44900, 44906, 44903>,
    <44900, 44903, 44907>    <44900, 44907, 44904>,
    <44900, 44904, 44908>    <44909, 44917, 44910>,
    <44909, 44910, 44914>    <44909, 44914, 44911>,
    <44909, 44911, 44915>    <44909, 44915, 44912>,
    <44909, 44912, 44916>    <44909, 44916, 44913>,
    <44909, 44913, 44917>    <44918, 44926, 44919>,
    <44918, 44919, 44923>    <44918, 44923, 44920>,
    <44918, 44920, 44924>    <44918, 44924, 44921>,
    <44918, 44921, 44925>    <44918, 44925, 44922>,
    <44918, 44922, 44926>    <44927, 44935, 44928>,
    <44927, 44928, 44932>    <44927, 44932, 44929>,
    <44927, 44929, 44933>    <44927, 44933, 44930>,
    <44927, 44930, 44934>    <44927, 44934, 44931>,
    <44927, 44931, 44935>    <44936, 44944, 44937>,
    <44936, 44937, 44941>    <44936, 44941, 44938>,
    <44936, 44938, 44942>    <44936, 44942, 44939>,
    <44936, 44939, 44943>    <44936, 44943, 44940>,
    <44936, 44940, 44944>    <44945, 44953, 44946>,
    <44945, 44946, 44950>    <44945, 44950, 44947>,
    <44945, 44947, 44951>    <44945, 44951, 44948>,
    <44945, 44948, 44952>    <44945, 44952, 44949>,
    <44945, 44949, 44953>    <44954, 44962, 44955>,
    <44954, 44955, 44959>    <44954, 44959, 44956>,
    <44954, 44956, 44960>    <44954, 44960, 44957>,
    <44954, 44957, 44961>    <44954, 44961, 44958>,
    <44954, 44958, 44962>    <44963, 44971, 44964>,
    <44963, 44964, 44968>    <44963, 44968, 44965>,
    <44963, 44965, 44969>    <44963, 44969, 44966>,
    <44963, 44966, 44970>    <44963, 44970, 44967>,
    <44963, 44967, 44971>    <44972, 44980, 44973>,
    <44972, 44973, 44977>    <44972, 44977, 44974>,
    <44972, 44974, 44978>    <44972, 44978, 44975>,
    <44972, 44975, 44979>    <44972, 44979, 44976>,
    <44972, 44976, 44980>    <44981, 44989, 44982>,
    <44981, 44982, 44986>    <44981, 44986, 44983>,
    <44981, 44983, 44987>    <44981, 44987, 44984>,
    <44981, 44984, 44988>    <44981, 44988, 44985>,
    <44981, 44985, 44989>    <44990, 44998, 44991>,
    <44990, 44991, 44995>    <44990, 44995, 44992>,
    <44990, 44992, 44996>    <44990, 44996, 44993>,
    <44990, 44993, 44997>    <44990, 44997, 44994>,
    <44990, 44994, 44998>    <44999, 45007, 45000>,
    <44999, 45000, 45004>    <44999, 45004, 45001>,
    <44999, 45001, 45005>    <44999, 45005, 45002>,
    <44999, 45002, 45006>    <44999, 45006, 45003>,
    <44999, 45003, 45007>    <45008, 45016, 45009>,
    <45008, 45009, 45013>    <45008, 45013, 45010>,
    <45008, 45010, 45014>    <45008, 45014, 45011>,
    <45008, 45011, 45015>    <45008, 45015, 45012>,
    <45008, 45012, 45016>    <45017, 45025, 45018>,
    <45017, 45018, 45022>    <45017, 45022, 45019>,
    <45017, 45019, 45023>    <45017, 45023, 45020>,
    <45017, 45020, 45024>    <45017, 45024, 45021>,
    <45017, 45021, 45025>    <45026, 45034, 45027>,
    <45026, 45027, 45031>    <45026, 45031, 45028>,
    <45026, 45028, 45032>    <45026, 45032, 45029>,
    <45026, 45029, 45033>    <45026, 45033, 45030>,
    <45026, 45030, 45034>    <45035, 45043, 45036>,
    <45035, 45036, 45040>    <45035, 45040, 45037>,
    <45035, 45037, 45041>    <45035, 45041, 45038>,
    <45035, 45038, 45042>    <45035, 45042, 45039>,
    <45035, 45039, 45043>    <45044, 45052, 45045>,
    <45044, 45045, 45049>    <45044, 45049, 45046>,
    <45044, 45046, 45050>    <45044, 45050, 45047>,
    <45044, 45047, 45051>    <45044, 45051, 45048>,
    <45044, 45048, 45052>    <45053, 45061, 45054>,
    <45053, 45054, 45058>    <45053, 45058, 45055>,
    <45053, 45055, 45059>    <45053, 45059, 45056>,
    <45053, 45056, 45060>    <45053, 45060, 45057>,
    <45053, 45057, 45061>    <45062, 45070, 45063>,
    <45062, 45063, 45067>    <45062, 45067, 45064>,
    <45062, 45064, 45068>    <45062, 45068, 45065>,
    <45062, 45065, 45069>    <45062, 45069, 45066>,
    <45062, 45066, 45070>    <45071, 45079, 45072>,
    <45071, 45072, 45076>    <45071, 45076, 45073>,
    <45071, 45073, 45077>    <45071, 45077, 45074>,
    <45071, 45074, 45078>    <45071, 45078, 45075>,
    <45071, 45075, 45079>    <45080, 45088, 45081>,
    <45080, 45081, 45085>    <45080, 45085, 45082>,
    <45080, 45082, 45086>    <45080, 45086, 45083>,
    <45080, 45083, 45087>    <45080, 45087, 45084>,
    <45080, 45084, 45088>    <45089, 45097, 45090>,
    <45089, 45090, 45094>    <45089, 45094, 45091>,
    <45089, 45091, 45095>    <45089, 45095, 45092>,
    <45089, 45092, 45096>    <45089, 45096, 45093>,
    <45089, 45093, 45097>    <45098, 45106, 45099>,
    <45098, 45099, 45103>    <45098, 45103, 45100>,
    <45098, 45100, 45104>    <45098, 45104, 45101>,
    <45098, 45101, 45105>    <45098, 45105, 45102>,
    <45098, 45102, 45106>    <45107, 45115, 45108>,
    <45107, 45108, 45112>    <45107, 45112, 45109>,
    <45107, 45109, 45113>    <45107, 45113, 45110>,
    <45107, 45110, 45114>    <45107, 45114, 45111>,
    <45107, 45111, 45115>    <45116, 45124, 45117>,
    <45116, 45117, 45121>    <45116, 45121, 45118>,
    <45116, 45118, 45122>    <45116, 45122, 45119>,
    <45116, 45119, 45123>    <45116, 45123, 45120>,
    <45116, 45120, 45124>    <45125, 45133, 45126>,
    <45125, 45126, 45130>    <45125, 45130, 45127>,
    <45125, 45127, 45131>    <45125, 45131, 45128>,
    <45125, 45128, 45132>    <45125, 45132, 45129>,
    <45125, 45129, 45133>    <45134, 45142, 45135>,
    <45134, 45135, 45139>    <45134, 45139, 45136>,
    <45134, 45136, 45140>    <45134, 45140, 45137>,
    <45134, 45137, 45141>    <45134, 45141, 45138>,
    <45134, 45138, 45142>    <45143, 45151, 45144>,
    <45143, 45144, 45148>    <45143, 45148, 45145>,
    <45143, 45145, 45149>    <45143, 45149, 45146>,
    <45143, 45146, 45150>    <45143, 45150, 45147>,
    <45143, 45147, 45151>    <45152, 45160, 45153>,
    <45152, 45153, 45157>    <45152, 45157, 45154>,
    <45152, 45154, 45158>    <45152, 45158, 45155>,
    <45152, 45155, 45159>    <45152, 45159, 45156>,
    <45152, 45156, 45160>    <45161, 45169, 45162>,
    <45161, 45162, 45166>    <45161, 45166, 45163>,
    <45161, 45163, 45167>    <45161, 45167, 45164>,
    <45161, 45164, 45168>    <45161, 45168, 45165>,
    <45161, 45165, 45169>    <45170, 45178, 45171>,
    <45170, 45171, 45175>    <45170, 45175, 45172>,
    <45170, 45172, 45176>    <45170, 45176, 45173>,
    <45170, 45173, 45177>    <45170, 45177, 45174>,
    <45170, 45174, 45178>    <45179, 45187, 45180>,
    <45179, 45180, 45184>    <45179, 45184, 45181>,
    <45179, 45181, 45185>    <45179, 45185, 45182>,
    <45179, 45182, 45186>    <45179, 45186, 45183>,
    <45179, 45183, 45187>    <45188, 45196, 45189>,
    <45188, 45189, 45193>    <45188, 45193, 45190>,
    <45188, 45190, 45194>    <45188, 45194, 45191>,
    <45188, 45191, 45195>    <45188, 45195, 45192>,
    <45188, 45192, 45196>    <45197, 45205, 45198>,
    <45197, 45198, 45202>    <45197, 45202, 45199>,
    <45197, 45199, 45203>    <45197, 45203, 45200>,
    <45197, 45200, 45204>    <45197, 45204, 45201>,
    <45197, 45201, 45205>    <45206, 45214, 45207>,
    <45206, 45207, 45211>    <45206, 45211, 45208>,
    <45206, 45208, 45212>    <45206, 45212, 45209>,
    <45206, 45209, 45213>    <45206, 45213, 45210>,
    <45206, 45210, 45214>    <45215, 45223, 45216>,
    <45215, 45216, 45220>    <45215, 45220, 45217>,
    <45215, 45217, 45221>    <45215, 45221, 45218>,
    <45215, 45218, 45222>    <45215, 45222, 45219>,
    <45215, 45219, 45223>    <45224, 45232, 45225>,
    <45224, 45225, 45229>    <45224, 45229, 45226>,
    <45224, 45226, 45230>    <45224, 45230, 45227>,
    <45224, 45227, 45231>    <45224, 45231, 45228>,
    <45224, 45228, 45232>    <45233, 45241, 45234>,
    <45233, 45234, 45238>    <45233, 45238, 45235>,
    <45233, 45235, 45239>    <45233, 45239, 45236>,
    <45233, 45236, 45240>    <45233, 45240, 45237>,
    <45233, 45237, 45241>    <45242, 45250, 45243>,
    <45242, 45243, 45247>    <45242, 45247, 45244>,
    <45242, 45244, 45248>    <45242, 45248, 45245>,
    <45242, 45245, 45249>    <45242, 45249, 45246>,
    <45242, 45246, 45250>    <45251, 45259, 45252>,
    <45251, 45252, 45256>    <45251, 45256, 45253>,
    <45251, 45253, 45257>    <45251, 45257, 45254>,
    <45251, 45254, 45258>    <45251, 45258, 45255>,
    <45251, 45255, 45259>    <45260, 45268, 45261>,
    <45260, 45261, 45265>    <45260, 45265, 45262>,
    <45260, 45262, 45266>    <45260, 45266, 45263>,
    <45260, 45263, 45267>    <45260, 45267, 45264>,
    <45260, 45264, 45268>    <45269, 45277, 45270>,
    <45269, 45270, 45274>    <45269, 45274, 45271>,
    <45269, 45271, 45275>    <45269, 45275, 45272>,
    <45269, 45272, 45276>    <45269, 45276, 45273>,
    <45269, 45273, 45277>    <45278, 45286, 45279>,
    <45278, 45279, 45283>    <45278, 45283, 45280>,
    <45278, 45280, 45284>    <45278, 45284, 45281>,
    <45278, 45281, 45285>    <45278, 45285, 45282>,
    <45278, 45282, 45286>    <45287, 45295, 45288>,
    <45287, 45288, 45292>    <45287, 45292, 45289>,
    <45287, 45289, 45293>    <45287, 45293, 45290>,
    <45287, 45290, 45294>    <45287, 45294, 45291>,
    <45287, 45291, 45295>    <45296, 45304, 45297>,
    <45296, 45297, 45301>    <45296, 45301, 45298>,
    <45296, 45298, 45302>    <45296, 45302, 45299>,
    <45296, 45299, 45303>    <45296, 45303, 45300>,
    <45296, 45300, 45304>    <45305, 45313, 45306>,
    <45305, 45306, 45310>    <45305, 45310, 45307>,
    <45305, 45307, 45311>    <45305, 45311, 45308>,
    <45305, 45308, 45312>    <45305, 45312, 45309>,
    <45305, 45309, 45313>    <45314, 45322, 45315>,
    <45314, 45315, 45319>    <45314, 45319, 45316>,
    <45314, 45316, 45320>    <45314, 45320, 45317>,
    <45314, 45317, 45321>    <45314, 45321, 45318>,
    <45314, 45318, 45322>    <45323, 45331, 45324>,
    <45323, 45324, 45328>    <45323, 45328, 45325>,
    <45323, 45325, 45329>    <45323, 45329, 45326>,
    <45323, 45326, 45330>    <45323, 45330, 45327>,
    <45323, 45327, 45331>    <45332, 45340, 45333>,
    <45332, 45333, 45337>    <45332, 45337, 45334>,
    <45332, 45334, 45338>    <45332, 45338, 45335>,
    <45332, 45335, 45339>    <45332, 45339, 45336>,
    <45332, 45336, 45340>    <45341, 45349, 45342>,
    <45341, 45342, 45346>    <45341, 45346, 45343>,
    <45341, 45343, 45347>    <45341, 45347, 45344>,
    <45341, 45344, 45348>    <45341, 45348, 45345>,
    <45341, 45345, 45349>    <45350, 45358, 45351>,
    <45350, 45351, 45355>    <45350, 45355, 45352>,
    <45350, 45352, 45356>    <45350, 45356, 45353>,
    <45350, 45353, 45357>    <45350, 45357, 45354>,
    <45350, 45354, 45358>    <45359, 45367, 45360>,
    <45359, 45360, 45364>    <45359, 45364, 45361>,
    <45359, 45361, 45365>    <45359, 45365, 45362>,
    <45359, 45362, 45366>    <45359, 45366, 45363>,
    <45359, 45363, 45367>    <45368, 45376, 45369>,
    <45368, 45369, 45373>    <45368, 45373, 45370>,
    <45368, 45370, 45374>    <45368, 45374, 45371>,
    <45368, 45371, 45375>    <45368, 45375, 45372>,
    <45368, 45372, 45376>    <45377, 45385, 45378>,
    <45377, 45378, 45382>    <45377, 45382, 45379>,
    <45377, 45379, 45383>    <45377, 45383, 45380>,
    <45377, 45380, 45384>    <45377, 45384, 45381>,
    <45377, 45381, 45385>    <45386, 45394, 45387>,
    <45386, 45387, 45391>    <45386, 45391, 45388>,
    <45386, 45388, 45392>    <45386, 45392, 45389>,
    <45386, 45389, 45393>    <45386, 45393, 45390>,
    <45386, 45390, 45394>    <45395, 45403, 45396>,
    <45395, 45396, 45400>    <45395, 45400, 45397>,
    <45395, 45397, 45401>    <45395, 45401, 45398>,
    <45395, 45398, 45402>    <45395, 45402, 45399>,
    <45395, 45399, 45403>    <45404, 45412, 45405>,
    <45404, 45405, 45409>    <45404, 45409, 45406>,
    <45404, 45406, 45410>    <45404, 45410, 45407>,
    <45404, 45407, 45411>    <45404, 45411, 45408>,
    <45404, 45408, 45412>    <45413, 45421, 45414>,
    <45413, 45414, 45418>    <45413, 45418, 45415>,
    <45413, 45415, 45419>    <45413, 45419, 45416>,
    <45413, 45416, 45420>    <45413, 45420, 45417>,
    <45413, 45417, 45421>    <45422, 45430, 45423>,
    <45422, 45423, 45427>    <45422, 45427, 45424>,
    <45422, 45424, 45428>    <45422, 45428, 45425>,
    <45422, 45425, 45429>    <45422, 45429, 45426>,
    <45422, 45426, 45430>    <45431, 45439, 45432>,
    <45431, 45432, 45436>    <45431, 45436, 45433>,
    <45431, 45433, 45437>    <45431, 45437, 45434>,
    <45431, 45434, 45438>    <45431, 45438, 45435>,
    <45431, 45435, 45439>    <45440, 45448, 45441>,
    <45440, 45441, 45445>    <45440, 45445, 45442>,
    <45440, 45442, 45446>    <45440, 45446, 45443>,
    <45440, 45443, 45447>    <45440, 45447, 45444>,
    <45440, 45444, 45448>    <45449, 45457, 45450>,
    <45449, 45450, 45454>    <45449, 45454, 45451>,
    <45449, 45451, 45455>    <45449, 45455, 45452>,
    <45449, 45452, 45456>    <45449, 45456, 45453>,
    <45449, 45453, 45457>    <45458, 45466, 45459>,
    <45458, 45459, 45463>    <45458, 45463, 45460>,
    <45458, 45460, 45464>    <45458, 45464, 45461>,
    <45458, 45461, 45465>    <45458, 45465, 45462>,
    <45458, 45462, 45466>    <45467, 45475, 45468>,
    <45467, 45468, 45472>    <45467, 45472, 45469>,
    <45467, 45469, 45473>    <45467, 45473, 45470>,
    <45467, 45470, 45474>    <45467, 45474, 45471>,
    <45467, 45471, 45475>    <45476, 45484, 45477>,
    <45476, 45477, 45481>    <45476, 45481, 45478>,
    <45476, 45478, 45482>    <45476, 45482, 45479>,
    <45476, 45479, 45483>    <45476, 45483, 45480>,
    <45476, 45480, 45484>    <45485, 45493, 45486>,
    <45485, 45486, 45490>    <45485, 45490, 45487>,
    <45485, 45487, 45491>    <45485, 45491, 45488>,
    <45485, 45488, 45492>    <45485, 45492, 45489>,
    <45485, 45489, 45493>    <45494, 45502, 45495>,
    <45494, 45495, 45499>    <45494, 45499, 45496>,
    <45494, 45496, 45500>    <45494, 45500, 45497>,
    <45494, 45497, 45501>    <45494, 45501, 45498>,
    <45494, 45498, 45502>    <45503, 45511, 45504>,
    <45503, 45504, 45508>    <45503, 45508, 45505>,
    <45503, 45505, 45509>    <45503, 45509, 45506>,
    <45503, 45506, 45510>    <45503, 45510, 45507>,
    <45503, 45507, 45511>    <45512, 45520, 45513>,
    <45512, 45513, 45517>    <45512, 45517, 45514>,
    <45512, 45514, 45518>    <45512, 45518, 45515>,
    <45512, 45515, 45519>    <45512, 45519, 45516>,
    <45512, 45516, 45520>    <45521, 45529, 45522>,
    <45521, 45522, 45526>    <45521, 45526, 45523>,
    <45521, 45523, 45527>    <45521, 45527, 45524>,
    <45521, 45524, 45528>    <45521, 45528, 45525>,
    <45521, 45525, 45529>    <45530, 45538, 45531>,
    <45530, 45531, 45535>    <45530, 45535, 45532>,
    <45530, 45532, 45536>    <45530, 45536, 45533>,
    <45530, 45533, 45537>    <45530, 45537, 45534>,
    <45530, 45534, 45538>    <45539, 45547, 45540>,
    <45539, 45540, 45544>    <45539, 45544, 45541>,
    <45539, 45541, 45545>    <45539, 45545, 45542>,
    <45539, 45542, 45546>    <45539, 45546, 45543>,
    <45539, 45543, 45547>    <45548, 45556, 45549>,
    <45548, 45549, 45553>    <45548, 45553, 45550>,
    <45548, 45550, 45554>    <45548, 45554, 45551>,
    <45548, 45551, 45555>    <45548, 45555, 45552>,
    <45548, 45552, 45556>    <45557, 45565, 45558>,
    <45557, 45558, 45562>    <45557, 45562, 45559>,
    <45557, 45559, 45563>    <45557, 45563, 45560>,
    <45557, 45560, 45564>    <45557, 45564, 45561>,
    <45557, 45561, 45565>    <45566, 45574, 45567>,
    <45566, 45567, 45571>    <45566, 45571, 45568>,
    <45566, 45568, 45572>    <45566, 45572, 45569>,
    <45566, 45569, 45573>    <45566, 45573, 45570>,
    <45566, 45570, 45574>    <45575, 45583, 45576>,
    <45575, 45576, 45580>    <45575, 45580, 45577>,
    <45575, 45577, 45581>    <45575, 45581, 45578>,
    <45575, 45578, 45582>    <45575, 45582, 45579>,
    <45575, 45579, 45583>    <45584, 45592, 45585>,
    <45584, 45585, 45589>    <45584, 45589, 45586>,
    <45584, 45586, 45590>    <45584, 45590, 45587>,
    <45584, 45587, 45591>    <45584, 45591, 45588>,
    <45584, 45588, 45592>    <45593, 45601, 45594>,
    <45593, 45594, 45598>    <45593, 45598, 45595>,
    <45593, 45595, 45599>    <45593, 45599, 45596>,
    <45593, 45596, 45600>    <45593, 45600, 45597>,
    <45593, 45597, 45601>    <45602, 45610, 45603>,
    <45602, 45603, 45607>    <45602, 45607, 45604>,
    <45602, 45604, 45608>    <45602, 45608, 45605>,
    <45602, 45605, 45609>    <45602, 45609, 45606>,
    <45602, 45606, 45610>    <45611, 45619, 45612>,
    <45611, 45612, 45616>    <45611, 45616, 45613>,
    <45611, 45613, 45617>    <45611, 45617, 45614>,
    <45611, 45614, 45618>    <45611, 45618, 45615>,
    <45611, 45615, 45619>    <45620, 45628, 45621>,
    <45620, 45621, 45625>    <45620, 45625, 45622>,
    <45620, 45622, 45626>    <45620, 45626, 45623>,
    <45620, 45623, 45627>    <45620, 45627, 45624>,
    <45620, 45624, 45628>    <45629, 45637, 45630>,
    <45629, 45630, 45634>    <45629, 45634, 45631>,
    <45629, 45631, 45635>    <45629, 45635, 45632>,
    <45629, 45632, 45636>    <45629, 45636, 45633>,
    <45629, 45633, 45637>    <45638, 45646, 45639>,
    <45638, 45639, 45643>    <45638, 45643, 45640>,
    <45638, 45640, 45644>    <45638, 45644, 45641>,
    <45638, 45641, 45645>    <45638, 45645, 45642>,
    <45638, 45642, 45646>    <45647, 45655, 45648>,
    <45647, 45648, 45652>    <45647, 45652, 45649>,
    <45647, 45649, 45653>    <45647, 45653, 45650>,
    <45647, 45650, 45654>    <45647, 45654, 45651>,
    <45647, 45651, 45655>    <45656, 45664, 45657>,
    <45656, 45657, 45661>    <45656, 45661, 45658>,
    <45656, 45658, 45662>    <45656, 45662, 45659>,
    <45656, 45659, 45663>    <45656, 45663, 45660>,
    <45656, 45660, 45664>    <45665, 45673, 45666>,
    <45665, 45666, 45670>    <45665, 45670, 45667>,
    <45665, 45667, 45671>    <45665, 45671, 45668>,
    <45665, 45668, 45672>    <45665, 45672, 45669>,
    <45665, 45669, 45673>    <45674, 45682, 45675>,
    <45674, 45675, 45679>    <45674, 45679, 45676>,
    <45674, 45676, 45680>    <45674, 45680, 45677>,
    <45674, 45677, 45681>    <45674, 45681, 45678>,
    <45674, 45678, 45682>    <45683, 45691, 45684>,
    <45683, 45684, 45688>    <45683, 45688, 45685>,
    <45683, 45685, 45689>    <45683, 45689, 45686>,
    <45683, 45686, 45690>    <45683, 45690, 45687>,
    <45683, 45687, 45691>    <45692, 45700, 45693>,
    <45692, 45693, 45697>    <45692, 45697, 45694>,
    <45692, 45694, 45698>    <45692, 45698, 45695>,
    <45692, 45695, 45699>    <45692, 45699, 45696>,
    <45692, 45696, 45700>    <45701, 45709, 45702>,
    <45701, 45702, 45706>    <45701, 45706, 45703>,
    <45701, 45703, 45707>    <45701, 45707, 45704>,
    <45701, 45704, 45708>    <45701, 45708, 45705>,
    <45701, 45705, 45709>    <45710, 45718, 45711>,
    <45710, 45711, 45715>    <45710, 45715, 45712>,
    <45710, 45712, 45716>    <45710, 45716, 45713>,
    <45710, 45713, 45717>    <45710, 45717, 45714>,
    <45710, 45714, 45718>    <45719, 45727, 45720>,
    <45719, 45720, 45724>    <45719, 45724, 45721>,
    <45719, 45721, 45725>    <45719, 45725, 45722>,
    <45719, 45722, 45726>    <45719, 45726, 45723>,
    <45719, 45723, 45727>    <45728, 45736, 45729>,
    <45728, 45729, 45733>    <45728, 45733, 45730>,
    <45728, 45730, 45734>    <45728, 45734, 45731>,
    <45728, 45731, 45735>    <45728, 45735, 45732>,
    <45728, 45732, 45736>    <45737, 45745, 45738>,
    <45737, 45738, 45742>    <45737, 45742, 45739>,
    <45737, 45739, 45743>    <45737, 45743, 45740>,
    <45737, 45740, 45744>    <45737, 45744, 45741>,
    <45737, 45741, 45745>    <45746, 45754, 45747>,
    <45746, 45747, 45751>    <45746, 45751, 45748>,
    <45746, 45748, 45752>    <45746, 45752, 45749>,
    <45746, 45749, 45753>    <45746, 45753, 45750>,
    <45746, 45750, 45754>    <45755, 45763, 45756>,
    <45755, 45756, 45760>    <45755, 45760, 45757>,
    <45755, 45757, 45761>    <45755, 45761, 45758>,
    <45755, 45758, 45762>    <45755, 45762, 45759>,
    <45755, 45759, 45763>    <45764, 45772, 45765>,
    <45764, 45765, 45769>    <45764, 45769, 45766>,
    <45764, 45766, 45770>    <45764, 45770, 45767>,
    <45764, 45767, 45771>    <45764, 45771, 45768>,
    <45764, 45768, 45772>    <45773, 45781, 45774>,
    <45773, 45774, 45778>    <45773, 45778, 45775>,
    <45773, 45775, 45779>    <45773, 45779, 45776>,
    <45773, 45776, 45780>    <45773, 45780, 45777>,
    <45773, 45777, 45781>    <45782, 45790, 45783>,
    <45782, 45783, 45787>    <45782, 45787, 45784>,
    <45782, 45784, 45788>    <45782, 45788, 45785>,
    <45782, 45785, 45789>    <45782, 45789, 45786>,
    <45782, 45786, 45790>    <45791, 45799, 45792>,
    <45791, 45792, 45796>    <45791, 45796, 45793>,
    <45791, 45793, 45797>    <45791, 45797, 45794>,
    <45791, 45794, 45798>    <45791, 45798, 45795>,
    <45791, 45795, 45799>    <45800, 45808, 45801>,
    <45800, 45801, 45805>    <45800, 45805, 45802>,
    <45800, 45802, 45806>    <45800, 45806, 45803>,
    <45800, 45803, 45807>    <45800, 45807, 45804>,
    <45800, 45804, 45808>    <45809, 45817, 45810>,
    <45809, 45810, 45814>    <45809, 45814, 45811>,
    <45809, 45811, 45815>    <45809, 45815, 45812>,
    <45809, 45812, 45816>    <45809, 45816, 45813>,
    <45809, 45813, 45817>    <45818, 45826, 45819>,
    <45818, 45819, 45823>    <45818, 45823, 45820>,
    <45818, 45820, 45824>    <45818, 45824, 45821>,
    <45818, 45821, 45825>    <45818, 45825, 45822>,
    <45818, 45822, 45826>    <45827, 45835, 45828>,
    <45827, 45828, 45832>    <45827, 45832, 45829>,
    <45827, 45829, 45833>    <45827, 45833, 45830>,
    <45827, 45830, 45834>    <45827, 45834, 45831>,
    <45827, 45831, 45835>    <45836, 45844, 45837>,
    <45836, 45837, 45841>    <45836, 45841, 45838>,
    <45836, 45838, 45842>    <45836, 45842, 45839>,
    <45836, 45839, 45843>    <45836, 45843, 45840>,
    <45836, 45840, 45844>    <45845, 45853, 45846>,
    <45845, 45846, 45850>    <45845, 45850, 45847>,
    <45845, 45847, 45851>    <45845, 45851, 45848>,
    <45845, 45848, 45852>    <45845, 45852, 45849>,
    <45845, 45849, 45853>    <45854, 45862, 45855>,
    <45854, 45855, 45859>    <45854, 45859, 45856>,
    <45854, 45856, 45860>    <45854, 45860, 45857>,
    <45854, 45857, 45861>    <45854, 45861, 45858>,
    <45854, 45858, 45862>    <45863, 45871, 45864>,
    <45863, 45864, 45868>    <45863, 45868, 45865>,
    <45863, 45865, 45869>    <45863, 45869, 45866>,
    <45863, 45866, 45870>    <45863, 45870, 45867>,
    <45863, 45867, 45871>    <45872, 45880, 45873>,
    <45872, 45873, 45877>    <45872, 45877, 45874>,
    <45872, 45874, 45878>    <45872, 45878, 45875>,
    <45872, 45875, 45879>    <45872, 45879, 45876>,
    <45872, 45876, 45880>    <45881, 45889, 45882>,
    <45881, 45882, 45886>    <45881, 45886, 45883>,
    <45881, 45883, 45887>    <45881, 45887, 45884>,
    <45881, 45884, 45888>    <45881, 45888, 45885>,
    <45881, 45885, 45889>    <45890, 45898, 45891>,
    <45890, 45891, 45895>    <45890, 45895, 45892>,
    <45890, 45892, 45896>    <45890, 45896, 45893>,
    <45890, 45893, 45897>    <45890, 45897, 45894>,
    <45890, 45894, 45898>    <45899, 45907, 45900>,
    <45899, 45900, 45904>    <45899, 45904, 45901>,
    <45899, 45901, 45905>    <45899, 45905, 45902>,
    <45899, 45902, 45906>    <45899, 45906, 45903>,
    <45899, 45903, 45907>    <45908, 45916, 45909>,
    <45908, 45909, 45913>    <45908, 45913, 45910>,
    <45908, 45910, 45914>    <45908, 45914, 45911>,
    <45908, 45911, 45915>    <45908, 45915, 45912>,
    <45908, 45912, 45916>    <45917, 45925, 45918>,
    <45917, 45918, 45922>    <45917, 45922, 45919>,
    <45917, 45919, 45923>    <45917, 45923, 45920>,
    <45917, 45920, 45924>    <45917, 45924, 45921>,
    <45917, 45921, 45925>    <45926, 45934, 45927>,
    <45926, 45927, 45931>    <45926, 45931, 45928>,
    <45926, 45928, 45932>    <45926, 45932, 45929>,
    <45926, 45929, 45933>    <45926, 45933, 45930>,
    <45926, 45930, 45934>    <45935, 45943, 45936>,
    <45935, 45936, 45940>    <45935, 45940, 45937>,
    <45935, 45937, 45941>    <45935, 45941, 45938>,
    <45935, 45938, 45942>    <45935, 45942, 45939>,
    <45935, 45939, 45943>    <45944, 45952, 45945>,
    <45944, 45945, 45949>    <45944, 45949, 45946>,
    <45944, 45946, 45950>    <45944, 45950, 45947>,
    <45944, 45947, 45951>    <45944, 45951, 45948>,
    <45944, 45948, 45952>    <45953, 45961, 45954>,
    <45953, 45954, 45958>    <45953, 45958, 45955>,
    <45953, 45955, 45959>    <45953, 45959, 45956>,
    <45953, 45956, 45960>    <45953, 45960, 45957>,
    <45953, 45957, 45961>    <45962, 45970, 45963>,
    <45962, 45963, 45967>    <45962, 45967, 45964>,
    <45962, 45964, 45968>    <45962, 45968, 45965>,
    <45962, 45965, 45969>    <45962, 45969, 45966>,
    <45962, 45966, 45970>    <45971, 45979, 45972>,
    <45971, 45972, 45976>    <45971, 45976, 45973>,
    <45971, 45973, 45977>    <45971, 45977, 45974>,
    <45971, 45974, 45978>    <45971, 45978, 45975>,
    <45971, 45975, 45979>    <45980, 45988, 45981>,
    <45980, 45981, 45985>    <45980, 45985, 45982>,
    <45980, 45982, 45986>    <45980, 45986, 45983>,
    <45980, 45983, 45987>    <45980, 45987, 45984>,
    <45980, 45984, 45988>    <45989, 45997, 45990>,
    <45989, 45990, 45994>    <45989, 45994, 45991>,
    <45989, 45991, 45995>    <45989, 45995, 45992>,
    <45989, 45992, 45996>    <45989, 45996, 45993>,
    <45989, 45993, 45997>    <45998, 46006, 45999>,
    <45998, 45999, 46003>    <45998, 46003, 46000>,
    <45998, 46000, 46004>    <45998, 46004, 46001>,
    <45998, 46001, 46005>    <45998, 46005, 46002>,
    <45998, 46002, 46006>    <46007, 46015, 46008>,
    <46007, 46008, 46012>    <46007, 46012, 46009>,
    <46007, 46009, 46013>    <46007, 46013, 46010>,
    <46007, 46010, 46014>    <46007, 46014, 46011>,
    <46007, 46011, 46015>    <46016, 46024, 46017>,
    <46016, 46017, 46021>    <46016, 46021, 46018>,
    <46016, 46018, 46022>    <46016, 46022, 46019>,
    <46016, 46019, 46023>    <46016, 46023, 46020>,
    <46016, 46020, 46024>    <46025, 46033, 46026>,
    <46025, 46026, 46030>    <46025, 46030, 46027>,
    <46025, 46027, 46031>    <46025, 46031, 46028>,
    <46025, 46028, 46032>    <46025, 46032, 46029>,
    <46025, 46029, 46033>    <46034, 46042, 46035>,
    <46034, 46035, 46039>    <46034, 46039, 46036>,
    <46034, 46036, 46040>    <46034, 46040, 46037>,
    <46034, 46037, 46041>    <46034, 46041, 46038>,
    <46034, 46038, 46042>    <46043, 46051, 46044>,
    <46043, 46044, 46048>    <46043, 46048, 46045>,
    <46043, 46045, 46049>    <46043, 46049, 46046>,
    <46043, 46046, 46050>    <46043, 46050, 46047>,
    <46043, 46047, 46051>    <46052, 46060, 46053>,
    <46052, 46053, 46057>    <46052, 46057, 46054>,
    <46052, 46054, 46058>    <46052, 46058, 46055>,
    <46052, 46055, 46059>    <46052, 46059, 46056>,
    <46052, 46056, 46060>    <46061, 46069, 46062>,
    <46061, 46062, 46066>    <46061, 46066, 46063>,
    <46061, 46063, 46067>    <46061, 46067, 46064>,
    <46061, 46064, 46068>    <46061, 46068, 46065>,
    <46061, 46065, 46069>    <46070, 46078, 46071>,
    <46070, 46071, 46075>    <46070, 46075, 46072>,
    <46070, 46072, 46076>    <46070, 46076, 46073>,
    <46070, 46073, 46077>    <46070, 46077, 46074>,
    <46070, 46074, 46078>    <46079, 46087, 46080>,
    <46079, 46080, 46084>    <46079, 46084, 46081>,
    <46079, 46081, 46085>    <46079, 46085, 46082>,
    <46079, 46082, 46086>    <46079, 46086, 46083>,
    <46079, 46083, 46087>    <46088, 46096, 46089>,
    <46088, 46089, 46093>    <46088, 46093, 46090>,
    <46088, 46090, 46094>    <46088, 46094, 46091>,
    <46088, 46091, 46095>    <46088, 46095, 46092>,
    <46088, 46092, 46096>    <46097, 46105, 46098>,
    <46097, 46098, 46102>    <46097, 46102, 46099>,
    <46097, 46099, 46103>    <46097, 46103, 46100>,
    <46097, 46100, 46104>    <46097, 46104, 46101>,
    <46097, 46101, 46105>    <46106, 46114, 46107>,
    <46106, 46107, 46111>    <46106, 46111, 46108>,
    <46106, 46108, 46112>    <46106, 46112, 46109>,
    <46106, 46109, 46113>    <46106, 46113, 46110>,
    <46106, 46110, 46114>    <46115, 46123, 46116>,
    <46115, 46116, 46120>    <46115, 46120, 46117>,
    <46115, 46117, 46121>    <46115, 46121, 46118>,
    <46115, 46118, 46122>    <46115, 46122, 46119>,
    <46115, 46119, 46123>    <46124, 46132, 46125>,
    <46124, 46125, 46129>    <46124, 46129, 46126>,
    <46124, 46126, 46130>    <46124, 46130, 46127>,
    <46124, 46127, 46131>    <46124, 46131, 46128>,
    <46124, 46128, 46132>    <46133, 46141, 46134>,
    <46133, 46134, 46138>    <46133, 46138, 46135>,
    <46133, 46135, 46139>    <46133, 46139, 46136>,
    <46133, 46136, 46140>    <46133, 46140, 46137>,
    <46133, 46137, 46141>    <46142, 46150, 46143>,
    <46142, 46143, 46147>    <46142, 46147, 46144>,
    <46142, 46144, 46148>    <46142, 46148, 46145>,
    <46142, 46145, 46149>    <46142, 46149, 46146>,
    <46142, 46146, 46150>    <46151, 46159, 46152>,
    <46151, 46152, 46156>    <46151, 46156, 46153>,
    <46151, 46153, 46157>    <46151, 46157, 46154>,
    <46151, 46154, 46158>    <46151, 46158, 46155>,
    <46151, 46155, 46159>    <46160, 46168, 46161>,
    <46160, 46161, 46165>    <46160, 46165, 46162>,
    <46160, 46162, 46166>    <46160, 46166, 46163>,
    <46160, 46163, 46167>    <46160, 46167, 46164>,
    <46160, 46164, 46168>    <46169, 46177, 46170>,
    <46169, 46170, 46174>    <46169, 46174, 46171>,
    <46169, 46171, 46175>    <46169, 46175, 46172>,
    <46169, 46172, 46176>    <46169, 46176, 46173>,
    <46169, 46173, 46177>    <46178, 46186, 46179>,
    <46178, 46179, 46183>    <46178, 46183, 46180>,
    <46178, 46180, 46184>    <46178, 46184, 46181>,
    <46178, 46181, 46185>    <46178, 46185, 46182>,
    <46178, 46182, 46186>    <46187, 46195, 46188>,
    <46187, 46188, 46192>    <46187, 46192, 46189>,
    <46187, 46189, 46193>    <46187, 46193, 46190>,
    <46187, 46190, 46194>    <46187, 46194, 46191>,
    <46187, 46191, 46195>    <46196, 46204, 46197>,
    <46196, 46197, 46201>    <46196, 46201, 46198>,
    <46196, 46198, 46202>    <46196, 46202, 46199>,
    <46196, 46199, 46203>    <46196, 46203, 46200>,
    <46196, 46200, 46204>    <46205, 46213, 46206>,
    <46205, 46206, 46210>    <46205, 46210, 46207>,
    <46205, 46207, 46211>    <46205, 46211, 46208>,
    <46205, 46208, 46212>    <46205, 46212, 46209>,
    <46205, 46209, 46213>    <46214, 46222, 46215>,
    <46214, 46215, 46219>    <46214, 46219, 46216>,
    <46214, 46216, 46220>    <46214, 46220, 46217>,
    <46214, 46217, 46221>    <46214, 46221, 46218>,
    <46214, 46218, 46222>    <46223, 46231, 46224>,
    <46223, 46224, 46228>    <46223, 46228, 46225>,
    <46223, 46225, 46229>    <46223, 46229, 46226>,
    <46223, 46226, 46230>    <46223, 46230, 46227>,
    <46223, 46227, 46231>    <46232, 46240, 46233>,
    <46232, 46233, 46237>    <46232, 46237, 46234>,
    <46232, 46234, 46238>    <46232, 46238, 46235>,
    <46232, 46235, 46239>    <46232, 46239, 46236>,
    <46232, 46236, 46240>    <46241, 46249, 46242>,
    <46241, 46242, 46246>    <46241, 46246, 46243>,
    <46241, 46243, 46247>    <46241, 46247, 46244>,
    <46241, 46244, 46248>    <46241, 46248, 46245>,
    <46241, 46245, 46249>    <46250, 46258, 46251>,
    <46250, 46251, 46255>    <46250, 46255, 46252>,
    <46250, 46252, 46256>    <46250, 46256, 46253>,
    <46250, 46253, 46257>    <46250, 46257, 46254>,
    <46250, 46254, 46258>    <46259, 46267, 46260>,
    <46259, 46260, 46264>    <46259, 46264, 46261>,
    <46259, 46261, 46265>    <46259, 46265, 46262>,
    <46259, 46262, 46266>    <46259, 46266, 46263>,
    <46259, 46263, 46267>    <46268, 46276, 46269>,
    <46268, 46269, 46273>    <46268, 46273, 46270>,
    <46268, 46270, 46274>    <46268, 46274, 46271>,
    <46268, 46271, 46275>    <46268, 46275, 46272>,
    <46268, 46272, 46276>    <46277, 46285, 46278>,
    <46277, 46278, 46282>    <46277, 46282, 46279>,
    <46277, 46279, 46283>    <46277, 46283, 46280>,
    <46277, 46280, 46284>    <46277, 46284, 46281>,
    <46277, 46281, 46285>    <46286, 46294, 46287>,
    <46286, 46287, 46291>    <46286, 46291, 46288>,
    <46286, 46288, 46292>    <46286, 46292, 46289>,
    <46286, 46289, 46293>    <46286, 46293, 46290>,
    <46286, 46290, 46294>    <46295, 46303, 46296>,
    <46295, 46296, 46300>    <46295, 46300, 46297>,
    <46295, 46297, 46301>    <46295, 46301, 46298>,
    <46295, 46298, 46302>    <46295, 46302, 46299>,
    <46295, 46299, 46303>    <46304, 46312, 46305>,
    <46304, 46305, 46309>    <46304, 46309, 46306>,
    <46304, 46306, 46310>    <46304, 46310, 46307>,
    <46304, 46307, 46311>    <46304, 46311, 46308>,
    <46304, 46308, 46312>    <46313, 46321, 46314>,
    <46313, 46314, 46318>    <46313, 46318, 46315>,
    <46313, 46315, 46319>    <46313, 46319, 46316>,
    <46313, 46316, 46320>    <46313, 46320, 46317>,
    <46313, 46317, 46321>    <46322, 46330, 46323>,
    <46322, 46323, 46327>    <46322, 46327, 46324>,
    <46322, 46324, 46328>    <46322, 46328, 46325>,
    <46322, 46325, 46329>    <46322, 46329, 46326>,
    <46322, 46326, 46330>    <46331, 46339, 46332>,
    <46331, 46332, 46336>    <46331, 46336, 46333>,
    <46331, 46333, 46337>    <46331, 46337, 46334>,
    <46331, 46334, 46338>    <46331, 46338, 46335>,
    <46331, 46335, 46339>    <46340, 46348, 46341>,
    <46340, 46341, 46345>    <46340, 46345, 46342>,
    <46340, 46342, 46346>    <46340, 46346, 46343>,
    <46340, 46343, 46347>    <46340, 46347, 46344>,
    <46340, 46344, 46348>    <46349, 46357, 46350>,
    <46349, 46350, 46354>    <46349, 46354, 46351>,
    <46349, 46351, 46355>    <46349, 46355, 46352>,
    <46349, 46352, 46356>    <46349, 46356, 46353>,
    <46349, 46353, 46357>    <46358, 46366, 46359>,
    <46358, 46359, 46363>    <46358, 46363, 46360>,
    <46358, 46360, 46364>    <46358, 46364, 46361>,
    <46358, 46361, 46365>    <46358, 46365, 46362>,
    <46358, 46362, 46366>    <46367, 46375, 46368>,
    <46367, 46368, 46372>    <46367, 46372, 46369>,
    <46367, 46369, 46373>    <46367, 46373, 46370>,
    <46367, 46370, 46374>    <46367, 46374, 46371>,
    <46367, 46371, 46375>    <46376, 46384, 46377>,
    <46376, 46377, 46381>    <46376, 46381, 46378>,
    <46376, 46378, 46382>    <46376, 46382, 46379>,
    <46376, 46379, 46383>    <46376, 46383, 46380>,
    <46376, 46380, 46384>    <46385, 46393, 46386>,
    <46385, 46386, 46390>    <46385, 46390, 46387>,
    <46385, 46387, 46391>    <46385, 46391, 46388>,
    <46385, 46388, 46392>    <46385, 46392, 46389>,
    <46385, 46389, 46393>    <46394, 46402, 46395>,
    <46394, 46395, 46399>    <46394, 46399, 46396>,
    <46394, 46396, 46400>    <46394, 46400, 46397>,
    <46394, 46397, 46401>    <46394, 46401, 46398>,
    <46394, 46398, 46402>    <46403, 46411, 46404>,
    <46403, 46404, 46408>    <46403, 46408, 46405>,
    <46403, 46405, 46409>    <46403, 46409, 46406>,
    <46403, 46406, 46410>    <46403, 46410, 46407>,
    <46403, 46407, 46411>    <46412, 46420, 46413>,
    <46412, 46413, 46417>    <46412, 46417, 46414>,
    <46412, 46414, 46418>    <46412, 46418, 46415>,
    <46412, 46415, 46419>    <46412, 46419, 46416>,
    <46412, 46416, 46420>    <46421, 46429, 46422>,
    <46421, 46422, 46426>    <46421, 46426, 46423>,
    <46421, 46423, 46427>    <46421, 46427, 46424>,
    <46421, 46424, 46428>    <46421, 46428, 46425>,
    <46421, 46425, 46429>    <46430, 46438, 46431>,
    <46430, 46431, 46435>    <46430, 46435, 46432>,
    <46430, 46432, 46436>    <46430, 46436, 46433>,
    <46430, 46433, 46437>    <46430, 46437, 46434>,
    <46430, 46434, 46438>    <46439, 46447, 46440>,
    <46439, 46440, 46444>    <46439, 46444, 46441>,
    <46439, 46441, 46445>    <46439, 46445, 46442>,
    <46439, 46442, 46446>    <46439, 46446, 46443>,
    <46439, 46443, 46447>    <46448, 46456, 46449>,
    <46448, 46449, 46453>    <46448, 46453, 46450>,
    <46448, 46450, 46454>    <46448, 46454, 46451>,
    <46448, 46451, 46455>    <46448, 46455, 46452>,
    <46448, 46452, 46456>    <46457, 46465, 46458>,
    <46457, 46458, 46462>    <46457, 46462, 46459>,
    <46457, 46459, 46463>    <46457, 46463, 46460>,
    <46457, 46460, 46464>    <46457, 46464, 46461>,
    <46457, 46461, 46465>    <46466, 46474, 46467>,
    <46466, 46467, 46471>    <46466, 46471, 46468>,
    <46466, 46468, 46472>    <46466, 46472, 46469>,
    <46466, 46469, 46473>    <46466, 46473, 46470>,
    <46466, 46470, 46474>    <46475, 46483, 46476>,
    <46475, 46476, 46480>    <46475, 46480, 46477>,
    <46475, 46477, 46481>    <46475, 46481, 46478>,
    <46475, 46478, 46482>    <46475, 46482, 46479>,
    <46475, 46479, 46483>    <46484, 46492, 46485>,
    <46484, 46485, 46489>    <46484, 46489, 46486>,
    <46484, 46486, 46490>    <46484, 46490, 46487>,
    <46484, 46487, 46491>    <46484, 46491, 46488>,
    <46484, 46488, 46492>    <46493, 46501, 46494>,
    <46493, 46494, 46498>    <46493, 46498, 46495>,
    <46493, 46495, 46499>    <46493, 46499, 46496>,
    <46493, 46496, 46500>    <46493, 46500, 46497>,
    <46493, 46497, 46501>    <46502, 46510, 46503>,
    <46502, 46503, 46507>    <46502, 46507, 46504>,
    <46502, 46504, 46508>    <46502, 46508, 46505>,
    <46502, 46505, 46509>    <46502, 46509, 46506>,
    <46502, 46506, 46510>    <46511, 46519, 46512>,
    <46511, 46512, 46516>    <46511, 46516, 46513>,
    <46511, 46513, 46517>    <46511, 46517, 46514>,
    <46511, 46514, 46518>    <46511, 46518, 46515>,
    <46511, 46515, 46519>    <46520, 46528, 46521>,
    <46520, 46521, 46525>    <46520, 46525, 46522>,
    <46520, 46522, 46526>    <46520, 46526, 46523>,
    <46520, 46523, 46527>    <46520, 46527, 46524>,
    <46520, 46524, 46528>    <46529, 46537, 46530>,
    <46529, 46530, 46534>    <46529, 46534, 46531>,
    <46529, 46531, 46535>    <46529, 46535, 46532>,
    <46529, 46532, 46536>    <46529, 46536, 46533>,
    <46529, 46533, 46537>    <46538, 46546, 46539>,
    <46538, 46539, 46543>    <46538, 46543, 46540>,
    <46538, 46540, 46544>    <46538, 46544, 46541>,
    <46538, 46541, 46545>    <46538, 46545, 46542>,
    <46538, 46542, 46546>    <46547, 46555, 46548>,
    <46547, 46548, 46552>    <46547, 46552, 46549>,
    <46547, 46549, 46553>    <46547, 46553, 46550>,
    <46547, 46550, 46554>    <46547, 46554, 46551>,
    <46547, 46551, 46555>    <46556, 46564, 46557>,
    <46556, 46557, 46561>    <46556, 46561, 46558>,
    <46556, 46558, 46562>    <46556, 46562, 46559>,
    <46556, 46559, 46563>    <46556, 46563, 46560>,
    <46556, 46560, 46564>    <46565, 46573, 46566>,
    <46565, 46566, 46570>    <46565, 46570, 46567>,
    <46565, 46567, 46571>    <46565, 46571, 46568>,
    <46565, 46568, 46572>    <46565, 46572, 46569>,
    <46565, 46569, 46573>    <46574, 46582, 46575>,
    <46574, 46575, 46579>    <46574, 46579, 46576>,
    <46574, 46576, 46580>    <46574, 46580, 46577>,
    <46574, 46577, 46581>    <46574, 46581, 46578>,
    <46574, 46578, 46582>    <46583, 46591, 46584>,
    <46583, 46584, 46588>    <46583, 46588, 46585>,
    <46583, 46585, 46589>    <46583, 46589, 46586>,
    <46583, 46586, 46590>    <46583, 46590, 46587>,
    <46583, 46587, 46591>    <46592, 46600, 46593>,
    <46592, 46593, 46597>    <46592, 46597, 46594>,
    <46592, 46594, 46598>    <46592, 46598, 46595>,
    <46592, 46595, 46599>    <46592, 46599, 46596>,
    <46592, 46596, 46600>    <46601, 46609, 46602>,
    <46601, 46602, 46606>    <46601, 46606, 46603>,
    <46601, 46603, 46607>    <46601, 46607, 46604>,
    <46601, 46604, 46608>    <46601, 46608, 46605>,
    <46601, 46605, 46609>    <46610, 46618, 46611>,
    <46610, 46611, 46615>    <46610, 46615, 46612>,
    <46610, 46612, 46616>    <46610, 46616, 46613>,
    <46610, 46613, 46617>    <46610, 46617, 46614>,
    <46610, 46614, 46618>    <46619, 46627, 46620>,
    <46619, 46620, 46624>    <46619, 46624, 46621>,
    <46619, 46621, 46625>    <46619, 46625, 46622>,
    <46619, 46622, 46626>    <46619, 46626, 46623>,
    <46619, 46623, 46627>    <46628, 46636, 46629>,
    <46628, 46629, 46633>    <46628, 46633, 46630>,
    <46628, 46630, 46634>    <46628, 46634, 46631>,
    <46628, 46631, 46635>    <46628, 46635, 46632>,
    <46628, 46632, 46636>    <46637, 46645, 46638>,
    <46637, 46638, 46642>    <46637, 46642, 46639>,
    <46637, 46639, 46643>    <46637, 46643, 46640>,
    <46637, 46640, 46644>    <46637, 46644, 46641>,
    <46637, 46641, 46645>    <46646, 46654, 46647>,
    <46646, 46647, 46651>    <46646, 46651, 46648>,
    <46646, 46648, 46652>    <46646, 46652, 46649>,
    <46646, 46649, 46653>    <46646, 46653, 46650>,
    <46646, 46650, 46654>    <46655, 46663, 46656>,
    <46655, 46656, 46660>    <46655, 46660, 46657>,
    <46655, 46657, 46661>    <46655, 46661, 46658>,
    <46655, 46658, 46662>    <46655, 46662, 46659>,
    <46655, 46659, 46663>    <46664, 46672, 46665>,
    <46664, 46665, 46669>    <46664, 46669, 46666>,
    <46664, 46666, 46670>    <46664, 46670, 46667>,
    <46664, 46667, 46671>    <46664, 46671, 46668>,
    <46664, 46668, 46672>    <46673, 46681, 46674>,
    <46673, 46674, 46678>    <46673, 46678, 46675>,
    <46673, 46675, 46679>    <46673, 46679, 46676>,
    <46673, 46676, 46680>    <46673, 46680, 46677>,
    <46673, 46677, 46681>    <46682, 46690, 46683>,
    <46682, 46683, 46687>    <46682, 46687, 46684>,
    <46682, 46684, 46688>    <46682, 46688, 46685>,
    <46682, 46685, 46689>    <46682, 46689, 46686>,
    <46682, 46686, 46690>    <46691, 46699, 46692>,
    <46691, 46692, 46696>    <46691, 46696, 46693>,
    <46691, 46693, 46697>    <46691, 46697, 46694>,
    <46691, 46694, 46698>    <46691, 46698, 46695>,
    <46691, 46695, 46699>    <46700, 46708, 46701>,
    <46700, 46701, 46705>    <46700, 46705, 46702>,
    <46700, 46702, 46706>    <46700, 46706, 46703>,
    <46700, 46703, 46707>    <46700, 46707, 46704>,
    <46700, 46704, 46708>    <46709, 46717, 46710>,
    <46709, 46710, 46714>    <46709, 46714, 46711>,
    <46709, 46711, 46715>    <46709, 46715, 46712>,
    <46709, 46712, 46716>    <46709, 46716, 46713>,
    <46709, 46713, 46717>    <46718, 46726, 46719>,
    <46718, 46719, 46723>    <46718, 46723, 46720>,
    <46718, 46720, 46724>    <46718, 46724, 46721>,
    <46718, 46721, 46725>    <46718, 46725, 46722>,
    <46718, 46722, 46726>    <46727, 46735, 46728>,
    <46727, 46728, 46732>    <46727, 46732, 46729>,
    <46727, 46729, 46733>    <46727, 46733, 46730>,
    <46727, 46730, 46734>    <46727, 46734, 46731>,
    <46727, 46731, 46735>    <46736, 46744, 46737>,
    <46736, 46737, 46741>    <46736, 46741, 46738>,
    <46736, 46738, 46742>    <46736, 46742, 46739>,
    <46736, 46739, 46743>    <46736, 46743, 46740>,
    <46736, 46740, 46744>    <46745, 46753, 46746>,
    <46745, 46746, 46750>    <46745, 46750, 46747>,
    <46745, 46747, 46751>    <46745, 46751, 46748>,
    <46745, 46748, 46752>    <46745, 46752, 46749>,
    <46745, 46749, 46753>    <46754, 46762, 46755>,
    <46754, 46755, 46759>    <46754, 46759, 46756>,
    <46754, 46756, 46760>    <46754, 46760, 46757>,
    <46754, 46757, 46761>    <46754, 46761, 46758>,
    <46754, 46758, 46762>    <46763, 46771, 46764>,
    <46763, 46764, 46768>    <46763, 46768, 46765>,
    <46763, 46765, 46769>    <46763, 46769, 46766>,
    <46763, 46766, 46770>    <46763, 46770, 46767>,
    <46763, 46767, 46771>    <46772, 46780, 46773>,
    <46772, 46773, 46777>    <46772, 46777, 46774>,
    <46772, 46774, 46778>    <46772, 46778, 46775>,
    <46772, 46775, 46779>    <46772, 46779, 46776>,
    <46772, 46776, 46780>    <46781, 46789, 46782>,
    <46781, 46782, 46786>    <46781, 46786, 46783>,
    <46781, 46783, 46787>    <46781, 46787, 46784>,
    <46781, 46784, 46788>    <46781, 46788, 46785>,
    <46781, 46785, 46789>    <46790, 46798, 46791>,
    <46790, 46791, 46795>    <46790, 46795, 46792>,
    <46790, 46792, 46796>    <46790, 46796, 46793>,
    <46790, 46793, 46797>    <46790, 46797, 46794>,
    <46790, 46794, 46798>    <46799, 46807, 46800>,
    <46799, 46800, 46804>    <46799, 46804, 46801>,
    <46799, 46801, 46805>    <46799, 46805, 46802>,
    <46799, 46802, 46806>    <46799, 46806, 46803>,
    <46799, 46803, 46807>    <46808, 46816, 46809>,
    <46808, 46809, 46813>    <46808, 46813, 46810>,
    <46808, 46810, 46814>    <46808, 46814, 46811>,
    <46808, 46811, 46815>    <46808, 46815, 46812>,
    <46808, 46812, 46816>    <46817, 46825, 46818>,
    <46817, 46818, 46822>    <46817, 46822, 46819>,
    <46817, 46819, 46823>    <46817, 46823, 46820>,
    <46817, 46820, 46824>    <46817, 46824, 46821>,
    <46817, 46821, 46825>    <46826, 46834, 46827>,
    <46826, 46827, 46831>    <46826, 46831, 46828>,
    <46826, 46828, 46832>    <46826, 46832, 46829>,
    <46826, 46829, 46833>    <46826, 46833, 46830>,
    <46826, 46830, 46834>    <46835, 46843, 46836>,
    <46835, 46836, 46840>    <46835, 46840, 46837>,
    <46835, 46837, 46841>    <46835, 46841, 46838>,
    <46835, 46838, 46842>    <46835, 46842, 46839>,
    <46835, 46839, 46843>    <46844, 46852, 46845>,
    <46844, 46845, 46849>    <46844, 46849, 46846>,
    <46844, 46846, 46850>    <46844, 46850, 46847>,
    <46844, 46847, 46851>    <46844, 46851, 46848>,
    <46844, 46848, 46852>    <46853, 46861, 46854>,
    <46853, 46854, 46858>    <46853, 46858, 46855>,
    <46853, 46855, 46859>    <46853, 46859, 46856>,
    <46853, 46856, 46860>    <46853, 46860, 46857>,
    <46853, 46857, 46861>    <46862, 46870, 46863>,
    <46862, 46863, 46867>    <46862, 46867, 46864>,
    <46862, 46864, 46868>    <46862, 46868, 46865>,
    <46862, 46865, 46869>    <46862, 46869, 46866>,
    <46862, 46866, 46870>    <46871, 46879, 46872>,
    <46871, 46872, 46876>    <46871, 46876, 46873>,
    <46871, 46873, 46877>    <46871, 46877, 46874>,
    <46871, 46874, 46878>    <46871, 46878, 46875>,
    <46871, 46875, 46879>    <46880, 46888, 46881>,
    <46880, 46881, 46885>    <46880, 46885, 46882>,
    <46880, 46882, 46886>    <46880, 46886, 46883>,
    <46880, 46883, 46887>    <46880, 46887, 46884>,
    <46880, 46884, 46888>    <46889, 46897, 46890>,
    <46889, 46890, 46894>    <46889, 46894, 46891>,
    <46889, 46891, 46895>    <46889, 46895, 46892>,
    <46889, 46892, 46896>    <46889, 46896, 46893>,
    <46889, 46893, 46897>    <46898, 46906, 46899>,
    <46898, 46899, 46903>    <46898, 46903, 46900>,
    <46898, 46900, 46904>    <46898, 46904, 46901>,
    <46898, 46901, 46905>    <46898, 46905, 46902>,
    <46898, 46902, 46906>    <46907, 46915, 46908>,
    <46907, 46908, 46912>    <46907, 46912, 46909>,
    <46907, 46909, 46913>    <46907, 46913, 46910>,
    <46907, 46910, 46914>    <46907, 46914, 46911>,
    <46907, 46911, 46915>    <46916, 46924, 46917>,
    <46916, 46917, 46921>    <46916, 46921, 46918>,
    <46916, 46918, 46922>    <46916, 46922, 46919>,
    <46916, 46919, 46923>    <46916, 46923, 46920>,
    <46916, 46920, 46924>    <46925, 46933, 46926>,
    <46925, 46926, 46930>    <46925, 46930, 46927>,
    <46925, 46927, 46931>    <46925, 46931, 46928>,
    <46925, 46928, 46932>    <46925, 46932, 46929>,
    <46925, 46929, 46933>    <46934, 46942, 46935>,
    <46934, 46935, 46939>    <46934, 46939, 46936>,
    <46934, 46936, 46940>    <46934, 46940, 46937>,
    <46934, 46937, 46941>    <46934, 46941, 46938>,
    <46934, 46938, 46942>    <46943, 46951, 46944>,
    <46943, 46944, 46948>    <46943, 46948, 46945>,
    <46943, 46945, 46949>    <46943, 46949, 46946>,
    <46943, 46946, 46950>    <46943, 46950, 46947>,
    <46943, 46947, 46951>    <46952, 46960, 46953>,
    <46952, 46953, 46957>    <46952, 46957, 46954>,
    <46952, 46954, 46958>    <46952, 46958, 46955>,
    <46952, 46955, 46959>    <46952, 46959, 46956>,
    <46952, 46956, 46960>    <46961, 46969, 46962>,
    <46961, 46962, 46966>    <46961, 46966, 46963>,
    <46961, 46963, 46967>    <46961, 46967, 46964>,
    <46961, 46964, 46968>    <46961, 46968, 46965>,
    <46961, 46965, 46969>    <46970, 46978, 46971>,
    <46970, 46971, 46975>    <46970, 46975, 46972>,
    <46970, 46972, 46976>    <46970, 46976, 46973>,
    <46970, 46973, 46977>    <46970, 46977, 46974>,
    <46970, 46974, 46978>    <46979, 46987, 46980>,
    <46979, 46980, 46984>    <46979, 46984, 46981>,
    <46979, 46981, 46985>    <46979, 46985, 46982>,
    <46979, 46982, 46986>    <46979, 46986, 46983>,
    <46979, 46983, 46987>    <46988, 46996, 46989>,
    <46988, 46989, 46993>    <46988, 46993, 46990>,
    <46988, 46990, 46994>    <46988, 46994, 46991>,
    <46988, 46991, 46995>    <46988, 46995, 46992>,
    <46988, 46992, 46996>    <46997, 47005, 46998>,
    <46997, 46998, 47002>    <46997, 47002, 46999>,
    <46997, 46999, 47003>    <46997, 47003, 47000>,
    <46997, 47000, 47004>    <46997, 47004, 47001>,
    <46997, 47001, 47005>    <47006, 47014, 47007>,
    <47006, 47007, 47011>    <47006, 47011, 47008>,
    <47006, 47008, 47012>    <47006, 47012, 47009>,
    <47006, 47009, 47013>    <47006, 47013, 47010>,
    <47006, 47010, 47014>    <47015, 47023, 47016>,
    <47015, 47016, 47020>    <47015, 47020, 47017>,
    <47015, 47017, 47021>    <47015, 47021, 47018>,
    <47015, 47018, 47022>    <47015, 47022, 47019>,
    <47015, 47019, 47023>    <47024, 47032, 47025>,
    <47024, 47025, 47029>    <47024, 47029, 47026>,
    <47024, 47026, 47030>    <47024, 47030, 47027>,
    <47024, 47027, 47031>    <47024, 47031, 47028>,
    <47024, 47028, 47032>    <47033, 47041, 47034>,
    <47033, 47034, 47038>    <47033, 47038, 47035>,
    <47033, 47035, 47039>    <47033, 47039, 47036>,
    <47033, 47036, 47040>    <47033, 47040, 47037>,
    <47033, 47037, 47041>    <47042, 47050, 47043>,
    <47042, 47043, 47047>    <47042, 47047, 47044>,
    <47042, 47044, 47048>    <47042, 47048, 47045>,
    <47042, 47045, 47049>    <47042, 47049, 47046>,
    <47042, 47046, 47050>    <47051, 47059, 47052>,
    <47051, 47052, 47056>    <47051, 47056, 47053>,
    <47051, 47053, 47057>    <47051, 47057, 47054>,
    <47051, 47054, 47058>    <47051, 47058, 47055>,
    <47051, 47055, 47059>    <47060, 47068, 47061>,
    <47060, 47061, 47065>    <47060, 47065, 47062>,
    <47060, 47062, 47066>    <47060, 47066, 47063>,
    <47060, 47063, 47067>    <47060, 47067, 47064>,
    <47060, 47064, 47068>    <47069, 47077, 47070>,
    <47069, 47070, 47074>    <47069, 47074, 47071>,
    <47069, 47071, 47075>    <47069, 47075, 47072>,
    <47069, 47072, 47076>    <47069, 47076, 47073>,
    <47069, 47073, 47077>    <47078, 47086, 47079>,
    <47078, 47079, 47083>    <47078, 47083, 47080>,
    <47078, 47080, 47084>    <47078, 47084, 47081>,
    <47078, 47081, 47085>    <47078, 47085, 47082>,
    <47078, 47082, 47086>    <47087, 47095, 47088>,
    <47087, 47088, 47092>    <47087, 47092, 47089>,
    <47087, 47089, 47093>    <47087, 47093, 47090>,
    <47087, 47090, 47094>    <47087, 47094, 47091>,
    <47087, 47091, 47095>    <47096, 47104, 47097>,
    <47096, 47097, 47101>    <47096, 47101, 47098>,
    <47096, 47098, 47102>    <47096, 47102, 47099>,
    <47096, 47099, 47103>    <47096, 47103, 47100>,
    <47096, 47100, 47104>    <47105, 47113, 47106>,
    <47105, 47106, 47110>    <47105, 47110, 47107>,
    <47105, 47107, 47111>    <47105, 47111, 47108>,
    <47105, 47108, 47112>    <47105, 47112, 47109>,
    <47105, 47109, 47113>    <47114, 47122, 47115>,
    <47114, 47115, 47119>    <47114, 47119, 47116>,
    <47114, 47116, 47120>    <47114, 47120, 47117>,
    <47114, 47117, 47121>    <47114, 47121, 47118>,
    <47114, 47118, 47122>    <47123, 47131, 47124>,
    <47123, 47124, 47128>    <47123, 47128, 47125>,
    <47123, 47125, 47129>    <47123, 47129, 47126>,
    <47123, 47126, 47130>    <47123, 47130, 47127>,
    <47123, 47127, 47131>    <47132, 47140, 47133>,
    <47132, 47133, 47137>    <47132, 47137, 47134>,
    <47132, 47134, 47138>    <47132, 47138, 47135>,
    <47132, 47135, 47139>    <47132, 47139, 47136>,
    <47132, 47136, 47140>    <47141, 47149, 47142>,
    <47141, 47142, 47146>    <47141, 47146, 47143>,
    <47141, 47143, 47147>    <47141, 47147, 47144>,
    <47141, 47144, 47148>    <47141, 47148, 47145>,
    <47141, 47145, 47149>    <47150, 47158, 47151>,
    <47150, 47151, 47155>    <47150, 47155, 47152>,
    <47150, 47152, 47156>    <47150, 47156, 47153>,
    <47150, 47153, 47157>    <47150, 47157, 47154>,
    <47150, 47154, 47158>    <47159, 47167, 47160>,
    <47159, 47160, 47164>    <47159, 47164, 47161>,
    <47159, 47161, 47165>    <47159, 47165, 47162>,
    <47159, 47162, 47166>    <47159, 47166, 47163>,
    <47159, 47163, 47167>    <47168, 47176, 47169>,
    <47168, 47169, 47173>    <47168, 47173, 47170>,
    <47168, 47170, 47174>    <47168, 47174, 47171>,
    <47168, 47171, 47175>    <47168, 47175, 47172>,
    <47168, 47172, 47176>    <47177, 47185, 47178>,
    <47177, 47178, 47182>    <47177, 47182, 47179>,
    <47177, 47179, 47183>    <47177, 47183, 47180>,
    <47177, 47180, 47184>    <47177, 47184, 47181>,
    <47177, 47181, 47185>    <47186, 47194, 47187>,
    <47186, 47187, 47191>    <47186, 47191, 47188>,
    <47186, 47188, 47192>    <47186, 47192, 47189>,
    <47186, 47189, 47193>    <47186, 47193, 47190>,
    <47186, 47190, 47194>    <47195, 47203, 47196>,
    <47195, 47196, 47200>    <47195, 47200, 47197>,
    <47195, 47197, 47201>    <47195, 47201, 47198>,
    <47195, 47198, 47202>    <47195, 47202, 47199>,
    <47195, 47199, 47203>    <47204, 47212, 47205>,
    <47204, 47205, 47209>    <47204, 47209, 47206>,
    <47204, 47206, 47210>    <47204, 47210, 47207>,
    <47204, 47207, 47211>    <47204, 47211, 47208>,
    <47204, 47208, 47212>    <47213, 47221, 47214>,
    <47213, 47214, 47218>    <47213, 47218, 47215>,
    <47213, 47215, 47219>    <47213, 47219, 47216>,
    <47213, 47216, 47220>    <47213, 47220, 47217>,
    <47213, 47217, 47221>    <47222, 47230, 47223>,
    <47222, 47223, 47227>    <47222, 47227, 47224>,
    <47222, 47224, 47228>    <47222, 47228, 47225>,
    <47222, 47225, 47229>    <47222, 47229, 47226>,
    <47222, 47226, 47230>    <47231, 47239, 47232>,
    <47231, 47232, 47236>    <47231, 47236, 47233>,
    <47231, 47233, 47237>    <47231, 47237, 47234>,
    <47231, 47234, 47238>    <47231, 47238, 47235>,
    <47231, 47235, 47239>    <47240, 47248, 47241>,
    <47240, 47241, 47245>    <47240, 47245, 47242>,
    <47240, 47242, 47246>    <47240, 47246, 47243>,
    <47240, 47243, 47247>    <47240, 47247, 47244>,
    <47240, 47244, 47248>    <47249, 47257, 47250>,
    <47249, 47250, 47254>    <47249, 47254, 47251>,
    <47249, 47251, 47255>    <47249, 47255, 47252>,
    <47249, 47252, 47256>    <47249, 47256, 47253>,
    <47249, 47253, 47257>    <47258, 47266, 47259>,
    <47258, 47259, 47263>    <47258, 47263, 47260>,
    <47258, 47260, 47264>    <47258, 47264, 47261>,
    <47258, 47261, 47265>    <47258, 47265, 47262>,
    <47258, 47262, 47266>    <47267, 47275, 47268>,
    <47267, 47268, 47272>    <47267, 47272, 47269>,
    <47267, 47269, 47273>    <47267, 47273, 47270>,
    <47267, 47270, 47274>    <47267, 47274, 47271>,
    <47267, 47271, 47275>    <47276, 47284, 47277>,
    <47276, 47277, 47281>    <47276, 47281, 47278>,
    <47276, 47278, 47282>    <47276, 47282, 47279>,
    <47276, 47279, 47283>    <47276, 47283, 47280>,
    <47276, 47280, 47284>    <47285, 47293, 47286>,
    <47285, 47286, 47290>    <47285, 47290, 47287>,
    <47285, 47287, 47291>    <47285, 47291, 47288>,
    <47285, 47288, 47292>    <47285, 47292, 47289>,
    <47285, 47289, 47293>    <47294, 47302, 47295>,
    <47294, 47295, 47299>    <47294, 47299, 47296>,
    <47294, 47296, 47300>    <47294, 47300, 47297>,
    <47294, 47297, 47301>    <47294, 47301, 47298>,
    <47294, 47298, 47302>    <47303, 47311, 47304>,
    <47303, 47304, 47308>    <47303, 47308, 47305>,
    <47303, 47305, 47309>    <47303, 47309, 47306>,
    <47303, 47306, 47310>    <47303, 47310, 47307>,
    <47303, 47307, 47311>    <47312, 47320, 47313>,
    <47312, 47313, 47317>    <47312, 47317, 47314>,
    <47312, 47314, 47318>    <47312, 47318, 47315>,
    <47312, 47315, 47319>    <47312, 47319, 47316>,
    <47312, 47316, 47320>    <47321, 47329, 47322>,
    <47321, 47322, 47326>    <47321, 47326, 47323>,
    <47321, 47323, 47327>    <47321, 47327, 47324>,
    <47321, 47324, 47328>    <47321, 47328, 47325>,
    <47321, 47325, 47329>    <47330, 47338, 47331>,
    <47330, 47331, 47335>    <47330, 47335, 47332>,
    <47330, 47332, 47336>    <47330, 47336, 47333>,
    <47330, 47333, 47337>    <47330, 47337, 47334>,
    <47330, 47334, 47338>    <47339, 47347, 47340>,
    <47339, 47340, 47344>    <47339, 47344, 47341>,
    <47339, 47341, 47345>    <47339, 47345, 47342>,
    <47339, 47342, 47346>    <47339, 47346, 47343>,
    <47339, 47343, 47347>    <47348, 47356, 47349>,
    <47348, 47349, 47353>    <47348, 47353, 47350>,
    <47348, 47350, 47354>    <47348, 47354, 47351>,
    <47348, 47351, 47355>    <47348, 47355, 47352>,
    <47348, 47352, 47356>    <47357, 47365, 47358>,
    <47357, 47358, 47362>    <47357, 47362, 47359>,
    <47357, 47359, 47363>    <47357, 47363, 47360>,
    <47357, 47360, 47364>    <47357, 47364, 47361>,
    <47357, 47361, 47365>    <47366, 47374, 47367>,
    <47366, 47367, 47371>    <47366, 47371, 47368>,
    <47366, 47368, 47372>    <47366, 47372, 47369>,
    <47366, 47369, 47373>    <47366, 47373, 47370>,
    <47366, 47370, 47374>    <47375, 47383, 47376>,
    <47375, 47376, 47380>    <47375, 47380, 47377>,
    <47375, 47377, 47381>    <47375, 47381, 47378>,
    <47375, 47378, 47382>    <47375, 47382, 47379>,
    <47375, 47379, 47383>    <47384, 47392, 47385>,
    <47384, 47385, 47389>    <47384, 47389, 47386>,
    <47384, 47386, 47390>    <47384, 47390, 47387>,
    <47384, 47387, 47391>    <47384, 47391, 47388>,
    <47384, 47388, 47392>    <47393, 47401, 47394>,
    <47393, 47394, 47398>    <47393, 47398, 47395>,
    <47393, 47395, 47399>    <47393, 47399, 47396>,
    <47393, 47396, 47400>    <47393, 47400, 47397>,
    <47393, 47397, 47401>    <47402, 47410, 47403>,
    <47402, 47403, 47407>    <47402, 47407, 47404>,
    <47402, 47404, 47408>    <47402, 47408, 47405>,
    <47402, 47405, 47409>    <47402, 47409, 47406>,
    <47402, 47406, 47410>    <47411, 47419, 47412>,
    <47411, 47412, 47416>    <47411, 47416, 47413>,
    <47411, 47413, 47417>    <47411, 47417, 47414>,
    <47411, 47414, 47418>    <47411, 47418, 47415>,
    <47411, 47415, 47419>    <47420, 47428, 47421>,
    <47420, 47421, 47425>    <47420, 47425, 47422>,
    <47420, 47422, 47426>    <47420, 47426, 47423>,
    <47420, 47423, 47427>    <47420, 47427, 47424>,
    <47420, 47424, 47428>    <47429, 47437, 47430>,
    <47429, 47430, 47434>    <47429, 47434, 47431>,
    <47429, 47431, 47435>    <47429, 47435, 47432>,
    <47429, 47432, 47436>    <47429, 47436, 47433>,
    <47429, 47433, 47437>    <47438, 47446, 47439>,
    <47438, 47439, 47443>    <47438, 47443, 47440>,
    <47438, 47440, 47444>    <47438, 47444, 47441>,
    <47438, 47441, 47445>    <47438, 47445, 47442>,
    <47438, 47442, 47446>    <47447, 47455, 47448>,
    <47447, 47448, 47452>    <47447, 47452, 47449>,
    <47447, 47449, 47453>    <47447, 47453, 47450>,
    <47447, 47450, 47454>    <47447, 47454, 47451>,
    <47447, 47451, 47455>    <47456, 47464, 47457>,
    <47456, 47457, 47461>    <47456, 47461, 47458>,
    <47456, 47458, 47462>    <47456, 47462, 47459>,
    <47456, 47459, 47463>    <47456, 47463, 47460>,
    <47456, 47460, 47464>    <47465, 47473, 47466>,
    <47465, 47466, 47470>    <47465, 47470, 47467>,
    <47465, 47467, 47471>    <47465, 47471, 47468>,
    <47465, 47468, 47472>    <47465, 47472, 47469>,
    <47465, 47469, 47473>    <47474, 47482, 47475>,
    <47474, 47475, 47479>    <47474, 47479, 47476>,
    <47474, 47476, 47480>    <47474, 47480, 47477>,
    <47474, 47477, 47481>    <47474, 47481, 47478>,
    <47474, 47478, 47482>    <47483, 47491, 47484>,
    <47483, 47484, 47488>    <47483, 47488, 47485>,
    <47483, 47485, 47489>    <47483, 47489, 47486>,
    <47483, 47486, 47490>    <47483, 47490, 47487>,
    <47483, 47487, 47491>    <47492, 47500, 47493>,
    <47492, 47493, 47497>    <47492, 47497, 47494>,
    <47492, 47494, 47498>    <47492, 47498, 47495>,
    <47492, 47495, 47499>    <47492, 47499, 47496>,
    <47492, 47496, 47500>    <47501, 47509, 47502>,
    <47501, 47502, 47506>    <47501, 47506, 47503>,
    <47501, 47503, 47507>    <47501, 47507, 47504>,
    <47501, 47504, 47508>    <47501, 47508, 47505>,
    <47501, 47505, 47509>    <47510, 47518, 47511>,
    <47510, 47511, 47515>    <47510, 47515, 47512>,
    <47510, 47512, 47516>    <47510, 47516, 47513>,
    <47510, 47513, 47517>    <47510, 47517, 47514>,
    <47510, 47514, 47518>    <47519, 47527, 47520>,
    <47519, 47520, 47524>    <47519, 47524, 47521>,
    <47519, 47521, 47525>    <47519, 47525, 47522>,
    <47519, 47522, 47526>    <47519, 47526, 47523>,
    <47519, 47523, 47527>    <47528, 47536, 47529>,
    <47528, 47529, 47533>    <47528, 47533, 47530>,
    <47528, 47530, 47534>    <47528, 47534, 47531>,
    <47528, 47531, 47535>    <47528, 47535, 47532>,
    <47528, 47532, 47536>    <47537, 47545, 47538>,
    <47537, 47538, 47542>    <47537, 47542, 47539>,
    <47537, 47539, 47543>    <47537, 47543, 47540>,
    <47537, 47540, 47544>    <47537, 47544, 47541>,
    <47537, 47541, 47545>    <47546, 47554, 47547>,
    <47546, 47547, 47551>    <47546, 47551, 47548>,
    <47546, 47548, 47552>    <47546, 47552, 47549>,
    <47546, 47549, 47553>    <47546, 47553, 47550>,
    <47546, 47550, 47554>    <47555, 47563, 47556>,
    <47555, 47556, 47560>    <47555, 47560, 47557>,
    <47555, 47557, 47561>    <47555, 47561, 47558>,
    <47555, 47558, 47562>    <47555, 47562, 47559>,
    <47555, 47559, 47563>    <47564, 47572, 47565>,
    <47564, 47565, 47569>    <47564, 47569, 47566>,
    <47564, 47566, 47570>    <47564, 47570, 47567>,
    <47564, 47567, 47571>    <47564, 47571, 47568>,
    <47564, 47568, 47572>    <47573, 47581, 47574>,
    <47573, 47574, 47578>    <47573, 47578, 47575>,
    <47573, 47575, 47579>    <47573, 47579, 47576>,
    <47573, 47576, 47580>    <47573, 47580, 47577>,
    <47573, 47577, 47581>    <47582, 47590, 47583>,
    <47582, 47583, 47587>    <47582, 47587, 47584>,
    <47582, 47584, 47588>    <47582, 47588, 47585>,
    <47582, 47585, 47589>    <47582, 47589, 47586>,
    <47582, 47586, 47590>    <47591, 47599, 47592>,
    <47591, 47592, 47596>    <47591, 47596, 47593>,
    <47591, 47593, 47597>    <47591, 47597, 47594>,
    <47591, 47594, 47598>    <47591, 47598, 47595>,
    <47591, 47595, 47599>    <47600, 47608, 47601>,
    <47600, 47601, 47605>    <47600, 47605, 47602>,
    <47600, 47602, 47606>    <47600, 47606, 47603>,
    <47600, 47603, 47607>    <47600, 47607, 47604>,
    <47600, 47604, 47608>    <47609, 47617, 47610>,
    <47609, 47610, 47614>    <47609, 47614, 47611>,
    <47609, 47611, 47615>    <47609, 47615, 47612>,
    <47609, 47612, 47616>    <47609, 47616, 47613>,
    <47609, 47613, 47617>    <47618, 47626, 47619>,
    <47618, 47619, 47623>    <47618, 47623, 47620>,
    <47618, 47620, 47624>    <47618, 47624, 47621>,
    <47618, 47621, 47625>    <47618, 47625, 47622>,
    <47618, 47622, 47626>    <47627, 47635, 47628>,
    <47627, 47628, 47632>    <47627, 47632, 47629>,
    <47627, 47629, 47633>    <47627, 47633, 47630>,
    <47627, 47630, 47634>    <47627, 47634, 47631>,
    <47627, 47631, 47635>    <47636, 47644, 47637>,
    <47636, 47637, 47641>    <47636, 47641, 47638>,
    <47636, 47638, 47642>    <47636, 47642, 47639>,
    <47636, 47639, 47643>    <47636, 47643, 47640>,
    <47636, 47640, 47644>    <47645, 47653, 47646>,
    <47645, 47646, 47650>    <47645, 47650, 47647>,
    <47645, 47647, 47651>    <47645, 47651, 47648>,
    <47645, 47648, 47652>    <47645, 47652, 47649>,
    <47645, 47649, 47653>    <47654, 47662, 47655>,
    <47654, 47655, 47659>    <47654, 47659, 47656>,
    <47654, 47656, 47660>    <47654, 47660, 47657>,
    <47654, 47657, 47661>    <47654, 47661, 47658>,
    <47654, 47658, 47662>    <47663, 47671, 47664>,
    <47663, 47664, 47668>    <47663, 47668, 47665>,
    <47663, 47665, 47669>    <47663, 47669, 47666>,
    <47663, 47666, 47670>    <47663, 47670, 47667>,
    <47663, 47667, 47671>    <47672, 47680, 47673>,
    <47672, 47673, 47677>    <47672, 47677, 47674>,
    <47672, 47674, 47678>    <47672, 47678, 47675>,
    <47672, 47675, 47679>    <47672, 47679, 47676>,
    <47672, 47676, 47680>    <47681, 47689, 47682>,
    <47681, 47682, 47686>    <47681, 47686, 47683>,
    <47681, 47683, 47687>    <47681, 47687, 47684>,
    <47681, 47684, 47688>    <47681, 47688, 47685>,
    <47681, 47685, 47689>    <47690, 47698, 47691>,
    <47690, 47691, 47695>    <47690, 47695, 47692>,
    <47690, 47692, 47696>    <47690, 47696, 47693>,
    <47690, 47693, 47697>    <47690, 47697, 47694>,
    <47690, 47694, 47698>    <47699, 47707, 47700>,
    <47699, 47700, 47704>    <47699, 47704, 47701>,
    <47699, 47701, 47705>    <47699, 47705, 47702>,
    <47699, 47702, 47706>    <47699, 47706, 47703>,
    <47699, 47703, 47707>    <47708, 47716, 47709>,
    <47708, 47709, 47713>    <47708, 47713, 47710>,
    <47708, 47710, 47714>    <47708, 47714, 47711>,
    <47708, 47711, 47715>    <47708, 47715, 47712>,
    <47708, 47712, 47716>    <47717, 47725, 47718>,
    <47717, 47718, 47722>    <47717, 47722, 47719>,
    <47717, 47719, 47723>    <47717, 47723, 47720>,
    <47717, 47720, 47724>    <47717, 47724, 47721>,
    <47717, 47721, 47725>    <47726, 47734, 47727>,
    <47726, 47727, 47731>    <47726, 47731, 47728>,
    <47726, 47728, 47732>    <47726, 47732, 47729>,
    <47726, 47729, 47733>    <47726, 47733, 47730>,
    <47726, 47730, 47734>    <47735, 47743, 47736>,
    <47735, 47736, 47740>    <47735, 47740, 47737>,
    <47735, 47737, 47741>    <47735, 47741, 47738>,
    <47735, 47738, 47742>    <47735, 47742, 47739>,
    <47735, 47739, 47743>    <47744, 47752, 47745>,
    <47744, 47745, 47749>    <47744, 47749, 47746>,
    <47744, 47746, 47750>    <47744, 47750, 47747>,
    <47744, 47747, 47751>    <47744, 47751, 47748>,
    <47744, 47748, 47752>    <47753, 47761, 47754>,
    <47753, 47754, 47758>    <47753, 47758, 47755>,
    <47753, 47755, 47759>    <47753, 47759, 47756>,
    <47753, 47756, 47760>    <47753, 47760, 47757>,
    <47753, 47757, 47761>    <47762, 47770, 47763>,
    <47762, 47763, 47767>    <47762, 47767, 47764>,
    <47762, 47764, 47768>    <47762, 47768, 47765>,
    <47762, 47765, 47769>    <47762, 47769, 47766>,
    <47762, 47766, 47770>    <47771, 47779, 47772>,
    <47771, 47772, 47776>    <47771, 47776, 47773>,
    <47771, 47773, 47777>    <47771, 47777, 47774>,
    <47771, 47774, 47778>    <47771, 47778, 47775>,
    <47771, 47775, 47779>    <47780, 47788, 47781>,
    <47780, 47781, 47785>    <47780, 47785, 47782>,
    <47780, 47782, 47786>    <47780, 47786, 47783>,
    <47780, 47783, 47787>    <47780, 47787, 47784>,
    <47780, 47784, 47788>    <47789, 47797, 47790>,
    <47789, 47790, 47794>    <47789, 47794, 47791>,
    <47789, 47791, 47795>    <47789, 47795, 47792>,
    <47789, 47792, 47796>    <47789, 47796, 47793>,
    <47789, 47793, 47797>    <47798, 47806, 47799>,
    <47798, 47799, 47803>    <47798, 47803, 47800>,
    <47798, 47800, 47804>    <47798, 47804, 47801>,
    <47798, 47801, 47805>    <47798, 47805, 47802>,
    <47798, 47802, 47806>    <47807, 47815, 47808>,
    <47807, 47808, 47812>    <47807, 47812, 47809>,
    <47807, 47809, 47813>    <47807, 47813, 47810>,
    <47807, 47810, 47814>    <47807, 47814, 47811>,
    <47807, 47811, 47815>    <47816, 47824, 47817>,
    <47816, 47817, 47821>    <47816, 47821, 47818>,
    <47816, 47818, 47822>    <47816, 47822, 47819>,
    <47816, 47819, 47823>    <47816, 47823, 47820>,
    <47816, 47820, 47824>    <47825, 47833, 47826>,
    <47825, 47826, 47830>    <47825, 47830, 47827>,
    <47825, 47827, 47831>    <47825, 47831, 47828>,
    <47825, 47828, 47832>    <47825, 47832, 47829>,
    <47825, 47829, 47833>    <47834, 47842, 47835>,
    <47834, 47835, 47839>    <47834, 47839, 47836>,
    <47834, 47836, 47840>    <47834, 47840, 47837>,
    <47834, 47837, 47841>    <47834, 47841, 47838>,
    <47834, 47838, 47842>    <47843, 47851, 47844>,
    <47843, 47844, 47848>    <47843, 47848, 47845>,
    <47843, 47845, 47849>    <47843, 47849, 47846>,
    <47843, 47846, 47850>    <47843, 47850, 47847>,
    <47843, 47847, 47851>    <47852, 47860, 47853>,
    <47852, 47853, 47857>    <47852, 47857, 47854>,
    <47852, 47854, 47858>    <47852, 47858, 47855>,
    <47852, 47855, 47859>    <47852, 47859, 47856>,
    <47852, 47856, 47860>    <47861, 47869, 47862>,
    <47861, 47862, 47866>    <47861, 47866, 47863>,
    <47861, 47863, 47867>    <47861, 47867, 47864>,
    <47861, 47864, 47868>    <47861, 47868, 47865>,
    <47861, 47865, 47869>    <47870, 47878, 47871>,
    <47870, 47871, 47875>    <47870, 47875, 47872>,
    <47870, 47872, 47876>    <47870, 47876, 47873>,
    <47870, 47873, 47877>    <47870, 47877, 47874>,
    <47870, 47874, 47878>    <47879, 47887, 47880>,
    <47879, 47880, 47884>    <47879, 47884, 47881>,
    <47879, 47881, 47885>    <47879, 47885, 47882>,
    <47879, 47882, 47886>    <47879, 47886, 47883>,
    <47879, 47883, 47887>    <47888, 47896, 47889>,
    <47888, 47889, 47893>    <47888, 47893, 47890>,
    <47888, 47890, 47894>    <47888, 47894, 47891>,
    <47888, 47891, 47895>    <47888, 47895, 47892>,
    <47888, 47892, 47896>    <47897, 47905, 47898>,
    <47897, 47898, 47902>    <47897, 47902, 47899>,
    <47897, 47899, 47903>    <47897, 47903, 47900>,
    <47897, 47900, 47904>    <47897, 47904, 47901>,
    <47897, 47901, 47905>    <47906, 47914, 47907>,
    <47906, 47907, 47911>    <47906, 47911, 47908>,
    <47906, 47908, 47912>    <47906, 47912, 47909>,
    <47906, 47909, 47913>    <47906, 47913, 47910>,
    <47906, 47910, 47914>    <47915, 47923, 47916>,
    <47915, 47916, 47920>    <47915, 47920, 47917>,
    <47915, 47917, 47921>    <47915, 47921, 47918>,
    <47915, 47918, 47922>    <47915, 47922, 47919>,
    <47915, 47919, 47923>    <47924, 47932, 47925>,
    <47924, 47925, 47929>    <47924, 47929, 47926>,
    <47924, 47926, 47930>    <47924, 47930, 47927>,
    <47924, 47927, 47931>    <47924, 47931, 47928>,
    <47924, 47928, 47932>    <47933, 47941, 47934>,
    <47933, 47934, 47938>    <47933, 47938, 47935>,
    <47933, 47935, 47939>    <47933, 47939, 47936>,
    <47933, 47936, 47940>    <47933, 47940, 47937>,
    <47933, 47937, 47941>    <47942, 47950, 47943>,
    <47942, 47943, 47947>    <47942, 47947, 47944>,
    <47942, 47944, 47948>    <47942, 47948, 47945>,
    <47942, 47945, 47949>    <47942, 47949, 47946>,
    <47942, 47946, 47950>    <47951, 47959, 47952>,
    <47951, 47952, 47956>    <47951, 47956, 47953>,
    <47951, 47953, 47957>    <47951, 47957, 47954>,
    <47951, 47954, 47958>    <47951, 47958, 47955>,
    <47951, 47955, 47959>    <47960, 47968, 47961>,
    <47960, 47961, 47965>    <47960, 47965, 47962>,
    <47960, 47962, 47966>    <47960, 47966, 47963>,
    <47960, 47963, 47967>    <47960, 47967, 47964>,
    <47960, 47964, 47968>    <47969, 47977, 47970>,
    <47969, 47970, 47974>    <47969, 47974, 47971>,
    <47969, 47971, 47975>    <47969, 47975, 47972>,
    <47969, 47972, 47976>    <47969, 47976, 47973>,
    <47969, 47973, 47977>    <47978, 47986, 47979>,
    <47978, 47979, 47983>    <47978, 47983, 47980>,
    <47978, 47980, 47984>    <47978, 47984, 47981>,
    <47978, 47981, 47985>    <47978, 47985, 47982>,
    <47978, 47982, 47986>    <47987, 47995, 47988>,
    <47987, 47988, 47992>    <47987, 47992, 47989>,
    <47987, 47989, 47993>    <47987, 47993, 47990>,
    <47987, 47990, 47994>    <47987, 47994, 47991>,
    <47987, 47991, 47995>    <47996, 48004, 47997>,
    <47996, 47997, 48001>    <47996, 48001, 47998>,
    <47996, 47998, 48002>    <47996, 48002, 47999>,
    <47996, 47999, 48003>    <47996, 48003, 48000>,
    <47996, 48000, 48004>    <48005, 48013, 48006>,
    <48005, 48006, 48010>    <48005, 48010, 48007>,
    <48005, 48007, 48011>    <48005, 48011, 48008>,
    <48005, 48008, 48012>    <48005, 48012, 48009>,
    <48005, 48009, 48013>    <48014, 48022, 48015>,
    <48014, 48015, 48019>    <48014, 48019, 48016>,
    <48014, 48016, 48020>    <48014, 48020, 48017>,
    <48014, 48017, 48021>    <48014, 48021, 48018>,
    <48014, 48018, 48022>    <48023, 48031, 48024>,
    <48023, 48024, 48028>    <48023, 48028, 48025>,
    <48023, 48025, 48029>    <48023, 48029, 48026>,
    <48023, 48026, 48030>    <48023, 48030, 48027>,
    <48023, 48027, 48031>    <48032, 48040, 48033>,
    <48032, 48033, 48037>    <48032, 48037, 48034>,
    <48032, 48034, 48038>    <48032, 48038, 48035>,
    <48032, 48035, 48039>    <48032, 48039, 48036>,
    <48032, 48036, 48040>    <48041, 48049, 48042>,
    <48041, 48042, 48046>    <48041, 48046, 48043>,
    <48041, 48043, 48047>    <48041, 48047, 48044>,
    <48041, 48044, 48048>    <48041, 48048, 48045>,
    <48041, 48045, 48049>    <48050, 48058, 48051>,
    <48050, 48051, 48055>    <48050, 48055, 48052>,
    <48050, 48052, 48056>    <48050, 48056, 48053>,
    <48050, 48053, 48057>    <48050, 48057, 48054>,
    <48050, 48054, 48058>    <48059, 48067, 48060>,
    <48059, 48060, 48064>    <48059, 48064, 48061>,
    <48059, 48061, 48065>    <48059, 48065, 48062>,
    <48059, 48062, 48066>    <48059, 48066, 48063>,
    <48059, 48063, 48067>    <48068, 48076, 48069>,
    <48068, 48069, 48073>    <48068, 48073, 48070>,
    <48068, 48070, 48074>    <48068, 48074, 48071>,
    <48068, 48071, 48075>    <48068, 48075, 48072>,
    <48068, 48072, 48076>    <48077, 48085, 48078>,
    <48077, 48078, 48082>    <48077, 48082, 48079>,
    <48077, 48079, 48083>    <48077, 48083, 48080>,
    <48077, 48080, 48084>    <48077, 48084, 48081>,
    <48077, 48081, 48085>    <48086, 48094, 48087>,
    <48086, 48087, 48091>    <48086, 48091, 48088>,
    <48086, 48088, 48092>    <48086, 48092, 48089>,
    <48086, 48089, 48093>    <48086, 48093, 48090>,
    <48086, 48090, 48094>    <48095, 48103, 48096>,
    <48095, 48096, 48100>    <48095, 48100, 48097>,
    <48095, 48097, 48101>    <48095, 48101, 48098>,
    <48095, 48098, 48102>    <48095, 48102, 48099>,
    <48095, 48099, 48103>    <48104, 48112, 48105>,
    <48104, 48105, 48109>    <48104, 48109, 48106>,
    <48104, 48106, 48110>    <48104, 48110, 48107>,
    <48104, 48107, 48111>    <48104, 48111, 48108>,
    <48104, 48108, 48112>    <48113, 48121, 48114>,
    <48113, 48114, 48118>    <48113, 48118, 48115>,
    <48113, 48115, 48119>    <48113, 48119, 48116>,
    <48113, 48116, 48120>    <48113, 48120, 48117>,
    <48113, 48117, 48121>    <48122, 48130, 48123>,
    <48122, 48123, 48127>    <48122, 48127, 48124>,
    <48122, 48124, 48128>    <48122, 48128, 48125>,
    <48122, 48125, 48129>    <48122, 48129, 48126>,
    <48122, 48126, 48130>    <48131, 48139, 48132>,
    <48131, 48132, 48136>    <48131, 48136, 48133>,
    <48131, 48133, 48137>    <48131, 48137, 48134>,
    <48131, 48134, 48138>    <48131, 48138, 48135>,
    <48131, 48135, 48139>    <48140, 48148, 48141>,
    <48140, 48141, 48145>    <48140, 48145, 48142>,
    <48140, 48142, 48146>    <48140, 48146, 48143>,
    <48140, 48143, 48147>    <48140, 48147, 48144>,
    <48140, 48144, 48148>    <48149, 48157, 48150>,
    <48149, 48150, 48154>    <48149, 48154, 48151>,
    <48149, 48151, 48155>    <48149, 48155, 48152>,
    <48149, 48152, 48156>    <48149, 48156, 48153>,
    <48149, 48153, 48157>    <48158, 48166, 48159>,
    <48158, 48159, 48163>    <48158, 48163, 48160>,
    <48158, 48160, 48164>    <48158, 48164, 48161>,
    <48158, 48161, 48165>    <48158, 48165, 48162>,
    <48158, 48162, 48166>    <48167, 48175, 48168>,
    <48167, 48168, 48172>    <48167, 48172, 48169>,
    <48167, 48169, 48173>    <48167, 48173, 48170>,
    <48167, 48170, 48174>    <48167, 48174, 48171>,
    <48167, 48171, 48175>    <48176, 48184, 48177>,
    <48176, 48177, 48181>    <48176, 48181, 48178>,
    <48176, 48178, 48182>    <48176, 48182, 48179>,
    <48176, 48179, 48183>    <48176, 48183, 48180>,
    <48176, 48180, 48184>    <48185, 48193, 48186>,
    <48185, 48186, 48190>    <48185, 48190, 48187>,
    <48185, 48187, 48191>    <48185, 48191, 48188>,
    <48185, 48188, 48192>    <48185, 48192, 48189>,
    <48185, 48189, 48193>    <48194, 48202, 48195>,
    <48194, 48195, 48199>    <48194, 48199, 48196>,
    <48194, 48196, 48200>    <48194, 48200, 48197>,
    <48194, 48197, 48201>    <48194, 48201, 48198>,
    <48194, 48198, 48202>    <48203, 48211, 48204>,
    <48203, 48204, 48208>    <48203, 48208, 48205>,
    <48203, 48205, 48209>    <48203, 48209, 48206>,
    <48203, 48206, 48210>    <48203, 48210, 48207>,
    <48203, 48207, 48211>    <48212, 48220, 48213>,
    <48212, 48213, 48217>    <48212, 48217, 48214>,
    <48212, 48214, 48218>    <48212, 48218, 48215>,
    <48212, 48215, 48219>    <48212, 48219, 48216>,
    <48212, 48216, 48220>    <48221, 48229, 48222>,
    <48221, 48222, 48226>    <48221, 48226, 48223>,
    <48221, 48223, 48227>    <48221, 48227, 48224>,
    <48221, 48224, 48228>    <48221, 48228, 48225>,
    <48221, 48225, 48229>    <48230, 48238, 48231>,
    <48230, 48231, 48235>    <48230, 48235, 48232>,
    <48230, 48232, 48236>    <48230, 48236, 48233>,
    <48230, 48233, 48237>    <48230, 48237, 48234>,
    <48230, 48234, 48238>    <48239, 48247, 48240>,
    <48239, 48240, 48244>    <48239, 48244, 48241>,
    <48239, 48241, 48245>    <48239, 48245, 48242>,
    <48239, 48242, 48246>    <48239, 48246, 48243>,
    <48239, 48243, 48247>    <48248, 48256, 48249>,
    <48248, 48249, 48253>    <48248, 48253, 48250>,
    <48248, 48250, 48254>    <48248, 48254, 48251>,
    <48248, 48251, 48255>    <48248, 48255, 48252>,
    <48248, 48252, 48256>    <48257, 48265, 48258>,
    <48257, 48258, 48262>    <48257, 48262, 48259>,
    <48257, 48259, 48263>    <48257, 48263, 48260>,
    <48257, 48260, 48264>    <48257, 48264, 48261>,
    <48257, 48261, 48265>    <48266, 48274, 48267>,
    <48266, 48267, 48271>    <48266, 48271, 48268>,
    <48266, 48268, 48272>    <48266, 48272, 48269>,
    <48266, 48269, 48273>    <48266, 48273, 48270>,
    <48266, 48270, 48274>    <48275, 48283, 48276>,
    <48275, 48276, 48280>    <48275, 48280, 48277>,
    <48275, 48277, 48281>    <48275, 48281, 48278>,
    <48275, 48278, 48282>    <48275, 48282, 48279>,
    <48275, 48279, 48283>    <48284, 48292, 48285>,
    <48284, 48285, 48289>    <48284, 48289, 48286>,
    <48284, 48286, 48290>    <48284, 48290, 48287>,
    <48284, 48287, 48291>    <48284, 48291, 48288>,
    <48284, 48288, 48292>    <48293, 48301, 48294>,
    <48293, 48294, 48298>    <48293, 48298, 48295>,
    <48293, 48295, 48299>    <48293, 48299, 48296>,
    <48293, 48296, 48300>    <48293, 48300, 48297>,
    <48293, 48297, 48301>    <48302, 48310, 48303>,
    <48302, 48303, 48307>    <48302, 48307, 48304>,
    <48302, 48304, 48308>    <48302, 48308, 48305>,
    <48302, 48305, 48309>    <48302, 48309, 48306>,
    <48302, 48306, 48310>    <48311, 48319, 48312>,
    <48311, 48312, 48316>    <48311, 48316, 48313>,
    <48311, 48313, 48317>    <48311, 48317, 48314>,
    <48311, 48314, 48318>    <48311, 48318, 48315>,
    <48311, 48315, 48319>    <48320, 48328, 48321>,
    <48320, 48321, 48325>    <48320, 48325, 48322>,
    <48320, 48322, 48326>    <48320, 48326, 48323>,
    <48320, 48323, 48327>    <48320, 48327, 48324>,
    <48320, 48324, 48328>    <48329, 48337, 48330>,
    <48329, 48330, 48334>    <48329, 48334, 48331>,
    <48329, 48331, 48335>    <48329, 48335, 48332>,
    <48329, 48332, 48336>    <48329, 48336, 48333>,
    <48329, 48333, 48337>    <48338, 48346, 48339>,
    <48338, 48339, 48343>    <48338, 48343, 48340>,
    <48338, 48340, 48344>    <48338, 48344, 48341>,
    <48338, 48341, 48345>    <48338, 48345, 48342>,
    <48338, 48342, 48346>    <48347, 48355, 48348>,
    <48347, 48348, 48352>    <48347, 48352, 48349>,
    <48347, 48349, 48353>    <48347, 48353, 48350>,
    <48347, 48350, 48354>    <48347, 48354, 48351>,
    <48347, 48351, 48355>    <48356, 48364, 48357>,
    <48356, 48357, 48361>    <48356, 48361, 48358>,
    <48356, 48358, 48362>    <48356, 48362, 48359>,
    <48356, 48359, 48363>    <48356, 48363, 48360>,
    <48356, 48360, 48364>    <48365, 48373, 48366>,
    <48365, 48366, 48370>    <48365, 48370, 48367>,
    <48365, 48367, 48371>    <48365, 48371, 48368>,
    <48365, 48368, 48372>    <48365, 48372, 48369>,
    <48365, 48369, 48373>    <48374, 48382, 48375>,
    <48374, 48375, 48379>    <48374, 48379, 48376>,
    <48374, 48376, 48380>    <48374, 48380, 48377>,
    <48374, 48377, 48381>    <48374, 48381, 48378>,
    <48374, 48378, 48382>    <48383, 48391, 48384>,
    <48383, 48384, 48388>    <48383, 48388, 48385>,
    <48383, 48385, 48389>    <48383, 48389, 48386>,
    <48383, 48386, 48390>    <48383, 48390, 48387>,
    <48383, 48387, 48391>    <48392, 48400, 48393>,
    <48392, 48393, 48397>    <48392, 48397, 48394>,
    <48392, 48394, 48398>    <48392, 48398, 48395>,
    <48392, 48395, 48399>    <48392, 48399, 48396>,
    <48392, 48396, 48400>    <48401, 48409, 48402>,
    <48401, 48402, 48406>    <48401, 48406, 48403>,
    <48401, 48403, 48407>    <48401, 48407, 48404>,
    <48401, 48404, 48408>    <48401, 48408, 48405>,
    <48401, 48405, 48409>    <48410, 48418, 48411>,
    <48410, 48411, 48415>    <48410, 48415, 48412>,
    <48410, 48412, 48416>    <48410, 48416, 48413>,
    <48410, 48413, 48417>    <48410, 48417, 48414>,
    <48410, 48414, 48418>    <48419, 48427, 48420>,
    <48419, 48420, 48424>    <48419, 48424, 48421>,
    <48419, 48421, 48425>    <48419, 48425, 48422>,
    <48419, 48422, 48426>    <48419, 48426, 48423>,
    <48419, 48423, 48427>    <48428, 48436, 48429>,
    <48428, 48429, 48433>    <48428, 48433, 48430>,
    <48428, 48430, 48434>    <48428, 48434, 48431>,
    <48428, 48431, 48435>    <48428, 48435, 48432>,
    <48428, 48432, 48436>    <48437, 48445, 48438>,
    <48437, 48438, 48442>    <48437, 48442, 48439>,
    <48437, 48439, 48443>    <48437, 48443, 48440>,
    <48437, 48440, 48444>    <48437, 48444, 48441>,
    <48437, 48441, 48445>    <48446, 48454, 48447>,
    <48446, 48447, 48451>    <48446, 48451, 48448>,
    <48446, 48448, 48452>    <48446, 48452, 48449>,
    <48446, 48449, 48453>    <48446, 48453, 48450>,
    <48446, 48450, 48454>    <48455, 48463, 48456>,
    <48455, 48456, 48460>    <48455, 48460, 48457>,
    <48455, 48457, 48461>    <48455, 48461, 48458>,
    <48455, 48458, 48462>    <48455, 48462, 48459>,
    <48455, 48459, 48463>    <48464, 48472, 48465>,
    <48464, 48465, 48469>    <48464, 48469, 48466>,
    <48464, 48466, 48470>    <48464, 48470, 48467>,
    <48464, 48467, 48471>    <48464, 48471, 48468>,
    <48464, 48468, 48472>    <48473, 48481, 48474>,
    <48473, 48474, 48478>    <48473, 48478, 48475>,
    <48473, 48475, 48479>    <48473, 48479, 48476>,
    <48473, 48476, 48480>    <48473, 48480, 48477>,
    <48473, 48477, 48481>    <48482, 48490, 48483>,
    <48482, 48483, 48487>    <48482, 48487, 48484>,
    <48482, 48484, 48488>    <48482, 48488, 48485>,
    <48482, 48485, 48489>    <48482, 48489, 48486>,
    <48482, 48486, 48490>    <48491, 48499, 48492>,
    <48491, 48492, 48496>    <48491, 48496, 48493>,
    <48491, 48493, 48497>    <48491, 48497, 48494>,
    <48491, 48494, 48498>    <48491, 48498, 48495>,
    <48491, 48495, 48499>    <48500, 48508, 48501>,
    <48500, 48501, 48505>    <48500, 48505, 48502>,
    <48500, 48502, 48506>    <48500, 48506, 48503>,
    <48500, 48503, 48507>    <48500, 48507, 48504>,
    <48500, 48504, 48508>    <48509, 48517, 48510>,
    <48509, 48510, 48514>    <48509, 48514, 48511>,
    <48509, 48511, 48515>    <48509, 48515, 48512>,
    <48509, 48512, 48516>    <48509, 48516, 48513>,
    <48509, 48513, 48517>    <48518, 48526, 48519>,
    <48518, 48519, 48523>    <48518, 48523, 48520>,
    <48518, 48520, 48524>    <48518, 48524, 48521>,
    <48518, 48521, 48525>    <48518, 48525, 48522>,
    <48518, 48522, 48526>    <48527, 48535, 48528>,
    <48527, 48528, 48532>    <48527, 48532, 48529>,
    <48527, 48529, 48533>    <48527, 48533, 48530>,
    <48527, 48530, 48534>    <48527, 48534, 48531>,
    <48527, 48531, 48535>    <48536, 48544, 48537>,
    <48536, 48537, 48541>    <48536, 48541, 48538>,
    <48536, 48538, 48542>    <48536, 48542, 48539>,
    <48536, 48539, 48543>    <48536, 48543, 48540>,
    <48536, 48540, 48544>    <48545, 48553, 48546>,
    <48545, 48546, 48550>    <48545, 48550, 48547>,
    <48545, 48547, 48551>    <48545, 48551, 48548>,
    <48545, 48548, 48552>    <48545, 48552, 48549>,
    <48545, 48549, 48553>    <48554, 48562, 48555>,
    <48554, 48555, 48559>    <48554, 48559, 48556>,
    <48554, 48556, 48560>    <48554, 48560, 48557>,
    <48554, 48557, 48561>    <48554, 48561, 48558>,
    <48554, 48558, 48562>    <48563, 48571, 48564>,
    <48563, 48564, 48568>    <48563, 48568, 48565>,
    <48563, 48565, 48569>    <48563, 48569, 48566>,
    <48563, 48566, 48570>    <48563, 48570, 48567>,
    <48563, 48567, 48571>    <48572, 48580, 48573>,
    <48572, 48573, 48577>    <48572, 48577, 48574>,
    <48572, 48574, 48578>    <48572, 48578, 48575>,
    <48572, 48575, 48579>    <48572, 48579, 48576>,
    <48572, 48576, 48580>    <48581, 48589, 48582>,
    <48581, 48582, 48586>    <48581, 48586, 48583>,
    <48581, 48583, 48587>    <48581, 48587, 48584>,
    <48581, 48584, 48588>    <48581, 48588, 48585>,
    <48581, 48585, 48589>    <48590, 48598, 48591>,
    <48590, 48591, 48595>    <48590, 48595, 48592>,
    <48590, 48592, 48596>    <48590, 48596, 48593>,
    <48590, 48593, 48597>    <48590, 48597, 48594>,
    <48590, 48594, 48598>    <48599, 48607, 48600>,
    <48599, 48600, 48604>    <48599, 48604, 48601>,
    <48599, 48601, 48605>    <48599, 48605, 48602>,
    <48599, 48602, 48606>    <48599, 48606, 48603>,
    <48599, 48603, 48607>    <48608, 48616, 48609>,
    <48608, 48609, 48613>    <48608, 48613, 48610>,
    <48608, 48610, 48614>    <48608, 48614, 48611>,
    <48608, 48611, 48615>    <48608, 48615, 48612>,
    <48608, 48612, 48616>    <48617, 48625, 48618>,
    <48617, 48618, 48622>    <48617, 48622, 48619>,
    <48617, 48619, 48623>    <48617, 48623, 48620>,
    <48617, 48620, 48624>    <48617, 48624, 48621>,
    <48617, 48621, 48625>    <48626, 48634, 48627>,
    <48626, 48627, 48631>    <48626, 48631, 48628>,
    <48626, 48628, 48632>    <48626, 48632, 48629>,
    <48626, 48629, 48633>    <48626, 48633, 48630>,
    <48626, 48630, 48634>    <48635, 48643, 48636>,
    <48635, 48636, 48640>    <48635, 48640, 48637>,
    <48635, 48637, 48641>    <48635, 48641, 48638>,
    <48635, 48638, 48642>    <48635, 48642, 48639>,
    <48635, 48639, 48643>    <48644, 48652, 48645>,
    <48644, 48645, 48649>    <48644, 48649, 48646>,
    <48644, 48646, 48650>    <48644, 48650, 48647>,
    <48644, 48647, 48651>    <48644, 48651, 48648>,
    <48644, 48648, 48652>    <48653, 48661, 48654>,
    <48653, 48654, 48658>    <48653, 48658, 48655>,
    <48653, 48655, 48659>    <48653, 48659, 48656>,
    <48653, 48656, 48660>    <48653, 48660, 48657>,
    <48653, 48657, 48661>    <48662, 48670, 48663>,
    <48662, 48663, 48667>    <48662, 48667, 48664>,
    <48662, 48664, 48668>    <48662, 48668, 48665>,
    <48662, 48665, 48669>    <48662, 48669, 48666>,
    <48662, 48666, 48670>    <48671, 48679, 48672>,
    <48671, 48672, 48676>    <48671, 48676, 48673>,
    <48671, 48673, 48677>    <48671, 48677, 48674>,
    <48671, 48674, 48678>    <48671, 48678, 48675>,
    <48671, 48675, 48679>    <48680, 48688, 48681>,
    <48680, 48681, 48685>    <48680, 48685, 48682>,
    <48680, 48682, 48686>    <48680, 48686, 48683>,
    <48680, 48683, 48687>    <48680, 48687, 48684>,
    <48680, 48684, 48688>    <48689, 48697, 48690>,
    <48689, 48690, 48694>    <48689, 48694, 48691>,
    <48689, 48691, 48695>    <48689, 48695, 48692>,
    <48689, 48692, 48696>    <48689, 48696, 48693>,
    <48689, 48693, 48697>    <48698, 48706, 48699>,
    <48698, 48699, 48703>    <48698, 48703, 48700>,
    <48698, 48700, 48704>    <48698, 48704, 48701>,
    <48698, 48701, 48705>    <48698, 48705, 48702>,
    <48698, 48702, 48706>    <48707, 48715, 48708>,
    <48707, 48708, 48712>    <48707, 48712, 48709>,
    <48707, 48709, 48713>    <48707, 48713, 48710>,
    <48707, 48710, 48714>    <48707, 48714, 48711>,
    <48707, 48711, 48715>    <48716, 48724, 48717>,
    <48716, 48717, 48721>    <48716, 48721, 48718>,
    <48716, 48718, 48722>    <48716, 48722, 48719>,
    <48716, 48719, 48723>    <48716, 48723, 48720>,
    <48716, 48720, 48724>    <48725, 48733, 48726>,
    <48725, 48726, 48730>    <48725, 48730, 48727>,
    <48725, 48727, 48731>    <48725, 48731, 48728>,
    <48725, 48728, 48732>    <48725, 48732, 48729>,
    <48725, 48729, 48733>    <48734, 48742, 48735>,
    <48734, 48735, 48739>    <48734, 48739, 48736>,
    <48734, 48736, 48740>    <48734, 48740, 48737>,
    <48734, 48737, 48741>    <48734, 48741, 48738>,
    <48734, 48738, 48742>    <48743, 48751, 48744>,
    <48743, 48744, 48748>    <48743, 48748, 48745>,
    <48743, 48745, 48749>    <48743, 48749, 48746>,
    <48743, 48746, 48750>    <48743, 48750, 48747>,
    <48743, 48747, 48751>    <48752, 48760, 48753>,
    <48752, 48753, 48757>    <48752, 48757, 48754>,
    <48752, 48754, 48758>    <48752, 48758, 48755>,
    <48752, 48755, 48759>    <48752, 48759, 48756>,
    <48752, 48756, 48760>    <48761, 48769, 48762>,
    <48761, 48762, 48766>    <48761, 48766, 48763>,
    <48761, 48763, 48767>    <48761, 48767, 48764>,
    <48761, 48764, 48768>    <48761, 48768, 48765>,
    <48761, 48765, 48769>    <48770, 48778, 48771>,
    <48770, 48771, 48775>    <48770, 48775, 48772>,
    <48770, 48772, 48776>    <48770, 48776, 48773>,
    <48770, 48773, 48777>    <48770, 48777, 48774>,
    <48770, 48774, 48778>    <48779, 48787, 48780>,
    <48779, 48780, 48784>    <48779, 48784, 48781>,
    <48779, 48781, 48785>    <48779, 48785, 48782>,
    <48779, 48782, 48786>    <48779, 48786, 48783>,
    <48779, 48783, 48787>    <48788, 48796, 48789>,
    <48788, 48789, 48793>    <48788, 48793, 48790>,
    <48788, 48790, 48794>    <48788, 48794, 48791>,
    <48788, 48791, 48795>    <48788, 48795, 48792>,
    <48788, 48792, 48796>    <48797, 48805, 48798>,
    <48797, 48798, 48802>    <48797, 48802, 48799>,
    <48797, 48799, 48803>    <48797, 48803, 48800>,
    <48797, 48800, 48804>    <48797, 48804, 48801>,
    <48797, 48801, 48805>    <48806, 48814, 48807>,
    <48806, 48807, 48811>    <48806, 48811, 48808>,
    <48806, 48808, 48812>    <48806, 48812, 48809>,
    <48806, 48809, 48813>    <48806, 48813, 48810>,
    <48806, 48810, 48814>    <48815, 48823, 48816>,
    <48815, 48816, 48820>    <48815, 48820, 48817>,
    <48815, 48817, 48821>    <48815, 48821, 48818>,
    <48815, 48818, 48822>    <48815, 48822, 48819>,
    <48815, 48819, 48823>    <48824, 48832, 48825>,
    <48824, 48825, 48829>    <48824, 48829, 48826>,
    <48824, 48826, 48830>    <48824, 48830, 48827>,
    <48824, 48827, 48831>    <48824, 48831, 48828>,
    <48824, 48828, 48832>    <48833, 48841, 48834>,
    <48833, 48834, 48838>    <48833, 48838, 48835>,
    <48833, 48835, 48839>    <48833, 48839, 48836>,
    <48833, 48836, 48840>    <48833, 48840, 48837>,
    <48833, 48837, 48841>    <48842, 48850, 48843>,
    <48842, 48843, 48847>    <48842, 48847, 48844>,
    <48842, 48844, 48848>    <48842, 48848, 48845>,
    <48842, 48845, 48849>    <48842, 48849, 48846>,
    <48842, 48846, 48850>    <48851, 48859, 48852>,
    <48851, 48852, 48856>    <48851, 48856, 48853>,
    <48851, 48853, 48857>    <48851, 48857, 48854>,
    <48851, 48854, 48858>    <48851, 48858, 48855>,
    <48851, 48855, 48859>    <48860, 48868, 48861>,
    <48860, 48861, 48865>    <48860, 48865, 48862>,
    <48860, 48862, 48866>    <48860, 48866, 48863>,
    <48860, 48863, 48867>    <48860, 48867, 48864>,
    <48860, 48864, 48868>    <48869, 48877, 48870>,
    <48869, 48870, 48874>    <48869, 48874, 48871>,
    <48869, 48871, 48875>    <48869, 48875, 48872>,
    <48869, 48872, 48876>    <48869, 48876, 48873>,
    <48869, 48873, 48877>    <48878, 48886, 48879>,
    <48878, 48879, 48883>    <48878, 48883, 48880>,
    <48878, 48880, 48884>    <48878, 48884, 48881>,
    <48878, 48881, 48885>    <48878, 48885, 48882>,
    <48878, 48882, 48886>    <48887, 48895, 48888>,
    <48887, 48888, 48892>    <48887, 48892, 48889>,
    <48887, 48889, 48893>    <48887, 48893, 48890>,
    <48887, 48890, 48894>    <48887, 48894, 48891>,
    <48887, 48891, 48895>    <48896, 48904, 48897>,
    <48896, 48897, 48901>    <48896, 48901, 48898>,
    <48896, 48898, 48902>    <48896, 48902, 48899>,
    <48896, 48899, 48903>    <48896, 48903, 48900>,
    <48896, 48900, 48904>    <48905, 48913, 48906>,
    <48905, 48906, 48910>    <48905, 48910, 48907>,
    <48905, 48907, 48911>    <48905, 48911, 48908>,
    <48905, 48908, 48912>    <48905, 48912, 48909>,
    <48905, 48909, 48913>    <48914, 48922, 48915>,
    <48914, 48915, 48919>    <48914, 48919, 48916>,
    <48914, 48916, 48920>    <48914, 48920, 48917>,
    <48914, 48917, 48921>    <48914, 48921, 48918>,
    <48914, 48918, 48922>    <48923, 48931, 48924>,
    <48923, 48924, 48928>    <48923, 48928, 48925>,
    <48923, 48925, 48929>    <48923, 48929, 48926>,
    <48923, 48926, 48930>    <48923, 48930, 48927>,
    <48923, 48927, 48931>    <48932, 48940, 48933>,
    <48932, 48933, 48937>    <48932, 48937, 48934>,
    <48932, 48934, 48938>    <48932, 48938, 48935>,
    <48932, 48935, 48939>    <48932, 48939, 48936>,
    <48932, 48936, 48940>    <48941, 48949, 48942>,
    <48941, 48942, 48946>    <48941, 48946, 48943>,
    <48941, 48943, 48947>    <48941, 48947, 48944>,
    <48941, 48944, 48948>    <48941, 48948, 48945>,
    <48941, 48945, 48949>    <48950, 48958, 48951>,
    <48950, 48951, 48955>    <48950, 48955, 48952>,
    <48950, 48952, 48956>    <48950, 48956, 48953>,
    <48950, 48953, 48957>    <48950, 48957, 48954>,
    <48950, 48954, 48958>    <48959, 48967, 48960>,
    <48959, 48960, 48964>    <48959, 48964, 48961>,
    <48959, 48961, 48965>    <48959, 48965, 48962>,
    <48959, 48962, 48966>    <48959, 48966, 48963>,
    <48959, 48963, 48967>    <48968, 48976, 48969>,
    <48968, 48969, 48973>    <48968, 48973, 48970>,
    <48968, 48970, 48974>    <48968, 48974, 48971>,
    <48968, 48971, 48975>    <48968, 48975, 48972>,
    <48968, 48972, 48976>    <48977, 48985, 48978>,
    <48977, 48978, 48982>    <48977, 48982, 48979>,
    <48977, 48979, 48983>    <48977, 48983, 48980>,
    <48977, 48980, 48984>    <48977, 48984, 48981>,
    <48977, 48981, 48985>    <48986, 48994, 48987>,
    <48986, 48987, 48991>    <48986, 48991, 48988>,
    <48986, 48988, 48992>    <48986, 48992, 48989>,
    <48986, 48989, 48993>    <48986, 48993, 48990>,
    <48986, 48990, 48994>    <48995, 49003, 48996>,
    <48995, 48996, 49000>    <48995, 49000, 48997>,
    <48995, 48997, 49001>    <48995, 49001, 48998>,
    <48995, 48998, 49002>    <48995, 49002, 48999>,
    <48995, 48999, 49003>    <49004, 49012, 49005>,
    <49004, 49005, 49009>    <49004, 49009, 49006>,
    <49004, 49006, 49010>    <49004, 49010, 49007>,
    <49004, 49007, 49011>    <49004, 49011, 49008>,
    <49004, 49008, 49012>    <49013, 49021, 49014>,
    <49013, 49014, 49018>    <49013, 49018, 49015>,
    <49013, 49015, 49019>    <49013, 49019, 49016>,
    <49013, 49016, 49020>    <49013, 49020, 49017>,
    <49013, 49017, 49021>    <49022, 49030, 49023>,
    <49022, 49023, 49027>    <49022, 49027, 49024>,
    <49022, 49024, 49028>    <49022, 49028, 49025>,
    <49022, 49025, 49029>    <49022, 49029, 49026>,
    <49022, 49026, 49030>    <49031, 49039, 49032>,
    <49031, 49032, 49036>    <49031, 49036, 49033>,
    <49031, 49033, 49037>    <49031, 49037, 49034>,
    <49031, 49034, 49038>    <49031, 49038, 49035>,
    <49031, 49035, 49039>    <49040, 49048, 49041>,
    <49040, 49041, 49045>    <49040, 49045, 49042>,
    <49040, 49042, 49046>    <49040, 49046, 49043>,
    <49040, 49043, 49047>    <49040, 49047, 49044>,
    <49040, 49044, 49048>    <49049, 49057, 49050>,
    <49049, 49050, 49054>    <49049, 49054, 49051>,
    <49049, 49051, 49055>    <49049, 49055, 49052>,
    <49049, 49052, 49056>    <49049, 49056, 49053>,
    <49049, 49053, 49057>    <49058, 49066, 49059>,
    <49058, 49059, 49063>    <49058, 49063, 49060>,
    <49058, 49060, 49064>    <49058, 49064, 49061>,
    <49058, 49061, 49065>    <49058, 49065, 49062>,
    <49058, 49062, 49066>    <49067, 49075, 49068>,
    <49067, 49068, 49072>    <49067, 49072, 49069>,
    <49067, 49069, 49073>    <49067, 49073, 49070>,
    <49067, 49070, 49074>    <49067, 49074, 49071>,
    <49067, 49071, 49075>    <49076, 49084, 49077>,
    <49076, 49077, 49081>    <49076, 49081, 49078>,
    <49076, 49078, 49082>    <49076, 49082, 49079>,
    <49076, 49079, 49083>    <49076, 49083, 49080>,
    <49076, 49080, 49084>    <49085, 49093, 49086>,
    <49085, 49086, 49090>    <49085, 49090, 49087>,
    <49085, 49087, 49091>    <49085, 49091, 49088>,
    <49085, 49088, 49092>    <49085, 49092, 49089>,
    <49085, 49089, 49093>    <49094, 49102, 49095>,
    <49094, 49095, 49099>    <49094, 49099, 49096>,
    <49094, 49096, 49100>    <49094, 49100, 49097>,
    <49094, 49097, 49101>    <49094, 49101, 49098>,
    <49094, 49098, 49102>    <49103, 49111, 49104>,
    <49103, 49104, 49108>    <49103, 49108, 49105>,
    <49103, 49105, 49109>    <49103, 49109, 49106>,
    <49103, 49106, 49110>    <49103, 49110, 49107>,
    <49103, 49107, 49111>    <49112, 49120, 49113>,
    <49112, 49113, 49117>    <49112, 49117, 49114>,
    <49112, 49114, 49118>    <49112, 49118, 49115>,
    <49112, 49115, 49119>    <49112, 49119, 49116>,
    <49112, 49116, 49120>    <49121, 49129, 49122>,
    <49121, 49122, 49126>    <49121, 49126, 49123>,
    <49121, 49123, 49127>    <49121, 49127, 49124>,
    <49121, 49124, 49128>    <49121, 49128, 49125>,
    <49121, 49125, 49129>    <49130, 49138, 49131>,
    <49130, 49131, 49135>    <49130, 49135, 49132>,
    <49130, 49132, 49136>    <49130, 49136, 49133>,
    <49130, 49133, 49137>    <49130, 49137, 49134>,
    <49130, 49134, 49138>    <49139, 49147, 49140>,
    <49139, 49140, 49144>    <49139, 49144, 49141>,
    <49139, 49141, 49145>    <49139, 49145, 49142>,
    <49139, 49142, 49146>    <49139, 49146, 49143>,
    <49139, 49143, 49147>    <49148, 49156, 49149>,
    <49148, 49149, 49153>    <49148, 49153, 49150>,
    <49148, 49150, 49154>    <49148, 49154, 49151>,
    <49148, 49151, 49155>    <49148, 49155, 49152>,
    <49148, 49152, 49156>    <49157, 49165, 49158>,
    <49157, 49158, 49162>    <49157, 49162, 49159>,
    <49157, 49159, 49163>    <49157, 49163, 49160>,
    <49157, 49160, 49164>    <49157, 49164, 49161>,
    <49157, 49161, 49165>    <49166, 49174, 49167>,
    <49166, 49167, 49171>    <49166, 49171, 49168>,
    <49166, 49168, 49172>    <49166, 49172, 49169>,
    <49166, 49169, 49173>    <49166, 49173, 49170>,
    <49166, 49170, 49174>    <49175, 49183, 49176>,
    <49175, 49176, 49180>    <49175, 49180, 49177>,
    <49175, 49177, 49181>    <49175, 49181, 49178>,
    <49175, 49178, 49182>    <49175, 49182, 49179>,
    <49175, 49179, 49183>    <49184, 49192, 49185>,
    <49184, 49185, 49189>    <49184, 49189, 49186>,
    <49184, 49186, 49190>    <49184, 49190, 49187>,
    <49184, 49187, 49191>    <49184, 49191, 49188>,
    <49184, 49188, 49192>    <49193, 49201, 49194>,
    <49193, 49194, 49198>    <49193, 49198, 49195>,
    <49193, 49195, 49199>    <49193, 49199, 49196>,
    <49193, 49196, 49200>    <49193, 49200, 49197>,
    <49193, 49197, 49201>    <49202, 49210, 49203>,
    <49202, 49203, 49207>    <49202, 49207, 49204>,
    <49202, 49204, 49208>    <49202, 49208, 49205>,
    <49202, 49205, 49209>    <49202, 49209, 49206>,
    <49202, 49206, 49210>    <49211, 49219, 49212>,
    <49211, 49212, 49216>    <49211, 49216, 49213>,
    <49211, 49213, 49217>    <49211, 49217, 49214>,
    <49211, 49214, 49218>    <49211, 49218, 49215>,
    <49211, 49215, 49219>    <49220, 49228, 49221>,
    <49220, 49221, 49225>    <49220, 49225, 49222>,
    <49220, 49222, 49226>    <49220, 49226, 49223>,
    <49220, 49223, 49227>    <49220, 49227, 49224>,
    <49220, 49224, 49228>    <49229, 49237, 49230>,
    <49229, 49230, 49234>    <49229, 49234, 49231>,
    <49229, 49231, 49235>    <49229, 49235, 49232>,
    <49229, 49232, 49236>    <49229, 49236, 49233>,
    <49229, 49233, 49237>    <49238, 49246, 49239>,
    <49238, 49239, 49243>    <49238, 49243, 49240>,
    <49238, 49240, 49244>    <49238, 49244, 49241>,
    <49238, 49241, 49245>    <49238, 49245, 49242>,
    <49238, 49242, 49246>    <49247, 49255, 49248>,
    <49247, 49248, 49252>    <49247, 49252, 49249>,
    <49247, 49249, 49253>    <49247, 49253, 49250>,
    <49247, 49250, 49254>    <49247, 49254, 49251>,
    <49247, 49251, 49255>    <49256, 49264, 49257>,
    <49256, 49257, 49261>    <49256, 49261, 49258>,
    <49256, 49258, 49262>    <49256, 49262, 49259>,
    <49256, 49259, 49263>    <49256, 49263, 49260>,
    <49256, 49260, 49264>    <49265, 49273, 49266>,
    <49265, 49266, 49270>    <49265, 49270, 49267>,
    <49265, 49267, 49271>    <49265, 49271, 49268>,
    <49265, 49268, 49272>    <49265, 49272, 49269>,
    <49265, 49269, 49273>    <49274, 49282, 49275>,
    <49274, 49275, 49279>    <49274, 49279, 49276>,
    <49274, 49276, 49280>    <49274, 49280, 49277>,
    <49274, 49277, 49281>    <49274, 49281, 49278>,
    <49274, 49278, 49282>    <49283, 49291, 49284>,
    <49283, 49284, 49288>    <49283, 49288, 49285>,
    <49283, 49285, 49289>    <49283, 49289, 49286>,
    <49283, 49286, 49290>    <49283, 49290, 49287>,
    <49283, 49287, 49291>    <49292, 49300, 49293>,
    <49292, 49293, 49297>    <49292, 49297, 49294>,
    <49292, 49294, 49298>    <49292, 49298, 49295>,
    <49292, 49295, 49299>    <49292, 49299, 49296>,
    <49292, 49296, 49300>    <49301, 49309, 49302>,
    <49301, 49302, 49306>    <49301, 49306, 49303>,
    <49301, 49303, 49307>    <49301, 49307, 49304>,
    <49301, 49304, 49308>    <49301, 49308, 49305>,
    <49301, 49305, 49309>    <49310, 49318, 49311>,
    <49310, 49311, 49315>    <49310, 49315, 49312>,
    <49310, 49312, 49316>    <49310, 49316, 49313>,
    <49310, 49313, 49317>    <49310, 49317, 49314>,
    <49310, 49314, 49318>    <49319, 49327, 49320>,
    <49319, 49320, 49324>    <49319, 49324, 49321>,
    <49319, 49321, 49325>    <49319, 49325, 49322>,
    <49319, 49322, 49326>    <49319, 49326, 49323>,
    <49319, 49323, 49327>    <49328, 49336, 49329>,
    <49328, 49329, 49333>    <49328, 49333, 49330>,
    <49328, 49330, 49334>    <49328, 49334, 49331>,
    <49328, 49331, 49335>    <49328, 49335, 49332>,
    <49328, 49332, 49336>    <49337, 49345, 49338>,
    <49337, 49338, 49342>    <49337, 49342, 49339>,
    <49337, 49339, 49343>    <49337, 49343, 49340>,
    <49337, 49340, 49344>    <49337, 49344, 49341>,
    <49337, 49341, 49345>    <49346, 49354, 49347>,
    <49346, 49347, 49351>    <49346, 49351, 49348>,
    <49346, 49348, 49352>    <49346, 49352, 49349>,
    <49346, 49349, 49353>    <49346, 49353, 49350>,
    <49346, 49350, 49354>    <49355, 49363, 49356>,
    <49355, 49356, 49360>    <49355, 49360, 49357>,
    <49355, 49357, 49361>    <49355, 49361, 49358>,
    <49355, 49358, 49362>    <49355, 49362, 49359>,
    <49355, 49359, 49363>    <49364, 49372, 49365>,
    <49364, 49365, 49369>    <49364, 49369, 49366>,
    <49364, 49366, 49370>    <49364, 49370, 49367>,
    <49364, 49367, 49371>    <49364, 49371, 49368>,
    <49364, 49368, 49372>    <49373, 49381, 49374>,
    <49373, 49374, 49378>    <49373, 49378, 49375>,
    <49373, 49375, 49379>    <49373, 49379, 49376>,
    <49373, 49376, 49380>    <49373, 49380, 49377>,
    <49373, 49377, 49381>    <49382, 49390, 49383>,
    <49382, 49383, 49387>    <49382, 49387, 49384>,
    <49382, 49384, 49388>    <49382, 49388, 49385>,
    <49382, 49385, 49389>    <49382, 49389, 49386>,
    <49382, 49386, 49390>    <49391, 49399, 49392>,
    <49391, 49392, 49396>    <49391, 49396, 49393>,
    <49391, 49393, 49397>    <49391, 49397, 49394>,
    <49391, 49394, 49398>    <49391, 49398, 49395>,
    <49391, 49395, 49399>    <49400, 49408, 49401>,
    <49400, 49401, 49405>    <49400, 49405, 49402>,
    <49400, 49402, 49406>    <49400, 49406, 49403>,
    <49400, 49403, 49407>    <49400, 49407, 49404>,
    <49400, 49404, 49408>    <49409, 49417, 49410>,
    <49409, 49410, 49414>    <49409, 49414, 49411>,
    <49409, 49411, 49415>    <49409, 49415, 49412>,
    <49409, 49412, 49416>    <49409, 49416, 49413>,
    <49409, 49413, 49417>    <49418, 49426, 49419>,
    <49418, 49419, 49423>    <49418, 49423, 49420>,
    <49418, 49420, 49424>    <49418, 49424, 49421>,
    <49418, 49421, 49425>    <49418, 49425, 49422>,
    <49418, 49422, 49426>    <49427, 49435, 49428>,
    <49427, 49428, 49432>    <49427, 49432, 49429>,
    <49427, 49429, 49433>    <49427, 49433, 49430>,
    <49427, 49430, 49434>    <49427, 49434, 49431>,
    <49427, 49431, 49435>    <49436, 49444, 49437>,
    <49436, 49437, 49441>    <49436, 49441, 49438>,
    <49436, 49438, 49442>    <49436, 49442, 49439>,
    <49436, 49439, 49443>    <49436, 49443, 49440>,
    <49436, 49440, 49444>    <49445, 49453, 49446>,
    <49445, 49446, 49450>    <49445, 49450, 49447>,
    <49445, 49447, 49451>    <49445, 49451, 49448>,
    <49445, 49448, 49452>    <49445, 49452, 49449>,
    <49445, 49449, 49453>    <49454, 49462, 49455>,
    <49454, 49455, 49459>    <49454, 49459, 49456>,
    <49454, 49456, 49460>    <49454, 49460, 49457>,
    <49454, 49457, 49461>    <49454, 49461, 49458>,
    <49454, 49458, 49462>    <49463, 49471, 49464>,
    <49463, 49464, 49468>    <49463, 49468, 49465>,
    <49463, 49465, 49469>    <49463, 49469, 49466>,
    <49463, 49466, 49470>    <49463, 49470, 49467>,
    <49463, 49467, 49471>    <49472, 49480, 49473>,
    <49472, 49473, 49477>    <49472, 49477, 49474>,
    <49472, 49474, 49478>    <49472, 49478, 49475>,
    <49472, 49475, 49479>    <49472, 49479, 49476>,
    <49472, 49476, 49480>    <49481, 49489, 49482>,
    <49481, 49482, 49486>    <49481, 49486, 49483>,
    <49481, 49483, 49487>    <49481, 49487, 49484>,
    <49481, 49484, 49488>    <49481, 49488, 49485>,
    <49481, 49485, 49489>    <49490, 49498, 49491>,
    <49490, 49491, 49495>    <49490, 49495, 49492>,
    <49490, 49492, 49496>    <49490, 49496, 49493>,
    <49490, 49493, 49497>    <49490, 49497, 49494>,
    <49490, 49494, 49498>    <49499, 49507, 49500>,
    <49499, 49500, 49504>    <49499, 49504, 49501>,
    <49499, 49501, 49505>    <49499, 49505, 49502>,
    <49499, 49502, 49506>    <49499, 49506, 49503>,
    <49499, 49503, 49507>    <49508, 49516, 49509>,
    <49508, 49509, 49513>    <49508, 49513, 49510>,
    <49508, 49510, 49514>    <49508, 49514, 49511>,
    <49508, 49511, 49515>    <49508, 49515, 49512>,
    <49508, 49512, 49516>    <49517, 49525, 49518>,
    <49517, 49518, 49522>    <49517, 49522, 49519>,
    <49517, 49519, 49523>    <49517, 49523, 49520>,
    <49517, 49520, 49524>    <49517, 49524, 49521>,
    <49517, 49521, 49525>    <49526, 49534, 49527>,
    <49526, 49527, 49531>    <49526, 49531, 49528>,
    <49526, 49528, 49532>    <49526, 49532, 49529>,
    <49526, 49529, 49533>    <49526, 49533, 49530>,
    <49526, 49530, 49534>    <49535, 49543, 49536>,
    <49535, 49536, 49540>    <49535, 49540, 49537>,
    <49535, 49537, 49541>    <49535, 49541, 49538>,
    <49535, 49538, 49542>    <49535, 49542, 49539>,
    <49535, 49539, 49543>    <49544, 49552, 49545>,
    <49544, 49545, 49549>    <49544, 49549, 49546>,
    <49544, 49546, 49550>    <49544, 49550, 49547>,
    <49544, 49547, 49551>    <49544, 49551, 49548>,
    <49544, 49548, 49552>    <49553, 49561, 49554>,
    <49553, 49554, 49558>    <49553, 49558, 49555>,
    <49553, 49555, 49559>    <49553, 49559, 49556>,
    <49553, 49556, 49560>    <49553, 49560, 49557>,
    <49553, 49557, 49561>    <49562, 49570, 49563>,
    <49562, 49563, 49567>    <49562, 49567, 49564>,
    <49562, 49564, 49568>    <49562, 49568, 49565>,
    <49562, 49565, 49569>    <49562, 49569, 49566>,
    <49562, 49566, 49570>    <49571, 49579, 49572>,
    <49571, 49572, 49576>    <49571, 49576, 49573>,
    <49571, 49573, 49577>    <49571, 49577, 49574>,
    <49571, 49574, 49578>    <49571, 49578, 49575>,
    <49571, 49575, 49579>    <49580, 49588, 49581>,
    <49580, 49581, 49585>    <49580, 49585, 49582>,
    <49580, 49582, 49586>    <49580, 49586, 49583>,
    <49580, 49583, 49587>    <49580, 49587, 49584>,
    <49580, 49584, 49588>    <49589, 49597, 49590>,
    <49589, 49590, 49594>    <49589, 49594, 49591>,
    <49589, 49591, 49595>    <49589, 49595, 49592>,
    <49589, 49592, 49596>    <49589, 49596, 49593>,
    <49589, 49593, 49597>    <49598, 49606, 49599>,
    <49598, 49599, 49603>    <49598, 49603, 49600>,
    <49598, 49600, 49604>    <49598, 49604, 49601>,
    <49598, 49601, 49605>    <49598, 49605, 49602>,
    <49598, 49602, 49606>    <49607, 49615, 49608>,
    <49607, 49608, 49612>    <49607, 49612, 49609>,
    <49607, 49609, 49613>    <49607, 49613, 49610>,
    <49607, 49610, 49614>    <49607, 49614, 49611>,
    <49607, 49611, 49615>    <49616, 49624, 49617>,
    <49616, 49617, 49621>    <49616, 49621, 49618>,
    <49616, 49618, 49622>    <49616, 49622, 49619>,
    <49616, 49619, 49623>    <49616, 49623, 49620>,
    <49616, 49620, 49624>    <49625, 49633, 49626>,
    <49625, 49626, 49630>    <49625, 49630, 49627>,
    <49625, 49627, 49631>    <49625, 49631, 49628>,
    <49625, 49628, 49632>    <49625, 49632, 49629>,
    <49625, 49629, 49633>    <49634, 49642, 49635>,
    <49634, 49635, 49639>    <49634, 49639, 49636>,
    <49634, 49636, 49640>    <49634, 49640, 49637>,
    <49634, 49637, 49641>    <49634, 49641, 49638>,
    <49634, 49638, 49642>    <49643, 49651, 49644>,
    <49643, 49644, 49648>    <49643, 49648, 49645>,
    <49643, 49645, 49649>    <49643, 49649, 49646>,
    <49643, 49646, 49650>    <49643, 49650, 49647>,
    <49643, 49647, 49651>    <49652, 49660, 49653>,
    <49652, 49653, 49657>    <49652, 49657, 49654>,
    <49652, 49654, 49658>    <49652, 49658, 49655>,
    <49652, 49655, 49659>    <49652, 49659, 49656>,
    <49652, 49656, 49660>    <49661, 49669, 49662>,
    <49661, 49662, 49666>    <49661, 49666, 49663>,
    <49661, 49663, 49667>    <49661, 49667, 49664>,
    <49661, 49664, 49668>    <49661, 49668, 49665>,
    <49661, 49665, 49669>    <49670, 49678, 49671>,
    <49670, 49671, 49675>    <49670, 49675, 49672>,
    <49670, 49672, 49676>    <49670, 49676, 49673>,
    <49670, 49673, 49677>    <49670, 49677, 49674>,
    <49670, 49674, 49678>    <49679, 49687, 49680>,
    <49679, 49680, 49684>    <49679, 49684, 49681>,
    <49679, 49681, 49685>    <49679, 49685, 49682>,
    <49679, 49682, 49686>    <49679, 49686, 49683>,
    <49679, 49683, 49687>    <49688, 49696, 49689>,
    <49688, 49689, 49693>    <49688, 49693, 49690>,
    <49688, 49690, 49694>    <49688, 49694, 49691>,
    <49688, 49691, 49695>    <49688, 49695, 49692>,
    <49688, 49692, 49696>    <49697, 49705, 49698>,
    <49697, 49698, 49702>    <49697, 49702, 49699>,
    <49697, 49699, 49703>    <49697, 49703, 49700>,
    <49697, 49700, 49704>    <49697, 49704, 49701>,
    <49697, 49701, 49705>    <49706, 49714, 49707>,
    <49706, 49707, 49711>    <49706, 49711, 49708>,
    <49706, 49708, 49712>    <49706, 49712, 49709>,
    <49706, 49709, 49713>    <49706, 49713, 49710>,
    <49706, 49710, 49714>    <49715, 49723, 49716>,
    <49715, 49716, 49720>    <49715, 49720, 49717>,
    <49715, 49717, 49721>    <49715, 49721, 49718>,
    <49715, 49718, 49722>    <49715, 49722, 49719>,
    <49715, 49719, 49723>    <49724, 49732, 49725>,
    <49724, 49725, 49729>    <49724, 49729, 49726>,
    <49724, 49726, 49730>    <49724, 49730, 49727>,
    <49724, 49727, 49731>    <49724, 49731, 49728>,
    <49724, 49728, 49732>    <49733, 49741, 49734>,
    <49733, 49734, 49738>    <49733, 49738, 49735>,
    <49733, 49735, 49739>    <49733, 49739, 49736>,
    <49733, 49736, 49740>    <49733, 49740, 49737>,
    <49733, 49737, 49741>    <49742, 49750, 49743>,
    <49742, 49743, 49747>    <49742, 49747, 49744>,
    <49742, 49744, 49748>    <49742, 49748, 49745>,
    <49742, 49745, 49749>    <49742, 49749, 49746>,
    <49742, 49746, 49750>    <49751, 49759, 49752>,
    <49751, 49752, 49756>    <49751, 49756, 49753>,
    <49751, 49753, 49757>    <49751, 49757, 49754>,
    <49751, 49754, 49758>    <49751, 49758, 49755>,
    <49751, 49755, 49759>    <49760, 49768, 49761>,
    <49760, 49761, 49765>    <49760, 49765, 49762>,
    <49760, 49762, 49766>    <49760, 49766, 49763>,
    <49760, 49763, 49767>    <49760, 49767, 49764>,
    <49760, 49764, 49768>    <49769, 49777, 49770>,
    <49769, 49770, 49774>    <49769, 49774, 49771>,
    <49769, 49771, 49775>    <49769, 49775, 49772>,
    <49769, 49772, 49776>    <49769, 49776, 49773>,
    <49769, 49773, 49777>    <49778, 49786, 49779>,
    <49778, 49779, 49783>    <49778, 49783, 49780>,
    <49778, 49780, 49784>    <49778, 49784, 49781>,
    <49778, 49781, 49785>    <49778, 49785, 49782>,
    <49778, 49782, 49786>    <49787, 49795, 49788>,
    <49787, 49788, 49792>    <49787, 49792, 49789>,
    <49787, 49789, 49793>    <49787, 49793, 49790>,
    <49787, 49790, 49794>    <49787, 49794, 49791>,
    <49787, 49791, 49795>    <49796, 49804, 49797>,
    <49796, 49797, 49801>    <49796, 49801, 49798>,
    <49796, 49798, 49802>    <49796, 49802, 49799>,
    <49796, 49799, 49803>    <49796, 49803, 49800>,
    <49796, 49800, 49804>    <49805, 49813, 49806>,
    <49805, 49806, 49810>    <49805, 49810, 49807>,
    <49805, 49807, 49811>    <49805, 49811, 49808>,
    <49805, 49808, 49812>    <49805, 49812, 49809>,
    <49805, 49809, 49813>    <49814, 49822, 49815>,
    <49814, 49815, 49819>    <49814, 49819, 49816>,
    <49814, 49816, 49820>    <49814, 49820, 49817>,
    <49814, 49817, 49821>    <49814, 49821, 49818>,
    <49814, 49818, 49822>    <49823, 49831, 49824>,
    <49823, 49824, 49828>    <49823, 49828, 49825>,
    <49823, 49825, 49829>    <49823, 49829, 49826>,
    <49823, 49826, 49830>    <49823, 49830, 49827>,
    <49823, 49827, 49831>    <49832, 49840, 49833>,
    <49832, 49833, 49837>    <49832, 49837, 49834>,
    <49832, 49834, 49838>    <49832, 49838, 49835>,
    <49832, 49835, 49839>    <49832, 49839, 49836>,
    <49832, 49836, 49840>    <49841, 49849, 49842>,
    <49841, 49842, 49846>    <49841, 49846, 49843>,
    <49841, 49843, 49847>    <49841, 49847, 49844>,
    <49841, 49844, 49848>    <49841, 49848, 49845>,
    <49841, 49845, 49849>    <49850, 49858, 49851>,
    <49850, 49851, 49855>    <49850, 49855, 49852>,
    <49850, 49852, 49856>    <49850, 49856, 49853>,
    <49850, 49853, 49857>    <49850, 49857, 49854>,
    <49850, 49854, 49858>    <49859, 49867, 49860>,
    <49859, 49860, 49864>    <49859, 49864, 49861>,
    <49859, 49861, 49865>    <49859, 49865, 49862>,
    <49859, 49862, 49866>    <49859, 49866, 49863>,
    <49859, 49863, 49867>    <49868, 49876, 49869>,
    <49868, 49869, 49873>    <49868, 49873, 49870>,
    <49868, 49870, 49874>    <49868, 49874, 49871>,
    <49868, 49871, 49875>    <49868, 49875, 49872>,
    <49868, 49872, 49876>    <49877, 49885, 49878>,
    <49877, 49878, 49882>    <49877, 49882, 49879>,
    <49877, 49879, 49883>    <49877, 49883, 49880>,
    <49877, 49880, 49884>    <49877, 49884, 49881>,
    <49877, 49881, 49885>    <49886, 49894, 49887>,
    <49886, 49887, 49891>    <49886, 49891, 49888>,
    <49886, 49888, 49892>    <49886, 49892, 49889>,
    <49886, 49889, 49893>    <49886, 49893, 49890>,
    <49886, 49890, 49894>    <49895, 49903, 49896>,
    <49895, 49896, 49900>    <49895, 49900, 49897>,
    <49895, 49897, 49901>    <49895, 49901, 49898>,
    <49895, 49898, 49902>    <49895, 49902, 49899>,
    <49895, 49899, 49903>    <49904, 49912, 49905>,
    <49904, 49905, 49909>    <49904, 49909, 49906>,
    <49904, 49906, 49910>    <49904, 49910, 49907>,
    <49904, 49907, 49911>    <49904, 49911, 49908>,
    <49904, 49908, 49912>    <49913, 49921, 49914>,
    <49913, 49914, 49918>    <49913, 49918, 49915>,
    <49913, 49915, 49919>    <49913, 49919, 49916>,
    <49913, 49916, 49920>    <49913, 49920, 49917>,
    <49913, 49917, 49921>    <49922, 49930, 49923>,
    <49922, 49923, 49927>    <49922, 49927, 49924>,
    <49922, 49924, 49928>    <49922, 49928, 49925>,
    <49922, 49925, 49929>    <49922, 49929, 49926>,
    <49922, 49926, 49930>    <49931, 49939, 49932>,
    <49931, 49932, 49936>    <49931, 49936, 49933>,
    <49931, 49933, 49937>    <49931, 49937, 49934>,
    <49931, 49934, 49938>    <49931, 49938, 49935>,
    <49931, 49935, 49939>    <49940, 49948, 49941>,
    <49940, 49941, 49945>    <49940, 49945, 49942>,
    <49940, 49942, 49946>    <49940, 49946, 49943>,
    <49940, 49943, 49947>    <49940, 49947, 49944>,
    <49940, 49944, 49948>    <49949, 49957, 49950>,
    <49949, 49950, 49954>    <49949, 49954, 49951>,
    <49949, 49951, 49955>    <49949, 49955, 49952>,
    <49949, 49952, 49956>    <49949, 49956, 49953>,
    <49949, 49953, 49957>    <49958, 49966, 49959>,
    <49958, 49959, 49963>    <49958, 49963, 49960>,
    <49958, 49960, 49964>    <49958, 49964, 49961>,
    <49958, 49961, 49965>    <49958, 49965, 49962>,
    <49958, 49962, 49966>    <49967, 49975, 49968>,
    <49967, 49968, 49972>    <49967, 49972, 49969>,
    <49967, 49969, 49973>    <49967, 49973, 49970>,
    <49967, 49970, 49974>    <49967, 49974, 49971>,
    <49967, 49971, 49975>    <49976, 49984, 49977>,
    <49976, 49977, 49981>    <49976, 49981, 49978>,
    <49976, 49978, 49982>    <49976, 49982, 49979>,
    <49976, 49979, 49983>    <49976, 49983, 49980>,
    <49976, 49980, 49984>    <49985, 49993, 49986>,
    <49985, 49986, 49990>    <49985, 49990, 49987>,
    <49985, 49987, 49991>    <49985, 49991, 49988>,
    <49985, 49988, 49992>    <49985, 49992, 49989>,
    <49985, 49989, 49993>    <49994, 50002, 49995>,
    <49994, 49995, 49999>    <49994, 49999, 49996>,
    <49994, 49996, 50000>    <49994, 50000, 49997>,
    <49994, 49997, 50001>    <49994, 50001, 49998>,
    <49994, 49998, 50002>    <50003, 50011, 50004>,
    <50003, 50004, 50008>    <50003, 50008, 50005>,
    <50003, 50005, 50009>    <50003, 50009, 50006>,
    <50003, 50006, 50010>    <50003, 50010, 50007>,
    <50003, 50007, 50011>    <50012, 50020, 50013>,
    <50012, 50013, 50017>    <50012, 50017, 50014>,
    <50012, 50014, 50018>    <50012, 50018, 50015>,
    <50012, 50015, 50019>    <50012, 50019, 50016>,
    <50012, 50016, 50020>    <50021, 50029, 50022>,
    <50021, 50022, 50026>    <50021, 50026, 50023>,
    <50021, 50023, 50027>    <50021, 50027, 50024>,
    <50021, 50024, 50028>    <50021, 50028, 50025>,
    <50021, 50025, 50029>    <50030, 50038, 50031>,
    <50030, 50031, 50035>    <50030, 50035, 50032>,
    <50030, 50032, 50036>    <50030, 50036, 50033>,
    <50030, 50033, 50037>    <50030, 50037, 50034>,
    <50030, 50034, 50038>    <50039, 50047, 50040>,
    <50039, 50040, 50044>    <50039, 50044, 50041>,
    <50039, 50041, 50045>    <50039, 50045, 50042>,
    <50039, 50042, 50046>    <50039, 50046, 50043>,
    <50039, 50043, 50047>    <50048, 50056, 50049>,
    <50048, 50049, 50053>    <50048, 50053, 50050>,
    <50048, 50050, 50054>    <50048, 50054, 50051>,
    <50048, 50051, 50055>    <50048, 50055, 50052>,
    <50048, 50052, 50056>    <50057, 50065, 50058>,
    <50057, 50058, 50062>    <50057, 50062, 50059>,
    <50057, 50059, 50063>    <50057, 50063, 50060>,
    <50057, 50060, 50064>    <50057, 50064, 50061>,
    <50057, 50061, 50065>    <50066, 50074, 50067>,
    <50066, 50067, 50071>    <50066, 50071, 50068>,
    <50066, 50068, 50072>    <50066, 50072, 50069>,
    <50066, 50069, 50073>    <50066, 50073, 50070>,
    <50066, 50070, 50074>    <50075, 50083, 50076>,
    <50075, 50076, 50080>    <50075, 50080, 50077>,
    <50075, 50077, 50081>    <50075, 50081, 50078>,
    <50075, 50078, 50082>    <50075, 50082, 50079>,
    <50075, 50079, 50083>    <50084, 50092, 50085>,
    <50084, 50085, 50089>    <50084, 50089, 50086>,
    <50084, 50086, 50090>    <50084, 50090, 50087>,
    <50084, 50087, 50091>    <50084, 50091, 50088>,
    <50084, 50088, 50092>    <50093, 50101, 50094>,
    <50093, 50094, 50098>    <50093, 50098, 50095>,
    <50093, 50095, 50099>    <50093, 50099, 50096>,
    <50093, 50096, 50100>    <50093, 50100, 50097>,
    <50093, 50097, 50101>    <50102, 50110, 50103>,
    <50102, 50103, 50107>    <50102, 50107, 50104>,
    <50102, 50104, 50108>    <50102, 50108, 50105>,
    <50102, 50105, 50109>    <50102, 50109, 50106>,
    <50102, 50106, 50110>    <50111, 50119, 50112>,
    <50111, 50112, 50116>    <50111, 50116, 50113>,
    <50111, 50113, 50117>    <50111, 50117, 50114>,
    <50111, 50114, 50118>    <50111, 50118, 50115>,
    <50111, 50115, 50119>    <50120, 50128, 50121>,
    <50120, 50121, 50125>    <50120, 50125, 50122>,
    <50120, 50122, 50126>    <50120, 50126, 50123>,
    <50120, 50123, 50127>    <50120, 50127, 50124>,
    <50120, 50124, 50128>    <50129, 50137, 50130>,
    <50129, 50130, 50134>    <50129, 50134, 50131>,
    <50129, 50131, 50135>    <50129, 50135, 50132>,
    <50129, 50132, 50136>    <50129, 50136, 50133>,
    <50129, 50133, 50137>    <50138, 50146, 50139>,
    <50138, 50139, 50143>    <50138, 50143, 50140>,
    <50138, 50140, 50144>    <50138, 50144, 50141>,
    <50138, 50141, 50145>    <50138, 50145, 50142>,
    <50138, 50142, 50146>    <50147, 50155, 50148>,
    <50147, 50148, 50152>    <50147, 50152, 50149>,
    <50147, 50149, 50153>    <50147, 50153, 50150>,
    <50147, 50150, 50154>    <50147, 50154, 50151>,
    <50147, 50151, 50155>    <50156, 50164, 50157>,
    <50156, 50157, 50161>    <50156, 50161, 50158>,
    <50156, 50158, 50162>    <50156, 50162, 50159>,
    <50156, 50159, 50163>    <50156, 50163, 50160>,
    <50156, 50160, 50164>    <50165, 50173, 50166>,
    <50165, 50166, 50170>    <50165, 50170, 50167>,
    <50165, 50167, 50171>    <50165, 50171, 50168>,
    <50165, 50168, 50172>    <50165, 50172, 50169>,
    <50165, 50169, 50173>    <50174, 50182, 50175>,
    <50174, 50175, 50179>    <50174, 50179, 50176>,
    <50174, 50176, 50180>    <50174, 50180, 50177>,
    <50174, 50177, 50181>    <50174, 50181, 50178>,
    <50174, 50178, 50182>    <50183, 50191, 50184>,
    <50183, 50184, 50188>    <50183, 50188, 50185>,
    <50183, 50185, 50189>    <50183, 50189, 50186>,
    <50183, 50186, 50190>    <50183, 50190, 50187>,
    <50183, 50187, 50191>    <50192, 50200, 50193>,
    <50192, 50193, 50197>    <50192, 50197, 50194>,
    <50192, 50194, 50198>    <50192, 50198, 50195>,
    <50192, 50195, 50199>    <50192, 50199, 50196>,
    <50192, 50196, 50200>    <50201, 50209, 50202>,
    <50201, 50202, 50206>    <50201, 50206, 50203>,
    <50201, 50203, 50207>    <50201, 50207, 50204>,
    <50201, 50204, 50208>    <50201, 50208, 50205>,
    <50201, 50205, 50209>    <50210, 50218, 50211>,
    <50210, 50211, 50215>    <50210, 50215, 50212>,
    <50210, 50212, 50216>    <50210, 50216, 50213>,
    <50210, 50213, 50217>    <50210, 50217, 50214>,
    <50210, 50214, 50218>    <50219, 50227, 50220>,
    <50219, 50220, 50224>    <50219, 50224, 50221>,
    <50219, 50221, 50225>    <50219, 50225, 50222>,
    <50219, 50222, 50226>    <50219, 50226, 50223>,
    <50219, 50223, 50227>    <50228, 50236, 50229>,
    <50228, 50229, 50233>    <50228, 50233, 50230>,
    <50228, 50230, 50234>    <50228, 50234, 50231>,
    <50228, 50231, 50235>    <50228, 50235, 50232>,
    <50228, 50232, 50236>    <50237, 50245, 50238>,
    <50237, 50238, 50242>    <50237, 50242, 50239>,
    <50237, 50239, 50243>    <50237, 50243, 50240>,
    <50237, 50240, 50244>    <50237, 50244, 50241>,
    <50237, 50241, 50245>    <50246, 50254, 50247>,
    <50246, 50247, 50251>    <50246, 50251, 50248>,
    <50246, 50248, 50252>    <50246, 50252, 50249>,
    <50246, 50249, 50253>    <50246, 50253, 50250>,
    <50246, 50250, 50254>    <50255, 50263, 50256>,
    <50255, 50256, 50260>    <50255, 50260, 50257>,
    <50255, 50257, 50261>    <50255, 50261, 50258>,
    <50255, 50258, 50262>    <50255, 50262, 50259>,
    <50255, 50259, 50263>    <50264, 50272, 50265>,
    <50264, 50265, 50269>    <50264, 50269, 50266>,
    <50264, 50266, 50270>    <50264, 50270, 50267>,
    <50264, 50267, 50271>    <50264, 50271, 50268>,
    <50264, 50268, 50272>    <50273, 50281, 50274>,
    <50273, 50274, 50278>    <50273, 50278, 50275>,
    <50273, 50275, 50279>    <50273, 50279, 50276>,
    <50273, 50276, 50280>    <50273, 50280, 50277>,
    <50273, 50277, 50281>    <50282, 50290, 50283>,
    <50282, 50283, 50287>    <50282, 50287, 50284>,
    <50282, 50284, 50288>    <50282, 50288, 50285>,
    <50282, 50285, 50289>    <50282, 50289, 50286>,
    <50282, 50286, 50290>    <50291, 50299, 50292>,
    <50291, 50292, 50296>    <50291, 50296, 50293>,
    <50291, 50293, 50297>    <50291, 50297, 50294>,
    <50291, 50294, 50298>    <50291, 50298, 50295>,
    <50291, 50295, 50299>    <50300, 50308, 50301>,
    <50300, 50301, 50305>    <50300, 50305, 50302>,
    <50300, 50302, 50306>    <50300, 50306, 50303>,
    <50300, 50303, 50307>    <50300, 50307, 50304>,
    <50300, 50304, 50308>    <50309, 50317, 50310>,
    <50309, 50310, 50314>    <50309, 50314, 50311>,
    <50309, 50311, 50315>    <50309, 50315, 50312>,
    <50309, 50312, 50316>    <50309, 50316, 50313>,
    <50309, 50313, 50317>    <50318, 50326, 50319>,
    <50318, 50319, 50323>    <50318, 50323, 50320>,
    <50318, 50320, 50324>    <50318, 50324, 50321>,
    <50318, 50321, 50325>    <50318, 50325, 50322>,
    <50318, 50322, 50326>    <50327, 50335, 50328>,
    <50327, 50328, 50332>    <50327, 50332, 50329>,
    <50327, 50329, 50333>    <50327, 50333, 50330>,
    <50327, 50330, 50334>    <50327, 50334, 50331>,
    <50327, 50331, 50335>    <50336, 50344, 50337>,
    <50336, 50337, 50341>    <50336, 50341, 50338>,
    <50336, 50338, 50342>    <50336, 50342, 50339>,
    <50336, 50339, 50343>    <50336, 50343, 50340>,
    <50336, 50340, 50344>    <50345, 50353, 50346>,
    <50345, 50346, 50350>    <50345, 50350, 50347>,
    <50345, 50347, 50351>    <50345, 50351, 50348>,
    <50345, 50348, 50352>    <50345, 50352, 50349>,
    <50345, 50349, 50353>    <50354, 50362, 50355>,
    <50354, 50355, 50359>    <50354, 50359, 50356>,
    <50354, 50356, 50360>    <50354, 50360, 50357>,
    <50354, 50357, 50361>    <50354, 50361, 50358>,
    <50354, 50358, 50362>    <50363, 50371, 50364>,
    <50363, 50364, 50368>    <50363, 50368, 50365>,
    <50363, 50365, 50369>    <50363, 50369, 50366>,
    <50363, 50366, 50370>    <50363, 50370, 50367>,
    <50363, 50367, 50371>    <50372, 50380, 50373>,
    <50372, 50373, 50377>    <50372, 50377, 50374>,
    <50372, 50374, 50378>    <50372, 50378, 50375>,
    <50372, 50375, 50379>    <50372, 50379, 50376>,
    <50372, 50376, 50380>    <50381, 50389, 50382>,
    <50381, 50382, 50386>    <50381, 50386, 50383>,
    <50381, 50383, 50387>    <50381, 50387, 50384>,
    <50381, 50384, 50388>    <50381, 50388, 50385>,
    <50381, 50385, 50389>    <50390, 50398, 50391>,
    <50390, 50391, 50395>    <50390, 50395, 50392>,
    <50390, 50392, 50396>    <50390, 50396, 50393>,
    <50390, 50393, 50397>    <50390, 50397, 50394>,
    <50390, 50394, 50398>    <50399, 50407, 50400>,
    <50399, 50400, 50404>    <50399, 50404, 50401>,
    <50399, 50401, 50405>    <50399, 50405, 50402>,
    <50399, 50402, 50406>    <50399, 50406, 50403>,
    <50399, 50403, 50407>    <50408, 50416, 50409>,
    <50408, 50409, 50413>    <50408, 50413, 50410>,
    <50408, 50410, 50414>    <50408, 50414, 50411>,
    <50408, 50411, 50415>    <50408, 50415, 50412>,
    <50408, 50412, 50416>    <50417, 50425, 50418>,
    <50417, 50418, 50422>    <50417, 50422, 50419>,
    <50417, 50419, 50423>    <50417, 50423, 50420>,
    <50417, 50420, 50424>    <50417, 50424, 50421>,
    <50417, 50421, 50425>    <50426, 50434, 50427>,
    <50426, 50427, 50431>    <50426, 50431, 50428>,
    <50426, 50428, 50432>    <50426, 50432, 50429>,
    <50426, 50429, 50433>    <50426, 50433, 50430>,
    <50426, 50430, 50434>    <50435, 50443, 50436>,
    <50435, 50436, 50440>    <50435, 50440, 50437>,
    <50435, 50437, 50441>    <50435, 50441, 50438>,
    <50435, 50438, 50442>    <50435, 50442, 50439>,
    <50435, 50439, 50443>    <50444, 50452, 50445>,
    <50444, 50445, 50449>    <50444, 50449, 50446>,
    <50444, 50446, 50450>    <50444, 50450, 50447>,
    <50444, 50447, 50451>    <50444, 50451, 50448>,
    <50444, 50448, 50452>    <50453, 50461, 50454>,
    <50453, 50454, 50458>    <50453, 50458, 50455>,
    <50453, 50455, 50459>    <50453, 50459, 50456>,
    <50453, 50456, 50460>    <50453, 50460, 50457>,
    <50453, 50457, 50461>    <50462, 50470, 50463>,
    <50462, 50463, 50467>    <50462, 50467, 50464>,
    <50462, 50464, 50468>    <50462, 50468, 50465>,
    <50462, 50465, 50469>    <50462, 50469, 50466>,
    <50462, 50466, 50470>    <50471, 50479, 50472>,
    <50471, 50472, 50476>    <50471, 50476, 50473>,
    <50471, 50473, 50477>    <50471, 50477, 50474>,
    <50471, 50474, 50478>    <50471, 50478, 50475>,
    <50471, 50475, 50479>    <50480, 50488, 50481>,
    <50480, 50481, 50485>    <50480, 50485, 50482>,
    <50480, 50482, 50486>    <50480, 50486, 50483>,
    <50480, 50483, 50487>    <50480, 50487, 50484>,
    <50480, 50484, 50488>    <50489, 50497, 50490>,
    <50489, 50490, 50494>    <50489, 50494, 50491>,
    <50489, 50491, 50495>    <50489, 50495, 50492>,
    <50489, 50492, 50496>    <50489, 50496, 50493>,
    <50489, 50493, 50497>    <50498, 50506, 50499>,
    <50498, 50499, 50503>    <50498, 50503, 50500>,
    <50498, 50500, 50504>    <50498, 50504, 50501>,
    <50498, 50501, 50505>    <50498, 50505, 50502>,
    <50498, 50502, 50506>    <50507, 50515, 50508>,
    <50507, 50508, 50512>    <50507, 50512, 50509>,
    <50507, 50509, 50513>    <50507, 50513, 50510>,
    <50507, 50510, 50514>    <50507, 50514, 50511>,
    <50507, 50511, 50515>    <50516, 50524, 50517>,
    <50516, 50517, 50521>    <50516, 50521, 50518>,
    <50516, 50518, 50522>    <50516, 50522, 50519>,
    <50516, 50519, 50523>    <50516, 50523, 50520>,
    <50516, 50520, 50524>    <50525, 50533, 50526>,
    <50525, 50526, 50530>    <50525, 50530, 50527>,
    <50525, 50527, 50531>    <50525, 50531, 50528>,
    <50525, 50528, 50532>    <50525, 50532, 50529>,
    <50525, 50529, 50533>    <50534, 50542, 50535>,
    <50534, 50535, 50539>    <50534, 50539, 50536>,
    <50534, 50536, 50540>    <50534, 50540, 50537>,
    <50534, 50537, 50541>    <50534, 50541, 50538>,
    <50534, 50538, 50542>    <50543, 50551, 50544>,
    <50543, 50544, 50548>    <50543, 50548, 50545>,
    <50543, 50545, 50549>    <50543, 50549, 50546>,
    <50543, 50546, 50550>    <50543, 50550, 50547>,
    <50543, 50547, 50551>    <50552, 50560, 50553>,
    <50552, 50553, 50557>    <50552, 50557, 50554>,
    <50552, 50554, 50558>    <50552, 50558, 50555>,
    <50552, 50555, 50559>    <50552, 50559, 50556>,
    <50552, 50556, 50560>    <50561, 50569, 50562>,
    <50561, 50562, 50566>    <50561, 50566, 50563>,
    <50561, 50563, 50567>    <50561, 50567, 50564>,
    <50561, 50564, 50568>    <50561, 50568, 50565>,
    <50561, 50565, 50569>    <50570, 50578, 50571>,
    <50570, 50571, 50575>    <50570, 50575, 50572>,
    <50570, 50572, 50576>    <50570, 50576, 50573>,
    <50570, 50573, 50577>    <50570, 50577, 50574>,
    <50570, 50574, 50578>    <50579, 50587, 50580>,
    <50579, 50580, 50584>    <50579, 50584, 50581>,
    <50579, 50581, 50585>    <50579, 50585, 50582>,
    <50579, 50582, 50586>    <50579, 50586, 50583>,
    <50579, 50583, 50587>    <50588, 50596, 50589>,
    <50588, 50589, 50593>    <50588, 50593, 50590>,
    <50588, 50590, 50594>    <50588, 50594, 50591>,
    <50588, 50591, 50595>    <50588, 50595, 50592>,
    <50588, 50592, 50596>    <50597, 50605, 50598>,
    <50597, 50598, 50602>    <50597, 50602, 50599>,
    <50597, 50599, 50603>    <50597, 50603, 50600>,
    <50597, 50600, 50604>    <50597, 50604, 50601>,
    <50597, 50601, 50605>    <50606, 50614, 50607>,
    <50606, 50607, 50611>    <50606, 50611, 50608>,
    <50606, 50608, 50612>    <50606, 50612, 50609>,
    <50606, 50609, 50613>    <50606, 50613, 50610>,
    <50606, 50610, 50614>    <50615, 50623, 50616>,
    <50615, 50616, 50620>    <50615, 50620, 50617>,
    <50615, 50617, 50621>    <50615, 50621, 50618>,
    <50615, 50618, 50622>    <50615, 50622, 50619>,
    <50615, 50619, 50623>    <50624, 50632, 50625>,
    <50624, 50625, 50629>    <50624, 50629, 50626>,
    <50624, 50626, 50630>    <50624, 50630, 50627>,
    <50624, 50627, 50631>    <50624, 50631, 50628>,
    <50624, 50628, 50632>    <50633, 50641, 50634>,
    <50633, 50634, 50638>    <50633, 50638, 50635>,
    <50633, 50635, 50639>    <50633, 50639, 50636>,
    <50633, 50636, 50640>    <50633, 50640, 50637>,
    <50633, 50637, 50641>    <50642, 50650, 50643>,
    <50642, 50643, 50647>    <50642, 50647, 50644>,
    <50642, 50644, 50648>    <50642, 50648, 50645>,
    <50642, 50645, 50649>    <50642, 50649, 50646>,
    <50642, 50646, 50650>    <50651, 50659, 50652>,
    <50651, 50652, 50656>    <50651, 50656, 50653>,
    <50651, 50653, 50657>    <50651, 50657, 50654>,
    <50651, 50654, 50658>    <50651, 50658, 50655>,
    <50651, 50655, 50659>    <50660, 50668, 50661>,
    <50660, 50661, 50665>    <50660, 50665, 50662>,
    <50660, 50662, 50666>    <50660, 50666, 50663>,
    <50660, 50663, 50667>    <50660, 50667, 50664>,
    <50660, 50664, 50668>    <50669, 50677, 50670>,
    <50669, 50670, 50674>    <50669, 50674, 50671>,
    <50669, 50671, 50675>    <50669, 50675, 50672>,
    <50669, 50672, 50676>    <50669, 50676, 50673>,
    <50669, 50673, 50677>    <50678, 50686, 50679>,
    <50678, 50679, 50683>    <50678, 50683, 50680>,
    <50678, 50680, 50684>    <50678, 50684, 50681>,
    <50678, 50681, 50685>    <50678, 50685, 50682>,
    <50678, 50682, 50686>    <50687, 50695, 50688>,
    <50687, 50688, 50692>    <50687, 50692, 50689>,
    <50687, 50689, 50693>    <50687, 50693, 50690>,
    <50687, 50690, 50694>    <50687, 50694, 50691>,
    <50687, 50691, 50695>    <50696, 50704, 50697>,
    <50696, 50697, 50701>    <50696, 50701, 50698>,
    <50696, 50698, 50702>    <50696, 50702, 50699>,
    <50696, 50699, 50703>    <50696, 50703, 50700>,
    <50696, 50700, 50704>    <50705, 50713, 50706>,
    <50705, 50706, 50710>    <50705, 50710, 50707>,
    <50705, 50707, 50711>    <50705, 50711, 50708>,
    <50705, 50708, 50712>    <50705, 50712, 50709>,
    <50705, 50709, 50713>    <50714, 50722, 50715>,
    <50714, 50715, 50719>    <50714, 50719, 50716>,
    <50714, 50716, 50720>    <50714, 50720, 50717>,
    <50714, 50717, 50721>    <50714, 50721, 50718>,
    <50714, 50718, 50722>    <50723, 50731, 50724>,
    <50723, 50724, 50728>    <50723, 50728, 50725>,
    <50723, 50725, 50729>    <50723, 50729, 50726>,
    <50723, 50726, 50730>    <50723, 50730, 50727>,
    <50723, 50727, 50731>    <50732, 50740, 50733>,
    <50732, 50733, 50737>    <50732, 50737, 50734>,
    <50732, 50734, 50738>    <50732, 50738, 50735>,
    <50732, 50735, 50739>    <50732, 50739, 50736>,
    <50732, 50736, 50740>    <50741, 50749, 50742>,
    <50741, 50742, 50746>    <50741, 50746, 50743>,
    <50741, 50743, 50747>    <50741, 50747, 50744>,
    <50741, 50744, 50748>    <50741, 50748, 50745>,
    <50741, 50745, 50749>    <50750, 50758, 50751>,
    <50750, 50751, 50755>    <50750, 50755, 50752>,
    <50750, 50752, 50756>    <50750, 50756, 50753>,
    <50750, 50753, 50757>    <50750, 50757, 50754>,
    <50750, 50754, 50758>    <50759, 50767, 50760>,
    <50759, 50760, 50764>    <50759, 50764, 50761>,
    <50759, 50761, 50765>    <50759, 50765, 50762>,
    <50759, 50762, 50766>    <50759, 50766, 50763>,
    <50759, 50763, 50767>    <50768, 50776, 50769>,
    <50768, 50769, 50773>    <50768, 50773, 50770>,
    <50768, 50770, 50774>    <50768, 50774, 50771>,
    <50768, 50771, 50775>    <50768, 50775, 50772>,
    <50768, 50772, 50776>    <50777, 50785, 50778>,
    <50777, 50778, 50782>    <50777, 50782, 50779>,
    <50777, 50779, 50783>    <50777, 50783, 50780>,
    <50777, 50780, 50784>    <50777, 50784, 50781>,
    <50777, 50781, 50785>    <50786, 50794, 50787>,
    <50786, 50787, 50791>    <50786, 50791, 50788>,
    <50786, 50788, 50792>    <50786, 50792, 50789>,
    <50786, 50789, 50793>    <50786, 50793, 50790>,
    <50786, 50790, 50794>    <50795, 50803, 50796>,
    <50795, 50796, 50800>    <50795, 50800, 50797>,
    <50795, 50797, 50801>    <50795, 50801, 50798>,
    <50795, 50798, 50802>    <50795, 50802, 50799>,
    <50795, 50799, 50803>    <50804, 50812, 50805>,
    <50804, 50805, 50809>    <50804, 50809, 50806>,
    <50804, 50806, 50810>    <50804, 50810, 50807>,
    <50804, 50807, 50811>    <50804, 50811, 50808>,
    <50804, 50808, 50812>    <50813, 50821, 50814>,
    <50813, 50814, 50818>    <50813, 50818, 50815>,
    <50813, 50815, 50819>    <50813, 50819, 50816>,
    <50813, 50816, 50820>    <50813, 50820, 50817>,
    <50813, 50817, 50821>    <50822, 50830, 50823>,
    <50822, 50823, 50827>    <50822, 50827, 50824>,
    <50822, 50824, 50828>    <50822, 50828, 50825>,
    <50822, 50825, 50829>    <50822, 50829, 50826>,
    <50822, 50826, 50830>    <50831, 50839, 50832>,
    <50831, 50832, 50836>    <50831, 50836, 50833>,
    <50831, 50833, 50837>    <50831, 50837, 50834>,
    <50831, 50834, 50838>    <50831, 50838, 50835>,
    <50831, 50835, 50839>    <50840, 50848, 50841>,
    <50840, 50841, 50845>    <50840, 50845, 50842>,
    <50840, 50842, 50846>    <50840, 50846, 50843>,
    <50840, 50843, 50847>    <50840, 50847, 50844>,
    <50840, 50844, 50848>    <50849, 50857, 50850>,
    <50849, 50850, 50854>    <50849, 50854, 50851>,
    <50849, 50851, 50855>    <50849, 50855, 50852>,
    <50849, 50852, 50856>    <50849, 50856, 50853>,
    <50849, 50853, 50857>    <50858, 50866, 50859>,
    <50858, 50859, 50863>    <50858, 50863, 50860>,
    <50858, 50860, 50864>    <50858, 50864, 50861>,
    <50858, 50861, 50865>    <50858, 50865, 50862>,
    <50858, 50862, 50866>    <50867, 50875, 50868>,
    <50867, 50868, 50872>    <50867, 50872, 50869>,
    <50867, 50869, 50873>    <50867, 50873, 50870>,
    <50867, 50870, 50874>    <50867, 50874, 50871>,
    <50867, 50871, 50875>    <50876, 50884, 50877>,
    <50876, 50877, 50881>    <50876, 50881, 50878>,
    <50876, 50878, 50882>    <50876, 50882, 50879>,
    <50876, 50879, 50883>    <50876, 50883, 50880>,
    <50876, 50880, 50884>    <50885, 50893, 50886>,
    <50885, 50886, 50890>    <50885, 50890, 50887>,
    <50885, 50887, 50891>    <50885, 50891, 50888>,
    <50885, 50888, 50892>    <50885, 50892, 50889>,
    <50885, 50889, 50893>    <50894, 50902, 50895>,
    <50894, 50895, 50899>    <50894, 50899, 50896>,
    <50894, 50896, 50900>    <50894, 50900, 50897>,
    <50894, 50897, 50901>    <50894, 50901, 50898>,
    <50894, 50898, 50902>    <50903, 50911, 50904>,
    <50903, 50904, 50908>    <50903, 50908, 50905>,
    <50903, 50905, 50909>    <50903, 50909, 50906>,
    <50903, 50906, 50910>    <50903, 50910, 50907>,
    <50903, 50907, 50911>    <50912, 50920, 50913>,
    <50912, 50913, 50917>    <50912, 50917, 50914>,
    <50912, 50914, 50918>    <50912, 50918, 50915>,
    <50912, 50915, 50919>    <50912, 50919, 50916>,
    <50912, 50916, 50920>    <50921, 50929, 50922>,
    <50921, 50922, 50926>    <50921, 50926, 50923>,
    <50921, 50923, 50927>    <50921, 50927, 50924>,
    <50921, 50924, 50928>    <50921, 50928, 50925>,
    <50921, 50925, 50929>    <50930, 50938, 50931>,
    <50930, 50931, 50935>    <50930, 50935, 50932>,
    <50930, 50932, 50936>    <50930, 50936, 50933>,
    <50930, 50933, 50937>    <50930, 50937, 50934>,
    <50930, 50934, 50938>    <50939, 50947, 50940>,
    <50939, 50940, 50944>    <50939, 50944, 50941>,
    <50939, 50941, 50945>    <50939, 50945, 50942>,
    <50939, 50942, 50946>    <50939, 50946, 50943>,
    <50939, 50943, 50947>    <50948, 50956, 50949>,
    <50948, 50949, 50953>    <50948, 50953, 50950>,
    <50948, 50950, 50954>    <50948, 50954, 50951>,
    <50948, 50951, 50955>    <50948, 50955, 50952>,
    <50948, 50952, 50956>    <50957, 50965, 50958>,
    <50957, 50958, 50962>    <50957, 50962, 50959>,
    <50957, 50959, 50963>    <50957, 50963, 50960>,
    <50957, 50960, 50964>    <50957, 50964, 50961>,
    <50957, 50961, 50965>    <50966, 50974, 50967>,
    <50966, 50967, 50971>    <50966, 50971, 50968>,
    <50966, 50968, 50972>    <50966, 50972, 50969>,
    <50966, 50969, 50973>    <50966, 50973, 50970>,
    <50966, 50970, 50974>    <50975, 50983, 50976>,
    <50975, 50976, 50980>    <50975, 50980, 50977>,
    <50975, 50977, 50981>    <50975, 50981, 50978>,
    <50975, 50978, 50982>    <50975, 50982, 50979>,
    <50975, 50979, 50983>    <50984, 50992, 50985>,
    <50984, 50985, 50989>    <50984, 50989, 50986>,
    <50984, 50986, 50990>    <50984, 50990, 50987>,
    <50984, 50987, 50991>    <50984, 50991, 50988>,
    <50984, 50988, 50992>    <50993, 51001, 50994>,
    <50993, 50994, 50998>    <50993, 50998, 50995>,
    <50993, 50995, 50999>    <50993, 50999, 50996>,
    <50993, 50996, 51000>    <50993, 51000, 50997>,
    <50993, 50997, 51001>    <51002, 51010, 51003>,
    <51002, 51003, 51007>    <51002, 51007, 51004>,
    <51002, 51004, 51008>    <51002, 51008, 51005>,
    <51002, 51005, 51009>    <51002, 51009, 51006>,
    <51002, 51006, 51010>    <51011, 51019, 51012>,
    <51011, 51012, 51016>    <51011, 51016, 51013>,
    <51011, 51013, 51017>    <51011, 51017, 51014>,
    <51011, 51014, 51018>    <51011, 51018, 51015>,
    <51011, 51015, 51019>    <51020, 51028, 51021>,
    <51020, 51021, 51025>    <51020, 51025, 51022>,
    <51020, 51022, 51026>    <51020, 51026, 51023>,
    <51020, 51023, 51027>    <51020, 51027, 51024>,
    <51020, 51024, 51028>    <51029, 51037, 51030>,
    <51029, 51030, 51034>    <51029, 51034, 51031>,
    <51029, 51031, 51035>    <51029, 51035, 51032>,
    <51029, 51032, 51036>    <51029, 51036, 51033>,
    <51029, 51033, 51037>    <51038, 51046, 51039>,
    <51038, 51039, 51043>    <51038, 51043, 51040>,
    <51038, 51040, 51044>    <51038, 51044, 51041>,
    <51038, 51041, 51045>    <51038, 51045, 51042>,
    <51038, 51042, 51046>    <51047, 51055, 51048>,
    <51047, 51048, 51052>    <51047, 51052, 51049>,
    <51047, 51049, 51053>    <51047, 51053, 51050>,
    <51047, 51050, 51054>    <51047, 51054, 51051>,
    <51047, 51051, 51055>    <51056, 51064, 51057>,
    <51056, 51057, 51061>    <51056, 51061, 51058>,
    <51056, 51058, 51062>    <51056, 51062, 51059>,
    <51056, 51059, 51063>    <51056, 51063, 51060>,
    <51056, 51060, 51064>    <51065, 51073, 51066>,
    <51065, 51066, 51070>    <51065, 51070, 51067>,
    <51065, 51067, 51071>    <51065, 51071, 51068>,
    <51065, 51068, 51072>    <51065, 51072, 51069>,
    <51065, 51069, 51073>    <51074, 51082, 51075>,
    <51074, 51075, 51079>    <51074, 51079, 51076>,
    <51074, 51076, 51080>    <51074, 51080, 51077>,
    <51074, 51077, 51081>    <51074, 51081, 51078>,
    <51074, 51078, 51082>    <51083, 51091, 51084>,
    <51083, 51084, 51088>    <51083, 51088, 51085>,
    <51083, 51085, 51089>    <51083, 51089, 51086>,
    <51083, 51086, 51090>    <51083, 51090, 51087>,
    <51083, 51087, 51091>    <51092, 51100, 51093>,
    <51092, 51093, 51097>    <51092, 51097, 51094>,
    <51092, 51094, 51098>    <51092, 51098, 51095>,
    <51092, 51095, 51099>    <51092, 51099, 51096>,
    <51092, 51096, 51100>    <51101, 51109, 51102>,
    <51101, 51102, 51106>    <51101, 51106, 51103>,
    <51101, 51103, 51107>    <51101, 51107, 51104>,
    <51101, 51104, 51108>    <51101, 51108, 51105>,
    <51101, 51105, 51109>    <51110, 51118, 51111>,
    <51110, 51111, 51115>    <51110, 51115, 51112>,
    <51110, 51112, 51116>    <51110, 51116, 51113>,
    <51110, 51113, 51117>    <51110, 51117, 51114>,
    <51110, 51114, 51118>    <51119, 51127, 51120>,
    <51119, 51120, 51124>    <51119, 51124, 51121>,
    <51119, 51121, 51125>    <51119, 51125, 51122>,
    <51119, 51122, 51126>    <51119, 51126, 51123>,
    <51119, 51123, 51127>    <51128, 51136, 51129>,
    <51128, 51129, 51133>    <51128, 51133, 51130>,
    <51128, 51130, 51134>    <51128, 51134, 51131>,
    <51128, 51131, 51135>    <51128, 51135, 51132>,
    <51128, 51132, 51136>    <51137, 51145, 51138>,
    <51137, 51138, 51142>    <51137, 51142, 51139>,
    <51137, 51139, 51143>    <51137, 51143, 51140>,
    <51137, 51140, 51144>    <51137, 51144, 51141>,
    <51137, 51141, 51145>    <51146, 51154, 51147>,
    <51146, 51147, 51151>    <51146, 51151, 51148>,
    <51146, 51148, 51152>    <51146, 51152, 51149>,
    <51146, 51149, 51153>    <51146, 51153, 51150>,
    <51146, 51150, 51154>    <51155, 51163, 51156>,
    <51155, 51156, 51160>    <51155, 51160, 51157>,
    <51155, 51157, 51161>    <51155, 51161, 51158>,
    <51155, 51158, 51162>    <51155, 51162, 51159>,
    <51155, 51159, 51163>    <51164, 51172, 51165>,
    <51164, 51165, 51169>    <51164, 51169, 51166>,
    <51164, 51166, 51170>    <51164, 51170, 51167>,
    <51164, 51167, 51171>    <51164, 51171, 51168>,
    <51164, 51168, 51172>    <51173, 51181, 51174>,
    <51173, 51174, 51178>    <51173, 51178, 51175>,
    <51173, 51175, 51179>    <51173, 51179, 51176>,
    <51173, 51176, 51180>    <51173, 51180, 51177>,
    <51173, 51177, 51181>    <51182, 51190, 51183>,
    <51182, 51183, 51187>    <51182, 51187, 51184>,
    <51182, 51184, 51188>    <51182, 51188, 51185>,
    <51182, 51185, 51189>    <51182, 51189, 51186>,
    <51182, 51186, 51190>    <51191, 51199, 51192>,
    <51191, 51192, 51196>    <51191, 51196, 51193>,
    <51191, 51193, 51197>    <51191, 51197, 51194>,
    <51191, 51194, 51198>    <51191, 51198, 51195>,
    <51191, 51195, 51199>    <51200, 51208, 51201>,
    <51200, 51201, 51205>    <51200, 51205, 51202>,
    <51200, 51202, 51206>    <51200, 51206, 51203>,
    <51200, 51203, 51207>    <51200, 51207, 51204>,
    <51200, 51204, 51208>    <51209, 51217, 51210>,
    <51209, 51210, 51214>    <51209, 51214, 51211>,
    <51209, 51211, 51215>    <51209, 51215, 51212>,
    <51209, 51212, 51216>    <51209, 51216, 51213>,
    <51209, 51213, 51217>    <51218, 51226, 51219>,
    <51218, 51219, 51223>    <51218, 51223, 51220>,
    <51218, 51220, 51224>    <51218, 51224, 51221>,
    <51218, 51221, 51225>    <51218, 51225, 51222>,
    <51218, 51222, 51226>    <51227, 51235, 51228>,
    <51227, 51228, 51232>    <51227, 51232, 51229>,
    <51227, 51229, 51233>    <51227, 51233, 51230>,
    <51227, 51230, 51234>    <51227, 51234, 51231>,
    <51227, 51231, 51235>    <51236, 51244, 51237>,
    <51236, 51237, 51241>    <51236, 51241, 51238>,
    <51236, 51238, 51242>    <51236, 51242, 51239>,
    <51236, 51239, 51243>    <51236, 51243, 51240>,
    <51236, 51240, 51244>    <51245, 51253, 51246>,
    <51245, 51246, 51250>    <51245, 51250, 51247>,
    <51245, 51247, 51251>    <51245, 51251, 51248>,
    <51245, 51248, 51252>    <51245, 51252, 51249>,
    <51245, 51249, 51253>    <51254, 51262, 51255>,
    <51254, 51255, 51259>    <51254, 51259, 51256>,
    <51254, 51256, 51260>    <51254, 51260, 51257>,
    <51254, 51257, 51261>    <51254, 51261, 51258>,
    <51254, 51258, 51262>    <51263, 51271, 51264>,
    <51263, 51264, 51268>    <51263, 51268, 51265>,
    <51263, 51265, 51269>    <51263, 51269, 51266>,
    <51263, 51266, 51270>    <51263, 51270, 51267>,
    <51263, 51267, 51271>    <51272, 51280, 51273>,
    <51272, 51273, 51277>    <51272, 51277, 51274>,
    <51272, 51274, 51278>    <51272, 51278, 51275>,
    <51272, 51275, 51279>    <51272, 51279, 51276>,
    <51272, 51276, 51280>    <51281, 51289, 51282>,
    <51281, 51282, 51286>    <51281, 51286, 51283>,
    <51281, 51283, 51287>    <51281, 51287, 51284>,
    <51281, 51284, 51288>    <51281, 51288, 51285>,
    <51281, 51285, 51289>    <51290, 51298, 51291>,
    <51290, 51291, 51295>    <51290, 51295, 51292>,
    <51290, 51292, 51296>    <51290, 51296, 51293>,
    <51290, 51293, 51297>    <51290, 51297, 51294>,
    <51290, 51294, 51298>    <51299, 51307, 51300>,
    <51299, 51300, 51304>    <51299, 51304, 51301>,
    <51299, 51301, 51305>    <51299, 51305, 51302>,
    <51299, 51302, 51306>    <51299, 51306, 51303>,
    <51299, 51303, 51307>    <51308, 51316, 51309>,
    <51308, 51309, 51313>    <51308, 51313, 51310>,
    <51308, 51310, 51314>    <51308, 51314, 51311>,
    <51308, 51311, 51315>    <51308, 51315, 51312>,
    <51308, 51312, 51316>    <51317, 51325, 51318>,
    <51317, 51318, 51322>    <51317, 51322, 51319>,
    <51317, 51319, 51323>    <51317, 51323, 51320>,
    <51317, 51320, 51324>    <51317, 51324, 51321>,
    <51317, 51321, 51325>    <51326, 51334, 51327>,
    <51326, 51327, 51331>    <51326, 51331, 51328>,
    <51326, 51328, 51332>    <51326, 51332, 51329>,
    <51326, 51329, 51333>    <51326, 51333, 51330>,
    <51326, 51330, 51334>    <51335, 51343, 51336>,
    <51335, 51336, 51340>    <51335, 51340, 51337>,
    <51335, 51337, 51341>    <51335, 51341, 51338>,
    <51335, 51338, 51342>    <51335, 51342, 51339>,
    <51335, 51339, 51343>    <51344, 51352, 51345>,
    <51344, 51345, 51349>    <51344, 51349, 51346>,
    <51344, 51346, 51350>    <51344, 51350, 51347>,
    <51344, 51347, 51351>    <51344, 51351, 51348>,
    <51344, 51348, 51352>    <51353, 51361, 51354>,
    <51353, 51354, 51358>    <51353, 51358, 51355>,
    <51353, 51355, 51359>    <51353, 51359, 51356>,
    <51353, 51356, 51360>    <51353, 51360, 51357>,
    <51353, 51357, 51361>    <51362, 51370, 51363>,
    <51362, 51363, 51367>    <51362, 51367, 51364>,
    <51362, 51364, 51368>    <51362, 51368, 51365>,
    <51362, 51365, 51369>    <51362, 51369, 51366>,
    <51362, 51366, 51370>    <51371, 51379, 51372>,
    <51371, 51372, 51376>    <51371, 51376, 51373>,
    <51371, 51373, 51377>    <51371, 51377, 51374>,
    <51371, 51374, 51378>    <51371, 51378, 51375>,
    <51371, 51375, 51379>    <51380, 51388, 51381>,
    <51380, 51381, 51385>    <51380, 51385, 51382>,
    <51380, 51382, 51386>    <51380, 51386, 51383>,
    <51380, 51383, 51387>    <51380, 51387, 51384>,
    <51380, 51384, 51388>    <51389, 51397, 51390>,
    <51389, 51390, 51394>    <51389, 51394, 51391>,
    <51389, 51391, 51395>    <51389, 51395, 51392>,
    <51389, 51392, 51396>    <51389, 51396, 51393>,
    <51389, 51393, 51397>    <51398, 51406, 51399>,
    <51398, 51399, 51403>    <51398, 51403, 51400>,
    <51398, 51400, 51404>    <51398, 51404, 51401>,
    <51398, 51401, 51405>    <51398, 51405, 51402>,
    <51398, 51402, 51406>    <51407, 51415, 51408>,
    <51407, 51408, 51412>    <51407, 51412, 51409>,
    <51407, 51409, 51413>    <51407, 51413, 51410>,
    <51407, 51410, 51414>    <51407, 51414, 51411>,
    <51407, 51411, 51415>    <51416, 51424, 51417>,
    <51416, 51417, 51421>    <51416, 51421, 51418>,
    <51416, 51418, 51422>    <51416, 51422, 51419>,
    <51416, 51419, 51423>    <51416, 51423, 51420>,
    <51416, 51420, 51424>    <51425, 51433, 51426>,
    <51425, 51426, 51430>    <51425, 51430, 51427>,
    <51425, 51427, 51431>    <51425, 51431, 51428>,
    <51425, 51428, 51432>    <51425, 51432, 51429>,
    <51425, 51429, 51433>    <51434, 51442, 51435>,
    <51434, 51435, 51439>    <51434, 51439, 51436>,
    <51434, 51436, 51440>    <51434, 51440, 51437>,
    <51434, 51437, 51441>    <51434, 51441, 51438>,
    <51434, 51438, 51442>    <51443, 51451, 51444>,
    <51443, 51444, 51448>    <51443, 51448, 51445>,
    <51443, 51445, 51449>    <51443, 51449, 51446>,
    <51443, 51446, 51450>    <51443, 51450, 51447>,
    <51443, 51447, 51451>    <51452, 51460, 51453>,
    <51452, 51453, 51457>    <51452, 51457, 51454>,
    <51452, 51454, 51458>    <51452, 51458, 51455>,
    <51452, 51455, 51459>    <51452, 51459, 51456>,
    <51452, 51456, 51460>    <51461, 51469, 51462>,
    <51461, 51462, 51466>    <51461, 51466, 51463>,
    <51461, 51463, 51467>    <51461, 51467, 51464>,
    <51461, 51464, 51468>    <51461, 51468, 51465>,
    <51461, 51465, 51469>    <51470, 51478, 51471>,
    <51470, 51471, 51475>    <51470, 51475, 51472>,
    <51470, 51472, 51476>    <51470, 51476, 51473>,
    <51470, 51473, 51477>    <51470, 51477, 51474>,
    <51470, 51474, 51478>    <51479, 51487, 51480>,
    <51479, 51480, 51484>    <51479, 51484, 51481>,
    <51479, 51481, 51485>    <51479, 51485, 51482>,
    <51479, 51482, 51486>    <51479, 51486, 51483>,
    <51479, 51483, 51487>    <51488, 51496, 51489>,
    <51488, 51489, 51493>    <51488, 51493, 51490>,
    <51488, 51490, 51494>    <51488, 51494, 51491>,
    <51488, 51491, 51495>    <51488, 51495, 51492>,
    <51488, 51492, 51496>    <51497, 51505, 51498>,
    <51497, 51498, 51502>    <51497, 51502, 51499>,
    <51497, 51499, 51503>    <51497, 51503, 51500>,
    <51497, 51500, 51504>    <51497, 51504, 51501>,
    <51497, 51501, 51505>    <51506, 51514, 51507>,
    <51506, 51507, 51511>    <51506, 51511, 51508>,
    <51506, 51508, 51512>    <51506, 51512, 51509>,
    <51506, 51509, 51513>    <51506, 51513, 51510>,
    <51506, 51510, 51514>    <51515, 51523, 51516>,
    <51515, 51516, 51520>    <51515, 51520, 51517>,
    <51515, 51517, 51521>    <51515, 51521, 51518>,
    <51515, 51518, 51522>    <51515, 51522, 51519>,
    <51515, 51519, 51523>    <51524, 51532, 51525>,
    <51524, 51525, 51529>    <51524, 51529, 51526>,
    <51524, 51526, 51530>    <51524, 51530, 51527>,
    <51524, 51527, 51531>    <51524, 51531, 51528>,
    <51524, 51528, 51532>    <51533, 51541, 51534>,
    <51533, 51534, 51538>    <51533, 51538, 51535>,
    <51533, 51535, 51539>    <51533, 51539, 51536>,
    <51533, 51536, 51540>    <51533, 51540, 51537>,
    <51533, 51537, 51541>    <51542, 51550, 51543>,
    <51542, 51543, 51547>    <51542, 51547, 51544>,
    <51542, 51544, 51548>    <51542, 51548, 51545>,
    <51542, 51545, 51549>    <51542, 51549, 51546>,
    <51542, 51546, 51550>    <51551, 51559, 51552>,
    <51551, 51552, 51556>    <51551, 51556, 51553>,
    <51551, 51553, 51557>    <51551, 51557, 51554>,
    <51551, 51554, 51558>    <51551, 51558, 51555>,
    <51551, 51555, 51559>    <51560, 51568, 51561>,
    <51560, 51561, 51565>    <51560, 51565, 51562>,
    <51560, 51562, 51566>    <51560, 51566, 51563>,
    <51560, 51563, 51567>    <51560, 51567, 51564>,
    <51560, 51564, 51568>    <51569, 51577, 51570>,
    <51569, 51570, 51574>    <51569, 51574, 51571>,
    <51569, 51571, 51575>    <51569, 51575, 51572>,
    <51569, 51572, 51576>    <51569, 51576, 51573>,
    <51569, 51573, 51577>    <51578, 51586, 51579>,
    <51578, 51579, 51583>    <51578, 51583, 51580>,
    <51578, 51580, 51584>    <51578, 51584, 51581>,
    <51578, 51581, 51585>    <51578, 51585, 51582>,
    <51578, 51582, 51586>    <51587, 51595, 51588>,
    <51587, 51588, 51592>    <51587, 51592, 51589>,
    <51587, 51589, 51593>    <51587, 51593, 51590>,
    <51587, 51590, 51594>    <51587, 51594, 51591>,
    <51587, 51591, 51595>    <51596, 51604, 51597>,
    <51596, 51597, 51601>    <51596, 51601, 51598>,
    <51596, 51598, 51602>    <51596, 51602, 51599>,
    <51596, 51599, 51603>    <51596, 51603, 51600>,
    <51596, 51600, 51604>    <51605, 51613, 51606>,
    <51605, 51606, 51610>    <51605, 51610, 51607>,
    <51605, 51607, 51611>    <51605, 51611, 51608>,
    <51605, 51608, 51612>    <51605, 51612, 51609>,
    <51605, 51609, 51613>    <51614, 51622, 51615>,
    <51614, 51615, 51619>    <51614, 51619, 51616>,
    <51614, 51616, 51620>    <51614, 51620, 51617>,
    <51614, 51617, 51621>    <51614, 51621, 51618>,
    <51614, 51618, 51622>    <51623, 51631, 51624>,
    <51623, 51624, 51628>    <51623, 51628, 51625>,
    <51623, 51625, 51629>    <51623, 51629, 51626>,
    <51623, 51626, 51630>    <51623, 51630, 51627>,
    <51623, 51627, 51631>    <51632, 51640, 51633>,
    <51632, 51633, 51637>    <51632, 51637, 51634>,
    <51632, 51634, 51638>    <51632, 51638, 51635>,
    <51632, 51635, 51639>    <51632, 51639, 51636>,
    <51632, 51636, 51640>    <51641, 51649, 51642>,
    <51641, 51642, 51646>    <51641, 51646, 51643>,
    <51641, 51643, 51647>    <51641, 51647, 51644>,
    <51641, 51644, 51648>    <51641, 51648, 51645>,
    <51641, 51645, 51649>    <51650, 51658, 51651>,
    <51650, 51651, 51655>    <51650, 51655, 51652>,
    <51650, 51652, 51656>    <51650, 51656, 51653>,
    <51650, 51653, 51657>    <51650, 51657, 51654>,
    <51650, 51654, 51658>    <51659, 51667, 51660>,
    <51659, 51660, 51664>    <51659, 51664, 51661>,
    <51659, 51661, 51665>    <51659, 51665, 51662>,
    <51659, 51662, 51666>    <51659, 51666, 51663>,
    <51659, 51663, 51667>    <51668, 51676, 51669>,
    <51668, 51669, 51673>    <51668, 51673, 51670>,
    <51668, 51670, 51674>    <51668, 51674, 51671>,
    <51668, 51671, 51675>    <51668, 51675, 51672>,
    <51668, 51672, 51676>    <51677, 51685, 51678>,
    <51677, 51678, 51682>    <51677, 51682, 51679>,
    <51677, 51679, 51683>    <51677, 51683, 51680>,
    <51677, 51680, 51684>    <51677, 51684, 51681>,
    <51677, 51681, 51685>    <51686, 51694, 51687>,
    <51686, 51687, 51691>    <51686, 51691, 51688>,
    <51686, 51688, 51692>    <51686, 51692, 51689>,
    <51686, 51689, 51693>    <51686, 51693, 51690>,
    <51686, 51690, 51694>    <51695, 51703, 51696>,
    <51695, 51696, 51700>    <51695, 51700, 51697>,
    <51695, 51697, 51701>    <51695, 51701, 51698>,
    <51695, 51698, 51702>    <51695, 51702, 51699>,
    <51695, 51699, 51703>    <51704, 51712, 51705>,
    <51704, 51705, 51709>    <51704, 51709, 51706>,
    <51704, 51706, 51710>    <51704, 51710, 51707>,
    <51704, 51707, 51711>    <51704, 51711, 51708>,
    <51704, 51708, 51712>    <51713, 51721, 51714>,
    <51713, 51714, 51718>    <51713, 51718, 51715>,
    <51713, 51715, 51719>    <51713, 51719, 51716>,
    <51713, 51716, 51720>    <51713, 51720, 51717>,
    <51713, 51717, 51721>    <51722, 51730, 51723>,
    <51722, 51723, 51727>    <51722, 51727, 51724>,
    <51722, 51724, 51728>    <51722, 51728, 51725>,
    <51722, 51725, 51729>    <51722, 51729, 51726>,
    <51722, 51726, 51730>    <51731, 51739, 51732>,
    <51731, 51732, 51736>    <51731, 51736, 51733>,
    <51731, 51733, 51737>    <51731, 51737, 51734>,
    <51731, 51734, 51738>    <51731, 51738, 51735>,
    <51731, 51735, 51739>    <51740, 51748, 51741>,
    <51740, 51741, 51745>    <51740, 51745, 51742>,
    <51740, 51742, 51746>    <51740, 51746, 51743>,
    <51740, 51743, 51747>    <51740, 51747, 51744>,
    <51740, 51744, 51748>    <51749, 51757, 51750>,
    <51749, 51750, 51754>    <51749, 51754, 51751>,
    <51749, 51751, 51755>    <51749, 51755, 51752>,
    <51749, 51752, 51756>    <51749, 51756, 51753>,
    <51749, 51753, 51757>    <51758, 51766, 51759>,
    <51758, 51759, 51763>    <51758, 51763, 51760>,
    <51758, 51760, 51764>    <51758, 51764, 51761>,
    <51758, 51761, 51765>    <51758, 51765, 51762>,
    <51758, 51762, 51766>    <51767, 51775, 51768>,
    <51767, 51768, 51772>    <51767, 51772, 51769>,
    <51767, 51769, 51773>    <51767, 51773, 51770>,
    <51767, 51770, 51774>    <51767, 51774, 51771>,
    <51767, 51771, 51775>    <51776, 51784, 51777>,
    <51776, 51777, 51781>    <51776, 51781, 51778>,
    <51776, 51778, 51782>    <51776, 51782, 51779>,
    <51776, 51779, 51783>    <51776, 51783, 51780>,
    <51776, 51780, 51784>    <51785, 51793, 51786>,
    <51785, 51786, 51790>    <51785, 51790, 51787>,
    <51785, 51787, 51791>    <51785, 51791, 51788>,
    <51785, 51788, 51792>    <51785, 51792, 51789>,
    <51785, 51789, 51793>    <51794, 51802, 51795>,
    <51794, 51795, 51799>    <51794, 51799, 51796>,
    <51794, 51796, 51800>    <51794, 51800, 51797>,
    <51794, 51797, 51801>    <51794, 51801, 51798>,
    <51794, 51798, 51802>    <51803, 51811, 51804>,
    <51803, 51804, 51808>    <51803, 51808, 51805>,
    <51803, 51805, 51809>    <51803, 51809, 51806>,
    <51803, 51806, 51810>    <51803, 51810, 51807>,
    <51803, 51807, 51811>    <51812, 51820, 51813>,
    <51812, 51813, 51817>    <51812, 51817, 51814>,
    <51812, 51814, 51818>    <51812, 51818, 51815>,
    <51812, 51815, 51819>    <51812, 51819, 51816>,
    <51812, 51816, 51820>    <51821, 51829, 51822>,
    <51821, 51822, 51826>    <51821, 51826, 51823>,
    <51821, 51823, 51827>    <51821, 51827, 51824>,
    <51821, 51824, 51828>    <51821, 51828, 51825>,
    <51821, 51825, 51829>    <51830, 51838, 51831>,
    <51830, 51831, 51835>    <51830, 51835, 51832>,
    <51830, 51832, 51836>    <51830, 51836, 51833>,
    <51830, 51833, 51837>    <51830, 51837, 51834>,
    <51830, 51834, 51838>    <51839, 51847, 51840>,
    <51839, 51840, 51844>    <51839, 51844, 51841>,
    <51839, 51841, 51845>    <51839, 51845, 51842>,
    <51839, 51842, 51846>    <51839, 51846, 51843>,
    <51839, 51843, 51847>    <51848, 51856, 51849>,
    <51848, 51849, 51853>    <51848, 51853, 51850>,
    <51848, 51850, 51854>    <51848, 51854, 51851>,
    <51848, 51851, 51855>    <51848, 51855, 51852>,
    <51848, 51852, 51856>    <51857, 51865, 51858>,
    <51857, 51858, 51862>    <51857, 51862, 51859>,
    <51857, 51859, 51863>    <51857, 51863, 51860>,
    <51857, 51860, 51864>    <51857, 51864, 51861>,
    <51857, 51861, 51865>    <51866, 51874, 51867>,
    <51866, 51867, 51871>    <51866, 51871, 51868>,
    <51866, 51868, 51872>    <51866, 51872, 51869>,
    <51866, 51869, 51873>    <51866, 51873, 51870>,
    <51866, 51870, 51874>    <51875, 51883, 51876>,
    <51875, 51876, 51880>    <51875, 51880, 51877>,
    <51875, 51877, 51881>    <51875, 51881, 51878>,
    <51875, 51878, 51882>    <51875, 51882, 51879>,
    <51875, 51879, 51883>    <51884, 51892, 51885>,
    <51884, 51885, 51889>    <51884, 51889, 51886>,
    <51884, 51886, 51890>    <51884, 51890, 51887>,
    <51884, 51887, 51891>    <51884, 51891, 51888>,
    <51884, 51888, 51892>    <51893, 51901, 51894>,
    <51893, 51894, 51898>    <51893, 51898, 51895>,
    <51893, 51895, 51899>    <51893, 51899, 51896>,
    <51893, 51896, 51900>    <51893, 51900, 51897>,
    <51893, 51897, 51901>    <51902, 51910, 51903>,
    <51902, 51903, 51907>    <51902, 51907, 51904>,
    <51902, 51904, 51908>    <51902, 51908, 51905>,
    <51902, 51905, 51909>    <51902, 51909, 51906>,
    <51902, 51906, 51910>    <51911, 51919, 51912>,
    <51911, 51912, 51916>    <51911, 51916, 51913>,
    <51911, 51913, 51917>    <51911, 51917, 51914>,
    <51911, 51914, 51918>    <51911, 51918, 51915>,
    <51911, 51915, 51919>    <51920, 51928, 51921>,
    <51920, 51921, 51925>    <51920, 51925, 51922>,
    <51920, 51922, 51926>    <51920, 51926, 51923>,
    <51920, 51923, 51927>    <51920, 51927, 51924>,
    <51920, 51924, 51928>    <51929, 51937, 51930>,
    <51929, 51930, 51934>    <51929, 51934, 51931>,
    <51929, 51931, 51935>    <51929, 51935, 51932>,
    <51929, 51932, 51936>    <51929, 51936, 51933>,
    <51929, 51933, 51937>    <51938, 51946, 51939>,
    <51938, 51939, 51943>    <51938, 51943, 51940>,
    <51938, 51940, 51944>    <51938, 51944, 51941>,
    <51938, 51941, 51945>    <51938, 51945, 51942>,
    <51938, 51942, 51946>    <51947, 51955, 51948>,
    <51947, 51948, 51952>    <51947, 51952, 51949>,
    <51947, 51949, 51953>    <51947, 51953, 51950>,
    <51947, 51950, 51954>    <51947, 51954, 51951>,
    <51947, 51951, 51955>    <51956, 51964, 51957>,
    <51956, 51957, 51961>    <51956, 51961, 51958>,
    <51956, 51958, 51962>    <51956, 51962, 51959>,
    <51956, 51959, 51963>    <51956, 51963, 51960>,
    <51956, 51960, 51964>    <51965, 51973, 51966>,
    <51965, 51966, 51970>    <51965, 51970, 51967>,
    <51965, 51967, 51971>    <51965, 51971, 51968>,
    <51965, 51968, 51972>    <51965, 51972, 51969>,
    <51965, 51969, 51973>    <51974, 51982, 51975>,
    <51974, 51975, 51979>    <51974, 51979, 51976>,
    <51974, 51976, 51980>    <51974, 51980, 51977>,
    <51974, 51977, 51981>    <51974, 51981, 51978>,
    <51974, 51978, 51982>    <51983, 51991, 51984>,
    <51983, 51984, 51988>    <51983, 51988, 51985>,
    <51983, 51985, 51989>    <51983, 51989, 51986>,
    <51983, 51986, 51990>    <51983, 51990, 51987>,
    <51983, 51987, 51991>    <51992, 52000, 51993>,
    <51992, 51993, 51997>    <51992, 51997, 51994>,
    <51992, 51994, 51998>    <51992, 51998, 51995>,
    <51992, 51995, 51999>    <51992, 51999, 51996>,
    <51992, 51996, 52000>    <52001, 52009, 52002>,
    <52001, 52002, 52006>    <52001, 52006, 52003>,
    <52001, 52003, 52007>    <52001, 52007, 52004>,
    <52001, 52004, 52008>    <52001, 52008, 52005>,
    <52001, 52005, 52009>    <52010, 52018, 52011>,
    <52010, 52011, 52015>    <52010, 52015, 52012>,
    <52010, 52012, 52016>    <52010, 52016, 52013>,
    <52010, 52013, 52017>    <52010, 52017, 52014>,
    <52010, 52014, 52018>    <52019, 52027, 52020>,
    <52019, 52020, 52024>    <52019, 52024, 52021>,
    <52019, 52021, 52025>    <52019, 52025, 52022>,
    <52019, 52022, 52026>    <52019, 52026, 52023>,
    <52019, 52023, 52027>    <52028, 52036, 52029>,
    <52028, 52029, 52033>    <52028, 52033, 52030>,
    <52028, 52030, 52034>    <52028, 52034, 52031>,
    <52028, 52031, 52035>    <52028, 52035, 52032>,
    <52028, 52032, 52036>    <52037, 52045, 52038>,
    <52037, 52038, 52042>    <52037, 52042, 52039>,
    <52037, 52039, 52043>    <52037, 52043, 52040>,
    <52037, 52040, 52044>    <52037, 52044, 52041>,
    <52037, 52041, 52045>    <52046, 52054, 52047>,
    <52046, 52047, 52051>    <52046, 52051, 52048>,
    <52046, 52048, 52052>    <52046, 52052, 52049>,
    <52046, 52049, 52053>    <52046, 52053, 52050>,
    <52046, 52050, 52054>    <52055, 52063, 52056>,
    <52055, 52056, 52060>    <52055, 52060, 52057>,
    <52055, 52057, 52061>    <52055, 52061, 52058>,
    <52055, 52058, 52062>    <52055, 52062, 52059>,
    <52055, 52059, 52063>    <52064, 52072, 52065>,
    <52064, 52065, 52069>    <52064, 52069, 52066>,
    <52064, 52066, 52070>    <52064, 52070, 52067>,
    <52064, 52067, 52071>    <52064, 52071, 52068>,
    <52064, 52068, 52072>    <52073, 52081, 52074>,
    <52073, 52074, 52078>    <52073, 52078, 52075>,
    <52073, 52075, 52079>    <52073, 52079, 52076>,
    <52073, 52076, 52080>    <52073, 52080, 52077>,
    <52073, 52077, 52081>    <52082, 52090, 52083>,
    <52082, 52083, 52087>    <52082, 52087, 52084>,
    <52082, 52084, 52088>    <52082, 52088, 52085>,
    <52082, 52085, 52089>    <52082, 52089, 52086>,
    <52082, 52086, 52090>    <52091, 52099, 52092>,
    <52091, 52092, 52096>    <52091, 52096, 52093>,
    <52091, 52093, 52097>    <52091, 52097, 52094>,
    <52091, 52094, 52098>    <52091, 52098, 52095>,
    <52091, 52095, 52099>    <52100, 52108, 52101>,
    <52100, 52101, 52105>    <52100, 52105, 52102>,
    <52100, 52102, 52106>    <52100, 52106, 52103>,
    <52100, 52103, 52107>    <52100, 52107, 52104>,
    <52100, 52104, 52108>    <52109, 52117, 52110>,
    <52109, 52110, 52114>    <52109, 52114, 52111>,
    <52109, 52111, 52115>    <52109, 52115, 52112>,
    <52109, 52112, 52116>    <52109, 52116, 52113>,
    <52109, 52113, 52117>    <52118, 52126, 52119>,
    <52118, 52119, 52123>    <52118, 52123, 52120>,
    <52118, 52120, 52124>    <52118, 52124, 52121>,
    <52118, 52121, 52125>    <52118, 52125, 52122>,
    <52118, 52122, 52126>    <52127, 52135, 52128>,
    <52127, 52128, 52132>    <52127, 52132, 52129>,
    <52127, 52129, 52133>    <52127, 52133, 52130>,
    <52127, 52130, 52134>    <52127, 52134, 52131>,
    <52127, 52131, 52135>    <52136, 52144, 52137>,
    <52136, 52137, 52141>    <52136, 52141, 52138>,
    <52136, 52138, 52142>    <52136, 52142, 52139>,
    <52136, 52139, 52143>    <52136, 52143, 52140>,
    <52136, 52140, 52144>    <52145, 52153, 52146>,
    <52145, 52146, 52150>    <52145, 52150, 52147>,
    <52145, 52147, 52151>    <52145, 52151, 52148>,
    <52145, 52148, 52152>    <52145, 52152, 52149>,
    <52145, 52149, 52153>    <52154, 52162, 52155>,
    <52154, 52155, 52159>    <52154, 52159, 52156>,
    <52154, 52156, 52160>    <52154, 52160, 52157>,
    <52154, 52157, 52161>    <52154, 52161, 52158>,
    <52154, 52158, 52162>    <52163, 52171, 52164>,
    <52163, 52164, 52168>    <52163, 52168, 52165>,
    <52163, 52165, 52169>    <52163, 52169, 52166>,
    <52163, 52166, 52170>    <52163, 52170, 52167>,
    <52163, 52167, 52171>    <52172, 52180, 52173>,
    <52172, 52173, 52177>    <52172, 52177, 52174>,
    <52172, 52174, 52178>    <52172, 52178, 52175>,
    <52172, 52175, 52179>    <52172, 52179, 52176>,
    <52172, 52176, 52180>    <52181, 52189, 52182>,
    <52181, 52182, 52186>    <52181, 52186, 52183>,
    <52181, 52183, 52187>    <52181, 52187, 52184>,
    <52181, 52184, 52188>    <52181, 52188, 52185>,
    <52181, 52185, 52189>    <52190, 52198, 52191>,
    <52190, 52191, 52195>    <52190, 52195, 52192>,
    <52190, 52192, 52196>    <52190, 52196, 52193>,
    <52190, 52193, 52197>    <52190, 52197, 52194>,
    <52190, 52194, 52198>    <52199, 52207, 52200>,
    <52199, 52200, 52204>    <52199, 52204, 52201>,
    <52199, 52201, 52205>    <52199, 52205, 52202>,
    <52199, 52202, 52206>    <52199, 52206, 52203>,
    <52199, 52203, 52207>    <52208, 52216, 52209>,
    <52208, 52209, 52213>    <52208, 52213, 52210>,
    <52208, 52210, 52214>    <52208, 52214, 52211>,
    <52208, 52211, 52215>    <52208, 52215, 52212>,
    <52208, 52212, 52216>    <52217, 52225, 52218>,
    <52217, 52218, 52222>    <52217, 52222, 52219>,
    <52217, 52219, 52223>    <52217, 52223, 52220>,
    <52217, 52220, 52224>    <52217, 52224, 52221>,
    <52217, 52221, 52225>    <52226, 52234, 52227>,
    <52226, 52227, 52231>    <52226, 52231, 52228>,
    <52226, 52228, 52232>    <52226, 52232, 52229>,
    <52226, 52229, 52233>    <52226, 52233, 52230>,
    <52226, 52230, 52234>    <52235, 52243, 52236>,
    <52235, 52236, 52240>    <52235, 52240, 52237>,
    <52235, 52237, 52241>    <52235, 52241, 52238>,
    <52235, 52238, 52242>    <52235, 52242, 52239>,
    <52235, 52239, 52243>    <52244, 52252, 52245>,
    <52244, 52245, 52249>    <52244, 52249, 52246>,
    <52244, 52246, 52250>    <52244, 52250, 52247>,
    <52244, 52247, 52251>    <52244, 52251, 52248>,
    <52244, 52248, 52252>    <52253, 52261, 52254>,
    <52253, 52254, 52258>    <52253, 52258, 52255>,
    <52253, 52255, 52259>    <52253, 52259, 52256>,
    <52253, 52256, 52260>    <52253, 52260, 52257>,
    <52253, 52257, 52261>    <52262, 52270, 52263>,
    <52262, 52263, 52267>    <52262, 52267, 52264>,
    <52262, 52264, 52268>    <52262, 52268, 52265>,
    <52262, 52265, 52269>    <52262, 52269, 52266>,
    <52262, 52266, 52270>    <52271, 52279, 52272>,
    <52271, 52272, 52276>    <52271, 52276, 52273>,
    <52271, 52273, 52277>    <52271, 52277, 52274>,
    <52271, 52274, 52278>    <52271, 52278, 52275>,
    <52271, 52275, 52279>    <52280, 52288, 52281>,
    <52280, 52281, 52285>    <52280, 52285, 52282>,
    <52280, 52282, 52286>    <52280, 52286, 52283>,
    <52280, 52283, 52287>    <52280, 52287, 52284>,
    <52280, 52284, 52288>
  }
  uv_mapping
  scale 0.996206
  rotate 3.069052*z
  translate  0.276305*z
}

#declare nordsud = union {
  box { // Cube057
    <-1, -1, -1>, <1, 1, 1>
    photons {
      collect off
    }
    scale <0.3, 0.006, 0.006>
    translate  <0.0, -0.000155, 0.198816>
  }
  text {   // TText001
    ttf      "Timesbd.ttf",
    "S",
    0.06,  // Depth
    <0.0,     0.0, 0.0> // Offset
    photons {
      collect off
    }
    scale 0.097082
    rotate <90.0, 0.0, -180.0>
    translate  <0.340472, -0.001823, 0.178>
  }

  text {   // TText002
    ttf      "Timesbd.ttf",
    "N",
    0.06,  // Depth
    <0.0,     0.0, 0.0> // Offset
    photons {
      collect off
    }
    scale 0.097082
    rotate 90.0*x
    translate  <-0.34441, 0.002767, 0.178613>
  }

  photons {
    collect off
  }
  scale 1.7
  translate  0.2*z
}
#declare nordsud1 = union {
  box { // Cube058
    <-1, -1, -1>, <1, 1, 1>
    photons {
      collect off
    }
    scale <0.3, 0.006, 0.006>
    translate  <0.0, -0.000155, 0.198816>
  }
  text {   // TText003
    ttf      "Timesbd.ttf",
    "W",
    0.06,  // Depth
    <0.0,     0.0, 0.0> // Offset
    photons {
      collect off
    }
    scale 0.097082
    rotate 90.0*x
    translate  <0.280669, 0.002644, 0.178>
  }

  text {   // TText004
    ttf      "Timesbd.ttf",
    "E",
    0.06,  // Depth
    <0.0,     0.0, 0.0> // Offset
    photons {
      collect off
    }
    scale 0.097082
    rotate <90.0, 0.0, -180.0>
    translate  <-0.29722, -0.004396, 0.178613>
  }

  photons {
    collect off
  }
  scale 1.7
  rotate -90.0*z
  translate  0.2*z
}
#declare Girouette = union {
  object { nordsud }
  cone { // Cone002
    <0,0,0>, 0.012, <0,0,1>, 0.002
    photons {
      collect off
    }
    scale <1.0, 1.0, 0.6>
  }
  object { nordsud1 }
  object { TransSweep029 }
  cone { // Cone008
    <0,0,0>, 0.009, <0,0,1>, 0.004
    photons {
      collect off
    }
    scale <1.0, 1.0, 0.22>
    translate  0.390815*z
  }
  cone { // Cone009
    <0,0,0>, 0.02, <0,0,1>, 0.002
    photons {
      collect off
    }
    scale <1.0, 1.0, 3.0>
  }
  object { // TransSweep030 -> TransSweep029
    TransSweep029
    rotate <0.0, -0.0, -45.0>
    translate  <-0.013418, 0.012849, 0.0>
  }
  sphere { // Sphere005
    <0,0,0>,1
    scale 0.1
    translate  <0.0, -0.0, 0.915194>
  }
  material {
    T_toit
  }
  photons {
    collect off
  }
  rotate <-0.0, 0.0, 111.625648>
  translate  37.40367*z
}
#declare Armature = union {
  object { Cube140 }
  object { // Cube141 -> Cube140
    Cube140
    rotate -60.0*z
    translate  -0.028421*z
  }
  object { // Cube142 -> Cube140
    Cube140
    rotate -120.0*z
    translate  -0.028421*z
  }
  object { // Cube143 -> Cube140
    Cube140
    rotate -180.0*z
    translate  -0.028421*z
  }
  object { // Cube144 -> Cube140
    Cube140
    rotate 120.0*z
    translate  -0.028421*z
  }
  object { // Cube145 -> Cube140
    Cube140
    rotate 60.0*z
    translate  -0.028421*z
  }
  disc { // Disc001
    <0,0,0>, <0,0,1>, 1.0, 0.18
    scale 0.4
    translate  33.571053*z
  }
  torus { // Torus026
    1.0, 0.02  rotate -x*90
    translate  <0.0, -0.034247, 33.529967>
  }
  material {
    T_peinture_Bois
  }
  translate  0.464396*z
}
#declare Calotte = union {
  object { Coupe_tore }
  object { Hemisphere }
  object { Boule_porteboule }
  object { TMesh017 }
  object { Girouette }
  object { Armature }
  material {
    T_peinture_rouge_metal
  }
  translate  -0.464396*z
}
#declare Vitre_circulaire = difference {
  cylinder { // Cylndr046
    <0,0,1>, <0,0,0>, 1 
    scale <1.66, 1.66, 2.49>
    translate  31.0*z
  }
  cylinder { // Cylndr047
    <0,0,1>, <0,0,0>, 1 
    scale <1.64, 1.64, 2.51>
    translate  30.99*z
  }
  material {
    Mat_verre_rouge
  }
}
#declare REnfortsevrtic = union {
  object { Cylndr075 }
  object { // Cylndr076 -> Cylndr075
    Cylndr075
    rotate -22.5*z
    translate  -0.0*z
  }
  object { // Cylndr079 -> Cylndr075
    Cylndr075
    rotate -45.0*z
    translate  -0.0*z
  }
  object { // Cylndr080 -> Cylndr075
    Cylndr075
    rotate -67.5*z
    translate  -0.0*z
  }
  object { // Cylndr081 -> Cylndr075
    Cylndr075
    rotate -90.0*z
    translate  -0.0*z
  }
  object { // Cylndr082 -> Cylndr075
    Cylndr075
    rotate -112.5*z
    translate  -0.0*z
  }
  object { // Cylndr083 -> Cylndr075
    Cylndr075
    rotate -135.0*z
    translate  -0.0*z
  }
  object { // Cylndr084 -> Cylndr075
    Cylndr075
    rotate -157.5*z
    translate  -0.0*z
  }
  object { // Cylndr085 -> Cylndr075
    Cylndr075
    rotate 180.0*z
    translate  -0.0*z
  }
  object { // Cylndr086 -> Cylndr075
    Cylndr075
    rotate 157.5*z
    translate  -0.0*z
  }
  object { // Cylndr087 -> Cylndr075
    Cylndr075
    rotate 135.0*z
    translate  -0.0*z
  }
  object { // Cylndr088 -> Cylndr075
    Cylndr075
    rotate 112.5*z
    translate  -0.0*z
  }
  object { // Cylndr106 -> Cylndr075
    Cylndr075
    rotate 90.0*z
    translate  -0.0*z
  }
  object { // Cylndr110 -> Cylndr075
    Cylndr075
    rotate 67.5*z
    translate  -0.0*z
  }
  object { // Cylndr111 -> Cylndr075
    Cylndr075
    rotate 45.0*z
    translate  -0.0*z
  }
  object { // Cylndr112 -> Cylndr075
    Cylndr075
    rotate 22.5*z
    translate  -0.0*z
  }
}
#declare Tourelle = union {
  cylinder { // Cylndr045
    <0,0,1>, <0,0,0>, 1 
    scale <1.65, 1.65, 2.0>
    translate  29.0*z
    material {
      T_peinture_rouge_norm
      // Transform to parent space
    }
  }
  object { Vitre_circulaire }
  object { REnfort_vitre_circulaire }
  object { // REnfort_vitre_circulaire1 -> REnfort_vitre_circulaire
    REnfort_vitre_circulaire
    translate  0.83*z
  }
  object { // REnfort_vitre_circulaire2 -> REnfort_vitre_circulaire
    REnfort_vitre_circulaire
    translate  1.66*z
  }
  object { // REnfort_vitre_circulaire3 -> REnfort_vitre_circulaire
    REnfort_vitre_circulaire
    translate  2.49*z
  }
  cylinder { // Cylndr056
    <0,0,1>, <0,0,0>, 1 
    scale <2.25, 2.25, 0.08>
    translate  30.85*z
    material {
      T_peinture_rouge_norm
      // Transform to parent space
    }
  }
  object { REnfortsevrtic }
  cylinder { // Cylndr074
    <0,0,1>, <0,0,0>, 1 
    scale <1.65, 1.65, 1.0>
    translate  -1.0*z
    material {
      T_peinture_rouge
    }
    scale <1.0, 1.0, 0.1>
    translate  31.013526*z
  }
  material {
    T_peinture_rouge_metal
  }
}
#declare Lentille = intersection {
  object { Sphere006 }
  object { // Sphere007 -> Sphere006
    Sphere006
    scale <1.0, -1.0, 1.0>
  }
  material {
    Mat_verre_lentille
  }
}
#declare Coupe_optique = intersection {
  object { Cylndr071 }
  object { Lentille }
}
#declare Fourreau_optique = difference {
  cylinder { // Cylndr052
    <0,0,1>, <0,0,0>, 1 
    translate  -0.5*z
    scale <1.2, 1.2, 0.244615>
    rotate -90.0*x
  }
  cylinder { // Cylndr070
    <0,0,1>, <0,0,0>, 1 
    translate  -0.5*z
    scale <1.19, 1.19, 0.25>
    rotate -90.0*x
  }
  material {
    T_bronze
  }
}
#declare Optique = union {
  object { Face_cerclage }
  object { // Face_cerclage1 -> Face_cerclage
    Face_cerclage
    scale <1.0, -1.0, 1.0>
  }
  object { // Face_cerclage2 -> Face_cerclage
    Face_cerclage
  }
  object { // Face_cerclage3 -> Face_cerclage
    Face_cerclage
  }
  object { // Face_cerclage4 -> Face_cerclage
    Face_cerclage
  }
  object { // Face_cerclage5 -> Face_cerclage
    Face_cerclage
  }
  object { // Face_cerclage6 -> Face_cerclage
    Face_cerclage
  }
  object { // Face_cerclage7 -> Face_cerclage
    Face_cerclage
  }
  object { Coupe_optique }
  object { Fourreau_optique }
  object { Cadre_opt_carre }
  object { // Cadre_opt_carre1 -> Cadre_opt_carre
    Cadre_opt_carre
    scale <1.0, -1.0, 1.0>
  }
  object { Coupe_pied_optique }
  object { // Coupe_pied_optique1 -> Coupe_pied_optique
    Coupe_pied_optique
    scale <-1.0, 1.0, 1.0>
  }
  translate  1.5*z
  // Scaling fixed
  // Translation fixed
  translate  30.768139*z
}
#declare REnfortsevrtic1 = union {
  object { Cube114 }
  object { // Cube115 -> Cube114
    Cube114
    rotate -22.5*z
    translate  <-0.000003, 0.000001, -0.0>
  }
  object { // Cube116 -> Cube114
    Cube114
    rotate -45.0*z
    translate  <-0.000006, 0.000002, -0.0>
  }
  object { // Cube117 -> Cube114
    Cube114
    rotate -67.5*z
    translate  <-0.000007, 0.000005, -0.0>
  }
  object { // Cube118 -> Cube114
    Cube114
    rotate -90.0*z
    translate  <-0.000008, 0.000008, -0.0>
  }
  object { // Cube119 -> Cube114
    Cube114
    rotate -112.5*z
    translate  <-0.000007, 0.000011, -0.0>
  }
  object { // Cube120 -> Cube114
    Cube114
    rotate -135.0*z
    translate  <-0.000006, 0.000013, -0.0>
  }
  object { // Cube121 -> Cube114
    Cube114
    rotate -157.5*z
    translate  <-0.000003, 0.000015, -0.0>
  }
  object { // Cube122 -> Cube114
    Cube114
    rotate 180.0*z
    translate  <0.0, 0.000016, -0.0>
  }
  object { // Cube123 -> Cube114
    Cube114
    rotate 157.5*z
    translate  <0.000003, 0.000015, -0.0>
  }
  object { // Cube124 -> Cube114
    Cube114
    rotate 135.0*z
    translate  <0.000006, 0.000013, -0.0>
  }
  object { // Cube125 -> Cube114
    Cube114
    rotate 112.5*z
    translate  <0.000007, 0.000011, -0.0>
  }
  object { // Cube126 -> Cube114
    Cube114
    rotate 90.0*z
    translate  <0.000008, 0.000008, -0.0>
  }
  object { // Cube127 -> Cube114
    Cube114
    rotate 67.5*z
    translate  <0.000007, 0.000005, -0.0>
  }
  object { // Cube128 -> Cube114
    Cube114
    rotate 45.0*z
    translate  <0.000006, 0.000002, -0.0>
  }
  object { // Cube129 -> Cube114
    Cube114
    rotate 22.5*z
    translate  <0.000003, 0.000001, -0.0>
  }
}
#declare Tourelle_interne = union {
  object { REnfort_vitre_circulaire4 }
  object { REnfortsevrtic1 }
  object { // REnfort_vitre_circulaire5 -> REnfort_vitre_circulaire4
    REnfort_vitre_circulaire4
    translate  0.83*z
  }
  object { // REnfort_vitre_circulaire6 -> REnfort_vitre_circulaire4
    REnfort_vitre_circulaire4
    translate  1.66*z
  }
  object { // REnfort_vitre_circulaire7 -> REnfort_vitre_circulaire4
    REnfort_vitre_circulaire4
    translate  2.49*z
  }
  material {
    T_peinture_Bois
  }
}
#declare Poteau_drapeau = union {
  cylinder { // Cylndr109
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 3.0>
  }
  sphere { // Sphere010
    <0,0,0>,1
    material {
      T_toit
    }
    scale 0.06
    translate  3.0*z
  }
  material {
    T_toit
  }
  rotate -39.540237*y
  translate  <-2.807173, -0.028149, 30.133061>
}
#declare Coupe_tore_rembarde_cabine5 = intersection {
  torus { // Torus032
    0.1, 0.015  rotate -x*90
  }
  box { // Cube034
    <-1, -1, -1>, <1, 1, 1>
    translate  <1.0, 1.0, 0.0>
    scale <0.12, 0.12, 0.02>
    rotate -90.0*z
  }
  scale -1.0
  rotate <179.996368, 89.988495, 104.022957>
  translate  <0.430476, -1.718742, 0.604903>
}
#declare Union_marches = union {
  object { Cube087 }
  object { // Cube107 -> Cube087
    Cube087
    translate  <0.12, 0.0, 0.16>
  }
  object { // Cube108 -> Cube087
    Cube087
    translate  <0.24, 0.0, 0.32>
  }
  object { // Cube109 -> Cube087
    Cube087
    translate  <0.36, 0.0, 0.48>
  }
  object { // Cube110 -> Cube087
    Cube087
    translate  <0.48, 0.0, 0.64>
  }
  object { // Cube111 -> Cube087
    Cube087
    translate  <0.6, 0.0, 0.8>
  }
  object { // Cube112 -> Cube087
    Cube087
    translate  <0.72, 0.0, 0.96>
  }
  object { Cylndr126 }
  object { // Cylndr127 -> Cylndr126
    Cylndr126
    rotate <0.0, -0.0, 0.0>
    translate  <-0.127485, 0.005751, 0.013774>
  }
  object { Cylndr128 }
  object { // Cylndr129 -> Cylndr128
    Cylndr128
    rotate -0.0*z
    translate  <-0.149778, 0.022861, -0.020661>
  }
  rotate 9.742507*z
  translate  <-0.097809, -1.860279, 0.0>
}
#declare Rembarde_cabine = union {
  object { Cylndr035 }
  object { // Cylndr036 -> Cylndr035
    Cylndr035
    rotate 0.0*z
    translate  -0.6*y
  }
  object { // Cylndr037 -> Cylndr035
    Cylndr035
    rotate 0.0*z
    translate  -1.2*y
  }
  object { // Cylndr038 -> Cylndr035
    Cylndr035
    rotate 0.0*z
    translate  <-0.224145, 0.245158, 0.0>
  }
  cylinder { // Cylndr042
    <0,0,1>, <0,0,0>, 1 
    scale <-0.015, -0.015, -0.7>
    rotate <-180.0, 0.0, 134.842712>
    translate  <1.090673, -1.947545, 0.0>
  }
  object { // Cylndr043 -> Cylndr035
    Cylndr035
    scale -1.0
    rotate <-180.0, 0.0, 134.842712>
    translate  <0.425427, 0.423098, 0.0>
  }
  object { // Cylndr044 -> Cylndr035
    Cylndr035
    scale -1.0
    rotate <-180.0, 0.0, 134.842712>
    translate  <0.850854, 0.846196, 0.0>
  }
  object { Coupe_tore_rembarde_cabine5 }
  object { Bastingage_cabine }
  object { // Bastingage_cabine1 -> Bastingage_cabine
    Bastingage_cabine
    translate  -0.35*z
  }
  cylinder { // Cylndr069
    <0,0,1>, <0,0,0>, 1 
    scale <-0.015, -0.015, -0.7>
    rotate <-180.0, 0.0, 134.842712>
    translate  <0.527036, -1.693154, -0.093247>
  }
  cylinder { // Cylndr089
    <0,0,1>, <0,0,0>, 1 
    scale <-0.015, -0.015, -0.7>
    rotate <-180.0, 0.0, 134.842712>
    translate  <0.869647, -2.06706, -0.000637>
  }
  object { Union_marches }
  material {
    T_peinture_rouge_norm
  }
  scale 1.25
  translate  30.93716*z
}
#declare Rembarde_tourelle = union {
  object { Cylndr039 }
  object { // Cylndr055 -> Cylndr039
    Cylndr039
    rotate -135.0*z
  }
  object { // Cylndr057 -> Cylndr039
    Cylndr039
    rotate -157.5*z
  }
  object { // Cylndr058 -> Cylndr039
    Cylndr039
    rotate 180.0*z
  }
  object { // Cylndr059 -> Cylndr039
    Cylndr039
    rotate 157.5*z
  }
  object { // Cylndr060 -> Cylndr039
    Cylndr039
    rotate 135.0*z
  }
  object { // Cylndr061 -> Cylndr039
    Cylndr039
    rotate 112.5*z
  }
  object { // Cylndr062 -> Cylndr039
    Cylndr039
    rotate 90.0*z
  }
  object { // Cylndr063 -> Cylndr039
    Cylndr039
    rotate 67.5*z
  }
  object { // Cylndr064 -> Cylndr039
    Cylndr039
    rotate 45.0*z
  }
  object { // Cylndr065 -> Cylndr039
    Cylndr039
    rotate 22.5*z
  }
  object { Coupe_tore_rembarde_tourelle }
  object { Coupe_tore_rembarde_tourelle1 }
  object { // Coupe_tore_rembarde_tourelle2 -> Coupe_tore_rembarde_tourelle1
    Coupe_tore_rembarde_tourelle1
    rotate 3.262552*z
  }
  material {
    T_peinture_rouge_norm
  }
  scale 1.25
  translate  30.93716*z
}
#declare Rembarde_plate_forme = union {
  object { Cylndr066 }
  object { // Cylndr091 -> Cylndr066
    Cylndr066
    rotate -0.0*z
    translate  <0.635, 0.0, 0.0>
  }
  object { // Cylndr092 -> Cylndr066
    Cylndr066
    rotate -0.0*z
    translate  <1.27, 0.0, 0.0>
  }
  object { Cylndr093 }
  object { // Cylndr094 -> Cylndr093
    Cylndr093
    translate  <0.0, 0.0, -0.25>
  }
  object { // Cylndr095 -> Cylndr093
    Cylndr093
    translate  <0.0, 0.0, -0.5>
  }
  object { // Cylndr096 -> Cylndr093
    Cylndr093
    translate  <0.0, 0.0, -0.606713>
  }
}
#declare Rembarde_plate_forme1 = union {
  cylinder { // Cylndr097
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 0.608351>
    translate  <-0.63418, 3.46605, 0.076374>
  }
  object { // Cylndr098 -> Cylndr066
    Cylndr066
    rotate -0.0*z
    translate  <0.57544, 0.0, 0.0>
  }
  object { // Cylndr099 -> Cylndr066
    Cylndr066
    rotate -0.0*z
    translate  <1.150881, 0.0, 0.0>
  }
  cylinder { // Cylndr100
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 1.153644>
    rotate 90.0*y
    translate  <-0.63418, 3.46605, 0.686205>
  }
  object { // Cylndr101 -> Cylndr093
    Cylndr093
    scale <0.893569, 1.0, 1.0>
    translate  <-0.071472, 0.0, -0.25>
  }
  object { // Cylndr102 -> Cylndr093
    Cylndr093
    scale <0.898749, 1.0, 1.0>
    translate  <-0.071472, 0.0, -0.5>
  }
  object { // Cylndr103 -> Cylndr093
    Cylndr093
    translate  <0.0, 0.0, -0.606713>
  }
  translate  -3.452995*y
  rotate -90.0*z
  translate  <0.622671, 2.831027, 0.0>
}
#declare Rembarde_plate_forme2 = union {
  cylinder { // Cylndr104
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 0.608351>
    translate  <-0.63418, 3.46605, 0.076374>
  }
  object { // Cylndr105 -> Cylndr066
    Cylndr066
    rotate -0.0*z
    translate  <0.635, 0.0, 0.0>
  }
  object { // Cylndr107 -> Cylndr066
    Cylndr066
    rotate -0.0*z
    translate  <1.27, 0.0, 0.0>
  }
  cylinder { // Cylndr108
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 1.286438>
    rotate 90.0*y
    translate  <-0.63418, 3.46605, 0.686205>
  }
  object { // Cylndr113 -> Cylndr093
    Cylndr093
    translate  <0.0, 0.0, -0.25>
  }
  object { // Cylndr114 -> Cylndr093
    Cylndr093
    translate  <0.0, 0.0, -0.5>
  }
  object { // Cylndr115 -> Cylndr093
    Cylndr093
    translate  <0.0, 0.0, -0.606713>
  }
  cylinder { // Cylndr123
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 1.286438>
    rotate <-179.281357, 49.144623, 133.628494>
    translate  <0.648718, 3.46605, 0.686438>
  }
  cylinder { // Cylndr124
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 1.286438>
    rotate <-179.281357, 49.144623, 133.628494>
    translate  <0.649707, 3.852369, 0.683726>
  }
  translate  -1.544197*y
}
#declare Rembarde_plate_forme3 = union {
  cylinder { // Cylndr116
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 0.608351>
    translate  <-0.63418, 3.46605, 0.076374>
  }
  object { // Cylndr117 -> Cylndr066
    Cylndr066
    rotate -0.0*z
    translate  <0.635, 0.0, 0.0>
  }
  object { // Cylndr118 -> Cylndr066
    Cylndr066
    rotate -0.0*z
    translate  <1.27, 0.0, 0.0>
  }
  cylinder { // Cylndr119
    <0,0,1>, <0,0,0>, 1 
    scale <0.015, 0.015, 1.286438>
    rotate 90.0*y
    translate  <-0.63418, 3.46605, 0.686205>
  }
  object { // Cylndr120 -> Cylndr093
    Cylndr093
    translate  <0.0, 0.0, -0.25>
  }
  object { // Cylndr121 -> Cylndr093
    Cylndr093
    translate  <0.0, 0.0, -0.5>
  }
  object { // Cylndr122 -> Cylndr093
    Cylndr093
    translate  <0.0, 0.0, -0.606713>
  }
  translate  -3.464038*y
  rotate -90.0*z
  translate  <-0.645391, 2.831818, 0.0>
}
#declare Plate_forme = union {
  object { Cube033 }
  object { // Cube037 -> Cube033
    Cube033
    rotate 0.0*z
    translate  <0.3, 0.0, 0.0>
  }
  object { // Cube038 -> Cube033
    Cube033
    rotate 0.0*z
    translate  <0.6, 0.0, 0.0>
  }
  object { // Cube039 -> Cube033
    Cube033
    rotate 0.0*z
    translate  <0.9, 0.0, 0.0>
  }
  object { // Cube040 -> Cube033
    Cube033
    rotate 0.0*z
    translate  <1.2, 0.0, 0.0>
  }
  object { Cube041 }
  object { // Cube042 -> Cube041
    Cube041
    translate  -1.489747*y
  }
  object { Cube043 }
  object { // Cube044 -> Cube043
    Cube043
    rotate <0.0, 0.0, 0.0>
    translate  <0.6, 0.0, -0.0>
  }
  object { // Cube045 -> Cube043
    Cube043
    rotate <0.0, 0.0, 0.0>
    translate  <1.2, 0.0, -0.0>
  }
  box { // Cube046
    <-1, -1, -1>, <1, 1, 1>
    scale 0.5
    translate  <0.0, 0.5, 0.5>
    scale <1.25, 1.539747, 0.01>
    translate  <0.0, 1.914891, 0.08>
    material {
      Mat_tole_deployee
      // Transform to parent space
    }
  }
  object { Rembarde_plate_forme }
  object { Rembarde_plate_forme1 }
  object { Rembarde_plate_forme2 }
  object { Rembarde_plate_forme3 }
  material {
    T_peinture_rouge_norm
  }
  scale 1.25
  translate  30.066005*z
}
#include "homme_rambarde_moray.inc"

#declare Poseray_scene_object_Ref = object {
  Poseray_scene_object
  scale 0.02125
  rotate <90.0, 0.0, 43.455002>
  translate  <1.27956, -2.06439, 30.95207>
}
#declare Ensemble_tourelle = union {
  object { Calotte }
  object { Tourelle }
  object { Optique }
  object { Tourelle_interne }
  object { Poteau_drapeau }
  object { Cabine }
  object { // Cabine1 -> Cabine
    Cabine
    scale <1.0, -1.0, 1.0>
    rotate -45.0*z
  }
  object { Rembarde_cabine }
  object { Rembarde_tourelle }
  object { Plate_forme }
  object { Element_rembarde_ciment }
  object { // Element_rembarde_ciment1 -> Element_rembarde_ciment
    Element_rembarde_ciment
    rotate -45.0*z
  }
  object { // Element_rembarde_ciment2 -> Element_rembarde_ciment
    Element_rembarde_ciment
    rotate -90.0*z
  }
  object { // Element_rembarde_ciment3 -> Element_rembarde_ciment
    Element_rembarde_ciment
    rotate -135.0*z
  }
  object { // Element_rembarde_ciment4 -> Element_rembarde_ciment
    Element_rembarde_ciment
    rotate 180.0*z
  }
  object { // Element_rembarde_ciment5 -> Element_rembarde_ciment
    Element_rembarde_ciment
    rotate 135.0*z
  }
  object { // Element_rembarde_ciment6 -> Element_rembarde_ciment
    Element_rembarde_ciment
    rotate 90.0*z
  }
  object { // Element_rembarde_ciment7 -> Element_rembarde_ciment
    Element_rembarde_ciment
    rotate 45.0*z
  }
  object { Poseray_scene_object_Ref }
  translate  -28.942672*z
  scale 0.8
  translate  21.29*z
}
union { // Objets_phare
  object { Ensemble_porte }
  object { TMesh001 }
  object { Ensemble_tourelle }
}


object { // Poteau1 -> Poteau
  Poteau
}


object { Barres_mole }


object { // Barres_mole1 -> Barres_mole
  Barres_mole
}


object {   // HgtFld001
  height_field {
    tga "Terrain.tga"
    water_level 0.0
  }
  rotate    <-90, 0, 0> // Turn onto XY plane. Now points along -Z
  scale     <  2, 2,-2> // Scale to Cube size. Now points along +Z
  translate < -1,-1,-1> // Center around origin
  material {
    M_rocher
  }
  scale <30.0, 50.0, 20.0>
  translate  <-2.67726, -8.091834, -20.380528>
}






// Spline_rembarde
#include"transforms.inc"
#declare N_poteaux=30;

#declare Sph_res=1000;

#declare Intervalle=1/N_poteaux;
#declare Sph_inter=1/Sph_res;
#macro Posit(Objet)
#declare Position=(max_extent(Objet)+min_extent(Objet))/2;
#end
#declare Bastin_spline =spline{natural_spline
Posit (Pos_sphere8)
-.125,Position
Posit(Pos_sphere1)
0,Position
Posit(Pos_sphere2)
0.125, Position
Posit(Pos_sphere3)
0.25, Position
Posit(Pos_sphere4)
0.375, Position
Posit(Pos_sphere5)
.5, Position
Posit(Pos_sphere6)
0.625, Position
Posit(Pos_sphere7)
0.75, Position
Posit(Pos_sphere8)
0.875, Position
Posit(Pos_sphere1)
1, Position
Posit(Pos_sphere2)
1.125, Position


}

#declare Cnt_spline=0;
#while (Cnt_spline<1)
object{Poteau Spline_Trans( Bastin_spline, Cnt_spline, z, Intervalle,0)}
#declare Cnt_spline=Cnt_spline+Intervalle;
#end
#declare Cnt_spline=0;
union{
#while (Cnt_spline<1.01)
object{Barres_mole Spline_Trans( Bastin_spline, Cnt_spline, z, Sph_inter,0)}
#declare Cnt_spline=Cnt_spline+Sph_inter;
#end
material{M_rouille}
}















plane { // Plane001
  z,0
  material {
    Fond
  }
  translate  <0.002318, 0.005278, -41.159875>
}


sphere { // Ciel
  <0,0,0>,1
  material {
    M_ciel
    scale <1.0, 1.0, 0.1>
    translate <0.000000, 0.000000, 0.900000>
  }
  no_shadow
  double_illuminate
  hollow
  photons {
    pass_through
  }
  scale 10000.0
  translate  -9000.0*z
}




















union { // Goelands
  object { Goeland2 }
  object { // Goeland3 -> Goeland2
    Goeland2
    photons {
      collect off
    }
    rotate <-0.0, -22.73914, -48.477787>
    translate  <-14.72888, 8.350741, -10.183283>
  }
  object { // Goeland4 -> Goeland2
    Goeland2
    photons {
      collect off
    }
    rotate <-37.128716, -20.576864, 65.097649>
    translate  <-15.751825, -7.896476, -4.515166>
  }
  object { // Goeland5 -> Goeland2
    Goeland2
    photons {
      collect off
    }
    rotate <6.60469, 2.397628, 173.800217>
    translate  <-24.647729, -43.980655, -13.838622>
  }
  object { // Goeland6 -> Goeland2
    Goeland2
    photons {
      collect off
    }
    rotate <6.468207, -29.737965, 25.283091>
    translate  <3.41125, 4.406198, 0.0>
  }
  object { // Goeland7 -> Goeland2
    Goeland2
    photons {
      collect off
    }
    rotate <-4.72765, 10.995791, 66.559128>
    translate  <5.187943, -3.184914, -4.664202>
  }
  photons {
    collect off
  }
  translate  <6.853738, -3.339994, 19.364606>
}




// Iso_mole
#declare Diamx=3.5;
#declare Diamy=5;
#declare Haut=5;
#declare Conicite=0.05;
#declare Pig_pierres_mole=pigment
      {
         image_map
         {
            jpeg   "Pierres_mole.jpg"
interpolate 2
         }
scale <.5,1,1>
         warp {
         cylindrical 
         orientation z 
         dist_exp .0
       }
rotate x*-90
      }
 #declare Fn_mole=  function { sqrt(pow(x,2) + pow(y,2))+z*Conicite-1 }
#declare F_pierres_mole=function{pigment{Pig_pierres_mole}}

isosurface {   
  function { Fn_mole(x, y, z)-F_pierres_mole(x,y,z).gray*.02 }       
  contained_by { box {-1*<1+Conicite,1+Conicite,1>,<1+Conicite,1+Conicite,1> } }  
 
  accuracy 0.01                      
  max_gradient 1    
               
texture

{  pigment_pattern
      {
            gradient z
            color_map
            {
               [ 0.0     rgb 0 ]
               [ 1.0     rgb 1 ]
            }
warp{turbulence 0.1}
    translate z*-.5 scale 2.2  }
texture_map{


[0.5, pigment{Pig_pierres_mole }   finish   {      ambient 0.0      specular 1      roughness 0.001 diffuse 0  }]
[ 0.7,pigment{Pig_pierres_mole }   finish   {      ambient 0      specular 0.0     roughness 0.01 diffuse 1  }]
}

}

scale< Diamx,Diamy,Haut>}

//_______________________________________________________________________ Isosurface pour la mousse
 #declare Fn_mole_mousse=  function { sqrt(pow(x,2) + pow(y,2))+z*Conicite*1.3-1.01 }
difference{
isosurface {   
  function { Fn_mole_mousse(x, y, z)-F_pierres_mole(x,y,z).gray*.004 }       
  contained_by { box {-1*<1+Conicite,1+Conicite,1>,<1+Conicite,1+Conicite,.96> } }  
 
  accuracy 0.01                      
  max_gradient 1                      

scale< Diamx,Diamy,Haut> translate z*0.03}
object{IsoMer }
texture{ pigment{color rgb 1}finish{ambient 0 diffuse 1}}
}



